/* pci-ids.c
 *
 * pci-ids.c is based on the pci.ids of The PCI ID Repository at
 * https://pci-ids.ucw.cz/, fetched indirectly via
 * https://github.com/pciutils/pciids
 *
 * List of PCI ID's
 *
 * Version: 2024.06.23
 * Date:    2024-06-23 03:15:02
 *
 * Maintained by Albert Pool, Martin Mares, and other volunteers from
 * the PCI ID Project at https://pci-ids.ucw.cz/.
 *
 * New data are always welcome, especially if they are accurate. If you have
 * anything to contribute, please follow the instructions at the web site.
 *
 * This file can be distributed under either the GPL
 * (version 2 or higher) or the 3-clause BSD License.
 *
 *
 * Generated by tools/make-pci-ids.py
 * By Caleb Chiu <caleb.chiu@macnica.com>
 * Copyright 2021
 *
 *
 * SPDX-License-Identifier: GPL-2.0-or-later
 */

#include <config.h>

#include <stddef.h>
#include <stdlib.h>

#include "wsutil/array.h"

#include "pci-ids.h"

typedef struct
{
  uint16_t vid;
  uint16_t did;
  uint16_t svid;
  uint16_t ssid;
  const char *name;

} pci_id_t;

typedef struct
{
  uint16_t vid;
  uint16_t count;
  pci_id_t const *ids_ptr;

} pci_vid_index_t;

static pci_id_t const pci_vid_0001[] = {
{0x0001, 0xFFFF, 0xFFFF, 0xFFFF, "SafeNet (wrong ID)(0x0001)"},
}; /* pci_vid_0001[] */

static pci_id_t const pci_vid_0010[] = {
{0x0010, 0xFFFF, 0xFFFF, 0xFFFF, "Allied Telesis, Inc (Wrong ID)(0x0010)"},
{0x0010, 0x8139, 0xFFFF, 0xFFFF, "AT-2500TX V3 Ethernet(0x8139)"},
}; /* pci_vid_0010[] */

static pci_id_t const pci_vid_0014[] = {
{0x0014, 0xFFFF, 0xFFFF, 0xFFFF, "Loongson Technology LLC(0x0014)"},
{0x0014, 0x7A00, 0xFFFF, 0xFFFF, "Hyper Transport Bridge Controller(0x7A00)"},
{0x0014, 0x7A02, 0xFFFF, 0xFFFF, "APB (Advanced Peripheral Bus) Controller(0x7A02)"},
{0x0014, 0x7A03, 0xFFFF, 0xFFFF, "Gigabit Ethernet Controller(0x7A03)"},
{0x0014, 0x7A04, 0xFFFF, 0xFFFF, "OTG USB Controller(0x7A04)"},
{0x0014, 0x7A05, 0xFFFF, 0xFFFF, "Vivante GPU (Graphics Processing Unit)(0x7A05)"},
{0x0014, 0x7A06, 0xFFFF, 0xFFFF, "DC (Display Controller)(0x7A06)"},
{0x0014, 0x7A07, 0xFFFF, 0xFFFF, "HDA (High Definition Audio) Controller(0x7A07)"},
{0x0014, 0x7A08, 0xFFFF, 0xFFFF, "SATA AHCI Controller(0x7A08)"},
{0x0014, 0x7A09, 0xFFFF, 0xFFFF, "PCI-to-PCI Bridge(0x7A09)"},
{0x0014, 0x7A0B, 0xFFFF, 0xFFFF, "SPI Controller(0x7A0B)"},
{0x0014, 0x7A0C, 0xFFFF, 0xFFFF, "LPC Controller(0x7A0C)"},
{0x0014, 0x7A0F, 0xFFFF, 0xFFFF, "DMA (Direct Memory Access) Controller(0x7A0F)"},
{0x0014, 0x7A10, 0xFFFF, 0xFFFF, "Hyper Transport Bridge Controller(0x7A10)"},
{0x0014, 0x7A14, 0xFFFF, 0xFFFF, "EHCI USB Controller(0x7A14)"},
{0x0014, 0x7A15, 0xFFFF, 0xFFFF, "Vivante GPU (Graphics Processing Unit)(0x7A15)"},
{0x0014, 0x7A19, 0xFFFF, 0xFFFF, "PCI-to-PCI Bridge(0x7A19)"},
{0x0014, 0x7A24, 0xFFFF, 0xFFFF, "OHCI USB Controller(0x7A24)"},
{0x0014, 0x7A25, 0xFFFF, 0xFFFF, "LG100 GPU(0x7A25)"},
{0x0014, 0x7A29, 0xFFFF, 0xFFFF, "PCI-to-PCI Bridge(0x7A29)"},
{0x0014, 0x7A36, 0xFFFF, 0xFFFF, "Display Controller(0x7A36)"},
}; /* pci_vid_0014[] */

static pci_id_t const pci_vid_0018[] = {
{0x0018, 0xFFFF, 0xFFFF, 0xFFFF, "Fn-Link Technology Limited(0x0018)"},
{0x0018, 0x6252, 0xFFFF, 0xFFFF, "6252CPUB 802.11ax PCIe Wireless Network Adapter(0x6252)"},
}; /* pci_vid_0018[] */

static pci_id_t const pci_vid_001C[] = {
{0x001C, 0xFFFF, 0xFFFF, 0xFFFF, "PEAK-System Technik GmbH(0x001C)"},
{0x001C, 0x0001, 0xFFFF, 0xFFFF, "PCAN-PCI CAN-Bus controller(0x0001)"},
{0x001C, 0x0001, 0x001C, 0x0004, "2 Channel CAN Bus SJC1000(0x001C-0x0004)"},
{0x001C, 0x0001, 0x001C, 0x0005, "2 Channel CAN Bus SJC1000 (Optically Isolated)(0x001C-0x0005)"},
}; /* pci_vid_001C[] */

static pci_id_t const pci_vid_003D[] = {
{0x003D, 0xFFFF, 0xFFFF, 0xFFFF, "Lockheed Martin-Marietta Corp(0x003D)"},
}; /* pci_vid_003D[] */

static pci_id_t const pci_vid_0059[] = {
{0x0059, 0xFFFF, 0xFFFF, 0xFFFF, "Tiger Jet Network Inc. (Wrong ID)(0x0059)"},
}; /* pci_vid_0059[] */

static pci_id_t const pci_vid_0070[] = {
{0x0070, 0xFFFF, 0xFFFF, 0xFFFF, "Hauppauge computer works Inc.(0x0070)"},
{0x0070, 0x7801, 0xFFFF, 0xFFFF, "WinTV HVR-1800 MCE(0x7801)"},
}; /* pci_vid_0070[] */

static pci_id_t const pci_vid_0071[] = {
{0x0071, 0xFFFF, 0xFFFF, 0xFFFF, "Nebula Electronics Ltd.(0x0071)"},
}; /* pci_vid_0071[] */

static pci_id_t const pci_vid_0095[] = {
{0x0095, 0xFFFF, 0xFFFF, 0xFFFF, "Silicon Image, Inc. (Wrong ID)(0x0095)"},
{0x0095, 0x0680, 0xFFFF, 0xFFFF, "Ultra ATA/133 IDE RAID CONTROLLER CARD(0x0680)"},
}; /* pci_vid_0095[] */

static pci_id_t const pci_vid_00A7[] = {
{0x00A7, 0xFFFF, 0xFFFF, 0xFFFF, "Teles AG (Wrong ID)(0x00A7)"},
}; /* pci_vid_00A7[] */

static pci_id_t const pci_vid_0100[] = {
{0x0100, 0xFFFF, 0xFFFF, 0xFFFF, "nCipher Security(0x0100)"},
}; /* pci_vid_0100[] */

static pci_id_t const pci_vid_0123[] = {
{0x0123, 0xFFFF, 0xFFFF, 0xFFFF, "General Dynamics(0x0123)"},
}; /* pci_vid_0123[] */

static pci_id_t const pci_vid_0128[] = {
{0x0128, 0xFFFF, 0xFFFF, 0xFFFF, "Dell (wrong ID)(0x0128)"},
}; /* pci_vid_0128[] */

static pci_id_t const pci_vid_018A[] = {
{0x018A, 0xFFFF, 0xFFFF, 0xFFFF, "LevelOne(0x018A)"},
{0x018A, 0x0106, 0xFFFF, 0xFFFF, "FPC-0106TX misprogrammed [RTL81xx](0x0106)"},
}; /* pci_vid_018A[] */

static pci_id_t const pci_vid_01DE[] = {
{0x01DE, 0xFFFF, 0xFFFF, 0xFFFF, "Oxide Computer Company(0x01DE)"},
{0x01DE, 0x0000, 0xFFFF, 0xFFFF, "Propolis NVMe Controller(0x0000)"},
{0x01DE, 0x0001, 0xFFFF, 0xFFFF, "Propolis xHCI Controller(0x0001)"},
{0x01DE, 0x0002, 0xFFFF, 0xFFFF, "Propolis PCI-PCI Bridge(0x0002)"},
}; /* pci_vid_01DE[] */

static pci_id_t const pci_vid_0200[] = {
{0x0200, 0xFFFF, 0xFFFF, 0xFFFF, "Dell (wrong ID)(0x0200)"},
}; /* pci_vid_0200[] */

static pci_id_t const pci_vid_021B[] = {
{0x021B, 0xFFFF, 0xFFFF, 0xFFFF, "Compaq Computer Corporation(0x021B)"},
{0x021B, 0x8139, 0xFFFF, 0xFFFF, "HNE-300 (RealTek RTL8139c) [iPaq Networking](0x8139)"},
}; /* pci_vid_021B[] */

static pci_id_t const pci_vid_025E[] = {
{0x025E, 0xFFFF, 0xFFFF, 0xFFFF, "Solidigm(0x025E)"},
{0x025E, 0x0B60, 0xFFFF, 0xFFFF, "NVMe DC SSD [Sentinel Rock Plus controller](0x0B60)"},
{0x025E, 0x0B60, 0x025E, 0x8008, "NVMe DC SSD U.2 15mm [D7-P5510](0x025E-0x8008)"},
{0x025E, 0x0B60, 0x025E, 0x8208, "NVMe DC SSD U.2 15mm [D7-P5810](0x025E-0x8208)"},
{0x025E, 0x0B60, 0x025E, 0x8D1D, "NVMe DC SSD E1.L 9.5mm [D5-P5316](0x025E-0x8D1D)"},
{0x025E, 0x0B60, 0x025E, 0x9008, "NVMe DC SSD U.2 15mm [D7-P5520](0x025E-0x9008)"},
{0x025E, 0x0B60, 0x025E, 0x900C, "NVMe DC SSD E1.S 9.5mm [D7-P5520](0x025E-0x900C)"},
{0x025E, 0x0B60, 0x025E, 0x900D, "NVMe DC SSD E1.S 15mm [D7-P5520](0x025E-0x900D)"},
{0x025E, 0x0B60, 0x025E, 0x901C, "NVMe DC SSD E1.L 9.5mm [D7-P5520](0x025E-0x901C)"},
{0x025E, 0x0B60, 0x025E, 0x9108, "NVMe DC SSD U.2 15mm [D7-P5620](0x025E-0x9108)"},
{0x025E, 0x0B60, 0x025E, 0xC008, "NVMe DC SSD U.2 15mm [D5-P5530](0x025E-0xC008)"},
{0x025E, 0x0B60, 0x025E, 0xD408, "NVMe DC SSD U.2 15mm [D5-P5430](0x025E-0xD408)"},
{0x025E, 0x0B60, 0x025E, 0xD40C, "NVMe DC SSD E1.S 9.5mm [D5-P5430](0x025E-0xD40C)"},
{0x025E, 0x0B60, 0x025E, 0xD419, "NVMe DC SSD E3.S 7.5mm [D5-P5430](0x025E-0xD419)"},
{0x025E, 0x0B60, 0x025E, 0xD808, "NVMe DC SSD U.2 15mm [D5-P5336](0x025E-0xD808)"},
{0x025E, 0x0B60, 0x025E, 0xD819, "NVMe DC SSD E3.S 7.5mm [D5-P5336](0x025E-0xD819)"},
{0x025E, 0x0B60, 0x025E, 0xD81C, "NVMe DC SSD E1.L 18mm [D5-P5336](0x025E-0xD81C)"},
{0x025E, 0x0B60, 0x025E, 0xD81D, "NVMe DC SSD E1.L 9.5mm [D5-P5336](0x025E-0xD81D)"},
{0x025E, 0x0B70, 0xFFFF, 0xFFFF, "NVMe DC SSD [Yorktown controller](0x0B70)"},
{0x025E, 0x2B59, 0xFFFF, 0xFFFF, "NVMe DC SSD [Atomos Prime](0x2B59)"},
{0x025E, 0x2B59, 0x025E, 0x0008, "NVMe DC SSD U.2-SFF 15mm [D7-PS1010](0x025E-0x0008)"},
{0x025E, 0x2B59, 0x025E, 0x0019, "NVMe DC SSD E3.S-1T 7.5mm [D7-PS1010](0x025E-0x0019)"},
{0x025E, 0x2B59, 0x025E, 0x0108, "NVMe DC SSD U.2-SFF 15mm [D7-PS1030](0x025E-0x0108)"},
{0x025E, 0x2B59, 0x025E, 0x0119, "NVMe DC SSD E3.S-1T 7.5mm [D7-PS1030](0x025E-0x0119)"},
{0x025E, 0x2B59, 0x108E, 0x48A0, "NVMe DC SSD U.2-SFF 15mm 3.84TB [D7-PS1010 Custom](0x108E-0x48A0)"},
{0x025E, 0x2B59, 0x108E, 0x48A1, "NVMe DC SSD U.2-SFF 15mm 7.68TB [D7-PS1010 Custom](0x108E-0x48A1)"},
{0x025E, 0x2B59, 0x108E, 0x48A2, "NVMe DC SSD U.2-SFF 15mm 15.36TB [D7-PS1010 Custom](0x108E-0x48A2)"},
{0x025E, 0x2B59, 0x108E, 0x48A3, "NVMe DC SSD Add-In-Card [D7-PS1030 Custom](0x108E-0x48A3)"},
{0x025E, 0x2B59, 0x108E, 0x48A4, "NVMe DC SSD E3.S-1T 7.5mm 3.84TB [D7-PS1010 Custom](0x108E-0x48A4)"},
{0x025E, 0x2B59, 0x108E, 0x48A5, "NVMe DC SSD E3.S-1T 7.5mm 7.68TB [D7-PS1010 Custom](0x108E-0x48A5)"},
{0x025E, 0x2B59, 0x108E, 0x48A6, "NVMe DC SSD E3.S-1T 7.5mm 15.36TB [D7-PS1010 Custom](0x108E-0x48A6)"},
{0x025E, 0xF1AB, 0xFFFF, 0xFFFF, "P41 Plus NVMe SSD (DRAM-less) [Echo Harbor](0xF1AB)"},
{0x025E, 0xF1AC, 0xFFFF, 0xFFFF, "P44 Pro NVMe SSD [Hollywood Beach](0xF1AC)"},
}; /* pci_vid_025E[] */

static pci_id_t const pci_vid_0270[] = {
{0x0270, 0xFFFF, 0xFFFF, 0xFFFF, "Hauppauge computer works Inc. (Wrong ID)(0x0270)"},
}; /* pci_vid_0270[] */

static pci_id_t const pci_vid_0291[] = {
{0x0291, 0xFFFF, 0xFFFF, 0xFFFF, "Davicom Semiconductor, Inc. (Wrong ID)(0x0291)"},
}; /* pci_vid_0291[] */

static pci_id_t const pci_vid_02AC[] = {
{0x02AC, 0xFFFF, 0xFFFF, 0xFFFF, "SpeedStream(0x02AC)"},
{0x02AC, 0x1012, 0xFFFF, 0xFFFF, "1012 PCMCIA 10/100 Ethernet Card [RTL81xx](0x1012)"},
}; /* pci_vid_02AC[] */

static pci_id_t const pci_vid_02E0[] = {
{0x02E0, 0xFFFF, 0xFFFF, 0xFFFF, "XFX Pine Group Inc. (Wrong ID)(0x02E0)"},
}; /* pci_vid_02E0[] */

static pci_id_t const pci_vid_0303[] = {
{0x0303, 0xFFFF, 0xFFFF, 0xFFFF, "Hewlett-Packard Company (Wrong ID)(0x0303)"},
}; /* pci_vid_0303[] */

static pci_id_t const pci_vid_0308[] = {
{0x0308, 0xFFFF, 0xFFFF, 0xFFFF, "ZyXEL Communications Corporation (Wrong ID)(0x0308)"},
}; /* pci_vid_0308[] */

static pci_id_t const pci_vid_0315[] = {
{0x0315, 0xFFFF, 0xFFFF, 0xFFFF, "SK-Electronics Co., Ltd.(0x0315)"},
}; /* pci_vid_0315[] */

static pci_id_t const pci_vid_0357[] = {
{0x0357, 0xFFFF, 0xFFFF, 0xFFFF, "TTTech Computertechnik AG (Wrong ID)(0x0357)"},
{0x0357, 0x000A, 0xFFFF, 0xFFFF, "TTP-Monitoring Card V2.0(0x000A)"},
}; /* pci_vid_0357[] */

static pci_id_t const pci_vid_0432[] = {
{0x0432, 0xFFFF, 0xFFFF, 0xFFFF, "SCM Microsystems, Inc.(0x0432)"},
{0x0432, 0x0001, 0xFFFF, 0xFFFF, "Pluto2 DVB-T Receiver for PCMCIA [EasyWatch MobilSet](0x0001)"},
}; /* pci_vid_0432[] */

static pci_id_t const pci_vid_0497[] = {
{0x0497, 0xFFFF, 0xFFFF, 0xFFFF, "Dell Inc. (wrong ID)(0x0497)"},
}; /* pci_vid_0497[] */

static pci_id_t const pci_vid_060E[] = {
{0x060E, 0xFFFF, 0xFFFF, 0xFFFF, "Lightelligence(0x060E)"},
{0x060E, 0x0001, 0xFFFF, 0xFFFF, "Hummingbird ES(0x0001)"},
}; /* pci_vid_060E[] */

static pci_id_t const pci_vid_0675[] = {
{0x0675, 0xFFFF, 0xFFFF, 0xFFFF, "Dynalink(0x0675)"},
{0x0675, 0x1700, 0xFFFF, 0xFFFF, "IS64PH ISDN Adapter(0x1700)"},
{0x0675, 0x1702, 0xFFFF, 0xFFFF, "IS64PH ISDN Adapter(0x1702)"},
{0x0675, 0x1703, 0xFFFF, 0xFFFF, "ISDN Adapter (PCI Bus, DV, W)(0x1703)"},
{0x0675, 0x1704, 0xFFFF, 0xFFFF, "ISDN Adapter (PCI Bus, D, C)(0x1704)"},
}; /* pci_vid_0675[] */

static pci_id_t const pci_vid_0721[] = {
{0x0721, 0xFFFF, 0xFFFF, 0xFFFF, "Sapphire, Inc.(0x0721)"},
}; /* pci_vid_0721[] */

static pci_id_t const pci_vid_0731[] = {
{0x0731, 0xFFFF, 0xFFFF, 0xFFFF, "Jingjia Microelectronics Co Ltd(0x0731)"},
{0x0731, 0x7200, 0xFFFF, 0xFFFF, "JM7200 Series GPU(0x7200)"},
{0x0731, 0x7200, 0x0731, 0x7201, "JM7201(0x0731-0x7201)"},
{0x0731, 0x7200, 0x0731, 0x7202, "JM7202(0x0731-0x7202)"},
{0x0731, 0x7200, 0x0731, 0x7208, "JM7200(0x0731-0x7208)"},
{0x0731, 0x7200, 0x0731, 0x7212, "JM7200(0x0731-0x7212)"},
{0x0731, 0x7200, 0x0731, 0x7214, "JM7500(0x0731-0x7214)"},
{0x0731, 0x7200, 0x0731, 0x7215, "JM7200(0x0731-0x7215)"},
{0x0731, 0x9100, 0xFFFF, 0xFFFF, "JM9100(0x9100)"},
{0x0731, 0x9100, 0x0731, 0x9101, "JM9100(0x0731-0x9101)"},
{0x0731, 0x9100, 0x0731, 0x9102, "JM9100-I(0x0731-0x9102)"},
{0x0731, 0x9100, 0x0731, 0x9103, "JM9100M(0x0731-0x9103)"},
{0x0731, 0x910A, 0xFFFF, 0xFFFF, "JH910(0x910A)"},
{0x0731, 0x910A, 0x0731, 0x910A, "JH910(0x0731-0x910A)"},
{0x0731, 0x910A, 0x0731, 0x910B, "JH910-I(0x0731-0x910B)"},
{0x0731, 0x910A, 0x0731, 0x910C, "JH910-M(0x0731-0x910C)"},
{0x0731, 0x9200, 0xFFFF, 0xFFFF, "JM9200(0x9200)"},
{0x0731, 0x920A, 0xFFFF, 0xFFFF, "JH920(0x920A)"},
{0x0731, 0x920A, 0x0731, 0x920A, "JH920(0x0731-0x920A)"},
{0x0731, 0x920A, 0x0731, 0x920B, "JH920-I(0x0731-0x920B)"},
{0x0731, 0x920A, 0x0731, 0x920C, "JH920-M(0x0731-0x920C)"},
{0x0731, 0x920B, 0xFFFF, 0xFFFF, "JH920-I(0x920B)"},
{0x0731, 0x920C, 0xFFFF, 0xFFFF, "JH920-M(0x920C)"},
{0x0731, 0x9210, 0xFFFF, 0xFFFF, "JM9210(0x9210)"},
{0x0731, 0x9210, 0x0731, 0x9210, "JM9210(0x0731-0x9210)"},
{0x0731, 0x9210, 0x0731, 0x9211, "JM9210-I(0x0731-0x9211)"},
{0x0731, 0x9211, 0xFFFF, 0xFFFF, "JM9210-I(0x9211)"},
{0x0731, 0x9230, 0xFFFF, 0xFFFF, "JM9230(0x9230)"},
{0x0731, 0x9230, 0x0731, 0x9230, "JM9230(0x0731-0x9230)"},
{0x0731, 0x9230, 0x0731, 0x9231, "JM9230-I(0x0731-0x9231)"},
{0x0731, 0x9231, 0xFFFF, 0xFFFF, "JM9231-I(0x9231)"},
{0x0731, 0x9250, 0xFFFF, 0xFFFF, "JM9250(0x9250)"},
{0x0731, 0x9250, 0x0731, 0x9250, "JM9250(0x0731-0x9250)"},
{0x0731, 0x930A, 0xFFFF, 0xFFFF, "JH930-I(0x930A)"},
{0x0731, 0x930A, 0x0731, 0x930A, "JH930-I(0x0731-0x930A)"},
{0x0731, 0x930A, 0x0731, 0x930B, "JH930-M(0x0731-0x930B)"},
{0x0731, 0x930A, 0x0731, 0x930C, "JH930(0x0731-0x930C)"},
{0x0731, 0x930B, 0xFFFF, 0xFFFF, "JH930-M(0x930B)"},
}; /* pci_vid_0731[] */

static pci_id_t const pci_vid_0777[] = {
{0x0777, 0xFFFF, 0xFFFF, 0xFFFF, "Ubiquiti Networks, Inc.(0x0777)"},
}; /* pci_vid_0777[] */

static pci_id_t const pci_vid_0795[] = {
{0x0795, 0xFFFF, 0xFFFF, 0xFFFF, "Wired Inc.(0x0795)"},
{0x0795, 0x6663, 0xFFFF, 0xFFFF, "Butane II (MPEG2 encoder board)(0x6663)"},
{0x0795, 0x6666, 0xFFFF, 0xFFFF, "MediaPress (MPEG2 encoder board)(0x6666)"},
}; /* pci_vid_0795[] */

static pci_id_t const pci_vid_07D1[] = {
{0x07D1, 0xFFFF, 0xFFFF, 0xFFFF, "D-Link System Inc(0x07D1)"},
}; /* pci_vid_07D1[] */

static pci_id_t const pci_vid_0824[] = {
{0x0824, 0xFFFF, 0xFFFF, 0xFFFF, "T1042 [Freescale](0x0824)"},
}; /* pci_vid_0824[] */

static pci_id_t const pci_vid_0925[] = {
{0x0925, 0xFFFF, 0xFFFF, 0xFFFF, "VIA Technologies, Inc. (Wrong ID)(0x0925)"},
}; /* pci_vid_0925[] */

static pci_id_t const pci_vid_0A89[] = {
{0x0A89, 0xFFFF, 0xFFFF, 0xFFFF, "BREA Technologies Inc(0x0A89)"},
}; /* pci_vid_0A89[] */

static pci_id_t const pci_vid_0B0B[] = {
{0x0B0B, 0xFFFF, 0xFFFF, 0xFFFF, "Rhino Equipment Corp.(0x0B0B)"},
{0x0B0B, 0x0105, 0xFFFF, 0xFFFF, "R1T1(0x0105)"},
{0x0B0B, 0x0205, 0xFFFF, 0xFFFF, "R4FXO(0x0205)"},
{0x0B0B, 0x0206, 0xFFFF, 0xFFFF, "RCB4FXO 4-channel FXO analog telephony card(0x0206)"},
{0x0B0B, 0x0305, 0xFFFF, 0xFFFF, "R4T1(0x0305)"},
{0x0B0B, 0x0405, 0xFFFF, 0xFFFF, "R8FXX(0x0405)"},
{0x0B0B, 0x0406, 0xFFFF, 0xFFFF, "RCB8FXX 8-channel modular analog telephony card(0x0406)"},
{0x0B0B, 0x0505, 0xFFFF, 0xFFFF, "R24FXX(0x0505)"},
{0x0B0B, 0x0506, 0xFFFF, 0xFFFF, "RCB24FXS 24-Channel FXS analog telephony card(0x0506)"},
{0x0B0B, 0x0605, 0xFFFF, 0xFFFF, "R2T1(0x0605)"},
{0x0B0B, 0x0705, 0xFFFF, 0xFFFF, "R24FXS(0x0705)"},
{0x0B0B, 0x0706, 0xFFFF, 0xFFFF, "RCB24FXO 24-Channel FXO analog telephony card(0x0706)"},
{0x0B0B, 0x0905, 0xFFFF, 0xFFFF, "R1T3 Single T3 Digital Telephony Card(0x0905)"},
{0x0B0B, 0x0906, 0xFFFF, 0xFFFF, "RCB24FXX 24-channel modular analog telephony card(0x0906)"},
{0x0B0B, 0x0A06, 0xFFFF, 0xFFFF, "RCB672FXX 672-channel modular analog telephony card(0x0A06)"},
}; /* pci_vid_0B0B[] */

static pci_id_t const pci_vid_0BAE[] = {
{0x0BAE, 0xFFFF, 0xFFFF, 0xFFFF, "Bachmann electronic GmbH(0x0BAE)"},
}; /* pci_vid_0BAE[] */

static pci_id_t const pci_vid_0CCD[] = {
{0x0CCD, 0xFFFF, 0xFFFF, 0xFFFF, "Preferred Networks, Inc.(0x0CCD)"},
{0x0CCD, 0x0110, 0xFFFF, 0xFFFF, "MN-Core(0x0110)"},
{0x0CCD, 0x0120, 0xFFFF, 0xFFFF, "MN-Core 2(0x0120)"},
{0x0CCD, 0x0120, 0x0CCD, 0x0000, "MN-Core 2 16GB(0x0CCD-0x0000)"},
{0x0CCD, 0x0120, 0x0CCD, 0x0010, "MN-Core 2 32GB(0x0CCD-0x0010)"},
{0x0CCD, 0x0200, 0xFFFF, 0xFFFF, "MN-Core Direct Connect(0x0200)"},
{0x0CCD, 0x0201, 0xFFFF, 0xFFFF, "MN-Core 2 Middle-plane(0x0201)"},
}; /* pci_vid_0CCD[] */

static pci_id_t const pci_vid_0E11[] = {
{0x0E11, 0xFFFF, 0xFFFF, 0xFFFF, "Compaq Computer Corporation(0x0E11)"},
{0x0E11, 0x0001, 0xFFFF, 0xFFFF, "PCI to EISA Bridge(0x0001)"},
{0x0E11, 0x0002, 0xFFFF, 0xFFFF, "PCI to ISA Bridge(0x0002)"},
{0x0E11, 0x0046, 0xFFFF, 0xFFFF, "Smart Array 64xx(0x0046)"},
{0x0E11, 0x0046, 0x0E11, 0x4091, "Smart Array 6i(0x0E11-0x4091)"},
{0x0E11, 0x0046, 0x0E11, 0x409A, "Smart Array 641(0x0E11-0x409A)"},
{0x0E11, 0x0046, 0x0E11, 0x409B, "Smart Array 642(0x0E11-0x409B)"},
{0x0E11, 0x0046, 0x0E11, 0x409C, "Smart Array 6400(0x0E11-0x409C)"},
{0x0E11, 0x0046, 0x0E11, 0x409D, "Smart Array 6400 EM(0x0E11-0x409D)"},
{0x0E11, 0x0049, 0xFFFF, 0xFFFF, "NC7132 Gigabit Upgrade Module(0x0049)"},
{0x0E11, 0x004A, 0xFFFF, 0xFFFF, "NC6136 Gigabit Server Adapter(0x004A)"},
{0x0E11, 0x005A, 0xFFFF, 0xFFFF, "Remote Insight II board - Lights-Out(0x005A)"},
{0x0E11, 0x007C, 0xFFFF, 0xFFFF, "NC7770 1000BaseTX(0x007C)"},
{0x0E11, 0x007D, 0xFFFF, 0xFFFF, "NC6770 1000BaseTX(0x007D)"},
{0x0E11, 0x0085, 0xFFFF, 0xFFFF, "NC7780 1000BaseTX(0x0085)"},
{0x0E11, 0x00B1, 0xFFFF, 0xFFFF, "Remote Insight II board - PCI device(0x00B1)"},
{0x0E11, 0x00BB, 0xFFFF, 0xFFFF, "NC7760(0x00BB)"},
{0x0E11, 0x00CA, 0xFFFF, 0xFFFF, "NC7771(0x00CA)"},
{0x0E11, 0x00CB, 0xFFFF, 0xFFFF, "NC7781(0x00CB)"},
{0x0E11, 0x00CF, 0xFFFF, 0xFFFF, "NC7772(0x00CF)"},
{0x0E11, 0x00D0, 0xFFFF, 0xFFFF, "NC7782(0x00D0)"},
{0x0E11, 0x00D1, 0xFFFF, 0xFFFF, "NC7783(0x00D1)"},
{0x0E11, 0x00E3, 0xFFFF, 0xFFFF, "NC7761(0x00E3)"},
{0x0E11, 0x0508, 0xFFFF, 0xFFFF, "Netelligent 4/16 Token Ring(0x0508)"},
{0x0E11, 0x1000, 0xFFFF, 0xFFFF, "Triflex/Pentium Bridge, Model 1000(0x1000)"},
{0x0E11, 0x2000, 0xFFFF, 0xFFFF, "Triflex/Pentium Bridge, Model 2000(0x2000)"},
{0x0E11, 0x3032, 0xFFFF, 0xFFFF, "QVision 1280/p(0x3032)"},
{0x0E11, 0x3033, 0xFFFF, 0xFFFF, "QVision 1280/p(0x3033)"},
{0x0E11, 0x3034, 0xFFFF, 0xFFFF, "QVision 1280/p(0x3034)"},
{0x0E11, 0x4000, 0xFFFF, 0xFFFF, "4000 [Triflex](0x4000)"},
{0x0E11, 0x4040, 0xFFFF, 0xFFFF, "Integrated Array(0x4040)"},
{0x0E11, 0x4048, 0xFFFF, 0xFFFF, "Compaq Raid LC2(0x4048)"},
{0x0E11, 0x4050, 0xFFFF, 0xFFFF, "Smart Array 4200(0x4050)"},
{0x0E11, 0x4051, 0xFFFF, 0xFFFF, "Smart Array 4250ES(0x4051)"},
{0x0E11, 0x4058, 0xFFFF, 0xFFFF, "Smart Array 431(0x4058)"},
{0x0E11, 0x4070, 0xFFFF, 0xFFFF, "Smart Array 5300(0x4070)"},
{0x0E11, 0x4080, 0xFFFF, 0xFFFF, "Smart Array 5i(0x4080)"},
{0x0E11, 0x4082, 0xFFFF, 0xFFFF, "Smart Array 532(0x4082)"},
{0x0E11, 0x4083, 0xFFFF, 0xFFFF, "Smart Array 5312(0x4083)"},
{0x0E11, 0x4091, 0xFFFF, 0xFFFF, "Smart Array 6i(0x4091)"},
{0x0E11, 0x409A, 0xFFFF, 0xFFFF, "Smart Array 641(0x409A)"},
{0x0E11, 0x409B, 0xFFFF, 0xFFFF, "Smart Array 642(0x409B)"},
{0x0E11, 0x409C, 0xFFFF, 0xFFFF, "Smart Array 6400(0x409C)"},
{0x0E11, 0x409D, 0xFFFF, 0xFFFF, "Smart Array 6400 EM(0x409D)"},
{0x0E11, 0x6010, 0xFFFF, 0xFFFF, "HotPlug PCI Bridge 6010(0x6010)"},
{0x0E11, 0x7020, 0xFFFF, 0xFFFF, "USB Controller(0x7020)"},
{0x0E11, 0xA0EC, 0xFFFF, 0xFFFF, "Fibre Channel Host Controller(0xA0EC)"},
{0x0E11, 0xA0F0, 0xFFFF, 0xFFFF, "Advanced System Management Controller(0xA0F0)"},
{0x0E11, 0xA0F0, 0x0E11, 0xB0F3, "ProLiant DL360(0x0E11-0xB0F3)"},
{0x0E11, 0xA0F3, 0xFFFF, 0xFFFF, "Triflex PCI to ISA Bridge(0xA0F3)"},
{0x0E11, 0xA0F7, 0xFFFF, 0xFFFF, "PCI Hotplug Controller(0xA0F7)"},
{0x0E11, 0xA0F7, 0x8086, 0x002A, "PCI Hotplug Controller A(0x8086-0x002A)"},
{0x0E11, 0xA0F7, 0x8086, 0x002B, "PCI Hotplug Controller B(0x8086-0x002B)"},
{0x0E11, 0xA0F8, 0xFFFF, 0xFFFF, "ZFMicro Chipset USB(0xA0F8)"},
{0x0E11, 0xA0FC, 0xFFFF, 0xFFFF, "FibreChannel HBA Tachyon(0xA0FC)"},
{0x0E11, 0xAE10, 0xFFFF, 0xFFFF, "Smart-2/P RAID Controller(0xAE10)"},
{0x0E11, 0xAE10, 0x0E11, 0x4030, "Smart-2/P Array Controller(0x0E11-0x4030)"},
{0x0E11, 0xAE10, 0x0E11, 0x4031, "Smart-2SL Array Controller(0x0E11-0x4031)"},
{0x0E11, 0xAE10, 0x0E11, 0x4032, "Smart Array 3200 Controller(0x0E11-0x4032)"},
{0x0E11, 0xAE10, 0x0E11, 0x4033, "Smart Array 3100ES Controller(0x0E11-0x4033)"},
{0x0E11, 0xAE10, 0x0E11, 0x4034, "Smart Array 221 Controller(0x0E11-0x4034)"},
{0x0E11, 0xAE29, 0xFFFF, 0xFFFF, "MIS-L(0xAE29)"},
{0x0E11, 0xAE2A, 0xFFFF, 0xFFFF, "MPC(0xAE2A)"},
{0x0E11, 0xAE2B, 0xFFFF, 0xFFFF, "MIS-E(0xAE2B)"},
{0x0E11, 0xAE31, 0xFFFF, 0xFFFF, "System Management Controller(0xAE31)"},
{0x0E11, 0xAE32, 0xFFFF, 0xFFFF, "Netelligent 10/100 TX PCI UTP(0xAE32)"},
{0x0E11, 0xAE33, 0xFFFF, 0xFFFF, "Triflex Dual EIDE Controller(0xAE33)"},
{0x0E11, 0xAE34, 0xFFFF, 0xFFFF, "Netelligent 10 T PCI UTP(0xAE34)"},
{0x0E11, 0xAE35, 0xFFFF, 0xFFFF, "Integrated NetFlex-3/P(0xAE35)"},
{0x0E11, 0xAE40, 0xFFFF, 0xFFFF, "Netelligent Dual 10/100 TX PCI UTP(0xAE40)"},
{0x0E11, 0xAE43, 0xFFFF, 0xFFFF, "Netelligent Integrated 10/100 TX UTP(0xAE43)"},
{0x0E11, 0xAE69, 0xFFFF, 0xFFFF, "CETUS-L(0xAE69)"},
{0x0E11, 0xAE6C, 0xFFFF, 0xFFFF, "Northstar(0xAE6C)"},
{0x0E11, 0xAE6D, 0xFFFF, 0xFFFF, "NorthStar CPU to PCI Bridge(0xAE6D)"},
{0x0E11, 0xB011, 0xFFFF, 0xFFFF, "Netelligent 10/100 TX Embedded UTP(0xB011)"},
{0x0E11, 0xB012, 0xFFFF, 0xFFFF, "Netelligent 10 T/2 PCI UTP/Coax(0xB012)"},
{0x0E11, 0xB01E, 0xFFFF, 0xFFFF, "NC3120 Fast Ethernet NIC(0xB01E)"},
{0x0E11, 0xB01F, 0xFFFF, 0xFFFF, "NC3122 Fast Ethernet NIC(0xB01F)"},
{0x0E11, 0xB02F, 0xFFFF, 0xFFFF, "NC1120 Ethernet NIC(0xB02F)"},
{0x0E11, 0xB030, 0xFFFF, 0xFFFF, "Netelligent 10/100 TX UTP(0xB030)"},
{0x0E11, 0xB04A, 0xFFFF, 0xFFFF, "10/100 TX PCI Intel WOL UTP Controller(0xB04A)"},
{0x0E11, 0xB060, 0xFFFF, 0xFFFF, "Smart Array 5300 Controller(0xB060)"},
{0x0E11, 0xB0C6, 0xFFFF, 0xFFFF, "NC3161 Fast Ethernet NIC(0xB0C6)"},
{0x0E11, 0xB0C7, 0xFFFF, 0xFFFF, "NC3160 Fast Ethernet NIC(0xB0C7)"},
{0x0E11, 0xB0D7, 0xFFFF, 0xFFFF, "NC3121 Fast Ethernet NIC(0xB0D7)"},
{0x0E11, 0xB0DD, 0xFFFF, 0xFFFF, "NC3131 Fast Ethernet NIC(0xB0DD)"},
{0x0E11, 0xB0DE, 0xFFFF, 0xFFFF, "NC3132 Fast Ethernet Module(0xB0DE)"},
{0x0E11, 0xB0DF, 0xFFFF, 0xFFFF, "NC6132 Gigabit Module(0xB0DF)"},
{0x0E11, 0xB0E0, 0xFFFF, 0xFFFF, "NC6133 Gigabit Module(0xB0E0)"},
{0x0E11, 0xB0E1, 0xFFFF, 0xFFFF, "NC3133 Fast Ethernet Module(0xB0E1)"},
{0x0E11, 0xB123, 0xFFFF, 0xFFFF, "NC6134 Gigabit NIC(0xB123)"},
{0x0E11, 0xB134, 0xFFFF, 0xFFFF, "NC3163 Fast Ethernet NIC(0xB134)"},
{0x0E11, 0xB13C, 0xFFFF, 0xFFFF, "NC3162 Fast Ethernet NIC(0xB13C)"},
{0x0E11, 0xB144, 0xFFFF, 0xFFFF, "NC3123 Fast Ethernet NIC(0xB144)"},
{0x0E11, 0xB163, 0xFFFF, 0xFFFF, "NC3134 Fast Ethernet NIC(0xB163)"},
{0x0E11, 0xB164, 0xFFFF, 0xFFFF, "NC3165 Fast Ethernet Upgrade Module(0xB164)"},
{0x0E11, 0xB178, 0xFFFF, 0xFFFF, "Smart Array 5i/532(0xB178)"},
{0x0E11, 0xB178, 0x0E11, 0x4080, "Smart Array 5i(0x0E11-0x4080)"},
{0x0E11, 0xB178, 0x0E11, 0x4082, "Smart Array 532(0x0E11-0x4082)"},
{0x0E11, 0xB178, 0x0E11, 0x4083, "Smart Array 5312(0x0E11-0x4083)"},
{0x0E11, 0xB1A4, 0xFFFF, 0xFFFF, "NC7131 Gigabit Server Adapter(0xB1A4)"},
{0x0E11, 0xB200, 0xFFFF, 0xFFFF, "Memory Hot-Plug Controller(0xB200)"},
{0x0E11, 0xB203, 0xFFFF, 0xFFFF, "Integrated Lights Out Controller(0xB203)"},
{0x0E11, 0xB203, 0x103C, 0x3305, "iLO2(0x103C-0x3305)"},
{0x0E11, 0xB204, 0xFFFF, 0xFFFF, "Integrated Lights Out  Processor(0xB204)"},
{0x0E11, 0xB204, 0x103C, 0x3305, "iLO2(0x103C-0x3305)"},
{0x0E11, 0xC000, 0xFFFF, 0xFFFF, "Remote Insight Lights-Out Edition(0xC000)"},
{0x0E11, 0xF130, 0xFFFF, 0xFFFF, "NetFlex-3/P ThunderLAN 1.0(0xF130)"},
{0x0E11, 0xF150, 0xFFFF, 0xFFFF, "NetFlex-3/P ThunderLAN 2.3(0xF150)"},
}; /* pci_vid_0E11[] */

static pci_id_t const pci_vid_0E55[] = {
{0x0E55, 0xFFFF, 0xFFFF, 0xFFFF, "HaSoTec GmbH(0x0E55)"},
}; /* pci_vid_0E55[] */

static pci_id_t const pci_vid_0EAC[] = {
{0x0EAC, 0xFFFF, 0xFFFF, 0xFFFF, "SHF Communication Technologies AG(0x0EAC)"},
{0x0EAC, 0x0008, 0xFFFF, 0xFFFF, "Ethernet Powerlink Managing Node 01(0x0008)"},
}; /* pci_vid_0EAC[] */

static pci_id_t const pci_vid_0F62[] = {
{0x0F62, 0xFFFF, 0xFFFF, 0xFFFF, "Acrox Technologies Co., Ltd.(0x0F62)"},
}; /* pci_vid_0F62[] */

static pci_id_t const pci_vid_1000[] = {
{0x1000, 0xFFFF, 0xFFFF, 0xFFFF, "Broadcom / LSI(0x1000)"},
{0x1000, 0x0001, 0xFFFF, 0xFFFF, "53c810(0x0001)"},
{0x1000, 0x0001, 0x1000, 0x1000, "LSI53C810AE PCI to SCSI I/O Processor(0x1000-0x1000)"},
{0x1000, 0x0002, 0xFFFF, 0xFFFF, "53c820(0x0002)"},
{0x1000, 0x0003, 0xFFFF, 0xFFFF, "53c825(0x0003)"},
{0x1000, 0x0003, 0x1000, 0x1000, "LSI53C825AE PCI to SCSI I/O Processor (Ultra Wide)(0x1000-0x1000)"},
{0x1000, 0x0004, 0xFFFF, 0xFFFF, "53c815(0x0004)"},
{0x1000, 0x0005, 0xFFFF, 0xFFFF, "53c810AP(0x0005)"},
{0x1000, 0x0006, 0xFFFF, 0xFFFF, "53c860(0x0006)"},
{0x1000, 0x0006, 0x1000, 0x1000, "LSI53C860E PCI to Ultra SCSI I/O Processor(0x1000-0x1000)"},
{0x1000, 0x000A, 0xFFFF, 0xFFFF, "53c1510(0x000A)"},
{0x1000, 0x000A, 0x0E11, 0xB143, "Integrated Dual Channel Wide Ultra2 SCSI Controller(0x0E11-0xB143)"},
{0x1000, 0x000A, 0x1000, 0x1000, "LSI53C1510 PCI to Dual Channel Wide Ultra2 SCSI Controller (Nonintelligent mode)(0x1000-0x1000)"},
{0x1000, 0x000B, 0xFFFF, 0xFFFF, "53C896/897(0x000B)"},
{0x1000, 0x000B, 0x0E11, 0x6004, "EOB003 Series SCSI host adapter(0x0E11-0x6004)"},
{0x1000, 0x000B, 0x1000, 0x1000, "LSI53C896/7 PCI to Dual Channel Ultra2 SCSI Multifunction Controller(0x1000-0x1000)"},
{0x1000, 0x000B, 0x1000, 0x1010, "LSI22910 PCI to Dual Channel Ultra2 SCSI host adapter(0x1000-0x1010)"},
{0x1000, 0x000B, 0x1000, 0x1020, "LSI21002 PCI to Dual Channel Ultra2 SCSI host adapter(0x1000-0x1020)"},
{0x1000, 0x000B, 0x13E9, 0x1000, "6221L-4U (Dual U2W SCSI, dual 10/100TX, graphics)(0x13E9-0x1000)"},
{0x1000, 0x000C, 0xFFFF, 0xFFFF, "53c895(0x000C)"},
{0x1000, 0x000C, 0x1000, 0x1010, "LSI8951U PCI to Ultra2 SCSI host adapter(0x1000-0x1010)"},
{0x1000, 0x000C, 0x1000, 0x1020, "LSI8952U PCI to Ultra2 SCSI host adapter(0x1000-0x1020)"},
{0x1000, 0x000C, 0x1DE1, 0x3906, "DC-390U2B SCSI adapter(0x1DE1-0x3906)"},
{0x1000, 0x000C, 0x1DE1, 0x3907, "DC-390U2W(0x1DE1-0x3907)"},
{0x1000, 0x000D, 0xFFFF, 0xFFFF, "53c885(0x000D)"},
{0x1000, 0x000F, 0xFFFF, 0xFFFF, "53c875(0x000F)"},
{0x1000, 0x000F, 0x0E11, 0x7004, "Embedded Ultra Wide SCSI Controller(0x0E11-0x7004)"},
{0x1000, 0x000F, 0x1000, 0x1000, "LSI53C876/E PCI to Dual Channel SCSI Controller(0x1000-0x1000)"},
{0x1000, 0x000F, 0x1000, 0x1010, "LSI22801 PCI to Dual Channel Ultra SCSI host adapter(0x1000-0x1010)"},
{0x1000, 0x000F, 0x1000, 0x1020, "LSI22802 PCI to Dual Channel Ultra SCSI host adapter(0x1000-0x1020)"},
{0x1000, 0x000F, 0x1092, 0x8760, "FirePort 40 Dual SCSI Controller(0x1092-0x8760)"},
{0x1000, 0x000F, 0x1775, 0x10D0, "V5D Single Board Computer Wide Ultra SCSI(0x1775-0x10D0)"},
{0x1000, 0x000F, 0x1775, 0x10D1, "V5D Single Board Computer Ultra SCSI(0x1775-0x10D1)"},
{0x1000, 0x000F, 0x1DE1, 0x3904, "DC390F/U Ultra Wide SCSI Adapter(0x1DE1-0x3904)"},
{0x1000, 0x000F, 0x4C53, 0x1000, "CC7/CR7/CP7/VC7/VP7/VR7 mainboard(0x4C53-0x1000)"},
{0x1000, 0x000F, 0x4C53, 0x1050, "CT7 mainboard(0x4C53-0x1050)"},
{0x1000, 0x0010, 0xFFFF, 0xFFFF, "53C1510(0x0010)"},
{0x1000, 0x0010, 0x0E11, 0x4040, "Integrated Smart Array Controller(0x0E11-0x4040)"},
{0x1000, 0x0010, 0x0E11, 0x4048, "RAID LC2 Controller(0x0E11-0x4048)"},
{0x1000, 0x0010, 0x1000, 0x1000, "53C1510 PCI to Dual Channel Wide Ultra2 SCSI Controller (Intelligent mode)(0x1000-0x1000)"},
{0x1000, 0x0012, 0xFFFF, 0xFFFF, "53c895a(0x0012)"},
{0x1000, 0x0012, 0x1000, 0x1000, "LSI53C895A PCI to Ultra2 SCSI Controller(0x1000-0x1000)"},
{0x1000, 0x0013, 0xFFFF, 0xFFFF, "53c875a(0x0013)"},
{0x1000, 0x0013, 0x1000, 0x1000, "LSI53C875A PCI to Ultra SCSI Controller(0x1000-0x1000)"},
{0x1000, 0x0014, 0xFFFF, 0xFFFF, "MegaRAID Tri-Mode SAS3516(0x0014)"},
{0x1000, 0x0014, 0x1000, 0x9460, "MegaRAID 9460-16i(0x1000-0x9460)"},
{0x1000, 0x0014, 0x1000, 0x9480, "MegaRAID 9480-8i8e(0x1000-0x9480)"},
{0x1000, 0x0014, 0x1000, 0x9481, "MegaRAID 9480-8e(0x1000-0x9481)"},
{0x1000, 0x0014, 0x1028, 0x1F3A, "PERC H745 Adapter(0x1028-0x1F3A)"},
{0x1000, 0x0014, 0x1028, 0x1F3B, "PERC H745 Front(0x1028-0x1F3B)"},
{0x1000, 0x0014, 0x1028, 0x1FD4, "PERC H745P MX(0x1028-0x1FD4)"},
{0x1000, 0x0014, 0x1137, 0x020E, "UCSC-RAID-M5 12G Modular RAID Controller(0x1137-0x020E)"},
{0x1000, 0x0014, 0x1D49, 0x0602, "ThinkSystem RAID 930-16i 4GB Flash PCIe 12Gb Adapter(0x1D49-0x0602)"},
{0x1000, 0x0014, 0x1D49, 0x0604, "ThinkSystem RAID 930-8e 4GB Flash PCIe 12Gb Adapter(0x1D49-0x0604)"},
{0x1000, 0x0014, 0x1D49, 0x0607, "ThinkSystem RAID 930-16i 8GB Flash PCIe 12Gb Adapter(0x1D49-0x0607)"},
{0x1000, 0x0014, 0x8086, 0x352D, "Integrated RAID Module RMSP3AD160F(0x8086-0x352D)"},
{0x1000, 0x0014, 0x8086, 0x9460, "RAID Controller RSP3TD160F(0x8086-0x9460)"},
{0x1000, 0x0014, 0x8086, 0x9480, "RAID Controller RSP3MD088F(0x8086-0x9480)"},
{0x1000, 0x0015, 0xFFFF, 0xFFFF, "MegaRAID Tri-Mode SAS3416(0x0015)"},
{0x1000, 0x0015, 0x1000, 0x9441, "MegaRAID 9440-16i(0x1000-0x9441)"},
{0x1000, 0x0015, 0x1028, 0x1F3C, "PERC H345 Adapter(0x1028-0x1F3C)"},
{0x1000, 0x0015, 0x1028, 0x1F3D, "PERC H345 Front(0x1028-0x1F3D)"},
{0x1000, 0x0015, 0x1D49, 0x0503, "ThinkSystem RAID 530-16i PCIe 12Gb Adapter(0x1D49-0x0503)"},
{0x1000, 0x0016, 0xFFFF, 0xFFFF, "MegaRAID Tri-Mode SAS3508(0x0016)"},
{0x1000, 0x0016, 0x1000, 0x9461, "MegaRAID 9460-8i(0x1000-0x9461)"},
{0x1000, 0x0016, 0x1000, 0x9462, "MegaRAID 9460-4i(0x1000-0x9462)"},
{0x1000, 0x0016, 0x1000, 0x9463, "MegaRAID 9365-28i(0x1000-0x9463)"},
{0x1000, 0x0016, 0x1000, 0x9464, "MegaRAID 9365-24i(0x1000-0x9464)"},
{0x1000, 0x0016, 0x1028, 0x1FC9, "PERC H840 Adapter(0x1028-0x1FC9)"},
{0x1000, 0x0016, 0x1028, 0x1FCB, "PERC H740P Adapter(0x1028-0x1FCB)"},
{0x1000, 0x0016, 0x1028, 0x1FCD, "PERC H740P Mini(0x1028-0x1FCD)"},
{0x1000, 0x0016, 0x1028, 0x1FCF, "PERC H740P Mini(0x1028-0x1FCF)"},
{0x1000, 0x0016, 0x1D49, 0x0601, "ThinkSystem RAID 930-8i 2GB Flash PCIe 12Gb Adapter(0x1D49-0x0601)"},
{0x1000, 0x0016, 0x1D49, 0x0603, "ThinkSystem RAID 930-24i 4GB Flash PCIe 12Gb Adapter(0x1D49-0x0603)"},
{0x1000, 0x0016, 0x8086, 0x352E, "Integrated RAID Module RMSP3CD080F(0x8086-0x352E)"},
{0x1000, 0x0016, 0x8086, 0x352F, "Integrated RAID Module RMSP3HD080E(0x8086-0x352F)"},
{0x1000, 0x0016, 0x8086, 0x9461, "RAID Controller RSP3DD080F(0x8086-0x9461)"},
{0x1000, 0x0017, 0xFFFF, 0xFFFF, "MegaRAID Tri-Mode SAS3408(0x0017)"},
{0x1000, 0x0017, 0x1000, 0x9440, "MegaRAID 9440-8i(0x1000-0x9440)"},
{0x1000, 0x0017, 0x1000, 0x9442, "MegaRAID 9440-4i(0x1000-0x9442)"},
{0x1000, 0x0017, 0x1D49, 0x0500, "ThinkSystem RAID 530-8i PCIe 12Gb Adapter(0x1D49-0x0500)"},
{0x1000, 0x0017, 0x1D49, 0x0502, "ThinkSystem RAID 530-8i Dense Adapter(0x1D49-0x0502)"},
{0x1000, 0x0017, 0x8086, 0x3528, "Integrated RAID RMSP3LD060(0x8086-0x3528)"},
{0x1000, 0x0017, 0x8086, 0x3529, "Integrated RAID RMSP3LD060(0x8086-0x3529)"},
{0x1000, 0x0017, 0x8086, 0x9441, "RAID Controller RSP3WD080E(0x8086-0x9441)"},
{0x1000, 0x001B, 0xFFFF, 0xFFFF, "MegaRAID Tri-Mode SAS3504(0x001B)"},
{0x1000, 0x001B, 0x1D49, 0x0605, "ThinkSystem RAID 930-4i 2GB Flash Flex Adapter(0x1D49-0x0605)"},
{0x1000, 0x001C, 0xFFFF, 0xFFFF, "MegaRAID Tri-Mode SAS3404(0x001C)"},
{0x1000, 0x001C, 0x1D49, 0x0501, "ThinkSystem RAID 530-4i Flex Adapter(0x1D49-0x0501)"},
{0x1000, 0x0020, 0xFFFF, 0xFFFF, "53c1010 Ultra3 SCSI Adapter(0x0020)"},
{0x1000, 0x0020, 0x1000, 0x1000, "LSI53C1010-33 PCI to Dual Channel Ultra160 SCSI Controller(0x1000-0x1000)"},
{0x1000, 0x0020, 0x107B, 0x1040, "Server Onboard 53C1010-33(0x107B-0x1040)"},
{0x1000, 0x0020, 0x1DE1, 0x1020, "DC-390U3W(0x1DE1-0x1020)"},
{0x1000, 0x0021, 0xFFFF, 0xFFFF, "53c1010 66MHz  Ultra3 SCSI Adapter(0x0021)"},
{0x1000, 0x0021, 0x1000, 0x1000, "LSI53C1000/1000R/1010R/1010-66 PCI to Ultra160 SCSI Controller(0x1000-0x1000)"},
{0x1000, 0x0021, 0x1000, 0x1010, "Asus TR-DLS onboard 53C1010-66(0x1000-0x1010)"},
{0x1000, 0x0021, 0x103C, 0x1300, "Ultra160 SCSI [AB306A](0x103C-0x1300)"},
{0x1000, 0x0021, 0x103C, 0x1310, "Ultra160 SCSI [A9918A](0x103C-0x1310)"},
{0x1000, 0x0021, 0x103C, 0x1330, "Ultra160 SCSI [A7059A](0x103C-0x1330)"},
{0x1000, 0x0021, 0x103C, 0x1340, "Ultra160 SCSI [A7060A](0x103C-0x1340)"},
{0x1000, 0x0021, 0x124B, 0x1070, "PMC-USCSI3(0x124B-0x1070)"},
{0x1000, 0x0021, 0x4C53, 0x1080, "CT8 mainboard(0x4C53-0x1080)"},
{0x1000, 0x0021, 0x4C53, 0x1300, "P017 mezzanine (32-bit PMC)(0x4C53-0x1300)"},
{0x1000, 0x0021, 0x4C53, 0x1310, "P017 mezzanine (64-bit PMC)(0x4C53-0x1310)"},
{0x1000, 0x002F, 0xFFFF, 0xFFFF, "MegaRAID SAS 2208 IOV [Thunderbolt](0x002F)"},
{0x1000, 0x002F, 0x1028, 0x1F39, "SPERC8-e(0x1028-0x1F39)"},
{0x1000, 0x002F, 0x1028, 0x1F3E, "SPERC 8(0x1028-0x1F3E)"},
{0x1000, 0x0030, 0xFFFF, 0xFFFF, "53c1030 PCI-X Fusion-MPT Dual Ultra320 SCSI(0x0030)"},
{0x1000, 0x0030, 0x0E11, 0x00DA, "ProLiant ML 350(0x0E11-0x00DA)"},
{0x1000, 0x0030, 0x1028, 0x0123, "LSI Logic 1020/1030(0x1028-0x0123)"},
{0x1000, 0x0030, 0x1028, 0x014A, "LSI Logic 1020/1030(0x1028-0x014A)"},
{0x1000, 0x0030, 0x1028, 0x016C, "PowerEdge 1850 MPT Fusion SCSI/RAID (Perc 4)(0x1028-0x016C)"},
{0x1000, 0x0030, 0x1028, 0x0183, "LSI Logic 1020/1030(0x1028-0x0183)"},
{0x1000, 0x0030, 0x1028, 0x018A, "PERC 4/IM(0x1028-0x018A)"},
{0x1000, 0x0030, 0x1028, 0x1010, "LSI U320 SCSI Controller(0x1028-0x1010)"},
{0x1000, 0x0030, 0x103C, 0x12C5, "Ultra320 SCSI [A7173A](0x103C-0x12C5)"},
{0x1000, 0x0030, 0x103C, 0x1323, "Core I/O LAN/SCSI Combo [AB314A](0x103C-0x1323)"},
{0x1000, 0x0030, 0x103C, 0x3108, "Single Channel Ultra320 SCSI HBA G2(0x103C-0x3108)"},
{0x1000, 0x0030, 0x103C, 0x322A, "SC11Xe Ultra320 Single Channel PCIe x4 SCSI Host Bus Adapter (412911-B21)(0x103C-0x322A)"},
{0x1000, 0x0030, 0x124B, 0x1170, "PMC-USCSI320(0x124B-0x1170)"},
{0x1000, 0x0030, 0x15AD, 0x1976, "LSI Logic Parallel SCSI Controller (emulated)(0x15AD-0x1976)"},
{0x1000, 0x0030, 0x1734, 0x1052, "PRIMERGY BX/RX/TX S2 series onboard SCSI(IME)(0x1734-0x1052)"},
{0x1000, 0x0031, 0xFFFF, 0xFFFF, "53c1030ZC PCI-X Fusion-MPT Dual Ultra320 SCSI(0x0031)"},
{0x1000, 0x0032, 0xFFFF, 0xFFFF, "53c1035 PCI-X Fusion-MPT Dual Ultra320 SCSI(0x0032)"},
{0x1000, 0x0032, 0x1000, 0x1000, "LSI53C1020/1030 PCI-X to Ultra320 SCSI Controller(0x1000-0x1000)"},
{0x1000, 0x0033, 0xFFFF, 0xFFFF, "1030ZC_53c1035 PCI-X Fusion-MPT Dual Ultra320 SCSI(0x0033)"},
{0x1000, 0x0040, 0xFFFF, 0xFFFF, "53c1035 PCI-X Fusion-MPT Dual Ultra320 SCSI(0x0040)"},
{0x1000, 0x0040, 0x1000, 0x0033, "MegaRAID SCSI 320-2XR(0x1000-0x0033)"},
{0x1000, 0x0040, 0x1000, 0x0066, "MegaRAID SCSI 320-2XRWS(0x1000-0x0066)"},
{0x1000, 0x0041, 0xFFFF, 0xFFFF, "53C1035ZC PCI-X Fusion-MPT Dual Ultra320 SCSI(0x0041)"},
{0x1000, 0x0050, 0xFFFF, 0xFFFF, "SAS1064 PCI-X Fusion-MPT SAS(0x0050)"},
{0x1000, 0x0050, 0x1028, 0x1F04, "SAS 5/E(0x1028-0x1F04)"},
{0x1000, 0x0050, 0x1028, 0x1F09, "SAS 5i/R(0x1028-0x1F09)"},
{0x1000, 0x0052, 0xFFFF, 0xFFFF, "MegaRAID SAS-3 3216/3224 [Cutlass](0x0052)"},
{0x1000, 0x0053, 0xFFFF, 0xFFFF, "MegaRAID SAS-3 3216/3224 [Cutlass](0x0053)"},
{0x1000, 0x0053, 0x1000, 0x9350, "MegaRAID SAS 9341-16i(0x1000-0x9350)"},
{0x1000, 0x0053, 0x1000, 0x9351, "MegaRAID SAS 9341-24i(0x1000-0x9351)"},
{0x1000, 0x0054, 0xFFFF, 0xFFFF, "SAS1068 PCI-X Fusion-MPT SAS(0x0054)"},
{0x1000, 0x0054, 0x1028, 0x1F04, "SAS 5/E Adapter Controller(0x1028-0x1F04)"},
{0x1000, 0x0054, 0x1028, 0x1F05, "SAS 5/i Adapter Controller(0x1028-0x1F05)"},
{0x1000, 0x0054, 0x1028, 0x1F06, "SAS 5/i Integrated Controller(0x1028-0x1F06)"},
{0x1000, 0x0054, 0x1028, 0x1F07, "SAS 5/iR Integrated RAID Controller(0x1028-0x1F07)"},
{0x1000, 0x0054, 0x1028, 0x1F08, "SAS 5/iR Integrated RAID Controller(0x1028-0x1F08)"},
{0x1000, 0x0054, 0x1028, 0x1F09, "SAS 5/iR Adapter RAID Controller(0x1028-0x1F09)"},
{0x1000, 0x0054, 0x103C, 0x3228, "SAS3080X-HP 8-port PCI-X 133MHz Host Bus Adapter with 2xSFF-8484(0x103C-0x3228)"},
{0x1000, 0x0054, 0x15AD, 0x1976, "SAS Controller(0x15AD-0x1976)"},
{0x1000, 0x0055, 0xFFFF, 0xFFFF, "SAS1068 PCI-X Fusion-MPT SAS(0x0055)"},
{0x1000, 0x0055, 0x1033, 0x8336, "SAS1068(0x1033-0x8336)"},
{0x1000, 0x0056, 0xFFFF, 0xFFFF, "SAS1064ET PCI-Express Fusion-MPT SAS(0x0056)"},
{0x1000, 0x0056, 0x1014, 0x03BB, "ServeRAID BR10il SAS/SATA Controller v2(0x1014-0x03BB)"},
{0x1000, 0x0056, 0x8086, 0x34DC, "AXX4SASMOD RAID Controller(0x8086-0x34DC)"},
{0x1000, 0x0057, 0xFFFF, 0xFFFF, "M1064E MegaRAID SAS(0x0057)"},
{0x1000, 0x0057, 0x8086, 0x346C, "Embedded Software RAID Technology II (ESTRII)(0x8086-0x346C)"},
{0x1000, 0x0058, 0xFFFF, 0xFFFF, "SAS1068E PCI-Express Fusion-MPT SAS(0x0058)"},
{0x1000, 0x0058, 0x1000, 0x3140, "SAS3081E-R 8-Port SAS/SATA Host Bus Adapter(0x1000-0x3140)"},
{0x1000, 0x0058, 0x1028, 0x021D, "SAS 6/iR Integrated Workstations RAID Controller(0x1028-0x021D)"},
{0x1000, 0x0058, 0x1028, 0x1F0E, "SAS 6/iR Adapter RAID Controller(0x1028-0x1F0E)"},
{0x1000, 0x0058, 0x1028, 0x1F0F, "SAS 6/iR Integrated Blades RAID Controller(0x1028-0x1F0F)"},
{0x1000, 0x0058, 0x1028, 0x1F10, "SAS 6/iR Integrated RAID Controller(0x1028-0x1F10)"},
{0x1000, 0x0058, 0x103C, 0x3229, "SC44Ge Host Bus Adapter(0x103C-0x3229)"},
{0x1000, 0x0059, 0xFFFF, 0xFFFF, "MegaRAID SAS 8208ELP/8208ELP(0x0059)"},
{0x1000, 0x005A, 0xFFFF, 0xFFFF, "SAS1066E PCI-Express Fusion-MPT SAS(0x005A)"},
{0x1000, 0x005B, 0xFFFF, 0xFFFF, "MegaRAID SAS 2208 [Thunderbolt](0x005B)"},
{0x1000, 0x005B, 0x1000, 0x9265, "MegaRAID SAS 9265-8i(0x1000-0x9265)"},
{0x1000, 0x005B, 0x1000, 0x9266, "MegaRAID SAS 9266-8i(0x1000-0x9266)"},
{0x1000, 0x005B, 0x1000, 0x9267, "MegaRAID SAS 9267-8i(0x1000-0x9267)"},
{0x1000, 0x005B, 0x1000, 0x9268, "MegaRAID SAS 9265CV-8i / 9270CV-8i(0x1000-0x9268)"},
{0x1000, 0x005B, 0x1000, 0x9269, "MegaRAID SAS 9266-4i(0x1000-0x9269)"},
{0x1000, 0x005B, 0x1000, 0x9270, "MegaRAID SAS 9270-8i(0x1000-0x9270)"},
{0x1000, 0x005B, 0x1000, 0x9271, "MegaRAID SAS 9271-8i(0x1000-0x9271)"},
{0x1000, 0x005B, 0x1000, 0x9272, "MegaRAID SAS 9272-8i(0x1000-0x9272)"},
{0x1000, 0x005B, 0x1000, 0x9273, "MegaRAID SAS 9270CV-8i(0x1000-0x9273)"},
{0x1000, 0x005B, 0x1000, 0x9274, "MegaRAID SAS 9270-4i(0x1000-0x9274)"},
{0x1000, 0x005B, 0x1000, 0x9275, "MegaRAID SAS 9271-8iCC(0x1000-0x9275)"},
{0x1000, 0x005B, 0x1000, 0x9276, "MegaRAID SAS 9271-4i(0x1000-0x9276)"},
{0x1000, 0x005B, 0x1000, 0x9285, "MegaRAID SAS 9285-8e(0x1000-0x9285)"},
{0x1000, 0x005B, 0x1000, 0x9288, "MegaRAID SAS 9285CV-8e(0x1000-0x9288)"},
{0x1000, 0x005B, 0x1000, 0x9290, "MegaRAID SAS 9286-8e(0x1000-0x9290)"},
{0x1000, 0x005B, 0x1000, 0x9291, "MegaRAID SAS 9286CV-8e(0x1000-0x9291)"},
{0x1000, 0x005B, 0x1000, 0x9295, "MegaRAID SAS 9286CV-8eCC(0x1000-0x9295)"},
{0x1000, 0x005B, 0x1014, 0x040B, "ServeRAID M5110 SAS/SATA Controller(0x1014-0x040B)"},
{0x1000, 0x005B, 0x1014, 0x040C, "ServeRAID M5120 SAS/SATA Controller(0x1014-0x040C)"},
{0x1000, 0x005B, 0x1014, 0x0412, "ServeRAID M5110e SAS/SATA Controller(0x1014-0x0412)"},
{0x1000, 0x005B, 0x1028, 0x1F2D, "PERC H810 Adapter(0x1028-0x1F2D)"},
{0x1000, 0x005B, 0x1028, 0x1F30, "PERC H710 Embedded(0x1028-0x1F30)"},
{0x1000, 0x005B, 0x1028, 0x1F31, "PERC H710P Adapter(0x1028-0x1F31)"},
{0x1000, 0x005B, 0x1028, 0x1F33, "PERC H710P Mini (for blades)(0x1028-0x1F33)"},
{0x1000, 0x005B, 0x1028, 0x1F34, "PERC H710P Mini (for monolithics)(0x1028-0x1F34)"},
{0x1000, 0x005B, 0x1028, 0x1F35, "PERC H710 Adapter(0x1028-0x1F35)"},
{0x1000, 0x005B, 0x1028, 0x1F37, "PERC H710 Mini (for blades)(0x1028-0x1F37)"},
{0x1000, 0x005B, 0x1028, 0x1F38, "PERC H710 Mini (for monolithics)(0x1028-0x1F38)"},
{0x1000, 0x005B, 0x15D9, 0x0690, "LSI MegaRAID ROMB(0x15D9-0x0690)"},
{0x1000, 0x005B, 0x8086, 0x3510, "RMS25PB080 RAID Controller(0x8086-0x3510)"},
{0x1000, 0x005B, 0x8086, 0x3511, "RMS25PB040 RAID Controller(0x8086-0x3511)"},
{0x1000, 0x005B, 0x8086, 0x3512, "RMT3PB080 RAID Controller(0x8086-0x3512)"},
{0x1000, 0x005B, 0x8086, 0x3513, "Integrated RAID Module RMS25CB080(0x8086-0x3513)"},
{0x1000, 0x005B, 0x8086, 0x3514, "RMS25CB040 RAID Controller(0x8086-0x3514)"},
{0x1000, 0x005B, 0x8086, 0x351C, "RMS25PB080N RAID Controller(0x8086-0x351C)"},
{0x1000, 0x005B, 0x8086, 0x351D, "RMS25CB080N RAID Controller(0x8086-0x351D)"},
{0x1000, 0x005B, 0x8086, 0x9265, "RS25DB080 RAID Controller(0x8086-0x9265)"},
{0x1000, 0x005B, 0x8086, 0x9268, "RS25AB080 RAID Controller(0x8086-0x9268)"},
{0x1000, 0x005B, 0x8086, 0x9285, "RS25NB008 RAID Controller(0x8086-0x9285)"},
{0x1000, 0x005B, 0x8086, 0x9288, "RS25SB008 RAID Controller(0x8086-0x9288)"},
{0x1000, 0x005C, 0xFFFF, 0xFFFF, "SAS1064A PCI-X Fusion-MPT SAS(0x005C)"},
{0x1000, 0x005D, 0xFFFF, 0xFFFF, "MegaRAID SAS-3 3108 [Invader](0x005D)"},
{0x1000, 0x005D, 0x1000, 0x9361, "MegaRAID SAS 9361-8i(0x1000-0x9361)"},
{0x1000, 0x005D, 0x1000, 0x9363, "MegaRAID SAS 9361-4i(0x1000-0x9363)"},
{0x1000, 0x005D, 0x1000, 0x9364, "MegaRAID SAS 9364-8i(0x1000-0x9364)"},
{0x1000, 0x005D, 0x1000, 0x936A, "MegaRAID SAS 9364-8i(0x1000-0x936A)"},
{0x1000, 0x005D, 0x1000, 0x9380, "MegaRAID SAS 9380-8e(0x1000-0x9380)"},
{0x1000, 0x005D, 0x1028, 0x1F41, "PERC H830 Adapter(0x1028-0x1F41)"},
{0x1000, 0x005D, 0x1028, 0x1F42, "PERC H730P Adapter(0x1028-0x1F42)"},
{0x1000, 0x005D, 0x1028, 0x1F43, "PERC H730 Adapter(0x1028-0x1F43)"},
{0x1000, 0x005D, 0x1028, 0x1F47, "PERC H730P Mini(0x1028-0x1F47)"},
{0x1000, 0x005D, 0x1028, 0x1F48, "PERC H730P Mini (for blades)(0x1028-0x1F48)"},
{0x1000, 0x005D, 0x1028, 0x1F49, "PERC H730 Mini(0x1028-0x1F49)"},
{0x1000, 0x005D, 0x1028, 0x1F4A, "PERC H730 Mini (for blades)(0x1028-0x1F4A)"},
{0x1000, 0x005D, 0x1028, 0x1F4D, "PERC FD33xS(0x1028-0x1F4D)"},
{0x1000, 0x005D, 0x1028, 0x1F4F, "PERC H730P Slim(0x1028-0x1F4F)"},
{0x1000, 0x005D, 0x1028, 0x1F54, "PERC FD33xD(0x1028-0x1F54)"},
{0x1000, 0x005D, 0x1028, 0x1FD1, "PERC H730P MX(0x1028-0x1FD1)"},
{0x1000, 0x005D, 0x1734, 0x11F6, "PRAID EP400i(0x1734-0x11F6)"},
{0x1000, 0x005D, 0x17AA, 0x1052, "ThinkServer RAID 720i(0x17AA-0x1052)"},
{0x1000, 0x005D, 0x17AA, 0x1053, "ThinkServer RAID 720ix(0x17AA-0x1053)"},
{0x1000, 0x005D, 0x1BD4, 0x0014, "12G SAS3108 2G(0x1BD4-0x0014)"},
{0x1000, 0x005D, 0x1BD4, 0x0015, "12G SAS3108 4G(0x1BD4-0x0015)"},
{0x1000, 0x005D, 0x1D49, 0x0600, "ThinkSystem RAID 730-8i 1GB Cache PCIe 12Gb Adapter(0x1D49-0x0600)"},
{0x1000, 0x005D, 0x1D49, 0x0608, "ThinkSystem RAID 730-8i 2GB Flash PCIe 12Gb Adapter(0x1D49-0x0608)"},
{0x1000, 0x005D, 0x1D49, 0x0609, "ThinkSystem RAID 730-8i 4GB Flash PCIe 12Gb Adapter(0x1D49-0x0609)"},
{0x1000, 0x005D, 0x8086, 0x351E, "RMS3CC080 RAID Controller(0x8086-0x351E)"},
{0x1000, 0x005D, 0x8086, 0x351F, "RMS3CC040 RAID Controller(0x8086-0x351F)"},
{0x1000, 0x005D, 0x8086, 0x9360, "RS3DC080 RAID Controller(0x8086-0x9360)"},
{0x1000, 0x005D, 0x8086, 0x9362, "RS3DC040 RAID Controller(0x8086-0x9362)"},
{0x1000, 0x005D, 0x8086, 0x9380, "RS3SC008 RAID Controller(0x8086-0x9380)"},
{0x1000, 0x005D, 0x8086, 0x9381, "RS3MC044 RAID Controller(0x8086-0x9381)"},
{0x1000, 0x005E, 0xFFFF, 0xFFFF, "SAS1066 PCI-X Fusion-MPT SAS(0x005E)"},
{0x1000, 0x005F, 0xFFFF, 0xFFFF, "MegaRAID SAS-3 3008 [Fury](0x005F)"},
{0x1000, 0x005F, 0x1028, 0x1F44, "PERC H330 Adapter(0x1028-0x1F44)"},
{0x1000, 0x005F, 0x1028, 0x1F4B, "PERC H330 Mini(0x1028-0x1F4B)"},
{0x1000, 0x005F, 0x1028, 0x1F4C, "PERC H330 Mini (for blades)(0x1028-0x1F4C)"},
{0x1000, 0x005F, 0x1028, 0x1F4D, "PERC H330 Embedded (for monolithic)(0x1028-0x1F4D)"},
{0x1000, 0x005F, 0x1054, 0x306A, "SAS 3004 iMR ROMB(0x1054-0x306A)"},
{0x1000, 0x005F, 0x1734, 0x1211, "PRAID CP400i [D3307-A12](0x1734-0x1211)"},
{0x1000, 0x005F, 0x1D49, 0x04DB, "ServeRAID M1210 SAS/SATA Controller(0x1D49-0x04DB)"},
{0x1000, 0x005F, 0x1D49, 0x0504, "ThinkSystem RAID 520-8i PCIe 12Gb Adapter(0x1D49-0x0504)"},
{0x1000, 0x0060, 0xFFFF, 0xFFFF, "MegaRAID SAS 1078(0x0060)"},
{0x1000, 0x0060, 0x1000, 0x1006, "MegaRAID SAS 8888ELP(0x1000-0x1006)"},
{0x1000, 0x0060, 0x1000, 0x100A, "MegaRAID SAS 8708ELP(0x1000-0x100A)"},
{0x1000, 0x0060, 0x1000, 0x100E, "MegaRAID SAS 8884E(0x1000-0x100E)"},
{0x1000, 0x0060, 0x1000, 0x100F, "MegaRAID SAS 8708E(0x1000-0x100F)"},
{0x1000, 0x0060, 0x1000, 0x1010, "MegaRAID SATA 350-8ELP(0x1000-0x1010)"},
{0x1000, 0x0060, 0x1000, 0x1011, "MegaRAID SATA 350-4ELP(0x1000-0x1011)"},
{0x1000, 0x0060, 0x1000, 0x1012, "MegaRAID SAS 8704ELP(0x1000-0x1012)"},
{0x1000, 0x0060, 0x1000, 0x1016, "MegaRAID SAS 8880EM2(0x1000-0x1016)"},
{0x1000, 0x0060, 0x1014, 0x0363, "MegaRAID SAS PCI Express ROMB(0x1014-0x0363)"},
{0x1000, 0x0060, 0x1014, 0x0364, "SystemX MegaRAID SAS 8808E(0x1014-0x0364)"},
{0x1000, 0x0060, 0x1014, 0x0365, "SystemX MegaRAID SAS 8884E(0x1014-0x0365)"},
{0x1000, 0x0060, 0x1014, 0x0379, "SystemX MegaRAID SAS 8880EM2(0x1014-0x0379)"},
{0x1000, 0x0060, 0x1028, 0x1F0A, "PERC 6/E Adapter RAID Controller(0x1028-0x1F0A)"},
{0x1000, 0x0060, 0x1028, 0x1F0B, "PERC 6/i Adapter RAID Controller(0x1028-0x1F0B)"},
{0x1000, 0x0060, 0x1028, 0x1F0C, "PERC 6/i Integrated RAID Controller(0x1028-0x1F0C)"},
{0x1000, 0x0060, 0x1028, 0x1F0D, "PERC 6/i Integrated RAID Controller(0x1028-0x1F0D)"},
{0x1000, 0x0060, 0x1028, 0x1F11, "CERC 6/i Integrated RAID Controller(0x1028-0x1F11)"},
{0x1000, 0x0060, 0x1033, 0x835A, "MegaRAID SAS PCI Express ROMB(0x1033-0x835A)"},
{0x1000, 0x0060, 0x1043, 0x824D, "MegaRAID SAS PCI Express ROMB(0x1043-0x824D)"},
{0x1000, 0x0060, 0x1170, 0x002F, "MegaRAID SAS PCI Express ROMB(0x1170-0x002F)"},
{0x1000, 0x0060, 0x1170, 0x0036, "MegaRAID SAS PCI Express ROMB(0x1170-0x0036)"},
{0x1000, 0x0060, 0x15D9, 0xC080, "MegaRAID SAS PCI Express ROMB(0x15D9-0xC080)"},
{0x1000, 0x0060, 0x17AA, 0x6B7C, "MegaRAID SAS PCI Express ROMB(0x17AA-0x6B7C)"},
{0x1000, 0x0060, 0x18A1, 0x0003, "LSI MegaRAID SAS PCI Express ROMB(0x18A1-0x0003)"},
{0x1000, 0x0060, 0x8086, 0x1006, "RAID Controller SRCSAS28EP(0x8086-0x1006)"},
{0x1000, 0x0060, 0x8086, 0x100A, "RAID Controller SRCSAS28EV(0x8086-0x100A)"},
{0x1000, 0x0060, 0x8086, 0x1010, "RAID Controller SRCSATA28E(0x8086-0x1010)"},
{0x1000, 0x0060, 0x8086, 0x34CC, "Integrated RAID Controller SROMBSAS28E(0x8086-0x34CC)"},
{0x1000, 0x0060, 0x8086, 0x34CD, "Integrated RAID Controller SROMBSAS28E(0x8086-0x34CD)"},
{0x1000, 0x0060, 0x8086, 0x3505, "Integrated RAID Controller SROMBSASMP2(0x8086-0x3505)"},
{0x1000, 0x0062, 0xFFFF, 0xFFFF, "SAS1078 PCI-Express Fusion-MPT SAS(0x0062)"},
{0x1000, 0x0062, 0x1000, 0x0062, "SAS1078 PCI-Express Fusion-MPT SAS(0x1000-0x0062)"},
{0x1000, 0x0064, 0xFFFF, 0xFFFF, "SAS2116 PCI-Express Fusion-MPT SAS-2 [Meteor](0x0064)"},
{0x1000, 0x0064, 0x1000, 0x3030, "9200-16e 6Gb/s SAS/SATA PCIe x8 External HBA(0x1000-0x3030)"},
{0x1000, 0x0064, 0x1000, 0x30C0, "SAS 9201-16i(0x1000-0x30C0)"},
{0x1000, 0x0064, 0x1000, 0x30D0, "9201-16e 6Gb/s SAS/SATA PCIe x8 External HBA(0x1000-0x30D0)"},
{0x1000, 0x0065, 0xFFFF, 0xFFFF, "SAS2116 PCI-Express Fusion-MPT SAS-2 [Meteor](0x0065)"},
{0x1000, 0x006E, 0xFFFF, 0xFFFF, "SAS2308 PCI-Express Fusion-MPT SAS-2(0x006E)"},
{0x1000, 0x0070, 0xFFFF, 0xFFFF, "SAS2004 PCI-Express Fusion-MPT SAS-2 [Spitfire](0x0070)"},
{0x1000, 0x0070, 0x1000, 0x3010, "SAS9211-4i(0x1000-0x3010)"},
{0x1000, 0x0070, 0x1014, 0x040E, "ServeRAID H1110(0x1014-0x040E)"},
{0x1000, 0x0071, 0xFFFF, 0xFFFF, "MR SAS HBA 2004(0x0071)"},
{0x1000, 0x0072, 0xFFFF, 0xFFFF, "SAS2008 PCI-Express Fusion-MPT SAS-2 [Falcon](0x0072)"},
{0x1000, 0x0072, 0x1000, 0x3020, "9211-8i(0x1000-0x3020)"},
{0x1000, 0x0072, 0x1000, 0x3040, "9210-8i(0x1000-0x3040)"},
{0x1000, 0x0072, 0x1000, 0x3080, "9200-8e [LSI SAS 6Gb/s SAS/SATA PCIe x8 External HBA](0x1000-0x3080)"},
{0x1000, 0x0072, 0x1000, 0x30B0, "9200-8e [LSI SAS 6Gb/s SAS/SATA PCIe x8 External HBA](0x1000-0x30B0)"},
{0x1000, 0x0072, 0x1014, 0x03CA, "IBM 6Gb SAS HBA [9212-4i4e](0x1014-0x03CA)"},
{0x1000, 0x0072, 0x1028, 0x1F1C, "6Gbps SAS HBA Adapter(0x1028-0x1F1C)"},
{0x1000, 0x0072, 0x1028, 0x1F1D, "PERC H200 Adapter(0x1028-0x1F1D)"},
{0x1000, 0x0072, 0x1028, 0x1F1E, "PERC H200 Integrated(0x1028-0x1F1E)"},
{0x1000, 0x0072, 0x1028, 0x1F1F, "PERC H200 Modular(0x1028-0x1F1F)"},
{0x1000, 0x0072, 0x1028, 0x1F20, "PERC H200 Embedded(0x1028-0x1F20)"},
{0x1000, 0x0072, 0x1028, 0x1F22, "PERC H200 Internal Tape Adapter(0x1028-0x1F22)"},
{0x1000, 0x0072, 0x1734, 0x1177, "HBA Ctrl SAS 6G 0/1 [D2607](0x1734-0x1177)"},
{0x1000, 0x0072, 0x1BD4, 0x000D, "6G SAS2008IT(0x1BD4-0x000D)"},
{0x1000, 0x0072, 0x1BD4, 0x000E, "6G SAS2008IR(0x1BD4-0x000E)"},
{0x1000, 0x0072, 0x1BD4, 0x000F, "6G SAS2008IT SA5248(0x1BD4-0x000F)"},
{0x1000, 0x0072, 0x1BD4, 0x0010, "6G SAS2008IR SA5248(0x1BD4-0x0010)"},
{0x1000, 0x0072, 0x4C52, 0x96C8, "LRSA96C8 8-Port SATA3(6Gb/s)Exchange Adapter (with Raid)(0x4C52-0x96C8)"},
{0x1000, 0x0072, 0x8086, 0x350F, "RMS2LL040 RAID Controller(0x8086-0x350F)"},
{0x1000, 0x0072, 0x8086, 0x3700, "SSD 910 Series(0x8086-0x3700)"},
{0x1000, 0x0073, 0xFFFF, 0xFFFF, "MegaRAID SAS 2008 [Falcon](0x0073)"},
{0x1000, 0x0073, 0x1000, 0x9240, "MegaRAID SAS 9240-8i(0x1000-0x9240)"},
{0x1000, 0x0073, 0x1000, 0x9241, "MegaRAID SAS 9240-4i(0x1000-0x9241)"},
{0x1000, 0x0073, 0x1000, 0x92A0, "MegaRAID SAS 9220-8i(0x1000-0x92A0)"},
{0x1000, 0x0073, 0x1014, 0x03B1, "ServeRAID M1015 SAS/SATA Controller(0x1014-0x03B1)"},
{0x1000, 0x0073, 0x1014, 0x040D, "ServeRAID M1115 SAS/SATA Controller(0x1014-0x040D)"},
{0x1000, 0x0073, 0x1028, 0x1F4E, "PERC H310 Adapter(0x1028-0x1F4E)"},
{0x1000, 0x0073, 0x1028, 0x1F4F, "PERC H310 Integrated(0x1028-0x1F4F)"},
{0x1000, 0x0073, 0x1028, 0x1F50, "PERC H310 Mini Blades(0x1028-0x1F50)"},
{0x1000, 0x0073, 0x1028, 0x1F51, "PERC H310 Mini Monolithics(0x1028-0x1F51)"},
{0x1000, 0x0073, 0x1028, 0x1F52, "PERC H310 Embedded1(0x1028-0x1F52)"},
{0x1000, 0x0073, 0x1028, 0x1F53, "PERC H310 Embedded2(0x1028-0x1F53)"},
{0x1000, 0x0073, 0x1028, 0x1F54, "PERC H310 Reserved(0x1028-0x1F54)"},
{0x1000, 0x0073, 0x1028, 0x1F78, "PERC H310(0x1028-0x1F78)"},
{0x1000, 0x0073, 0x1054, 0x3035, "LSI MegaRAID SAS 9240-8i(0x1054-0x3035)"},
{0x1000, 0x0073, 0x1137, 0x0072, "2004 iMR ROMB(0x1137-0x0072)"},
{0x1000, 0x0073, 0x1137, 0x0073, "2008 ROMB(0x1137-0x0073)"},
{0x1000, 0x0073, 0x1137, 0x00B0, "UCSC RAID SAS 2008M-8i(0x1137-0x00B0)"},
{0x1000, 0x0073, 0x1137, 0x00B1, "UCSC RAID SAS 2008M-8i(0x1137-0x00B1)"},
{0x1000, 0x0073, 0x1137, 0x00C2, "UCS E-Series Double Wide(0x1137-0x00C2)"},
{0x1000, 0x0073, 0x1137, 0x00C3, "UCS E-Series Single Wide(0x1137-0x00C3)"},
{0x1000, 0x0073, 0x15D9, 0x0400, "Supermicro SMC2008-iMR(0x15D9-0x0400)"},
{0x1000, 0x0073, 0x1734, 0x1177, "RAID Ctrl SAS 6G 0/1 (D2607)(0x1734-0x1177)"},
{0x1000, 0x0073, 0x17AA, 0x1051, "ThinkServer RAID 510i(0x17AA-0x1051)"},
{0x1000, 0x0073, 0x8086, 0x350D, "RMS2AF040 RAID Controller(0x8086-0x350D)"},
{0x1000, 0x0073, 0x8086, 0x9240, "RAID Controller RS2WC080(0x8086-0x9240)"},
{0x1000, 0x0073, 0x8086, 0x9241, "RAID Controller RS2WC040(0x8086-0x9241)"},
{0x1000, 0x0074, 0xFFFF, 0xFFFF, "SAS2108 PCI-Express Fusion-MPT SAS-2 [Liberator](0x0074)"},
{0x1000, 0x0076, 0xFFFF, 0xFFFF, "SAS2108 PCI-Express Fusion-MPT SAS-2 [Liberator](0x0076)"},
{0x1000, 0x0077, 0xFFFF, 0xFFFF, "SAS2108 PCI-Express Fusion-MPT SAS-2 [Liberator](0x0077)"},
{0x1000, 0x0079, 0xFFFF, 0xFFFF, "MegaRAID SAS 2108 [Liberator](0x0079)"},
{0x1000, 0x0079, 0x1000, 0x9251, "MegaRAID SAS 9260-4ix(0x1000-0x9251)"},
{0x1000, 0x0079, 0x1000, 0x9256, "MegaRAID SAS 9260-8ix(0x1000-0x9256)"},
{0x1000, 0x0079, 0x1000, 0x9260, "MegaRAID SAS 9260-4i(0x1000-0x9260)"},
{0x1000, 0x0079, 0x1000, 0x9261, "MegaRAID SAS 9260-8i(0x1000-0x9261)"},
{0x1000, 0x0079, 0x1000, 0x9262, "MegaRAID SAS 9262-8i(0x1000-0x9262)"},
{0x1000, 0x0079, 0x1000, 0x9263, "MegaRAID SAS 9261-8i(0x1000-0x9263)"},
{0x1000, 0x0079, 0x1000, 0x9264, "MegaRAID SAS 9264-8i(0x1000-0x9264)"},
{0x1000, 0x0079, 0x1000, 0x9267, "MegaRAID SAS 9260CV-4i(0x1000-0x9267)"},
{0x1000, 0x0079, 0x1000, 0x9268, "MegaRAID SAS 9260CV-8i(0x1000-0x9268)"},
{0x1000, 0x0079, 0x1000, 0x9275, "MegaRAID SAS 9280-8ex(0x1000-0x9275)"},
{0x1000, 0x0079, 0x1000, 0x9276, "MR9260-16i(0x1000-0x9276)"},
{0x1000, 0x0079, 0x1000, 0x9280, "MegaRAID SAS 9280-8e(0x1000-0x9280)"},
{0x1000, 0x0079, 0x1000, 0x9281, "MegaRAID SAS 9281-8E(0x1000-0x9281)"},
{0x1000, 0x0079, 0x1000, 0x9282, "MegaRAID SAS 9280-4i4e(0x1000-0x9282)"},
{0x1000, 0x0079, 0x1000, 0x9290, "MegaRAID SAS 9280DE-24i4e(0x1000-0x9290)"},
{0x1000, 0x0079, 0x1014, 0x03B2, "ServeRAID M5015 SAS/SATA Controller(0x1014-0x03B2)"},
{0x1000, 0x0079, 0x1014, 0x03B3, "ServeRAID M5025 SAS/SATA Controller(0x1014-0x03B3)"},
{0x1000, 0x0079, 0x1028, 0x1F15, "PERC H800 Adapter(0x1028-0x1F15)"},
{0x1000, 0x0079, 0x1028, 0x1F16, "PERC H700 Adapter(0x1028-0x1F16)"},
{0x1000, 0x0079, 0x1028, 0x1F17, "PERC H700 Integrated(0x1028-0x1F17)"},
{0x1000, 0x0079, 0x1028, 0x1F18, "PERC H700 Modular(0x1028-0x1F18)"},
{0x1000, 0x0079, 0x1028, 0x1F1A, "PERC H800 Proto Adapter(0x1028-0x1F1A)"},
{0x1000, 0x0079, 0x1028, 0x1F1B, "PERC H700 Integrated(0x1028-0x1F1B)"},
{0x1000, 0x0079, 0x1043, 0x8480, "PIKE-2108 16PD(0x1043-0x8480)"},
{0x1000, 0x0079, 0x1734, 0x1176, "RAID Ctrl SAS 6G 5/6 512MB (D2616)(0x1734-0x1176)"},
{0x1000, 0x0079, 0x1734, 0x1177, "RAID Ctrl SAS 6G 0/1 (D2607)(0x1734-0x1177)"},
{0x1000, 0x0079, 0x8086, 0x350B, "RMS2MH080 RAID Controller(0x8086-0x350B)"},
{0x1000, 0x0079, 0x8086, 0x9256, "MegaRAID SAS 9260DE-8i RS2BL080DE(0x8086-0x9256)"},
{0x1000, 0x0079, 0x8086, 0x9260, "RAID Controller RS2BL040(0x8086-0x9260)"},
{0x1000, 0x0079, 0x8086, 0x9261, "RAID Controller RS2BL080(0x8086-0x9261)"},
{0x1000, 0x0079, 0x8086, 0x9264, "RAID Controller RT3WB080 Warm Beach (Caster Lite)(0x8086-0x9264)"},
{0x1000, 0x0079, 0x8086, 0x9267, "RAID Controller RS2VB040(0x8086-0x9267)"},
{0x1000, 0x0079, 0x8086, 0x9268, "RAID Controller RS2VB080(0x8086-0x9268)"},
{0x1000, 0x0079, 0x8086, 0x9275, "RAID Controller RS2PI008DE(0x8086-0x9275)"},
{0x1000, 0x0079, 0x8086, 0x9276, "RAID Controller RS2WG160(0x8086-0x9276)"},
{0x1000, 0x0079, 0x8086, 0x9280, "RAID Controller RS2PI008(0x8086-0x9280)"},
{0x1000, 0x0079, 0x8086, 0x9282, "RAID Controller RS2MB044(0x8086-0x9282)"},
{0x1000, 0x0079, 0x8086, 0x9290, "RAID Controller RS2SG244(0x8086-0x9290)"},
{0x1000, 0x007C, 0xFFFF, 0xFFFF, "MegaRAID SAS 1078DE(0x007C)"},
{0x1000, 0x007C, 0x1014, 0x0395, "ServeRAID-AR10is SAS/SATA Controller(0x1014-0x0395)"},
{0x1000, 0x007E, 0xFFFF, 0xFFFF, "SSS6200 PCI-Express Flash SSD(0x007E)"},
{0x1000, 0x007E, 0x1000, 0x0504, "Nytro NWD-BLP4-800(0x1000-0x0504)"},
{0x1000, 0x007E, 0x1000, 0x0507, "Nytro NWD-BLP4-1600(0x1000-0x0507)"},
{0x1000, 0x007E, 0x1000, 0x0581, "Nytro NWD-BLP4-400(0x1000-0x0581)"},
{0x1000, 0x007E, 0x1000, 0x100D, "Nytro NWD-BFH6-1200(0x1000-0x100D)"},
{0x1000, 0x007E, 0x1000, 0x100E, "Nytro NWD-BFH8-1600(0x1000-0x100E)"},
{0x1000, 0x007E, 0x1000, 0x107E, "Nytro NWD-BFH8-3200(0x1000-0x107E)"},
{0x1000, 0x007E, 0x1000, 0x1310, "Nytro XP6302-8B1536(0x1000-0x1310)"},
{0x1000, 0x007E, 0x1000, 0x1311, "Nytro XP6302-8B2048(0x1000-0x1311)"},
{0x1000, 0x007E, 0x1000, 0x1314, "Nytro XP6302-8B4096(0x1000-0x1314)"},
{0x1000, 0x007E, 0x1000, 0x150C, "Nytro XP6210-4A2048(0x1000-0x150C)"},
{0x1000, 0x007E, 0x1000, 0x150F, "Nytro XP6210-4B2048(0x1000-0x150F)"},
{0x1000, 0x007E, 0x1000, 0x160B, "Nytro XP6209-4A1024(0x1000-0x160B)"},
{0x1000, 0x007E, 0x1000, 0x1613, "Nytro XP6209-4B2048(0x1000-0x1613)"},
{0x1000, 0x007E, 0x108E, 0x050A, "Nytro ELP4x200_4d_n(0x108E-0x050A)"},
{0x1000, 0x007E, 0x108E, 0x0581, "Nytro ELP4x100_4d_n(0x108E-0x0581)"},
{0x1000, 0x0080, 0xFFFF, 0xFFFF, "SAS2208 PCI-Express Fusion-MPT SAS-2(0x0080)"},
{0x1000, 0x0081, 0xFFFF, 0xFFFF, "SAS2208 PCI-Express Fusion-MPT SAS-2(0x0081)"},
{0x1000, 0x0082, 0xFFFF, 0xFFFF, "SAS2208 PCI-Express Fusion-MPT SAS-2(0x0082)"},
{0x1000, 0x0083, 0xFFFF, 0xFFFF, "SAS2208 PCI-Express Fusion-MPT SAS-2(0x0083)"},
{0x1000, 0x0084, 0xFFFF, 0xFFFF, "SAS2208 PCI-Express Fusion-MPT SAS-2(0x0084)"},
{0x1000, 0x0085, 0xFFFF, 0xFFFF, "SAS2208 PCI-Express Fusion-MPT SAS-2(0x0085)"},
{0x1000, 0x0086, 0xFFFF, 0xFFFF, "SAS2308 PCI-Express Fusion-MPT SAS-2(0x0086)"},
{0x1000, 0x0086, 0x15D9, 0x0690, "Onboard MegaRAID SAS2208 [Thunderbolt](0x15D9-0x0690)"},
{0x1000, 0x0086, 0x15D9, 0x0691, "Onboard SAS2308 PCI-Express Fusion-MPT SAS-2(0x15D9-0x0691)"},
{0x1000, 0x0087, 0xFFFF, 0xFFFF, "SAS2308 PCI-Express Fusion-MPT SAS-2(0x0087)"},
{0x1000, 0x0087, 0x1000, 0x3020, "9207-8i SAS2.1 HBA(0x1000-0x3020)"},
{0x1000, 0x0087, 0x1000, 0x3030, "SAS9207-4i4e(0x1000-0x3030)"},
{0x1000, 0x0087, 0x1000, 0x3040, "9207-8e SAS2.1 HBA(0x1000-0x3040)"},
{0x1000, 0x0087, 0x1000, 0x3050, "SAS9217-8i(0x1000-0x3050)"},
{0x1000, 0x0087, 0x1000, 0x3060, "SAS9217-4i4e(0x1000-0x3060)"},
{0x1000, 0x0087, 0x1014, 0x0472, "N2125 External Host Bus Adapter(0x1014-0x0472)"},
{0x1000, 0x0087, 0x1014, 0x047A, "N2115 Internal Host Bus Adapter(0x1014-0x047A)"},
{0x1000, 0x0087, 0x1590, 0x0041, "H220i(0x1590-0x0041)"},
{0x1000, 0x0087, 0x1590, 0x0042, "H221 / 9207-8e(0x1590-0x0042)"},
{0x1000, 0x0087, 0x1590, 0x0044, "H220i(0x1590-0x0044)"},
{0x1000, 0x0087, 0x1BD4, 0x0009, "6G SAS2308IR(0x1BD4-0x0009)"},
{0x1000, 0x0087, 0x1BD4, 0x000A, "6G SAS2308IT(0x1BD4-0x000A)"},
{0x1000, 0x0087, 0x8086, 0x3000, "RS25GB008 RAID Controller(0x8086-0x3000)"},
{0x1000, 0x0087, 0x8086, 0x3060, "RS25FB044 RAID Controller(0x8086-0x3060)"},
{0x1000, 0x0087, 0x8086, 0x3516, "RMS25JB080 RAID Controller(0x8086-0x3516)"},
{0x1000, 0x0087, 0x8086, 0x3517, "RMS25JB040 RAID Controller(0x8086-0x3517)"},
{0x1000, 0x0087, 0x8086, 0x3518, "RMS25KB080 RAID Controller(0x8086-0x3518)"},
{0x1000, 0x0087, 0x8086, 0x3519, "RMS25KB040 RAID Controller(0x8086-0x3519)"},
{0x1000, 0x0087, 0x8086, 0x351A, "RMS25LB040 RAID Controller(0x8086-0x351A)"},
{0x1000, 0x0087, 0x8086, 0x351B, "RMS25LB080 RAID Controller(0x8086-0x351B)"},
{0x1000, 0x008F, 0xFFFF, 0xFFFF, "53c875J(0x008F)"},
{0x1000, 0x008F, 0x1092, 0x8000, "FirePort 40 SCSI Controller(0x1092-0x8000)"},
{0x1000, 0x008F, 0x1092, 0x8760, "FirePort 40 Dual SCSI Host Adapter(0x1092-0x8760)"},
{0x1000, 0x0090, 0xFFFF, 0xFFFF, "SAS3108 PCI-Express Fusion-MPT SAS-3(0x0090)"},
{0x1000, 0x0091, 0xFFFF, 0xFFFF, "SAS3108 PCI-Express Fusion-MPT SAS-3(0x0091)"},
{0x1000, 0x0094, 0xFFFF, 0xFFFF, "SAS3108 PCI-Express Fusion-MPT SAS-3(0x0094)"},
{0x1000, 0x0095, 0xFFFF, 0xFFFF, "SAS3108 PCI-Express Fusion-MPT SAS-3(0x0095)"},
{0x1000, 0x0096, 0xFFFF, 0xFFFF, "SAS3004 PCI-Express Fusion-MPT SAS-3(0x0096)"},
{0x1000, 0x0097, 0xFFFF, 0xFFFF, "SAS3008 PCI-Express Fusion-MPT SAS-3(0x0097)"},
{0x1000, 0x0097, 0x1000, 0x3090, "SAS9311-8i(0x1000-0x3090)"},
{0x1000, 0x0097, 0x1000, 0x30A0, "SAS9300-8e(0x1000-0x30A0)"},
{0x1000, 0x0097, 0x1000, 0x30E0, "SAS9300-8i(0x1000-0x30E0)"},
{0x1000, 0x0097, 0x1000, 0x3130, "SAS 9300-16i(0x1000-0x3130)"},
{0x1000, 0x0097, 0x1028, 0x1F45, "HBA330 Adapter(0x1028-0x1F45)"},
{0x1000, 0x0097, 0x1028, 0x1F46, "12Gbps HBA(0x1028-0x1F46)"},
{0x1000, 0x0097, 0x1028, 0x1F53, "HBA330 Mini(0x1028-0x1F53)"},
{0x1000, 0x0097, 0x1028, 0x1FD2, "HBA330 MX(0x1028-0x1FD2)"},
{0x1000, 0x0097, 0x1028, 0x1FD3, "HBA330 MMZ(0x1028-0x1FD3)"},
{0x1000, 0x0097, 0x15D9, 0x0808, "AOC-S3008L-L8e(0x15D9-0x0808)"},
{0x1000, 0x0097, 0x1BD4, 0x0008, "12G SAS3008IMR Onboard(0x1BD4-0x0008)"},
{0x1000, 0x0097, 0x1BD4, 0x000B, "12G SAS3008IR(0x1BD4-0x000B)"},
{0x1000, 0x0097, 0x1BD4, 0x000C, "12G SAS3008IT(0x1BD4-0x000C)"},
{0x1000, 0x0097, 0x1BD4, 0x0011, "Inspur 12Gb 8i-3008 IT SAS HBA(0x1BD4-0x0011)"},
{0x1000, 0x0097, 0x1BD4, 0x0012, "12Gb SAS3008IR UDM(0x1BD4-0x0012)"},
{0x1000, 0x0097, 0x1BD4, 0x001F, "12G SAS3008IR Onboard(0x1BD4-0x001F)"},
{0x1000, 0x0097, 0x1BD4, 0x0020, "12G SAS3008IT Onboard(0x1BD4-0x0020)"},
{0x1000, 0x0097, 0x1BD4, 0x0026, "12G SAS3008IT RACK(0x1BD4-0x0026)"},
{0x1000, 0x0097, 0x1BD4, 0x0027, "12G SAS3008IMR RACK(0x1BD4-0x0027)"},
{0x1000, 0x0097, 0x1BD4, 0x0028, "12G SAS3008IR RACK(0x1BD4-0x0028)"},
{0x1000, 0x00A5, 0xFFFF, 0xFFFF, "Fusion-MPT 24GSAS/PCIe SAS40xx/41xx(0x00A5)"},
{0x1000, 0x00A5, 0x1000, 0x4600, "MegaRAID 9670W-16i Tri-Mode Storage Adapter(0x1000-0x4600)"},
{0x1000, 0x00A5, 0x1000, 0x4610, "MegaRAID 9670-24i Tri-Mode Storage Adapter(0x1000-0x4610)"},
{0x1000, 0x00A5, 0x1000, 0x4620, "MegaRAID 9660-16i Tri-Mode Storage Adapter(0x1000-0x4620)"},
{0x1000, 0x00A5, 0x1000, 0x4630, "MegaRAID 9660-8i8e Tri-Mode Storage Adapter(0x1000-0x4630)"},
{0x1000, 0x00A5, 0x1000, 0x4640, "eHBA 9600W-16i Tri-Mode Storage Adapter(0x1000-0x4640)"},
{0x1000, 0x00A5, 0x1000, 0x4650, "eHBA 9600W-16e Tri-Mode Storage Adapter(0x1000-0x4650)"},
{0x1000, 0x00A5, 0x1000, 0x4660, "eHBA 9600-24i Tri-Mode Storage Adapter(0x1000-0x4660)"},
{0x1000, 0x00A5, 0x1000, 0x4670, "eHBA 9600-16i Tri-Mode Storage Adapter(0x1000-0x4670)"},
{0x1000, 0x00A5, 0x1000, 0x4680, "eHBA 9600-16e Tri-Mode Storage Adapter(0x1000-0x4680)"},
{0x1000, 0x00A5, 0x1000, 0x4690, "MegaRAID 9620-16i Tri-Mode Storage Adapter(0x1000-0x4690)"},
{0x1000, 0x00A5, 0x1000, 0x46A0, "MegaRAID 9660-24i Tri-Mode Storage Adapter(0x1000-0x46A0)"},
{0x1000, 0x00A5, 0x1000, 0x46C0, "eHBA 9680W-16e Tri-Mode Storage Adapter(0x1000-0x46C0)"},
{0x1000, 0x00A5, 0x1000, 0x46D0, "eHBA 9600-8i8e Tri-Mode Storage Adapter(0x1000-0x46D0)"},
{0x1000, 0x00A5, 0x1000, 0x46E0, "eHBA 9602W-16e Tri-Mode Storage Adapter(0x1000-0x46E0)"},
{0x1000, 0x00A5, 0x1028, 0x2114, "PERC H965i Adapter(0x1028-0x2114)"},
{0x1000, 0x00A5, 0x1028, 0x2115, "PERC H965i Front(0x1028-0x2115)"},
{0x1000, 0x00A5, 0x1028, 0x2117, "PERC H965i MX(0x1028-0x2117)"},
{0x1000, 0x00A5, 0x1028, 0x213A, "PERC H965e Adapter(0x1028-0x213A)"},
{0x1000, 0x00A5, 0x1028, 0x213B, "PERC H765i Adapter(0x1028-0x213B)"},
{0x1000, 0x00A5, 0x1028, 0x213C, "PERC H765i Front(0x1028-0x213C)"},
{0x1000, 0x00A5, 0x1028, 0x213D, "PERC H765N Front(0x1028-0x213D)"},
{0x1000, 0x00A5, 0x1028, 0x213E, "PERC H765i MX(0x1028-0x213E)"},
{0x1000, 0x00A5, 0x1028, 0x213F, "PERC H365i Adapter(0x1028-0x213F)"},
{0x1000, 0x00A5, 0x1028, 0x2140, "PERC H365i Front(0x1028-0x2140)"},
{0x1000, 0x00A5, 0x1028, 0x2142, "HBA465e Adapter(0x1028-0x2142)"},
{0x1000, 0x00A5, 0x1028, 0x2209, "HBA465i Adapter(0x1028-0x2209)"},
{0x1000, 0x00A5, 0x1028, 0x220A, "HBA465i Front(0x1028-0x220A)"},
{0x1000, 0x00A5, 0x1028, 0x22CB, "PERC H365i Front(0x1028-0x22CB)"},
{0x1000, 0x00A5, 0x1028, 0x22CC, "PERC H965i Front(0x1028-0x22CC)"},
{0x1000, 0x00A5, 0x1028, 0x22CD, "HBA465i Front(0x1028-0x22CD)"},
{0x1000, 0x00A5, 0x15D9, 0x1D03, "AOC-S4116L-H16IR (16DD/96DD) RAID Adapter(0x15D9-0x1D03)"},
{0x1000, 0x00A5, 0x15D9, 0x1D07, "AOC-S4016L-L16IT Storage Adapter(0x15D9-0x1D07)"},
{0x1000, 0x00A5, 0x15D9, 0x1D08, "AOC-S4016L-L16IR Storage Adapter(0x15D9-0x1D08)"},
{0x1000, 0x00A5, 0x1D49, 0x020A, "ThinkSystem 450W-16e SAS/SATA PCIe Gen4 24Gb HBA(0x1D49-0x020A)"},
{0x1000, 0x00AB, 0xFFFF, 0xFFFF, "SAS3516 Fusion-MPT Tri-Mode RAID On Chip (ROC)(0x00AB)"},
{0x1000, 0x00AB, 0x1000, 0x3040, "HBA 9400-8i8e(0x1000-0x3040)"},
{0x1000, 0x00AB, 0x8086, 0x3530, "Integrated RAID Module RMSP3JD160J(0x8086-0x3530)"},
{0x1000, 0x00AC, 0xFFFF, 0xFFFF, "SAS3416 Fusion-MPT Tri-Mode I/O Controller Chip (IOC)(0x00AC)"},
{0x1000, 0x00AC, 0x1000, 0x3000, "HBA 9400-16i(0x1000-0x3000)"},
{0x1000, 0x00AC, 0x1000, 0x3020, "HBA 9400-16e(0x1000-0x3020)"},
{0x1000, 0x00AC, 0x1028, 0x1FE3, "HBA345 Adapter(0x1028-0x1FE3)"},
{0x1000, 0x00AC, 0x1028, 0x1FE4, "HBA345 Front(0x1028-0x1FE4)"},
{0x1000, 0x00AC, 0x1D49, 0x0201, "ThinkSystem 430-16i SAS/SATA 12Gb HBA(0x1D49-0x0201)"},
{0x1000, 0x00AC, 0x1D49, 0x0203, "ThinkSystem 430-16e SAS/SATA 12Gb HBA(0x1D49-0x0203)"},
{0x1000, 0x00AC, 0x8086, 0x3000, "RAID Controller RSP3QD160J(0x8086-0x3000)"},
{0x1000, 0x00AC, 0x8086, 0x3020, "RAID Controller RSP3GD016J(0x8086-0x3020)"},
{0x1000, 0x00AE, 0xFFFF, 0xFFFF, "SAS3508 Fusion-MPT Tri-Mode RAID On Chip (ROC)(0x00AE)"},
{0x1000, 0x00AF, 0xFFFF, 0xFFFF, "SAS3408 Fusion-MPT Tri-Mode I/O Controller Chip (IOC)(0x00AF)"},
{0x1000, 0x00AF, 0x1000, 0x3010, "HBA 9400-8i(0x1000-0x3010)"},
{0x1000, 0x00AF, 0x1000, 0x3030, "HBA 9400-8e(0x1000-0x3030)"},
{0x1000, 0x00AF, 0x1D49, 0x0200, "ThinkSystem 430-8i SAS/SATA 12Gb HBA(0x1D49-0x0200)"},
{0x1000, 0x00AF, 0x1D49, 0x0202, "ThinkSystem 430-8e SAS/SATA 12Gb HBA(0x1D49-0x0202)"},
{0x1000, 0x00AF, 0x1D49, 0x0204, "ThinkSystem 430-8i SAS/SATA 12Gb Dense HBA(0x1D49-0x0204)"},
{0x1000, 0x00B2, 0xFFFF, 0xFFFF, "PCIe Switch management endpoint(0x00B2)"},
{0x1000, 0x00B2, 0x1D49, 0x0003, "ThinkSystem 1611-8P PCIe Gen4 NVMe Switch Adapter(0x1D49-0x0003)"},
{0x1000, 0x00B3, 0xFFFF, 0xFFFF, "Fusion-MPT 24G SAS/PCIe SAS50xx/SAS51xx(0x00B3)"},
{0x1000, 0x00B3, 0x1000, 0x5000, "MegaRAID 9760W-32i 24G SAS/PCIe Storage Adapter(0x1000-0x5000)"},
{0x1000, 0x00B3, 0x1000, 0x5001, "MegaRAID 9760W-16i 24G SAS/PCIe Storage Adapter(0x1000-0x5001)"},
{0x1000, 0x00B3, 0x1000, 0x5010, "MegaRAID 9760W-16i16e 24G SAS/PCIe Storage Adapter(0x1000-0x5010)"},
{0x1000, 0x00B3, 0x1000, 0x5020, "eHBA 9700W-32i 24G SAS/PCIe Storage Adapter(0x1000-0x5020)"},
{0x1000, 0x00B3, 0x1000, 0x5021, "eHBA 9700W-16i 24G SAS/PCIe Storage Adapter(0x1000-0x5021)"},
{0x1000, 0x00B3, 0x1000, 0x5030, "eHBA 9700-16e 24G SAS/PCIe Storage Adapter(0x1000-0x5030)"},
{0x1000, 0x00B3, 0x1028, 0x22D2, "PERC H975i Front(0x1028-0x22D2)"},
{0x1000, 0x00B3, 0x1028, 0x22D3, "PERC H975i Adapter(0x1028-0x22D3)"},
{0x1000, 0x00B3, 0x1D49, 0x020B, "ThinkSystem 460-16e SAS/SATA PCIe Gen5 24Gb HBA(0x1D49-0x020B)"},
{0x1000, 0x00B5, 0xFFFF, 0xFFFF, "Fusion-MPT 24G SAS/PCIe SAS50xx/SAS51xx(0x00B5)"},
{0x1000, 0x00B5, 0x1000, 0x5000, "MegaRAID 9760W-32i 24G SAS/PCIe Storage Adapter(0x1000-0x5000)"},
{0x1000, 0x00B5, 0x1000, 0x5001, "MegaRAID 9760W-16i 24G SAS/PCIe Storage Adapter(0x1000-0x5001)"},
{0x1000, 0x00B5, 0x1000, 0x5010, "MegaRAID 9760W-16i16e 24G SAS/PCIe Storage Adapter(0x1000-0x5010)"},
{0x1000, 0x00B5, 0x1000, 0x5020, "eHBA 9700W-32i 24G SAS/PCIe Storage Adapter(0x1000-0x5020)"},
{0x1000, 0x00B5, 0x1000, 0x5021, "eHBA 9700W-16i 24G SAS/PCIe Storage Adapter(0x1000-0x5021)"},
{0x1000, 0x00B5, 0x1000, 0x5030, "eHBA 9700-16e 24G SAS/PCIe Storage Adapter(0x1000-0x5030)"},
{0x1000, 0x00B8, 0xFFFF, 0xFFFF, "Fusion-MPT Switch SAS50xx/SAS51xx(0x00B8)"},
{0x1000, 0x00BE, 0xFFFF, 0xFFFF, "SAS3504 Fusion-MPT Tri-Mode RAID On Chip (ROC)(0x00BE)"},
{0x1000, 0x00BF, 0xFFFF, 0xFFFF, "SAS3404 Fusion-MPT Tri-Mode I/O Controller Chip (IOC)(0x00BF)"},
{0x1000, 0x00C0, 0xFFFF, 0xFFFF, "SAS3324 PCI-Express Fusion-MPT SAS-3(0x00C0)"},
{0x1000, 0x00C1, 0xFFFF, 0xFFFF, "SAS3324 PCI-Express Fusion-MPT SAS-3(0x00C1)"},
{0x1000, 0x00C2, 0xFFFF, 0xFFFF, "SAS3324 PCI-Express Fusion-MPT SAS-3(0x00C2)"},
{0x1000, 0x00C3, 0xFFFF, 0xFFFF, "SAS3324 PCI-Express Fusion-MPT SAS-3(0x00C3)"},
{0x1000, 0x00C4, 0xFFFF, 0xFFFF, "SAS3224 PCI-Express Fusion-MPT SAS-3(0x00C4)"},
{0x1000, 0x00C4, 0x1000, 0x3190, "SAS9305-16i(0x1000-0x3190)"},
{0x1000, 0x00C4, 0x1000, 0x31A0, "SAS9305-24i(0x1000-0x31A0)"},
{0x1000, 0x00C4, 0x1170, 0x0002, "SAS3224 PCI Express to 12Gb HBA MEZZ CARD(0x1170-0x0002)"},
{0x1000, 0x00C5, 0xFFFF, 0xFFFF, "SAS3316 PCI-Express Fusion-MPT SAS-3(0x00C5)"},
{0x1000, 0x00C6, 0xFFFF, 0xFFFF, "SAS3316 PCI-Express Fusion-MPT SAS-3(0x00C6)"},
{0x1000, 0x00C7, 0xFFFF, 0xFFFF, "SAS3316 PCI-Express Fusion-MPT SAS-3(0x00C7)"},
{0x1000, 0x00C8, 0xFFFF, 0xFFFF, "SAS3316 PCI-Express Fusion-MPT SAS-3(0x00C8)"},
{0x1000, 0x00C9, 0xFFFF, 0xFFFF, "SAS3216 PCI-Express Fusion-MPT SAS-3(0x00C9)"},
{0x1000, 0x00C9, 0x1000, 0x3180, "SAS9305-16e(0x1000-0x3180)"},
{0x1000, 0x00CE, 0xFFFF, 0xFFFF, "MegaRAID SAS-3 3316 [Intruder](0x00CE)"},
{0x1000, 0x00CE, 0x1000, 0x9371, "MegaRAID SAS 9361-16i(0x1000-0x9371)"},
{0x1000, 0x00CE, 0x1000, 0x9390, "MegaRAID SAS 9380-8i8e(0x1000-0x9390)"},
{0x1000, 0x00CF, 0xFFFF, 0xFFFF, "MegaRAID SAS-3 3324 [Intruder](0x00CF)"},
{0x1000, 0x00CF, 0x1000, 0x9370, "MegaRAID SAS 9361-24i(0x1000-0x9370)"},
{0x1000, 0x00D0, 0xFFFF, 0xFFFF, "SAS3716 Fusion-MPT Tri-Mode RAID Controller Chip (ROC)(0x00D0)"},
{0x1000, 0x00D0, 0x1000, 0x3050, "HBA 9405W-16i(0x1000-0x3050)"},
{0x1000, 0x00D0, 0x1000, 0x3070, "HBA 9405W-8i8e(0x1000-0x3070)"},
{0x1000, 0x00D1, 0xFFFF, 0xFFFF, "SAS3616 Fusion-MPT Tri-Mode I/O Controller Chip (IOC)(0x00D1)"},
{0x1000, 0x00D1, 0x1000, 0x3080, "HBA 9405W-16e(0x1000-0x3080)"},
{0x1000, 0x00D1, 0x1000, 0x3090, "HBA 9405W-16i(0x1000-0x3090)"},
{0x1000, 0x00D3, 0xFFFF, 0xFFFF, "MegaRAID Tri-Mode SAS3716W(0x00D3)"},
{0x1000, 0x00E0, 0xFFFF, 0xFFFF, "Fusion-MPT 12GSAS/PCIe Unsupported SAS39xx(0x00E0)"},
{0x1000, 0x00E1, 0xFFFF, 0xFFFF, "Fusion-MPT 12GSAS/PCIe SAS39xx(0x00E1)"},
{0x1000, 0x00E2, 0xFFFF, 0xFFFF, "Fusion-MPT 12GSAS/PCIe Secure SAS39xx(0x00E2)"},
{0x1000, 0x00E3, 0xFFFF, 0xFFFF, "Fusion-MPT 12GSAS/PCIe Unsupported SAS39xx(0x00E3)"},
{0x1000, 0x00E4, 0xFFFF, 0xFFFF, "Fusion-MPT 12GSAS/PCIe Unsupported SAS38xx(0x00E4)"},
{0x1000, 0x00E4, 0x1028, 0x200B, "HBA355i Adapter Invalid(0x1028-0x200B)"},
{0x1000, 0x00E4, 0x1028, 0x200C, "HBA355i Front Invalid(0x1028-0x200C)"},
{0x1000, 0x00E4, 0x1028, 0x200D, "HBA355e Adapter Invalid(0x1028-0x200D)"},
{0x1000, 0x00E4, 0x1028, 0x200E, "HBA350i MX Invalid(0x1028-0x200E)"},
{0x1000, 0x00E5, 0xFFFF, 0xFFFF, "Fusion-MPT 12GSAS/PCIe SAS38xx(0x00E5)"},
{0x1000, 0x00E5, 0x1028, 0x200B, "HBA355i Adapter(0x1028-0x200B)"},
{0x1000, 0x00E5, 0x1028, 0x200C, "HBA355i Front(0x1028-0x200C)"},
{0x1000, 0x00E5, 0x1028, 0x200D, "HBA355e Adapter(0x1028-0x200D)"},
{0x1000, 0x00E5, 0x1028, 0x200E, "HBA350i MX(0x1028-0x200E)"},
{0x1000, 0x00E5, 0x1D49, 0x0205, "ThinkSystem 440-16i SAS/SATA PCIe Gen4 12Gb Internal HBA(0x1D49-0x0205)"},
{0x1000, 0x00E5, 0x1D49, 0x0206, "ThinkSystem 440-16e SAS/SATA PCIe Gen4 12Gb HBA(0x1D49-0x0206)"},
{0x1000, 0x00E6, 0xFFFF, 0xFFFF, "Fusion-MPT 12GSAS/PCIe Secure SAS38xx(0x00E6)"},
{0x1000, 0x00E6, 0x1000, 0x4050, "9500-16i Tri-Mode HBA(0x1000-0x4050)"},
{0x1000, 0x00E6, 0x1000, 0x4060, "9500-8i Tri-Mode HBA(0x1000-0x4060)"},
{0x1000, 0x00E6, 0x1000, 0x4070, "9500-16e Tri-Mode HBA(0x1000-0x4070)"},
{0x1000, 0x00E6, 0x1000, 0x4080, "9500-8e Tri-Mode HBA(0x1000-0x4080)"},
{0x1000, 0x00E6, 0x1028, 0x200B, "HBA355i Adapter(0x1028-0x200B)"},
{0x1000, 0x00E6, 0x1028, 0x200C, "HBA355i Front(0x1028-0x200C)"},
{0x1000, 0x00E6, 0x1028, 0x200D, "HBA355e Adapter(0x1028-0x200D)"},
{0x1000, 0x00E6, 0x1028, 0x200E, "HBA350i MX(0x1028-0x200E)"},
{0x1000, 0x00E6, 0x1028, 0x2170, "HBA350i MM(0x1028-0x2170)"},
{0x1000, 0x00E6, 0x1028, 0x2175, "HBA350i Adapter(0x1028-0x2175)"},
{0x1000, 0x00E6, 0x1028, 0x2197, "HBA350i MM LP(0x1028-0x2197)"},
{0x1000, 0x00E6, 0x1028, 0x2212, "HBA355e-s Adapter(0x1028-0x2212)"},
{0x1000, 0x00E6, 0x15D9, 0x1B64, "SCC-B8SB80-B1 (NI22) Storage Controller Card(0x15D9-0x1B64)"},
{0x1000, 0x00E6, 0x15D9, 0x1B65, "AOC-S3816L-L16iT (NI22) Storage Adapter(0x15D9-0x1B65)"},
{0x1000, 0x00E6, 0x15D9, 0x1B99, "AOC-S3808L-L8iT Storage Adapter(0x15D9-0x1B99)"},
{0x1000, 0x00E6, 0x1D49, 0x0205, "ThinkSystem 440-16i SAS/SATA PCIe Gen4 12Gb Internal HBA(0x1D49-0x0205)"},
{0x1000, 0x00E6, 0x1D49, 0x0206, "ThinkSystem 440-16e SAS/SATA PCIe Gen4 12Gb HBA(0x1D49-0x0206)"},
{0x1000, 0x00E6, 0x1D49, 0x0207, "ThinkSystem 440-8i SAS/SATA PCIe Gen4 12Gb HBA(0x1D49-0x0207)"},
{0x1000, 0x00E6, 0x1D49, 0x0208, "ThinkSystem 440-16i SAS/SATA PCIe Gen4 12Gb HBA(0x1D49-0x0208)"},
{0x1000, 0x00E6, 0x1D49, 0x0209, "ThinkSystem 440-8e SAS/SATA PCIe Gen4 12Gb HBA(0x1D49-0x0209)"},
{0x1000, 0x00E6, 0x8086, 0x4050, "Storage Controller RS3P4QF160J(0x8086-0x4050)"},
{0x1000, 0x00E6, 0x8086, 0x4070, "Storage Controller RS3P4GF016J(0x8086-0x4070)"},
{0x1000, 0x00E7, 0xFFFF, 0xFFFF, "Fusion-MPT 12GSAS/PCIe Unsupported SAS38xx(0x00E7)"},
{0x1000, 0x00E7, 0x1028, 0x200B, "HBA355i Adapter Tampered(0x1028-0x200B)"},
{0x1000, 0x00E7, 0x1028, 0x200C, "HBA355i Front Tampered(0x1028-0x200C)"},
{0x1000, 0x00E7, 0x1028, 0x200D, "HBA355e Adapter Tampered(0x1028-0x200D)"},
{0x1000, 0x00E7, 0x1028, 0x200E, "HBA350i MX Tampered(0x1028-0x200E)"},
{0x1000, 0x02B0, 0xFFFF, 0xFFFF, "Virtual Endpoint on PCIe Switch(0x02B0)"},
{0x1000, 0x02B0, 0x1D49, 0x0001, "ThinkSystem 1610-4P NVMe Switch Adapter(0x1D49-0x0001)"},
{0x1000, 0x02B0, 0x1D49, 0x0002, "ThinkSystem 810-4P NVMe Switch Adapter(0x1D49-0x0002)"},
{0x1000, 0x02B1, 0xFFFF, 0xFFFF, "Virtual Endpoint on PCIe Switch (9749)(0x02B1)"},
{0x1000, 0x02B1, 0x1D49, 0x0004, "ThinkSystem 1610-8P NVMe Switch Adapter(0x1D49-0x0004)"},
{0x1000, 0x02B2, 0xFFFF, 0xFFFF, "Virtual PCIe Placeholder Endpoint(0x02B2)"},
{0x1000, 0x0407, 0xFFFF, 0xFFFF, "MegaRAID(0x0407)"},
{0x1000, 0x0407, 0x1000, 0x0530, "MegaRAID 530 SCSI 320-0X RAID Controller(0x1000-0x0530)"},
{0x1000, 0x0407, 0x1000, 0x0531, "MegaRAID 531 SCSI 320-4X RAID Controller(0x1000-0x0531)"},
{0x1000, 0x0407, 0x1000, 0x0532, "MegaRAID 532 SCSI 320-2X RAID Controller(0x1000-0x0532)"},
{0x1000, 0x0407, 0x1028, 0x0531, "PowerEdge Expandable RAID Controller 4/QC(0x1028-0x0531)"},
{0x1000, 0x0407, 0x1028, 0x0533, "PowerEdge Expandable RAID Controller 4/QC(0x1028-0x0533)"},
{0x1000, 0x0407, 0x8086, 0x0530, "MegaRAID Intel RAID Controller SRCZCRX(0x8086-0x0530)"},
{0x1000, 0x0407, 0x8086, 0x0532, "MegaRAID Intel RAID Controller SRCU42X(0x8086-0x0532)"},
{0x1000, 0x0408, 0xFFFF, 0xFFFF, "MegaRAID(0x0408)"},
{0x1000, 0x0408, 0x1000, 0x0001, "MegaRAID SCSI 320-1E RAID Controller(0x1000-0x0001)"},
{0x1000, 0x0408, 0x1000, 0x0002, "MegaRAID SCSI 320-2E RAID Controller(0x1000-0x0002)"},
{0x1000, 0x0408, 0x1025, 0x004D, "MegaRAID ACER ROMB-2E RAID Controller(0x1025-0x004D)"},
{0x1000, 0x0408, 0x1028, 0x0001, "PowerEdge RAID Controller PERC4e/SC(0x1028-0x0001)"},
{0x1000, 0x0408, 0x1028, 0x0002, "PowerEdge RAID Controller PERC4e/DC(0x1028-0x0002)"},
{0x1000, 0x0408, 0x1028, 0x0012, "PowerEdge RAID Controller RAC4(0x1028-0x0012)"},
{0x1000, 0x0408, 0x1028, 0x0015, "PowerEdge RAID Controller PERC5(0x1028-0x0015)"},
{0x1000, 0x0408, 0x1028, 0x1F03, "PowerEdge RAID Controller PERC5(0x1028-0x1F03)"},
{0x1000, 0x0408, 0x1734, 0x1065, "FSC MegaRAID PCI Express ROMB(0x1734-0x1065)"},
{0x1000, 0x0408, 0x8086, 0x0002, "MegaRAID Intel RAID Controller SRCU42E(0x8086-0x0002)"},
{0x1000, 0x0408, 0x8086, 0x3449, "MegaRAID Intel RAID Controller SROMBU(0x8086-0x3449)"},
{0x1000, 0x0409, 0xFFFF, 0xFFFF, "MegaRAID(0x0409)"},
{0x1000, 0x0409, 0x1000, 0x3004, "MegaRAID SATA 300-4X RAID Controller(0x1000-0x3004)"},
{0x1000, 0x0409, 0x1000, 0x3008, "MegaRAID SATA 300-8X RAID Controller(0x1000-0x3008)"},
{0x1000, 0x0409, 0x8086, 0x3008, "MegaRAID RAID Controller SRCS28X(0x8086-0x3008)"},
{0x1000, 0x0409, 0x8086, 0x3431, "MegaRAID RAID Controller Alief SROMBU42E(0x8086-0x3431)"},
{0x1000, 0x0409, 0x8086, 0x3499, "MegaRAID RAID Controller Harwich SROMBU42E(0x8086-0x3499)"},
{0x1000, 0x0411, 0xFFFF, 0xFFFF, "MegaRAID SAS 1068(0x0411)"},
{0x1000, 0x0411, 0x1000, 0x1001, "MegaRAID SAS 8408E(0x1000-0x1001)"},
{0x1000, 0x0411, 0x1000, 0x1002, "MegaRAID SAS 8480E(0x1000-0x1002)"},
{0x1000, 0x0411, 0x1000, 0x1003, "MegaRAID SAS 8344ELP(0x1000-0x1003)"},
{0x1000, 0x0411, 0x1000, 0x1004, "MegaRAID SAS 8308ELP(0x1000-0x1004)"},
{0x1000, 0x0411, 0x1000, 0x1008, "MegaRAID SAS 84016E(0x1000-0x1008)"},
{0x1000, 0x0411, 0x1000, 0x100C, "MegaRAID SATA 300-12E(0x1000-0x100C)"},
{0x1000, 0x0411, 0x1000, 0x100D, "MegaRAID SATA 300-16E(0x1000-0x100D)"},
{0x1000, 0x0411, 0x1000, 0x2004, "MegaRAID SATA 300-8ELP(0x1000-0x2004)"},
{0x1000, 0x0411, 0x1000, 0x2005, "MegaRAID SATA 300-4ELP(0x1000-0x2005)"},
{0x1000, 0x0411, 0x1033, 0x8287, "MegaRAID SAS PCI Express ROMB(0x1033-0x8287)"},
{0x1000, 0x0411, 0x1054, 0x3016, "MegaRAID SAS RoMB Server(0x1054-0x3016)"},
{0x1000, 0x0411, 0x1734, 0x1081, "MegaRAID SAS PCI Express ROMB(0x1734-0x1081)"},
{0x1000, 0x0411, 0x1734, 0x10A3, "MegaRAID SAS PCI Express ROMB(0x1734-0x10A3)"},
{0x1000, 0x0411, 0x8086, 0x1001, "RAID Controller SRCSAS18E(0x8086-0x1001)"},
{0x1000, 0x0411, 0x8086, 0x1003, "RAID Controller SRCSAS144E(0x8086-0x1003)"},
{0x1000, 0x0411, 0x8086, 0x3500, "SROMBSAS18E RAID Controller(0x8086-0x3500)"},
{0x1000, 0x0411, 0x8086, 0x3501, "SROMBSAS18E RAID Controller(0x8086-0x3501)"},
{0x1000, 0x0411, 0x8086, 0x3504, "SROMBSAS18E RAID Controller(0x8086-0x3504)"},
{0x1000, 0x0413, 0xFFFF, 0xFFFF, "MegaRAID SAS 1068 [Verde ZCR](0x0413)"},
{0x1000, 0x0413, 0x1000, 0x1005, "MegaRAID SAS 8300XLP(0x1000-0x1005)"},
{0x1000, 0x0621, 0xFFFF, 0xFFFF, "FC909 Fibre Channel Adapter(0x0621)"},
{0x1000, 0x0622, 0xFFFF, 0xFFFF, "FC929 Fibre Channel Adapter(0x0622)"},
{0x1000, 0x0622, 0x1000, 0x1020, "44929 O Dual Fibre Channel card(0x1000-0x1020)"},
{0x1000, 0x0623, 0xFFFF, 0xFFFF, "FC929 LAN(0x0623)"},
{0x1000, 0x0624, 0xFFFF, 0xFFFF, "FC919 Fibre Channel Adapter(0x0624)"},
{0x1000, 0x0625, 0xFFFF, 0xFFFF, "FC919 LAN(0x0625)"},
{0x1000, 0x0626, 0xFFFF, 0xFFFF, "FC929X Fibre Channel Adapter(0x0626)"},
{0x1000, 0x0626, 0x1000, 0x1010, "7202-XP-LC Dual Fibre Channel card(0x1000-0x1010)"},
{0x1000, 0x0627, 0xFFFF, 0xFFFF, "FC929X LAN(0x0627)"},
{0x1000, 0x0628, 0xFFFF, 0xFFFF, "FC919X Fibre Channel Adapter(0x0628)"},
{0x1000, 0x0629, 0xFFFF, 0xFFFF, "FC919X LAN(0x0629)"},
{0x1000, 0x0640, 0xFFFF, 0xFFFF, "FC949X Fibre Channel Adapter(0x0640)"},
{0x1000, 0x0642, 0xFFFF, 0xFFFF, "FC939X Fibre Channel Adapter(0x0642)"},
{0x1000, 0x0646, 0xFFFF, 0xFFFF, "FC949ES Fibre Channel Adapter(0x0646)"},
{0x1000, 0x0701, 0xFFFF, 0xFFFF, "83C885 NT50 DigitalScape Fast Ethernet(0x0701)"},
{0x1000, 0x0702, 0xFFFF, 0xFFFF, "Yellowfin G-NIC gigabit ethernet(0x0702)"},
{0x1000, 0x0702, 0x1318, 0x0000, "PEI100X(0x1318-0x0000)"},
{0x1000, 0x0804, 0xFFFF, 0xFFFF, "SA2010(0x0804)"},
{0x1000, 0x0805, 0xFFFF, 0xFFFF, "SA2010ZC(0x0805)"},
{0x1000, 0x0806, 0xFFFF, 0xFFFF, "SA2020(0x0806)"},
{0x1000, 0x0807, 0xFFFF, 0xFFFF, "SA2020ZC(0x0807)"},
{0x1000, 0x0901, 0xFFFF, 0xFFFF, "61C102(0x0901)"},
{0x1000, 0x1000, 0xFFFF, 0xFFFF, "63C815(0x1000)"},
{0x1000, 0x10E0, 0xFFFF, 0xFFFF, "MegaRAID 12GSAS/PCIe Unsupported SAS39xx(0x10E0)"},
{0x1000, 0x10E0, 0x1028, 0x1AE0, "PERC H755 Adapter - Invalid Device(0x1028-0x1AE0)"},
{0x1000, 0x10E0, 0x1028, 0x1AE1, "PERC H755 Front - Invalid Device(0x1028-0x1AE1)"},
{0x1000, 0x10E0, 0x1028, 0x1AE2, "PERC H755N Front - Invalid Device(0x1028-0x1AE2)"},
{0x1000, 0x10E0, 0x1028, 0x1AE3, "PERC H755 MX - Invalid Device(0x1028-0x1AE3)"},
{0x1000, 0x10E1, 0xFFFF, 0xFFFF, "MegaRAID 12GSAS/PCIe SAS39xx(0x10E1)"},
{0x1000, 0x10E1, 0x1028, 0x1AE0, "PERC H755 Adapter(0x1028-0x1AE0)"},
{0x1000, 0x10E1, 0x1028, 0x1AE1, "PERC H755 Front(0x1028-0x1AE1)"},
{0x1000, 0x10E1, 0x1028, 0x1AE2, "PERC H755N Front(0x1028-0x1AE2)"},
{0x1000, 0x10E1, 0x1028, 0x1AE3, "PERC H755 MX(0x1028-0x1AE3)"},
{0x1000, 0x10E1, 0x1D49, 0x060A, "ThinkSystem RAID 940-8i 4GB Flash PCIe Gen4 12Gb Adapter(0x1D49-0x060A)"},
{0x1000, 0x10E1, 0x1D49, 0x060B, "ThinkSystem RAID 940-8i 8GB Flash PCIe Gen4 12Gb Adapter(0x1D49-0x060B)"},
{0x1000, 0x10E1, 0x1D49, 0x060C, "ThinkSystem RAID 940-16i 8GB Flash PCIe Gen4 12Gb Adapter(0x1D49-0x060C)"},
{0x1000, 0x10E1, 0x1D49, 0x060D, "ThinkSystem RAID 940-16i 8GB Flash PCIe Gen4 12Gb Internal Adapter(0x1D49-0x060D)"},
{0x1000, 0x10E1, 0x1D49, 0x060E, "ThinkSystem RAID 940-32i 8GB Flash PCIe Gen4 12Gb Adapter(0x1D49-0x060E)"},
{0x1000, 0x10E1, 0x1D49, 0x060F, "ThinkSystem RAID 940-8e 4GB Flash PCIe Gen4 12Gb Adapter(0x1D49-0x060F)"},
{0x1000, 0x10E2, 0xFFFF, 0xFFFF, "MegaRAID 12GSAS/PCIe Secure SAS39xx(0x10E2)"},
{0x1000, 0x10E2, 0x1000, 0x4000, "MegaRAID 9560-16i(0x1000-0x4000)"},
{0x1000, 0x10E2, 0x1000, 0x4002, "MegaRAID 9561-16i(0x1000-0x4002)"},
{0x1000, 0x10E2, 0x1000, 0x4010, "MegaRAID 9560-8i(0x1000-0x4010)"},
{0x1000, 0x10E2, 0x1000, 0x4015, "MegaRAID 9550-8i(0x1000-0x4015)"},
{0x1000, 0x10E2, 0x1000, 0x4020, "MegaRAID 9580-8i8e(0x1000-0x4020)"},
{0x1000, 0x10E2, 0x1000, 0x40B0, "MegaRAID 9562-16i(0x1000-0x40B0)"},
{0x1000, 0x10E2, 0x1028, 0x1AE0, "PERC H755 Adapter(0x1028-0x1AE0)"},
{0x1000, 0x10E2, 0x1028, 0x1AE1, "PERC H755 Front(0x1028-0x1AE1)"},
{0x1000, 0x10E2, 0x1028, 0x1AE2, "PERC H755N Front(0x1028-0x1AE2)"},
{0x1000, 0x10E2, 0x1028, 0x1AE3, "PERC H755 MX(0x1028-0x1AE3)"},
{0x1000, 0x10E2, 0x1028, 0x2171, "PERC H750 Mini(0x1028-0x2171)"},
{0x1000, 0x10E2, 0x1028, 0x2176, "PERC H750 Adapter(0x1028-0x2176)"},
{0x1000, 0x10E2, 0x15D9, 0x1B66, "AOC-S3908L-H8iR RAID Adapter(0x15D9-0x1B66)"},
{0x1000, 0x10E2, 0x15D9, 0x1B67, "AOC-S3916L-H16iR RAID Adapter(0x15D9-0x1B67)"},
{0x1000, 0x10E2, 0x15D9, 0x1C06, "AOC-S3916L-H16iR-32DD+ RAID Adapter(0x15D9-0x1C06)"},
{0x1000, 0x10E2, 0x1D49, 0x060A, "ThinkSystem RAID 940-8i 4GB Flash PCIe Gen4 12Gb Adapter(0x1D49-0x060A)"},
{0x1000, 0x10E2, 0x1D49, 0x060B, "ThinkSystem RAID 940-8i 8GB Flash PCIe Gen4 12Gb Adapter(0x1D49-0x060B)"},
{0x1000, 0x10E2, 0x1D49, 0x060C, "ThinkSystem RAID 940-16i 8GB Flash PCIe Gen4 12Gb Adapter(0x1D49-0x060C)"},
{0x1000, 0x10E2, 0x1D49, 0x060D, "ThinkSystem RAID 940-16i 8GB Flash PCIe Gen4 12Gb Internal Adapter(0x1D49-0x060D)"},
{0x1000, 0x10E2, 0x1D49, 0x060E, "ThinkSystem RAID 940-32i 8GB Flash PCIe Gen4 12Gb Adapter(0x1D49-0x060E)"},
{0x1000, 0x10E2, 0x1D49, 0x060F, "ThinkSystem RAID 940-8e 4GB Flash PCIe Gen4 12Gb Adapter(0x1D49-0x060F)"},
{0x1000, 0x10E2, 0x1D49, 0x0610, "ThinkSystem RAID 940-16i 4GB Flash PCIe Gen4 12Gb Adapter(0x1D49-0x0610)"},
{0x1000, 0x10E2, 0x8086, 0x4000, "RAID Controller RS3P4TF160F(0x8086-0x4000)"},
{0x1000, 0x10E2, 0x8086, 0x4020, "RAID Controller RS3P4MF088F(0x8086-0x4020)"},
{0x1000, 0x10E3, 0xFFFF, 0xFFFF, "MegaRAID 12GSAS/PCIe Unsupported SAS39xx(0x10E3)"},
{0x1000, 0x10E3, 0x1028, 0x1AE0, "PERC H755 Adapter - Tampered Device(0x1028-0x1AE0)"},
{0x1000, 0x10E3, 0x1028, 0x1AE1, "PERC H755 Front - Tampered Device(0x1028-0x1AE1)"},
{0x1000, 0x10E3, 0x1028, 0x1AE2, "PERC H755N Front - Tampered Device(0x1028-0x1AE2)"},
{0x1000, 0x10E3, 0x1028, 0x1AE3, "PERC H755 MX - Tampered Device(0x1028-0x1AE3)"},
{0x1000, 0x10E4, 0xFFFF, 0xFFFF, "MegaRAID 12GSAS/PCIe Unsupported SAS38xx(0x10E4)"},
{0x1000, 0x10E5, 0xFFFF, 0xFFFF, "MegaRAID 12GSAS/PCIe SAS38xx(0x10E5)"},
{0x1000, 0x10E6, 0xFFFF, 0xFFFF, "MegaRAID 12GSAS/PCIe Secure SAS38xx(0x10E6)"},
{0x1000, 0x10E6, 0x1000, 0x04D9, "3808N iMR ROMB(0x1000-0x04D9)"},
{0x1000, 0x10E6, 0x1000, 0x04DA, "3808N iMR ROMB(0x1000-0x04DA)"},
{0x1000, 0x10E6, 0x1000, 0x04DB, "3808N iMR ROMB(0x1000-0x04DB)"},
{0x1000, 0x10E6, 0x1000, 0x04DC, "3808N iMR ROMB(0x1000-0x04DC)"},
{0x1000, 0x10E6, 0x1000, 0x04DD, "3808N iMR ROMB(0x1000-0x04DD)"},
{0x1000, 0x10E6, 0x1000, 0x40D8, "MegaRAID 9524-8i(0x1000-0x40D8)"},
{0x1000, 0x10E6, 0x1000, 0x40E0, "MegaRAID 9540-2M2(0x1000-0x40E0)"},
{0x1000, 0x10E6, 0x1028, 0x2172, "PERC H355 Adapter(0x1028-0x2172)"},
{0x1000, 0x10E6, 0x1028, 0x2173, "PERC H355 Front(0x1028-0x2173)"},
{0x1000, 0x10E6, 0x1028, 0x2174, "PERC H350 Mini(0x1028-0x2174)"},
{0x1000, 0x10E6, 0x1028, 0x2177, "PERC H350 Adapter(0x1028-0x2177)"},
{0x1000, 0x10E6, 0x1028, 0x2199, "PERC H350 Mini LP(0x1028-0x2199)"},
{0x1000, 0x10E6, 0x15D9, 0x1B9D, "AOC-S3816L-L16IR Storage Adapter(0x15D9-0x1B9D)"},
{0x1000, 0x10E6, 0x15D9, 0x1B9F, "AOC-S3816L-L8IR Storage Adapter(0x15D9-0x1B9F)"},
{0x1000, 0x10E6, 0x15D9, 0x1C6D, "AOC-S3808L-L8IR Storage Adapter(0x15D9-0x1C6D)"},
{0x1000, 0x10E6, 0x15D9, 0x1C6E, "AOC-SLG4-2H8M2 Storage Adapter(0x15D9-0x1C6E)"},
{0x1000, 0x10E6, 0x1D49, 0x0505, "ThinkSystem RAID 540-8i PCIe Gen4 12Gb Adapter(0x1D49-0x0505)"},
{0x1000, 0x10E6, 0x1D49, 0x0506, "ThinkSystem RAID 540-16i PCIe Gen4 12Gb Adapter(0x1D49-0x0506)"},
{0x1000, 0x10E6, 0x1D49, 0x0507, "ThinkSystem RAID 545-8i PCIe Gen4 12Gb Adapter(0x1D49-0x0507)"},
{0x1000, 0x10E6, 0x1D49, 0x0700, "ThinkSystem M.2 RAID B540i-2i SATA/NVMe Enablement Kit(0x1D49-0x0700)"},
{0x1000, 0x10E6, 0x1D49, 0x0701, "ThinkSystem 7mm RAID B540p-2HS SATA/NVMe Enablement Kit(0x1D49-0x0701)"},
{0x1000, 0x10E6, 0x1D49, 0x0702, "ThinkSystem M.2 RAID B540p-2HS SATA/NVMe Enablement Kit(0x1D49-0x0702)"},
{0x1000, 0x10E6, 0x1D49, 0x0703, "ThinkSystem M.2 RAID B540d-2HS SATA/NVMe Enablement Kit(0x1D49-0x0703)"},
{0x1000, 0x10E6, 0x1D49, 0x0704, "ThinkSystem M.2 RAID B545i-2i SATA/NVMe Enablement Kit(0x1D49-0x0704)"},
{0x1000, 0x10E7, 0xFFFF, 0xFFFF, "MegaRAID 12GSAS/PCIe Unsupported SAS38xx(0x10E7)"},
{0x1000, 0x1960, 0xFFFF, 0xFFFF, "MegaRAID(0x1960)"},
{0x1000, 0x1960, 0x1000, 0x0518, "MegaRAID 518 SCSI 320-2 Controller(0x1000-0x0518)"},
{0x1000, 0x1960, 0x1000, 0x0520, "MegaRAID 520 SCSI 320-1 Controller(0x1000-0x0520)"},
{0x1000, 0x1960, 0x1000, 0x0522, "MegaRAID 522 i4 133 RAID Controller(0x1000-0x0522)"},
{0x1000, 0x1960, 0x1000, 0x0523, "MegaRAID SATA 150-6 RAID Controller(0x1000-0x0523)"},
{0x1000, 0x1960, 0x1000, 0x4523, "MegaRAID SATA 150-4 RAID Controller(0x1000-0x4523)"},
{0x1000, 0x1960, 0x1000, 0xA520, "MegaRAID ZCR SCSI 320-0 Controller(0x1000-0xA520)"},
{0x1000, 0x1960, 0x1028, 0x0518, "MegaRAID 518 DELL PERC 4/DC RAID Controller(0x1028-0x0518)"},
{0x1000, 0x1960, 0x1028, 0x0520, "MegaRAID 520 DELL PERC 4/SC RAID Controller(0x1028-0x0520)"},
{0x1000, 0x1960, 0x1028, 0x0531, "PowerEdge Expandable RAID Controller 4/QC(0x1028-0x0531)"},
{0x1000, 0x1960, 0x1028, 0x0533, "PowerEdge Expandable RAID Controller 4/QC(0x1028-0x0533)"},
{0x1000, 0x1960, 0x8086, 0x0520, "MegaRAID RAID Controller SRCU41L(0x8086-0x0520)"},
{0x1000, 0x1960, 0x8086, 0x0523, "MegaRAID RAID Controller SRCS16(0x8086-0x0523)"},
{0x1000, 0x3050, 0xFFFF, 0xFFFF, "SAS2008 PCI-Express Fusion-MPT SAS-2(0x3050)"},
{0x1000, 0x3150, 0xFFFF, 0xFFFF, "1068e(0x3150)"},
{0x1000, 0x6001, 0xFFFF, 0xFFFF, "DX1 Multiformat Broadcast HD/SD Encoder/Decoder(0x6001)"},
{0x1000, 0xC010, 0xFFFF, 0xFFFF, "PEX880xx PCIe Gen 4 Switch(0xC010)"},
{0x1000, 0xC010, 0x1000, 0x100B, "PEX88000 PCIe Gen 4 Virtual Upstream/Downstream Port(0x1000-0x100B)"},
{0x1000, 0xC010, 0x1000, 0x2004, "PEX88000 Virtual PCIe TWC/NT2 Endpoint(0x1000-0x2004)"},
{0x1000, 0xC010, 0x1000, 0x2005, "PEX88000 Virtual PCIe gDMA Endpoint(0x1000-0x2005)"},
{0x1000, 0xC010, 0x1000, 0xA024, "PEX88024 24 lane/port PCIe Gen 4.0 Switch(0x1000-0xA024)"},
{0x1000, 0xC010, 0x1000, 0xA032, "PEX88032 32 lane/port PCIe Gen 4 Switch(0x1000-0xA032)"},
{0x1000, 0xC010, 0x1000, 0xA048, "PEX88048 50 lane/port PCIe Gen 4.0 Switch(0x1000-0xA048)"},
{0x1000, 0xC010, 0x1000, 0xA064, "PEX88064 64 lane/port PCIe Gen 4 Switch(0x1000-0xA064)"},
{0x1000, 0xC010, 0x1000, 0xA080, "PEX88080 80 lane/port PCIe Gen 4 Switch(0x1000-0xA080)"},
{0x1000, 0xC010, 0x1000, 0xA096, "PEX88096 98 lane/port PCIe Gen 4.0 Switch(0x1000-0xA096)"},
{0x1000, 0xC010, 0x4C52, 0x9F48, "LRNV9F48 4-port Built-in 8654 NVMe Switching Adapter(0x4C52-0x9F48)"},
{0x1000, 0xC012, 0xFFFF, 0xFFFF, "PEX880xx PCIe Gen 4 Switch(0xC012)"},
{0x1000, 0xC012, 0x1000, 0x100B, "PEX88000 PCIe Gen 4 Virtual Upstream/Downstream Port(0x1000-0x100B)"},
{0x1000, 0xC012, 0x1000, 0x2004, "PEX88000 Virtual PCIe TWC/NT2 Endpoint(0x1000-0x2004)"},
{0x1000, 0xC012, 0x1000, 0x2005, "PEX88000 Virtual PCIe gDMA Endpoint(0x1000-0x2005)"},
{0x1000, 0xC012, 0x1000, 0xA024, "PEX88024 24 lane/port PCIe Gen 4.0 Switch(0x1000-0xA024)"},
{0x1000, 0xC012, 0x1000, 0xA032, "PEX88032 32 lane/port PCIe Gen 4.0 Switch(0x1000-0xA032)"},
{0x1000, 0xC012, 0x1000, 0xA048, "PEX88048 48 lane/port PCIe Gen 4.0 Switch(0x1000-0xA048)"},
{0x1000, 0xC012, 0x1000, 0xA064, "PEX88064 64 lane/port PCIe Gen 4.0 Switch(0x1000-0xA064)"},
{0x1000, 0xC012, 0x1000, 0xA080, "PEX88080 80 lane/port PCIe Gen 4.0 Switch(0x1000-0xA080)"},
{0x1000, 0xC012, 0x1000, 0xA096, "PEX88096 96 lane/port PCIe Gen 4.0 Switch(0x1000-0xA096)"},
{0x1000, 0xC012, 0x1D49, 0x0003, "ThinkSystem 1611-8P PCIe Gen4 NVMe Switch Adapter(0x1D49-0x0003)"},
{0x1000, 0xC030, 0xFFFF, 0xFFFF, "PEX890xx PCIe Gen 5 Switch(0xC030)"},
{0x1000, 0xC030, 0x1000, 0x0024, "PEX89024 PCIe Gen 5 24 port/lane Switch Upstream/Downstream Port(0x1000-0x0024)"},
{0x1000, 0xC030, 0x1000, 0x0032, "PEX89032 PCIe Gen 5 32 port/lane Switch Upstream/Downstream Port(0x1000-0x0032)"},
{0x1000, 0xC030, 0x1000, 0x0048, "PEX89048 PCIe Gen 5 48 port/lane Switch Upstream/Downstream Port(0x1000-0x0048)"},
{0x1000, 0xC030, 0x1000, 0x0072, "PEX89072 PCIe Gen 5 36 port/72 lane Switch Upstream/Downstream Port(0x1000-0x0072)"},
{0x1000, 0xC030, 0x1000, 0x0088, "PEX89088 PCIe Gen 5 44 port/88 lane Switch Upstream/Downstream Port(0x1000-0x0088)"},
{0x1000, 0xC030, 0x1000, 0x0104, "PEX89104 PCIe Gen 5 52 port/104 lane Switch Upstream/Downstream Port(0x1000-0x0104)"},
{0x1000, 0xC030, 0x1000, 0x0144, "PEX89144 PCIe Gen 5 72 port/144 lane Switch Upstream/Downstream Port(0x1000-0x0144)"},
{0x1000, 0xC030, 0x1000, 0x100B, "PEX89000 PCIe Gen 5 Virtual Upstream/Downstream Port(0x1000-0x100B)"},
{0x1000, 0xC030, 0x1000, 0x2004, "PEX89000 Virtual PCIe TWC/NT 2.0 Endpoint(0x1000-0x2004)"},
{0x1000, 0xC030, 0x1000, 0x2005, "PEX89000 Virtual PCIe gDMA Endpoint(0x1000-0x2005)"},
{0x1000, 0xC034, 0xFFFF, 0xFFFF, "PEX890xx PCIe Gen 5 Switch(0xC034)"},
{0x1000, 0xC034, 0x1000, 0x0024, "PEX89024 PCIe Gen 5 24 port/lane Switch Upstream/Downstream Port(0x1000-0x0024)"},
{0x1000, 0xC034, 0x1000, 0x0032, "PEX89032 PCIe Gen 5 32 port/lane Switch Upstream/Downstream Port(0x1000-0x0032)"},
{0x1000, 0xC034, 0x1000, 0x0048, "PEX89048 PCIe Gen 5 48 port/lane Switch Upstream/Downstream Port(0x1000-0x0048)"},
{0x1000, 0xC034, 0x1000, 0x100B, "PEX89000 PCIe Gen 5 Virtual Upstream/Downstream Port(0x1000-0x100B)"},
{0x1000, 0xC034, 0x1000, 0x2004, "PEX89000 Virtual PCIe TWC/NT 2.0 Endpoint(0x1000-0x2004)"},
{0x1000, 0xC034, 0x1000, 0x2005, "PEX89000 Virtual PCIe gDMA Endpoint(0x1000-0x2005)"},
}; /* pci_vid_1000[] */

static pci_id_t const pci_vid_1001[] = {
{0x1001, 0xFFFF, 0xFFFF, 0xFFFF, "Kolter Electronic(0x1001)"},
{0x1001, 0x0010, 0xFFFF, 0xFFFF, "PCI 1616 Measurement card with 32 digital I/O lines(0x0010)"},
{0x1001, 0x0011, 0xFFFF, 0xFFFF, "OPTO-PCI Opto-Isolated digital I/O board(0x0011)"},
{0x1001, 0x0012, 0xFFFF, 0xFFFF, "PCI-AD/DA Analogue I/O board(0x0012)"},
{0x1001, 0x0013, 0xFFFF, 0xFFFF, "PCI-OPTO-RELAIS Digital I/O board with relay outputs(0x0013)"},
{0x1001, 0x0014, 0xFFFF, 0xFFFF, "PCI-Counter/Timer Counter Timer board(0x0014)"},
{0x1001, 0x0015, 0xFFFF, 0xFFFF, "PCI-DAC416 Analogue output board(0x0015)"},
{0x1001, 0x0016, 0xFFFF, 0xFFFF, "PCI-MFB Analogue I/O board(0x0016)"},
{0x1001, 0x0017, 0xFFFF, 0xFFFF, "PROTO-3 PCI Prototyping board(0x0017)"},
{0x1001, 0x9100, 0xFFFF, 0xFFFF, "INI-9100/9100W SCSI Host(0x9100)"},
}; /* pci_vid_1001[] */

static pci_id_t const pci_vid_1002[] = {
{0x1002, 0xFFFF, 0xFFFF, 0xFFFF, "Advanced Micro Devices, Inc. [AMD/ATI](0x1002)"},
{0x1002, 0x1304, 0xFFFF, 0xFFFF, "Kaveri(0x1304)"},
{0x1002, 0x1305, 0xFFFF, 0xFFFF, "Kaveri(0x1305)"},
{0x1002, 0x1306, 0xFFFF, 0xFFFF, "Kaveri(0x1306)"},
{0x1002, 0x1307, 0xFFFF, 0xFFFF, "Kaveri(0x1307)"},
{0x1002, 0x1308, 0xFFFF, 0xFFFF, "Kaveri HDMI/DP Audio Controller(0x1308)"},
{0x1002, 0x1308, 0x17AA, 0x3988, "Z50-75(0x17AA-0x3988)"},
{0x1002, 0x1309, 0xFFFF, 0xFFFF, "Kaveri [Radeon R6/R7 Graphics](0x1309)"},
{0x1002, 0x1309, 0x17AA, 0x3830, "Z50-75(0x17AA-0x3830)"},
{0x1002, 0x130A, 0xFFFF, 0xFFFF, "Kaveri [Radeon R6 Graphics](0x130A)"},
{0x1002, 0x130B, 0xFFFF, 0xFFFF, "Kaveri [Radeon R4 Graphics](0x130B)"},
{0x1002, 0x130C, 0xFFFF, 0xFFFF, "Kaveri [Radeon R7 Graphics](0x130C)"},
{0x1002, 0x130D, 0xFFFF, 0xFFFF, "Kaveri [Radeon R6 Graphics](0x130D)"},
{0x1002, 0x130E, 0xFFFF, 0xFFFF, "Kaveri [Radeon R5 Graphics](0x130E)"},
{0x1002, 0x130F, 0xFFFF, 0xFFFF, "Kaveri [Radeon R7 Graphics](0x130F)"},
{0x1002, 0x1310, 0xFFFF, 0xFFFF, "Kaveri(0x1310)"},
{0x1002, 0x1311, 0xFFFF, 0xFFFF, "Kaveri(0x1311)"},
{0x1002, 0x1312, 0xFFFF, 0xFFFF, "Kaveri(0x1312)"},
{0x1002, 0x1313, 0xFFFF, 0xFFFF, "Kaveri [Radeon R7 Graphics](0x1313)"},
{0x1002, 0x1314, 0xFFFF, 0xFFFF, "Wrestler HDMI Audio(0x1314)"},
{0x1002, 0x1314, 0x174B, 0x1001, "PURE Fusion Mini(0x174B-0x1001)"},
{0x1002, 0x1315, 0xFFFF, 0xFFFF, "Kaveri [Radeon R5 Graphics](0x1315)"},
{0x1002, 0x1316, 0xFFFF, 0xFFFF, "Kaveri [Radeon R5 Graphics](0x1316)"},
{0x1002, 0x1317, 0xFFFF, 0xFFFF, "Kaveri(0x1317)"},
{0x1002, 0x1318, 0xFFFF, 0xFFFF, "Kaveri [Radeon R5 Graphics](0x1318)"},
{0x1002, 0x131B, 0xFFFF, 0xFFFF, "Kaveri [Radeon R4 Graphics](0x131B)"},
{0x1002, 0x131C, 0xFFFF, 0xFFFF, "Kaveri [Radeon R7 Graphics](0x131C)"},
{0x1002, 0x131D, 0xFFFF, 0xFFFF, "Kaveri [Radeon R6 Graphics](0x131D)"},
{0x1002, 0x13E9, 0xFFFF, 0xFFFF, "Ariel/Navi10Lite(0x13E9)"},
{0x1002, 0x13F9, 0xFFFF, 0xFFFF, "Oberon/Navi12Lite(0x13F9)"},
{0x1002, 0x13FE, 0xFFFF, 0xFFFF, "Cyan Skillfish [BC-250](0x13FE)"},
{0x1002, 0x1435, 0xFFFF, 0xFFFF, "Sephiroth [AMD Custom GPU 0405](0x1435)"},
{0x1002, 0x145A, 0xFFFF, 0xFFFF, "Dummy Function (absent graphics controller)(0x145A)"},
{0x1002, 0x1478, 0xFFFF, 0xFFFF, "Navi 10 XL Upstream Port of PCI Express Switch(0x1478)"},
{0x1002, 0x1479, 0xFFFF, 0xFFFF, "Navi 10 XL Downstream Port of PCI Express Switch(0x1479)"},
{0x1002, 0x1506, 0xFFFF, 0xFFFF, "Mendocino(0x1506)"},
{0x1002, 0x154C, 0xFFFF, 0xFFFF, "Kryptos [Radeon RX 350](0x154C)"},
{0x1002, 0x154C, 0x1462, 0x7C28, "MS-7C28 Motherboard(0x1462-0x7C28)"},
{0x1002, 0x154E, 0xFFFF, 0xFFFF, "Garfield(0x154E)"},
{0x1002, 0x1551, 0xFFFF, 0xFFFF, "Arlene(0x1551)"},
{0x1002, 0x1552, 0xFFFF, 0xFFFF, "Pooky(0x1552)"},
{0x1002, 0x1561, 0xFFFF, 0xFFFF, "Anubis(0x1561)"},
{0x1002, 0x15BF, 0xFFFF, 0xFFFF, "Phoenix1(0x15BF)"},
{0x1002, 0x15C8, 0xFFFF, 0xFFFF, "Phoenix2(0x15C8)"},
{0x1002, 0x15D8, 0xFFFF, 0xFFFF, "Picasso/Raven 2 [Radeon Vega Series / Radeon Vega Mobile Series](0x15D8)"},
{0x1002, 0x15D8, 0x103C, 0x8615, "Pavilion Laptop 15-cw1xxx(0x103C-0x8615)"},
{0x1002, 0x15D8, 0x17AA, 0x3181, "ThinkCentre M75n IoT(0x17AA-0x3181)"},
{0x1002, 0x15D8, 0x17AA, 0x5124, "ThinkPad E595(0x17AA-0x5124)"},
{0x1002, 0x15D8, 0x1DC2, 0x2209, "Avita Pura 14 Notebook(0x1DC2-0x2209)"},
{0x1002, 0x15D8, 0xEA50, 0xCC10, "RXi2-BP(0xEA50-0xCC10)"},
{0x1002, 0x15DD, 0xFFFF, 0xFFFF, "Raven Ridge [Radeon Vega Series / Radeon Vega Mobile Series](0x15DD)"},
{0x1002, 0x15DD, 0x103C, 0x83C6, "Radeon Vega 8 Mobile(0x103C-0x83C6)"},
{0x1002, 0x15DD, 0x1043, 0x876B, "PRIME Motherboard(0x1043-0x876B)"},
{0x1002, 0x15DD, 0x1458, 0xD000, "Radeon RX Vega 11(0x1458-0xD000)"},
{0x1002, 0x15DD, 0xEA50, 0xCC10, "RXi2-BP(0xEA50-0xCC10)"},
{0x1002, 0x15DE, 0xFFFF, 0xFFFF, "Raven/Raven2/Fenghuang HDMI/DP Audio Controller(0x15DE)"},
{0x1002, 0x15DE, 0x103C, 0x8615, "Pavilion Laptop 15-cw1xxx(0x103C-0x8615)"},
{0x1002, 0x15DE, 0x1043, 0x876B, "PRIME B450M-A Motherboard(0x1043-0x876B)"},
{0x1002, 0x15DE, 0x17AA, 0x5124, "ThinkPad E595(0x17AA-0x5124)"},
{0x1002, 0x15DE, 0xEA50, 0xCC10, "RXi2-BP(0xEA50-0xCC10)"},
{0x1002, 0x15DF, 0xFFFF, 0xFFFF, "Raven/Raven2/Fenghuang/Renoir Cryptographic Coprocessor(0x15DF)"},
{0x1002, 0x15DF, 0x103C, 0x8615, "Pavilion Laptop 15-cw1xxx(0x103C-0x8615)"},
{0x1002, 0x15DF, 0xEA50, 0xCE19, "mCOM10-L1900(0xEA50-0xCE19)"},
{0x1002, 0x15E7, 0xFFFF, 0xFFFF, "Barcelo(0x15E7)"},
{0x1002, 0x15E7, 0x103C, 0x8B17, "ProBook 445 G9/455 G9 [Ryzen 7 Integrated Radeon GPU](0x103C-0x8B17)"},
{0x1002, 0x15FF, 0xFFFF, 0xFFFF, "Fenghuang [Zhongshan Subor Z+](0x15FF)"},
{0x1002, 0x1607, 0xFFFF, 0xFFFF, "Arden(0x1607)"},
{0x1002, 0x1636, 0xFFFF, 0xFFFF, "Renoir [Radeon Vega Series / Radeon Vega Mobile Series](0x1636)"},
{0x1002, 0x1637, 0xFFFF, 0xFFFF, "Renoir Radeon High Definition Audio Controller(0x1637)"},
{0x1002, 0x1638, 0xFFFF, 0xFFFF, "Cezanne [Radeon Vega Series / Radeon Vega Mobile Series](0x1638)"},
{0x1002, 0x1638, 0x1043, 0x16C2, "Radeon Vega 8(0x1043-0x16C2)"},
{0x1002, 0x163F, 0xFFFF, 0xFFFF, "VanGogh [AMD Custom GPU 0405](0x163F)"},
{0x1002, 0x1640, 0xFFFF, 0xFFFF, "Rembrandt Radeon High Definition Audio Controller(0x1640)"},
{0x1002, 0x164C, 0xFFFF, 0xFFFF, "Lucienne(0x164C)"},
{0x1002, 0x164D, 0xFFFF, 0xFFFF, "Rembrandt(0x164D)"},
{0x1002, 0x164E, 0xFFFF, 0xFFFF, "Raphael(0x164E)"},
{0x1002, 0x164F, 0xFFFF, 0xFFFF, "Phoenix(0x164F)"},
{0x1002, 0x1681, 0xFFFF, 0xFFFF, "Rembrandt [Radeon 680M](0x1681)"},
{0x1002, 0x1714, 0xFFFF, 0xFFFF, "BeaverCreek HDMI Audio [Radeon HD 6500D and 6400G-6600G series](0x1714)"},
{0x1002, 0x1714, 0x103C, 0x168B, "ProBook 4535s(0x103C-0x168B)"},
{0x1002, 0x1900, 0xFFFF, 0xFFFF, "Phoenix3(0x1900)"},
{0x1002, 0x1901, 0xFFFF, 0xFFFF, "Phoenix4(0x1901)"},
{0x1002, 0x3150, 0xFFFF, 0xFFFF, "RV380/M24 [Mobility Radeon X600](0x3150)"},
{0x1002, 0x3150, 0x103C, 0x0934, "nx8220(0x103C-0x0934)"},
{0x1002, 0x3151, 0xFFFF, 0xFFFF, "RV380 GL [FireMV 2400](0x3151)"},
{0x1002, 0x3152, 0xFFFF, 0xFFFF, "RV370/M22 [Mobility Radeon X300](0x3152)"},
{0x1002, 0x3154, 0xFFFF, 0xFFFF, "RV380/M24 GL [Mobility FireGL V3200](0x3154)"},
{0x1002, 0x3155, 0xFFFF, 0xFFFF, "RV380 GL [FireMV 2400](0x3155)"},
{0x1002, 0x3171, 0xFFFF, 0xFFFF, "RV380 GL [FireMV 2400] (Secondary)(0x3171)"},
{0x1002, 0x3E50, 0xFFFF, 0xFFFF, "RV380 [Radeon X550/X600](0x3E50)"},
{0x1002, 0x3E54, 0xFFFF, 0xFFFF, "RV380 GL [FireGL V3200](0x3E54)"},
{0x1002, 0x3E70, 0xFFFF, 0xFFFF, "RV380 [Radeon X550/X600] (Secondary)(0x3E70)"},
{0x1002, 0x4136, 0xFFFF, 0xFFFF, "RS100 [Mobility IGP 320M](0x4136)"},
{0x1002, 0x4137, 0xFFFF, 0xFFFF, "RS200 [Radeon IGP 340](0x4137)"},
{0x1002, 0x4144, 0xFFFF, 0xFFFF, "R300 [Radeon 9500](0x4144)"},
{0x1002, 0x4146, 0xFFFF, 0xFFFF, "R300 [Radeon 9700 PRO](0x4146)"},
{0x1002, 0x4147, 0xFFFF, 0xFFFF, "R300 GL [FireGL Z1](0x4147)"},
{0x1002, 0x4148, 0xFFFF, 0xFFFF, "R350 [Radeon 9800/9800 SE](0x4148)"},
{0x1002, 0x4150, 0xFFFF, 0xFFFF, "RV350 [Radeon 9550/9600/X1050 Series](0x4150)"},
{0x1002, 0x4150, 0x1002, 0x0002, "R9600 Pro primary (Asus OEM for HP)(0x1002-0x0002)"},
{0x1002, 0x4150, 0x1002, 0x0003, "R9600 Pro secondary (Asus OEM for HP)(0x1002-0x0003)"},
{0x1002, 0x4150, 0x1002, 0x4722, "All-in-Wonder 2006 AGP Edition(0x1002-0x4722)"},
{0x1002, 0x4150, 0x1458, 0x4024, "GV-R96128D(0x1458-0x4024)"},
{0x1002, 0x4150, 0x148C, 0x2064, "R96A-C3N(0x148C-0x2064)"},
{0x1002, 0x4150, 0x148C, 0x2066, "R96A-C3N(0x148C-0x2066)"},
{0x1002, 0x4150, 0x174B, 0x7C19, "Atlantis Radeon 9600 Pro(0x174B-0x7C19)"},
{0x1002, 0x4150, 0x174B, 0x7C29, "GC-R9600PRO(0x174B-0x7C29)"},
{0x1002, 0x4150, 0x17EE, 0x2002, "Radeon 9600 256Mb Primary(0x17EE-0x2002)"},
{0x1002, 0x4150, 0x18BC, 0x0101, "GC-R9600PRO (Primary)(0x18BC-0x0101)"},
{0x1002, 0x4151, 0xFFFF, 0xFFFF, "RV350 [Radeon 9600 Series](0x4151)"},
{0x1002, 0x4151, 0x1043, 0xC004, "A9600SE(0x1043-0xC004)"},
{0x1002, 0x4151, 0x174B, 0x7C37, "Radeon 9600SE 128M DDR V/D/VO(0x174B-0x7C37)"},
{0x1002, 0x4152, 0xFFFF, 0xFFFF, "RV360 [Radeon 9600/X1050 Series](0x4152)"},
{0x1002, 0x4152, 0x1002, 0x0002, "Radeon 9600XT(0x1002-0x0002)"},
{0x1002, 0x4152, 0x1002, 0x4772, "All-in-Wonder 9600 XT(0x1002-0x4772)"},
{0x1002, 0x4152, 0x1043, 0xC002, "Radeon 9600 XT TVD(0x1043-0xC002)"},
{0x1002, 0x4152, 0x1043, 0xC01A, "A9600XT/TD(0x1043-0xC01A)"},
{0x1002, 0x4152, 0x1462, 0x9510, "RX9600XT (MS-8951)(0x1462-0x9510)"},
{0x1002, 0x4152, 0x174B, 0x7C29, "Radeon 9600XT(0x174B-0x7C29)"},
{0x1002, 0x4152, 0x1787, 0x4002, "Radeon 9600 XT(0x1787-0x4002)"},
{0x1002, 0x4153, 0xFFFF, 0xFFFF, "RV350 [Radeon 9550](0x4153)"},
{0x1002, 0x4153, 0x1043, 0x010C, "A9550GE/TD(0x1043-0x010C)"},
{0x1002, 0x4153, 0x1462, 0x932C, "RX9550SE-TD128 (MS-8932)(0x1462-0x932C)"},
{0x1002, 0x4154, 0xFFFF, 0xFFFF, "RV350 GL [FireGL T2](0x4154)"},
{0x1002, 0x4155, 0xFFFF, 0xFFFF, "RV350 [Radeon 9600](0x4155)"},
{0x1002, 0x4157, 0xFFFF, 0xFFFF, "RV350 GL [FireGL T2](0x4157)"},
{0x1002, 0x4158, 0xFFFF, 0xFFFF, "68800AX [Graphics Ultra Pro PCI](0x4158)"},
{0x1002, 0x4164, 0xFFFF, 0xFFFF, "R300 [Radeon 9500 PRO] (Secondary)(0x4164)"},
{0x1002, 0x4165, 0xFFFF, 0xFFFF, "R300 [Radeon 9700 PRO] (Secondary)(0x4165)"},
{0x1002, 0x4166, 0xFFFF, 0xFFFF, "R300 [Radeon 9700 PRO] (Secondary)(0x4166)"},
{0x1002, 0x4168, 0xFFFF, 0xFFFF, "RV350 [Radeon 9800 SE] (Secondary)(0x4168)"},
{0x1002, 0x4170, 0xFFFF, 0xFFFF, "RV350 [Radeon 9550/9600/X1050 Series] (Secondary)(0x4170)"},
{0x1002, 0x4170, 0x1002, 0x0003, "R9600 Pro secondary (Asus OEM for HP)(0x1002-0x0003)"},
{0x1002, 0x4170, 0x1002, 0x4723, "All-in-Wonder 2006 AGP Edition (Secondary)(0x1002-0x4723)"},
{0x1002, 0x4170, 0x1458, 0x4025, "GV-R96128D (Secondary)(0x1458-0x4025)"},
{0x1002, 0x4170, 0x148C, 0x2067, "R96A-C3N (Secondary)(0x148C-0x2067)"},
{0x1002, 0x4170, 0x174B, 0x7C28, "GC-R9600PRO (Secondary)(0x174B-0x7C28)"},
{0x1002, 0x4170, 0x17EE, 0x2003, "Radeon 9600 256Mb (Secondary)(0x17EE-0x2003)"},
{0x1002, 0x4170, 0x18BC, 0x0100, "GC-R9600PRO (Secondary)(0x18BC-0x0100)"},
{0x1002, 0x4171, 0xFFFF, 0xFFFF, "RV350 [Radeon 9600] (Secondary)(0x4171)"},
{0x1002, 0x4171, 0x1043, 0xC005, "A9600SE (Secondary)(0x1043-0xC005)"},
{0x1002, 0x4171, 0x174B, 0x7C36, "Radeon 9600SE 128M DDR V/D/VO (secondary)(0x174B-0x7C36)"},
{0x1002, 0x4172, 0xFFFF, 0xFFFF, "RV350 [Radeon 9600/X1050 Series] (Secondary)(0x4172)"},
{0x1002, 0x4172, 0x1002, 0x0003, "Radeon 9600XT (Secondary)(0x1002-0x0003)"},
{0x1002, 0x4172, 0x1002, 0x4773, "All-in-Wonder 9600 XT (Secondary)(0x1002-0x4773)"},
{0x1002, 0x4172, 0x1043, 0xC003, "A9600XT (Secondary)(0x1043-0xC003)"},
{0x1002, 0x4172, 0x1043, 0xC01B, "A9600XT/TD (Secondary)(0x1043-0xC01B)"},
{0x1002, 0x4172, 0x174B, 0x7C28, "Radeon 9600XT (Secondary)(0x174B-0x7C28)"},
{0x1002, 0x4172, 0x1787, 0x4003, "Radeon 9600 XT (Secondary)(0x1787-0x4003)"},
{0x1002, 0x4173, 0xFFFF, 0xFFFF, "RV350 [Radeon 9550] (Secondary)(0x4173)"},
{0x1002, 0x4173, 0x1043, 0x010D, "A9550GE/TD (Secondary)(0x1043-0x010D)"},
{0x1002, 0x4242, 0xFFFF, 0xFFFF, "R200 [All-In-Wonder Radeon 8500 DV](0x4242)"},
{0x1002, 0x4242, 0x1002, 0x02AA, "Radeon 8500 AIW DV Edition(0x1002-0x02AA)"},
{0x1002, 0x4243, 0xFFFF, 0xFFFF, "R200 PCI Bridge [All-in-Wonder Radeon 8500DV](0x4243)"},
{0x1002, 0x4336, 0xFFFF, 0xFFFF, "RS100 [Radeon IGP 320M](0x4336)"},
{0x1002, 0x4336, 0x1002, 0x4336, "Pavilion ze4300 ATI Radeon Mobility U1 (IGP 320 M)(0x1002-0x4336)"},
{0x1002, 0x4336, 0x103C, 0x0024, "Pavilion ze4400 builtin Video(0x103C-0x0024)"},
{0x1002, 0x4336, 0x161F, 0x2029, "eMachines M5312 builtin Video(0x161F-0x2029)"},
{0x1002, 0x4337, 0xFFFF, 0xFFFF, "RS200M [Radeon IGP 330M/340M/345M/350M](0x4337)"},
{0x1002, 0x4337, 0x1014, 0x053A, "ThinkPad R40e(0x1014-0x053A)"},
{0x1002, 0x4337, 0x103C, 0x0850, "Radeon IGP 345M(0x103C-0x0850)"},
{0x1002, 0x4341, 0xFFFF, 0xFFFF, "SB200 AC97 Audio Controller(0x4341)"},
{0x1002, 0x4342, 0xFFFF, 0xFFFF, "SB200 PCI to PCI Bridge(0x4342)"},
{0x1002, 0x4345, 0xFFFF, 0xFFFF, "SB200 EHCI USB Controller(0x4345)"},
{0x1002, 0x4346, 0xFFFF, 0xFFFF, "Crayola 6 [XENOS Parent Die (XBOX 360)](0x4346)"},
{0x1002, 0x4347, 0xFFFF, 0xFFFF, "SB200 OHCI USB Controller #1(0x4347)"},
{0x1002, 0x4348, 0xFFFF, 0xFFFF, "SB200 OHCI USB Controller #2(0x4348)"},
{0x1002, 0x4349, 0xFFFF, 0xFFFF, "SB200 IDE Controller(0x4349)"},
{0x1002, 0x434C, 0xFFFF, 0xFFFF, "SB200 PCI to LPC Bridge(0x434C)"},
{0x1002, 0x434D, 0xFFFF, 0xFFFF, "SB200 AC97 Modem Controller(0x434D)"},
{0x1002, 0x4353, 0xFFFF, 0xFFFF, "SB200 SMBus Controller(0x4353)"},
{0x1002, 0x4354, 0xFFFF, 0xFFFF, "215CT [Mach64 CT PCI](0x4354)"},
{0x1002, 0x4358, 0xFFFF, 0xFFFF, "Mach64 CX [Graphics Xpression](0x4358)"},
{0x1002, 0x4361, 0xFFFF, 0xFFFF, "SB300 AC'97 Audio Controller(0x4361)"},
{0x1002, 0x4362, 0xFFFF, 0xFFFF, "SB300 PCI to PCI Bridge(0x4362)"},
{0x1002, 0x4363, 0xFFFF, 0xFFFF, "SB300 SMBus Controller(0x4363)"},
{0x1002, 0x4365, 0xFFFF, 0xFFFF, "SB300 USB Controller (EHCI)(0x4365)"},
{0x1002, 0x4367, 0xFFFF, 0xFFFF, "SB300 USB Controller (EHCI)(0x4367)"},
{0x1002, 0x4368, 0xFFFF, 0xFFFF, "SB300 USB Controller (EHCI)(0x4368)"},
{0x1002, 0x4369, 0xFFFF, 0xFFFF, "SB300 IDE Controller(0x4369)"},
{0x1002, 0x436C, 0xFFFF, 0xFFFF, "SB300 PCI to LPC Bridge(0x436C)"},
{0x1002, 0x436D, 0xFFFF, 0xFFFF, "SB300 AC97 Modem Controller(0x436D)"},
{0x1002, 0x436E, 0xFFFF, 0xFFFF, "SB300 Serial ATA Controller(0x436E)"},
{0x1002, 0x4370, 0xFFFF, 0xFFFF, "IXP SB400 AC'97 Audio Controller(0x4370)"},
{0x1002, 0x4370, 0x1025, 0x0079, "Aspire 5024WLMMi(0x1025-0x0079)"},
{0x1002, 0x4370, 0x1025, 0x0091, "Aspire 5032WXMi(0x1025-0x0091)"},
{0x1002, 0x4370, 0x103C, 0x2A05, "Pavilion t3030.de Desktop PC(0x103C-0x2A05)"},
{0x1002, 0x4370, 0x103C, 0x308B, "MX6125(0x103C-0x308B)"},
{0x1002, 0x4370, 0x105B, 0x0C81, "Realtek ALC 653(0x105B-0x0C81)"},
{0x1002, 0x4370, 0x107B, 0x0300, "MX6421(0x107B-0x0300)"},
{0x1002, 0x4370, 0x1462, 0x0131, "MS-1013 Notebook(0x1462-0x0131)"},
{0x1002, 0x4371, 0xFFFF, 0xFFFF, "IXP SB4x0 PCI-PCI Bridge(0x4371)"},
{0x1002, 0x4371, 0x103C, 0x308B, "MX6125(0x103C-0x308B)"},
{0x1002, 0x4371, 0x1462, 0x7217, "Aspire L250(0x1462-0x7217)"},
{0x1002, 0x4372, 0xFFFF, 0xFFFF, "IXP SB4x0 SMBus Controller(0x4372)"},
{0x1002, 0x4372, 0x1025, 0x0080, "Aspire 5024WLMMi(0x1025-0x0080)"},
{0x1002, 0x4372, 0x103C, 0x2A20, "Pavilion t3030.de Desktop PC(0x103C-0x2A20)"},
{0x1002, 0x4372, 0x103C, 0x308B, "MX6125(0x103C-0x308B)"},
{0x1002, 0x4372, 0x1462, 0x0131, "MS-1013 Notebook(0x1462-0x0131)"},
{0x1002, 0x4372, 0x1462, 0x7217, "Aspire L250(0x1462-0x7217)"},
{0x1002, 0x4373, 0xFFFF, 0xFFFF, "IXP SB4x0 USB2 Host Controller(0x4373)"},
{0x1002, 0x4373, 0x1025, 0x0080, "Aspire 5024WLMMi(0x1025-0x0080)"},
{0x1002, 0x4373, 0x103C, 0x2A20, "Pavilion t3030.de Desktop PC(0x103C-0x2A20)"},
{0x1002, 0x4373, 0x103C, 0x308B, "MX6125(0x103C-0x308B)"},
{0x1002, 0x4373, 0x1462, 0x7217, "Aspire L250(0x1462-0x7217)"},
{0x1002, 0x4374, 0xFFFF, 0xFFFF, "IXP SB4x0 USB Host Controller(0x4374)"},
{0x1002, 0x4374, 0x103C, 0x2A20, "Pavilion t3030.de Desktop PC(0x103C-0x2A20)"},
{0x1002, 0x4374, 0x103C, 0x308B, "MX6125(0x103C-0x308B)"},
{0x1002, 0x4374, 0x1462, 0x7217, "Aspire L250(0x1462-0x7217)"},
{0x1002, 0x4375, 0xFFFF, 0xFFFF, "IXP SB4x0 USB Host Controller(0x4375)"},
{0x1002, 0x4375, 0x1025, 0x0080, "Aspire 5024WLMMi(0x1025-0x0080)"},
{0x1002, 0x4375, 0x103C, 0x2A20, "Pavilion t3030.de Desktop PC(0x103C-0x2A20)"},
{0x1002, 0x4375, 0x103C, 0x308B, "MX6125(0x103C-0x308B)"},
{0x1002, 0x4375, 0x1462, 0x7217, "Aspire L250(0x1462-0x7217)"},
{0x1002, 0x4376, 0xFFFF, 0xFFFF, "IXP SB4x0 IDE Controller(0x4376)"},
{0x1002, 0x4376, 0x1025, 0x0080, "Aspire 5024WLMMi(0x1025-0x0080)"},
{0x1002, 0x4376, 0x103C, 0x2A20, "Pavilion t3030.de Desktop PC(0x103C-0x2A20)"},
{0x1002, 0x4376, 0x103C, 0x308B, "MX6125(0x103C-0x308B)"},
{0x1002, 0x4376, 0x1462, 0x0131, "MS-1013 Notebook(0x1462-0x0131)"},
{0x1002, 0x4376, 0x1462, 0x7217, "Aspire L250(0x1462-0x7217)"},
{0x1002, 0x4377, 0xFFFF, 0xFFFF, "IXP SB4x0 PCI-ISA Bridge(0x4377)"},
{0x1002, 0x4377, 0x1025, 0x0080, "Aspire 5024WLMi(0x1025-0x0080)"},
{0x1002, 0x4377, 0x103C, 0x2A20, "Pavilion t3030.de Desktop PC(0x103C-0x2A20)"},
{0x1002, 0x4377, 0x103C, 0x308B, "MX6125(0x103C-0x308B)"},
{0x1002, 0x4377, 0x1462, 0x7217, "Aspire L250(0x1462-0x7217)"},
{0x1002, 0x4378, 0xFFFF, 0xFFFF, "IXP SB400 AC'97 Modem Controller(0x4378)"},
{0x1002, 0x4378, 0x1025, 0x0080, "Aspire 5024WLMMi(0x1025-0x0080)"},
{0x1002, 0x4378, 0x103C, 0x308B, "MX6125(0x103C-0x308B)"},
{0x1002, 0x4378, 0x1462, 0x0131, "MS-1013 Notebook(0x1462-0x0131)"},
{0x1002, 0x4379, 0xFFFF, 0xFFFF, "IXP SB4x0 Serial ATA Controller(0x4379)"},
{0x1002, 0x4379, 0x1462, 0x7141, "Aspire L250(0x1462-0x7141)"},
{0x1002, 0x437A, 0xFFFF, 0xFFFF, "IXP SB400 Serial ATA Controller(0x437A)"},
{0x1002, 0x437A, 0x1002, 0x4379, "4379 Serial ATA Controller(0x1002-0x4379)"},
{0x1002, 0x437A, 0x1002, 0x437A, "437A Serial ATA Controller(0x1002-0x437A)"},
{0x1002, 0x437A, 0x1462, 0x7141, "Aspire L250(0x1462-0x7141)"},
{0x1002, 0x437A, 0x14F1, 0x8800, "Leadtek WinFast TV2000XP Expert(0x14F1-0x8800)"},
{0x1002, 0x437B, 0xFFFF, 0xFFFF, "IXP SB4x0 High Definition Audio Controller(0x437B)"},
{0x1002, 0x437B, 0x1002, 0x437B, "IXP SB4x0 High Definition Audio Controller(0x1002-0x437B)"},
{0x1002, 0x437B, 0x10CF, 0x1326, "Fujitsu Lifebook A3040(0x10CF-0x1326)"},
{0x1002, 0x437B, 0x1734, 0x10B8, "Realtek High Definition Audio(0x1734-0x10B8)"},
{0x1002, 0x4380, 0xFFFF, 0xFFFF, "SB600 Non-Raid-5 SATA(0x4380)"},
{0x1002, 0x4380, 0x103C, 0x2813, "DC5750 Microtower(0x103C-0x2813)"},
{0x1002, 0x4380, 0x1179, 0xFF50, "Satellite P305D-S8995E(0x1179-0xFF50)"},
{0x1002, 0x4380, 0x1458, 0xB003, "GA-MA790FX-DS5 (rev. 1.0)(0x1458-0xB003)"},
{0x1002, 0x4380, 0x1458, 0xB005, "Gigabyte GA-MA69G-S3H Motherboard(0x1458-0xB005)"},
{0x1002, 0x4380, 0x1462, 0x7327, "K9AG Neo2(0x1462-0x7327)"},
{0x1002, 0x4380, 0x17F2, 0x5999, "KI690-AM2 Motherboard(0x17F2-0x5999)"},
{0x1002, 0x4381, 0xFFFF, 0xFFFF, "SB600 SATA Controller (RAID 5 mode)(0x4381)"},
{0x1002, 0x4382, 0xFFFF, 0xFFFF, "SB600 AC97 Audio(0x4382)"},
{0x1002, 0x4383, 0xFFFF, 0xFFFF, "SBx00 Azalia (Intel HDA)(0x4383)"},
{0x1002, 0x4383, 0x1019, 0x2120, "A785GM-M(0x1019-0x2120)"},
{0x1002, 0x4383, 0x103C, 0x1611, "Pavilion dm1z-3000(0x103C-0x1611)"},
{0x1002, 0x4383, 0x103C, 0x280A, "DC5750 Microtower(0x103C-0x280A)"},
{0x1002, 0x4383, 0x1043, 0x8230, "M3A78-EH Motherboard(0x1043-0x8230)"},
{0x1002, 0x4383, 0x1043, 0x836C, "M4A785TD Motherboard(0x1043-0x836C)"},
{0x1002, 0x4383, 0x1043, 0x8410, "M4A89GTD PRO/USB3 Motherboard(0x1043-0x8410)"},
{0x1002, 0x4383, 0x1043, 0x841B, "M5A88-V EVO(0x1043-0x841B)"},
{0x1002, 0x4383, 0x1043, 0x8445, "M5A78L LE(0x1043-0x8445)"},
{0x1002, 0x4383, 0x105B, 0x0E13, "N15235/A74MX mainboard / AMD SB700(0x105B-0x0E13)"},
{0x1002, 0x4383, 0x1179, 0xFF1E, "Satellite C660D-113(0x1179-0xFF1E)"},
{0x1002, 0x4383, 0x1179, 0xFF50, "Satellite P305D-S8995E(0x1179-0xFF50)"},
{0x1002, 0x4383, 0x1458, 0xA022, "GA-770/78-series motherboard(0x1458-0xA022)"},
{0x1002, 0x4383, 0x1458, 0xA102, "GA-880GMA-USB3(0x1458-0xA102)"},
{0x1002, 0x4383, 0x1462, 0x7596, "760GM-E51(MS-7596) Motherboard(0x1462-0x7596)"},
{0x1002, 0x4383, 0x17F2, 0x5000, "KI690-AM2 Motherboard(0x17F2-0x5000)"},
{0x1002, 0x4384, 0xFFFF, 0xFFFF, "SBx00 PCI to PCI Bridge(0x4384)"},
{0x1002, 0x4385, 0xFFFF, 0xFFFF, "SBx00 SMBus Controller(0x4385)"},
{0x1002, 0x4385, 0x1019, 0x2120, "A785GM-M(0x1019-0x2120)"},
{0x1002, 0x4385, 0x103C, 0x1611, "Pavilion DM1Z-3000(0x103C-0x1611)"},
{0x1002, 0x4385, 0x103C, 0x280A, "DC5750 Microtower(0x103C-0x280A)"},
{0x1002, 0x4385, 0x1043, 0x82EF, "M3A78-EH Motherboard(0x1043-0x82EF)"},
{0x1002, 0x4385, 0x1043, 0x8389, "M4A785TD Motherboard(0x1043-0x8389)"},
{0x1002, 0x4385, 0x105B, 0x0E13, "N15235/A74MX mainboard / AMD SB700(0x105B-0x0E13)"},
{0x1002, 0x4385, 0x1179, 0xFF50, "Satellite P305D-S8995E(0x1179-0xFF50)"},
{0x1002, 0x4385, 0x1458, 0x4385, "GA-770/78-series motherboard(0x1458-0x4385)"},
{0x1002, 0x4385, 0x1462, 0x7368, "K9AG Neo2(0x1462-0x7368)"},
{0x1002, 0x4385, 0x1462, 0x7596, "760GM-E51(MS-7596) Motherboard(0x1462-0x7596)"},
{0x1002, 0x4385, 0x15D9, 0xA811, "H8DGU(0x15D9-0xA811)"},
{0x1002, 0x4385, 0x174B, 0x1001, "PURE Fusion Mini(0x174B-0x1001)"},
{0x1002, 0x4385, 0x17F2, 0x5000, "KI690-AM2 Motherboard(0x17F2-0x5000)"},
{0x1002, 0x4386, 0xFFFF, 0xFFFF, "SB600 USB Controller (EHCI)(0x4386)"},
{0x1002, 0x4386, 0x103C, 0x280A, "DC5750 Microtower(0x103C-0x280A)"},
{0x1002, 0x4386, 0x1179, 0xFF50, "Satellite P305D-S8995E(0x1179-0xFF50)"},
{0x1002, 0x4386, 0x1462, 0x7368, "K9AG Neo2(0x1462-0x7368)"},
{0x1002, 0x4386, 0x17F2, 0x5000, "KI690-AM2 Motherboard(0x17F2-0x5000)"},
{0x1002, 0x4387, 0xFFFF, 0xFFFF, "SB600 USB (OHCI0)(0x4387)"},
{0x1002, 0x4387, 0x103C, 0x280A, "DC5750 Microtower(0x103C-0x280A)"},
{0x1002, 0x4387, 0x1179, 0xFF50, "Satellite P305D-S8995E(0x1179-0xFF50)"},
{0x1002, 0x4387, 0x1462, 0x7368, "K9AG Neo2(0x1462-0x7368)"},
{0x1002, 0x4387, 0x17F2, 0x5000, "KI690-AM2 Motherboard(0x17F2-0x5000)"},
{0x1002, 0x4388, 0xFFFF, 0xFFFF, "SB600 USB (OHCI1)(0x4388)"},
{0x1002, 0x4388, 0x103C, 0x280A, "DC5750 Microtower(0x103C-0x280A)"},
{0x1002, 0x4388, 0x1179, 0xFF50, "Satellite P305D-S8995E(0x1179-0xFF50)"},
{0x1002, 0x4388, 0x1462, 0x7368, "K9AG Neo2(0x1462-0x7368)"},
{0x1002, 0x4388, 0x17F2, 0x5000, "KI690-AM2 Motherboard(0x17F2-0x5000)"},
{0x1002, 0x4389, 0xFFFF, 0xFFFF, "SB600 USB (OHCI2)(0x4389)"},
{0x1002, 0x4389, 0x103C, 0x280A, "DC5750 Microtower(0x103C-0x280A)"},
{0x1002, 0x4389, 0x1179, 0xFF50, "Satellite P305D-S8995E(0x1179-0xFF50)"},
{0x1002, 0x4389, 0x1462, 0x7368, "K9AG Neo2(0x1462-0x7368)"},
{0x1002, 0x4389, 0x17F2, 0x5000, "KI690-AM2 Motherboard(0x17F2-0x5000)"},
{0x1002, 0x438A, 0xFFFF, 0xFFFF, "SB600 USB (OHCI3)(0x438A)"},
{0x1002, 0x438A, 0x103C, 0x280A, "DC5750 Microtower(0x103C-0x280A)"},
{0x1002, 0x438A, 0x1179, 0xFF50, "Satellite P305D-S8995E(0x1179-0xFF50)"},
{0x1002, 0x438A, 0x1462, 0x7368, "K9AG Neo2(0x1462-0x7368)"},
{0x1002, 0x438A, 0x17F2, 0x5000, "KI690-AM2 Motherboard(0x17F2-0x5000)"},
{0x1002, 0x438B, 0xFFFF, 0xFFFF, "SB600 USB (OHCI4)(0x438B)"},
{0x1002, 0x438B, 0x103C, 0x280A, "DC5750 Microtower(0x103C-0x280A)"},
{0x1002, 0x438B, 0x1179, 0xFF50, "Satellite P305D-S8995E(0x1179-0xFF50)"},
{0x1002, 0x438B, 0x1462, 0x7368, "K9AG Neo2(0x1462-0x7368)"},
{0x1002, 0x438B, 0x17F2, 0x5000, "KI690-AM2 Motherboard(0x17F2-0x5000)"},
{0x1002, 0x438C, 0xFFFF, 0xFFFF, "SB600 IDE(0x438C)"},
{0x1002, 0x438C, 0x103C, 0x280A, "DC5750 Microtower(0x103C-0x280A)"},
{0x1002, 0x438C, 0x1179, 0xFF50, "Satellite P305D-S8995E(0x1179-0xFF50)"},
{0x1002, 0x438C, 0x1458, 0x5002, "Gigabyte GA-MA69G-S3H Motherboard(0x1458-0x5002)"},
{0x1002, 0x438C, 0x1462, 0x7368, "K9AG Neo2(0x1462-0x7368)"},
{0x1002, 0x438C, 0x17F2, 0x5000, "KI690-AM2 Motherboard(0x17F2-0x5000)"},
{0x1002, 0x438D, 0xFFFF, 0xFFFF, "SB600 PCI to LPC Bridge(0x438D)"},
{0x1002, 0x438D, 0x103C, 0x280A, "DC5750 Microtower(0x103C-0x280A)"},
{0x1002, 0x438D, 0x1179, 0xFF50, "Satellite P305D-S8995E(0x1179-0xFF50)"},
{0x1002, 0x438D, 0x1462, 0x7368, "K9AG Neo2(0x1462-0x7368)"},
{0x1002, 0x438D, 0x17F2, 0x5000, "KI690-AM2 Motherboard(0x17F2-0x5000)"},
{0x1002, 0x438E, 0xFFFF, 0xFFFF, "SB600 AC97 Modem(0x438E)"},
{0x1002, 0x4390, 0xFFFF, 0xFFFF, "SB7x0/SB8x0/SB9x0 SATA Controller [IDE mode](0x4390)"},
{0x1002, 0x4390, 0x1043, 0x82EF, "M3A78-EH Motherboard(0x1043-0x82EF)"},
{0x1002, 0x4390, 0x1043, 0x8389, "M4A785TD Motherboard(0x1043-0x8389)"},
{0x1002, 0x4390, 0x105B, 0x0E13, "N15235/A74MX mainboard / AMD SB700(0x105B-0x0E13)"},
{0x1002, 0x4390, 0x1458, 0xB002, "GA-MA770-DS3rev2.0 Motherboard(0x1458-0xB002)"},
{0x1002, 0x4390, 0x1462, 0x7596, "760GM-E51(MS-7596) Motherboard(0x1462-0x7596)"},
{0x1002, 0x4390, 0x1849, 0x4390, "Motherboard (one of many)(0x1849-0x4390)"},
{0x1002, 0x4391, 0xFFFF, 0xFFFF, "SB7x0/SB8x0/SB9x0 SATA Controller [AHCI mode](0x4391)"},
{0x1002, 0x4391, 0x103C, 0x1609, "ProLiant MicroServer N36L(0x103C-0x1609)"},
{0x1002, 0x4391, 0x103C, 0x1611, "Pavilion DM1Z-3000(0x103C-0x1611)"},
{0x1002, 0x4391, 0x1043, 0x82EF, "M3A78-EH Motherboard(0x1043-0x82EF)"},
{0x1002, 0x4391, 0x1043, 0x8443, "M5A88-V EVO(0x1043-0x8443)"},
{0x1002, 0x4391, 0x1043, 0x84DD, "M5A99X EVO (R1.0) SB950(0x1043-0x84DD)"},
{0x1002, 0x4391, 0x105B, 0x0E13, "N15235/A74MX mainboard / AMD SB700(0x105B-0x0E13)"},
{0x1002, 0x4391, 0x1458, 0xB002, "GA-78/880-series motherboard(0x1458-0xB002)"},
{0x1002, 0x4391, 0x174B, 0x1001, "PURE Fusion Mini(0x174B-0x1001)"},
{0x1002, 0x4392, 0xFFFF, 0xFFFF, "SB7x0/SB8x0/SB9x0 SATA Controller [Non-RAID5 mode](0x4392)"},
{0x1002, 0x4392, 0x105B, 0x0E13, "N15235/A74MX mainboard / AMD SB700(0x105B-0x0E13)"},
{0x1002, 0x4393, 0xFFFF, 0xFFFF, "SB7x0/SB8x0/SB9x0 SATA Controller [RAID5 mode](0x4393)"},
{0x1002, 0x4394, 0xFFFF, 0xFFFF, "SB7x0/SB8x0/SB9x0 SATA Controller [AHCI mode](0x4394)"},
{0x1002, 0x4395, 0xFFFF, 0xFFFF, "SB8x0/SB9x0 SATA Controller [Storage mode](0x4395)"},
{0x1002, 0x4396, 0xFFFF, 0xFFFF, "SB7x0/SB8x0/SB9x0 USB EHCI Controller(0x4396)"},
{0x1002, 0x4396, 0x1019, 0x2120, "A785GM-M(0x1019-0x2120)"},
{0x1002, 0x4396, 0x103C, 0x1609, "ProLiant MicroServer N36L(0x103C-0x1609)"},
{0x1002, 0x4396, 0x103C, 0x1611, "Pavilion DM1Z-3000(0x103C-0x1611)"},
{0x1002, 0x4396, 0x1043, 0x82EF, "M3A78-EH Motherboard(0x1043-0x82EF)"},
{0x1002, 0x4396, 0x1043, 0x8443, "M5A88-V EVO(0x1043-0x8443)"},
{0x1002, 0x4396, 0x105B, 0x0E13, "N15235/A74MX mainboard / AMD SB700(0x105B-0x0E13)"},
{0x1002, 0x4396, 0x1458, 0x5004, "GA-78/880-series motherboard(0x1458-0x5004)"},
{0x1002, 0x4396, 0x1462, 0x7596, "760GM-E51(MS-7596) Motherboard(0x1462-0x7596)"},
{0x1002, 0x4396, 0x15D9, 0xA811, "H8DGU(0x15D9-0xA811)"},
{0x1002, 0x4396, 0x174B, 0x1001, "PURE Fusion Mini(0x174B-0x1001)"},
{0x1002, 0x4397, 0xFFFF, 0xFFFF, "SB7x0/SB8x0/SB9x0 USB OHCI0 Controller(0x4397)"},
{0x1002, 0x4397, 0x1019, 0x2120, "A785GM-M(0x1019-0x2120)"},
{0x1002, 0x4397, 0x103C, 0x1609, "ProLiant MicroServer N36L(0x103C-0x1609)"},
{0x1002, 0x4397, 0x103C, 0x1611, "Pavilion DM1Z-3000(0x103C-0x1611)"},
{0x1002, 0x4397, 0x1043, 0x82EF, "M3A78-EH Motherboard(0x1043-0x82EF)"},
{0x1002, 0x4397, 0x1043, 0x8443, "M5A88-V EVO(0x1043-0x8443)"},
{0x1002, 0x4397, 0x105B, 0x0E13, "N15235/A74MX mainboard / AMD SB700(0x105B-0x0E13)"},
{0x1002, 0x4397, 0x1458, 0x5004, "GA-78/880-series motherboard(0x1458-0x5004)"},
{0x1002, 0x4397, 0x1462, 0x7596, "760GM-E51(MS-7596) Motherboard(0x1462-0x7596)"},
{0x1002, 0x4397, 0x15D9, 0xA811, "H8DGU(0x15D9-0xA811)"},
{0x1002, 0x4397, 0x174B, 0x1001, "PURE Fusion Mini(0x174B-0x1001)"},
{0x1002, 0x4398, 0xFFFF, 0xFFFF, "SB7x0 USB OHCI1 Controller(0x4398)"},
{0x1002, 0x4398, 0x1019, 0x2120, "A785GM-M(0x1019-0x2120)"},
{0x1002, 0x4398, 0x1043, 0x82EF, "M3A78-EH Motherboard(0x1043-0x82EF)"},
{0x1002, 0x4398, 0x105B, 0x0E13, "N15235/A74MX mainboard / AMD SB700(0x105B-0x0E13)"},
{0x1002, 0x4398, 0x1458, 0x5004, "GA-MA78GM-S2H motherboard(0x1458-0x5004)"},
{0x1002, 0x4398, 0x1462, 0x7596, "760GM-E51(MS-7596) Motherboard(0x1462-0x7596)"},
{0x1002, 0x4398, 0x15D9, 0xA811, "H8DGU(0x15D9-0xA811)"},
{0x1002, 0x4399, 0xFFFF, 0xFFFF, "SB7x0/SB8x0/SB9x0 USB OHCI2 Controller(0x4399)"},
{0x1002, 0x4399, 0x1019, 0x2120, "A785GM-M(0x1019-0x2120)"},
{0x1002, 0x4399, 0x1043, 0x82EF, "M3A78-EH Motherboard(0x1043-0x82EF)"},
{0x1002, 0x4399, 0x1043, 0x8443, "M5A88-V EVO(0x1043-0x8443)"},
{0x1002, 0x4399, 0x105B, 0x0E13, "N15235/A74MX mainboard / AMD SB700(0x105B-0x0E13)"},
{0x1002, 0x4399, 0x1458, 0x5004, "GA-78/880-series motherboard(0x1458-0x5004)"},
{0x1002, 0x4399, 0x1462, 0x7596, "760GM-E51(MS-7596) Motherboard(0x1462-0x7596)"},
{0x1002, 0x4399, 0x174B, 0x1001, "PURE Fusion Mini(0x174B-0x1001)"},
{0x1002, 0x439C, 0xFFFF, 0xFFFF, "SB7x0/SB8x0/SB9x0 IDE Controller(0x439C)"},
{0x1002, 0x439C, 0x1002, 0x4392, "MSI MS-7713 motherboard(0x1002-0x4392)"},
{0x1002, 0x439C, 0x1019, 0x2120, "A785GM-M(0x1019-0x2120)"},
{0x1002, 0x439C, 0x103C, 0x1609, "ProLiant MicroServer N36L(0x103C-0x1609)"},
{0x1002, 0x439C, 0x1043, 0x82EF, "M3A78-EH Motherboard(0x1043-0x82EF)"},
{0x1002, 0x439C, 0x105B, 0x0E13, "N15235/A74MX mainboard / AMD SB700(0x105B-0x0E13)"},
{0x1002, 0x439C, 0x1458, 0x5002, "GA-MA78GM-S2H motherboard(0x1458-0x5002)"},
{0x1002, 0x439C, 0x1462, 0x7596, "760GM-E51(MS-7596) Motherboard(0x1462-0x7596)"},
{0x1002, 0x439D, 0xFFFF, 0xFFFF, "SB7x0/SB8x0/SB9x0 LPC host controller(0x439D)"},
{0x1002, 0x439D, 0x1019, 0x2120, "A785GM-M(0x1019-0x2120)"},
{0x1002, 0x439D, 0x103C, 0x1609, "ProLiant MicroServer N36L(0x103C-0x1609)"},
{0x1002, 0x439D, 0x103C, 0x1611, "Pavilion DM1Z-3000(0x103C-0x1611)"},
{0x1002, 0x439D, 0x1043, 0x82EF, "M3A78-EH Motherboard(0x1043-0x82EF)"},
{0x1002, 0x439D, 0x1043, 0x8443, "M5A88-V EVO(0x1043-0x8443)"},
{0x1002, 0x439D, 0x105B, 0x0E13, "N15235/A74MX mainboard / AMD SB700(0x105B-0x0E13)"},
{0x1002, 0x439D, 0x1462, 0x7596, "760GM-E51(MS-7596) Motherboard(0x1462-0x7596)"},
{0x1002, 0x439D, 0x174B, 0x1001, "PURE Fusion Mini(0x174B-0x1001)"},
{0x1002, 0x43A0, 0xFFFF, 0xFFFF, "SB700/SB800/SB900 PCI to PCI bridge (PCIE port 0)(0x43A0)"},
{0x1002, 0x43A1, 0xFFFF, 0xFFFF, "SB700/SB800/SB900 PCI to PCI bridge (PCIE port 1)(0x43A1)"},
{0x1002, 0x43A2, 0xFFFF, 0xFFFF, "SB900 PCI to PCI bridge (PCIE port 2)(0x43A2)"},
{0x1002, 0x43A3, 0xFFFF, 0xFFFF, "SB900 PCI to PCI bridge (PCIE port 3)(0x43A3)"},
{0x1002, 0x4437, 0xFFFF, 0xFFFF, "RS250 [Mobility Radeon 7000 IGP](0x4437)"},
{0x1002, 0x4554, 0xFFFF, 0xFFFF, "210888ET [Mach64 ET](0x4554)"},
{0x1002, 0x4630, 0xFFFF, 0xFFFF, "XENOS Parent Die (XBOX 360)(0x4630)"},
{0x1002, 0x4631, 0xFFFF, 0xFFFF, "XENOS Daughter Die (XBOX 360)(0x4631)"},
{0x1002, 0x4654, 0xFFFF, 0xFFFF, "Mach64 VT(0x4654)"},
{0x1002, 0x4742, 0xFFFF, 0xFFFF, "Rage 3 [3D Rage PRO AGP 2X](0x4742)"},
{0x1002, 0x4742, 0x1002, 0x0040, "Rage Pro Turbo AGP 2X(0x1002-0x0040)"},
{0x1002, 0x4742, 0x1002, 0x0044, "Rage Pro Turbo AGP 2X(0x1002-0x0044)"},
{0x1002, 0x4742, 0x1002, 0x0061, "Rage Pro AIW AGP 2X(0x1002-0x0061)"},
{0x1002, 0x4742, 0x1002, 0x0062, "Rage Pro AIW AGP 2X(0x1002-0x0062)"},
{0x1002, 0x4742, 0x1002, 0x0063, "Rage Pro AIW AGP 2X(0x1002-0x0063)"},
{0x1002, 0x4742, 0x1002, 0x0080, "Rage Pro Turbo AGP 2X(0x1002-0x0080)"},
{0x1002, 0x4742, 0x1002, 0x0084, "Rage Pro Turbo AGP 2X(0x1002-0x0084)"},
{0x1002, 0x4742, 0x1002, 0x4742, "Rage Pro Turbo AGP 2X(0x1002-0x4742)"},
{0x1002, 0x4742, 0x1002, 0x8001, "Rage Pro Turbo AGP 2X(0x1002-0x8001)"},
{0x1002, 0x4742, 0x1028, 0x0082, "Rage Pro Turbo AGP 2X(0x1028-0x0082)"},
{0x1002, 0x4742, 0x1028, 0x4082, "Optiplex GX1 Onboard Display Adapter(0x1028-0x4082)"},
{0x1002, 0x4742, 0x1028, 0x8082, "Rage Pro Turbo AGP 2X(0x1028-0x8082)"},
{0x1002, 0x4742, 0x1028, 0xC082, "Rage Pro Turbo AGP 2X(0x1028-0xC082)"},
{0x1002, 0x4742, 0x8086, 0x4152, "Xpert 98D AGP 2X(0x8086-0x4152)"},
{0x1002, 0x4742, 0x8086, 0x464A, "Rage Pro Turbo AGP 2X(0x8086-0x464A)"},
{0x1002, 0x4744, 0xFFFF, 0xFFFF, "Rage 3 [3D Rage PRO AGP 1X](0x4744)"},
{0x1002, 0x4744, 0x1002, 0x4744, "Rage Pro Turbo AGP(0x1002-0x4744)"},
{0x1002, 0x4744, 0x8086, 0x4D55, "Rage 3D Pro AGP 1X [Intel MU440EX](0x8086-0x4D55)"},
{0x1002, 0x4749, 0xFFFF, 0xFFFF, "3D Rage PRO PCI(0x4749)"},
{0x1002, 0x4749, 0x1002, 0x0061, "Rage Pro AIW(0x1002-0x0061)"},
{0x1002, 0x4749, 0x1002, 0x0062, "Rage Pro AIW(0x1002-0x0062)"},
{0x1002, 0x474D, 0xFFFF, 0xFFFF, "Rage XL AGP 2X(0x474D)"},
{0x1002, 0x474D, 0x1002, 0x0004, "Xpert 98 RXL AGP 2X(0x1002-0x0004)"},
{0x1002, 0x474D, 0x1002, 0x0008, "Xpert 98 RXL AGP 2X(0x1002-0x0008)"},
{0x1002, 0x474D, 0x1002, 0x0080, "Rage XL AGP 2X(0x1002-0x0080)"},
{0x1002, 0x474D, 0x1002, 0x0084, "Xpert 98 AGP 2X(0x1002-0x0084)"},
{0x1002, 0x474D, 0x1002, 0x474D, "Rage XL AGP(0x1002-0x474D)"},
{0x1002, 0x474D, 0x1033, 0x806A, "Rage XL AGP(0x1033-0x806A)"},
{0x1002, 0x474E, 0xFFFF, 0xFFFF, "Rage XC AGP(0x474E)"},
{0x1002, 0x474E, 0x1002, 0x474E, "Rage XC AGP(0x1002-0x474E)"},
{0x1002, 0x474F, 0xFFFF, 0xFFFF, "Rage XL(0x474F)"},
{0x1002, 0x474F, 0x1002, 0x0008, "Rage XL(0x1002-0x0008)"},
{0x1002, 0x474F, 0x1002, 0x474F, "Rage XL(0x1002-0x474F)"},
{0x1002, 0x4750, 0xFFFF, 0xFFFF, "3D Rage Pro PCI(0x4750)"},
{0x1002, 0x4750, 0x1002, 0x0040, "Rage Pro Turbo(0x1002-0x0040)"},
{0x1002, 0x4750, 0x1002, 0x0044, "Rage Pro Turbo(0x1002-0x0044)"},
{0x1002, 0x4750, 0x1002, 0x0080, "Rage Pro Turbo(0x1002-0x0080)"},
{0x1002, 0x4750, 0x1002, 0x0084, "Rage Pro Turbo(0x1002-0x0084)"},
{0x1002, 0x4750, 0x1002, 0x4750, "Rage Pro Turbo(0x1002-0x4750)"},
{0x1002, 0x4752, 0xFFFF, 0xFFFF, "Rage 3 [Rage XL PCI](0x4752)"},
{0x1002, 0x4752, 0x0E11, 0x001E, "Proliant Rage XL(0x0E11-0x001E)"},
{0x1002, 0x4752, 0x1002, 0x0008, "Rage XL(0x1002-0x0008)"},
{0x1002, 0x4752, 0x1002, 0x4752, "Proliant Rage XL(0x1002-0x4752)"},
{0x1002, 0x4752, 0x1002, 0x8008, "Rage XL(0x1002-0x8008)"},
{0x1002, 0x4752, 0x1014, 0x0240, "eServer xSeries server mainboard(0x1014-0x0240)"},
{0x1002, 0x4752, 0x1028, 0x00CE, "PowerEdge 1400(0x1028-0x00CE)"},
{0x1002, 0x4752, 0x1028, 0x00D1, "PowerEdge 2550(0x1028-0x00D1)"},
{0x1002, 0x4752, 0x1028, 0x00D9, "PowerEdge 2500(0x1028-0x00D9)"},
{0x1002, 0x4752, 0x1028, 0x0134, "PowerEdge 600SC(0x1028-0x0134)"},
{0x1002, 0x4752, 0x1028, 0x014A, "PowerEdge 1750(0x1028-0x014A)"},
{0x1002, 0x4752, 0x1028, 0x0165, "PowerEdge 750(0x1028-0x0165)"},
{0x1002, 0x4752, 0x103C, 0x10E1, "NetServer Rage XL(0x103C-0x10E1)"},
{0x1002, 0x4752, 0x103C, 0x3208, "ProLiant DL140 G2(0x103C-0x3208)"},
{0x1002, 0x4752, 0x107B, 0x6400, "6400 Server(0x107B-0x6400)"},
{0x1002, 0x4752, 0x1734, 0x007A, "PRIMERGY RX/TX series onboard VGA(0x1734-0x007A)"},
{0x1002, 0x4752, 0x1734, 0x1073, "Primergy Econel 200 D2020 mainboard(0x1734-0x1073)"},
{0x1002, 0x4752, 0x8086, 0x3411, "SDS2 Mainboard(0x8086-0x3411)"},
{0x1002, 0x4752, 0x8086, 0x3427, "S875WP1-E mainboard(0x8086-0x3427)"},
{0x1002, 0x4752, 0x8086, 0x5744, "S845WD1-E mainboard(0x8086-0x5744)"},
{0x1002, 0x4753, 0xFFFF, 0xFFFF, "Rage XC(0x4753)"},
{0x1002, 0x4753, 0x1002, 0x4753, "Rage XC(0x1002-0x4753)"},
{0x1002, 0x4754, 0xFFFF, 0xFFFF, "Mach64 GT/GT-B [3D Rage I/II](0x4754)"},
{0x1002, 0x4755, 0xFFFF, 0xFFFF, "Mach64 GT-B [3D Rage II+ DVD](0x4755)"},
{0x1002, 0x4756, 0xFFFF, 0xFFFF, "Rage 2 [3D Rage IIC PCI](0x4756)"},
{0x1002, 0x4756, 0x1002, 0x4756, "Rage IIC(0x1002-0x4756)"},
{0x1002, 0x4757, 0xFFFF, 0xFFFF, "Rage 2 [3D Rage IIC AGP](0x4757)"},
{0x1002, 0x4757, 0x1002, 0x4757, "Rage IIC AGP(0x1002-0x4757)"},
{0x1002, 0x4757, 0x1028, 0x0089, "Rage 3D IIC(0x1028-0x0089)"},
{0x1002, 0x4757, 0x1028, 0x008E, "PowerEdge 1300 onboard video(0x1028-0x008E)"},
{0x1002, 0x4757, 0x1028, 0x4082, "Rage 3D IIC(0x1028-0x4082)"},
{0x1002, 0x4757, 0x1028, 0x8082, "Rage 3D IIC(0x1028-0x8082)"},
{0x1002, 0x4757, 0x1028, 0xC082, "Rage 3D IIC(0x1028-0xC082)"},
{0x1002, 0x4758, 0xFFFF, 0xFFFF, "Mach64 GX [WinTurbo](0x4758)"},
{0x1002, 0x4759, 0xFFFF, 0xFFFF, "Rage 3 [3D Rage IIC PCI](0x4759)"},
{0x1002, 0x475A, 0xFFFF, 0xFFFF, "3D Rage IIC AGP(0x475A)"},
{0x1002, 0x475A, 0x1002, 0x0084, "Rage 3D Pro AGP 2x XPERT 98(0x1002-0x0084)"},
{0x1002, 0x475A, 0x1002, 0x0087, "Rage 3D IIC(0x1002-0x0087)"},
{0x1002, 0x475A, 0x1002, 0x475A, "Rage IIC AGP(0x1002-0x475A)"},
{0x1002, 0x4845, 0xFFFF, 0xFFFF, "Xilleon 220 HBIU for HDTV2(0x4845)"},
{0x1002, 0x4846, 0xFFFF, 0xFFFF, "Xilleon 220 IDE for HDTV2(0x4846)"},
{0x1002, 0x4847, 0xFFFF, 0xFFFF, "Xilleon 220 USB for HDTV2(0x4847)"},
{0x1002, 0x4848, 0xFFFF, 0xFFFF, "Xilleon 220 DAIO-0 for HDTV2(0x4848)"},
{0x1002, 0x4849, 0xFFFF, 0xFFFF, "Xilleon 220 DAIO-1 for HDTV2(0x4849)"},
{0x1002, 0x484A, 0xFFFF, 0xFFFF, "Xilleon 220 LPC for HDTV2(0x484A)"},
{0x1002, 0x4850, 0xFFFF, 0xFFFF, "Xilleon 215 HBIU for X215(0x4850)"},
{0x1002, 0x4851, 0xFFFF, 0xFFFF, "Xilleon 215 IDE for X215(0x4851)"},
{0x1002, 0x4852, 0xFFFF, 0xFFFF, "Xilleon 215 USB for X215(0x4852)"},
{0x1002, 0x4853, 0xFFFF, 0xFFFF, "Xilleon 215 DAIO-0 for X215(0x4853)"},
{0x1002, 0x4854, 0xFFFF, 0xFFFF, "Xilleon 215 DAIO-1 for X215(0x4854)"},
{0x1002, 0x4855, 0xFFFF, 0xFFFF, "Xilleon 225 HBIU for X225(0x4855)"},
{0x1002, 0x4856, 0xFFFF, 0xFFFF, "Xilleon 225 IDE for X225(0x4856)"},
{0x1002, 0x4857, 0xFFFF, 0xFFFF, "Xilleon 225 USB for X225(0x4857)"},
{0x1002, 0x4858, 0xFFFF, 0xFFFF, "Xilleon 225 DAIO-0 for X225(0x4858)"},
{0x1002, 0x4859, 0xFFFF, 0xFFFF, "Xilleon 225 DAIO-1 for X225(0x4859)"},
{0x1002, 0x4860, 0xFFFF, 0xFFFF, "Xilleon 210 HBIU for X210(0x4860)"},
{0x1002, 0x4861, 0xFFFF, 0xFFFF, "Xilleon 210 IDE for X210(0x4861)"},
{0x1002, 0x4862, 0xFFFF, 0xFFFF, "Xilleon 210 USB for X210(0x4862)"},
{0x1002, 0x4863, 0xFFFF, 0xFFFF, "Xilleon 210 DAIO-0 for X210(0x4863)"},
{0x1002, 0x4864, 0xFFFF, 0xFFFF, "Xilleon 210 DAIO-1 for X210(0x4864)"},
{0x1002, 0x4865, 0xFFFF, 0xFFFF, "Xilleon 226 HBIU for X226(0x4865)"},
{0x1002, 0x4866, 0xFFFF, 0xFFFF, "Xilleon 226 IDE for X226(0x4866)"},
{0x1002, 0x4867, 0xFFFF, 0xFFFF, "Xilleon 226 USB for X226(0x4867)"},
{0x1002, 0x4868, 0xFFFF, 0xFFFF, "Xilleon 226 DAIO-0 for X226(0x4868)"},
{0x1002, 0x4869, 0xFFFF, 0xFFFF, "Xilleon 226 DAIO-1 for X226(0x4869)"},
{0x1002, 0x486A, 0xFFFF, 0xFFFF, "Xilleon 240S HBIU for X240S(0x486A)"},
{0x1002, 0x486B, 0xFFFF, 0xFFFF, "Xilleon 240H HBIU for X240H(0x486B)"},
{0x1002, 0x486C, 0xFFFF, 0xFFFF, "Xilleon 240S USB for X240S(0x486C)"},
{0x1002, 0x486D, 0xFFFF, 0xFFFF, "Xilleon 240H USB for X240H(0x486D)"},
{0x1002, 0x486E, 0xFFFF, 0xFFFF, "Xilleon 250 USB 1.1 for X250(0x486E)"},
{0x1002, 0x486F, 0xFFFF, 0xFFFF, "Xilleon 260 USB 1.1 for X260(0x486F)"},
{0x1002, 0x4870, 0xFFFF, 0xFFFF, "Xilleon 250 HBIU for X250(0x4870)"},
{0x1002, 0x4871, 0xFFFF, 0xFFFF, "Xilleon 250 IDE for X250(0x4871)"},
{0x1002, 0x4872, 0xFFFF, 0xFFFF, "Xilleon 234/235 HBIU for X234/X235(0x4872)"},
{0x1002, 0x4873, 0xFFFF, 0xFFFF, "Xilleon 244/245 HBIU for X244/X245(0x4873)"},
{0x1002, 0x4874, 0xFFFF, 0xFFFF, "Xilleon 234/235 USB 1.1 for X234/X235(0x4874)"},
{0x1002, 0x4875, 0xFFFF, 0xFFFF, "Xilleon 260 HBIU for X260(0x4875)"},
{0x1002, 0x4876, 0xFFFF, 0xFFFF, "Xilleon 260 IDE for X260(0x4876)"},
{0x1002, 0x4877, 0xFFFF, 0xFFFF, "Xilleon 244/245 USB 1.1 for X244/X245(0x4877)"},
{0x1002, 0x4878, 0xFFFF, 0xFFFF, "Xilleon 270 HBIU for X270(0x4878)"},
{0x1002, 0x487B, 0xFFFF, 0xFFFF, "Xilleon 242 HBIU for X242(0x487B)"},
{0x1002, 0x487D, 0xFFFF, 0xFFFF, "Xilleon 242 USB 1.1 for X242(0x487D)"},
{0x1002, 0x4880, 0xFFFF, 0xFFFF, "Xilleon 254 HBIU for X254(0x4880)"},
{0x1002, 0x4881, 0xFFFF, 0xFFFF, "Xilleon 254 USB 1.1 for X254(0x4881)"},
{0x1002, 0x4882, 0xFFFF, 0xFFFF, "Xilleon 255 HBIU for X255(0x4882)"},
{0x1002, 0x4883, 0xFFFF, 0xFFFF, "Xilleon 255 USB 1.1 for X255(0x4883)"},
{0x1002, 0x4884, 0xFFFF, 0xFFFF, "Xilleon 243 HBIU for X243(0x4884)"},
{0x1002, 0x4885, 0xFFFF, 0xFFFF, "Xilleon 243 USB 1.1 for X243(0x4885)"},
{0x1002, 0x4886, 0xFFFF, 0xFFFF, "Xilleon 233 HBIU for X233(0x4886)"},
{0x1002, 0x4887, 0xFFFF, 0xFFFF, "Xilleon 233 USB 1.1 for X233(0x4887)"},
{0x1002, 0x4888, 0xFFFF, 0xFFFF, "Xilleon 143 HBIU for X143(0x4888)"},
{0x1002, 0x4889, 0xFFFF, 0xFFFF, "Xilleon 143 HBIU for X143L(0x4889)"},
{0x1002, 0x488A, 0xFFFF, 0xFFFF, "Xilleon 143 HBIU for X143S(0x488A)"},
{0x1002, 0x4966, 0xFFFF, 0xFFFF, "RV250 [Radeon 9000 Series](0x4966)"},
{0x1002, 0x4966, 0x10F1, 0x0002, "RV250 If [Tachyon G9000 PRO](0x10F1-0x0002)"},
{0x1002, 0x4966, 0x148C, 0x2039, "RV250 If [Radeon 9000 Pro \"Evil Commando\"](0x148C-0x2039)"},
{0x1002, 0x4966, 0x1509, 0x9A00, "RV250 If [Radeon 9000 \"AT009\"](0x1509-0x9A00)"},
{0x1002, 0x4966, 0x1681, 0x0040, "RV250 If [3D prophet 9000](0x1681-0x0040)"},
{0x1002, 0x4966, 0x174B, 0x7176, "Radeon 9000 Pro(0x174B-0x7176)"},
{0x1002, 0x4966, 0x174B, 0x7192, "RV250 If [Radeon 9000 \"Atlantis\"](0x174B-0x7192)"},
{0x1002, 0x4966, 0x17AF, 0x2005, "RV250 If [Excalibur Radeon 9000 Pro](0x17AF-0x2005)"},
{0x1002, 0x4966, 0x17AF, 0x2006, "RV250 If [Excalibur Radeon 9000](0x17AF-0x2006)"},
{0x1002, 0x496E, 0xFFFF, 0xFFFF, "RV250 [Radeon 9000] (Secondary)(0x496E)"},
{0x1002, 0x4A49, 0xFFFF, 0xFFFF, "R420 [Radeon X800 PRO/GTO AGP](0x4A49)"},
{0x1002, 0x4A49, 0x174B, 0x2620, "R420 [Radeon X800 GTO AGP](0x174B-0x2620)"},
{0x1002, 0x4A4A, 0xFFFF, 0xFFFF, "R420 [Radeon X800 GT AGP](0x4A4A)"},
{0x1002, 0x4A4B, 0xFFFF, 0xFFFF, "R420 [Radeon X800 AGP Series](0x4A4B)"},
{0x1002, 0x4A4D, 0xFFFF, 0xFFFF, "R420 GL [FireGL X3-256](0x4A4D)"},
{0x1002, 0x4A4E, 0xFFFF, 0xFFFF, "RV420/M18 [Mobility Radeon 9800](0x4A4E)"},
{0x1002, 0x4A4F, 0xFFFF, 0xFFFF, "R420 [Radeon X850 AGP](0x4A4F)"},
{0x1002, 0x4A50, 0xFFFF, 0xFFFF, "R420 [Radeon X800 XT Platinum Edition AGP](0x4A50)"},
{0x1002, 0x4A54, 0xFFFF, 0xFFFF, "R420 [Radeon X800 VE AGP](0x4A54)"},
{0x1002, 0x4A54, 0x1002, 0x4422, "All-In-Wonder X800 VE AGP(0x1002-0x4422)"},
{0x1002, 0x4A69, 0xFFFF, 0xFFFF, "R420 [Radeon X800 PRO/GTO] (Secondary)(0x4A69)"},
{0x1002, 0x4A6A, 0xFFFF, 0xFFFF, "R420 [Radeon X800] (Secondary)(0x4A6A)"},
{0x1002, 0x4A6B, 0xFFFF, 0xFFFF, "R420 [Radeon X800 XT AGP] (Secondary)(0x4A6B)"},
{0x1002, 0x4A70, 0xFFFF, 0xFFFF, "R420 [Radeon X800 XT Platinum Edition AGP] (Secondary)(0x4A70)"},
{0x1002, 0x4A74, 0xFFFF, 0xFFFF, "R420 [Radeon X800 VE] (Secondary)(0x4A74)"},
{0x1002, 0x4B49, 0xFFFF, 0xFFFF, "R481 [Radeon X850 XT AGP](0x4B49)"},
{0x1002, 0x4B4B, 0xFFFF, 0xFFFF, "R481 [Radeon X850 PRO AGP](0x4B4B)"},
{0x1002, 0x4B4C, 0xFFFF, 0xFFFF, "R481 [Radeon X850 XT Platinum Edition AGP](0x4B4C)"},
{0x1002, 0x4B69, 0xFFFF, 0xFFFF, "R481 [Radeon X850 XT AGP] (Secondary)(0x4B69)"},
{0x1002, 0x4B6B, 0xFFFF, 0xFFFF, "R481 [Radeon X850 PRO AGP] (Secondary)(0x4B6B)"},
{0x1002, 0x4B6C, 0xFFFF, 0xFFFF, "R481 [Radeon X850 XT Platinum Edition AGP] (Secondary)(0x4B6C)"},
{0x1002, 0x4C42, 0xFFFF, 0xFFFF, "Mach64 LT [3D Rage LT PRO AGP](0x4C42)"},
{0x1002, 0x4C42, 0x0E11, 0xB0E7, "Rage LT Pro (Compaq Presario 5240)(0x0E11-0xB0E7)"},
{0x1002, 0x4C42, 0x0E11, 0xB0E8, "Rage 3D LT Pro(0x0E11-0xB0E8)"},
{0x1002, 0x4C42, 0x0E11, 0xB10E, "3D Rage LT Pro (Compaq Armada 1750)(0x0E11-0xB10E)"},
{0x1002, 0x4C42, 0x1002, 0x0040, "Rage LT Pro AGP 2X(0x1002-0x0040)"},
{0x1002, 0x4C42, 0x1002, 0x0044, "Rage LT Pro AGP 2X(0x1002-0x0044)"},
{0x1002, 0x4C42, 0x1002, 0x4C42, "Rage LT Pro AGP 2X(0x1002-0x4C42)"},
{0x1002, 0x4C42, 0x1002, 0x8001, "Rage LT Pro AGP 2X(0x1002-0x8001)"},
{0x1002, 0x4C42, 0x1028, 0x0085, "Rage 3D LT Pro(0x1028-0x0085)"},
{0x1002, 0x4C46, 0xFFFF, 0xFFFF, "Rage Mobility 128 AGP 2X/Mobility M3(0x4C46)"},
{0x1002, 0x4C46, 0x1002, 0x0155, "IBM Thinkpad A22p(0x1002-0x0155)"},
{0x1002, 0x4C46, 0x1014, 0x0155, "Thinkpad A22p(0x1014-0x0155)"},
{0x1002, 0x4C46, 0x1028, 0x00B1, "Latitude C600(0x1028-0x00B1)"},
{0x1002, 0x4C47, 0xFFFF, 0xFFFF, "3D Rage IIC PCI / Mobility Radeon 7500/7500C(0x4C47)"},
{0x1002, 0x4C49, 0xFFFF, 0xFFFF, "3D Rage LT PRO PCI(0x4C49)"},
{0x1002, 0x4C49, 0x1002, 0x0004, "Rage LT Pro(0x1002-0x0004)"},
{0x1002, 0x4C49, 0x1002, 0x0040, "Rage LT Pro(0x1002-0x0040)"},
{0x1002, 0x4C49, 0x1002, 0x0044, "Rage LT Pro(0x1002-0x0044)"},
{0x1002, 0x4C49, 0x1002, 0x4C49, "Rage LT Pro(0x1002-0x4C49)"},
{0x1002, 0x4C4D, 0xFFFF, 0xFFFF, "Rage Mobility AGP 2x Series(0x4C4D)"},
{0x1002, 0x4C4D, 0x0E11, 0xB111, "Armada M700(0x0E11-0xB111)"},
{0x1002, 0x4C4D, 0x0E11, 0xB160, "Armada E500(0x0E11-0xB160)"},
{0x1002, 0x4C4D, 0x1002, 0x0084, "Xpert 98 AGP 2X (Mobility)(0x1002-0x0084)"},
{0x1002, 0x4C4D, 0x1014, 0x0154, "ThinkPad A20m/A21m(0x1014-0x0154)"},
{0x1002, 0x4C4D, 0x1028, 0x00AA, "Latitude CPt(0x1028-0x00AA)"},
{0x1002, 0x4C4D, 0x1028, 0x00BB, "Latitude CPx(0x1028-0x00BB)"},
{0x1002, 0x4C4D, 0x1179, 0xFF00, "Satellite 1715XCDS laptop(0x1179-0xFF00)"},
{0x1002, 0x4C4D, 0x13BD, 0x1019, "PC-AR10(0x13BD-0x1019)"},
{0x1002, 0x4C4E, 0xFFFF, 0xFFFF, "Rage Mobility L AGP 2x(0x4C4E)"},
{0x1002, 0x4C50, 0xFFFF, 0xFFFF, "Rage 3 LT [3D Rage LT PRO PCI](0x4C50)"},
{0x1002, 0x4C50, 0x1002, 0x4C50, "Rage LT Pro(0x1002-0x4C50)"},
{0x1002, 0x4C52, 0xFFFF, 0xFFFF, "M1 [Rage Mobility-M1 PCI](0x4C52)"},
{0x1002, 0x4C52, 0x1033, 0x8112, "Versa Note VXi(0x1033-0x8112)"},
{0x1002, 0x4C54, 0xFFFF, 0xFFFF, "264LT [Mach64 LT](0x4C54)"},
{0x1002, 0x4C57, 0xFFFF, 0xFFFF, "RV200/M7 [Mobility Radeon 7500](0x4C57)"},
{0x1002, 0x4C57, 0x1014, 0x0517, "ThinkPad T30(0x1014-0x0517)"},
{0x1002, 0x4C57, 0x1014, 0x0530, "ThinkPad T4x Series(0x1014-0x0530)"},
{0x1002, 0x4C57, 0x1028, 0x00E6, "Radeon Mobility M7 LW (Dell Inspiron 8100)(0x1028-0x00E6)"},
{0x1002, 0x4C57, 0x1028, 0x012A, "Latitude C640(0x1028-0x012A)"},
{0x1002, 0x4C57, 0x1043, 0x1622, "Mobility Radeon M7 (L3C/S)(0x1043-0x1622)"},
{0x1002, 0x4C57, 0x144D, 0xC006, "Radeon Mobility M7 LW in vpr Matrix 170B4(0x144D-0xC006)"},
{0x1002, 0x4C58, 0xFFFF, 0xFFFF, "RV200/M7 GL [Mobility FireGL 7800](0x4C58)"},
{0x1002, 0x4C59, 0xFFFF, 0xFFFF, "RV100/M6 [Rage/Radeon Mobility Series](0x4C59)"},
{0x1002, 0x4C59, 0x0E11, 0xB111, "Evo N600c(0x0E11-0xB111)"},
{0x1002, 0x4C59, 0x1014, 0x0235, "ThinkPad A30/A30p (2652/2653)(0x1014-0x0235)"},
{0x1002, 0x4C59, 0x1014, 0x0239, "ThinkPad X22/X23/X24(0x1014-0x0239)"},
{0x1002, 0x4C59, 0x103C, 0x0025, "XE4500 Notebook(0x103C-0x0025)"},
{0x1002, 0x4C59, 0x104D, 0x80E7, "VAIO PCG-GR214EP/GR214MP/GR215MP/GR314MP/GR315MP(0x104D-0x80E7)"},
{0x1002, 0x4C59, 0x104D, 0x8140, "PCG-Z1SP laptop(0x104D-0x8140)"},
{0x1002, 0x4C59, 0x1509, 0x1930, "Medion MD9703(0x1509-0x1930)"},
{0x1002, 0x4C66, 0xFFFF, 0xFFFF, "RV250/M9 GL [Mobility FireGL 9000/Radeon 9000](0x4C66)"},
{0x1002, 0x4C66, 0x1014, 0x054D, "ThinkPad T41(0x1014-0x054D)"},
{0x1002, 0x4C6E, 0xFFFF, 0xFFFF, "RV250/M9 [Mobility Radeon 9000] (Secondary)(0x4C6E)"},
{0x1002, 0x4D46, 0xFFFF, 0xFFFF, "Rage Mobility 128 AGP 4X/Mobility M4(0x4D46)"},
{0x1002, 0x4D52, 0xFFFF, 0xFFFF, "Theater 550 PRO PCI [ATI TV Wonder 550](0x4D52)"},
{0x1002, 0x4D53, 0xFFFF, 0xFFFF, "Theater 550 PRO PCIe(0x4D53)"},
{0x1002, 0x4E44, 0xFFFF, 0xFFFF, "R300 [Radeon 9700/9700 PRO](0x4E44)"},
{0x1002, 0x4E44, 0x1002, 0x515E, "Radeon ES1000(0x1002-0x515E)"},
{0x1002, 0x4E44, 0x1002, 0x5965, "Radeon ES1000(0x1002-0x5965)"},
{0x1002, 0x4E45, 0xFFFF, 0xFFFF, "R300 [Radeon 9500 PRO/9700](0x4E45)"},
{0x1002, 0x4E45, 0x1002, 0x0002, "Radeon R300 NE [Radeon 9500 Pro](0x1002-0x0002)"},
{0x1002, 0x4E45, 0x1681, 0x0002, "Hercules 3D Prophet 9500 PRO [Radeon 9500 Pro](0x1681-0x0002)"},
{0x1002, 0x4E46, 0xFFFF, 0xFFFF, "R300 [Radeon 9600 TX](0x4E46)"},
{0x1002, 0x4E47, 0xFFFF, 0xFFFF, "R300 GL [FireGL X1](0x4E47)"},
{0x1002, 0x4E48, 0xFFFF, 0xFFFF, "R350 [Radeon 9800 Series](0x4E48)"},
{0x1002, 0x4E49, 0xFFFF, 0xFFFF, "R350 [Radeon 9800](0x4E49)"},
{0x1002, 0x4E4A, 0xFFFF, 0xFFFF, "R360 [Radeon 9800 XXL/XT](0x4E4A)"},
{0x1002, 0x4E4A, 0x1002, 0x4E4A, "R360 [Radeon 9800 XT](0x1002-0x4E4A)"},
{0x1002, 0x4E4B, 0xFFFF, 0xFFFF, "R350 GL [FireGL X2 AGP Pro](0x4E4B)"},
{0x1002, 0x4E50, 0xFFFF, 0xFFFF, "RV350/M10 / RV360/M11 [Mobility Radeon 9600 (PRO) / 9700](0x4E50)"},
{0x1002, 0x4E50, 0x1025, 0x005A, "TravelMate 290(0x1025-0x005A)"},
{0x1002, 0x4E50, 0x1025, 0x0064, "Extensa 3000 series laptop: ATI RV360/M11 [Mobility Radeon 9700](0x1025-0x0064)"},
{0x1002, 0x4E50, 0x103C, 0x088C, "NC8000 laptop(0x103C-0x088C)"},
{0x1002, 0x4E50, 0x103C, 0x0890, "NC6000 laptop(0x103C-0x0890)"},
{0x1002, 0x4E50, 0x144D, 0xC00C, "P35 notebook(0x144D-0xC00C)"},
{0x1002, 0x4E50, 0x1462, 0x0311, "MSI M510A(0x1462-0x0311)"},
{0x1002, 0x4E50, 0x1734, 0x1055, "Amilo M1420W(0x1734-0x1055)"},
{0x1002, 0x4E51, 0xFFFF, 0xFFFF, "RV350 [Radeon 9550/9600/X1050 Series](0x4E51)"},
{0x1002, 0x4E52, 0xFFFF, 0xFFFF, "RV350/M10 [Mobility Radeon 9500/9700 SE](0x4E52)"},
{0x1002, 0x4E52, 0x144D, 0xC00C, "P35 notebook(0x144D-0xC00C)"},
{0x1002, 0x4E54, 0xFFFF, 0xFFFF, "RV350/M10 GL [Mobility FireGL T2](0x4E54)"},
{0x1002, 0x4E56, 0xFFFF, 0xFFFF, "RV360/M12 [Mobility Radeon 9550](0x4E56)"},
{0x1002, 0x4E64, 0xFFFF, 0xFFFF, "R300 [Radeon 9700 PRO] (Secondary)(0x4E64)"},
{0x1002, 0x4E65, 0xFFFF, 0xFFFF, "R300 [Radeon 9500 PRO] (Secondary)(0x4E65)"},
{0x1002, 0x4E65, 0x1002, 0x0003, "Radeon R300 NE [Radeon 9500 Pro](0x1002-0x0003)"},
{0x1002, 0x4E65, 0x1681, 0x0003, "Hercules 3D Prophet 9500 PRO [Radeon 9500 Pro] (Secondary)(0x1681-0x0003)"},
{0x1002, 0x4E66, 0xFFFF, 0xFFFF, "RV350 [Radeon 9600] (Secondary)(0x4E66)"},
{0x1002, 0x4E67, 0xFFFF, 0xFFFF, "R300 GL [FireGL X1] (Secondary)(0x4E67)"},
{0x1002, 0x4E68, 0xFFFF, 0xFFFF, "R350 [Radeon 9800 PRO] (Secondary)(0x4E68)"},
{0x1002, 0x4E69, 0xFFFF, 0xFFFF, "R350 [Radeon 9800] (Secondary)(0x4E69)"},
{0x1002, 0x4E6A, 0xFFFF, 0xFFFF, "RV350 [Radeon 9800 XT] (Secondary)(0x4E6A)"},
{0x1002, 0x4E6A, 0x1002, 0x4E6A, "R360 [Radeon 9800 XT] (Secondary)(0x1002-0x4E6A)"},
{0x1002, 0x4E6A, 0x1002, 0x4E71, "M10 NQ [Radeon Mobility 9600](0x1002-0x4E71)"},
{0x1002, 0x4E71, 0xFFFF, 0xFFFF, "RV350/M10 [Mobility Radeon 9600] (Secondary)(0x4E71)"},
{0x1002, 0x4F72, 0xFFFF, 0xFFFF, "RV250 [Radeon 9000 Series](0x4F72)"},
{0x1002, 0x4F73, 0xFFFF, 0xFFFF, "RV250 [Radeon 9000 Series] (Secondary)(0x4F73)"},
{0x1002, 0x5044, 0xFFFF, 0xFFFF, "All-In-Wonder 128 PCI(0x5044)"},
{0x1002, 0x5044, 0x1002, 0x0028, "Rage 128 AIW(0x1002-0x0028)"},
{0x1002, 0x5044, 0x1002, 0x0029, "Rage 128 AIW(0x1002-0x0029)"},
{0x1002, 0x5046, 0xFFFF, 0xFFFF, "Rage 4 [Rage 128 PRO AGP 4X](0x5046)"},
{0x1002, 0x5046, 0x1002, 0x0004, "Rage Fury Pro(0x1002-0x0004)"},
{0x1002, 0x5046, 0x1002, 0x0008, "Rage Fury Pro/Xpert 2000 Pro(0x1002-0x0008)"},
{0x1002, 0x5046, 0x1002, 0x0014, "Rage Fury Pro(0x1002-0x0014)"},
{0x1002, 0x5046, 0x1002, 0x0018, "Rage Fury Pro/Xpert 2000 Pro(0x1002-0x0018)"},
{0x1002, 0x5046, 0x1002, 0x0028, "Rage 128 Pro AIW AGP(0x1002-0x0028)"},
{0x1002, 0x5046, 0x1002, 0x002A, "Rage 128 Pro AIW AGP(0x1002-0x002A)"},
{0x1002, 0x5046, 0x1002, 0x0048, "Rage Fury Pro(0x1002-0x0048)"},
{0x1002, 0x5046, 0x1002, 0x2000, "Rage Fury MAXX AGP 4x (TMDS) (VGA device)(0x1002-0x2000)"},
{0x1002, 0x5046, 0x1002, 0x2001, "Rage Fury MAXX AGP 4x (TMDS) (Extra device?-!)(0x1002-0x2001)"},
{0x1002, 0x5050, 0xFFFF, 0xFFFF, "Rage 4 [Rage 128 PRO PCI / Xpert 128 PCI](0x5050)"},
{0x1002, 0x5050, 0x1002, 0x0008, "Xpert 128(0x1002-0x0008)"},
{0x1002, 0x5052, 0xFFFF, 0xFFFF, "Rage 4 [Rage 128 PRO AGP 4X](0x5052)"},
{0x1002, 0x5144, 0xFFFF, 0xFFFF, "R100 [Radeon 7200 / All-In-Wonder Radeon](0x5144)"},
{0x1002, 0x5144, 0x1002, 0x0008, "Radeon 7000/Radeon VE(0x1002-0x0008)"},
{0x1002, 0x5144, 0x1002, 0x0009, "Radeon 7000/Radeon(0x1002-0x0009)"},
{0x1002, 0x5144, 0x1002, 0x000A, "Radeon 7000/Radeon(0x1002-0x000A)"},
{0x1002, 0x5144, 0x1002, 0x001A, "Radeon 7000/Radeon(0x1002-0x001A)"},
{0x1002, 0x5144, 0x1002, 0x0029, "Radeon AIW(0x1002-0x0029)"},
{0x1002, 0x5144, 0x1002, 0x0038, "Radeon 7000/Radeon(0x1002-0x0038)"},
{0x1002, 0x5144, 0x1002, 0x0039, "Radeon 7000/Radeon(0x1002-0x0039)"},
{0x1002, 0x5144, 0x1002, 0x008A, "Radeon 7000/Radeon(0x1002-0x008A)"},
{0x1002, 0x5144, 0x1002, 0x00BA, "Radeon 7000/Radeon(0x1002-0x00BA)"},
{0x1002, 0x5144, 0x1002, 0x0139, "Radeon 7000/Radeon(0x1002-0x0139)"},
{0x1002, 0x5144, 0x1002, 0x028A, "Radeon 7000/Radeon(0x1002-0x028A)"},
{0x1002, 0x5144, 0x1002, 0x02AA, "Radeon AIW(0x1002-0x02AA)"},
{0x1002, 0x5144, 0x1002, 0x053A, "Radeon 7000/Radeon(0x1002-0x053A)"},
{0x1002, 0x5148, 0xFFFF, 0xFFFF, "R200 GL [FireGL 8800](0x5148)"},
{0x1002, 0x5148, 0x1002, 0x010A, "FireGL 8800 64Mb(0x1002-0x010A)"},
{0x1002, 0x5148, 0x1002, 0x0152, "FireGL 8800 128Mb(0x1002-0x0152)"},
{0x1002, 0x5148, 0x1002, 0x0162, "FireGL 8700 32Mb(0x1002-0x0162)"},
{0x1002, 0x5148, 0x1002, 0x0172, "FireGL 8700 64Mb(0x1002-0x0172)"},
{0x1002, 0x514C, 0xFFFF, 0xFFFF, "R200 [Radeon 8500/8500 LE](0x514C)"},
{0x1002, 0x514C, 0x1002, 0x003A, "Radeon R200 QL [Radeon 8500 LE](0x1002-0x003A)"},
{0x1002, 0x514C, 0x1002, 0x013A, "Radeon 8500(0x1002-0x013A)"},
{0x1002, 0x514C, 0x148C, 0x2026, "R200 QL [Radeon 8500 Evil Master II Multi Display Edition](0x148C-0x2026)"},
{0x1002, 0x514C, 0x1681, 0x0010, "Radeon 8500 [3D Prophet 8500 128Mb](0x1681-0x0010)"},
{0x1002, 0x514C, 0x174B, 0x7149, "Radeon 8500 LE(0x174B-0x7149)"},
{0x1002, 0x514C, 0x1787, 0x0F08, "Radeon R200 QL [PowerMagic Radeon 8500](0x1787-0x0F08)"},
{0x1002, 0x514D, 0xFFFF, 0xFFFF, "R200 [Radeon 9100](0x514D)"},
{0x1002, 0x5157, 0xFFFF, 0xFFFF, "RV200 [Radeon 7500/7500 LE](0x5157)"},
{0x1002, 0x5157, 0x1002, 0x013A, "Radeon 7500(0x1002-0x013A)"},
{0x1002, 0x5157, 0x1002, 0x0F2B, "ALL-IN-WONDER VE PCI(0x1002-0x0F2B)"},
{0x1002, 0x5157, 0x1002, 0x103A, "Dell Optiplex GX260(0x1002-0x103A)"},
{0x1002, 0x5157, 0x1458, 0x4000, "RV200 QW [RADEON 7500 PRO MAYA AR](0x1458-0x4000)"},
{0x1002, 0x5157, 0x148C, 0x2024, "RV200 QW [Radeon 7500LE Dual Display](0x148C-0x2024)"},
{0x1002, 0x5157, 0x148C, 0x2025, "RV200 QW [Radeon 7500 Evil Master Multi Display Edition](0x148C-0x2025)"},
{0x1002, 0x5157, 0x148C, 0x2036, "RV200 QW [Radeon 7500 PCI Dual Display](0x148C-0x2036)"},
{0x1002, 0x5157, 0x174B, 0x7146, "RV200 QW [Radeon 7500 LE](0x174B-0x7146)"},
{0x1002, 0x5157, 0x174B, 0x7147, "Radeon 7500 LE(0x174B-0x7147)"},
{0x1002, 0x5157, 0x174B, 0x7161, "Radeon RV200 QW [Radeon 7500 LE](0x174B-0x7161)"},
{0x1002, 0x5157, 0x17AF, 0x0202, "RV200 QW [Excalibur Radeon 7500LE](0x17AF-0x0202)"},
{0x1002, 0x5159, 0xFFFF, 0xFFFF, "RV100 [Radeon 7000 / Radeon VE](0x5159)"},
{0x1002, 0x5159, 0x1002, 0x000A, "Radeon 7000/Radeon VE(0x1002-0x000A)"},
{0x1002, 0x5159, 0x1002, 0x000B, "Radeon 7000(0x1002-0x000B)"},
{0x1002, 0x5159, 0x1002, 0x0038, "Radeon 7000/Radeon VE(0x1002-0x0038)"},
{0x1002, 0x5159, 0x1002, 0x003A, "Radeon 7000/Radeon VE(0x1002-0x003A)"},
{0x1002, 0x5159, 0x1002, 0x00BA, "Radeon 7000/Radeon VE(0x1002-0x00BA)"},
{0x1002, 0x5159, 0x1002, 0x013A, "Radeon 7000/Radeon VE(0x1002-0x013A)"},
{0x1002, 0x5159, 0x1002, 0x0908, "XVR-100 (supplied by Sun)(0x1002-0x0908)"},
{0x1002, 0x5159, 0x1014, 0x029A, "Remote Supervisor Adapter II (RSA2)(0x1014-0x029A)"},
{0x1002, 0x5159, 0x1014, 0x02C8, "eServer xSeries server mainboard(0x1014-0x02C8)"},
{0x1002, 0x5159, 0x1028, 0x016C, "PowerEdge 1850 Embedded Radeon 7000/VE(0x1028-0x016C)"},
{0x1002, 0x5159, 0x1028, 0x016D, "PowerEdge 2850 Embedded Radeon 7000-M(0x1028-0x016D)"},
{0x1002, 0x5159, 0x1028, 0x0170, "PowerEdge 6850 Embedded Radeon 7000/VE(0x1028-0x0170)"},
{0x1002, 0x5159, 0x1028, 0x019A, "PowerEdge SC1425(0x1028-0x019A)"},
{0x1002, 0x5159, 0x103C, 0x1292, "Radeon 7000(0x103C-0x1292)"},
{0x1002, 0x5159, 0x1043, 0xC00A, "A7000/T/64M(0x1043-0xC00A)"},
{0x1002, 0x5159, 0x1458, 0x4002, "RV100 QY [RADEON 7000 PRO MAYA AV Series](0x1458-0x4002)"},
{0x1002, 0x5159, 0x148C, 0x2003, "RV100 QY [Radeon 7000 Multi-Display Edition](0x148C-0x2003)"},
{0x1002, 0x5159, 0x148C, 0x2023, "RV100 QY [Radeon 7000 Evil Master Multi-Display](0x148C-0x2023)"},
{0x1002, 0x5159, 0x148C, 0x2081, "RV6DE(0x148C-0x2081)"},
{0x1002, 0x5159, 0x174B, 0x0280, "Radeon RV100 QY [Radeon 7000/VE](0x174B-0x0280)"},
{0x1002, 0x5159, 0x174B, 0x7112, "Radeon VE 7000(0x174B-0x7112)"},
{0x1002, 0x5159, 0x174B, 0x7C28, "Radeon VE 7000 DDR(0x174B-0x7C28)"},
{0x1002, 0x5159, 0x1787, 0x0202, "RV100 QY [Excalibur Radeon 7000](0x1787-0x0202)"},
{0x1002, 0x5159, 0x17EE, 0x1001, "Radeon 7000 64MB DDR + DVI(0x17EE-0x1001)"},
{0x1002, 0x515E, 0xFFFF, 0xFFFF, "ES1000(0x515E)"},
{0x1002, 0x515E, 0x1028, 0x01BB, "PowerEdge 1955 Embedded ATI ES1000(0x1028-0x01BB)"},
{0x1002, 0x515E, 0x1028, 0x01DF, "PowerEdge SC440(0x1028-0x01DF)"},
{0x1002, 0x515E, 0x1028, 0x01E6, "PowerEdge 860(0x1028-0x01E6)"},
{0x1002, 0x515E, 0x1028, 0x01F0, "PowerEdge R900 Embedded ATI ES1000(0x1028-0x01F0)"},
{0x1002, 0x515E, 0x1028, 0x0205, "PowerEdge 2970 Embedded ATI ES1000(0x1028-0x0205)"},
{0x1002, 0x515E, 0x1028, 0x020B, "PowerEdge T605 Embedded ATI ES1000(0x1028-0x020B)"},
{0x1002, 0x515E, 0x1028, 0x020F, "PowerEdge R300 Embedded ATI ES1000(0x1028-0x020F)"},
{0x1002, 0x515E, 0x1028, 0x0210, "PowerEdge T300 Embedded ATI ES1000(0x1028-0x0210)"},
{0x1002, 0x515E, 0x1028, 0x0221, "PowerEdge R805 Embedded ATI ES1000(0x1028-0x0221)"},
{0x1002, 0x515E, 0x1028, 0x0223, "PowerEdge R905 Embedded ATI ES1000(0x1028-0x0223)"},
{0x1002, 0x515E, 0x1028, 0x0225, "PowerEdge T105 Embedded ATI ES1000(0x1028-0x0225)"},
{0x1002, 0x515E, 0x1028, 0x023C, "PowerEdge R200 Embedded ATI ES1000(0x1028-0x023C)"},
{0x1002, 0x515E, 0x103C, 0x1304, "Integrity iLO2 Advanced KVM VGA [AD307A](0x103C-0x1304)"},
{0x1002, 0x515E, 0x103C, 0x31FB, "ProLiant DL360 G5(0x103C-0x31FB)"},
{0x1002, 0x515E, 0x15D9, 0x8680, "X7DVL-E-O motherboard(0x15D9-0x8680)"},
{0x1002, 0x515E, 0x15D9, 0x9680, "X7DBN Motherboard(0x15D9-0x9680)"},
{0x1002, 0x515E, 0x8086, 0x3476, "S5000PSLSATA Server Board(0x8086-0x3476)"},
{0x1002, 0x5245, 0xFFFF, 0xFFFF, "Rage 128 GL PCI(0x5245)"},
{0x1002, 0x5245, 0x1002, 0x0008, "Xpert 128(0x1002-0x0008)"},
{0x1002, 0x5245, 0x1002, 0x0028, "Rage 128 AIW(0x1002-0x0028)"},
{0x1002, 0x5245, 0x1002, 0x0029, "Rage 128 AIW(0x1002-0x0029)"},
{0x1002, 0x5245, 0x1002, 0x0068, "Rage 128 AIW(0x1002-0x0068)"},
{0x1002, 0x5246, 0xFFFF, 0xFFFF, "Rage 128 (Rage 4) series(0x5246)"},
{0x1002, 0x5246, 0x1002, 0x0004, "Magnum/Xpert 128/Xpert 99(0x1002-0x0004)"},
{0x1002, 0x5246, 0x1002, 0x0008, "Rage 128 AGP 2x(0x1002-0x0008)"},
{0x1002, 0x5246, 0x1002, 0x0028, "Rage 128 AIW AGP(0x1002-0x0028)"},
{0x1002, 0x5246, 0x1002, 0x0044, "Rage Fury/Xpert 128/Xpert 2000(0x1002-0x0044)"},
{0x1002, 0x5246, 0x1002, 0x0068, "Rage 128 AIW AGP(0x1002-0x0068)"},
{0x1002, 0x5246, 0x1002, 0x0448, "Rage Fury(0x1002-0x0448)"},
{0x1002, 0x524B, 0xFFFF, 0xFFFF, "Rage 128 VR PCI(0x524B)"},
{0x1002, 0x524C, 0xFFFF, 0xFFFF, "Rage 128 VR AGP(0x524C)"},
{0x1002, 0x524C, 0x1002, 0x0008, "Xpert 99/Xpert 2000(0x1002-0x0008)"},
{0x1002, 0x524C, 0x1002, 0x0088, "Xpert 99(0x1002-0x0088)"},
{0x1002, 0x534D, 0xFFFF, 0xFFFF, "Rage 128 4X AGP 4x(0x534D)"},
{0x1002, 0x534D, 0x1002, 0x0008, "Xpert 99/Xpert 2000(0x1002-0x0008)"},
{0x1002, 0x534D, 0x1002, 0x0018, "Xpert 2000(0x1002-0x0018)"},
{0x1002, 0x5354, 0xFFFF, 0xFFFF, "Mach 64 VT(0x5354)"},
{0x1002, 0x5354, 0x1002, 0x5654, "Mach 64 reference(0x1002-0x5654)"},
{0x1002, 0x5446, 0xFFFF, 0xFFFF, "Rage 128 PRO Ultra AGP 4x(0x5446)"},
{0x1002, 0x5446, 0x1002, 0x0004, "Rage Fury Pro(0x1002-0x0004)"},
{0x1002, 0x5446, 0x1002, 0x0008, "Rage Fury Pro/Xpert 2000 Pro(0x1002-0x0008)"},
{0x1002, 0x5446, 0x1002, 0x0018, "Rage Fury Pro/Xpert 2000 Pro(0x1002-0x0018)"},
{0x1002, 0x5446, 0x1002, 0x0028, "Rage 128 AIW Pro AGP(0x1002-0x0028)"},
{0x1002, 0x5446, 0x1002, 0x0029, "Rage 128 AIW(0x1002-0x0029)"},
{0x1002, 0x5446, 0x1002, 0x002A, "Rage 128 AIW Pro AGP(0x1002-0x002A)"},
{0x1002, 0x5446, 0x1002, 0x002B, "Rage 128 AIW(0x1002-0x002B)"},
{0x1002, 0x5446, 0x1002, 0x0048, "Xpert 2000 Pro(0x1002-0x0048)"},
{0x1002, 0x5452, 0xFFFF, 0xFFFF, "Rage 128 PRO Ultra4XL VR-R AGP(0x5452)"},
{0x1002, 0x5452, 0x1002, 0x001C, "Rage 128 Pro 4XL(0x1002-0x001C)"},
{0x1002, 0x5452, 0x103C, 0x1279, "Rage 128 Pro 4XL(0x103C-0x1279)"},
{0x1002, 0x5460, 0xFFFF, 0xFFFF, "RV370/M22 [Mobility Radeon X300](0x5460)"},
{0x1002, 0x5460, 0x1775, 0x1100, "CR11/VR11 Single Board Computer(0x1775-0x1100)"},
{0x1002, 0x5461, 0xFFFF, 0xFFFF, "RV370/M22 [Mobility Radeon X300](0x5461)"},
{0x1002, 0x5462, 0xFFFF, 0xFFFF, "RV380/M24C [Mobility Radeon X600 SE](0x5462)"},
{0x1002, 0x5464, 0xFFFF, 0xFFFF, "RV370/M22 GL [Mobility FireGL V3100](0x5464)"},
{0x1002, 0x5549, 0xFFFF, 0xFFFF, "R423 [Radeon X800 GTO](0x5549)"},
{0x1002, 0x554A, 0xFFFF, 0xFFFF, "R423 [Radeon X800 XT Platinum Edition](0x554A)"},
{0x1002, 0x554B, 0xFFFF, 0xFFFF, "R423 [Radeon X800 GT/SE](0x554B)"},
{0x1002, 0x554B, 0x1002, 0x0302, "Radeon X800 SE(0x1002-0x0302)"},
{0x1002, 0x554D, 0xFFFF, 0xFFFF, "R480 [Radeon X800 GTO2/XL](0x554D)"},
{0x1002, 0x554D, 0x1002, 0x0322, "All-In-Wonder X800 XL(0x1002-0x0322)"},
{0x1002, 0x554D, 0x1458, 0x2124, "GV-R80L256V-B (AGP)(0x1458-0x2124)"},
{0x1002, 0x554E, 0xFFFF, 0xFFFF, "R430 [All-In-Wonder X800 GT](0x554E)"},
{0x1002, 0x554F, 0xFFFF, 0xFFFF, "R430 [Radeon X800](0x554F)"},
{0x1002, 0x5550, 0xFFFF, 0xFFFF, "R423 GL [FireGL V7100](0x5550)"},
{0x1002, 0x5551, 0xFFFF, 0xFFFF, "R423 GL [FireGL V5100](0x5551)"},
{0x1002, 0x5569, 0xFFFF, 0xFFFF, "R423 [Radeon X800 PRO] (Secondary)(0x5569)"},
{0x1002, 0x556B, 0xFFFF, 0xFFFF, "R423 [Radeon X800 GT] (Secondary)(0x556B)"},
{0x1002, 0x556D, 0xFFFF, 0xFFFF, "R480 [Radeon X800 GTO2/XL] (Secondary)(0x556D)"},
{0x1002, 0x556D, 0x1458, 0x2125, "GV-R80L256V-B (AGP)(0x1458-0x2125)"},
{0x1002, 0x556F, 0xFFFF, 0xFFFF, "R430 [Radeon X800] (Secondary)(0x556F)"},
{0x1002, 0x5571, 0xFFFF, 0xFFFF, "R423 GL [FireGL V5100] (Secondary)(0x5571)"},
{0x1002, 0x564B, 0xFFFF, 0xFFFF, "RV410/M26 GL [Mobility FireGL V5000](0x564B)"},
{0x1002, 0x564F, 0xFFFF, 0xFFFF, "RV410/M26 [Mobility Radeon X700 XL](0x564F)"},
{0x1002, 0x5652, 0xFFFF, 0xFFFF, "RV410/M26 [Mobility Radeon X700](0x5652)"},
{0x1002, 0x5653, 0xFFFF, 0xFFFF, "RV410/M26 [Mobility Radeon X700](0x5653)"},
{0x1002, 0x5653, 0x1025, 0x0080, "Aspire 5024WLMi(0x1025-0x0080)"},
{0x1002, 0x5653, 0x103C, 0x0940, "Compaq NW8240 Mobile Workstation(0x103C-0x0940)"},
{0x1002, 0x5654, 0xFFFF, 0xFFFF, "Mach64 VT [Video Xpression](0x5654)"},
{0x1002, 0x5654, 0x1002, 0x5654, "Mach64VT Reference(0x1002-0x5654)"},
{0x1002, 0x5655, 0xFFFF, 0xFFFF, "264VT3 [Mach64 VT3](0x5655)"},
{0x1002, 0x5656, 0xFFFF, 0xFFFF, "Mach64 VT4 [Video Xpression+](0x5656)"},
{0x1002, 0x5657, 0xFFFF, 0xFFFF, "RV410 [Radeon X550 XTX / X700](0x5657)"},
{0x1002, 0x5830, 0xFFFF, 0xFFFF, "RS300 Host Bridge(0x5830)"},
{0x1002, 0x5831, 0xFFFF, 0xFFFF, "RS300 Host Bridge(0x5831)"},
{0x1002, 0x5832, 0xFFFF, 0xFFFF, "RS300 Host Bridge(0x5832)"},
{0x1002, 0x5833, 0xFFFF, 0xFFFF, "RS300 Host Bridge(0x5833)"},
{0x1002, 0x5834, 0xFFFF, 0xFFFF, "RS300 [Radeon 9100 IGP](0x5834)"},
{0x1002, 0x5835, 0xFFFF, 0xFFFF, "RS300M [Mobility Radeon 9100 IGP](0x5835)"},
{0x1002, 0x5838, 0xFFFF, 0xFFFF, "RS300 AGP Bridge(0x5838)"},
{0x1002, 0x5854, 0xFFFF, 0xFFFF, "RS480 [Radeon Xpress 200 Series] (Secondary)(0x5854)"},
{0x1002, 0x5874, 0xFFFF, 0xFFFF, "RS480 [Radeon Xpress 1150] (Secondary)(0x5874)"},
{0x1002, 0x5940, 0xFFFF, 0xFFFF, "RV280 [Radeon 9200 PRO] (Secondary)(0x5940)"},
{0x1002, 0x5940, 0x17AF, 0x2021, "Excalibur Radeon 9250 (Secondary)(0x17AF-0x2021)"},
{0x1002, 0x5941, 0xFFFF, 0xFFFF, "RV280 [Radeon 9200] (Secondary)(0x5941)"},
{0x1002, 0x5941, 0x1458, 0x4019, "Radeon 9200(0x1458-0x4019)"},
{0x1002, 0x5941, 0x174B, 0x7C12, "Radeon 9200(0x174B-0x7C12)"},
{0x1002, 0x5941, 0x17AF, 0x200D, "Excalibur Radeon 9200(0x17AF-0x200D)"},
{0x1002, 0x5941, 0x18BC, 0x0050, "GC-R9200-C3 (Secondary)(0x18BC-0x0050)"},
{0x1002, 0x5944, 0xFFFF, 0xFFFF, "RV280 [Radeon 9200 SE PCI](0x5944)"},
{0x1002, 0x5950, 0xFFFF, 0xFFFF, "RS480/RS482/RS485 Host Bridge(0x5950)"},
{0x1002, 0x5950, 0x1025, 0x0080, "Aspire 5024WLMMi(0x1025-0x0080)"},
{0x1002, 0x5950, 0x103C, 0x280A, "DC5750 Microtower(0x103C-0x280A)"},
{0x1002, 0x5950, 0x103C, 0x2A20, "Pavilion t3030.de Desktop PC(0x103C-0x2A20)"},
{0x1002, 0x5950, 0x103C, 0x308B, "MX6125(0x103C-0x308B)"},
{0x1002, 0x5950, 0x1462, 0x0131, "MS-1013 Notebook(0x1462-0x0131)"},
{0x1002, 0x5950, 0x1462, 0x7217, "Aspire L250(0x1462-0x7217)"},
{0x1002, 0x5951, 0xFFFF, 0xFFFF, "RX480/RX482 Host Bridge(0x5951)"},
{0x1002, 0x5952, 0xFFFF, 0xFFFF, "RD580 Host Bridge(0x5952)"},
{0x1002, 0x5954, 0xFFFF, 0xFFFF, "RS480 [Radeon Xpress 200 Series](0x5954)"},
{0x1002, 0x5954, 0x1002, 0x5954, "RV370 [Radeon Xpress 200G Series](0x1002-0x5954)"},
{0x1002, 0x5955, 0xFFFF, 0xFFFF, "RS480M [Mobility Radeon Xpress 200](0x5955)"},
{0x1002, 0x5955, 0x1002, 0x5955, "RS480 0x5955 [Radeon XPRESS 200M 5955 (PCIE)](0x1002-0x5955)"},
{0x1002, 0x5955, 0x103C, 0x308B, "MX6125(0x103C-0x308B)"},
{0x1002, 0x5955, 0x1462, 0x0131, "MS-1013 Notebook(0x1462-0x0131)"},
{0x1002, 0x5956, 0xFFFF, 0xFFFF, "RD790 Host Bridge(0x5956)"},
{0x1002, 0x5957, 0xFFFF, 0xFFFF, "RX780/RX790 Host Bridge(0x5957)"},
{0x1002, 0x5957, 0x1849, 0x5957, "A770CrossFire Motherboard(0x1849-0x5957)"},
{0x1002, 0x5958, 0xFFFF, 0xFFFF, "RD780 Host Bridge(0x5958)"},
{0x1002, 0x5960, 0xFFFF, 0xFFFF, "RV280 [Radeon 9200 PRO / 9250](0x5960)"},
{0x1002, 0x5960, 0x17AF, 0x2020, "Excalibur Radeon 9250(0x17AF-0x2020)"},
{0x1002, 0x5961, 0xFFFF, 0xFFFF, "RV280 [Radeon 9200](0x5961)"},
{0x1002, 0x5961, 0x1002, 0x2F72, "All-in-Wonder 9200 Series(0x1002-0x2F72)"},
{0x1002, 0x5961, 0x1019, 0x4C30, "Radeon 9200 VIVO(0x1019-0x4C30)"},
{0x1002, 0x5961, 0x12AB, 0x5961, "YUAN SMARTVGA Radeon 9200(0x12AB-0x5961)"},
{0x1002, 0x5961, 0x1458, 0x4018, "Radeon 9200(0x1458-0x4018)"},
{0x1002, 0x5961, 0x174B, 0x7C13, "Radeon 9200(0x174B-0x7C13)"},
{0x1002, 0x5961, 0x17AF, 0x200C, "Excalibur Radeon 9200(0x17AF-0x200C)"},
{0x1002, 0x5961, 0x18BC, 0x0050, "Radeon 9200 Game Buster(0x18BC-0x0050)"},
{0x1002, 0x5961, 0x18BC, 0x0051, "GC-R9200-C3(0x18BC-0x0051)"},
{0x1002, 0x5961, 0x18BC, 0x0053, "Radeon 9200 Game Buster VIVO(0x18BC-0x0053)"},
{0x1002, 0x5962, 0xFFFF, 0xFFFF, "RV280 [Radeon 9200](0x5962)"},
{0x1002, 0x5964, 0xFFFF, 0xFFFF, "RV280 [Radeon 9200 SE](0x5964)"},
{0x1002, 0x5964, 0x1002, 0x5964, "Radeon 9200 SE, 64-bit 128MB DDR, 200/166MHz(0x1002-0x5964)"},
{0x1002, 0x5964, 0x1043, 0xC006, "Radeon 9200 SE / TD / 128M(0x1043-0xC006)"},
{0x1002, 0x5964, 0x1458, 0x4018, "R92S128T [Radeon 9200 SE 128MB](0x1458-0x4018)"},
{0x1002, 0x5964, 0x1458, 0x4032, "Radeon 9200 SE 128MB(0x1458-0x4032)"},
{0x1002, 0x5964, 0x147B, 0x6191, "R9200SE-DT(0x147B-0x6191)"},
{0x1002, 0x5964, 0x148C, 0x2073, "CN-AG92E(0x148C-0x2073)"},
{0x1002, 0x5964, 0x174B, 0x7C13, "Radeon 9200 SE(0x174B-0x7C13)"},
{0x1002, 0x5964, 0x1787, 0x5964, "Excalibur 9200SE VIVO 128M(0x1787-0x5964)"},
{0x1002, 0x5964, 0x17AF, 0x2012, "Radeon 9200 SE Excalibur(0x17AF-0x2012)"},
{0x1002, 0x5964, 0x18BC, 0x0170, "Sapphire Radeon 9200 SE 128MB Game Buster(0x18BC-0x0170)"},
{0x1002, 0x5964, 0x18BC, 0x0173, "GC-R9200L(SE)-C3H [Radeon 9200 Game Buster](0x18BC-0x0173)"},
{0x1002, 0x5965, 0xFFFF, 0xFFFF, "RV280 GL [FireMV 2200 PCI](0x5965)"},
{0x1002, 0x5974, 0xFFFF, 0xFFFF, "RS482/RS485 [Radeon Xpress 1100/1150](0x5974)"},
{0x1002, 0x5974, 0x103C, 0x280A, "DC5750 Microtower(0x103C-0x280A)"},
{0x1002, 0x5974, 0x1462, 0x7141, "Aspire L250(0x1462-0x7141)"},
{0x1002, 0x5975, 0xFFFF, 0xFFFF, "RS482M [Mobility Radeon Xpress 200](0x5975)"},
{0x1002, 0x5978, 0xFFFF, 0xFFFF, "RX780/RD790 PCI to PCI bridge (external gfx0 port A)(0x5978)"},
{0x1002, 0x5978, 0x1849, 0x5957, "A770CrossFire Motherboard(0x1849-0x5957)"},
{0x1002, 0x5979, 0xFFFF, 0xFFFF, "RD790 PCI to PCI bridge (external gfx0 port B)(0x5979)"},
{0x1002, 0x597A, 0xFFFF, 0xFFFF, "RD790 PCI to PCI bridge (PCI express gpp port A)(0x597A)"},
{0x1002, 0x597B, 0xFFFF, 0xFFFF, "RX780/RD790 PCI to PCI bridge (PCI express gpp port B)(0x597B)"},
{0x1002, 0x597C, 0xFFFF, 0xFFFF, "RD790 PCI to PCI bridge (PCI express gpp port C)(0x597C)"},
{0x1002, 0x597D, 0xFFFF, 0xFFFF, "RX780/RD790 PCI to PCI bridge (PCI express gpp port D)(0x597D)"},
{0x1002, 0x597E, 0xFFFF, 0xFFFF, "RD790 PCI to PCI bridge (PCI express gpp port E)(0x597E)"},
{0x1002, 0x597E, 0x1849, 0x5957, "A770CrossFire Motherboard(0x1849-0x5957)"},
{0x1002, 0x597F, 0xFFFF, 0xFFFF, "RD790 PCI to PCI bridge (PCI express gpp port F)(0x597F)"},
{0x1002, 0x597F, 0x1849, 0x5957, "A770CrossFire Motherboard(0x1849-0x5957)"},
{0x1002, 0x5980, 0xFFFF, 0xFFFF, "RD790 PCI to PCI bridge (external gfx1 port A)(0x5980)"},
{0x1002, 0x5981, 0xFFFF, 0xFFFF, "RD790 PCI to PCI bridge (external gfx1 port B)(0x5981)"},
{0x1002, 0x5982, 0xFFFF, 0xFFFF, "RD790 PCI to PCI bridge (NB-SB link)(0x5982)"},
{0x1002, 0x5A10, 0xFFFF, 0xFFFF, "RD890 Northbridge only dual slot (2x16) PCI-e GFX Hydra part(0x5A10)"},
{0x1002, 0x5A11, 0xFFFF, 0xFFFF, "RD890 Northbridge only single slot PCI-e GFX Hydra part(0x5A11)"},
{0x1002, 0x5A12, 0xFFFF, 0xFFFF, "RD890 Northbridge only dual slot (2x8) PCI-e GFX Hydra part(0x5A12)"},
{0x1002, 0x5A12, 0x15D9, 0xA811, "H8DGU(0x15D9-0xA811)"},
{0x1002, 0x5A13, 0xFFFF, 0xFFFF, "RD890S/SR5650 Host Bridge(0x5A13)"},
{0x1002, 0x5A14, 0xFFFF, 0xFFFF, "RD9x0/RX980 Host Bridge(0x5A14)"},
{0x1002, 0x5A15, 0xFFFF, 0xFFFF, "RD890 PCI to PCI bridge (PCI express gpp port A)(0x5A15)"},
{0x1002, 0x5A16, 0xFFFF, 0xFFFF, "RD890/RD9x0/RX980 PCI to PCI bridge (PCI Express GFX port 0)(0x5A16)"},
{0x1002, 0x5A17, 0xFFFF, 0xFFFF, "RD890/RD9x0 PCI to PCI bridge (PCI Express GFX port 1)(0x5A17)"},
{0x1002, 0x5A18, 0xFFFF, 0xFFFF, "RD890/RD9x0/RX980 PCI to PCI bridge (PCI Express GPP Port 0)(0x5A18)"},
{0x1002, 0x5A18, 0x15D9, 0xA811, "H8DGU(0x15D9-0xA811)"},
{0x1002, 0x5A19, 0xFFFF, 0xFFFF, "RD890/RD9x0/RX980 PCI to PCI bridge (PCI Express GPP Port 1)(0x5A19)"},
{0x1002, 0x5A1A, 0xFFFF, 0xFFFF, "RD890/RD9x0/RX980 PCI to PCI bridge (PCI Express GPP Port 2)(0x5A1A)"},
{0x1002, 0x5A1B, 0xFFFF, 0xFFFF, "RD890/RD9x0/RX980 PCI to PCI bridge (PCI Express GPP Port 3)(0x5A1B)"},
{0x1002, 0x5A1C, 0xFFFF, 0xFFFF, "RD890/RD9x0/RX980 PCI to PCI bridge (PCI Express GPP Port 4)(0x5A1C)"},
{0x1002, 0x5A1D, 0xFFFF, 0xFFFF, "RD890/RD9x0/RX980 PCI to PCI bridge (PCI Express GPP Port 5)(0x5A1D)"},
{0x1002, 0x5A1E, 0xFFFF, 0xFFFF, "RD890/RD9x0/RX980 PCI to PCI bridge (PCI Express GPP2 Port 0)(0x5A1E)"},
{0x1002, 0x5A1F, 0xFFFF, 0xFFFF, "RD890/RD990 PCI to PCI bridge (PCI Express GFX2 port 0)(0x5A1F)"},
{0x1002, 0x5A1F, 0x15D9, 0xA811, "H8DGU(0x15D9-0xA811)"},
{0x1002, 0x5A20, 0xFFFF, 0xFFFF, "RD890/RD990 PCI to PCI bridge (PCI Express GFX2 port 1)(0x5A20)"},
{0x1002, 0x5A23, 0xFFFF, 0xFFFF, "RD890S/RD990 I/O Memory Management Unit (IOMMU)(0x5A23)"},
{0x1002, 0x5A31, 0xFFFF, 0xFFFF, "RC410 Host Bridge(0x5A31)"},
{0x1002, 0x5A33, 0xFFFF, 0xFFFF, "RS400 Host Bridge(0x5A33)"},
{0x1002, 0x5A34, 0xFFFF, 0xFFFF, "RS4xx PCI Express Port [ext gfx](0x5A34)"},
{0x1002, 0x5A36, 0xFFFF, 0xFFFF, "RC4xx/RS4xx PCI Express Port 1(0x5A36)"},
{0x1002, 0x5A37, 0xFFFF, 0xFFFF, "RC4xx/RS4xx PCI Express Port 2(0x5A37)"},
{0x1002, 0x5A38, 0xFFFF, 0xFFFF, "RC4xx/RS4xx PCI Express Port 3(0x5A38)"},
{0x1002, 0x5A39, 0xFFFF, 0xFFFF, "RC4xx/RS4xx PCI Express Port 4(0x5A39)"},
{0x1002, 0x5A3F, 0xFFFF, 0xFFFF, "RC4xx/RS4xx PCI Bridge [int gfx](0x5A3F)"},
{0x1002, 0x5A3F, 0x1462, 0x7217, "Aspire L250(0x1462-0x7217)"},
{0x1002, 0x5A41, 0xFFFF, 0xFFFF, "RS400 [Radeon Xpress 200](0x5A41)"},
{0x1002, 0x5A42, 0xFFFF, 0xFFFF, "RS400M [Radeon Xpress 200M](0x5A42)"},
{0x1002, 0x5A61, 0xFFFF, 0xFFFF, "RC410 [Radeon Xpress 200/1100](0x5A61)"},
{0x1002, 0x5A62, 0xFFFF, 0xFFFF, "RC410M [Mobility Radeon Xpress 200M](0x5A62)"},
{0x1002, 0x5B60, 0xFFFF, 0xFFFF, "RV370 [Radeon X300](0x5B60)"},
{0x1002, 0x5B60, 0x1043, 0x002A, "Extreme AX300SE-X(0x1043-0x002A)"},
{0x1002, 0x5B60, 0x1043, 0x032E, "Extreme AX300/TD(0x1043-0x032E)"},
{0x1002, 0x5B60, 0x1458, 0x2102, "GV-RX30S128D (X300SE)(0x1458-0x2102)"},
{0x1002, 0x5B60, 0x1462, 0x0400, "RX300SE-TD128E (MS-8940 REV:200)(0x1462-0x0400)"},
{0x1002, 0x5B60, 0x1462, 0x0402, "RX300SE-TD128E (MS-8940)(0x1462-0x0402)"},
{0x1002, 0x5B60, 0x174B, 0x0500, "Radeon X300 (PCIE)(0x174B-0x0500)"},
{0x1002, 0x5B60, 0x196D, 0x1086, "X300SE HM(0x196D-0x1086)"},
{0x1002, 0x5B62, 0xFFFF, 0xFFFF, "RV370 [Radeon X600/X600 SE](0x5B62)"},
{0x1002, 0x5B63, 0xFFFF, 0xFFFF, "RV370 [Radeon X300/X550/X1050 Series](0x5B63)"},
{0x1002, 0x5B64, 0xFFFF, 0xFFFF, "RV370 GL [FireGL V3100](0x5B64)"},
{0x1002, 0x5B65, 0xFFFF, 0xFFFF, "RV370 GL [FireMV 2200](0x5B65)"},
{0x1002, 0x5B66, 0xFFFF, 0xFFFF, "RV370X(0x5B66)"},
{0x1002, 0x5B70, 0xFFFF, 0xFFFF, "RV370 [Radeon X300 SE](0x5B70)"},
{0x1002, 0x5B70, 0x1462, 0x0403, "Radeon X300 SE 128MB DDR(0x1462-0x0403)"},
{0x1002, 0x5B70, 0x174B, 0x0501, "Radeon X300 SE(0x174B-0x0501)"},
{0x1002, 0x5B70, 0x196D, 0x1087, "Radeon X300 SE HyperMemory(0x196D-0x1087)"},
{0x1002, 0x5B72, 0xFFFF, 0xFFFF, "RV380 [Radeon X300/X550/X1050 Series] (Secondary)(0x5B72)"},
{0x1002, 0x5B73, 0xFFFF, 0xFFFF, "RV370 [Radeon X300/X550/X1050 Series] (Secondary)(0x5B73)"},
{0x1002, 0x5B74, 0xFFFF, 0xFFFF, "RV370 GL [FireGL V3100] (Secondary)(0x5B74)"},
{0x1002, 0x5B75, 0xFFFF, 0xFFFF, "RV370 GL [FireMV 2200] (Secondary)(0x5B75)"},
{0x1002, 0x5C61, 0xFFFF, 0xFFFF, "RV280/M9+ [Mobility Radeon 9200 AGP](0x5C61)"},
{0x1002, 0x5C63, 0xFFFF, 0xFFFF, "RV280/M9+ [Mobility Radeon 9200 AGP](0x5C63)"},
{0x1002, 0x5C63, 0x1002, 0x5C63, "Apple iBook G4 2004(0x1002-0x5C63)"},
{0x1002, 0x5C63, 0x144D, 0xC00C, "P30 notebook(0x144D-0xC00C)"},
{0x1002, 0x5D44, 0xFFFF, 0xFFFF, "RV280 [Radeon 9200 SE] (Secondary)(0x5D44)"},
{0x1002, 0x5D44, 0x1458, 0x4019, "R92S128T (Radeon 9200 SE 128MB Secondary)(0x1458-0x4019)"},
{0x1002, 0x5D44, 0x1458, 0x4032, "Radeon 9200 SE 128MB(0x1458-0x4032)"},
{0x1002, 0x5D44, 0x147B, 0x6190, "R9200SE-DT (Secondary)(0x147B-0x6190)"},
{0x1002, 0x5D44, 0x174B, 0x7C12, "Radeon 9200 SE (Secondary)(0x174B-0x7C12)"},
{0x1002, 0x5D44, 0x1787, 0x5965, "Excalibur 9200SE VIVO 128M (Secondary)(0x1787-0x5965)"},
{0x1002, 0x5D44, 0x17AF, 0x2013, "Radeon 9200 SE Excalibur (Secondary)(0x17AF-0x2013)"},
{0x1002, 0x5D44, 0x18BC, 0x0171, "Radeon 9200 SE 128MB Game Buster (Secondary)(0x18BC-0x0171)"},
{0x1002, 0x5D44, 0x18BC, 0x0172, "GC-R9200L(SE)-C3H [Radeon 9200 Game Buster](0x18BC-0x0172)"},
{0x1002, 0x5D45, 0xFFFF, 0xFFFF, "RV280 GL [FireMV 2200 PCI] (Secondary)(0x5D45)"},
{0x1002, 0x5D48, 0xFFFF, 0xFFFF, "R423/M28 [Mobility Radeon X800 XT](0x5D48)"},
{0x1002, 0x5D49, 0xFFFF, 0xFFFF, "R423/M28 GL [Mobility FireGL V5100](0x5D49)"},
{0x1002, 0x5D4A, 0xFFFF, 0xFFFF, "R423/M28 [Mobility Radeon X800](0x5D4A)"},
{0x1002, 0x5D4D, 0xFFFF, 0xFFFF, "R480 [Radeon X850 XT Platinum Edition](0x5D4D)"},
{0x1002, 0x5D4E, 0xFFFF, 0xFFFF, "R480 [Radeon X850 SE](0x5D4E)"},
{0x1002, 0x5D4F, 0xFFFF, 0xFFFF, "R480 [Radeon X800 GTO](0x5D4F)"},
{0x1002, 0x5D50, 0xFFFF, 0xFFFF, "R480 GL [FireGL V7200](0x5D50)"},
{0x1002, 0x5D52, 0xFFFF, 0xFFFF, "R480 [Radeon X850 XT](0x5D52)"},
{0x1002, 0x5D52, 0x1002, 0x0B12, "PowerColor X850XT PCIe (Primary)(0x1002-0x0B12)"},
{0x1002, 0x5D57, 0xFFFF, 0xFFFF, "R423 [Radeon X800 XT](0x5D57)"},
{0x1002, 0x5D6D, 0xFFFF, 0xFFFF, "R480 [Radeon X850 XT Platinum Edition] (Secondary)(0x5D6D)"},
{0x1002, 0x5D6F, 0xFFFF, 0xFFFF, "R480 [Radeon X800 GTO] (Secondary)(0x5D6F)"},
{0x1002, 0x5D72, 0xFFFF, 0xFFFF, "R480 [Radeon X850 XT] (Secondary)(0x5D72)"},
{0x1002, 0x5D72, 0x1002, 0x0B13, "PowerColor X850XT PCIe (Secondary)(0x1002-0x0B13)"},
{0x1002, 0x5D77, 0xFFFF, 0xFFFF, "R423 [Radeon X800 XT] (Secondary)(0x5D77)"},
{0x1002, 0x5E48, 0xFFFF, 0xFFFF, "RV410 GL [FireGL V5000](0x5E48)"},
{0x1002, 0x5E49, 0xFFFF, 0xFFFF, "RV410 [Radeon X700 Series](0x5E49)"},
{0x1002, 0x5E4A, 0xFFFF, 0xFFFF, "RV410 [Radeon X700 XT](0x5E4A)"},
{0x1002, 0x5E4B, 0xFFFF, 0xFFFF, "RV410 [Radeon X700 PRO](0x5E4B)"},
{0x1002, 0x5E4C, 0xFFFF, 0xFFFF, "RV410 [Radeon X700 SE](0x5E4C)"},
{0x1002, 0x5E4D, 0xFFFF, 0xFFFF, "RV410 [Radeon X700](0x5E4D)"},
{0x1002, 0x5E4D, 0x148C, 0x2116, "Bravo X700(0x148C-0x2116)"},
{0x1002, 0x5E4F, 0xFFFF, 0xFFFF, "RV410 [Radeon X700](0x5E4F)"},
{0x1002, 0x5E4F, 0x1569, 0x1E4F, "Radeon X550 XT(0x1569-0x1E4F)"},
{0x1002, 0x5E6B, 0xFFFF, 0xFFFF, "RV410 [Radeon X700 PRO] (Secondary)(0x5E6B)"},
{0x1002, 0x5E6D, 0xFFFF, 0xFFFF, "RV410 [Radeon X700] (Secondary)(0x5E6D)"},
{0x1002, 0x5E6D, 0x148C, 0x2117, "Bravo X700 (Secondary)(0x148C-0x2117)"},
{0x1002, 0x5F57, 0xFFFF, 0xFFFF, "R423 [Radeon X800 XT](0x5F57)"},
{0x1002, 0x6600, 0xFFFF, 0xFFFF, "Mars [Radeon HD 8670A/8670M/8750M / R7 M370](0x6600)"},
{0x1002, 0x6600, 0x103C, 0x1952, "ProBook 455 G1(0x103C-0x1952)"},
{0x1002, 0x6601, 0xFFFF, 0xFFFF, "Mars [Radeon HD 8730M](0x6601)"},
{0x1002, 0x6601, 0x103C, 0x2100, "FirePro M4100(0x103C-0x2100)"},
{0x1002, 0x6604, 0xFFFF, 0xFFFF, "Opal XT [Radeon R7 M265/M365X/M465](0x6604)"},
{0x1002, 0x6604, 0x1025, 0x0776, "Aspire V5 Radeon R7 M265(0x1025-0x0776)"},
{0x1002, 0x6604, 0x103C, 0x8006, "FirePro M4170(0x103C-0x8006)"},
{0x1002, 0x6604, 0x103C, 0x814F, "Litho XT [Radeon R7 M365X](0x103C-0x814F)"},
{0x1002, 0x6604, 0x103C, 0x82AA, "Litho XT [Radeon R7 M465](0x103C-0x82AA)"},
{0x1002, 0x6604, 0x17AA, 0x3643, "Radeon R7 A360(0x17AA-0x3643)"},
{0x1002, 0x6605, 0xFFFF, 0xFFFF, "Opal PRO [Radeon R7 M260X](0x6605)"},
{0x1002, 0x6605, 0x103C, 0x2259, "FirePro M4150(0x103C-0x2259)"},
{0x1002, 0x6606, 0xFFFF, 0xFFFF, "Mars XTX [Radeon HD 8790M](0x6606)"},
{0x1002, 0x6606, 0x1028, 0x0684, "FirePro W4170M(0x1028-0x0684)"},
{0x1002, 0x6607, 0xFFFF, 0xFFFF, "Mars LE [Radeon HD 8530M / R5 M240](0x6607)"},
{0x1002, 0x6608, 0xFFFF, 0xFFFF, "Oland GL [FirePro W2100](0x6608)"},
{0x1002, 0x6608, 0x13CC, 0x3D28, "MXRT-2600(0x13CC-0x3D28)"},
{0x1002, 0x6609, 0xFFFF, 0xFFFF, "Oland GL [FirePro W2100 / Barco MXRT 2600](0x6609)"},
{0x1002, 0x6610, 0xFFFF, 0xFFFF, "Oland XT [Radeon HD 8670 / R5 340X OEM / R7 250/350/350X OEM](0x6610)"},
{0x1002, 0x6610, 0x1019, 0x0030, "Radeon HD 8670(0x1019-0x0030)"},
{0x1002, 0x6610, 0x1028, 0x0081, "Radeon R7 350X OEM(0x1028-0x0081)"},
{0x1002, 0x6610, 0x1028, 0x0083, "Radeon R5 340X OEM(0x1028-0x0083)"},
{0x1002, 0x6610, 0x1028, 0x2120, "Radeon R7 250(0x1028-0x2120)"},
{0x1002, 0x6610, 0x1028, 0x2322, "Radeon R7 250(0x1028-0x2322)"},
{0x1002, 0x6610, 0x1462, 0x2910, "Radeon HD 8670(0x1462-0x2910)"},
{0x1002, 0x6610, 0x1462, 0x2911, "Radeon HD 8670(0x1462-0x2911)"},
{0x1002, 0x6610, 0x148C, 0x7350, "Radeon R7 350(0x148C-0x7350)"},
{0x1002, 0x6610, 0x1642, 0x3C81, "Radeon HD 8670(0x1642-0x3C81)"},
{0x1002, 0x6610, 0x1642, 0x3C91, "Radeon HD 8670(0x1642-0x3C91)"},
{0x1002, 0x6610, 0x1642, 0x3F09, "Radeon R7 350(0x1642-0x3F09)"},
{0x1002, 0x6611, 0xFFFF, 0xFFFF, "Oland [Radeon HD 8570 / R5 430 OEM / R7 240/340 / Radeon 520 OEM](0x6611)"},
{0x1002, 0x6611, 0x1028, 0x1001, "Radeon R5 430 OEM (1024 MByte)(0x1028-0x1001)"},
{0x1002, 0x6611, 0x1028, 0x1002, "Radeon R5 430 OEM (2048 MByte)(0x1028-0x1002)"},
{0x1002, 0x6611, 0x1028, 0x1711, "R5 430 OEM (2048 MByte)(0x1028-0x1711)"},
{0x1002, 0x6611, 0x1028, 0x210B, "Radeon R5 240 OEM(0x1028-0x210B)"},
{0x1002, 0x6611, 0x1028, 0x2121, "Radeon HD 8570 OEM(0x1028-0x2121)"},
{0x1002, 0x6611, 0x10CF, 0x1889, "Radeon HD 8570 OEM(0x10CF-0x1889)"},
{0x1002, 0x6611, 0x1642, 0x1869, "Radeon 520 OEM(0x1642-0x1869)"},
{0x1002, 0x6611, 0x174B, 0x4248, "Radeon R7 240 OEM(0x174B-0x4248)"},
{0x1002, 0x6611, 0x174B, 0xA240, "Radeon R7 240 OEM(0x174B-0xA240)"},
{0x1002, 0x6611, 0x174B, 0xD340, "Radeon R7 340 OEM(0x174B-0xD340)"},
{0x1002, 0x6611, 0x1B0A, 0x90D3, "Radeon R7 240 OEM(0x1B0A-0x90D3)"},
{0x1002, 0x6613, 0xFFFF, 0xFFFF, "Oland PRO [Radeon R7 240/340 / Radeon 520](0x6613)"},
{0x1002, 0x6613, 0x148C, 0x7340, "Radeon R7 340(0x148C-0x7340)"},
{0x1002, 0x6613, 0x1682, 0x7240, "R7 240 2048 MB(0x1682-0x7240)"},
{0x1002, 0x6613, 0x1DCF, 0x3000, "Oland PRO [Radeon R7 240/340 / Radeon 520](0x1DCF-0x3000)"},
{0x1002, 0x6617, 0xFFFF, 0xFFFF, "Oland LE [Radeon R7 240](0x6617)"},
{0x1002, 0x6631, 0xFFFF, 0xFFFF, "Oland(0x6631)"},
{0x1002, 0x6640, 0xFFFF, 0xFFFF, "Saturn XT [FirePro M6100](0x6640)"},
{0x1002, 0x6640, 0x106B, 0x014B, "Tropo XT [Radeon R9 M380 Mac Edition](0x106B-0x014B)"},
{0x1002, 0x6641, 0xFFFF, 0xFFFF, "Saturn PRO [Radeon HD 8930M](0x6641)"},
{0x1002, 0x6646, 0xFFFF, 0xFFFF, "Bonaire XT [Radeon R9 M280X / FirePro W6150M](0x6646)"},
{0x1002, 0x6647, 0xFFFF, 0xFFFF, "Saturn PRO/XT [Radeon R9 M270X/M280X](0x6647)"},
{0x1002, 0x6647, 0x1043, 0x223D, "N551ZU laptop Radeon R9 M280X(0x1043-0x223D)"},
{0x1002, 0x6649, 0xFFFF, 0xFFFF, "Bonaire [FirePro W5100](0x6649)"},
{0x1002, 0x6649, 0x1002, 0x0B0C, "FirePro W4300(0x1002-0x0B0C)"},
{0x1002, 0x6649, 0x103C, 0x0B0C, "Bonaire [FirePro W4300](0x103C-0x0B0C)"},
{0x1002, 0x6649, 0x103C, 0x230C, "FirePro W5100(0x103C-0x230C)"},
{0x1002, 0x6649, 0x13CC, 0x3D2A, "MXRT-5600(0x13CC-0x3D2A)"},
{0x1002, 0x664D, 0xFFFF, 0xFFFF, "Bonaire [FirePro W5100 / Barco MXRT-5600](0x664D)"},
{0x1002, 0x6650, 0xFFFF, 0xFFFF, "Bonaire(0x6650)"},
{0x1002, 0x6651, 0xFFFF, 0xFFFF, "Bonaire(0x6651)"},
{0x1002, 0x6658, 0xFFFF, 0xFFFF, "Bonaire XTX [Radeon R7 260X/360](0x6658)"},
{0x1002, 0x6658, 0x1043, 0x048F, "R7260X-DC2OC-2GD5(0x1043-0x048F)"},
{0x1002, 0x6658, 0x1043, 0x04D3, "AMD Radeon R7 260X(0x1043-0x04D3)"},
{0x1002, 0x6658, 0x1458, 0x227B, "Radeon R7 260X(0x1458-0x227B)"},
{0x1002, 0x6658, 0x148C, 0x0907, "Radeon R7 360(0x148C-0x0907)"},
{0x1002, 0x6658, 0x1682, 0x0907, "Radeon R7 360(0x1682-0x0907)"},
{0x1002, 0x6658, 0x1682, 0x7360, "Radeon R7 360(0x1682-0x7360)"},
{0x1002, 0x665C, 0xFFFF, 0xFFFF, "Bonaire XT [Radeon HD 7790/8770 / R7 360 / R9 260/360 OEM](0x665C)"},
{0x1002, 0x665C, 0x1043, 0x0452, "Radeon HD 7790 DirectCU II OC(0x1043-0x0452)"},
{0x1002, 0x665C, 0x1462, 0x2930, "Radeon HD 7790 OC(0x1462-0x2930)"},
{0x1002, 0x665C, 0x1462, 0x2932, "Radeon HD 8770(0x1462-0x2932)"},
{0x1002, 0x665C, 0x1462, 0x2934, "Radeon R9 260 OEM(0x1462-0x2934)"},
{0x1002, 0x665C, 0x1462, 0x2938, "Radeon R9 360 OEM(0x1462-0x2938)"},
{0x1002, 0x665C, 0x148C, 0x0907, "Radeon R7 360(0x148C-0x0907)"},
{0x1002, 0x665C, 0x148C, 0x9260, "Radeon R9 260 OEM(0x148C-0x9260)"},
{0x1002, 0x665C, 0x148C, 0x9360, "Radeon R9 360 OEM(0x148C-0x9360)"},
{0x1002, 0x665C, 0x1682, 0x0907, "Radeon R7 360(0x1682-0x0907)"},
{0x1002, 0x665C, 0x1682, 0x3310, "Radeon HD 7790 Black Edition 2 GB(0x1682-0x3310)"},
{0x1002, 0x665C, 0x174B, 0xE253, "Radeon HD 7790 Dual-X OC(0x174B-0xE253)"},
{0x1002, 0x665C, 0x1787, 0x2329, "Radeon HD 7790 TurboDuo(0x1787-0x2329)"},
{0x1002, 0x665D, 0xFFFF, 0xFFFF, "Bonaire [Radeon R7 200 Series](0x665D)"},
{0x1002, 0x665F, 0xFFFF, 0xFFFF, "Tobago PRO [Radeon R7 360 / R9 360 OEM](0x665F)"},
{0x1002, 0x665F, 0x1028, 0x0B04, "Radeon R9 360 OEM(0x1028-0x0B04)"},
{0x1002, 0x665F, 0x1462, 0x2938, "Radeon R9 360 OEM(0x1462-0x2938)"},
{0x1002, 0x665F, 0x1462, 0x3271, "Radeon R9 360 OEM(0x1462-0x3271)"},
{0x1002, 0x665F, 0x1682, 0x7360, "Radeon R7 360(0x1682-0x7360)"},
{0x1002, 0x6660, 0xFFFF, 0xFFFF, "Sun XT [Radeon HD 8670A/8670M/8690M / R5 M330 / M430 / Radeon 520 Mobile](0x6660)"},
{0x1002, 0x6660, 0x1028, 0x05EA, "Radeon HD 8670M(0x1028-0x05EA)"},
{0x1002, 0x6660, 0x1028, 0x06BF, "Radeon R5 M335(0x1028-0x06BF)"},
{0x1002, 0x6660, 0x103C, 0x1970, "Radeon HD 8670M(0x103C-0x1970)"},
{0x1002, 0x6660, 0x103C, 0x80BE, "Radeon R5 M330(0x103C-0x80BE)"},
{0x1002, 0x6660, 0x103C, 0x8136, "Radeon R5 M330(0x103C-0x8136)"},
{0x1002, 0x6660, 0x103C, 0x8329, "Radeon R7 M520(0x103C-0x8329)"},
{0x1002, 0x6660, 0x17AA, 0x3633, "Radeon R5 A330(0x17AA-0x3633)"},
{0x1002, 0x6660, 0x17AA, 0x3804, "Radeon R5 M330(0x17AA-0x3804)"},
{0x1002, 0x6660, 0x17AA, 0x3809, "Radeon R5 M330(0x17AA-0x3809)"},
{0x1002, 0x6660, 0x17AA, 0x381A, "Radeon R5 M430(0x17AA-0x381A)"},
{0x1002, 0x6660, 0x17AA, 0x390C, "Radeon R5 M330(0x17AA-0x390C)"},
{0x1002, 0x6663, 0xFFFF, 0xFFFF, "Sun PRO [Radeon HD 8570A/8570M](0x6663)"},
{0x1002, 0x6663, 0x1025, 0x0846, "Radeon HD 8570A(0x1025-0x0846)"},
{0x1002, 0x6663, 0x17AA, 0x3805, "Radeon HD 8570M(0x17AA-0x3805)"},
{0x1002, 0x6664, 0xFFFF, 0xFFFF, "Jet XT [Radeon R5 M240](0x6664)"},
{0x1002, 0x6665, 0xFFFF, 0xFFFF, "Jet PRO [Radeon R5 M230 / R7 M260DX / Radeon 520/610 Mobile](0x6665)"},
{0x1002, 0x6665, 0x17AA, 0x1309, "Z50-75 Radeon R7 M260DX(0x17AA-0x1309)"},
{0x1002, 0x6665, 0x17AA, 0x368F, "Radeon R5 A230(0x17AA-0x368F)"},
{0x1002, 0x6667, 0xFFFF, 0xFFFF, "Jet ULT [Radeon R5 M230](0x6667)"},
{0x1002, 0x666F, 0xFFFF, 0xFFFF, "Sun LE [Radeon HD 8550M / R5 M230](0x666F)"},
{0x1002, 0x66A0, 0xFFFF, 0xFFFF, "Vega 20 [Radeon Pro/Radeon Instinct](0x66A0)"},
{0x1002, 0x66A1, 0xFFFF, 0xFFFF, "Vega 20 [Radeon Pro VII/Radeon Instinct MI50 32GB](0x66A1)"},
{0x1002, 0x66A2, 0xFFFF, 0xFFFF, "Vega 20(0x66A2)"},
{0x1002, 0x66A3, 0xFFFF, 0xFFFF, "Vega 20 [Radeon Pro Vega II/Radeon Pro Vega II Duo](0x66A3)"},
{0x1002, 0x66A7, 0xFFFF, 0xFFFF, "Vega 20 [Radeon Pro Vega 20](0x66A7)"},
{0x1002, 0x66AF, 0xFFFF, 0xFFFF, "Vega 20 [Radeon VII](0x66AF)"},
{0x1002, 0x6704, 0xFFFF, 0xFFFF, "Cayman PRO GL [FirePro V7900](0x6704)"},
{0x1002, 0x6707, 0xFFFF, 0xFFFF, "Cayman LE GL [FirePro V5900](0x6707)"},
{0x1002, 0x6718, 0xFFFF, 0xFFFF, "Cayman XT [Radeon HD 6970](0x6718)"},
{0x1002, 0x6719, 0xFFFF, 0xFFFF, "Cayman PRO [Radeon HD 6950](0x6719)"},
{0x1002, 0x671C, 0xFFFF, 0xFFFF, "Antilles [Radeon HD 6990](0x671C)"},
{0x1002, 0x671D, 0xFFFF, 0xFFFF, "Antilles [Radeon HD 6990](0x671D)"},
{0x1002, 0x671F, 0xFFFF, 0xFFFF, "Cayman CE [Radeon HD 6930](0x671F)"},
{0x1002, 0x6720, 0xFFFF, 0xFFFF, "Blackcomb [Radeon HD 6970M/6990M](0x6720)"},
{0x1002, 0x6720, 0x1028, 0x048F, "Radeon HD 6990M(0x1028-0x048F)"},
{0x1002, 0x6720, 0x1028, 0x0490, "Alienware M17x R3 Radeon HD 6970M(0x1028-0x0490)"},
{0x1002, 0x6720, 0x1028, 0x04A4, "FirePro M8900(0x1028-0x04A4)"},
{0x1002, 0x6720, 0x1028, 0x04BA, "Radeon HD 6990M(0x1028-0x04BA)"},
{0x1002, 0x6720, 0x1028, 0x053F, "FirePro M8900(0x1028-0x053F)"},
{0x1002, 0x6720, 0x106B, 0x0B00, "Radeon HD 6970M(0x106B-0x0B00)"},
{0x1002, 0x6720, 0x1558, 0x5102, "Radeon HD 6970M(0x1558-0x5102)"},
{0x1002, 0x6720, 0x1558, 0x5104, "Radeon HD 6990M(0x1558-0x5104)"},
{0x1002, 0x6720, 0x1558, 0x7201, "Radeon HD 6990M(0x1558-0x7201)"},
{0x1002, 0x6720, 0x174B, 0xE188, "Radeon HD 6970M(0x174B-0xE188)"},
{0x1002, 0x6738, 0xFFFF, 0xFFFF, "Barts XT [Radeon HD 6870](0x6738)"},
{0x1002, 0x6738, 0x1682, 0x3103, "Radeon HD 8670(0x1682-0x3103)"},
{0x1002, 0x6738, 0x1787, 0x201A, "Barts XT [Radeon HD 6870 X2](0x1787-0x201A)"},
{0x1002, 0x6738, 0x1787, 0x201B, "Barts XT [Radeon HD 6870 X2](0x1787-0x201B)"},
{0x1002, 0x6739, 0xFFFF, 0xFFFF, "Barts PRO [Radeon HD 6850](0x6739)"},
{0x1002, 0x6739, 0x1043, 0x03B4, "EAH6850 [Radeon HD 6850](0x1043-0x03B4)"},
{0x1002, 0x673E, 0xFFFF, 0xFFFF, "Barts LE [Radeon HD 6790](0x673E)"},
{0x1002, 0x673E, 0x148C, 0x7720, "Radeon HD 7720 OEM(0x148C-0x7720)"},
{0x1002, 0x6740, 0xFFFF, 0xFFFF, "Whistler [Radeon HD 6730M/6770M/7690M XT](0x6740)"},
{0x1002, 0x6740, 0x1019, 0x238C, "Radeon HD 6730M(0x1019-0x238C)"},
{0x1002, 0x6740, 0x1019, 0x238E, "Radeon HD 6730M(0x1019-0x238E)"},
{0x1002, 0x6740, 0x1019, 0x2391, "Radeon HD 6730M(0x1019-0x2391)"},
{0x1002, 0x6740, 0x1019, 0x2392, "Radeon HD 6770M(0x1019-0x2392)"},
{0x1002, 0x6740, 0x1028, 0x04A3, "Precision M4600(0x1028-0x04A3)"},
{0x1002, 0x6740, 0x1028, 0x053E, "FirePro M5950(0x1028-0x053E)"},
{0x1002, 0x6740, 0x103C, 0x1630, "FirePro M5950(0x103C-0x1630)"},
{0x1002, 0x6740, 0x103C, 0x1631, "FirePro M5950(0x103C-0x1631)"},
{0x1002, 0x6740, 0x103C, 0x164B, "Radeon HD 6730M(0x103C-0x164B)"},
{0x1002, 0x6740, 0x103C, 0x164E, "Radeon HD 6730M(0x103C-0x164E)"},
{0x1002, 0x6740, 0x103C, 0x1657, "Radeon HD 6770M(0x103C-0x1657)"},
{0x1002, 0x6740, 0x103C, 0x1658, "Radeon HD 6770M(0x103C-0x1658)"},
{0x1002, 0x6740, 0x103C, 0x165A, "Radeon HD 6770M(0x103C-0x165A)"},
{0x1002, 0x6740, 0x103C, 0x165B, "Radeon HD 6770M(0x103C-0x165B)"},
{0x1002, 0x6740, 0x103C, 0x1688, "Radeon HD 6770M(0x103C-0x1688)"},
{0x1002, 0x6740, 0x103C, 0x1689, "Radeon HD 6770M(0x103C-0x1689)"},
{0x1002, 0x6740, 0x103C, 0x168A, "Radeon HD 6770M(0x103C-0x168A)"},
{0x1002, 0x6740, 0x103C, 0x185E, "Radeon HD 7690M XT(0x103C-0x185E)"},
{0x1002, 0x6740, 0x103C, 0x3388, "Radeon HD 6770M(0x103C-0x3388)"},
{0x1002, 0x6740, 0x103C, 0x3389, "Radeon HD 6770M(0x103C-0x3389)"},
{0x1002, 0x6740, 0x103C, 0x3582, "Radeon HD 6770M(0x103C-0x3582)"},
{0x1002, 0x6740, 0x103C, 0x366C, "Radeon HD 6730M(0x103C-0x366C)"},
{0x1002, 0x6740, 0x1043, 0x1D02, "Radeon HD 6730M(0x1043-0x1D02)"},
{0x1002, 0x6740, 0x1043, 0x1D12, "Radeon HD 6730M(0x1043-0x1D12)"},
{0x1002, 0x6740, 0x104D, 0x9084, "Radeon HD 6730M(0x104D-0x9084)"},
{0x1002, 0x6740, 0x104D, 0x9085, "Radeon HD 6730M(0x104D-0x9085)"},
{0x1002, 0x6740, 0x144D, 0xB074, "Radeon HD 6730M(0x144D-0xB074)"},
{0x1002, 0x6740, 0x144D, 0xB077, "Radeon HD 6730M(0x144D-0xB077)"},
{0x1002, 0x6740, 0x144D, 0xB084, "Radeon HD 6730M(0x144D-0xB084)"},
{0x1002, 0x6740, 0x144D, 0xB088, "Radeon HD 6730M(0x144D-0xB088)"},
{0x1002, 0x6740, 0x17AA, 0x3982, "Radeon HD 6730M(0x17AA-0x3982)"},
{0x1002, 0x6741, 0xFFFF, 0xFFFF, "Whistler [Radeon HD 6630M/6650M/6750M/7670M/7690M](0x6741)"},
{0x1002, 0x6741, 0x1019, 0x238E, "Radeon HD 6650M(0x1019-0x238E)"},
{0x1002, 0x6741, 0x1019, 0x238F, "Radeon HD 6650M(0x1019-0x238F)"},
{0x1002, 0x6741, 0x1025, 0x0379, "Radeon HD 6650M(0x1025-0x0379)"},
{0x1002, 0x6741, 0x1025, 0x037B, "Radeon HD 6650M(0x1025-0x037B)"},
{0x1002, 0x6741, 0x1025, 0x037E, "Radeon HD 6650M(0x1025-0x037E)"},
{0x1002, 0x6741, 0x1025, 0x0382, "Radeon HD 6650M(0x1025-0x0382)"},
{0x1002, 0x6741, 0x1025, 0x0384, "Radeon HD 6650M(0x1025-0x0384)"},
{0x1002, 0x6741, 0x1025, 0x0385, "Radeon HD 6650M(0x1025-0x0385)"},
{0x1002, 0x6741, 0x1025, 0x0386, "Radeon HD 6650M(0x1025-0x0386)"},
{0x1002, 0x6741, 0x1025, 0x0387, "Radeon HD 6650M(0x1025-0x0387)"},
{0x1002, 0x6741, 0x1025, 0x0388, "Radeon HD 6650M(0x1025-0x0388)"},
{0x1002, 0x6741, 0x1025, 0x0442, "Radeon HD 6650M(0x1025-0x0442)"},
{0x1002, 0x6741, 0x1025, 0x0451, "Radeon HD 6650M(0x1025-0x0451)"},
{0x1002, 0x6741, 0x1025, 0x0489, "Radeon HD 6650M(0x1025-0x0489)"},
{0x1002, 0x6741, 0x1025, 0x048B, "Radeon HD 6650M(0x1025-0x048B)"},
{0x1002, 0x6741, 0x1025, 0x048C, "Radeon HD 6650M(0x1025-0x048C)"},
{0x1002, 0x6741, 0x1025, 0x050A, "Radeon HD 6650M(0x1025-0x050A)"},
{0x1002, 0x6741, 0x1025, 0x050B, "Radeon HD 6650M(0x1025-0x050B)"},
{0x1002, 0x6741, 0x1025, 0x050C, "Radeon HD 6650M(0x1025-0x050C)"},
{0x1002, 0x6741, 0x1025, 0x050E, "Radeon HD 6650M(0x1025-0x050E)"},
{0x1002, 0x6741, 0x1025, 0x050F, "Radeon HD 6650M(0x1025-0x050F)"},
{0x1002, 0x6741, 0x1025, 0x0513, "Radeon HD 6650M(0x1025-0x0513)"},
{0x1002, 0x6741, 0x1025, 0x0514, "Radeon HD 6650M(0x1025-0x0514)"},
{0x1002, 0x6741, 0x1025, 0x0515, "Radeon HD 6650M(0x1025-0x0515)"},
{0x1002, 0x6741, 0x1025, 0x0516, "Radeon HD 6650M(0x1025-0x0516)"},
{0x1002, 0x6741, 0x1025, 0x051E, "Radeon HD 6650M(0x1025-0x051E)"},
{0x1002, 0x6741, 0x1025, 0x051F, "Radeon HD 6650M(0x1025-0x051F)"},
{0x1002, 0x6741, 0x1025, 0x0520, "Radeon HD 6650M(0x1025-0x0520)"},
{0x1002, 0x6741, 0x1025, 0x0521, "Radeon HD 6650M(0x1025-0x0521)"},
{0x1002, 0x6741, 0x1025, 0x052A, "Radeon HD 6650M(0x1025-0x052A)"},
{0x1002, 0x6741, 0x1025, 0x0555, "Radeon HD 6650M(0x1025-0x0555)"},
{0x1002, 0x6741, 0x1025, 0x0556, "Radeon HD 6650M(0x1025-0x0556)"},
{0x1002, 0x6741, 0x1025, 0x055D, "Radeon HD 6650M(0x1025-0x055D)"},
{0x1002, 0x6741, 0x1025, 0x055E, "Radeon HD 6650M(0x1025-0x055E)"},
{0x1002, 0x6741, 0x1025, 0x056D, "Radeon HD 6650M(0x1025-0x056D)"},
{0x1002, 0x6741, 0x1025, 0x059A, "Radeon HD 6650M(0x1025-0x059A)"},
{0x1002, 0x6741, 0x1025, 0x059B, "Radeon HD 6650M(0x1025-0x059B)"},
{0x1002, 0x6741, 0x1025, 0x059E, "Radeon HD 6650M(0x1025-0x059E)"},
{0x1002, 0x6741, 0x1025, 0x059F, "Radeon HD 6650M(0x1025-0x059F)"},
{0x1002, 0x6741, 0x1025, 0x0600, "Radeon HD 6650M(0x1025-0x0600)"},
{0x1002, 0x6741, 0x1025, 0x0605, "Radeon HD 6650M(0x1025-0x0605)"},
{0x1002, 0x6741, 0x1025, 0x0606, "Radeon HD 6650M(0x1025-0x0606)"},
{0x1002, 0x6741, 0x1025, 0x0619, "Radeon HD 6650M(0x1025-0x0619)"},
{0x1002, 0x6741, 0x1028, 0x04C1, "Radeon HD 6630M(0x1028-0x04C1)"},
{0x1002, 0x6741, 0x1028, 0x04C5, "Radeon HD 6630M(0x1028-0x04C5)"},
{0x1002, 0x6741, 0x1028, 0x04CD, "Radeon HD 6630M(0x1028-0x04CD)"},
{0x1002, 0x6741, 0x1028, 0x04D7, "Radeon HD 6630M(0x1028-0x04D7)"},
{0x1002, 0x6741, 0x1028, 0x04D9, "Radeon HD 6630M(0x1028-0x04D9)"},
{0x1002, 0x6741, 0x1028, 0x052D, "Radeon HD 6630M(0x1028-0x052D)"},
{0x1002, 0x6741, 0x103C, 0x1617, "Radeon HD 6650M(0x103C-0x1617)"},
{0x1002, 0x6741, 0x103C, 0x1646, "Radeon HD 6750M(0x103C-0x1646)"},
{0x1002, 0x6741, 0x103C, 0x1647, "Radeon HD 6650M(0x103C-0x1647)"},
{0x1002, 0x6741, 0x103C, 0x164B, "Radeon HD 6650M(0x103C-0x164B)"},
{0x1002, 0x6741, 0x103C, 0x164E, "Radeon HD 6650M(0x103C-0x164E)"},
{0x1002, 0x6741, 0x103C, 0x1688, "Radeon HD 6750M(0x103C-0x1688)"},
{0x1002, 0x6741, 0x103C, 0x1689, "Radeon HD 6750M(0x103C-0x1689)"},
{0x1002, 0x6741, 0x103C, 0x168A, "Radeon HD 6750M(0x103C-0x168A)"},
{0x1002, 0x6741, 0x103C, 0x1860, "Radeon HD 7690M(0x103C-0x1860)"},
{0x1002, 0x6741, 0x103C, 0x3385, "Radeon HD 6630M(0x103C-0x3385)"},
{0x1002, 0x6741, 0x103C, 0x3560, "Radeon HD 6750M(0x103C-0x3560)"},
{0x1002, 0x6741, 0x103C, 0x358D, "Radeon HD 6750M(0x103C-0x358D)"},
{0x1002, 0x6741, 0x103C, 0x3590, "Radeon HD 6750M(0x103C-0x3590)"},
{0x1002, 0x6741, 0x103C, 0x3593, "Radeon HD 6750M(0x103C-0x3593)"},
{0x1002, 0x6741, 0x103C, 0x366C, "Radeon HD 6650M(0x103C-0x366C)"},
{0x1002, 0x6741, 0x1043, 0x1CD2, "Radeon HD 6650M(0x1043-0x1CD2)"},
{0x1002, 0x6741, 0x1043, 0x2121, "Radeon HD 6650M(0x1043-0x2121)"},
{0x1002, 0x6741, 0x1043, 0x2122, "Radeon HD 6650M(0x1043-0x2122)"},
{0x1002, 0x6741, 0x1043, 0x2123, "Radeon HD 6650M(0x1043-0x2123)"},
{0x1002, 0x6741, 0x1043, 0x2125, "Radeon HD 7670M(0x1043-0x2125)"},
{0x1002, 0x6741, 0x1043, 0x2127, "Radeon HD 7670M(0x1043-0x2127)"},
{0x1002, 0x6741, 0x104D, 0x907B, "Radeon HD 6630M(0x104D-0x907B)"},
{0x1002, 0x6741, 0x104D, 0x9080, "Radeon HD 6630M(0x104D-0x9080)"},
{0x1002, 0x6741, 0x104D, 0x9081, "Radeon HD 6630M(0x104D-0x9081)"},
{0x1002, 0x6741, 0x106B, 0x00E2, "MacBookPro8,2 [Core i7, 15\", Late 2011](0x106B-0x00E2)"},
{0x1002, 0x6741, 0x1179, 0xFD63, "Radeon HD 6630M(0x1179-0xFD63)"},
{0x1002, 0x6741, 0x1179, 0xFD65, "Radeon HD 6630M(0x1179-0xFD65)"},
{0x1002, 0x6741, 0x144D, 0xC093, "Radeon HD 6650M(0x144D-0xC093)"},
{0x1002, 0x6741, 0x144D, 0xC0AC, "Radeon HD 6650M(0x144D-0xC0AC)"},
{0x1002, 0x6741, 0x144D, 0xC0B3, "Radeon HD 6750M(0x144D-0xC0B3)"},
{0x1002, 0x6741, 0x144D, 0xC539, "Radeon HD 6630M(0x144D-0xC539)"},
{0x1002, 0x6741, 0x144D, 0xC609, "Radeon HD 6630M(0x144D-0xC609)"},
{0x1002, 0x6741, 0x152D, 0x0914, "Radeon HD 6650M(0x152D-0x0914)"},
{0x1002, 0x6741, 0x17AA, 0x21E1, "Radeon HD 6630M(0x17AA-0x21E1)"},
{0x1002, 0x6741, 0x17AA, 0x3970, "Radeon HD 6650M(0x17AA-0x3970)"},
{0x1002, 0x6741, 0x17AA, 0x3976, "Radeon HD 6650M(0x17AA-0x3976)"},
{0x1002, 0x6741, 0x1854, 0x0907, "Radeon HD 6650M(0x1854-0x0907)"},
{0x1002, 0x6742, 0xFFFF, 0xFFFF, "Whistler LE [Radeon HD 6610M/7610M](0x6742)"},
{0x1002, 0x6742, 0x1002, 0x6570, "Turks [Radeon HD 6570](0x1002-0x6570)"},
{0x1002, 0x6742, 0x1019, 0x2393, "Radeon HD 6610M(0x1019-0x2393)"},
{0x1002, 0x6742, 0x1043, 0x1D82, "K53SK Laptop Radeon HD 7610M(0x1043-0x1D82)"},
{0x1002, 0x6742, 0x1179, 0xFB22, "Radeon HD 7610M(0x1179-0xFB22)"},
{0x1002, 0x6742, 0x1179, 0xFB23, "Radeon HD 7610M(0x1179-0xFB23)"},
{0x1002, 0x6742, 0x1179, 0xFB27, "Radeon HD 7610M(0x1179-0xFB27)"},
{0x1002, 0x6742, 0x1179, 0xFB2A, "Radeon HD 7610M(0x1179-0xFB2A)"},
{0x1002, 0x6742, 0x1179, 0xFB2C, "Radeon HD 7610M(0x1179-0xFB2C)"},
{0x1002, 0x6742, 0x1179, 0xFB30, "Radeon HD 7610M(0x1179-0xFB30)"},
{0x1002, 0x6742, 0x1179, 0xFB31, "Radeon HD 7610M(0x1179-0xFB31)"},
{0x1002, 0x6742, 0x1179, 0xFB32, "Radeon HD 7610M(0x1179-0xFB32)"},
{0x1002, 0x6742, 0x1179, 0xFB38, "Radeon HD 7610M(0x1179-0xFB38)"},
{0x1002, 0x6742, 0x1179, 0xFB39, "Radeon HD 7610M(0x1179-0xFB39)"},
{0x1002, 0x6742, 0x1179, 0xFB3A, "Radeon HD 7610M(0x1179-0xFB3A)"},
{0x1002, 0x6742, 0x1179, 0xFB3B, "Radeon HD 7610M(0x1179-0xFB3B)"},
{0x1002, 0x6742, 0x1179, 0xFB40, "Radeon HD 7610M(0x1179-0xFB40)"},
{0x1002, 0x6742, 0x1179, 0xFB41, "Radeon HD 7610M(0x1179-0xFB41)"},
{0x1002, 0x6742, 0x1179, 0xFB47, "Radeon HD 7610M(0x1179-0xFB47)"},
{0x1002, 0x6742, 0x1179, 0xFB48, "Radeon HD 7610M(0x1179-0xFB48)"},
{0x1002, 0x6742, 0x1179, 0xFB49, "Radeon HD 7610M(0x1179-0xFB49)"},
{0x1002, 0x6742, 0x1179, 0xFB51, "Radeon HD 7610M(0x1179-0xFB51)"},
{0x1002, 0x6742, 0x1179, 0xFB52, "Radeon HD 7610M(0x1179-0xFB52)"},
{0x1002, 0x6742, 0x1179, 0xFB53, "Radeon HD 7610M(0x1179-0xFB53)"},
{0x1002, 0x6742, 0x1179, 0xFB56, "Radeon HD 7610M(0x1179-0xFB56)"},
{0x1002, 0x6742, 0x1179, 0xFB81, "Radeon HD 7610M(0x1179-0xFB81)"},
{0x1002, 0x6742, 0x1179, 0xFB82, "Radeon HD 7610M(0x1179-0xFB82)"},
{0x1002, 0x6742, 0x1179, 0xFB83, "Radeon HD 7610M(0x1179-0xFB83)"},
{0x1002, 0x6742, 0x1179, 0xFC56, "Radeon HD 7610M(0x1179-0xFC56)"},
{0x1002, 0x6742, 0x1179, 0xFCD4, "Radeon HD 7610M(0x1179-0xFCD4)"},
{0x1002, 0x6742, 0x1179, 0xFCEE, "Radeon HD 7610M(0x1179-0xFCEE)"},
{0x1002, 0x6742, 0x1458, 0x6570, "Turks [Radeon HD 6570](0x1458-0x6570)"},
{0x1002, 0x6742, 0x1462, 0x6570, "Turks [Radeon HD 6570](0x1462-0x6570)"},
{0x1002, 0x6742, 0x148C, 0x6570, "Turks [Radeon HD 6570](0x148C-0x6570)"},
{0x1002, 0x6742, 0x1682, 0x6570, "Turks [Radeon HD 6570](0x1682-0x6570)"},
{0x1002, 0x6742, 0x174B, 0x5570, "Turks [Radeon HD 5570](0x174B-0x5570)"},
{0x1002, 0x6742, 0x174B, 0x6570, "Turks [Radeon HD 6570](0x174B-0x6570)"},
{0x1002, 0x6742, 0x174B, 0x7570, "Turks [Radeon HD 7570](0x174B-0x7570)"},
{0x1002, 0x6742, 0x174B, 0x8510, "Turks [Radeon HD 8510](0x174B-0x8510)"},
{0x1002, 0x6742, 0x174B, 0x8570, "Turks [Radeon HD 8570](0x174B-0x8570)"},
{0x1002, 0x6742, 0x1787, 0x6570, "Turks [Radeon HD 6570](0x1787-0x6570)"},
{0x1002, 0x6742, 0x17AF, 0x6570, "Turks [Radeon HD 6570](0x17AF-0x6570)"},
{0x1002, 0x6742, 0x8086, 0x2111, "Radeon HD 6625M(0x8086-0x2111)"},
{0x1002, 0x6743, 0xFFFF, 0xFFFF, "Whistler [Radeon E6760](0x6743)"},
{0x1002, 0x6749, 0xFFFF, 0xFFFF, "Turks GL [FirePro V4900](0x6749)"},
{0x1002, 0x6749, 0x15C3, 0x2B06, "MED-X4900 (EIZO)(0x15C3-0x2B06)"},
{0x1002, 0x674A, 0xFFFF, 0xFFFF, "Turks GL [FirePro V3900](0x674A)"},
{0x1002, 0x674A, 0x13CC, 0x3D22, "MXRT-2500(0x13CC-0x3D22)"},
{0x1002, 0x674A, 0x15C3, 0x0106, "MED-X3900(0x15C3-0x0106)"},
{0x1002, 0x6750, 0xFFFF, 0xFFFF, "Onega [Radeon HD 6650A/7650A](0x6750)"},
{0x1002, 0x6750, 0x1462, 0x2670, "Radeon HD 6670A(0x1462-0x2670)"},
{0x1002, 0x6750, 0x17AA, 0x3079, "Radeon HD 7650A(0x17AA-0x3079)"},
{0x1002, 0x6750, 0x17AA, 0x307A, "Radeon HD 6650A(0x17AA-0x307A)"},
{0x1002, 0x6750, 0x17AA, 0x3087, "Radeon HD 7650A(0x17AA-0x3087)"},
{0x1002, 0x6750, 0x17AA, 0x3618, "Radeon HD 6650A(0x17AA-0x3618)"},
{0x1002, 0x6750, 0x17AA, 0x3623, "Radeon HD 6650A(0x17AA-0x3623)"},
{0x1002, 0x6750, 0x17AA, 0x3627, "Radeon HD 6650A(0x17AA-0x3627)"},
{0x1002, 0x6751, 0xFFFF, 0xFFFF, "Turks [Radeon HD 7650A/7670A](0x6751)"},
{0x1002, 0x6751, 0x1028, 0x0548, "Radeon HD 7650A(0x1028-0x0548)"},
{0x1002, 0x6751, 0x1462, 0x2671, "Radeon HD 7670A(0x1462-0x2671)"},
{0x1002, 0x6751, 0x1462, 0x2672, "Radeon HD 7670A(0x1462-0x2672)"},
{0x1002, 0x6751, 0x1462, 0x2680, "Radeon HD 7650A(0x1462-0x2680)"},
{0x1002, 0x6751, 0x1462, 0x2681, "Radeon HD 7650A(0x1462-0x2681)"},
{0x1002, 0x6751, 0x17AA, 0x3087, "Radeon HD 7650A(0x17AA-0x3087)"},
{0x1002, 0x6758, 0xFFFF, 0xFFFF, "Turks XT [Radeon HD 6670/7670](0x6758)"},
{0x1002, 0x6758, 0x1028, 0x0B0E, "Radeon HD 6670(0x1028-0x0B0E)"},
{0x1002, 0x6758, 0x103C, 0x6882, "Radeon HD 6670(0x103C-0x6882)"},
{0x1002, 0x6758, 0x1462, 0x250A, "Radeon HD 7670(0x1462-0x250A)"},
{0x1002, 0x6758, 0x148C, 0x7670, "Radeon HD 7670(0x148C-0x7670)"},
{0x1002, 0x6758, 0x1545, 0x7670, "Radeon HD 7670(0x1545-0x7670)"},
{0x1002, 0x6758, 0x1682, 0x3300, "Radeon HD 7670(0x1682-0x3300)"},
{0x1002, 0x6758, 0x174B, 0x7670, "Radeon HD 7670(0x174B-0x7670)"},
{0x1002, 0x6758, 0x174B, 0xE181, "Radeon HD 6670(0x174B-0xE181)"},
{0x1002, 0x6758, 0x1787, 0x2309, "Radeon HD 6670(0x1787-0x2309)"},
{0x1002, 0x6759, 0xFFFF, 0xFFFF, "Turks PRO [Radeon HD 6570/7570/8550 / R5 230](0x6759)"},
{0x1002, 0x6759, 0x103C, 0x3130, "Radeon HD 6570(0x103C-0x3130)"},
{0x1002, 0x6759, 0x1043, 0x0403, "Radeon HD 6570(0x1043-0x0403)"},
{0x1002, 0x6759, 0x1462, 0x2500, "Radeon HD 6570(0x1462-0x2500)"},
{0x1002, 0x6759, 0x1462, 0x2509, "Radeon HD 7570(0x1462-0x2509)"},
{0x1002, 0x6759, 0x148C, 0x7570, "Radeon HD 7570(0x148C-0x7570)"},
{0x1002, 0x6759, 0x1642, 0x3A67, "Radeon HD 6570(0x1642-0x3A67)"},
{0x1002, 0x6759, 0x1682, 0x3280, "Radeon HD 7570(0x1682-0x3280)"},
{0x1002, 0x6759, 0x1682, 0x3530, "Radeon HD 8550(0x1682-0x3530)"},
{0x1002, 0x6759, 0x1682, 0x5230, "Radeon R5 230 series(0x1682-0x5230)"},
{0x1002, 0x6759, 0x1682, 0x6450, "Radeon HD 6450 series(0x1682-0x6450)"},
{0x1002, 0x6759, 0x174B, 0x7570, "Radeon HD 7570(0x174B-0x7570)"},
{0x1002, 0x6759, 0x174B, 0x8550, "Radeon HD8550 OEM(0x174B-0x8550)"},
{0x1002, 0x6759, 0x174B, 0x8570, "Radeon HD8550 OEM(0x174B-0x8570)"},
{0x1002, 0x6759, 0x174B, 0xE142, "Radeon HD 6570(0x174B-0xE142)"},
{0x1002, 0x6759, 0x174B, 0xE181, "Radeon HD 6570(0x174B-0xE181)"},
{0x1002, 0x6759, 0x1787, 0xA230, "Radeon R5 230 series(0x1787-0xA230)"},
{0x1002, 0x6759, 0x1787, 0xA450, "Radeon HD 6450 series(0x1787-0xA450)"},
{0x1002, 0x6759, 0x1B0A, 0x908F, "Radeon HD 6570(0x1B0A-0x908F)"},
{0x1002, 0x6759, 0x1B0A, 0x9090, "Radeon HD 6570(0x1B0A-0x9090)"},
{0x1002, 0x6759, 0x1B0A, 0x9091, "Radeon HD 6570(0x1B0A-0x9091)"},
{0x1002, 0x6759, 0x1B0A, 0x9092, "Radeon HD 6570(0x1B0A-0x9092)"},
{0x1002, 0x6759, 0x1B0A, 0x909E, "Radeon HD 6570(0x1B0A-0x909E)"},
{0x1002, 0x6759, 0x1B0A, 0x90B5, "Radeon HD 7570(0x1B0A-0x90B5)"},
{0x1002, 0x6759, 0x1B0A, 0x90B6, "Radeon HD 7570(0x1B0A-0x90B6)"},
{0x1002, 0x675B, 0xFFFF, 0xFFFF, "Turks [Radeon HD 7600 Series](0x675B)"},
{0x1002, 0x675D, 0xFFFF, 0xFFFF, "Turks PRO [Radeon HD 7570](0x675D)"},
{0x1002, 0x675F, 0xFFFF, 0xFFFF, "Turks LE [Radeon HD 5570/6510/7510/8510](0x675F)"},
{0x1002, 0x675F, 0x148C, 0x6510, "Radeon HD 6510(0x148C-0x6510)"},
{0x1002, 0x675F, 0x148C, 0x6530, "Radeon HD 6530(0x148C-0x6530)"},
{0x1002, 0x675F, 0x148C, 0x7510, "Radeon HD 7510(0x148C-0x7510)"},
{0x1002, 0x675F, 0x1545, 0x7570, "Radeon HD 7570(0x1545-0x7570)"},
{0x1002, 0x675F, 0x174B, 0x6510, "Radeon HD 6510(0x174B-0x6510)"},
{0x1002, 0x675F, 0x174B, 0x7510, "Radeon HD 7510(0x174B-0x7510)"},
{0x1002, 0x675F, 0x174B, 0x8510, "Radeon HD 8510(0x174B-0x8510)"},
{0x1002, 0x675F, 0x1787, 0x2012, "Radeon HD 5570 2GB GDDR3(0x1787-0x2012)"},
{0x1002, 0x675F, 0x1787, 0x2314, "Radeon HD 5570 1GB DDR2/GDDR3(0x1787-0x2314)"},
{0x1002, 0x6760, 0xFFFF, 0xFFFF, "Seymour [Radeon HD 6400M/7400M Series](0x6760)"},
{0x1002, 0x6760, 0x1002, 0x0124, "Radeon HD 6470M(0x1002-0x0124)"},
{0x1002, 0x6760, 0x1002, 0x0134, "Radeon HD 6470M(0x1002-0x0134)"},
{0x1002, 0x6760, 0x1019, 0x238B, "Radeon HD 6470M(0x1019-0x238B)"},
{0x1002, 0x6760, 0x1019, 0x238E, "Radeon HD 6470M(0x1019-0x238E)"},
{0x1002, 0x6760, 0x1019, 0x2390, "Radeon HD 6470M(0x1019-0x2390)"},
{0x1002, 0x6760, 0x1019, 0x9985, "Radeon HD 6470M(0x1019-0x9985)"},
{0x1002, 0x6760, 0x1028, 0x04C1, "Radeon HD 6470M(0x1028-0x04C1)"},
{0x1002, 0x6760, 0x1028, 0x04C3, "Radeon HD 6470M(0x1028-0x04C3)"},
{0x1002, 0x6760, 0x1028, 0x04CA, "Radeon HD 6470M(0x1028-0x04CA)"},
{0x1002, 0x6760, 0x1028, 0x04CB, "Radeon HD 6470M(0x1028-0x04CB)"},
{0x1002, 0x6760, 0x1028, 0x04CC, "Vostro 3350(0x1028-0x04CC)"},
{0x1002, 0x6760, 0x1028, 0x04D1, "Radeon HD 6470M(0x1028-0x04D1)"},
{0x1002, 0x6760, 0x1028, 0x04D3, "Radeon HD 6470M(0x1028-0x04D3)"},
{0x1002, 0x6760, 0x1028, 0x04D7, "Radeon HD 6470M(0x1028-0x04D7)"},
{0x1002, 0x6760, 0x1028, 0x0502, "Radeon HD 6470M(0x1028-0x0502)"},
{0x1002, 0x6760, 0x1028, 0x0503, "Radeon HD 6470M(0x1028-0x0503)"},
{0x1002, 0x6760, 0x1028, 0x0506, "Radeon HD 6470M(0x1028-0x0506)"},
{0x1002, 0x6760, 0x1028, 0x0507, "Radeon HD 6470M(0x1028-0x0507)"},
{0x1002, 0x6760, 0x1028, 0x0514, "Radeon HD 6470M(0x1028-0x0514)"},
{0x1002, 0x6760, 0x1028, 0x051C, "Radeon HD 6450M / 7430M(0x1028-0x051C)"},
{0x1002, 0x6760, 0x1028, 0x051D, "Radeon HD 6450M / 7430M(0x1028-0x051D)"},
{0x1002, 0x6760, 0x103C, 0x161A, "Radeon HD 6470M(0x103C-0x161A)"},
{0x1002, 0x6760, 0x103C, 0x161B, "Radeon HD 6470M(0x103C-0x161B)"},
{0x1002, 0x6760, 0x103C, 0x161E, "Radeon HD 6470M(0x103C-0x161E)"},
{0x1002, 0x6760, 0x103C, 0x161F, "Radeon HD 6470M(0x103C-0x161F)"},
{0x1002, 0x6760, 0x103C, 0x1622, "Radeon HD 6450M(0x103C-0x1622)"},
{0x1002, 0x6760, 0x103C, 0x1623, "Radeon HD 6450M(0x103C-0x1623)"},
{0x1002, 0x6760, 0x103C, 0x164A, "Radeon HD 6470M(0x103C-0x164A)"},
{0x1002, 0x6760, 0x103C, 0x164D, "Radeon HD 6470M(0x103C-0x164D)"},
{0x1002, 0x6760, 0x103C, 0x1651, "Radeon HD 6470M(0x103C-0x1651)"},
{0x1002, 0x6760, 0x103C, 0x1656, "Radeon HD 6490M(0x103C-0x1656)"},
{0x1002, 0x6760, 0x103C, 0x1658, "Radeon HD 6490M(0x103C-0x1658)"},
{0x1002, 0x6760, 0x103C, 0x1659, "Radeon HD 6490M(0x103C-0x1659)"},
{0x1002, 0x6760, 0x103C, 0x165B, "Radeon HD 6490M(0x103C-0x165B)"},
{0x1002, 0x6760, 0x103C, 0x165D, "Radeon HD 6470M(0x103C-0x165D)"},
{0x1002, 0x6760, 0x103C, 0x165F, "Radeon HD 6470M(0x103C-0x165F)"},
{0x1002, 0x6760, 0x103C, 0x1661, "Radeon HD 6470M(0x103C-0x1661)"},
{0x1002, 0x6760, 0x103C, 0x1663, "Radeon HD 6470M(0x103C-0x1663)"},
{0x1002, 0x6760, 0x103C, 0x1665, "Radeon HD 6470M(0x103C-0x1665)"},
{0x1002, 0x6760, 0x103C, 0x1667, "Radeon HD 6470M(0x103C-0x1667)"},
{0x1002, 0x6760, 0x103C, 0x1669, "Radeon HD 6470M(0x103C-0x1669)"},
{0x1002, 0x6760, 0x103C, 0x166B, "Radeon HD 6470M(0x103C-0x166B)"},
{0x1002, 0x6760, 0x103C, 0x166C, "Radeon HD 6470M(0x103C-0x166C)"},
{0x1002, 0x6760, 0x103C, 0x166E, "Radeon HD 6470M(0x103C-0x166E)"},
{0x1002, 0x6760, 0x103C, 0x1670, "Radeon HD 6470M(0x103C-0x1670)"},
{0x1002, 0x6760, 0x103C, 0x1672, "Radeon HD 6470M(0x103C-0x1672)"},
{0x1002, 0x6760, 0x103C, 0x167A, "Radeon HD 6470M(0x103C-0x167A)"},
{0x1002, 0x6760, 0x103C, 0x167B, "Radeon HD 6470M(0x103C-0x167B)"},
{0x1002, 0x6760, 0x103C, 0x167D, "Radeon HD 6490M(0x103C-0x167D)"},
{0x1002, 0x6760, 0x103C, 0x167F, "Radeon HD 6490M(0x103C-0x167F)"},
{0x1002, 0x6760, 0x103C, 0x168C, "Radeon HD 6470M(0x103C-0x168C)"},
{0x1002, 0x6760, 0x103C, 0x168F, "Radeon HD 6470M(0x103C-0x168F)"},
{0x1002, 0x6760, 0x103C, 0x1694, "Radeon HD 6470M(0x103C-0x1694)"},
{0x1002, 0x6760, 0x103C, 0x1696, "Radeon HD 6470M(0x103C-0x1696)"},
{0x1002, 0x6760, 0x103C, 0x1698, "Radeon HD 6470M(0x103C-0x1698)"},
{0x1002, 0x6760, 0x103C, 0x169A, "Radeon HD 6470M(0x103C-0x169A)"},
{0x1002, 0x6760, 0x103C, 0x169C, "Radeon HD 6490M(0x103C-0x169C)"},
{0x1002, 0x6760, 0x103C, 0x1855, "Radeon HD 7450M(0x103C-0x1855)"},
{0x1002, 0x6760, 0x103C, 0x1859, "Radeon HD 7450M(0x103C-0x1859)"},
{0x1002, 0x6760, 0x103C, 0x185C, "Radeon HD 7450M(0x103C-0x185C)"},
{0x1002, 0x6760, 0x103C, 0x185D, "Radeon HD 7470M(0x103C-0x185D)"},
{0x1002, 0x6760, 0x103C, 0x185F, "Radeon HD 7470M(0x103C-0x185F)"},
{0x1002, 0x6760, 0x103C, 0x1863, "Radeon HD 7450M(0x103C-0x1863)"},
{0x1002, 0x6760, 0x103C, 0x355C, "Radeon HD 6490M(0x103C-0x355C)"},
{0x1002, 0x6760, 0x103C, 0x355F, "Radeon HD 6490M(0x103C-0x355F)"},
{0x1002, 0x6760, 0x103C, 0x3563, "Radeon HD 6470M(0x103C-0x3563)"},
{0x1002, 0x6760, 0x103C, 0x3565, "Radeon HD 6470M(0x103C-0x3565)"},
{0x1002, 0x6760, 0x103C, 0x3567, "Radeon HD 6470M(0x103C-0x3567)"},
{0x1002, 0x6760, 0x103C, 0x3569, "Radeon HD 6470M(0x103C-0x3569)"},
{0x1002, 0x6760, 0x103C, 0x3581, "Radeon HD 6490M(0x103C-0x3581)"},
{0x1002, 0x6760, 0x103C, 0x3584, "Radeon HD 6470M(0x103C-0x3584)"},
{0x1002, 0x6760, 0x103C, 0x358C, "Radeon HD 6490M(0x103C-0x358C)"},
{0x1002, 0x6760, 0x103C, 0x358F, "Radeon HD 6490M(0x103C-0x358F)"},
{0x1002, 0x6760, 0x103C, 0x3592, "Radeon HD 6490M(0x103C-0x3592)"},
{0x1002, 0x6760, 0x103C, 0x3596, "Radeon HD 6490M(0x103C-0x3596)"},
{0x1002, 0x6760, 0x103C, 0x366B, "Radeon HD 6470M(0x103C-0x366B)"},
{0x1002, 0x6760, 0x103C, 0x3671, "FirePro M3900(0x103C-0x3671)"},
{0x1002, 0x6760, 0x103C, 0x3673, "Radeon HD 6470M(0x103C-0x3673)"},
{0x1002, 0x6760, 0x1043, 0x100A, "Radeon HD 7470M(0x1043-0x100A)"},
{0x1002, 0x6760, 0x1043, 0x100C, "Radeon HD 6470M(0x1043-0x100C)"},
{0x1002, 0x6760, 0x1043, 0x101B, "Radeon HD 6470M(0x1043-0x101B)"},
{0x1002, 0x6760, 0x1043, 0x101C, "Radeon HD 6470M(0x1043-0x101C)"},
{0x1002, 0x6760, 0x1043, 0x102A, "Radeon HD 7450M(0x1043-0x102A)"},
{0x1002, 0x6760, 0x1043, 0x102C, "Radeon HD 6470M(0x1043-0x102C)"},
{0x1002, 0x6760, 0x1043, 0x104B, "Radeon HD 7470M(0x1043-0x104B)"},
{0x1002, 0x6760, 0x1043, 0x105D, "Radeon HD 7470M(0x1043-0x105D)"},
{0x1002, 0x6760, 0x1043, 0x106B, "Radeon HD 7470M(0x1043-0x106B)"},
{0x1002, 0x6760, 0x1043, 0x106D, "Radeon HD 7470M(0x1043-0x106D)"},
{0x1002, 0x6760, 0x1043, 0x107D, "Radeon HD 7470M(0x1043-0x107D)"},
{0x1002, 0x6760, 0x1043, 0x1CB2, "Radeon HD 6470M(0x1043-0x1CB2)"},
{0x1002, 0x6760, 0x1043, 0x1D22, "Radeon HD 6470M(0x1043-0x1D22)"},
{0x1002, 0x6760, 0x1043, 0x1D32, "Radeon HD 6470M(0x1043-0x1D32)"},
{0x1002, 0x6760, 0x1043, 0x2001, "Radeon HD 6470M(0x1043-0x2001)"},
{0x1002, 0x6760, 0x1043, 0x2002, "Radeon HD 7470M(0x1043-0x2002)"},
{0x1002, 0x6760, 0x1043, 0x2107, "Radeon HD 7470M(0x1043-0x2107)"},
{0x1002, 0x6760, 0x1043, 0x2108, "Radeon HD 7470M(0x1043-0x2108)"},
{0x1002, 0x6760, 0x1043, 0x2109, "Radeon HD 7470M(0x1043-0x2109)"},
{0x1002, 0x6760, 0x1043, 0x84A0, "Radeon HD 6470M(0x1043-0x84A0)"},
{0x1002, 0x6760, 0x1043, 0x84E9, "Radeon HD 6470M(0x1043-0x84E9)"},
{0x1002, 0x6760, 0x1043, 0x8515, "Radeon HD 7470M(0x1043-0x8515)"},
{0x1002, 0x6760, 0x1043, 0x8517, "Radeon HD 7470M(0x1043-0x8517)"},
{0x1002, 0x6760, 0x1043, 0x855A, "Radeon HD 7470M(0x1043-0x855A)"},
{0x1002, 0x6760, 0x104D, 0x907B, "Radeon HD 6470M(0x104D-0x907B)"},
{0x1002, 0x6760, 0x104D, 0x9081, "Radeon HD 6470M(0x104D-0x9081)"},
{0x1002, 0x6760, 0x104D, 0x9084, "Radeon HD 6470M(0x104D-0x9084)"},
{0x1002, 0x6760, 0x104D, 0x9085, "Radeon HD 6470M(0x104D-0x9085)"},
{0x1002, 0x6760, 0x1179, 0x0001, "Radeon HD 6450M(0x1179-0x0001)"},
{0x1002, 0x6760, 0x1179, 0x0003, "Radeon HD 6450M(0x1179-0x0003)"},
{0x1002, 0x6760, 0x1179, 0x0004, "Radeon HD 6450M(0x1179-0x0004)"},
{0x1002, 0x6760, 0x1179, 0xFB22, "Radeon HD 7470M(0x1179-0xFB22)"},
{0x1002, 0x6760, 0x1179, 0xFB23, "Radeon HD 7470M(0x1179-0xFB23)"},
{0x1002, 0x6760, 0x1179, 0xFB2C, "Radeon HD 7470M(0x1179-0xFB2C)"},
{0x1002, 0x6760, 0x1179, 0xFB31, "Radeon HD 7470M(0x1179-0xFB31)"},
{0x1002, 0x6760, 0x1179, 0xFB32, "Radeon HD 7470M(0x1179-0xFB32)"},
{0x1002, 0x6760, 0x1179, 0xFB33, "Radeon HD 7470M(0x1179-0xFB33)"},
{0x1002, 0x6760, 0x1179, 0xFB38, "Radeon HD 7470M(0x1179-0xFB38)"},
{0x1002, 0x6760, 0x1179, 0xFB39, "Radeon HD 7470M(0x1179-0xFB39)"},
{0x1002, 0x6760, 0x1179, 0xFB3A, "Radeon HD 7470M(0x1179-0xFB3A)"},
{0x1002, 0x6760, 0x1179, 0xFB40, "Radeon HD 7470M(0x1179-0xFB40)"},
{0x1002, 0x6760, 0x1179, 0xFB41, "Radeon HD 7470M(0x1179-0xFB41)"},
{0x1002, 0x6760, 0x1179, 0xFB42, "Radeon HD 7470M(0x1179-0xFB42)"},
{0x1002, 0x6760, 0x1179, 0xFB47, "Radeon HD 7470M(0x1179-0xFB47)"},
{0x1002, 0x6760, 0x1179, 0xFB48, "Radeon HD 7470M(0x1179-0xFB48)"},
{0x1002, 0x6760, 0x1179, 0xFB51, "Radeon HD 7470M(0x1179-0xFB51)"},
{0x1002, 0x6760, 0x1179, 0xFB52, "Radeon HD 7470M(0x1179-0xFB52)"},
{0x1002, 0x6760, 0x1179, 0xFB53, "Radeon HD 7470M(0x1179-0xFB53)"},
{0x1002, 0x6760, 0x1179, 0xFB81, "Radeon HD 7470M(0x1179-0xFB81)"},
{0x1002, 0x6760, 0x1179, 0xFB82, "Radeon HD 7470M(0x1179-0xFB82)"},
{0x1002, 0x6760, 0x1179, 0xFB83, "Radeon HD 7470M(0x1179-0xFB83)"},
{0x1002, 0x6760, 0x1179, 0xFC51, "Radeon HD 6470M(0x1179-0xFC51)"},
{0x1002, 0x6760, 0x1179, 0xFC52, "Radeon HD 7470M(0x1179-0xFC52)"},
{0x1002, 0x6760, 0x1179, 0xFC56, "Radeon HD 7470M(0x1179-0xFC56)"},
{0x1002, 0x6760, 0x1179, 0xFCD3, "Radeon HD 7470M(0x1179-0xFCD3)"},
{0x1002, 0x6760, 0x1179, 0xFCD4, "Radeon HD 7470M(0x1179-0xFCD4)"},
{0x1002, 0x6760, 0x1179, 0xFCEE, "Radeon HD 7470M(0x1179-0xFCEE)"},
{0x1002, 0x6760, 0x1179, 0xFDEE, "Radeon HD 7470M(0x1179-0xFDEE)"},
{0x1002, 0x6760, 0x144D, 0xB074, "Radeon HD 6470M(0x144D-0xB074)"},
{0x1002, 0x6760, 0x144D, 0xB084, "Radeon HD 6470M(0x144D-0xB084)"},
{0x1002, 0x6760, 0x144D, 0xC095, "Radeon HD 6470M(0x144D-0xC095)"},
{0x1002, 0x6760, 0x144D, 0xC0B3, "Radeon HD 6490M(0x144D-0xC0B3)"},
{0x1002, 0x6760, 0x144D, 0xC538, "Radeon HD 6470M(0x144D-0xC538)"},
{0x1002, 0x6760, 0x144D, 0xC581, "Radeon HD 6470M(0x144D-0xC581)"},
{0x1002, 0x6760, 0x144D, 0xC589, "Radeon HD 6470M(0x144D-0xC589)"},
{0x1002, 0x6760, 0x144D, 0xC609, "Radeon HD 7470M(0x144D-0xC609)"},
{0x1002, 0x6760, 0x144D, 0xC625, "Radeon HD 7470M(0x144D-0xC625)"},
{0x1002, 0x6760, 0x144D, 0xC636, "Radeon HD 7450M(0x144D-0xC636)"},
{0x1002, 0x6760, 0x1462, 0x10AC, "Radeon HD 6470M(0x1462-0x10AC)"},
{0x1002, 0x6760, 0x152D, 0x0916, "Radeon HD 6470M(0x152D-0x0916)"},
{0x1002, 0x6760, 0x17AA, 0x21E5, "Radeon HD 6470M(0x17AA-0x21E5)"},
{0x1002, 0x6760, 0x17AA, 0x3900, "Radeon HD 7450M(0x17AA-0x3900)"},
{0x1002, 0x6760, 0x17AA, 0x3902, "Radeon HD 7450M(0x17AA-0x3902)"},
{0x1002, 0x6760, 0x17AA, 0x3969, "Radeon HD 6470M(0x17AA-0x3969)"},
{0x1002, 0x6760, 0x17AA, 0x3970, "Radeon HD 7450M(0x17AA-0x3970)"},
{0x1002, 0x6760, 0x17AA, 0x3976, "Radeon HD 6470M(0x17AA-0x3976)"},
{0x1002, 0x6760, 0x17AA, 0x397B, "Radeon HD 6470M(0x17AA-0x397B)"},
{0x1002, 0x6760, 0x17AA, 0x397D, "Radeon HD 6470M(0x17AA-0x397D)"},
{0x1002, 0x6760, 0x17AA, 0x5101, "Radeon HD 7470M(0x17AA-0x5101)"},
{0x1002, 0x6760, 0x17AA, 0x5102, "Radeon HD 7450M(0x17AA-0x5102)"},
{0x1002, 0x6760, 0x17AA, 0x5103, "Radeon HD 7450M(0x17AA-0x5103)"},
{0x1002, 0x6760, 0x17AA, 0x5106, "Radeon HD 7450M(0x17AA-0x5106)"},
{0x1002, 0x6760, 0x1854, 0x0897, "Radeon HD 6470M(0x1854-0x0897)"},
{0x1002, 0x6760, 0x1854, 0x0900, "Radeon HD 6470M(0x1854-0x0900)"},
{0x1002, 0x6760, 0x1854, 0x0908, "Radeon HD 6470M(0x1854-0x0908)"},
{0x1002, 0x6760, 0x1854, 0x2015, "Radeon HD 6470M(0x1854-0x2015)"},
{0x1002, 0x6761, 0xFFFF, 0xFFFF, "Seymour LP [Radeon HD 6430M](0x6761)"},
{0x1002, 0x6763, 0xFFFF, 0xFFFF, "Seymour [Radeon E6460](0x6763)"},
{0x1002, 0x6764, 0xFFFF, 0xFFFF, "Seymour [Radeon HD 6400M Series](0x6764)"},
{0x1002, 0x6765, 0xFFFF, 0xFFFF, "Seymour [Radeon HD 6400M Series](0x6765)"},
{0x1002, 0x6766, 0xFFFF, 0xFFFF, "Caicos(0x6766)"},
{0x1002, 0x6767, 0xFFFF, 0xFFFF, "Caicos(0x6767)"},
{0x1002, 0x6768, 0xFFFF, 0xFFFF, "Caicos(0x6768)"},
{0x1002, 0x6770, 0xFFFF, 0xFFFF, "Caicos [Radeon HD 6450A/7450A](0x6770)"},
{0x1002, 0x6770, 0x17AA, 0x308D, "Radeon HD 7450A(0x17AA-0x308D)"},
{0x1002, 0x6770, 0x17AA, 0x3623, "Radeon HD 6450A(0x17AA-0x3623)"},
{0x1002, 0x6770, 0x17AA, 0x3627, "Radeon HD 6450A(0x17AA-0x3627)"},
{0x1002, 0x6770, 0x17AA, 0x3629, "Radeon HD 6450A(0x17AA-0x3629)"},
{0x1002, 0x6770, 0x17AA, 0x363C, "Radeon HD 6450A(0x17AA-0x363C)"},
{0x1002, 0x6770, 0x17AA, 0x3658, "Radeon HD 7470A(0x17AA-0x3658)"},
{0x1002, 0x6771, 0xFFFF, 0xFFFF, "Caicos XTX [Radeon HD 8490 / R5 235X OEM](0x6771)"},
{0x1002, 0x6772, 0xFFFF, 0xFFFF, "Caicos [Radeon HD 7450A](0x6772)"},
{0x1002, 0x6778, 0xFFFF, 0xFFFF, "Caicos XT [Radeon HD 7470/8470 / R5 235/310 OEM](0x6778)"},
{0x1002, 0x6778, 0x1019, 0x0024, "Radeon HD 7470(0x1019-0x0024)"},
{0x1002, 0x6778, 0x1019, 0x0027, "Radeon HD 8470(0x1019-0x0027)"},
{0x1002, 0x6778, 0x1028, 0x2120, "Radeon HD 7470(0x1028-0x2120)"},
{0x1002, 0x6778, 0x1462, 0xB491, "Radeon HD 8470(0x1462-0xB491)"},
{0x1002, 0x6778, 0x1462, 0xB492, "Radeon HD 8470(0x1462-0xB492)"},
{0x1002, 0x6778, 0x1462, 0xB493, "Radeon HD 8470 OEM(0x1462-0xB493)"},
{0x1002, 0x6778, 0x1462, 0xB499, "Radeon R5 235 OEM(0x1462-0xB499)"},
{0x1002, 0x6778, 0x1642, 0x3C65, "Radeon HD 8470(0x1642-0x3C65)"},
{0x1002, 0x6778, 0x1642, 0x3C75, "Radeon HD 8470(0x1642-0x3C75)"},
{0x1002, 0x6778, 0x174B, 0x8145, "Radeon HD 8470(0x174B-0x8145)"},
{0x1002, 0x6778, 0x174B, 0xD145, "Radeon R5 235 OEM(0x174B-0xD145)"},
{0x1002, 0x6778, 0x174B, 0xD335, "Radeon R5 310 OEM(0x174B-0xD335)"},
{0x1002, 0x6778, 0x174B, 0xE145, "Radeon HD 7470(0x174B-0xE145)"},
{0x1002, 0x6778, 0x17AA, 0x3694, "Radeon R5 A220(0x17AA-0x3694)"},
{0x1002, 0x6779, 0xFFFF, 0xFFFF, "Caicos [Radeon HD 6450/7450/8450 / R5 230 OEM](0x6779)"},
{0x1002, 0x6779, 0x1019, 0x0016, "Radeon HD 6450(0x1019-0x0016)"},
{0x1002, 0x6779, 0x1019, 0x0017, "Radeon HD 6450(0x1019-0x0017)"},
{0x1002, 0x6779, 0x1019, 0x0018, "Radeon HD 6450(0x1019-0x0018)"},
{0x1002, 0x6779, 0x1028, 0x2120, "Radeon HD 6450(0x1028-0x2120)"},
{0x1002, 0x6779, 0x103C, 0x2128, "Radeon HD 6450(0x103C-0x2128)"},
{0x1002, 0x6779, 0x103C, 0x2AEE, "Radeon HD 7450A(0x103C-0x2AEE)"},
{0x1002, 0x6779, 0x1043, 0x047B, "EAH6450 SILENT/DI/1GD3(LP)(0x1043-0x047B)"},
{0x1002, 0x6779, 0x1092, 0x6450, "Radeon HD 6450(0x1092-0x6450)"},
{0x1002, 0x6779, 0x1462, 0x2125, "Radeon HD 6450(0x1462-0x2125)"},
{0x1002, 0x6779, 0x1462, 0x2346, "Radeon HD 7450(0x1462-0x2346)"},
{0x1002, 0x6779, 0x1462, 0x2490, "Radeon HD 6450(0x1462-0x2490)"},
{0x1002, 0x6779, 0x1462, 0x2494, "Radeon HD 6450(0x1462-0x2494)"},
{0x1002, 0x6779, 0x1462, 0x2496, "Radeon HD 7450(0x1462-0x2496)"},
{0x1002, 0x6779, 0x148C, 0x7450, "Radeon HD 7450(0x148C-0x7450)"},
{0x1002, 0x6779, 0x148C, 0x8450, "Radeon HD 8450 OEM(0x148C-0x8450)"},
{0x1002, 0x6779, 0x1545, 0x7470, "Radeon HD 7470(0x1545-0x7470)"},
{0x1002, 0x6779, 0x1642, 0x3A65, "Radeon HD 6450(0x1642-0x3A65)"},
{0x1002, 0x6779, 0x1642, 0x3A66, "Radeon HD 7450(0x1642-0x3A66)"},
{0x1002, 0x6779, 0x1642, 0x3A75, "Radeon HD 6450(0x1642-0x3A75)"},
{0x1002, 0x6779, 0x1642, 0x3A76, "Radeon HD 7450(0x1642-0x3A76)"},
{0x1002, 0x6779, 0x1682, 0x3200, "Radeon HD 7450(0x1682-0x3200)"},
{0x1002, 0x6779, 0x174B, 0x7450, "Radeon HD 7450(0x174B-0x7450)"},
{0x1002, 0x6779, 0x174B, 0xE127, "Radeon HD 6450(0x174B-0xE127)"},
{0x1002, 0x6779, 0x174B, 0xE153, "Radeon HD 6450(0x174B-0xE153)"},
{0x1002, 0x6779, 0x174B, 0xE164, "Radeon HD 6450 1 GB DDR3(0x174B-0xE164)"},
{0x1002, 0x6779, 0x174B, 0xE180, "Radeon HD 6450(0x174B-0xE180)"},
{0x1002, 0x6779, 0x174B, 0xE201, "Radeon HD 6450(0x174B-0xE201)"},
{0x1002, 0x6779, 0x1787, 0x2311, "Radeon HD 6450(0x1787-0x2311)"},
{0x1002, 0x6779, 0x17AF, 0x8450, "Radeon HD 8450 OEM(0x17AF-0x8450)"},
{0x1002, 0x6779, 0x1B0A, 0x9096, "Radeon HD 6450(0x1B0A-0x9096)"},
{0x1002, 0x6779, 0x1B0A, 0x9097, "Radeon HD 6450(0x1B0A-0x9097)"},
{0x1002, 0x6779, 0x1B0A, 0x90A8, "Radeon HD 6450A(0x1B0A-0x90A8)"},
{0x1002, 0x6779, 0x1B0A, 0x90B1, "Radeon HD 6450(0x1B0A-0x90B1)"},
{0x1002, 0x6779, 0x1B0A, 0x90B3, "Radeon HD 7450A(0x1B0A-0x90B3)"},
{0x1002, 0x6779, 0x1B0A, 0x90BB, "Radeon HD 7450A(0x1B0A-0x90BB)"},
{0x1002, 0x677B, 0xFFFF, 0xFFFF, "Caicos PRO [Radeon HD 7450](0x677B)"},
{0x1002, 0x6780, 0xFFFF, 0xFFFF, "Tahiti XT GL [FirePro W9000](0x6780)"},
{0x1002, 0x6784, 0xFFFF, 0xFFFF, "Tahiti [FirePro Series Graphics Adapter](0x6784)"},
{0x1002, 0x6788, 0xFFFF, 0xFFFF, "Tahiti [FirePro Series Graphics Adapter](0x6788)"},
{0x1002, 0x678A, 0xFFFF, 0xFFFF, "Tahiti PRO GL [FirePro Series](0x678A)"},
{0x1002, 0x678A, 0x1002, 0x030C, "FirePro W8000(0x1002-0x030C)"},
{0x1002, 0x678A, 0x1002, 0x0310, "FirePro S9000(0x1002-0x0310)"},
{0x1002, 0x678A, 0x1002, 0x0420, "Radeon Sky 700(0x1002-0x0420)"},
{0x1002, 0x678A, 0x1002, 0x0422, "Radeon Sky 900(0x1002-0x0422)"},
{0x1002, 0x678A, 0x1002, 0x0710, "FirePro S9050(0x1002-0x0710)"},
{0x1002, 0x678A, 0x1002, 0x0B0E, "FirePro S10000 Passive(0x1002-0x0B0E)"},
{0x1002, 0x678A, 0x1002, 0x0B2A, "FirePro S10000(0x1002-0x0B2A)"},
{0x1002, 0x678A, 0x1028, 0x030C, "FirePro W8000(0x1028-0x030C)"},
{0x1002, 0x678A, 0x1028, 0x0710, "FirePro S9000(0x1028-0x0710)"},
{0x1002, 0x6798, 0xFFFF, 0xFFFF, "Tahiti XT [Radeon HD 7970/8970 OEM / R9 280X](0x6798)"},
{0x1002, 0x6798, 0x1002, 0x3000, "Tahiti XT2 [Radeon HD 7970 GHz Edition](0x1002-0x3000)"},
{0x1002, 0x6798, 0x1002, 0x3001, "Tahiti XTL [Radeon R9 280X](0x1002-0x3001)"},
{0x1002, 0x6798, 0x1002, 0x4000, "Radeon HD 8970 OEM(0x1002-0x4000)"},
{0x1002, 0x6798, 0x1043, 0x041C, "HD 7970 DirectCU II(0x1043-0x041C)"},
{0x1002, 0x6798, 0x1043, 0x0420, "HD 7970 DirectCU II TOP(0x1043-0x0420)"},
{0x1002, 0x6798, 0x1043, 0x0444, "HD 7970 DirectCU II TOP(0x1043-0x0444)"},
{0x1002, 0x6798, 0x1043, 0x0448, "HD 7970 DirectCU II TOP(0x1043-0x0448)"},
{0x1002, 0x6798, 0x1043, 0x044A, "Tahiti XT2 [Matrix HD 7970](0x1043-0x044A)"},
{0x1002, 0x6798, 0x1043, 0x044C, "Tahiti XT2 [Matrix HD 7970 Platinum](0x1043-0x044C)"},
{0x1002, 0x6798, 0x1043, 0x3001, "Tahiti XTL [ROG Matrix R9 280X](0x1043-0x3001)"},
{0x1002, 0x6798, 0x1043, 0x3006, "Tahiti XTL [Radeon R9 280X DirectCU II TOP](0x1043-0x3006)"},
{0x1002, 0x6798, 0x1043, 0x9999, "ARES II(0x1043-0x9999)"},
{0x1002, 0x6798, 0x106B, 0x0127, "FirePro D700(0x106B-0x0127)"},
{0x1002, 0x6798, 0x106B, 0x0128, "FirePro D700(0x106B-0x0128)"},
{0x1002, 0x6798, 0x1092, 0x3000, "Tahiti XT2 [Radeon HD 7970 GHz Edition](0x1092-0x3000)"},
{0x1002, 0x6798, 0x1458, 0x2261, "Tahiti XT2 [Radeon HD 7970 GHz Edition OC](0x1458-0x2261)"},
{0x1002, 0x6798, 0x1458, 0x3001, "Tahiti XTL [Radeon R9 280X OC](0x1458-0x3001)"},
{0x1002, 0x6798, 0x1462, 0x2774, "HD 7970 TwinFrozr III Boost Edition OC(0x1462-0x2774)"},
{0x1002, 0x6798, 0x1682, 0x3001, "Tahiti XTL [Radeon R9 280X](0x1682-0x3001)"},
{0x1002, 0x6798, 0x1682, 0x3211, "Double D HD 7970 Black Edition(0x1682-0x3211)"},
{0x1002, 0x6798, 0x1682, 0x3213, "HD 7970 Black Edition(0x1682-0x3213)"},
{0x1002, 0x6798, 0x1682, 0x3214, "Double D HD 7970(0x1682-0x3214)"},
{0x1002, 0x6798, 0x1787, 0x201C, "HD 7970 IceQ X²(0x1787-0x201C)"},
{0x1002, 0x6798, 0x1787, 0x2317, "Radeon HD 7990(0x1787-0x2317)"},
{0x1002, 0x6798, 0x1787, 0x3000, "Tahiti XT2 [Radeon HD 7970 GHz Edition](0x1787-0x3000)"},
{0x1002, 0x679A, 0xFFFF, 0xFFFF, "Tahiti PRO [Radeon HD 7950/8950 OEM / R9 280](0x679A)"},
{0x1002, 0x679A, 0x1002, 0x0B01, "Radeon HD 8950 OEM(0x1002-0x0B01)"},
{0x1002, 0x679A, 0x1002, 0x3000, "Tahiti PRO2 [Radeon HD 7950 Boost](0x1002-0x3000)"},
{0x1002, 0x679A, 0x1462, 0x3000, "Radeon HD 8950 OEM(0x1462-0x3000)"},
{0x1002, 0x679A, 0x174B, 0xA003, "Radeon R9 280(0x174B-0xA003)"},
{0x1002, 0x679B, 0xFFFF, 0xFFFF, "Malta [Radeon HD 7990/8990 OEM](0x679B)"},
{0x1002, 0x679B, 0x1002, 0x0B28, "Radeon HD 8990 OEM(0x1002-0x0B28)"},
{0x1002, 0x679B, 0x1002, 0x0B2A, "Radeon HD 7990(0x1002-0x0B2A)"},
{0x1002, 0x679B, 0x1462, 0x8036, "Radeon HD 8990 OEM(0x1462-0x8036)"},
{0x1002, 0x679B, 0x148C, 0x8990, "Radeon HD 8990 OEM(0x148C-0x8990)"},
{0x1002, 0x679E, 0xFFFF, 0xFFFF, "Tahiti LE [Radeon HD 7870 XT](0x679E)"},
{0x1002, 0x679E, 0x106B, 0x0125, "FirePro D500(0x106B-0x0125)"},
{0x1002, 0x679E, 0x106B, 0x0126, "FirePro D500(0x106B-0x0126)"},
{0x1002, 0x679E, 0x1787, 0x2328, "Radeon HD 7870 Black Edition 2 GB GDDR5 [2GBD5-2DHV3E](0x1787-0x2328)"},
{0x1002, 0x679F, 0xFFFF, 0xFFFF, "Tahiti(0x679F)"},
{0x1002, 0x67A0, 0xFFFF, 0xFFFF, "Hawaii XT GL [FirePro W9100](0x67A0)"},
{0x1002, 0x67A0, 0x1002, 0x0335, "FirePro S9150(0x1002-0x0335)"},
{0x1002, 0x67A0, 0x1002, 0x0735, "FirePro S9170(0x1002-0x0735)"},
{0x1002, 0x67A0, 0x1028, 0x031F, "FirePro W9100(0x1028-0x031F)"},
{0x1002, 0x67A0, 0x1028, 0x0335, "FirePro S9150(0x1028-0x0335)"},
{0x1002, 0x67A1, 0xFFFF, 0xFFFF, "Hawaii PRO GL [FirePro W8100](0x67A1)"},
{0x1002, 0x67A1, 0x1002, 0x0335, "FirePro S9100(0x1002-0x0335)"},
{0x1002, 0x67A1, 0x1028, 0x0335, "FirePro S9100(0x1028-0x0335)"},
{0x1002, 0x67A2, 0xFFFF, 0xFFFF, "Hawaii GL(0x67A2)"},
{0x1002, 0x67A8, 0xFFFF, 0xFFFF, "Hawaii(0x67A8)"},
{0x1002, 0x67A9, 0xFFFF, 0xFFFF, "Hawaii(0x67A9)"},
{0x1002, 0x67AA, 0xFFFF, 0xFFFF, "Hawaii(0x67AA)"},
{0x1002, 0x67B0, 0xFFFF, 0xFFFF, "Hawaii XT / Grenada XT [Radeon R9 290X/390X](0x67B0)"},
{0x1002, 0x67B0, 0x1028, 0x0B00, "Grenada XT [Radeon R9 390X](0x1028-0x0B00)"},
{0x1002, 0x67B0, 0x103C, 0x6566, "Radeon R9 390X(0x103C-0x6566)"},
{0x1002, 0x67B0, 0x1043, 0x046A, "R9 290X DirectCU II(0x1043-0x046A)"},
{0x1002, 0x67B0, 0x1043, 0x046C, "R9 290X DirectCU II OC(0x1043-0x046C)"},
{0x1002, 0x67B0, 0x1043, 0x0474, "Matrix R9 290X Platinum(0x1043-0x0474)"},
{0x1002, 0x67B0, 0x1043, 0x0476, "ARES III(0x1043-0x0476)"},
{0x1002, 0x67B0, 0x1043, 0x04D7, "Radeon R9 390X(0x1043-0x04D7)"},
{0x1002, 0x67B0, 0x1043, 0x04DB, "Radeon R9 390X(0x1043-0x04DB)"},
{0x1002, 0x67B0, 0x1043, 0x04DF, "Radeon R9 390X(0x1043-0x04DF)"},
{0x1002, 0x67B0, 0x1043, 0x04E9, "Radeon R9 390X(0x1043-0x04E9)"},
{0x1002, 0x67B0, 0x1458, 0x227C, "R9 290X WindForce 3X OC(0x1458-0x227C)"},
{0x1002, 0x67B0, 0x1458, 0x2281, "R9 290X WindForce 3X OC(0x1458-0x2281)"},
{0x1002, 0x67B0, 0x1458, 0x228C, "R9 290X WindForce 3X(0x1458-0x228C)"},
{0x1002, 0x67B0, 0x1458, 0x228D, "R9 290X WindForce 3X OC(0x1458-0x228D)"},
{0x1002, 0x67B0, 0x1458, 0x2290, "R9 290X WindForce 3X(0x1458-0x2290)"},
{0x1002, 0x67B0, 0x1458, 0x22BC, "Radeon R9 390X(0x1458-0x22BC)"},
{0x1002, 0x67B0, 0x1458, 0x22C1, "Grenada PRO [Radeon R9 390](0x1458-0x22C1)"},
{0x1002, 0x67B0, 0x1462, 0x2015, "Radeon R9 390X(0x1462-0x2015)"},
{0x1002, 0x67B0, 0x1462, 0x3070, "R9 290X Lightning(0x1462-0x3070)"},
{0x1002, 0x67B0, 0x1462, 0x3071, "R9 290X Lightning(0x1462-0x3071)"},
{0x1002, 0x67B0, 0x1462, 0x3072, "R9 290X Lightning LE(0x1462-0x3072)"},
{0x1002, 0x67B0, 0x1462, 0x3080, "R9 290X Gaming(0x1462-0x3080)"},
{0x1002, 0x67B0, 0x1462, 0x3082, "R9 290X Gaming OC(0x1462-0x3082)"},
{0x1002, 0x67B0, 0x148C, 0x2347, "Devil 13 Dual Core R9 290X(0x148C-0x2347)"},
{0x1002, 0x67B0, 0x148C, 0x2357, "Grenada XT [Radeon R9 390X](0x148C-0x2357)"},
{0x1002, 0x67B0, 0x1682, 0x9290, "Double Dissipation R9 290X(0x1682-0x9290)"},
{0x1002, 0x67B0, 0x1682, 0x9395, "Grenada XT [Radeon R9 390X](0x1682-0x9395)"},
{0x1002, 0x67B0, 0x174B, 0x0E34, "Radeon R9 390X(0x174B-0x0E34)"},
{0x1002, 0x67B0, 0x174B, 0xE282, "Vapor-X R9 290X Tri-X OC(0x174B-0xE282)"},
{0x1002, 0x67B0, 0x174B, 0xE285, "R9 290X Tri-X OC(0x174B-0xE285)"},
{0x1002, 0x67B0, 0x174B, 0xE324, "Grenada XT2 [Radeon R9 390X](0x174B-0xE324)"},
{0x1002, 0x67B0, 0x1787, 0x2020, "R9 290X IceQ X² Turbo(0x1787-0x2020)"},
{0x1002, 0x67B0, 0x1787, 0x2357, "Grenada XT [Radeon R9 390X](0x1787-0x2357)"},
{0x1002, 0x67B1, 0xFFFF, 0xFFFF, "Hawaii PRO [Radeon R9 290/390](0x67B1)"},
{0x1002, 0x67B1, 0x1043, 0x04DD, "STRIX R9 390(0x1043-0x04DD)"},
{0x1002, 0x67B1, 0x148C, 0x2358, "Radeon R9 390(0x148C-0x2358)"},
{0x1002, 0x67B1, 0x174B, 0xE324, "Sapphire Nitro R9 390(0x174B-0xE324)"},
{0x1002, 0x67B8, 0xFFFF, 0xFFFF, "Hawaii XT [Radeon R9 290X Engineering Sample](0x67B8)"},
{0x1002, 0x67B9, 0xFFFF, 0xFFFF, "Vesuvius [Radeon R9 295X2](0x67B9)"},
{0x1002, 0x67BE, 0xFFFF, 0xFFFF, "Hawaii LE(0x67BE)"},
{0x1002, 0x67C0, 0xFFFF, 0xFFFF, "Ellesmere [Radeon Pro WX 7100 Mobile](0x67C0)"},
{0x1002, 0x67C2, 0xFFFF, 0xFFFF, "Ellesmere [Radeon Pro V7300X / V7350x2](0x67C2)"},
{0x1002, 0x67C4, 0xFFFF, 0xFFFF, "Ellesmere [Radeon Pro WX 7100](0x67C4)"},
{0x1002, 0x67C4, 0x1002, 0x0336, "Radeon Pro Duo(0x1002-0x0336)"},
{0x1002, 0x67C4, 0x1002, 0x1336, "Radeon Pro Duo(0x1002-0x1336)"},
{0x1002, 0x67C7, 0xFFFF, 0xFFFF, "Ellesmere [Radeon Pro WX 5100](0x67C7)"},
{0x1002, 0x67CA, 0xFFFF, 0xFFFF, "Ellesmere [Polaris10](0x67CA)"},
{0x1002, 0x67CC, 0xFFFF, 0xFFFF, "Ellesmere [Polaris10](0x67CC)"},
{0x1002, 0x67CF, 0xFFFF, 0xFFFF, "Ellesmere [Polaris10](0x67CF)"},
{0x1002, 0x67D0, 0xFFFF, 0xFFFF, "Ellesmere [Radeon Pro V7300X / V7350x2](0x67D0)"},
{0x1002, 0x67D4, 0xFFFF, 0xFFFF, "Ellesmere [Radeon Pro WX 7100 / Barco MXRT-8700](0x67D4)"},
{0x1002, 0x67D7, 0xFFFF, 0xFFFF, "Ellesmere [Radeon Pro WX 5100 / Barco MXRT-6700](0x67D7)"},
{0x1002, 0x67DF, 0xFFFF, 0xFFFF, "Ellesmere [Radeon RX 470/480/570/570X/580/580X/590](0x67DF)"},
{0x1002, 0x67DF, 0x1002, 0x0B37, "Radeon RX 480(0x1002-0x0B37)"},
{0x1002, 0x67DF, 0x1028, 0x1722, "Radeon RX 570X(0x1028-0x1722)"},
{0x1002, 0x67DF, 0x1028, 0x1723, "Radeon RX 580X(0x1028-0x1723)"},
{0x1002, 0x67DF, 0x103C, 0x840E, "Radeon RX 580 4GB(0x103C-0x840E)"},
{0x1002, 0x67DF, 0x1043, 0x04A8, "Radeon RX 480(0x1043-0x04A8)"},
{0x1002, 0x67DF, 0x1043, 0x04B0, "Radeon RX 470(0x1043-0x04B0)"},
{0x1002, 0x67DF, 0x1043, 0x04FB, "Radeon RX 480(0x1043-0x04FB)"},
{0x1002, 0x67DF, 0x1043, 0x04FD, "Radeon RX 480 8GB(0x1043-0x04FD)"},
{0x1002, 0x67DF, 0x1043, 0x056A, "Radeon RX 590(0x1043-0x056A)"},
{0x1002, 0x67DF, 0x106B, 0x0161, "Radeon Pro 580(0x106B-0x0161)"},
{0x1002, 0x67DF, 0x106B, 0x0162, "Radeon Pro 575(0x106B-0x0162)"},
{0x1002, 0x67DF, 0x106B, 0x0163, "Radeon Pro 570(0x106B-0x0163)"},
{0x1002, 0x67DF, 0x1458, 0x22F0, "Radeon RX 570(0x1458-0x22F0)"},
{0x1002, 0x67DF, 0x1458, 0x22F7, "Radeon RX 570 Gaming 4G(0x1458-0x22F7)"},
{0x1002, 0x67DF, 0x1462, 0x3411, "Radeon RX 470(0x1462-0x3411)"},
{0x1002, 0x67DF, 0x1462, 0x3413, "Radeon RX 480 Gaming X 8GB(0x1462-0x3413)"},
{0x1002, 0x67DF, 0x1462, 0x3416, "Radeon RX 570(0x1462-0x3416)"},
{0x1002, 0x67DF, 0x1462, 0x3418, "Radeon RX 580 ARMOR 8G OC(0x1462-0x3418)"},
{0x1002, 0x67DF, 0x1462, 0x341B, "Radeon RX 570 Armor 8G OC(0x1462-0x341B)"},
{0x1002, 0x67DF, 0x1462, 0x341E, "Radeon RX 570 Armor 4G OC(0x1462-0x341E)"},
{0x1002, 0x67DF, 0x1462, 0x809E, "Radeon RX 480 4GB(0x1462-0x809E)"},
{0x1002, 0x67DF, 0x1462, 0x8A92, "Radeon RX 580(0x1462-0x8A92)"},
{0x1002, 0x67DF, 0x148C, 0x2372, "Radeon RX 480 [Red Dragon](0x148C-0x2372)"},
{0x1002, 0x67DF, 0x148C, 0x2373, "Radeon RX 470(0x148C-0x2373)"},
{0x1002, 0x67DF, 0x148C, 0x2377, "Red Devil RX 580 8G Golden(0x148C-0x2377)"},
{0x1002, 0x67DF, 0x148C, 0x2378, "Radeon RX 580(0x148C-0x2378)"},
{0x1002, 0x67DF, 0x148C, 0x2379, "Radeon RX 570 4G [Red Dragon](0x148C-0x2379)"},
{0x1002, 0x67DF, 0x148C, 0x2391, "Radeon RX 590 [Red Devil](0x148C-0x2391)"},
{0x1002, 0x67DF, 0x1682, 0x9470, "Radeon RX 470(0x1682-0x9470)"},
{0x1002, 0x67DF, 0x1682, 0x9480, "Radeon RX 480(0x1682-0x9480)"},
{0x1002, 0x67DF, 0x1682, 0x9587, "Radeon RX 590 FATBOY 8GB(0x1682-0x9587)"},
{0x1002, 0x67DF, 0x1682, 0x9588, "Radeon RX 580 XTR(0x1682-0x9588)"},
{0x1002, 0x67DF, 0x1682, 0xC570, "Radeon RX 570(0x1682-0xC570)"},
{0x1002, 0x67DF, 0x1682, 0xC580, "Radeon RX 580(0x1682-0xC580)"},
{0x1002, 0x67DF, 0x174B, 0xE347, "Radeon RX 470/480(0x174B-0xE347)"},
{0x1002, 0x67DF, 0x174B, 0xE349, "Radeon RX 470(0x174B-0xE349)"},
{0x1002, 0x67DF, 0x1787, 0xA470, "Radeon RX 470(0x1787-0xA470)"},
{0x1002, 0x67DF, 0x1787, 0xA480, "Radeon RX 480(0x1787-0xA480)"},
{0x1002, 0x67DF, 0x1849, 0x5001, "Phantom Gaming X RX 580 OC(0x1849-0x5001)"},
{0x1002, 0x67DF, 0x1849, 0x5030, "Phantom Gaming D Radeon RX580 8G OC(0x1849-0x5030)"},
{0x1002, 0x67DF, 0x1DA2, 0xE343, "Radeon RX 570 Pulse ITX 4GB(0x1DA2-0xE343)"},
{0x1002, 0x67DF, 0x1DA2, 0xE353, "Radeon RX 570 Pulse 4GB(0x1DA2-0xE353)"},
{0x1002, 0x67DF, 0x1DA2, 0xE366, "Nitro+ Radeon RX 570/580/590(0x1DA2-0xE366)"},
{0x1002, 0x67DF, 0x1DA2, 0xE387, "Radeon RX 580 Pulse 4GB(0x1DA2-0xE387)"},
{0x1002, 0x67E0, 0xFFFF, 0xFFFF, "Baffin [Radeon Pro WX 4170](0x67E0)"},
{0x1002, 0x67E0, 0x103C, 0x8270, "Radeon Pro WX 4170(0x103C-0x8270)"},
{0x1002, 0x67E0, 0x103C, 0x8272, "Radeon Pro WX 4170(0x103C-0x8272)"},
{0x1002, 0x67E1, 0xFFFF, 0xFFFF, "Baffin [Polaris11](0x67E1)"},
{0x1002, 0x67E3, 0xFFFF, 0xFFFF, "Baffin [Radeon Pro WX 4100](0x67E3)"},
{0x1002, 0x67E8, 0xFFFF, 0xFFFF, "Baffin [Radeon Pro WX 4130/4150](0x67E8)"},
{0x1002, 0x67E8, 0x1028, 0x075D, "Radeon Pro WX 4150(0x1028-0x075D)"},
{0x1002, 0x67E8, 0x1028, 0x07B0, "Radeon Pro WX 4130/4150(0x1028-0x07B0)"},
{0x1002, 0x67E8, 0x1028, 0x07B1, "Radeon Pro WX 4130(0x1028-0x07B1)"},
{0x1002, 0x67E8, 0x1028, 0x175D, "Radeon Pro WX 4150(0x1028-0x175D)"},
{0x1002, 0x67E8, 0x1028, 0x17B0, "Radeon Pro WX 4130/4150(0x1028-0x17B0)"},
{0x1002, 0x67E8, 0x1028, 0x17B1, "Radeon Pro WX 4130(0x1028-0x17B1)"},
{0x1002, 0x67E8, 0x103C, 0x8275, "Radeon Pro WX 4150(0x103C-0x8275)"},
{0x1002, 0x67E8, 0x103C, 0x8277, "Radeon Pro WX 4150(0x103C-0x8277)"},
{0x1002, 0x67E9, 0xFFFF, 0xFFFF, "Baffin [Polaris11](0x67E9)"},
{0x1002, 0x67EB, 0xFFFF, 0xFFFF, "Baffin [Radeon Pro V5300X](0x67EB)"},
{0x1002, 0x67EF, 0xFFFF, 0xFFFF, "Baffin [Radeon RX 460/560D / Pro 450/455/460/555/555X/560/560X](0x67EF)"},
{0x1002, 0x67EF, 0x1025, 0x1367, "RX560X 4GB(0x1025-0x1367)"},
{0x1002, 0x67EF, 0x1028, 0x1703, "RX 560D OEM OC 2 GB(0x1028-0x1703)"},
{0x1002, 0x67EF, 0x103C, 0x3421, "Radeon RX 460(0x103C-0x3421)"},
{0x1002, 0x67EF, 0x1043, 0x0561, "AREZ Radeon RX 560(0x1043-0x0561)"},
{0x1002, 0x67EF, 0x106B, 0x0160, "Radeon Pro 460(0x106B-0x0160)"},
{0x1002, 0x67EF, 0x106B, 0x0166, "Radeon Pro 455(0x106B-0x0166)"},
{0x1002, 0x67EF, 0x106B, 0x0167, "Radeon Pro 450(0x106B-0x0167)"},
{0x1002, 0x67EF, 0x106B, 0x0179, "Radeon Pro 560(0x106B-0x0179)"},
{0x1002, 0x67EF, 0x106B, 0x017A, "Radeon Pro 555(0x106B-0x017A)"},
{0x1002, 0x67EF, 0x106B, 0x018F, "Radeon Pro 560X(0x106B-0x018F)"},
{0x1002, 0x67EF, 0x106B, 0x0190, "Radeon Pro 555X(0x106B-0x0190)"},
{0x1002, 0x67EF, 0x1642, 0x1727, "Polaris 21 XL [Radeon RX 560D](0x1642-0x1727)"},
{0x1002, 0x67EF, 0x1682, 0x956D, "Polaris 21 XL [Radeon RX 560D](0x1682-0x956D)"},
{0x1002, 0x67FF, 0xFFFF, 0xFFFF, "Baffin [Radeon RX 550 640SP / RX 560/560X](0x67FF)"},
{0x1002, 0x67FF, 0x1002, 0x0B04, "Radeon RX 560(0x1002-0x0B04)"},
{0x1002, 0x67FF, 0x1028, 0x1721, "Radeon RX 560X(0x1028-0x1721)"},
{0x1002, 0x67FF, 0x1028, 0x1726, "Radeon RX 560DX(0x1028-0x1726)"},
{0x1002, 0x67FF, 0x103C, 0x8479, "Radeon RX 560X Mobile(0x103C-0x8479)"},
{0x1002, 0x67FF, 0x1043, 0x04BC, "Radeon RX 560(0x1043-0x04BC)"},
{0x1002, 0x67FF, 0x1043, 0x052F, "Radeon RX 560(0x1043-0x052F)"},
{0x1002, 0x67FF, 0x1458, 0x22ED, "Radeon RX 560(0x1458-0x22ED)"},
{0x1002, 0x67FF, 0x148C, 0x2381, "Radeon RX 560(0x148C-0x2381)"},
{0x1002, 0x67FF, 0x1682, 0x9560, "Radeon RX 560(0x1682-0x9560)"},
{0x1002, 0x67FF, 0x1DA2, 0xE348, "Radeon RX 560(0x1DA2-0xE348)"},
{0x1002, 0x67FF, 0x1DA2, 0xE367, "Radeon RX 550 640SP(0x1DA2-0xE367)"},
{0x1002, 0x6800, 0xFFFF, 0xFFFF, "Wimbledon XT [Radeon HD 7970M](0x6800)"},
{0x1002, 0x6800, 0x1002, 0x0124, "Radeon HD 7970M(0x1002-0x0124)"},
{0x1002, 0x6800, 0x8086, 0x2110, "Radeon HD 7970M(0x8086-0x2110)"},
{0x1002, 0x6800, 0x8086, 0x2111, "Radeon HD 7970M(0x8086-0x2111)"},
{0x1002, 0x6801, 0xFFFF, 0xFFFF, "Neptune XT [Radeon HD 8970M](0x6801)"},
{0x1002, 0x6801, 0x1002, 0x0124, "Radeon HD 8970M(0x1002-0x0124)"},
{0x1002, 0x6801, 0x1462, 0x1117, "Radeon R9 M290X(0x1462-0x1117)"},
{0x1002, 0x6801, 0x8086, 0x2110, "Radeon HD 8970M(0x8086-0x2110)"},
{0x1002, 0x6801, 0x8086, 0x2111, "Radeon HD 8970M(0x8086-0x2111)"},
{0x1002, 0x6802, 0xFFFF, 0xFFFF, "Wimbledon(0x6802)"},
{0x1002, 0x6806, 0xFFFF, 0xFFFF, "Neptune(0x6806)"},
{0x1002, 0x6808, 0xFFFF, 0xFFFF, "Pitcairn XT GL [FirePro W7000](0x6808)"},
{0x1002, 0x6808, 0x1002, 0x0310, "FirePro S7000(0x1002-0x0310)"},
{0x1002, 0x6808, 0x1002, 0x0420, "Radeon Sky 500(0x1002-0x0420)"},
{0x1002, 0x6808, 0x103C, 0x030C, "MED-X7000(0x103C-0x030C)"},
{0x1002, 0x6808, 0x13CC, 0x3D25, "MXRT-7500(0x13CC-0x3D25)"},
{0x1002, 0x6808, 0x15C3, 0x030C, "MED-X7000(0x15C3-0x030C)"},
{0x1002, 0x6809, 0xFFFF, 0xFFFF, "Pitcairn LE GL [FirePro W5000](0x6809)"},
{0x1002, 0x6809, 0x13CC, 0x3D23, "MXRT-5500(0x13CC-0x3D23)"},
{0x1002, 0x6809, 0x13CC, 0x3D24, "MXRT-5550(0x13CC-0x3D24)"},
{0x1002, 0x6809, 0x15C3, 0x0B06, "MED-X5000(0x15C3-0x0B06)"},
{0x1002, 0x6810, 0xFFFF, 0xFFFF, "Curacao XT / Trinidad XT [Radeon R7 370 / R9 270X/370X](0x6810)"},
{0x1002, 0x6810, 0x106B, 0x012A, "FirePro D300(0x106B-0x012A)"},
{0x1002, 0x6810, 0x106B, 0x012B, "FirePro D300(0x106B-0x012B)"},
{0x1002, 0x6810, 0x148C, 0x0908, "Radeon R9 370 OEM(0x148C-0x0908)"},
{0x1002, 0x6810, 0x1682, 0x7370, "Radeon R7 370(0x1682-0x7370)"},
{0x1002, 0x6811, 0xFFFF, 0xFFFF, "Curacao PRO [Radeon R7 370 / R9 270/370 OEM](0x6811)"},
{0x1002, 0x6811, 0x1028, 0x0B00, "Trinidad PRO [Radeon R9 370 OEM](0x1028-0x0B00)"},
{0x1002, 0x6811, 0x1043, 0x2016, "Trinidad PRO [Radeon R9 370 OEM](0x1043-0x2016)"},
{0x1002, 0x6811, 0x1458, 0x2016, "Trinidad PRO [Radeon R9 370 OEM](0x1458-0x2016)"},
{0x1002, 0x6811, 0x1462, 0x2016, "Trinidad PRO [Radeon R9 370 OEM](0x1462-0x2016)"},
{0x1002, 0x6811, 0x1462, 0x3050, "R9 270 Gaming OC(0x1462-0x3050)"},
{0x1002, 0x6811, 0x148C, 0x2016, "Trinidad PRO [Radeon R9 370 OEM](0x148C-0x2016)"},
{0x1002, 0x6811, 0x1682, 0x2015, "Trinidad PRO [Radeon R7 370](0x1682-0x2015)"},
{0x1002, 0x6811, 0x174B, 0x2015, "NITRO Radeon R7 370(0x174B-0x2015)"},
{0x1002, 0x6811, 0x174B, 0x2016, "Trinidad PRO [Radeon R9 370 OEM](0x174B-0x2016)"},
{0x1002, 0x6811, 0x1787, 0x2016, "Trinidad PRO [Radeon R9 370 OEM](0x1787-0x2016)"},
{0x1002, 0x6816, 0xFFFF, 0xFFFF, "Pitcairn(0x6816)"},
{0x1002, 0x6817, 0xFFFF, 0xFFFF, "Pitcairn(0x6817)"},
{0x1002, 0x6818, 0xFFFF, 0xFFFF, "Pitcairn XT [Radeon HD 7870 GHz Edition](0x6818)"},
{0x1002, 0x6818, 0x1002, 0x0B05, "Radeon HD 8870 OEM(0x1002-0x0B05)"},
{0x1002, 0x6818, 0x174B, 0x8B04, "Radeon HD 8860(0x174B-0x8B04)"},
{0x1002, 0x6819, 0xFFFF, 0xFFFF, "Pitcairn PRO [Radeon HD 7850 / R7 265 / R9 270 1024SP](0x6819)"},
{0x1002, 0x6819, 0x1043, 0x042C, "Radeon HD 7850(0x1043-0x042C)"},
{0x1002, 0x6819, 0x1682, 0x7269, "Radeon R9 270 1024SP(0x1682-0x7269)"},
{0x1002, 0x6819, 0x1682, 0x9278, "Radeon R9 270 1024SP(0x1682-0x9278)"},
{0x1002, 0x6819, 0x174B, 0xA008, "Radeon R9 270 1024SP(0x174B-0xA008)"},
{0x1002, 0x6819, 0x174B, 0xE221, "Radeon HD 7850 2GB GDDR5 DVI-I/DVI-D/HDMI/DP(0x174B-0xE221)"},
{0x1002, 0x6820, 0xFFFF, 0xFFFF, "Venus XTX [Radeon HD 8890M / R9 M275X/M375X](0x6820)"},
{0x1002, 0x6820, 0x103C, 0x1851, "Radeon HD 7750M(0x103C-0x1851)"},
{0x1002, 0x6820, 0x17AA, 0x3643, "Radeon R9 A375(0x17AA-0x3643)"},
{0x1002, 0x6820, 0x17AA, 0x3801, "Radeon R9 M275(0x17AA-0x3801)"},
{0x1002, 0x6820, 0x17AA, 0x3824, "Radeon R9 M375(0x17AA-0x3824)"},
{0x1002, 0x6820, 0x1DA2, 0xE26A, "Radeon R7 250(0x1DA2-0xE26A)"},
{0x1002, 0x6821, 0xFFFF, 0xFFFF, "Venus XT [Radeon HD 8870M / R9 M270X/M370X](0x6821)"},
{0x1002, 0x6821, 0x1002, 0x031E, "FirePro SX4000(0x1002-0x031E)"},
{0x1002, 0x6821, 0x1028, 0x05CC, "FirePro M5100(0x1028-0x05CC)"},
{0x1002, 0x6821, 0x1028, 0x15CC, "FirePro M5100(0x1028-0x15CC)"},
{0x1002, 0x6821, 0x106B, 0x0149, "Radeon R9 M370X Mac Edition(0x106B-0x0149)"},
{0x1002, 0x6822, 0xFFFF, 0xFFFF, "Venus PRO [Radeon E8860](0x6822)"},
{0x1002, 0x6823, 0xFFFF, 0xFFFF, "Venus PRO [Radeon HD 8850M / R9 M265X](0x6823)"},
{0x1002, 0x6825, 0xFFFF, 0xFFFF, "Heathrow XT [Radeon HD 7870M](0x6825)"},
{0x1002, 0x6825, 0x1028, 0x053F, "FirePro M6000(0x1028-0x053F)"},
{0x1002, 0x6825, 0x1028, 0x05CD, "FirePro M6000(0x1028-0x05CD)"},
{0x1002, 0x6825, 0x1028, 0x15CD, "FirePro M6000(0x1028-0x15CD)"},
{0x1002, 0x6825, 0x103C, 0x176C, "FirePro M6000(0x103C-0x176C)"},
{0x1002, 0x6825, 0x8086, 0x2111, "Chelsea PRO(0x8086-0x2111)"},
{0x1002, 0x6826, 0xFFFF, 0xFFFF, "Chelsea LP [Radeon HD 7700M Series](0x6826)"},
{0x1002, 0x6827, 0xFFFF, 0xFFFF, "Heathrow PRO [Radeon HD 7850M/8850M](0x6827)"},
{0x1002, 0x6828, 0xFFFF, 0xFFFF, "Cape Verde PRO [FirePro W600](0x6828)"},
{0x1002, 0x6828, 0x15C3, 0x2B1E, "MED-X6000(0x15C3-0x2B1E)"},
{0x1002, 0x6829, 0xFFFF, 0xFFFF, "Cape Verde(0x6829)"},
{0x1002, 0x682A, 0xFFFF, 0xFFFF, "Venus PRO(0x682A)"},
{0x1002, 0x682B, 0xFFFF, 0xFFFF, "Cape Verde PRO / Venus LE / Tropo PRO-L [Radeon HD 8830M / R7 250 / R7 M465X](0x682B)"},
{0x1002, 0x682B, 0x0128, 0x079C, "Radeon R7 465X(0x0128-0x079C)"},
{0x1002, 0x682B, 0x1462, 0x3012, "Radeon R7 250(0x1462-0x3012)"},
{0x1002, 0x682C, 0xFFFF, 0xFFFF, "Cape Verde GL [FirePro W4100](0x682C)"},
{0x1002, 0x682D, 0xFFFF, 0xFFFF, "Chelsea XT GL [FirePro M4000](0x682D)"},
{0x1002, 0x682F, 0xFFFF, 0xFFFF, "Chelsea LP [Radeon HD 7730M](0x682F)"},
{0x1002, 0x682F, 0x103C, 0x1851, "Radeon HD 7750M(0x103C-0x1851)"},
{0x1002, 0x6835, 0xFFFF, 0xFFFF, "Cape Verde PRX [Radeon R9 255 OEM](0x6835)"},
{0x1002, 0x6837, 0xFFFF, 0xFFFF, "Cape Verde LE [Radeon HD 7730/8730](0x6837)"},
{0x1002, 0x6837, 0x1462, 0x2796, "Radeon HD 8730(0x1462-0x2796)"},
{0x1002, 0x6837, 0x1462, 0x8092, "Radeon HD 8730(0x1462-0x8092)"},
{0x1002, 0x6837, 0x148C, 0x8730, "Radeon HD 8730(0x148C-0x8730)"},
{0x1002, 0x6837, 0x1787, 0x3000, "Radeon HD 6570(0x1787-0x3000)"},
{0x1002, 0x683D, 0xFFFF, 0xFFFF, "Cape Verde XT [Radeon HD 7770/8760 / R7 250X](0x683D)"},
{0x1002, 0x683D, 0x1002, 0x0030, "Radeon HD 8760 OEM(0x1002-0x0030)"},
{0x1002, 0x683D, 0x1019, 0x0030, "Radeon HD 8760 OEM(0x1019-0x0030)"},
{0x1002, 0x683D, 0x103C, 0x6890, "Radeon HD 8760 OEM(0x103C-0x6890)"},
{0x1002, 0x683D, 0x1043, 0x8760, "Radeon HD 8760 OEM(0x1043-0x8760)"},
{0x1002, 0x683D, 0x1462, 0x2710, "R7770-PMD1GD5(0x1462-0x2710)"},
{0x1002, 0x683D, 0x174B, 0x8304, "Radeon HD 8760 OEM(0x174B-0x8304)"},
{0x1002, 0x683F, 0xFFFF, 0xFFFF, "Cape Verde PRO [Radeon HD 7750/8740 / R7 250E](0x683F)"},
{0x1002, 0x683F, 0x1462, 0x2790, "Radeon HD 8740(0x1462-0x2790)"},
{0x1002, 0x683F, 0x1462, 0x2791, "Radeon HD 8740(0x1462-0x2791)"},
{0x1002, 0x683F, 0x1642, 0x3B97, "Radeon HD 8740(0x1642-0x3B97)"},
{0x1002, 0x6840, 0xFFFF, 0xFFFF, "Thames [Radeon HD 7500M/7600M Series](0x6840)"},
{0x1002, 0x6840, 0x1025, 0x050E, "Radeon HD 7670M(0x1025-0x050E)"},
{0x1002, 0x6840, 0x1025, 0x050F, "Radeon HD 7670M(0x1025-0x050F)"},
{0x1002, 0x6840, 0x1025, 0x0513, "Radeon HD 7670M(0x1025-0x0513)"},
{0x1002, 0x6840, 0x1025, 0x0514, "Radeon HD 7670M(0x1025-0x0514)"},
{0x1002, 0x6840, 0x1025, 0x056D, "Radeon HD 7670M(0x1025-0x056D)"},
{0x1002, 0x6840, 0x1025, 0x059A, "Radeon HD 7670M(0x1025-0x059A)"},
{0x1002, 0x6840, 0x1025, 0x059B, "Radeon HD 7670M(0x1025-0x059B)"},
{0x1002, 0x6840, 0x1025, 0x059E, "Radeon HD 7670M(0x1025-0x059E)"},
{0x1002, 0x6840, 0x1025, 0x0600, "Radeon HD 7670M(0x1025-0x0600)"},
{0x1002, 0x6840, 0x1025, 0x0606, "Radeon HD 7670M(0x1025-0x0606)"},
{0x1002, 0x6840, 0x1025, 0x0696, "Radeon HD 7650M(0x1025-0x0696)"},
{0x1002, 0x6840, 0x1025, 0x0697, "Radeon HD 7650M(0x1025-0x0697)"},
{0x1002, 0x6840, 0x1025, 0x0698, "Radeon HD 7650M(0x1025-0x0698)"},
{0x1002, 0x6840, 0x1025, 0x0699, "Radeon HD 7650M(0x1025-0x0699)"},
{0x1002, 0x6840, 0x1025, 0x0757, "Radeon HD 7670M(0x1025-0x0757)"},
{0x1002, 0x6840, 0x1028, 0x056A, "Radeon HD 7670M(0x1028-0x056A)"},
{0x1002, 0x6840, 0x1028, 0x056E, "Radeon HD 7670M(0x1028-0x056E)"},
{0x1002, 0x6840, 0x1028, 0x0598, "Radeon HD 7670M(0x1028-0x0598)"},
{0x1002, 0x6840, 0x1028, 0x059D, "Radeon HD 7670M(0x1028-0x059D)"},
{0x1002, 0x6840, 0x1028, 0x05A3, "Radeon HD 7670M(0x1028-0x05A3)"},
{0x1002, 0x6840, 0x1028, 0x05B9, "Radeon HD 7670M(0x1028-0x05B9)"},
{0x1002, 0x6840, 0x1028, 0x05BB, "Radeon HD 7670M(0x1028-0x05BB)"},
{0x1002, 0x6840, 0x103C, 0x1789, "FirePro M2000(0x103C-0x1789)"},
{0x1002, 0x6840, 0x103C, 0x17F1, "Radeon HD 7570M(0x103C-0x17F1)"},
{0x1002, 0x6840, 0x103C, 0x17F4, "Radeon HD 7650M(0x103C-0x17F4)"},
{0x1002, 0x6840, 0x103C, 0x1813, "Radeon HD 7590M(0x103C-0x1813)"},
{0x1002, 0x6840, 0x103C, 0x182F, "Radeon HD 7670M(0x103C-0x182F)"},
{0x1002, 0x6840, 0x103C, 0x1830, "Radeon HD 7670M(0x103C-0x1830)"},
{0x1002, 0x6840, 0x103C, 0x1835, "Radeon HD 7670M(0x103C-0x1835)"},
{0x1002, 0x6840, 0x103C, 0x183A, "Radeon HD 7670M(0x103C-0x183A)"},
{0x1002, 0x6840, 0x103C, 0x183C, "Radeon HD 7670M(0x103C-0x183C)"},
{0x1002, 0x6840, 0x103C, 0x183E, "Radeon HD 7670M(0x103C-0x183E)"},
{0x1002, 0x6840, 0x103C, 0x1840, "Radeon HD 7670M(0x103C-0x1840)"},
{0x1002, 0x6840, 0x103C, 0x1842, "Radeon HD 7670M(0x103C-0x1842)"},
{0x1002, 0x6840, 0x103C, 0x1844, "Radeon HD 7670M(0x103C-0x1844)"},
{0x1002, 0x6840, 0x103C, 0x1848, "Radeon HD 7670M(0x103C-0x1848)"},
{0x1002, 0x6840, 0x103C, 0x184A, "Radeon HD 7670M(0x103C-0x184A)"},
{0x1002, 0x6840, 0x103C, 0x184C, "Radeon HD 7670M(0x103C-0x184C)"},
{0x1002, 0x6840, 0x103C, 0x1895, "Radeon HD 7670M(0x103C-0x1895)"},
{0x1002, 0x6840, 0x103C, 0x1897, "Radeon HD 7670M(0x103C-0x1897)"},
{0x1002, 0x6840, 0x103C, 0x18A5, "Radeon HD 7670M(0x103C-0x18A5)"},
{0x1002, 0x6840, 0x103C, 0x18A7, "Radeon HD 7670M(0x103C-0x18A7)"},
{0x1002, 0x6840, 0x103C, 0x18F4, "Radeon HD 7670M(0x103C-0x18F4)"},
{0x1002, 0x6840, 0x1043, 0x100A, "Radeon HD 7670M(0x1043-0x100A)"},
{0x1002, 0x6840, 0x1043, 0x104B, "Radeon HD 7670M(0x1043-0x104B)"},
{0x1002, 0x6840, 0x1043, 0x10DC, "Radeon HD 7670M(0x1043-0x10DC)"},
{0x1002, 0x6840, 0x1043, 0x2121, "Radeon HD 7670M(0x1043-0x2121)"},
{0x1002, 0x6840, 0x1043, 0x2122, "Radeon HD 7670M(0x1043-0x2122)"},
{0x1002, 0x6840, 0x1043, 0x2123, "Radeon HD 7670M(0x1043-0x2123)"},
{0x1002, 0x6840, 0x1043, 0x2125, "Radeon HD 7670M(0x1043-0x2125)"},
{0x1002, 0x6840, 0x1043, 0x2127, "Radeon HD 7670M(0x1043-0x2127)"},
{0x1002, 0x6840, 0x1179, 0xFB11, "Radeon HD 7670M(0x1179-0xFB11)"},
{0x1002, 0x6840, 0x1179, 0xFB22, "Radeon HD 7670M(0x1179-0xFB22)"},
{0x1002, 0x6840, 0x1179, 0xFB23, "Radeon HD 7670M(0x1179-0xFB23)"},
{0x1002, 0x6840, 0x1179, 0xFB2C, "Radeon HD 7670M(0x1179-0xFB2C)"},
{0x1002, 0x6840, 0x1179, 0xFB31, "Radeon HD 7670M(0x1179-0xFB31)"},
{0x1002, 0x6840, 0x1179, 0xFB32, "Radeon HD 7670M(0x1179-0xFB32)"},
{0x1002, 0x6840, 0x1179, 0xFB38, "Radeon HD 7670M(0x1179-0xFB38)"},
{0x1002, 0x6840, 0x1179, 0xFB39, "Radeon HD 7670M(0x1179-0xFB39)"},
{0x1002, 0x6840, 0x1179, 0xFB3A, "Radeon HD 7670M(0x1179-0xFB3A)"},
{0x1002, 0x6840, 0x1179, 0xFB40, "Radeon HD 7670M(0x1179-0xFB40)"},
{0x1002, 0x6840, 0x1179, 0xFB41, "Radeon HD 7670M(0x1179-0xFB41)"},
{0x1002, 0x6840, 0x1179, 0xFB47, "Radeon HD 7670M(0x1179-0xFB47)"},
{0x1002, 0x6840, 0x1179, 0xFB48, "Radeon HD 7670M(0x1179-0xFB48)"},
{0x1002, 0x6840, 0x1179, 0xFB51, "Radeon HD 7670M(0x1179-0xFB51)"},
{0x1002, 0x6840, 0x1179, 0xFB52, "Radeon HD 7670M(0x1179-0xFB52)"},
{0x1002, 0x6840, 0x1179, 0xFB53, "Radeon HD 7670M(0x1179-0xFB53)"},
{0x1002, 0x6840, 0x1179, 0xFB81, "Radeon HD 7670M(0x1179-0xFB81)"},
{0x1002, 0x6840, 0x1179, 0xFB82, "Radeon HD 7670M(0x1179-0xFB82)"},
{0x1002, 0x6840, 0x1179, 0xFB83, "Radeon HD 7670M(0x1179-0xFB83)"},
{0x1002, 0x6840, 0x1179, 0xFC56, "Radeon HD 7670M(0x1179-0xFC56)"},
{0x1002, 0x6840, 0x1179, 0xFCD4, "Radeon HD 7670M(0x1179-0xFCD4)"},
{0x1002, 0x6840, 0x1179, 0xFCEE, "Radeon HD 7670M(0x1179-0xFCEE)"},
{0x1002, 0x6840, 0x144D, 0xC0C5, "Radeon HD 7690M(0x144D-0xC0C5)"},
{0x1002, 0x6840, 0x144D, 0xC0CE, "Radeon HD 7670M(0x144D-0xC0CE)"},
{0x1002, 0x6840, 0x144D, 0xC0DA, "Radeon HD 7670M(0x144D-0xC0DA)"},
{0x1002, 0x6840, 0x17AA, 0x3970, "Radeon HD 7670M(0x17AA-0x3970)"},
{0x1002, 0x6840, 0x17AA, 0x397B, "Radeon HD 7670M(0x17AA-0x397B)"},
{0x1002, 0x6840, 0x17AA, 0x5101, "Radeon HD 7670M(0x17AA-0x5101)"},
{0x1002, 0x6840, 0x17AA, 0x5102, "Radeon HD 7670M(0x17AA-0x5102)"},
{0x1002, 0x6840, 0x17AA, 0x5103, "Radeon HD 7670M(0x17AA-0x5103)"},
{0x1002, 0x6841, 0xFFFF, 0xFFFF, "Thames [Radeon HD 7550M/7570M/7650M](0x6841)"},
{0x1002, 0x6841, 0x1028, 0x0561, "Radeon HD 7650M(0x1028-0x0561)"},
{0x1002, 0x6841, 0x1028, 0x056C, "Radeon HD 7650M(0x1028-0x056C)"},
{0x1002, 0x6841, 0x1028, 0x057F, "Radeon HD 7570M(0x1028-0x057F)"},
{0x1002, 0x6841, 0x103C, 0x17F1, "Radeon HD 7570M(0x103C-0x17F1)"},
{0x1002, 0x6841, 0x103C, 0x17F4, "Radeon HD 7650M(0x103C-0x17F4)"},
{0x1002, 0x6841, 0x103C, 0x1813, "Radeon HD 7570M(0x103C-0x1813)"},
{0x1002, 0x6841, 0x103C, 0x183A, "Radeon HD 7650M(0x103C-0x183A)"},
{0x1002, 0x6841, 0x103C, 0x183C, "Radeon HD 7650M(0x103C-0x183C)"},
{0x1002, 0x6841, 0x103C, 0x183E, "Radeon HD 7650M(0x103C-0x183E)"},
{0x1002, 0x6841, 0x103C, 0x1840, "Radeon HD 7650M(0x103C-0x1840)"},
{0x1002, 0x6841, 0x103C, 0x1842, "Radeon HD 7650M(0x103C-0x1842)"},
{0x1002, 0x6841, 0x103C, 0x1844, "Radeon HD 7650M(0x103C-0x1844)"},
{0x1002, 0x6841, 0x1043, 0x100A, "Radeon HD 7650M(0x1043-0x100A)"},
{0x1002, 0x6841, 0x1043, 0x104B, "Radeon HD 7650M(0x1043-0x104B)"},
{0x1002, 0x6841, 0x1043, 0x10DC, "Radeon HD 7650M(0x1043-0x10DC)"},
{0x1002, 0x6841, 0x1043, 0x2134, "Radeon HD 7650M(0x1043-0x2134)"},
{0x1002, 0x6841, 0x1179, 0x0001, "Radeon HD 7570M(0x1179-0x0001)"},
{0x1002, 0x6841, 0x1179, 0x0002, "Radeon HD 7570M(0x1179-0x0002)"},
{0x1002, 0x6841, 0x1179, 0xFB43, "Radeon HD 7550M(0x1179-0xFB43)"},
{0x1002, 0x6841, 0x1179, 0xFB91, "Radeon HD 7550M(0x1179-0xFB91)"},
{0x1002, 0x6841, 0x1179, 0xFB92, "Radeon HD 7550M(0x1179-0xFB92)"},
{0x1002, 0x6841, 0x1179, 0xFB93, "Radeon HD 7550M(0x1179-0xFB93)"},
{0x1002, 0x6841, 0x1179, 0xFBA2, "Radeon HD 7550M(0x1179-0xFBA2)"},
{0x1002, 0x6841, 0x1179, 0xFBA3, "Radeon HD 7550M(0x1179-0xFBA3)"},
{0x1002, 0x6841, 0x144D, 0xC0C7, "Radeon HD 7550M(0x144D-0xC0C7)"},
{0x1002, 0x6842, 0xFFFF, 0xFFFF, "Thames LE [Radeon HD 7000M Series](0x6842)"},
{0x1002, 0x6843, 0xFFFF, 0xFFFF, "Thames [Radeon HD 7670M](0x6843)"},
{0x1002, 0x6860, 0xFFFF, 0xFFFF, "Vega 10 [Instinct MI25/MI25x2/V340/V320](0x6860)"},
{0x1002, 0x6860, 0x1002, 0x0C35, "Radeon PRO V320(0x1002-0x0C35)"},
{0x1002, 0x6860, 0x1002, 0x6C75, "Radeon PRO V320(0x1002-0x6C75)"},
{0x1002, 0x6860, 0x106B, 0x017C, "Radeon Pro Vega 64(0x106B-0x017C)"},
{0x1002, 0x6861, 0xFFFF, 0xFFFF, "Vega 10 XT [Radeon PRO WX 9100](0x6861)"},
{0x1002, 0x6862, 0xFFFF, 0xFFFF, "Vega 10 XT [Radeon PRO SSG](0x6862)"},
{0x1002, 0x6863, 0xFFFF, 0xFFFF, "Vega 10 XTX [Radeon Vega Frontier Edition](0x6863)"},
{0x1002, 0x6864, 0xFFFF, 0xFFFF, "Vega 10 [Radeon Pro V340/Instinct MI25x2](0x6864)"},
{0x1002, 0x6867, 0xFFFF, 0xFFFF, "Vega 10 XL [Radeon Pro Vega 56](0x6867)"},
{0x1002, 0x6868, 0xFFFF, 0xFFFF, "Vega 10 [Radeon PRO WX 8100/8200](0x6868)"},
{0x1002, 0x6869, 0xFFFF, 0xFFFF, "Vega 10 XGA [Radeon Pro Vega 48](0x6869)"},
{0x1002, 0x686A, 0xFFFF, 0xFFFF, "Vega 10 LEA(0x686A)"},
{0x1002, 0x686B, 0xFFFF, 0xFFFF, "Vega 10 XTXA [Radeon Pro Vega 64X](0x686B)"},
{0x1002, 0x686C, 0xFFFF, 0xFFFF, "Vega 10 [Instinct MI25 MxGPU/MI25x2 MxGPU/V340 MxGPU/V340L MxGPU](0x686C)"},
{0x1002, 0x686D, 0xFFFF, 0xFFFF, "Vega 10 GLXTA(0x686D)"},
{0x1002, 0x686E, 0xFFFF, 0xFFFF, "Vega 10 GLXLA(0x686E)"},
{0x1002, 0x687F, 0xFFFF, 0xFFFF, "Vega 10 XL/XT [Radeon RX Vega 56/64](0x687F)"},
{0x1002, 0x687F, 0x1002, 0x0B36, "RX Vega64(0x1002-0x0B36)"},
{0x1002, 0x687F, 0x1002, 0x6B76, "AMD Radeon RX Vega 56 8GB(0x1002-0x6B76)"},
{0x1002, 0x687F, 0x1043, 0x04C4, "Radeon RX Vega 64(0x1043-0x04C4)"},
{0x1002, 0x687F, 0x1458, 0x230C, "Radeon RX VEGA 56 GAMING OC 8G(0x1458-0x230C)"},
{0x1002, 0x687F, 0x1DA2, 0xE376, "Radeon RX VEGA 56 Pulse 8GB OC HBM2(0x1DA2-0xE376)"},
{0x1002, 0x6880, 0xFFFF, 0xFFFF, "Lexington [Radeon HD 6550M](0x6880)"},
{0x1002, 0x6880, 0x103C, 0x163C, "Pavilion dv6 Radeon HD 6550M(0x103C-0x163C)"},
{0x1002, 0x6888, 0xFFFF, 0xFFFF, "Cypress XT [FirePro V8800](0x6888)"},
{0x1002, 0x6889, 0xFFFF, 0xFFFF, "Cypress PRO [FirePro V7800](0x6889)"},
{0x1002, 0x6889, 0x1002, 0x0301, "FirePro V7800P(0x1002-0x0301)"},
{0x1002, 0x6889, 0x13CC, 0x3D1F, "MXRT-7400(0x13CC-0x3D1F)"},
{0x1002, 0x688A, 0xFFFF, 0xFFFF, "Cypress XT [FirePro V9800](0x688A)"},
{0x1002, 0x688A, 0x1002, 0x030C, "FirePro V9800P(0x1002-0x030C)"},
{0x1002, 0x688C, 0xFFFF, 0xFFFF, "Cypress XT GL [FireStream 9370](0x688C)"},
{0x1002, 0x688D, 0xFFFF, 0xFFFF, "Cypress PRO GL [FireStream 9350](0x688D)"},
{0x1002, 0x6898, 0xFFFF, 0xFFFF, "Cypress XT [Radeon HD 5870](0x6898)"},
{0x1002, 0x6898, 0x1002, 0x0B00, "Radeon HD 5870 Eyefinity Edition(0x1002-0x0B00)"},
{0x1002, 0x6898, 0x106B, 0x00D0, "Radeon HD 5870 Mac Edition(0x106B-0x00D0)"},
{0x1002, 0x6898, 0x1462, 0x8032, "Radeon HD 5870 1 GB GDDR5(0x1462-0x8032)"},
{0x1002, 0x6898, 0x174B, 0x6870, "Radeon HD 6870 1600SP Edition(0x174B-0x6870)"},
{0x1002, 0x6899, 0xFFFF, 0xFFFF, "Cypress PRO [Radeon HD 5850](0x6899)"},
{0x1002, 0x6899, 0x1043, 0x0330, "Radeon HD 5850(0x1043-0x0330)"},
{0x1002, 0x6899, 0x174B, 0x237B, "Radeon HD 5850 X2(0x174B-0x237B)"},
{0x1002, 0x6899, 0x174B, 0x6850, "Radeon HD 6850 1440SP Edition(0x174B-0x6850)"},
{0x1002, 0x689B, 0xFFFF, 0xFFFF, "Cypress PRO [Radeon HD 6800 Series](0x689B)"},
{0x1002, 0x689C, 0xFFFF, 0xFFFF, "Hemlock [Radeon HD 5970](0x689C)"},
{0x1002, 0x689C, 0x1043, 0x0352, "ARES(0x1043-0x0352)"},
{0x1002, 0x689D, 0xFFFF, 0xFFFF, "Hemlock [Radeon HD 5970](0x689D)"},
{0x1002, 0x689E, 0xFFFF, 0xFFFF, "Cypress LE [Radeon HD 5830](0x689E)"},
{0x1002, 0x68A0, 0xFFFF, 0xFFFF, "Broadway XT [Mobility Radeon HD 5870](0x68A0)"},
{0x1002, 0x68A0, 0x1028, 0x12EF, "FirePro M7820(0x1028-0x12EF)"},
{0x1002, 0x68A0, 0x103C, 0x1520, "FirePro M7820(0x103C-0x1520)"},
{0x1002, 0x68A1, 0xFFFF, 0xFFFF, "Broadway PRO [Mobility Radeon HD 5850](0x68A1)"},
{0x1002, 0x68A1, 0x106B, 0x00CC, "iMac MC511 Mobility Radeon HD 5850 MXM Module(0x106B-0x00CC)"},
{0x1002, 0x68A8, 0xFFFF, 0xFFFF, "Granville [Radeon HD 6850M/6870M](0x68A8)"},
{0x1002, 0x68A8, 0x1025, 0x0442, "Radeon HD 6850M(0x1025-0x0442)"},
{0x1002, 0x68A8, 0x1025, 0x0451, "Radeon HD 6850M(0x1025-0x0451)"},
{0x1002, 0x68A8, 0x1025, 0x050A, "Radeon HD 6850M(0x1025-0x050A)"},
{0x1002, 0x68A8, 0x1025, 0x050B, "Radeon HD 6850M(0x1025-0x050B)"},
{0x1002, 0x68A8, 0x1025, 0x050C, "Radeon HD 6850M(0x1025-0x050C)"},
{0x1002, 0x68A8, 0x1025, 0x050E, "Radeon HD 6850M(0x1025-0x050E)"},
{0x1002, 0x68A8, 0x1025, 0x050F, "Radeon HD 6850M(0x1025-0x050F)"},
{0x1002, 0x68A8, 0x1025, 0x0513, "Radeon HD 6850M(0x1025-0x0513)"},
{0x1002, 0x68A8, 0x1025, 0x0514, "Radeon HD 6850M(0x1025-0x0514)"},
{0x1002, 0x68A8, 0x1025, 0x0515, "Radeon HD 6850M(0x1025-0x0515)"},
{0x1002, 0x68A8, 0x1025, 0x0516, "Radeon HD 6850M(0x1025-0x0516)"},
{0x1002, 0x68A8, 0x1025, 0x0525, "Radeon HD 6850M(0x1025-0x0525)"},
{0x1002, 0x68A8, 0x1025, 0x0526, "Radeon HD 6850M(0x1025-0x0526)"},
{0x1002, 0x68A8, 0x1025, 0x056D, "Radeon HD 6850M(0x1025-0x056D)"},
{0x1002, 0x68A8, 0x1028, 0x048F, "Radeon HD 6870M(0x1028-0x048F)"},
{0x1002, 0x68A8, 0x1028, 0x0490, "Radeon HD 6870M(0x1028-0x0490)"},
{0x1002, 0x68A8, 0x1028, 0x04B9, "Radeon HD 6870M(0x1028-0x04B9)"},
{0x1002, 0x68A8, 0x1028, 0x04BA, "Radeon HD 6870M(0x1028-0x04BA)"},
{0x1002, 0x68A8, 0x103C, 0x159B, "Radeon HD 6850M(0x103C-0x159B)"},
{0x1002, 0x68A8, 0x144D, 0xC0AD, "Radeon HD 6850M(0x144D-0xC0AD)"},
{0x1002, 0x68A9, 0xFFFF, 0xFFFF, "Juniper XT [FirePro V5800](0x68A9)"},
{0x1002, 0x68A9, 0x13CC, 0x3D1E, "MXRT-5400(0x13CC-0x3D1E)"},
{0x1002, 0x68A9, 0x13CC, 0x3D20, "MXRT-5450(0x13CC-0x3D20)"},
{0x1002, 0x68B8, 0xFFFF, 0xFFFF, "Juniper XT [Radeon HD 5770](0x68B8)"},
{0x1002, 0x68B8, 0x106B, 0x00CF, "MacPro5,1 [Mac Pro 2.8GHz DDR3](0x106B-0x00CF)"},
{0x1002, 0x68B9, 0xFFFF, 0xFFFF, "Juniper LE [Radeon HD 5670 640SP Edition](0x68B9)"},
{0x1002, 0x68BA, 0xFFFF, 0xFFFF, "Juniper XT [Radeon HD 6770](0x68BA)"},
{0x1002, 0x68BE, 0xFFFF, 0xFFFF, "Juniper PRO [Radeon HD 5750](0x68BE)"},
{0x1002, 0x68BE, 0x148C, 0x3000, "Radeon HD 6750(0x148C-0x3000)"},
{0x1002, 0x68BF, 0xFFFF, 0xFFFF, "Juniper PRO [Radeon HD 6750](0x68BF)"},
{0x1002, 0x68BF, 0x174B, 0x6750, "Radeon HD 6750(0x174B-0x6750)"},
{0x1002, 0x68C0, 0xFFFF, 0xFFFF, "Madison [Mobility Radeon HD 5730 / 6570M](0x68C0)"},
{0x1002, 0x68C0, 0x1019, 0x2383, "Mobility Radeon HD 5730(0x1019-0x2383)"},
{0x1002, 0x68C0, 0x1028, 0x02A2, "Mobility Radeon HD 5730(0x1028-0x02A2)"},
{0x1002, 0x68C0, 0x1028, 0x02FE, "Mobility Radeon HD 5730(0x1028-0x02FE)"},
{0x1002, 0x68C0, 0x1028, 0x0419, "Mobility Radeon HD 5730(0x1028-0x0419)"},
{0x1002, 0x68C0, 0x103C, 0x147D, "Mobility Radeon HD 5730(0x103C-0x147D)"},
{0x1002, 0x68C0, 0x103C, 0x1521, "Madison XT [FirePro M5800](0x103C-0x1521)"},
{0x1002, 0x68C0, 0x103C, 0x1593, "Mobility Radeon HD 6570(0x103C-0x1593)"},
{0x1002, 0x68C0, 0x103C, 0x1596, "Mobility Radeon HD 6570(0x103C-0x1596)"},
{0x1002, 0x68C0, 0x103C, 0x1599, "Mobility Radeon HD 6570(0x103C-0x1599)"},
{0x1002, 0x68C0, 0x1043, 0x1C22, "Mobility Radeon HD 5730(0x1043-0x1C22)"},
{0x1002, 0x68C0, 0x17AA, 0x3927, "Mobility Radeon HD 5730(0x17AA-0x3927)"},
{0x1002, 0x68C0, 0x17AA, 0x3952, "Mobility Radeon HD 5730(0x17AA-0x3952)"},
{0x1002, 0x68C0, 0x17AA, 0x3978, "Radeon HD 6570M(0x17AA-0x3978)"},
{0x1002, 0x68C1, 0xFFFF, 0xFFFF, "Madison [Mobility Radeon HD 5650/5750 / 6530M/6550M](0x68C1)"},
{0x1002, 0x68C1, 0x1025, 0x0205, "Mobility Radeon HD 5650(0x1025-0x0205)"},
{0x1002, 0x68C1, 0x1025, 0x0293, "Mobility Radeon HD 5650(0x1025-0x0293)"},
{0x1002, 0x68C1, 0x1025, 0x0294, "Mobility Radeon HD 5650(0x1025-0x0294)"},
{0x1002, 0x68C1, 0x1025, 0x0296, "Mobility Radeon HD 5650(0x1025-0x0296)"},
{0x1002, 0x68C1, 0x1025, 0x0308, "Mobility Radeon HD 5650(0x1025-0x0308)"},
{0x1002, 0x68C1, 0x1025, 0x030A, "Mobility Radeon HD 5650(0x1025-0x030A)"},
{0x1002, 0x68C1, 0x1025, 0x0311, "Mobility Radeon HD 5650(0x1025-0x0311)"},
{0x1002, 0x68C1, 0x1025, 0x0312, "Mobility Radeon HD 5650(0x1025-0x0312)"},
{0x1002, 0x68C1, 0x1025, 0x031C, "Mobility Radeon HD 5650(0x1025-0x031C)"},
{0x1002, 0x68C1, 0x1025, 0x031D, "Mobility Radeon HD 5650(0x1025-0x031D)"},
{0x1002, 0x68C1, 0x1025, 0x033D, "Mobility Radeon HD 5650(0x1025-0x033D)"},
{0x1002, 0x68C1, 0x1025, 0x033E, "Mobility Radeon HD 5650(0x1025-0x033E)"},
{0x1002, 0x68C1, 0x1025, 0x033F, "Mobility Radeon HD 5650(0x1025-0x033F)"},
{0x1002, 0x68C1, 0x1025, 0x0346, "Mobility Radeon HD 5650(0x1025-0x0346)"},
{0x1002, 0x68C1, 0x1025, 0x0347, "Aspire 7740G(0x1025-0x0347)"},
{0x1002, 0x68C1, 0x1025, 0x0348, "Mobility Radeon HD 5650(0x1025-0x0348)"},
{0x1002, 0x68C1, 0x1025, 0x0356, "Mobility Radeon HD 5650(0x1025-0x0356)"},
{0x1002, 0x68C1, 0x1025, 0x0357, "Mobility Radeon HD 5650(0x1025-0x0357)"},
{0x1002, 0x68C1, 0x1025, 0x0358, "Mobility Radeon HD 5650(0x1025-0x0358)"},
{0x1002, 0x68C1, 0x1025, 0x0359, "Mobility Radeon HD 5650(0x1025-0x0359)"},
{0x1002, 0x68C1, 0x1025, 0x035A, "Mobility Radeon HD 5650(0x1025-0x035A)"},
{0x1002, 0x68C1, 0x1025, 0x035B, "Mobility Radeon HD 5650(0x1025-0x035B)"},
{0x1002, 0x68C1, 0x1025, 0x035C, "Mobility Radeon HD 5650(0x1025-0x035C)"},
{0x1002, 0x68C1, 0x1025, 0x035D, "Mobility Radeon HD 5650(0x1025-0x035D)"},
{0x1002, 0x68C1, 0x1025, 0x035E, "Mobility Radeon HD 5650(0x1025-0x035E)"},
{0x1002, 0x68C1, 0x1025, 0x0360, "Mobility Radeon HD 5650(0x1025-0x0360)"},
{0x1002, 0x68C1, 0x1025, 0x0362, "Mobility Radeon HD 5650(0x1025-0x0362)"},
{0x1002, 0x68C1, 0x1025, 0x0364, "Mobility Radeon HD 5650(0x1025-0x0364)"},
{0x1002, 0x68C1, 0x1025, 0x0365, "Mobility Radeon HD 5650(0x1025-0x0365)"},
{0x1002, 0x68C1, 0x1025, 0x0366, "Mobility Radeon HD 5650(0x1025-0x0366)"},
{0x1002, 0x68C1, 0x1025, 0x0367, "Mobility Radeon HD 5650(0x1025-0x0367)"},
{0x1002, 0x68C1, 0x1025, 0x0368, "Mobility Radeon HD 5650(0x1025-0x0368)"},
{0x1002, 0x68C1, 0x1025, 0x036C, "Mobility Radeon HD 5650(0x1025-0x036C)"},
{0x1002, 0x68C1, 0x1025, 0x036D, "Mobility Radeon HD 5650(0x1025-0x036D)"},
{0x1002, 0x68C1, 0x1025, 0x036E, "Mobility Radeon HD 5650(0x1025-0x036E)"},
{0x1002, 0x68C1, 0x1025, 0x036F, "Mobility Radeon HD 5650(0x1025-0x036F)"},
{0x1002, 0x68C1, 0x1025, 0x0372, "Mobility Radeon HD 5650(0x1025-0x0372)"},
{0x1002, 0x68C1, 0x1025, 0x0373, "Mobility Radeon HD 5650(0x1025-0x0373)"},
{0x1002, 0x68C1, 0x1025, 0x0377, "Mobility Radeon HD 5650(0x1025-0x0377)"},
{0x1002, 0x68C1, 0x1025, 0x0378, "Mobility Radeon HD 5650(0x1025-0x0378)"},
{0x1002, 0x68C1, 0x1025, 0x0379, "Mobility Radeon HD 5650(0x1025-0x0379)"},
{0x1002, 0x68C1, 0x1025, 0x037A, "Mobility Radeon HD 5650(0x1025-0x037A)"},
{0x1002, 0x68C1, 0x1025, 0x037B, "Mobility Radeon HD 5650(0x1025-0x037B)"},
{0x1002, 0x68C1, 0x1025, 0x037E, "Mobility Radeon HD 5650(0x1025-0x037E)"},
{0x1002, 0x68C1, 0x1025, 0x037F, "Mobility Radeon HD 5650(0x1025-0x037F)"},
{0x1002, 0x68C1, 0x1025, 0x0382, "Mobility Radeon HD 5650(0x1025-0x0382)"},
{0x1002, 0x68C1, 0x1025, 0x0383, "Mobility Radeon HD 5650(0x1025-0x0383)"},
{0x1002, 0x68C1, 0x1025, 0x0384, "Mobility Radeon HD 5650(0x1025-0x0384)"},
{0x1002, 0x68C1, 0x1025, 0x0385, "Mobility Radeon HD 5650(0x1025-0x0385)"},
{0x1002, 0x68C1, 0x1025, 0x0386, "Mobility Radeon HD 5650(0x1025-0x0386)"},
{0x1002, 0x68C1, 0x1025, 0x0387, "Mobility Radeon HD 5650(0x1025-0x0387)"},
{0x1002, 0x68C1, 0x1025, 0x0388, "Mobility Radeon HD 5650(0x1025-0x0388)"},
{0x1002, 0x68C1, 0x1025, 0x038B, "Mobility Radeon HD 5650(0x1025-0x038B)"},
{0x1002, 0x68C1, 0x1025, 0x038C, "Mobility Radeon HD 5650(0x1025-0x038C)"},
{0x1002, 0x68C1, 0x1025, 0x039A, "Mobility Radeon HD 5650(0x1025-0x039A)"},
{0x1002, 0x68C1, 0x1025, 0x0411, "Mobility Radeon HD 5650(0x1025-0x0411)"},
{0x1002, 0x68C1, 0x1025, 0x0412, "Mobility Radeon HD 5650(0x1025-0x0412)"},
{0x1002, 0x68C1, 0x1025, 0x0418, "Mobility Radeon HD 5650(0x1025-0x0418)"},
{0x1002, 0x68C1, 0x1025, 0x0419, "Mobility Radeon HD 5650(0x1025-0x0419)"},
{0x1002, 0x68C1, 0x1025, 0x0420, "Mobility Radeon HD 5650(0x1025-0x0420)"},
{0x1002, 0x68C1, 0x1025, 0x0421, "Mobility Radeon HD 5650(0x1025-0x0421)"},
{0x1002, 0x68C1, 0x1025, 0x0425, "Mobility Radeon HD 5650(0x1025-0x0425)"},
{0x1002, 0x68C1, 0x1025, 0x042A, "Mobility Radeon HD 5650(0x1025-0x042A)"},
{0x1002, 0x68C1, 0x1025, 0x042E, "Mobility Radeon HD 5650(0x1025-0x042E)"},
{0x1002, 0x68C1, 0x1025, 0x042F, "Mobility Radeon HD 5650(0x1025-0x042F)"},
{0x1002, 0x68C1, 0x1025, 0x0432, "Mobility Radeon HD 5650(0x1025-0x0432)"},
{0x1002, 0x68C1, 0x1025, 0x0433, "Mobility Radeon HD 5650(0x1025-0x0433)"},
{0x1002, 0x68C1, 0x1025, 0x0442, "Mobility Radeon HD 5650(0x1025-0x0442)"},
{0x1002, 0x68C1, 0x1025, 0x044C, "Mobility Radeon HD 5650(0x1025-0x044C)"},
{0x1002, 0x68C1, 0x1025, 0x044E, "Mobility Radeon HD 5650(0x1025-0x044E)"},
{0x1002, 0x68C1, 0x1025, 0x0451, "Mobility Radeon HD 5650(0x1025-0x0451)"},
{0x1002, 0x68C1, 0x1025, 0x0454, "Mobility Radeon HD 5650(0x1025-0x0454)"},
{0x1002, 0x68C1, 0x1025, 0x0455, "Mobility Radeon HD 5650(0x1025-0x0455)"},
{0x1002, 0x68C1, 0x1025, 0x0475, "Mobility Radeon HD 5650(0x1025-0x0475)"},
{0x1002, 0x68C1, 0x1025, 0x0476, "Mobility Radeon HD 5650(0x1025-0x0476)"},
{0x1002, 0x68C1, 0x1025, 0x0487, "Mobility Radeon HD 5650(0x1025-0x0487)"},
{0x1002, 0x68C1, 0x1025, 0x0489, "Mobility Radeon HD 5650(0x1025-0x0489)"},
{0x1002, 0x68C1, 0x1025, 0x0498, "Mobility Radeon HD 5650(0x1025-0x0498)"},
{0x1002, 0x68C1, 0x1025, 0x0517, "Radeon HD 6550M(0x1025-0x0517)"},
{0x1002, 0x68C1, 0x1025, 0x051A, "Radeon HD 6550M(0x1025-0x051A)"},
{0x1002, 0x68C1, 0x1025, 0x051B, "Radeon HD 6550M(0x1025-0x051B)"},
{0x1002, 0x68C1, 0x1025, 0x051C, "Radeon HD 6550M(0x1025-0x051C)"},
{0x1002, 0x68C1, 0x1025, 0x051D, "Radeon HD 6550M(0x1025-0x051D)"},
{0x1002, 0x68C1, 0x1025, 0x0525, "Radeon HD 6550M(0x1025-0x0525)"},
{0x1002, 0x68C1, 0x1025, 0x0526, "Radeon HD 6550M(0x1025-0x0526)"},
{0x1002, 0x68C1, 0x1025, 0x052B, "Radeon HD 6550M(0x1025-0x052B)"},
{0x1002, 0x68C1, 0x1025, 0x052C, "Radeon HD 6550M(0x1025-0x052C)"},
{0x1002, 0x68C1, 0x1025, 0x053C, "Radeon HD 6550M(0x1025-0x053C)"},
{0x1002, 0x68C1, 0x1025, 0x053D, "Radeon HD 6550M(0x1025-0x053D)"},
{0x1002, 0x68C1, 0x1025, 0x053E, "Radeon HD 6550M(0x1025-0x053E)"},
{0x1002, 0x68C1, 0x1025, 0x053F, "Radeon HD 6550M(0x1025-0x053F)"},
{0x1002, 0x68C1, 0x1025, 0x0607, "Radeon HD 6550M(0x1025-0x0607)"},
{0x1002, 0x68C1, 0x1028, 0x041B, "Mobility Radeon HD 5650(0x1028-0x041B)"},
{0x1002, 0x68C1, 0x1028, 0x0447, "Mobility Radeon HD 5650(0x1028-0x0447)"},
{0x1002, 0x68C1, 0x1028, 0x0448, "Mobility Radeon HD 5650(0x1028-0x0448)"},
{0x1002, 0x68C1, 0x1028, 0x0456, "Mobility Radeon HD 5650(0x1028-0x0456)"},
{0x1002, 0x68C1, 0x1028, 0x0457, "Mobility Radeon HD 5650(0x1028-0x0457)"},
{0x1002, 0x68C1, 0x103C, 0x1436, "Mobility Radeon HD 5650(0x103C-0x1436)"},
{0x1002, 0x68C1, 0x103C, 0x1437, "Mobility Radeon HD 5650(0x103C-0x1437)"},
{0x1002, 0x68C1, 0x103C, 0x1440, "Mobility Radeon HD 5650(0x103C-0x1440)"},
{0x1002, 0x68C1, 0x103C, 0x1448, "Mobility Radeon HD 5650(0x103C-0x1448)"},
{0x1002, 0x68C1, 0x103C, 0x1449, "Mobility Radeon HD 5650(0x103C-0x1449)"},
{0x1002, 0x68C1, 0x103C, 0x144A, "Mobility Radeon HD 5650(0x103C-0x144A)"},
{0x1002, 0x68C1, 0x103C, 0x144B, "Mobility Radeon HD 5650(0x103C-0x144B)"},
{0x1002, 0x68C1, 0x103C, 0x147B, "Mobility Radeon HD 5650(0x103C-0x147B)"},
{0x1002, 0x68C1, 0x103C, 0x149C, "Mobility Radeon HD 5650(0x103C-0x149C)"},
{0x1002, 0x68C1, 0x103C, 0x149E, "Mobility Radeon HD 5650(0x103C-0x149E)"},
{0x1002, 0x68C1, 0x103C, 0x1521, "Madison Pro [FirePro M5800](0x103C-0x1521)"},
{0x1002, 0x68C1, 0x1043, 0x1BC2, "Mobility Radeon HD 5650(0x1043-0x1BC2)"},
{0x1002, 0x68C1, 0x104D, 0x9071, "Mobility Radeon HD 5650(0x104D-0x9071)"},
{0x1002, 0x68C1, 0x104D, 0x9077, "Mobility Radeon HD 5650(0x104D-0x9077)"},
{0x1002, 0x68C1, 0x104D, 0x9081, "Mobility Radeon HD 5650(0x104D-0x9081)"},
{0x1002, 0x68C1, 0x1179, 0xFD00, "Mobility Radeon HD 5650(0x1179-0xFD00)"},
{0x1002, 0x68C1, 0x1179, 0xFD12, "Mobility Radeon HD 5650(0x1179-0xFD12)"},
{0x1002, 0x68C1, 0x1179, 0xFD1A, "Mobility Radeon HD 5650(0x1179-0xFD1A)"},
{0x1002, 0x68C1, 0x1179, 0xFD30, "Mobility Radeon HD 5650(0x1179-0xFD30)"},
{0x1002, 0x68C1, 0x1179, 0xFD31, "Mobility Radeon HD 5650(0x1179-0xFD31)"},
{0x1002, 0x68C1, 0x1179, 0xFD50, "Mobility Radeon HD 5650(0x1179-0xFD50)"},
{0x1002, 0x68C1, 0x1179, 0xFD52, "Radeon HD 6530M(0x1179-0xFD52)"},
{0x1002, 0x68C1, 0x1179, 0xFD63, "Radeon HD 6530M(0x1179-0xFD63)"},
{0x1002, 0x68C1, 0x1179, 0xFD65, "Radeon HD 6530M(0x1179-0xFD65)"},
{0x1002, 0x68C1, 0x1179, 0xFDD0, "Mobility Radeon HD 5650(0x1179-0xFDD0)"},
{0x1002, 0x68C1, 0x1179, 0xFDD2, "Radeon HD 6530M(0x1179-0xFDD2)"},
{0x1002, 0x68C1, 0x144D, 0xC07E, "Mobility Radeon HD 5650(0x144D-0xC07E)"},
{0x1002, 0x68C1, 0x144D, 0xC085, "Mobility Radeon HD 5650(0x144D-0xC085)"},
{0x1002, 0x68C1, 0x14C0, 0x0043, "Mobility Radeon HD 5650(0x14C0-0x0043)"},
{0x1002, 0x68C1, 0x14C0, 0x004D, "Mobility Radeon HD 5650(0x14C0-0x004D)"},
{0x1002, 0x68C1, 0x17AA, 0x3928, "Mobility Radeon HD 5650(0x17AA-0x3928)"},
{0x1002, 0x68C1, 0x17AA, 0x3951, "Mobility Radeon HD 5650(0x17AA-0x3951)"},
{0x1002, 0x68C1, 0x17AA, 0x3977, "Radeon HD 6550M(0x17AA-0x3977)"},
{0x1002, 0x68C7, 0xFFFF, 0xFFFF, "Pinewood [Mobility Radeon HD 5570/6550A](0x68C7)"},
{0x1002, 0x68C7, 0x1462, 0x2241, "Mobility Radeon HD 5570(0x1462-0x2241)"},
{0x1002, 0x68C7, 0x1462, 0x2243, "Mobility Radeon HD 5570(0x1462-0x2243)"},
{0x1002, 0x68C7, 0x1462, 0x2244, "Mobility Radeon HD 5570(0x1462-0x2244)"},
{0x1002, 0x68C7, 0x1462, 0x2245, "Radeon HD 6550A(0x1462-0x2245)"},
{0x1002, 0x68C7, 0x1462, 0x2246, "Radeon HD 6550A(0x1462-0x2246)"},
{0x1002, 0x68C8, 0xFFFF, 0xFFFF, "Redwood XT GL [FirePro V4800](0x68C8)"},
{0x1002, 0x68C9, 0xFFFF, 0xFFFF, "Redwood PRO GL [FirePro V3800](0x68C9)"},
{0x1002, 0x68C9, 0x13CC, 0x3D1D, "MXRT-2400(0x13CC-0x3D1D)"},
{0x1002, 0x68D8, 0xFFFF, 0xFFFF, "Redwood XT [Radeon HD 5670/5690/5730](0x68D8)"},
{0x1002, 0x68D8, 0x1028, 0x68E0, "Radeon HD 5670(0x1028-0x68E0)"},
{0x1002, 0x68D8, 0x174B, 0x5690, "Radeon HD 5690(0x174B-0x5690)"},
{0x1002, 0x68D8, 0x174B, 0x5730, "Radeon HD 5730(0x174B-0x5730)"},
{0x1002, 0x68D8, 0x174B, 0xE151, "Radeon HD 5670(0x174B-0xE151)"},
{0x1002, 0x68D8, 0x1787, 0x3000, "Radeon HD 5730(0x1787-0x3000)"},
{0x1002, 0x68D8, 0x17AF, 0x3010, "Radeon HD 5730(0x17AF-0x3010)"},
{0x1002, 0x68D8, 0x17AF, 0x3011, "Radeon HD 5690(0x17AF-0x3011)"},
{0x1002, 0x68D9, 0xFFFF, 0xFFFF, "Redwood PRO [Radeon HD 5550/5570/5630/6510/6610/7570](0x68D9)"},
{0x1002, 0x68D9, 0x103C, 0x6870, "Radeon HD 5570(0x103C-0x6870)"},
{0x1002, 0x68D9, 0x103C, 0x6872, "Radeon HD 5570(0x103C-0x6872)"},
{0x1002, 0x68D9, 0x1043, 0x03CE, "Radeon HD 5550(0x1043-0x03CE)"},
{0x1002, 0x68D9, 0x1462, 0x2151, "Radeon HD 5570(0x1462-0x2151)"},
{0x1002, 0x68D9, 0x1462, 0x2240, "Radeon HD 5570(0x1462-0x2240)"},
{0x1002, 0x68D9, 0x148C, 0x3000, "Radeon HD 6510(0x148C-0x3000)"},
{0x1002, 0x68D9, 0x148C, 0x3001, "Radeon HD 6610(0x148C-0x3001)"},
{0x1002, 0x68D9, 0x1545, 0x5550, "Radeon HD 5550(0x1545-0x5550)"},
{0x1002, 0x68D9, 0x1545, 0x7570, "Radeon HD 7570(0x1545-0x7570)"},
{0x1002, 0x68D9, 0x1642, 0x3985, "Radeon HD 5570(0x1642-0x3985)"},
{0x1002, 0x68D9, 0x1642, 0x3996, "Radeon HD 5570(0x1642-0x3996)"},
{0x1002, 0x68D9, 0x174B, 0x3000, "Radeon HD 6510(0x174B-0x3000)"},
{0x1002, 0x68D9, 0x174B, 0x6510, "Radeon HD 6510(0x174B-0x6510)"},
{0x1002, 0x68D9, 0x174B, 0x6610, "Radeon HD 6610(0x174B-0x6610)"},
{0x1002, 0x68D9, 0x174B, 0xE142, "Radeon HD 5570(0x174B-0xE142)"},
{0x1002, 0x68D9, 0x1787, 0x3000, "Radeon HD 6510(0x1787-0x3000)"},
{0x1002, 0x68D9, 0x17AF, 0x3000, "Radeon HD 6510(0x17AF-0x3000)"},
{0x1002, 0x68D9, 0x17AF, 0x3010, "Radeon HD 5630(0x17AF-0x3010)"},
{0x1002, 0x68DA, 0xFFFF, 0xFFFF, "Redwood LE [Radeon HD 5550/5570/5630/6390/6490/7570](0x68DA)"},
{0x1002, 0x68DA, 0x1462, 0x8071, "VR5550-MD1G (Radeon HD 5550)(0x1462-0x8071)"},
{0x1002, 0x68DA, 0x148C, 0x3000, "Radeon HD 6390(0x148C-0x3000)"},
{0x1002, 0x68DA, 0x148C, 0x3001, "Radeon HD 6490(0x148C-0x3001)"},
{0x1002, 0x68DA, 0x1545, 0x7570, "Radeon HD 7570(0x1545-0x7570)"},
{0x1002, 0x68DA, 0x174B, 0x3000, "Radeon HD 6390(0x174B-0x3000)"},
{0x1002, 0x68DA, 0x174B, 0x5570, "Radeon HD 5570(0x174B-0x5570)"},
{0x1002, 0x68DA, 0x174B, 0x5630, "Radeon HD 5630(0x174B-0x5630)"},
{0x1002, 0x68DA, 0x174B, 0x6490, "Radeon HD 6490(0x174B-0x6490)"},
{0x1002, 0x68DA, 0x1787, 0x3000, "Radeon HD 5630(0x1787-0x3000)"},
{0x1002, 0x68DA, 0x17AF, 0x3000, "Radeon HD 6390(0x17AF-0x3000)"},
{0x1002, 0x68DA, 0x17AF, 0x3010, "Radeon HD 5630(0x17AF-0x3010)"},
{0x1002, 0x68DE, 0xFFFF, 0xFFFF, "Redwood(0x68DE)"},
{0x1002, 0x68E0, 0xFFFF, 0xFFFF, "Park [Mobility Radeon HD 5430/5450/5470](0x68E0)"},
{0x1002, 0x68E0, 0x1028, 0x0404, "Mobility Radeon HD 5450(0x1028-0x0404)"},
{0x1002, 0x68E0, 0x1028, 0x0414, "Mobility Radeon HD 5450(0x1028-0x0414)"},
{0x1002, 0x68E0, 0x1028, 0x0434, "Mobility Radeon HD 5450(0x1028-0x0434)"},
{0x1002, 0x68E0, 0x103C, 0x1433, "Mobility Radeon HD 5450(0x103C-0x1433)"},
{0x1002, 0x68E0, 0x103C, 0x1434, "Mobility Radeon HD 5450(0x103C-0x1434)"},
{0x1002, 0x68E0, 0x103C, 0x1469, "Mobility Radeon HD 5450(0x103C-0x1469)"},
{0x1002, 0x68E0, 0x103C, 0x146B, "Mobility Radeon HD 5450(0x103C-0x146B)"},
{0x1002, 0x68E0, 0x103C, 0x1486, "TouchSmart tm2-2050er discrete GPU (Mobility Radeon HD 5450)(0x103C-0x1486)"},
{0x1002, 0x68E0, 0x103C, 0x1622, "Mobility Radeon HD 5450(0x103C-0x1622)"},
{0x1002, 0x68E0, 0x103C, 0x1623, "Mobility Radeon HD 5450(0x103C-0x1623)"},
{0x1002, 0x68E0, 0x103C, 0xEEEE, "Mobility Radeon HD 5450(0x103C-0xEEEE)"},
{0x1002, 0x68E0, 0x104D, 0x9076, "Mobility Radeon HD 5450(0x104D-0x9076)"},
{0x1002, 0x68E0, 0x1682, 0x304E, "Caicos [Radeon HD 5450](0x1682-0x304E)"},
{0x1002, 0x68E0, 0x1682, 0x6000, "Caicos [Radeon HD 5450](0x1682-0x6000)"},
{0x1002, 0x68E0, 0x17AA, 0x9E52, "FirePro M3800(0x17AA-0x9E52)"},
{0x1002, 0x68E0, 0x17AA, 0x9E53, "FirePro M3800(0x17AA-0x9E53)"},
{0x1002, 0x68E1, 0xFFFF, 0xFFFF, "Park [Mobility Radeon HD 5430](0x68E1)"},
{0x1002, 0x68E1, 0x1043, 0x041F, "Caicos [Radeon HD 7350](0x1043-0x041F)"},
{0x1002, 0x68E1, 0x1043, 0x3000, "Caicos [Radeon HD 5450](0x1043-0x3000)"},
{0x1002, 0x68E1, 0x148C, 0x3000, "Caicos [Radeon HD 5450](0x148C-0x3000)"},
{0x1002, 0x68E1, 0x148C, 0x3001, "Caicos [Radeon HD 6230](0x148C-0x3001)"},
{0x1002, 0x68E1, 0x148C, 0x3002, "Caicos [Radeon HD 6250](0x148C-0x3002)"},
{0x1002, 0x68E1, 0x148C, 0x3003, "Caicos [Radeon HD 6350](0x148C-0x3003)"},
{0x1002, 0x68E1, 0x148C, 0x7350, "Caicos [Radeon HD 7350](0x148C-0x7350)"},
{0x1002, 0x68E1, 0x148C, 0x8350, "Caicos [Radeon HD 8350](0x148C-0x8350)"},
{0x1002, 0x68E1, 0x1545, 0x5450, "Caicos [Radeon HD 5450](0x1545-0x5450)"},
{0x1002, 0x68E1, 0x1545, 0x7350, "Caicos [Radeon HD 7350](0x1545-0x7350)"},
{0x1002, 0x68E1, 0x1682, 0x3000, "Caicos [Radeon HD 5450](0x1682-0x3000)"},
{0x1002, 0x68E1, 0x1682, 0x6000, "Caicos [Radeon HD 5450](0x1682-0x6000)"},
{0x1002, 0x68E1, 0x1682, 0x7350, "Caicos [Radeon HD 7350](0x1682-0x7350)"},
{0x1002, 0x68E1, 0x174B, 0x3000, "Caicos [Radeon HD 5450](0x174B-0x3000)"},
{0x1002, 0x68E1, 0x174B, 0x5470, "Caicos [Radeon HD 5470](0x174B-0x5470)"},
{0x1002, 0x68E1, 0x174B, 0x6000, "Caicos [Radeon HD 5450](0x174B-0x6000)"},
{0x1002, 0x68E1, 0x174B, 0x6230, "Caicos [Radeon HD 6230](0x174B-0x6230)"},
{0x1002, 0x68E1, 0x174B, 0x6350, "Caicos [Radeon HD 6350](0x174B-0x6350)"},
{0x1002, 0x68E1, 0x174B, 0x7350, "Caicos [Radeon HD 7350](0x174B-0x7350)"},
{0x1002, 0x68E1, 0x1787, 0x3000, "Caicos [Radeon HD 5450](0x1787-0x3000)"},
{0x1002, 0x68E1, 0x17AF, 0x3000, "Caicos [Radeon HD 5450](0x17AF-0x3000)"},
{0x1002, 0x68E1, 0x17AF, 0x3001, "Caicos [Radeon HD 6230](0x17AF-0x3001)"},
{0x1002, 0x68E1, 0x17AF, 0x3014, "Caicos [Radeon HD 6350](0x17AF-0x3014)"},
{0x1002, 0x68E1, 0x17AF, 0x3015, "Caicos [Radeon HD 7350](0x17AF-0x3015)"},
{0x1002, 0x68E1, 0x17AF, 0x8350, "Caicos [Radeon HD 8350 OEM](0x17AF-0x8350)"},
{0x1002, 0x68E4, 0xFFFF, 0xFFFF, "Robson CE [Radeon HD 6370M/7370M](0x68E4)"},
{0x1002, 0x68E4, 0x1019, 0x2386, "Radeon HD 6350M(0x1019-0x2386)"},
{0x1002, 0x68E4, 0x1019, 0x2387, "Radeon HD 6350M(0x1019-0x2387)"},
{0x1002, 0x68E4, 0x1019, 0x238D, "Radeon HD 6370M(0x1019-0x238D)"},
{0x1002, 0x68E4, 0x1019, 0x238E, "Radeon HD 6370M(0x1019-0x238E)"},
{0x1002, 0x68E4, 0x1025, 0x0382, "Radeon HD 6370M(0x1025-0x0382)"},
{0x1002, 0x68E4, 0x1025, 0x0489, "Radeon HD 6370M(0x1025-0x0489)"},
{0x1002, 0x68E4, 0x1025, 0x048A, "Radeon HD 6370M(0x1025-0x048A)"},
{0x1002, 0x68E4, 0x1025, 0x048B, "Radeon HD 6370M(0x1025-0x048B)"},
{0x1002, 0x68E4, 0x1025, 0x048C, "Radeon HD 6370M(0x1025-0x048C)"},
{0x1002, 0x68E4, 0x1028, 0x04C1, "Radeon HD 6370M(0x1028-0x04C1)"},
{0x1002, 0x68E4, 0x1028, 0x04CA, "Radeon HD 6370M(0x1028-0x04CA)"},
{0x1002, 0x68E4, 0x1028, 0x04CC, "Radeon HD 6370M(0x1028-0x04CC)"},
{0x1002, 0x68E4, 0x1028, 0x04CD, "Radeon HD 6370M(0x1028-0x04CD)"},
{0x1002, 0x68E4, 0x1028, 0x04D7, "Radeon HD 6370M(0x1028-0x04D7)"},
{0x1002, 0x68E4, 0x103C, 0x1411, "Radeon HD 6370M(0x103C-0x1411)"},
{0x1002, 0x68E4, 0x103C, 0x1421, "Radeon HD 6370M(0x103C-0x1421)"},
{0x1002, 0x68E4, 0x103C, 0x1426, "Radeon HD 6370M(0x103C-0x1426)"},
{0x1002, 0x68E4, 0x103C, 0x1428, "Radeon HD 6370M(0x103C-0x1428)"},
{0x1002, 0x68E4, 0x103C, 0x142A, "Radeon HD 6370M(0x103C-0x142A)"},
{0x1002, 0x68E4, 0x103C, 0x142B, "Radeon HD 6370M(0x103C-0x142B)"},
{0x1002, 0x68E4, 0x103C, 0x143A, "Radeon HD 6370M(0x103C-0x143A)"},
{0x1002, 0x68E4, 0x103C, 0x143C, "Radeon HD 6370M(0x103C-0x143C)"},
{0x1002, 0x68E4, 0x103C, 0x1445, "Radeon HD 6370M(0x103C-0x1445)"},
{0x1002, 0x68E4, 0x103C, 0x162C, "Radeon HD 6370M(0x103C-0x162C)"},
{0x1002, 0x68E4, 0x103C, 0x162D, "Radeon HD 6370M(0x103C-0x162D)"},
{0x1002, 0x68E4, 0x103C, 0x162E, "Radeon HD 6370M(0x103C-0x162E)"},
{0x1002, 0x68E4, 0x103C, 0x162F, "Radeon HD 6370M(0x103C-0x162F)"},
{0x1002, 0x68E4, 0x103C, 0x1639, "Radeon HD 6370M(0x103C-0x1639)"},
{0x1002, 0x68E4, 0x103C, 0x163A, "Radeon HD 6370M(0x103C-0x163A)"},
{0x1002, 0x68E4, 0x103C, 0x163B, "Radeon HD 6370M(0x103C-0x163B)"},
{0x1002, 0x68E4, 0x103C, 0x163C, "Radeon HD 6370M(0x103C-0x163C)"},
{0x1002, 0x68E4, 0x103C, 0x163D, "Radeon HD 6370M(0x103C-0x163D)"},
{0x1002, 0x68E4, 0x103C, 0x163E, "Radeon HD 6370M(0x103C-0x163E)"},
{0x1002, 0x68E4, 0x103C, 0x163F, "Radeon HD 6370M(0x103C-0x163F)"},
{0x1002, 0x68E4, 0x103C, 0x1641, "Radeon HD 6370M(0x103C-0x1641)"},
{0x1002, 0x68E4, 0x103C, 0x1643, "Radeon HD 6370M(0x103C-0x1643)"},
{0x1002, 0x68E4, 0x103C, 0x3578, "Radeon HD 6370M(0x103C-0x3578)"},
{0x1002, 0x68E4, 0x103C, 0x357A, "Radeon HD 6370M(0x103C-0x357A)"},
{0x1002, 0x68E4, 0x103C, 0x3673, "Radeon HD 6370M(0x103C-0x3673)"},
{0x1002, 0x68E4, 0x103C, 0x3675, "Radeon HD 6370M(0x103C-0x3675)"},
{0x1002, 0x68E4, 0x1043, 0x1C92, "Radeon HD 6370M(0x1043-0x1C92)"},
{0x1002, 0x68E4, 0x1043, 0x84A1, "Radeon HD 6370M(0x1043-0x84A1)"},
{0x1002, 0x68E4, 0x1043, 0x84AD, "Radeon HD 6370M(0x1043-0x84AD)"},
{0x1002, 0x68E4, 0x104D, 0x9081, "Radeon HD 6370M(0x104D-0x9081)"},
{0x1002, 0x68E4, 0x1545, 0x7350, "Cedar [Radeon HD 7350](0x1545-0x7350)"},
{0x1002, 0x68E4, 0x1558, 0x4510, "Radeon HD 6370M(0x1558-0x4510)"},
{0x1002, 0x68E4, 0x1558, 0x5505, "Radeon HD 6370M(0x1558-0x5505)"},
{0x1002, 0x68E4, 0x174B, 0x5450, "Cedar [Radeon HD 5450](0x174B-0x5450)"},
{0x1002, 0x68E4, 0x17AA, 0x21DD, "Radeon HD 6370M(0x17AA-0x21DD)"},
{0x1002, 0x68E4, 0x17AA, 0x21E9, "Radeon HD 6370M(0x17AA-0x21E9)"},
{0x1002, 0x68E4, 0x17AA, 0x3971, "Radeon HD 6370M(0x17AA-0x3971)"},
{0x1002, 0x68E4, 0x17AA, 0x3972, "Radeon HD 7370M(0x17AA-0x3972)"},
{0x1002, 0x68E4, 0x17AA, 0x397A, "Radeon HD 6370M/7370M(0x17AA-0x397A)"},
{0x1002, 0x68E4, 0x17AA, 0x397B, "Radeon HD 6370M/7370M(0x17AA-0x397B)"},
{0x1002, 0x68E4, 0x17AA, 0x397F, "Radeon HD 7370M(0x17AA-0x397F)"},
{0x1002, 0x68E5, 0xFFFF, 0xFFFF, "Robson LE [Radeon HD 6330M](0x68E5)"},
{0x1002, 0x68E5, 0x1179, 0xFD3C, "Radeon HD 6330M(0x1179-0xFD3C)"},
{0x1002, 0x68E5, 0x1179, 0xFD50, "Radeon HD 6330M(0x1179-0xFD50)"},
{0x1002, 0x68E5, 0x1179, 0xFD52, "Radeon HD 6330M(0x1179-0xFD52)"},
{0x1002, 0x68E5, 0x1179, 0xFD63, "Radeon HD 6330M(0x1179-0xFD63)"},
{0x1002, 0x68E5, 0x1179, 0xFD65, "Radeon HD 6330M(0x1179-0xFD65)"},
{0x1002, 0x68E5, 0x1179, 0xFD73, "Radeon HD 6330M(0x1179-0xFD73)"},
{0x1002, 0x68E5, 0x1179, 0xFD75, "Radeon HD 6330M(0x1179-0xFD75)"},
{0x1002, 0x68E5, 0x1179, 0xFDD0, "Radeon HD 6330M(0x1179-0xFDD0)"},
{0x1002, 0x68E5, 0x1179, 0xFDD2, "Radeon HD 6330M(0x1179-0xFDD2)"},
{0x1002, 0x68E5, 0x1179, 0xFDEA, "Radeon HD 6330M(0x1179-0xFDEA)"},
{0x1002, 0x68E5, 0x1179, 0xFDF8, "Radeon HD 6330M(0x1179-0xFDF8)"},
{0x1002, 0x68E5, 0x148C, 0x5450, "Cedar [Radeon HD 5450](0x148C-0x5450)"},
{0x1002, 0x68E5, 0x148C, 0x6350, "Cedar [Radeon HD 6350](0x148C-0x6350)"},
{0x1002, 0x68E5, 0x148C, 0x7350, "Cedar [Radeon HD 7350](0x148C-0x7350)"},
{0x1002, 0x68E5, 0x148C, 0x8350, "Cedar [Radeon HD 8350](0x148C-0x8350)"},
{0x1002, 0x68E5, 0x1545, 0x7350, "Cedar [Radeon HD 7350](0x1545-0x7350)"},
{0x1002, 0x68E8, 0xFFFF, 0xFFFF, "Cedar(0x68E8)"},
{0x1002, 0x68E9, 0xFFFF, 0xFFFF, "Cedar [ATI FirePro (FireGL) Graphics Adapter](0x68E9)"},
{0x1002, 0x68F1, 0xFFFF, 0xFFFF, "Cedar GL [FirePro 2460](0x68F1)"},
{0x1002, 0x68F2, 0xFFFF, 0xFFFF, "Cedar GL [FirePro 2270](0x68F2)"},
{0x1002, 0x68F8, 0xFFFF, 0xFFFF, "Cedar [Radeon HD 7300 Series](0x68F8)"},
{0x1002, 0x68F9, 0xFFFF, 0xFFFF, "Cedar [Radeon HD 5000/6000/7350/8350 Series](0x68F9)"},
{0x1002, 0x68F9, 0x1019, 0x0001, "Radeon HD 5450(0x1019-0x0001)"},
{0x1002, 0x68F9, 0x1019, 0x0002, "Radeon HD 5450(0x1019-0x0002)"},
{0x1002, 0x68F9, 0x1019, 0x0019, "Radeon HD 6350(0x1019-0x0019)"},
{0x1002, 0x68F9, 0x1025, 0x0518, "Radeon HD 5450(0x1025-0x0518)"},
{0x1002, 0x68F9, 0x1025, 0x0519, "Radeon HD 5450(0x1025-0x0519)"},
{0x1002, 0x68F9, 0x1028, 0x010E, "XPS 8300(0x1028-0x010E)"},
{0x1002, 0x68F9, 0x1028, 0x2126, "Radeon HD 6350(0x1028-0x2126)"},
{0x1002, 0x68F9, 0x103C, 0x2126, "Radeon HD 6350(0x103C-0x2126)"},
{0x1002, 0x68F9, 0x103C, 0x2AAC, "Radeon HD 5450(0x103C-0x2AAC)"},
{0x1002, 0x68F9, 0x103C, 0x2AAE, "Radeon HD 5450(0x103C-0x2AAE)"},
{0x1002, 0x68F9, 0x103C, 0x3580, "Radeon HD 5450(0x103C-0x3580)"},
{0x1002, 0x68F9, 0x1043, 0x0386, "Radeon HD 5450(0x1043-0x0386)"},
{0x1002, 0x68F9, 0x1043, 0x03C2, "EAH5450 SILENT/DI/512MD2 (LP)(0x1043-0x03C2)"},
{0x1002, 0x68F9, 0x1458, 0x21D8, "Radeon HD 5450 1GB DDR3 Silent(0x1458-0x21D8)"},
{0x1002, 0x68F9, 0x1462, 0x2130, "Radeon HD 5450(0x1462-0x2130)"},
{0x1002, 0x68F9, 0x1462, 0x2131, "Radeon HD 5450(0x1462-0x2131)"},
{0x1002, 0x68F9, 0x1462, 0x2133, "Radeon HD 6350(0x1462-0x2133)"},
{0x1002, 0x68F9, 0x1462, 0x2180, "Radeon HD 5450(0x1462-0x2180)"},
{0x1002, 0x68F9, 0x1462, 0x2181, "Radeon HD 5450(0x1462-0x2181)"},
{0x1002, 0x68F9, 0x1462, 0x2182, "Radeon HD 6350(0x1462-0x2182)"},
{0x1002, 0x68F9, 0x1462, 0x2183, "Radeon HD 6350(0x1462-0x2183)"},
{0x1002, 0x68F9, 0x1462, 0x2230, "Radeon HD 5450(0x1462-0x2230)"},
{0x1002, 0x68F9, 0x1462, 0x2231, "Radeon HD 5450(0x1462-0x2231)"},
{0x1002, 0x68F9, 0x1462, 0x2495, "Radeon HD 6350(0x1462-0x2495)"},
{0x1002, 0x68F9, 0x148C, 0x3001, "Radeon HD 5530/6250(0x148C-0x3001)"},
{0x1002, 0x68F9, 0x148C, 0x3002, "Radeon HD 6290(0x148C-0x3002)"},
{0x1002, 0x68F9, 0x148C, 0x3003, "Radeon HD 6230(0x148C-0x3003)"},
{0x1002, 0x68F9, 0x148C, 0x3004, "Radeon HD 6350(0x148C-0x3004)"},
{0x1002, 0x68F9, 0x148C, 0x7350, "Radeon HD 7350(0x148C-0x7350)"},
{0x1002, 0x68F9, 0x148C, 0x8350, "Radeon HD 8350(0x148C-0x8350)"},
{0x1002, 0x68F9, 0x1545, 0x7350, "Radeon HD 7350(0x1545-0x7350)"},
{0x1002, 0x68F9, 0x1642, 0x3983, "Radeon HD 5450(0x1642-0x3983)"},
{0x1002, 0x68F9, 0x1642, 0x3984, "Radeon HD 6350(0x1642-0x3984)"},
{0x1002, 0x68F9, 0x1642, 0x3987, "Radeon HD 6350(0x1642-0x3987)"},
{0x1002, 0x68F9, 0x1642, 0x3997, "Radeon HD 5450(0x1642-0x3997)"},
{0x1002, 0x68F9, 0x1642, 0x3A05, "Radeon HD 5450(0x1642-0x3A05)"},
{0x1002, 0x68F9, 0x1642, 0x3B31, "Radeon HD 6350A(0x1642-0x3B31)"},
{0x1002, 0x68F9, 0x1682, 0x3270, "Radeon HD 7350(0x1682-0x3270)"},
{0x1002, 0x68F9, 0x174B, 0x3000, "Radeon HD 6230(0x174B-0x3000)"},
{0x1002, 0x68F9, 0x174B, 0x3987, "Radeon HD 6350(0x174B-0x3987)"},
{0x1002, 0x68F9, 0x174B, 0x5470, "Radeon HD 5470(0x174B-0x5470)"},
{0x1002, 0x68F9, 0x174B, 0x5490, "Radeon HD 5490(0x174B-0x5490)"},
{0x1002, 0x68F9, 0x174B, 0x5530, "Radeon HD 5530(0x174B-0x5530)"},
{0x1002, 0x68F9, 0x174B, 0x6230, "Radeon HD 6230(0x174B-0x6230)"},
{0x1002, 0x68F9, 0x174B, 0x6250, "Radeon HD 6250(0x174B-0x6250)"},
{0x1002, 0x68F9, 0x174B, 0x6290, "Radeon HD 6290(0x174B-0x6290)"},
{0x1002, 0x68F9, 0x174B, 0x6350, "Radeon HD 6350(0x174B-0x6350)"},
{0x1002, 0x68F9, 0x174B, 0x7350, "Radeon HD 7350(0x174B-0x7350)"},
{0x1002, 0x68F9, 0x174B, 0x8350, "Radeon HD 8350(0x174B-0x8350)"},
{0x1002, 0x68F9, 0x174B, 0xE127, "Radeon HD 5450(0x174B-0xE127)"},
{0x1002, 0x68F9, 0x174B, 0xE145, "Radeon HD 5450(0x174B-0xE145)"},
{0x1002, 0x68F9, 0x174B, 0xE153, "Radeon HD 5450(0x174B-0xE153)"},
{0x1002, 0x68F9, 0x1787, 0x3000, "Radeon HD 5470(0x1787-0x3000)"},
{0x1002, 0x68F9, 0x1787, 0x3001, "Radeon HD 5530(0x1787-0x3001)"},
{0x1002, 0x68F9, 0x1787, 0x3002, "Radeon HD 5490(0x1787-0x3002)"},
{0x1002, 0x68F9, 0x17AA, 0x3602, "Radeon HD 5450(0x17AA-0x3602)"},
{0x1002, 0x68F9, 0x17AA, 0x3603, "Radeon HD 5450(0x17AA-0x3603)"},
{0x1002, 0x68F9, 0x17AA, 0x360F, "Radeon HD 5450(0x17AA-0x360F)"},
{0x1002, 0x68F9, 0x17AA, 0x3619, "Radeon HD 5450(0x17AA-0x3619)"},
{0x1002, 0x68F9, 0x17AF, 0x3000, "Radeon HD 6250(0x17AF-0x3000)"},
{0x1002, 0x68F9, 0x17AF, 0x3001, "Radeon HD 6230(0x17AF-0x3001)"},
{0x1002, 0x68F9, 0x17AF, 0x3002, "Radeon HD 6290(0x17AF-0x3002)"},
{0x1002, 0x68F9, 0x17AF, 0x3011, "Radeon HD 5470(0x17AF-0x3011)"},
{0x1002, 0x68F9, 0x17AF, 0x3012, "Radeon HD 5490(0x17AF-0x3012)"},
{0x1002, 0x68F9, 0x17AF, 0x3013, "Radeon HD 5470(0x17AF-0x3013)"},
{0x1002, 0x68F9, 0x17AF, 0x3014, "Radeon HD 6350(0x17AF-0x3014)"},
{0x1002, 0x68FA, 0xFFFF, 0xFFFF, "Cedar [Radeon HD 7350/8350 / R5 220](0x68FA)"},
{0x1002, 0x68FA, 0x1019, 0x0019, "Radeon HD 7350(0x1019-0x0019)"},
{0x1002, 0x68FA, 0x1019, 0x0021, "Radeon HD 7350(0x1019-0x0021)"},
{0x1002, 0x68FA, 0x1019, 0x0022, "Radeon HD 7350(0x1019-0x0022)"},
{0x1002, 0x68FA, 0x1019, 0x0026, "Radeon HD 8350(0x1019-0x0026)"},
{0x1002, 0x68FA, 0x103C, 0x2ADF, "Radeon HD 7350A(0x103C-0x2ADF)"},
{0x1002, 0x68FA, 0x103C, 0x2AE8, "Radeon HD 7350A(0x103C-0x2AE8)"},
{0x1002, 0x68FA, 0x1043, 0x8350, "Radeon HD 8350(0x1043-0x8350)"},
{0x1002, 0x68FA, 0x1462, 0x2128, "Radeon HD 7350(0x1462-0x2128)"},
{0x1002, 0x68FA, 0x1462, 0x2184, "Radeon HD 7350(0x1462-0x2184)"},
{0x1002, 0x68FA, 0x1462, 0x2186, "Radeon HD 7350(0x1462-0x2186)"},
{0x1002, 0x68FA, 0x1462, 0x2495, "Radeon HD 7350(0x1462-0x2495)"},
{0x1002, 0x68FA, 0x1462, 0xB490, "Radeon HD 7350(0x1462-0xB490)"},
{0x1002, 0x68FA, 0x1642, 0x3985, "Radeon HD 7350(0x1642-0x3985)"},
{0x1002, 0x68FA, 0x174B, 0x3510, "Radeon HD 8350(0x174B-0x3510)"},
{0x1002, 0x68FA, 0x174B, 0x3521, "Radeon R5 220(0x174B-0x3521)"},
{0x1002, 0x68FA, 0x174B, 0x3522, "Radeon R5 220(0x174B-0x3522)"},
{0x1002, 0x68FA, 0x174B, 0x7350, "Radeon HD 7350(0x174B-0x7350)"},
{0x1002, 0x68FA, 0x174B, 0x8153, "Radeon HD 8350(0x174B-0x8153)"},
{0x1002, 0x68FA, 0x174B, 0xE127, "Radeon HD 7350(0x174B-0xE127)"},
{0x1002, 0x68FA, 0x174B, 0xE153, "Radeon HD 7350(0x174B-0xE153)"},
{0x1002, 0x68FA, 0x174B, 0xE180, "Radeon HD 7350(0x174B-0xE180)"},
{0x1002, 0x68FA, 0x17AF, 0x3015, "Radeon HD 7350(0x17AF-0x3015)"},
{0x1002, 0x68FE, 0xFFFF, 0xFFFF, "Cedar LE(0x68FE)"},
{0x1002, 0x6900, 0xFFFF, 0xFFFF, "Topaz XT [Radeon R7 M260/M265 / M340/M360 / M440/M445 / 530/535 / 620/625 Mobile](0x6900)"},
{0x1002, 0x6900, 0x1025, 0x1056, "Radeon R7 M360 / R8 M365DX(0x1025-0x1056)"},
{0x1002, 0x6900, 0x1028, 0x0640, "Radeon R7 M260/M265(0x1028-0x0640)"},
{0x1002, 0x6900, 0x1028, 0x0643, "Radeon R7 M260/M265(0x1028-0x0643)"},
{0x1002, 0x6900, 0x1028, 0x067F, "Radeon R7 M260(0x1028-0x067F)"},
{0x1002, 0x6900, 0x1028, 0x0767, "Radeon R7 M445(0x1028-0x0767)"},
{0x1002, 0x6900, 0x1028, 0x0810, "Radeon 530(0x1028-0x0810)"},
{0x1002, 0x6900, 0x1028, 0x130A, "Radeon R7 M260(0x1028-0x130A)"},
{0x1002, 0x6900, 0x103C, 0x2263, "Radeon R7 M260(0x103C-0x2263)"},
{0x1002, 0x6900, 0x103C, 0x2269, "Radeon R7 M260(0x103C-0x2269)"},
{0x1002, 0x6900, 0x103C, 0x22C6, "Radeon R7 M260(0x103C-0x22C6)"},
{0x1002, 0x6900, 0x103C, 0x22C8, "Radeon R7 M260(0x103C-0x22C8)"},
{0x1002, 0x6900, 0x103C, 0x2B45, "Radeon R7 A360(0x103C-0x2B45)"},
{0x1002, 0x6900, 0x103C, 0x808C, "Radeon R7 M260(0x103C-0x808C)"},
{0x1002, 0x6900, 0x103C, 0x8099, "Radeon R7 M360(0x103C-0x8099)"},
{0x1002, 0x6900, 0x103C, 0x80B5, "Radeon R7 M360(0x103C-0x80B5)"},
{0x1002, 0x6900, 0x103C, 0x80B9, "Radeon R7 M360(0x103C-0x80B9)"},
{0x1002, 0x6900, 0x103C, 0x811C, "Radeon R7 M340(0x103C-0x811C)"},
{0x1002, 0x6900, 0x103C, 0x8226, "Radeon R7 M440(0x103C-0x8226)"},
{0x1002, 0x6900, 0x10CF, 0x1906, "Radeon R7 M260(0x10CF-0x1906)"},
{0x1002, 0x6900, 0x1170, 0x9979, "Radeon R7 M360(0x1170-0x9979)"},
{0x1002, 0x6900, 0x1179, 0xF903, "Radeon R7 M260(0x1179-0xF903)"},
{0x1002, 0x6900, 0x1179, 0xF922, "Radeon R7 M260(0x1179-0xF922)"},
{0x1002, 0x6900, 0x1179, 0xF923, "Radeon R7 M260(0x1179-0xF923)"},
{0x1002, 0x6900, 0x1179, 0xF934, "Radeon R7 M260(0x1179-0xF934)"},
{0x1002, 0x6900, 0x17AA, 0x3822, "Radeon R7 M360(0x17AA-0x3822)"},
{0x1002, 0x6900, 0x17AA, 0x3824, "Radeon R7 M360(0x17AA-0x3824)"},
{0x1002, 0x6900, 0x17AA, 0x5021, "Radeon R7 M260(0x17AA-0x5021)"},
{0x1002, 0x6901, 0xFFFF, 0xFFFF, "Topaz PRO [Radeon R5 M255](0x6901)"},
{0x1002, 0x6901, 0x103C, 0x1318, "Radeon R6 M255DX(0x103C-0x1318)"},
{0x1002, 0x6907, 0xFFFF, 0xFFFF, "Meso XT [Radeon R5 M315](0x6907)"},
{0x1002, 0x6920, 0xFFFF, 0xFFFF, "Amethyst [Radeon R9 M395/ M395X Mac Edition](0x6920)"},
{0x1002, 0x6921, 0xFFFF, 0xFFFF, "Amethyst XT [Radeon R9 M295X / M390X](0x6921)"},
{0x1002, 0x6929, 0xFFFF, 0xFFFF, "Tonga XT GL [FirePro S7150](0x6929)"},
{0x1002, 0x692B, 0xFFFF, 0xFFFF, "Tonga PRO GL [FirePro W7100](0x692B)"},
{0x1002, 0x692B, 0x13CC, 0x3D2B, "MXRT-7600(0x13CC-0x3D2B)"},
{0x1002, 0x692F, 0xFFFF, 0xFFFF, "Tonga XTV GL [FirePro S7150V](0x692F)"},
{0x1002, 0x6930, 0xFFFF, 0xFFFF, "Tonga PRO [Radeon R9 380 4GB](0x6930)"},
{0x1002, 0x6938, 0xFFFF, 0xFFFF, "Tonga XT / Amethyst XT [Radeon R9 380X / R9 M295X](0x6938)"},
{0x1002, 0x6938, 0x1043, 0x04F5, "Radeon R9 380X(0x1043-0x04F5)"},
{0x1002, 0x6938, 0x1043, 0x04F7, "Radeon R9 380X(0x1043-0x04F7)"},
{0x1002, 0x6938, 0x106B, 0x013A, "Radeon R9 M295X Mac Edition(0x106B-0x013A)"},
{0x1002, 0x6938, 0x1458, 0x22C8, "Radeon R9 380X(0x1458-0x22C8)"},
{0x1002, 0x6938, 0x148C, 0x2350, "Radeon R9 380X(0x148C-0x2350)"},
{0x1002, 0x6938, 0x1682, 0x9385, "Radeon R9 380X(0x1682-0x9385)"},
{0x1002, 0x6938, 0x174B, 0xE308, "Radeon R9 380X Nitro 4G D5(0x174B-0xE308)"},
{0x1002, 0x6938, 0x17AF, 0x2006, "Radeon R9 380X(0x17AF-0x2006)"},
{0x1002, 0x6939, 0xFFFF, 0xFFFF, "Tonga PRO [Radeon R9 285/380](0x6939)"},
{0x1002, 0x6939, 0x1462, 0x2015, "Radeon R9 380 Gaming 4G(0x1462-0x2015)"},
{0x1002, 0x6939, 0x148C, 0x9380, "Radeon R9 380(0x148C-0x9380)"},
{0x1002, 0x6939, 0x174B, 0xE308, "Radeon R9 380 Nitro 4G D5(0x174B-0xE308)"},
{0x1002, 0x6939, 0x174B, 0xE315, "Radeon R9 285(0x174B-0xE315)"},
{0x1002, 0x693B, 0xFFFF, 0xFFFF, "Tonga PRO GL [FirePro W7100 / Barco MXRT-7600](0x693B)"},
{0x1002, 0x694C, 0xFFFF, 0xFFFF, "Polaris 22 XT [Radeon RX Vega M GH](0x694C)"},
{0x1002, 0x694E, 0xFFFF, 0xFFFF, "Polaris 22 XL [Radeon RX Vega M GL](0x694E)"},
{0x1002, 0x694F, 0xFFFF, 0xFFFF, "Polaris 22 MGL XL [Radeon Pro WX Vega M GL](0x694F)"},
{0x1002, 0x6980, 0xFFFF, 0xFFFF, "Polaris12(0x6980)"},
{0x1002, 0x6981, 0xFFFF, 0xFFFF, "Lexa XT [Radeon PRO WX 3200](0x6981)"},
{0x1002, 0x6985, 0xFFFF, 0xFFFF, "Lexa XT [Radeon PRO WX 3100](0x6985)"},
{0x1002, 0x6985, 0x103C, 0x83B5, "Radeon PRO WX 3100(0x103C-0x83B5)"},
{0x1002, 0x6986, 0xFFFF, 0xFFFF, "Polaris12(0x6986)"},
{0x1002, 0x6987, 0xFFFF, 0xFFFF, "Lexa [Radeon 540X/550X/630 / RX 640 / E9171 MCM](0x6987)"},
{0x1002, 0x698F, 0xFFFF, 0xFFFF, "Lexa XT [Radeon PRO WX 3100 / Barco MXRT 4700](0x698F)"},
{0x1002, 0x6995, 0xFFFF, 0xFFFF, "Lexa XT [Radeon PRO WX 2100](0x6995)"},
{0x1002, 0x699F, 0xFFFF, 0xFFFF, "Lexa PRO [Radeon 540/540X/550/550X / RX 540X/550/550X](0x699F)"},
{0x1002, 0x699F, 0x1028, 0x1720, "Radeon RX 550X(0x1028-0x1720)"},
{0x1002, 0x699F, 0x148C, 0x2380, "Lexa XL [Radeon RX 550](0x148C-0x2380)"},
{0x1002, 0x699F, 0x17AA, 0x5069, "Thinkpad E480/E580(0x17AA-0x5069)"},
{0x1002, 0x699F, 0x1DA2, 0xE367, "Lexa PRO [Radeon RX 550](0x1DA2-0xE367)"},
{0x1002, 0x69A0, 0xFFFF, 0xFFFF, "Vega 12(0x69A0)"},
{0x1002, 0x69A1, 0xFFFF, 0xFFFF, "Vega 12(0x69A1)"},
{0x1002, 0x69A2, 0xFFFF, 0xFFFF, "Vega 12(0x69A2)"},
{0x1002, 0x69A3, 0xFFFF, 0xFFFF, "Vega 12(0x69A3)"},
{0x1002, 0x69AF, 0xFFFF, 0xFFFF, "Vega 12 [Radeon Pro Vega 20](0x69AF)"},
{0x1002, 0x6FDF, 0xFFFF, 0xFFFF, "Polaris 20 XL [Radeon RX 580 2048SP](0x6FDF)"},
{0x1002, 0x700F, 0xFFFF, 0xFFFF, "RS100 AGP Bridge(0x700F)"},
{0x1002, 0x7010, 0xFFFF, 0xFFFF, "RS200/RS250 AGP Bridge(0x7010)"},
{0x1002, 0x7100, 0xFFFF, 0xFFFF, "R520 [Radeon X1800 XT](0x7100)"},
{0x1002, 0x7101, 0xFFFF, 0xFFFF, "R520/M58 [Mobility Radeon X1800 XT](0x7101)"},
{0x1002, 0x7102, 0xFFFF, 0xFFFF, "R520/M58 [Mobility Radeon X1800](0x7102)"},
{0x1002, 0x7104, 0xFFFF, 0xFFFF, "R520 GL [FireGL V7200 / Barco MXTR-5100](0x7104)"},
{0x1002, 0x7104, 0x13CC, 0x3D0A, "MXRT-5100(0x13CC-0x3D0A)"},
{0x1002, 0x7109, 0xFFFF, 0xFFFF, "R520 [Radeon X1800 XL](0x7109)"},
{0x1002, 0x7109, 0x1002, 0x0322, "All-in-Wonder X1800XL(0x1002-0x0322)"},
{0x1002, 0x7109, 0x1002, 0x0D02, "Radeon X1800 CrossFire Edition(0x1002-0x0D02)"},
{0x1002, 0x710A, 0xFFFF, 0xFFFF, "R520 [Radeon X1800 GTO](0x710A)"},
{0x1002, 0x710A, 0x1002, 0x0B12, "Radeon X1800 GTO²(0x1002-0x0B12)"},
{0x1002, 0x710B, 0xFFFF, 0xFFFF, "R520 [Radeon X1800 GTO](0x710B)"},
{0x1002, 0x710E, 0xFFFF, 0xFFFF, "R520 GL [FireGL V7300](0x710E)"},
{0x1002, 0x710E, 0x13CC, 0x3D0C, "MXRT-5150(0x13CC-0x3D0C)"},
{0x1002, 0x710F, 0xFFFF, 0xFFFF, "R520 GL [FireGL V7350](0x710F)"},
{0x1002, 0x710F, 0x13CC, 0x3D0E, "MXRT-7100(0x13CC-0x3D0E)"},
{0x1002, 0x7120, 0xFFFF, 0xFFFF, "R520 [Radeon X1800] (Secondary)(0x7120)"},
{0x1002, 0x7124, 0xFFFF, 0xFFFF, "R520 GL [FireGL V7200] (Secondary)(0x7124)"},
{0x1002, 0x7124, 0x13CC, 0x3D0B, "MXRT-5100 (Secondary)(0x13CC-0x3D0B)"},
{0x1002, 0x7129, 0xFFFF, 0xFFFF, "R520 [Radeon X1800] (Secondary)(0x7129)"},
{0x1002, 0x7129, 0x1002, 0x0323, "All-In-Wonder X1800 XL (Secondary)(0x1002-0x0323)"},
{0x1002, 0x7129, 0x1002, 0x0D03, "Radeon X1800 CrossFire Edition (Secondary)(0x1002-0x0D03)"},
{0x1002, 0x712E, 0xFFFF, 0xFFFF, "R520 GL [FireGL V7300] (Secondary)(0x712E)"},
{0x1002, 0x712E, 0x13CC, 0x3D0D, "MXRT-5150 (Secondary)(0x13CC-0x3D0D)"},
{0x1002, 0x712F, 0xFFFF, 0xFFFF, "R520 GL [FireGL V7350] (Secondary)(0x712F)"},
{0x1002, 0x712F, 0x13CC, 0x3D0F, "MXRT-7100 (Secondary)(0x13CC-0x3D0F)"},
{0x1002, 0x7140, 0xFFFF, 0xFFFF, "RV515 [Radeon X1300/X1550/X1600 Series](0x7140)"},
{0x1002, 0x7142, 0xFFFF, 0xFFFF, "RV515 PRO [Radeon X1300/X1550 Series](0x7142)"},
{0x1002, 0x7142, 0x1002, 0x0322, "All-in-Wonder 2006 PCI-E Edition(0x1002-0x0322)"},
{0x1002, 0x7142, 0x1043, 0x0142, "EAX1300PRO/TD/256M(0x1043-0x0142)"},
{0x1002, 0x7143, 0xFFFF, 0xFFFF, "RV505 [Radeon X1300/X1550 Series](0x7143)"},
{0x1002, 0x7145, 0xFFFF, 0xFFFF, "RV515/M54 [Mobility Radeon X1400](0x7145)"},
{0x1002, 0x7145, 0x17AA, 0x2006, "Thinkpad T60 model 2007(0x17AA-0x2006)"},
{0x1002, 0x7146, 0xFFFF, 0xFFFF, "RV515 [Radeon X1300/X1550](0x7146)"},
{0x1002, 0x7146, 0x1002, 0x0322, "All-in-Wonder 2006 PCI-E Edition(0x1002-0x0322)"},
{0x1002, 0x7146, 0x1545, 0x1996, "Radeon X1300 512MB PCI-e(0x1545-0x1996)"},
{0x1002, 0x7147, 0xFFFF, 0xFFFF, "RV505 [Radeon X1550 64-bit](0x7147)"},
{0x1002, 0x7149, 0xFFFF, 0xFFFF, "RV515/M52 [Mobility Radeon X1300](0x7149)"},
{0x1002, 0x714A, 0xFFFF, 0xFFFF, "RV515/M52 [Mobility Radeon X1300](0x714A)"},
{0x1002, 0x7152, 0xFFFF, 0xFFFF, "RV515 GL [FireGL V3300](0x7152)"},
{0x1002, 0x7153, 0xFFFF, 0xFFFF, "RV515 GL [FireGL V3350](0x7153)"},
{0x1002, 0x715F, 0xFFFF, 0xFFFF, "RV505 CE [Radeon X1550 64-bit](0x715F)"},
{0x1002, 0x7162, 0xFFFF, 0xFFFF, "RV515 PRO [Radeon X1300/X1550 Series] (Secondary)(0x7162)"},
{0x1002, 0x7162, 0x1002, 0x0323, "All-in-Wonder 2006 PCI-E Edition (Secondary)(0x1002-0x0323)"},
{0x1002, 0x7163, 0xFFFF, 0xFFFF, "RV505 [Radeon X1550 Series] (Secondary)(0x7163)"},
{0x1002, 0x7166, 0xFFFF, 0xFFFF, "RV515 [Radeon X1300/X1550 Series] (Secondary)(0x7166)"},
{0x1002, 0x7166, 0x1002, 0x0323, "All-in-Wonder 2006 PCI-E Edition (Secondary)(0x1002-0x0323)"},
{0x1002, 0x7166, 0x1545, 0x1997, "Radeon X1300 512MB PCI-e (Secondary)(0x1545-0x1997)"},
{0x1002, 0x7167, 0xFFFF, 0xFFFF, "RV515 [Radeon X1550 64-bit] (Secondary)(0x7167)"},
{0x1002, 0x7172, 0xFFFF, 0xFFFF, "RV515 GL [FireGL V3300] (Secondary)(0x7172)"},
{0x1002, 0x7173, 0xFFFF, 0xFFFF, "RV515 GL [FireGL V3350] (Secondary)(0x7173)"},
{0x1002, 0x7181, 0xFFFF, 0xFFFF, "RV516 [Radeon X1600/X1650 Series](0x7181)"},
{0x1002, 0x7183, 0xFFFF, 0xFFFF, "RV516 [Radeon X1300/X1550 Series](0x7183)"},
{0x1002, 0x7186, 0xFFFF, 0xFFFF, "RV516/M64 [Mobility Radeon X1450](0x7186)"},
{0x1002, 0x7187, 0xFFFF, 0xFFFF, "RV516 [Radeon X1300/X1550 Series](0x7187)"},
{0x1002, 0x7188, 0xFFFF, 0xFFFF, "RV516/M64-S [Mobility Radeon X2300](0x7188)"},
{0x1002, 0x7188, 0x103C, 0x30C1, "6910p(0x103C-0x30C1)"},
{0x1002, 0x718A, 0xFFFF, 0xFFFF, "RV516/M64 [Mobility Radeon X2300](0x718A)"},
{0x1002, 0x718B, 0xFFFF, 0xFFFF, "RV516/M62 [Mobility Radeon X1350](0x718B)"},
{0x1002, 0x718B, 0x1071, 0x8209, "Medion MIM 2240 Notebook PC [MD98100](0x1071-0x8209)"},
{0x1002, 0x718C, 0xFFFF, 0xFFFF, "RV516/M62-CSP64 [Mobility Radeon X1350](0x718C)"},
{0x1002, 0x718D, 0xFFFF, 0xFFFF, "RV516/M64-CSP128 [Mobility Radeon X1450](0x718D)"},
{0x1002, 0x7193, 0xFFFF, 0xFFFF, "RV516 [Radeon X1550 Series](0x7193)"},
{0x1002, 0x7196, 0xFFFF, 0xFFFF, "RV516/M62-S [Mobility Radeon X1350](0x7196)"},
{0x1002, 0x719B, 0xFFFF, 0xFFFF, "RV516 GL [FireMV 2250](0x719B)"},
{0x1002, 0x719B, 0x13CC, 0x3D12, "MXRT-1150(0x13CC-0x3D12)"},
{0x1002, 0x719B, 0x13CC, 0x3D14, "MXRT-2150(0x13CC-0x3D14)"},
{0x1002, 0x719F, 0xFFFF, 0xFFFF, "RV516 [Radeon X1550 Series](0x719F)"},
{0x1002, 0x71A0, 0xFFFF, 0xFFFF, "RV516 [Radeon X1300/X1550 Series] (Secondary)(0x71A0)"},
{0x1002, 0x71A1, 0xFFFF, 0xFFFF, "RV516 [Radeon X1600/X1650 Series] (Secondary)(0x71A1)"},
{0x1002, 0x71A3, 0xFFFF, 0xFFFF, "RV516 [Radeon X1300/X1550 Series] (Secondary)(0x71A3)"},
{0x1002, 0x71A7, 0xFFFF, 0xFFFF, "RV516 [Radeon X1300/X1550 Series] (Secondary)(0x71A7)"},
{0x1002, 0x71BB, 0xFFFF, 0xFFFF, "RV516 GL [FireMV 2250] (Secondary)(0x71BB)"},
{0x1002, 0x71BB, 0x13CC, 0x3D13, "MXRT-1150 (Secondary)(0x13CC-0x3D13)"},
{0x1002, 0x71BB, 0x13CC, 0x3D15, "MXRT-2150 (Secondary)(0x13CC-0x3D15)"},
{0x1002, 0x71C0, 0xFFFF, 0xFFFF, "RV530 [Radeon X1600 XT/X1650 GTO](0x71C0)"},
{0x1002, 0x71C0, 0x1002, 0xE160, "Radeon X1650 GTO(0x1002-0xE160)"},
{0x1002, 0x71C0, 0x174B, 0xE160, "Radeon X1650 GTO(0x174B-0xE160)"},
{0x1002, 0x71C1, 0xFFFF, 0xFFFF, "RV535 [Radeon X1650 PRO](0x71C1)"},
{0x1002, 0x71C1, 0x174B, 0x0880, "Radeon X1700 FSC(0x174B-0x0880)"},
{0x1002, 0x71C2, 0xFFFF, 0xFFFF, "RV530 [Radeon X1600 PRO](0x71C2)"},
{0x1002, 0x71C3, 0xFFFF, 0xFFFF, "RV530 [Radeon X1600 PRO](0x71C3)"},
{0x1002, 0x71C4, 0xFFFF, 0xFFFF, "RV530/M56 GL [Mobility FireGL V5200](0x71C4)"},
{0x1002, 0x71C4, 0x17AA, 0x2007, "ThinkPad T60p(0x17AA-0x2007)"},
{0x1002, 0x71C5, 0xFFFF, 0xFFFF, "RV530/M56-P [Mobility Radeon X1600](0x71C5)"},
{0x1002, 0x71C5, 0x103C, 0x309F, "Compaq nx9420 Notebook(0x103C-0x309F)"},
{0x1002, 0x71C5, 0x103C, 0x30A3, "Compaq NW8440(0x103C-0x30A3)"},
{0x1002, 0x71C5, 0x1043, 0x10B2, "A6J-Q008(0x1043-0x10B2)"},
{0x1002, 0x71C5, 0x106B, 0x0080, "MacBook Pro(0x106B-0x0080)"},
{0x1002, 0x71C6, 0xFFFF, 0xFFFF, "RV530LE [Radeon X1600/X1650 PRO](0x71C6)"},
{0x1002, 0x71C7, 0xFFFF, 0xFFFF, "RV535 [Radeon X1650 PRO](0x71C7)"},
{0x1002, 0x71C7, 0x1787, 0x3000, "PowerColor X1650 PRO AGP(0x1787-0x3000)"},
{0x1002, 0x71CE, 0xFFFF, 0xFFFF, "RV530 [Radeon X1300 XT/X1600 PRO](0x71CE)"},
{0x1002, 0x71D2, 0xFFFF, 0xFFFF, "RV530 GL [FireGL V3400](0x71D2)"},
{0x1002, 0x71D2, 0x13CC, 0x3D08, "MXRT-2100(0x13CC-0x3D08)"},
{0x1002, 0x71D4, 0xFFFF, 0xFFFF, "RV530/M66 GL [Mobility FireGL V5250](0x71D4)"},
{0x1002, 0x71D5, 0xFFFF, 0xFFFF, "RV530/M66-P [Mobility Radeon X1700](0x71D5)"},
{0x1002, 0x71D6, 0xFFFF, 0xFFFF, "RV530/M66-XT [Mobility Radeon X1700](0x71D6)"},
{0x1002, 0x71DE, 0xFFFF, 0xFFFF, "RV530/M66 [Mobility Radeon X1700/X2500](0x71DE)"},
{0x1002, 0x71E0, 0xFFFF, 0xFFFF, "RV530 [Radeon X1600] (Secondary)(0x71E0)"},
{0x1002, 0x71E0, 0x174B, 0xE161, "Radeon X1600 GTO (Secondary)(0x174B-0xE161)"},
{0x1002, 0x71E1, 0xFFFF, 0xFFFF, "RV535 [Radeon X1650 PRO] (Secondary)(0x71E1)"},
{0x1002, 0x71E1, 0x174B, 0x0881, "Radeon X1700 FSC (Secondary)(0x174B-0x0881)"},
{0x1002, 0x71E2, 0xFFFF, 0xFFFF, "RV530 [Radeon X1600] (Secondary)(0x71E2)"},
{0x1002, 0x71E6, 0xFFFF, 0xFFFF, "RV530 [Radeon X1650] (Secondary)(0x71E6)"},
{0x1002, 0x71E7, 0xFFFF, 0xFFFF, "RV535 [Radeon X1650 PRO] (Secondary)(0x71E7)"},
{0x1002, 0x71E7, 0x1787, 0x3001, "Radeon X1650 PRO AGP(0x1787-0x3001)"},
{0x1002, 0x71F2, 0xFFFF, 0xFFFF, "RV530 GL [FireGL V3400] (Secondary)(0x71F2)"},
{0x1002, 0x71F2, 0x13CC, 0x3D09, "MXRT-2100 (Secondary)(0x13CC-0x3D09)"},
{0x1002, 0x7210, 0xFFFF, 0xFFFF, "RV550/M71 [Mobility Radeon HD 2300](0x7210)"},
{0x1002, 0x7211, 0xFFFF, 0xFFFF, "RV550/M71 [Mobility Radeon X2300 HD](0x7211)"},
{0x1002, 0x7240, 0xFFFF, 0xFFFF, "R580+ [Radeon X1950 XTX](0x7240)"},
{0x1002, 0x7240, 0x1002, 0x0D02, "Radeon X1950 CrossFire Edition(0x1002-0x0D02)"},
{0x1002, 0x7244, 0xFFFF, 0xFFFF, "R580+ [Radeon X1950 XT](0x7244)"},
{0x1002, 0x7248, 0xFFFF, 0xFFFF, "R580 [Radeon X1950](0x7248)"},
{0x1002, 0x7249, 0xFFFF, 0xFFFF, "R580 [Radeon X1900 XT](0x7249)"},
{0x1002, 0x7249, 0x1002, 0x0412, "All-In-Wonder X1900(0x1002-0x0412)"},
{0x1002, 0x7249, 0x1002, 0x0B12, "Radeon X1900 XT/XTX(0x1002-0x0B12)"},
{0x1002, 0x7249, 0x1002, 0x0D02, "Radeon X1900 CrossFire Edition(0x1002-0x0D02)"},
{0x1002, 0x7249, 0x1043, 0x0160, "Radeon X1900 XTX 512 MB GDDR3(0x1043-0x0160)"},
{0x1002, 0x724B, 0xFFFF, 0xFFFF, "R580 [Radeon X1900 GT](0x724B)"},
{0x1002, 0x724B, 0x1002, 0x0B12, "Radeon X1900 (Primary)(0x1002-0x0B12)"},
{0x1002, 0x724B, 0x1002, 0x0B13, "Radeon X1900 (Secondary)(0x1002-0x0B13)"},
{0x1002, 0x724E, 0xFFFF, 0xFFFF, "R580 GL [FireGL V7350](0x724E)"},
{0x1002, 0x7269, 0xFFFF, 0xFFFF, "R580 [Radeon X1900 XT] (Secondary)(0x7269)"},
{0x1002, 0x726B, 0xFFFF, 0xFFFF, "R580 [Radeon X1900 GT] (Secondary)(0x726B)"},
{0x1002, 0x726E, 0xFFFF, 0xFFFF, "R580 [AMD Stream Processor] (Secondary)(0x726E)"},
{0x1002, 0x7280, 0xFFFF, 0xFFFF, "RV570 [Radeon X1950 PRO](0x7280)"},
{0x1002, 0x7288, 0xFFFF, 0xFFFF, "RV570 [Radeon X1950 GT](0x7288)"},
{0x1002, 0x7291, 0xFFFF, 0xFFFF, "RV560 [Radeon X1650 XT](0x7291)"},
{0x1002, 0x7291, 0x1462, 0x0810, "Radeon X1700 SE(0x1462-0x0810)"},
{0x1002, 0x7293, 0xFFFF, 0xFFFF, "RV560 [Radeon X1650 GT](0x7293)"},
{0x1002, 0x72A0, 0xFFFF, 0xFFFF, "RV570 [Radeon X1950 PRO] (Secondary)(0x72A0)"},
{0x1002, 0x72A8, 0xFFFF, 0xFFFF, "RV570 [Radeon X1950 GT] (Secondary)(0x72A8)"},
{0x1002, 0x72B1, 0xFFFF, 0xFFFF, "RV560 [Radeon X1650 XT] (Secondary)(0x72B1)"},
{0x1002, 0x72B3, 0xFFFF, 0xFFFF, "RV560 [Radeon X1650 GT] (Secondary)(0x72B3)"},
{0x1002, 0x7300, 0xFFFF, 0xFFFF, "Fiji [Radeon R9 FURY / NANO Series](0x7300)"},
{0x1002, 0x7300, 0x1002, 0x0B35, "FirePro S9300 X2(0x1002-0x0B35)"},
{0x1002, 0x7300, 0x1002, 0x0B36, "Radeon R9 FURY X / NANO(0x1002-0x0B36)"},
{0x1002, 0x7300, 0x1002, 0x1B36, "Radeon Pro Duo(0x1002-0x1B36)"},
{0x1002, 0x7300, 0x1043, 0x049E, "Radeon R9 FURY(0x1043-0x049E)"},
{0x1002, 0x7300, 0x1043, 0x04A0, "Radeon R9 FURY X(0x1043-0x04A0)"},
{0x1002, 0x7300, 0x174B, 0xE329, "Radeon R9 FURY(0x174B-0xE329)"},
{0x1002, 0x7310, 0xFFFF, 0xFFFF, "Navi 10 [Radeon Pro W5700X](0x7310)"},
{0x1002, 0x7312, 0xFFFF, 0xFFFF, "Navi 10 [Radeon Pro W5700](0x7312)"},
{0x1002, 0x7314, 0xFFFF, 0xFFFF, "Navi 10 USB(0x7314)"},
{0x1002, 0x7319, 0xFFFF, 0xFFFF, "Navi 10 [Radeon Pro 5700 XT](0x7319)"},
{0x1002, 0x731B, 0xFFFF, 0xFFFF, "Navi 10 [Radeon Pro 5700](0x731B)"},
{0x1002, 0x731E, 0xFFFF, 0xFFFF, "TDC-150(0x731E)"},
{0x1002, 0x731F, 0xFFFF, 0xFFFF, "Navi 10 [Radeon RX 5600 OEM/5600 XT / 5700/5700 XT](0x731F)"},
{0x1002, 0x731F, 0x1002, 0x0B36, "Reference RX 5700 XT(0x1002-0x0B36)"},
{0x1002, 0x731F, 0x1458, 0x2313, "Radeon RX 5700 XT Gaming OC(0x1458-0x2313)"},
{0x1002, 0x731F, 0x1458, 0x231D, "Radeon RX 5600 XT/REV 2.0 [Windforce 6GB OC](0x1458-0x231D)"},
{0x1002, 0x731F, 0x148C, 0x2398, "AXRX 5700 XT 8GBD6-3DHE/OC [PowerColor Red Devil Radeon RX 5700 XT](0x148C-0x2398)"},
{0x1002, 0x731F, 0x1682, 0x5701, "RX 5700 XT RAW II(0x1682-0x5701)"},
{0x1002, 0x731F, 0x1849, 0x5120, "Radeon RX 5600 XT(0x1849-0x5120)"},
{0x1002, 0x731F, 0x1DA2, 0xE409, "Sapphire Technology Limited Navi 10 [Radeon RX 5600 OEM/5600 XT / 5700/5700 XT](0x1DA2-0xE409)"},
{0x1002, 0x731F, 0x1DA2, 0xE410, "Sapphire NITRO+ RX 5700 XT(0x1DA2-0xE410)"},
{0x1002, 0x731F, 0x1DA2, 0xE411, "Radeon RX 5600 XT(0x1DA2-0xE411)"},
{0x1002, 0x7340, 0xFFFF, 0xFFFF, "Navi 14 [Radeon RX 5500/5500M / Pro 5500M](0x7340)"},
{0x1002, 0x7341, 0xFFFF, 0xFFFF, "Navi 14 [Radeon Pro W5500](0x7341)"},
{0x1002, 0x7347, 0xFFFF, 0xFFFF, "Navi 14 [Radeon Pro W5500M](0x7347)"},
{0x1002, 0x734F, 0xFFFF, 0xFFFF, "Navi 14 [Radeon Pro W5300M](0x734F)"},
{0x1002, 0x7360, 0xFFFF, 0xFFFF, "Navi 12 [Radeon Pro 5600M/V520/BC-160](0x7360)"},
{0x1002, 0x7362, 0xFFFF, 0xFFFF, "Navi 12 [Radeon Pro V520/V540](0x7362)"},
{0x1002, 0x7388, 0xFFFF, 0xFFFF, "Arcturus GL-XL(0x7388)"},
{0x1002, 0x738C, 0xFFFF, 0xFFFF, "Arcturus GL-XL [Instinct MI100](0x738C)"},
{0x1002, 0x738E, 0xFFFF, 0xFFFF, "Arcturus GL-XL [Instinct MI100](0x738E)"},
{0x1002, 0x73A1, 0xFFFF, 0xFFFF, "Navi 21 [Radeon Pro V620](0x73A1)"},
{0x1002, 0x73A2, 0xFFFF, 0xFFFF, "Navi 21 Pro-XTA [Radeon Pro W6900X](0x73A2)"},
{0x1002, 0x73A3, 0xFFFF, 0xFFFF, "Navi 21 GL-XL [Radeon PRO W6800](0x73A3)"},
{0x1002, 0x73A4, 0xFFFF, 0xFFFF, "Navi 21 USB(0x73A4)"},
{0x1002, 0x73A5, 0xFFFF, 0xFFFF, "Navi 21 [Radeon RX 6950 XT](0x73A5)"},
{0x1002, 0x73A5, 0x1002, 0x0E3A, "Radeon RX 6950 XT(0x1002-0x0E3A)"},
{0x1002, 0x73A5, 0x1849, 0x5230, "Navi 21 [ASRock OC Forumla Radeon RX 6950XT](0x1849-0x5230)"},
{0x1002, 0x73A5, 0x1DA2, 0x441D, "Navi 21 [Sapphire Nitro+ Radeon RX 6950 XT](0x1DA2-0x441D)"},
{0x1002, 0x73A5, 0x1EAE, 0x6950, "Navi 21 [XFX Speedster MERC319 Radeon RX 6950 XT](0x1EAE-0x6950)"},
{0x1002, 0x73AB, 0xFFFF, 0xFFFF, "Navi 21 Pro-XLA [Radeon Pro W6800X/Radeon Pro W6800X Duo](0x73AB)"},
{0x1002, 0x73AE, 0xFFFF, 0xFFFF, "Navi 21 [Radeon Pro V620 MxGPU](0x73AE)"},
{0x1002, 0x73AF, 0xFFFF, 0xFFFF, "Navi 21 [Radeon RX 6900 XT](0x73AF)"},
{0x1002, 0x73AF, 0x148C, 0x2414, "Navi 21 XTXH [PowerColor Red Devil RX 6900 XT Ultimate](0x148C-0x2414)"},
{0x1002, 0x73BF, 0xFFFF, 0xFFFF, "Navi 21 [Radeon RX 6800/6800 XT / 6900 XT](0x73BF)"},
{0x1002, 0x73BF, 0x1002, 0x0E3A, "Radeon RX 6900 XT(0x1002-0x0E3A)"},
{0x1002, 0x73BF, 0x148C, 0x2408, "Red Devil AMD Radeon RX 6900 XT(0x148C-0x2408)"},
{0x1002, 0x73BF, 0x1DA2, 0x438E, "NITRO+ Radeon RX 6800 XT(0x1DA2-0x438E)"},
{0x1002, 0x73BF, 0x1DA2, 0x440F, "TOXIC RX 6900 XT(0x1DA2-0x440F)"},
{0x1002, 0x73BF, 0x1DA2, 0xE437, "Pulse Radeon RX 6800(0x1DA2-0xE437)"},
{0x1002, 0x73BF, 0x1EAE, 0x6701, "Speedster MERC 319 AMD Radeon RX 6800 XT Black(0x1EAE-0x6701)"},
{0x1002, 0x73BF, 0x1EAE, 0x6901, "Speedster MERC 319 AMD Radeon RX 6900 XT Black(0x1EAE-0x6901)"},
{0x1002, 0x73C3, 0xFFFF, 0xFFFF, "Navi 22(0x73C3)"},
{0x1002, 0x73C4, 0xFFFF, 0xFFFF, "Navi 22 USB(0x73C4)"},
{0x1002, 0x73CE, 0xFFFF, 0xFFFF, "Navi 22-XL SRIOV MxGPU(0x73CE)"},
{0x1002, 0x73DF, 0xFFFF, 0xFFFF, "Navi 22 [Radeon RX 6700/6700 XT/6750 XT / 6800M/6850M XT](0x73DF)"},
{0x1002, 0x73DF, 0x1043, 0x16C2, "Radeon RX 6800M(0x1043-0x16C2)"},
{0x1002, 0x73DF, 0x1458, 0x2408, "Radeon RX 6750 XT GAMING OC 12G(0x1458-0x2408)"},
{0x1002, 0x73DF, 0x1462, 0x3980, "Radeon RX 6700 XT Mech 2X 12G [MSI](0x1462-0x3980)"},
{0x1002, 0x73DF, 0x148C, 0x2409, "Red Devil RX 6700 XT(0x148C-0x2409)"},
{0x1002, 0x73DF, 0x1849, 0x5210, "Radeon RX 6700 XT Challenger D(0x1849-0x5210)"},
{0x1002, 0x73DF, 0x1849, 0x5219, "Radeon RX 6700 XT Challenger D(0x1849-0x5219)"},
{0x1002, 0x73DF, 0x1849, 0x5222, "RX 6700 XT Challenger D OC(0x1849-0x5222)"},
{0x1002, 0x73DF, 0x1DA2, 0x445E, "Radeon RX 6700 XT GAMING OC 12G [Sapphire PULSE](0x1DA2-0x445E)"},
{0x1002, 0x73DF, 0x1DA2, 0x465E, "Radeon RX 6750 XT PULSE OC(0x1DA2-0x465E)"},
{0x1002, 0x73DF, 0x1DA2, 0xE445, "Sapphire Radeon RX 6700(0x1DA2-0xE445)"},
{0x1002, 0x73DF, 0x1EAE, 0x6601, "Speedster QICK 319 RX 6700 XT(0x1EAE-0x6601)"},
{0x1002, 0x73DF, 0x1EAE, 0x661A, "Radeon RX 6700 [SPEEDSTER SWFT 309](0x1EAE-0x661A)"},
{0x1002, 0x73E0, 0xFFFF, 0xFFFF, "Navi 23(0x73E0)"},
{0x1002, 0x73E1, 0xFFFF, 0xFFFF, "Navi 23 WKS-XM [Radeon PRO W6600M](0x73E1)"},
{0x1002, 0x73E3, 0xFFFF, 0xFFFF, "Navi 23 WKS-XL [Radeon PRO W6600](0x73E3)"},
{0x1002, 0x73E4, 0xFFFF, 0xFFFF, "Navi 23 USB(0x73E4)"},
{0x1002, 0x73EF, 0xFFFF, 0xFFFF, "Navi 23 [Radeon RX 6650 XT / 6700S / 6800S](0x73EF)"},
{0x1002, 0x73EF, 0x1458, 0x2405, "Navi 23 [Radeon RX 6650 XT](0x1458-0x2405)"},
{0x1002, 0x73EF, 0x1849, 0x5236, "RX 6650 XT Challenger D OC(0x1849-0x5236)"},
{0x1002, 0x73F0, 0xFFFF, 0xFFFF, "Navi 33 [Radeon RX 7600M XT](0x73F0)"},
{0x1002, 0x73FF, 0xFFFF, 0xFFFF, "Navi 23 [Radeon RX 6600/6600 XT/6600M](0x73FF)"},
{0x1002, 0x73FF, 0x1462, 0x5021, "MSI RX 6600XT MECH 2X(0x1462-0x5021)"},
{0x1002, 0x73FF, 0x1462, 0x5022, "RX 6600 MECH 2X(0x1462-0x5022)"},
{0x1002, 0x73FF, 0x148C, 0x2412, "PowerColor Red Devil RX 6600 XT(0x148C-0x2412)"},
{0x1002, 0x73FF, 0x1849, 0x5218, "Radeon RX 6600 Challenger ITX 8GB(0x1849-0x5218)"},
{0x1002, 0x73FF, 0x1DA2, 0x448E, "Radeon RX 6600 XT Pulse(0x1DA2-0x448E)"},
{0x1002, 0x7408, 0xFFFF, 0xFFFF, "Aldebaran/MI200 [Instinct MI250X](0x7408)"},
{0x1002, 0x740C, 0xFFFF, 0xFFFF, "Aldebaran/MI200 [Instinct MI250X/MI250](0x740C)"},
{0x1002, 0x740F, 0xFFFF, 0xFFFF, "Aldebaran/MI200 [Instinct MI210](0x740F)"},
{0x1002, 0x7421, 0xFFFF, 0xFFFF, "Navi 24 [Radeon PRO W6500M](0x7421)"},
{0x1002, 0x7422, 0xFFFF, 0xFFFF, "Navi 24 [Radeon PRO W6400](0x7422)"},
{0x1002, 0x7423, 0xFFFF, 0xFFFF, "Navi 24 [Radeon PRO W6300/W6300M](0x7423)"},
{0x1002, 0x7424, 0xFFFF, 0xFFFF, "Navi 24 [Radeon RX 6300](0x7424)"},
{0x1002, 0x743F, 0xFFFF, 0xFFFF, "Navi 24 [Radeon RX 6400/6500 XT/6500M](0x743F)"},
{0x1002, 0x743F, 0x1DA2, 0xE457, "PULSE AMD Radeon RX 6500 XT(0x1DA2-0xE457)"},
{0x1002, 0x7446, 0xFFFF, 0xFFFF, "Navi 31 USB(0x7446)"},
{0x1002, 0x7448, 0xFFFF, 0xFFFF, "Navi 31 [Radeon Pro W7900](0x7448)"},
{0x1002, 0x744C, 0xFFFF, 0xFFFF, "Navi 31 [Radeon RX 7900 XT/7900 XTX/7900M](0x744C)"},
{0x1002, 0x744C, 0x1002, 0x0E3B, "RX 7900 GRE [XFX](0x1002-0x0E3B)"},
{0x1002, 0x744C, 0x1043, 0x0506, "TUF Gaming Radeon RX 7900 XTX OC(0x1043-0x0506)"},
{0x1002, 0x744C, 0x1849, 0x5304, "Radeon RX 7900 XTX(0x1849-0x5304)"},
{0x1002, 0x744C, 0x1DA2, 0x471E, "PULSE RX 7900 XTX(0x1DA2-0x471E)"},
{0x1002, 0x744C, 0x1DA2, 0x475E, "PULSE RX 7900 GRE(0x1DA2-0x475E)"},
{0x1002, 0x744C, 0x1DA2, 0xE471, "NITRO+ RX 7900 XTX Vapor-X(0x1DA2-0xE471)"},
{0x1002, 0x744C, 0x1EAE, 0x7901, "RX-79XMERCB9 [SPEEDSTER MERC 310 RX 7900 XTX](0x1EAE-0x7901)"},
{0x1002, 0x745E, 0xFFFF, 0xFFFF, "Navi 31 [Radeon Pro W7800](0x745E)"},
{0x1002, 0x7460, 0xFFFF, 0xFFFF, "7460 Navi32 GL-XL [AMD Radeon PRO V710](0x7460)"},
{0x1002, 0x7470, 0xFFFF, 0xFFFF, "Navi 32 [Radeon PRO W7700](0x7470)"},
{0x1002, 0x747E, 0xFFFF, 0xFFFF, "Navi 32 [Radeon RX 7700 XT / 7800 XT](0x747E)"},
{0x1002, 0x7480, 0xFFFF, 0xFFFF, "Navi 33 [Radeon RX 7600/7600 XT/7600M XT/7600S/7700S / PRO W7600](0x7480)"},
{0x1002, 0x7480, 0x1849, 0x5313, "RX 7600 Challenger OC(0x1849-0x5313)"},
{0x1002, 0x7483, 0xFFFF, 0xFFFF, "Navi 33 [Radeon RX 7600M/7600M XT](0x7483)"},
{0x1002, 0x7489, 0xFFFF, 0xFFFF, "Navi 33 [Radeon Pro W7500](0x7489)"},
{0x1002, 0x74A0, 0xFFFF, 0xFFFF, "Aqua Vanjaram [Instinct MI300A](0x74A0)"},
{0x1002, 0x74A1, 0xFFFF, 0xFFFF, "Aqua Vanjaram [Instinct MI300X](0x74A1)"},
{0x1002, 0x7833, 0xFFFF, 0xFFFF, "RS350 Host Bridge(0x7833)"},
{0x1002, 0x7834, 0xFFFF, 0xFFFF, "RS350 [Radeon 9100 PRO/XT IGP](0x7834)"},
{0x1002, 0x7835, 0xFFFF, 0xFFFF, "RS350M [Mobility Radeon 9000 IGP](0x7835)"},
{0x1002, 0x7838, 0xFFFF, 0xFFFF, "RS350 AGP Bridge(0x7838)"},
{0x1002, 0x7910, 0xFFFF, 0xFFFF, "RS690 Host Bridge(0x7910)"},
{0x1002, 0x7910, 0x1179, 0xFF50, "Satellite P305D-S8995E(0x1179-0xFF50)"},
{0x1002, 0x7910, 0x17F2, 0x5000, "KI690-AM2 Motherboard(0x17F2-0x5000)"},
{0x1002, 0x7911, 0xFFFF, 0xFFFF, "RS690/RS740 Host Bridge(0x7911)"},
{0x1002, 0x7911, 0x1002, 0x7910, "RS690/RS740 Host Bridge(0x1002-0x7910)"},
{0x1002, 0x7912, 0xFFFF, 0xFFFF, "RS690/RS740 PCI to PCI Bridge (Internal gfx)(0x7912)"},
{0x1002, 0x7913, 0xFFFF, 0xFFFF, "RS690 PCI to PCI Bridge (PCI Express Graphics Port 0)(0x7913)"},
{0x1002, 0x7915, 0xFFFF, 0xFFFF, "RS690 PCI to PCI Bridge (PCI Express Port 1)(0x7915)"},
{0x1002, 0x7916, 0xFFFF, 0xFFFF, "RS690 PCI to PCI Bridge (PCI Express Port 2)(0x7916)"},
{0x1002, 0x7917, 0xFFFF, 0xFFFF, "RS690 PCI to PCI Bridge (PCI Express Port 3)(0x7917)"},
{0x1002, 0x7917, 0x1002, 0x7910, "RS690 PCI to PCI Bridge(0x1002-0x7910)"},
{0x1002, 0x7919, 0xFFFF, 0xFFFF, "RS690 HDMI Audio [Radeon Xpress 1200 Series](0x7919)"},
{0x1002, 0x7919, 0x1179, 0x7919, "Satellite P305D-S8995E(0x1179-0x7919)"},
{0x1002, 0x7919, 0x17F2, 0x5000, "KI690-AM2 Motherboard(0x17F2-0x5000)"},
{0x1002, 0x791E, 0xFFFF, 0xFFFF, "RS690 [Radeon X1200](0x791E)"},
{0x1002, 0x791E, 0x1462, 0x7327, "K9AG Neo2(0x1462-0x7327)"},
{0x1002, 0x791E, 0x17F2, 0x5000, "KI690-AM2 Motherboard(0x17F2-0x5000)"},
{0x1002, 0x791F, 0xFFFF, 0xFFFF, "RS690M [Radeon Xpress 1200/1250/1270](0x791F)"},
{0x1002, 0x791F, 0x1179, 0xFF50, "Satellite P305D-S8995E(0x1179-0xFF50)"},
{0x1002, 0x7930, 0xFFFF, 0xFFFF, "RS600 Host Bridge(0x7930)"},
{0x1002, 0x7932, 0xFFFF, 0xFFFF, "RS600 PCI to PCI Bridge (Internal gfx)(0x7932)"},
{0x1002, 0x7933, 0xFFFF, 0xFFFF, "RS600 PCI to PCI Bridge (PCI Express Graphics Port 0)(0x7933)"},
{0x1002, 0x7935, 0xFFFF, 0xFFFF, "RS600 PCI to PCI Bridge (PCI Express Port 1)(0x7935)"},
{0x1002, 0x7936, 0xFFFF, 0xFFFF, "RS600 PCI to PCI Bridge (PCI Express Port 2)(0x7936)"},
{0x1002, 0x7937, 0xFFFF, 0xFFFF, "RS690 PCI to PCI Bridge (PCI Express Port 3)(0x7937)"},
{0x1002, 0x793B, 0xFFFF, 0xFFFF, "RS600 HDMI Audio [Radeon Xpress 1250](0x793B)"},
{0x1002, 0x793F, 0xFFFF, 0xFFFF, "RS690M [Radeon Xpress 1200/1250/1270] (Secondary)(0x793F)"},
{0x1002, 0x7941, 0xFFFF, 0xFFFF, "RS600 [Radeon Xpress 1250](0x7941)"},
{0x1002, 0x7942, 0xFFFF, 0xFFFF, "RS600M [Radeon Xpress 1250](0x7942)"},
{0x1002, 0x796E, 0xFFFF, 0xFFFF, "RS740 [Radeon 2100](0x796E)"},
{0x1002, 0x796E, 0x105B, 0x0E13, "N15235/A74MX mainboard(0x105B-0x0E13)"},
{0x1002, 0x9400, 0xFFFF, 0xFFFF, "R600 [Radeon HD 2900 PRO/XT](0x9400)"},
{0x1002, 0x9400, 0x1002, 0x2552, "Radeon HD 2900 XT(0x1002-0x2552)"},
{0x1002, 0x9400, 0x1002, 0x3000, "Radeon HD 2900 PRO(0x1002-0x3000)"},
{0x1002, 0x9400, 0x1002, 0x3142, "HIS Radeon HD 2900XT 512MB GDDR3 VIVO PCIe(0x1002-0x3142)"},
{0x1002, 0x9401, 0xFFFF, 0xFFFF, "R600 [Radeon HD 2900 XT](0x9401)"},
{0x1002, 0x9403, 0xFFFF, 0xFFFF, "R600 [Radeon HD 2900 PRO](0x9403)"},
{0x1002, 0x9405, 0xFFFF, 0xFFFF, "R600 [Radeon HD 2900 GT](0x9405)"},
{0x1002, 0x940A, 0xFFFF, 0xFFFF, "R600 GL [FireGL V8650](0x940A)"},
{0x1002, 0x940A, 0x13CC, 0x3D16, "MXRT-7200(0x13CC-0x3D16)"},
{0x1002, 0x940B, 0xFFFF, 0xFFFF, "R600 GL [FireGL V8600](0x940B)"},
{0x1002, 0x940F, 0xFFFF, 0xFFFF, "R600 GL [FireGL V7600](0x940F)"},
{0x1002, 0x9440, 0xFFFF, 0xFFFF, "RV770 [Radeon HD 4870](0x9440)"},
{0x1002, 0x9441, 0xFFFF, 0xFFFF, "R700 [Radeon HD 4870 X2](0x9441)"},
{0x1002, 0x9442, 0xFFFF, 0xFFFF, "RV770 [Radeon HD 4850](0x9442)"},
{0x1002, 0x9442, 0x1002, 0x0502, "MSI Radeon HD 4850 512MB GDDR3(0x1002-0x0502)"},
{0x1002, 0x9442, 0x174B, 0xE810, "Radeon HD 4850 512MB GDDR3(0x174B-0xE810)"},
{0x1002, 0x9443, 0xFFFF, 0xFFFF, "R700 [Radeon HD 4850 X2](0x9443)"},
{0x1002, 0x9444, 0xFFFF, 0xFFFF, "RV770 GL [FirePro V8750](0x9444)"},
{0x1002, 0x9446, 0xFFFF, 0xFFFF, "RV770 GL [FirePro V7760](0x9446)"},
{0x1002, 0x944A, 0xFFFF, 0xFFFF, "RV770/M98L [Mobility Radeon HD 4850](0x944A)"},
{0x1002, 0x944B, 0xFFFF, 0xFFFF, "RV770/M98 [Mobility Radeon HD 4850 X2](0x944B)"},
{0x1002, 0x944C, 0xFFFF, 0xFFFF, "RV770 LE [Radeon HD 4830](0x944C)"},
{0x1002, 0x944E, 0xFFFF, 0xFFFF, "RV770 CE [Radeon HD 4710](0x944E)"},
{0x1002, 0x944E, 0x174B, 0x3261, "Radeon HD 4810(0x174B-0x3261)"},
{0x1002, 0x9450, 0xFFFF, 0xFFFF, "RV770 GL [FireStream 9270](0x9450)"},
{0x1002, 0x9452, 0xFFFF, 0xFFFF, "RV770 GL [FireStream 9250](0x9452)"},
{0x1002, 0x9456, 0xFFFF, 0xFFFF, "RV770 GL [FirePro V8700](0x9456)"},
{0x1002, 0x945A, 0xFFFF, 0xFFFF, "RV770/M98-XT [Mobility Radeon HD 4870](0x945A)"},
{0x1002, 0x9460, 0xFFFF, 0xFFFF, "RV790 [Radeon HD 4890](0x9460)"},
{0x1002, 0x9462, 0xFFFF, 0xFFFF, "RV790 [Radeon HD 4860](0x9462)"},
{0x1002, 0x946A, 0xFFFF, 0xFFFF, "RV770 GL [FirePro M7750](0x946A)"},
{0x1002, 0x9480, 0xFFFF, 0xFFFF, "RV730/M96 [Mobility Radeon HD 4650/5165](0x9480)"},
{0x1002, 0x9480, 0x103C, 0x3628, "Mobility Radeon HD 4650 [dv6-1190en](0x103C-0x3628)"},
{0x1002, 0x9488, 0xFFFF, 0xFFFF, "RV730/M96-XT [Mobility Radeon HD 4670](0x9488)"},
{0x1002, 0x9489, 0xFFFF, 0xFFFF, "RV730/M96 GL [Mobility FireGL V5725](0x9489)"},
{0x1002, 0x9490, 0xFFFF, 0xFFFF, "RV730 XT [Radeon HD 4670](0x9490)"},
{0x1002, 0x9490, 0x174B, 0xE880, "Radeon HD 4670 512MB GDDR3 Dual DVI-I/TVO(0x174B-0xE880)"},
{0x1002, 0x9491, 0xFFFF, 0xFFFF, "RV730/M96-CSP [Radeon E4690](0x9491)"},
{0x1002, 0x9495, 0xFFFF, 0xFFFF, "RV730 [Radeon HD 4600 AGP Series](0x9495)"},
{0x1002, 0x9495, 0x1002, 0x0028, "Radeon HD 4650/4670 AGP(0x1002-0x0028)"},
{0x1002, 0x9495, 0x1092, 0x0028, "Radeon HD 4670 AGP 512MB DDR2(0x1092-0x0028)"},
{0x1002, 0x9495, 0x1458, 0x0028, "Radeon HD 4650 AGP(0x1458-0x0028)"},
{0x1002, 0x9495, 0x1682, 0x0028, "Radeon HD 4650 AGP(0x1682-0x0028)"},
{0x1002, 0x9495, 0x174B, 0x0028, "Radeon HD 4650 AGP DDR2(0x174B-0x0028)"},
{0x1002, 0x9498, 0xFFFF, 0xFFFF, "RV730 PRO [Radeon HD 4650](0x9498)"},
{0x1002, 0x949C, 0xFFFF, 0xFFFF, "RV730 GL [FirePro V7750](0x949C)"},
{0x1002, 0x949C, 0x13CC, 0x3D1B, "MXRT-7300(0x13CC-0x3D1B)"},
{0x1002, 0x949E, 0xFFFF, 0xFFFF, "RV730 GL [FirePro V5700](0x949E)"},
{0x1002, 0x949F, 0xFFFF, 0xFFFF, "RV730 GL [FirePro V3750](0x949F)"},
{0x1002, 0x94A0, 0xFFFF, 0xFFFF, "RV740/M97 [Mobility Radeon HD 4830](0x94A0)"},
{0x1002, 0x94A1, 0xFFFF, 0xFFFF, "RV740/M97-XT [Mobility Radeon HD 4860](0x94A1)"},
{0x1002, 0x94A3, 0xFFFF, 0xFFFF, "RV740/M97 GL [FirePro M7740](0x94A3)"},
{0x1002, 0x94B3, 0xFFFF, 0xFFFF, "RV740 PRO [Radeon HD 4770](0x94B3)"},
{0x1002, 0x94B4, 0xFFFF, 0xFFFF, "RV740 PRO [Radeon HD 4750](0x94B4)"},
{0x1002, 0x94C1, 0xFFFF, 0xFFFF, "RV610 [Radeon HD 2400 PRO/XT](0x94C1)"},
{0x1002, 0x94C1, 0x1028, 0x0211, "Optiplex 755(0x1028-0x0211)"},
{0x1002, 0x94C1, 0x1028, 0x0D02, "Optiplex 755(0x1028-0x0D02)"},
{0x1002, 0x94C3, 0xFFFF, 0xFFFF, "RV610 [Radeon HD 2400 PRO](0x94C3)"},
{0x1002, 0x94C3, 0x1028, 0x0302, "Radeon HD 2400 Pro(0x1028-0x0302)"},
{0x1002, 0x94C3, 0x174B, 0xE400, "Radeon HD 2400 PRO(0x174B-0xE400)"},
{0x1002, 0x94C3, 0x18BC, 0x3550, "Radeon HD 2400 PRO(0x18BC-0x3550)"},
{0x1002, 0x94C4, 0xFFFF, 0xFFFF, "RV610 LE [Radeon HD 2400 PRO AGP](0x94C4)"},
{0x1002, 0x94C5, 0xFFFF, 0xFFFF, "RV610 [Radeon HD 2400 LE](0x94C5)"},
{0x1002, 0x94C7, 0xFFFF, 0xFFFF, "RV610 [Radeon HD 2350](0x94C7)"},
{0x1002, 0x94C8, 0xFFFF, 0xFFFF, "RV610/M74 [Mobility Radeon HD 2400 XT](0x94C8)"},
{0x1002, 0x94C9, 0xFFFF, 0xFFFF, "RV610/M72-S [Mobility Radeon HD 2400](0x94C9)"},
{0x1002, 0x94C9, 0x1002, 0x94C9, "Radeon HD2400(0x1002-0x94C9)"},
{0x1002, 0x94CB, 0xFFFF, 0xFFFF, "RV610 [Radeon E2400](0x94CB)"},
{0x1002, 0x94CC, 0xFFFF, 0xFFFF, "RV610 LE [Radeon HD 2400 PRO PCI](0x94CC)"},
{0x1002, 0x9500, 0xFFFF, 0xFFFF, "RV670 [Radeon HD 3850 X2](0x9500)"},
{0x1002, 0x9501, 0xFFFF, 0xFFFF, "RV670 [Radeon HD 3870](0x9501)"},
{0x1002, 0x9501, 0x174B, 0xE620, "Radeon HD 3870(0x174B-0xE620)"},
{0x1002, 0x9504, 0xFFFF, 0xFFFF, "RV670/M88 [Mobility Radeon HD 3850](0x9504)"},
{0x1002, 0x9505, 0xFFFF, 0xFFFF, "RV670 [Radeon HD 3690/3850](0x9505)"},
{0x1002, 0x9505, 0x148C, 0x3000, "Radeon HD 3850(0x148C-0x3000)"},
{0x1002, 0x9505, 0x174B, 0x3000, "Radeon HD 3690/3850(0x174B-0x3000)"},
{0x1002, 0x9505, 0x1787, 0x3000, "Radeon HD 3690(0x1787-0x3000)"},
{0x1002, 0x9506, 0xFFFF, 0xFFFF, "RV670/M88 [Mobility Radeon HD 3850 X2](0x9506)"},
{0x1002, 0x9507, 0xFFFF, 0xFFFF, "RV670 [Radeon HD 3830](0x9507)"},
{0x1002, 0x9508, 0xFFFF, 0xFFFF, "RV670/M88-XT [Mobility Radeon HD 3870](0x9508)"},
{0x1002, 0x9509, 0xFFFF, 0xFFFF, "RV670/M88 [Mobility Radeon HD 3870 X2](0x9509)"},
{0x1002, 0x950F, 0xFFFF, 0xFFFF, "R680 [Radeon HD 3870 X2](0x950F)"},
{0x1002, 0x9511, 0xFFFF, 0xFFFF, "RV670 GL [FireGL V7700](0x9511)"},
{0x1002, 0x9513, 0xFFFF, 0xFFFF, "RV670 [Radeon HD 3850 X2](0x9513)"},
{0x1002, 0x9515, 0xFFFF, 0xFFFF, "RV670 PRO [Radeon HD 3850 AGP](0x9515)"},
{0x1002, 0x9519, 0xFFFF, 0xFFFF, "RV670 GL [FireStream 9170](0x9519)"},
{0x1002, 0x9540, 0xFFFF, 0xFFFF, "RV710 [Radeon HD 4550](0x9540)"},
{0x1002, 0x954F, 0xFFFF, 0xFFFF, "RV710 [Radeon HD 4350/4550](0x954F)"},
{0x1002, 0x954F, 0x1462, 0x1618, "R4350 MD512H (MS-V161)(0x1462-0x1618)"},
{0x1002, 0x9552, 0xFFFF, 0xFFFF, "RV710/M92 [Mobility Radeon HD 4330/4350/4550](0x9552)"},
{0x1002, 0x9552, 0x1028, 0x1103, "M92 [Mobility Radeon HD 4330](0x1028-0x1103)"},
{0x1002, 0x9552, 0x1458, 0x21AC, "Radeon HD 4350(0x1458-0x21AC)"},
{0x1002, 0x9552, 0x1458, 0x21ED, "Radeon HD 4550(0x1458-0x21ED)"},
{0x1002, 0x9552, 0x148C, 0x3000, "Radeon HD 4350 Go! Green 512MB GDDR3(0x148C-0x3000)"},
{0x1002, 0x9552, 0x174B, 0x3000, "Radeon HD 4350/4550 HyperMemory DDR2(0x174B-0x3000)"},
{0x1002, 0x9553, 0xFFFF, 0xFFFF, "RV710/M92 [Mobility Radeon HD 4530/4570/5145/530v/540v/545v](0x9553)"},
{0x1002, 0x9553, 0x1025, 0x015E, "Mobility Radeon HD 4570(0x1025-0x015E)"},
{0x1002, 0x9553, 0x1025, 0x017D, "Mobility Radeon HD 4570(0x1025-0x017D)"},
{0x1002, 0x9553, 0x1025, 0x0205, "Mobility Radeon HD 4570 / 545v(0x1025-0x0205)"},
{0x1002, 0x9553, 0x1025, 0x0206, "Mobility Radeon HD 4570(0x1025-0x0206)"},
{0x1002, 0x9553, 0x1025, 0x0237, "Mobility Radeon HD 4570(0x1025-0x0237)"},
{0x1002, 0x9553, 0x1028, 0x02BE, "Mobility Radeon HD 4570 / 545v(0x1028-0x02BE)"},
{0x1002, 0x9553, 0x1028, 0x02E8, "Mobility Radeon HD 4530(0x1028-0x02E8)"},
{0x1002, 0x9553, 0x103C, 0x143C, "Mobility Radeon HD 545v(0x103C-0x143C)"},
{0x1002, 0x9553, 0x103C, 0x1446, "Mobility Radeon HD 545v(0x103C-0x1446)"},
{0x1002, 0x9553, 0x103C, 0x3624, "Mobility Radeon HD 4530(0x103C-0x3624)"},
{0x1002, 0x9553, 0x103C, 0x3628, "Mobility Radeon HD 4530(0x103C-0x3628)"},
{0x1002, 0x9553, 0x103C, 0x3636, "Mobility Radeon HD 4530(0x103C-0x3636)"},
{0x1002, 0x9553, 0x1043, 0x1B32, "Mobility Radeon HD 4570(0x1043-0x1B32)"},
{0x1002, 0x9553, 0x1043, 0x1B42, "Mobility Radeon HD 4570(0x1043-0x1B42)"},
{0x1002, 0x9553, 0x104D, 0x9056, "Mobility Radeon HD 4570(0x104D-0x9056)"},
{0x1002, 0x9553, 0x1179, 0xFF82, "Satellite L505-13T GPU (Mobility Radeon HD 5145)(0x1179-0xFF82)"},
{0x1002, 0x9553, 0x144D, 0xC07F, "Mobility Radeon HD 545v(0x144D-0xC07F)"},
{0x1002, 0x9553, 0x144D, 0xC571, "Mobility Radeon HD 545v(0x144D-0xC571)"},
{0x1002, 0x9553, 0x1462, 0x1006, "Mobility Radeon HD 545v(0x1462-0x1006)"},
{0x1002, 0x9553, 0x17AA, 0x2129, "Mobility Radeon HD 545v(0x17AA-0x2129)"},
{0x1002, 0x9553, 0x17AA, 0x215B, "Mobility Radeon HD 545v(0x17AA-0x215B)"},
{0x1002, 0x9553, 0x17AA, 0x21BB, "Mobility Radeon HD 545v(0x17AA-0x21BB)"},
{0x1002, 0x9555, 0xFFFF, 0xFFFF, "RV711/M93 [Mobility Radeon HD 4350/4550/530v/540v/545v / FirePro RG220](0x9555)"},
{0x1002, 0x9555, 0x103C, 0x1411, "ProBook 4720s GPU (Mobility Radeon HD 4350)(0x103C-0x1411)"},
{0x1002, 0x9557, 0xFFFF, 0xFFFF, "RV711/M93 GL [FirePro RG220](0x9557)"},
{0x1002, 0x955F, 0xFFFF, 0xFFFF, "RV710/M92 [Mobility Radeon HD 4330](0x955F)"},
{0x1002, 0x9580, 0xFFFF, 0xFFFF, "RV630 [Radeon HD 2600 PRO](0x9580)"},
{0x1002, 0x9581, 0xFFFF, 0xFFFF, "RV630/M76 [Mobility Radeon HD 2600](0x9581)"},
{0x1002, 0x9583, 0xFFFF, 0xFFFF, "RV630/M76 [Mobility Radeon HD 2600 XT/2700](0x9583)"},
{0x1002, 0x9583, 0x106B, 0x0083, "iMac 7,1(0x106B-0x0083)"},
{0x1002, 0x9583, 0x1734, 0x1107, "Mobility Radeon HD 2700(0x1734-0x1107)"},
{0x1002, 0x9586, 0xFFFF, 0xFFFF, "RV630 XT [Radeon HD 2600 XT AGP](0x9586)"},
{0x1002, 0x9587, 0xFFFF, 0xFFFF, "RV630 PRO [Radeon HD 2600 PRO AGP](0x9587)"},
{0x1002, 0x9588, 0xFFFF, 0xFFFF, "RV630 XT [Radeon HD 2600 XT](0x9588)"},
{0x1002, 0x9588, 0x1458, 0x216C, "Radeon HD 2600 XT, 256MB GDDR3, 2x DVI, TV-out, PCIe (GV-RX26T256H)(0x1458-0x216C)"},
{0x1002, 0x9589, 0xFFFF, 0xFFFF, "RV630 PRO [Radeon HD 2600 PRO](0x9589)"},
{0x1002, 0x9589, 0x1787, 0x3000, "Radeon HD 3610(0x1787-0x3000)"},
{0x1002, 0x958A, 0xFFFF, 0xFFFF, "RV630 [Radeon HD 2600 X2](0x958A)"},
{0x1002, 0x958B, 0xFFFF, 0xFFFF, "RV630/M76 [Mobility Radeon HD 2600 XT](0x958B)"},
{0x1002, 0x958C, 0xFFFF, 0xFFFF, "RV630 GL [FireGL V5600](0x958C)"},
{0x1002, 0x958C, 0x13CC, 0x3D18, "MXRT-5200(0x13CC-0x3D18)"},
{0x1002, 0x958D, 0xFFFF, 0xFFFF, "RV630 GL [FireGL V3600](0x958D)"},
{0x1002, 0x9591, 0xFFFF, 0xFFFF, "RV635/M86 [Mobility Radeon HD 3650](0x9591)"},
{0x1002, 0x9591, 0x1002, 0x9591, "Mobility Radeon HD 3650(0x1002-0x9591)"},
{0x1002, 0x9593, 0xFFFF, 0xFFFF, "RV635/M86 [Mobility Radeon HD 3670](0x9593)"},
{0x1002, 0x9595, 0xFFFF, 0xFFFF, "RV635/M86 GL [Mobility FireGL V5700](0x9595)"},
{0x1002, 0x9596, 0xFFFF, 0xFFFF, "RV635 PRO [Radeon HD 3650 AGP](0x9596)"},
{0x1002, 0x9596, 0x1043, 0x0028, "EAH3650 SILENT/HTDI/512M/A(0x1043-0x0028)"},
{0x1002, 0x9597, 0xFFFF, 0xFFFF, "RV635 PRO [Radeon HD 3650 AGP](0x9597)"},
{0x1002, 0x9598, 0xFFFF, 0xFFFF, "RV635 [Radeon HD 3650/3750/4570/4580](0x9598)"},
{0x1002, 0x9598, 0x1002, 0x9598, "Mobility Radeon HD 3600(0x1002-0x9598)"},
{0x1002, 0x9598, 0x1043, 0x01D6, "EAH3650 Silent(0x1043-0x01D6)"},
{0x1002, 0x9598, 0x1043, 0x3001, "Radeon HD 4570(0x1043-0x3001)"},
{0x1002, 0x9598, 0x174B, 0x3001, "Radeon HD 3750(0x174B-0x3001)"},
{0x1002, 0x9598, 0x174B, 0x4580, "RV635 PRO [Radeon HD 4580](0x174B-0x4580)"},
{0x1002, 0x9598, 0x17AF, 0x3011, "RV635 PRO [Radeon HD 4580](0x17AF-0x3011)"},
{0x1002, 0x9599, 0xFFFF, 0xFFFF, "RV635 PRO [Radeon HD 3650 AGP](0x9599)"},
{0x1002, 0x95C0, 0xFFFF, 0xFFFF, "RV620 PRO [Radeon HD 3470](0x95C0)"},
{0x1002, 0x95C0, 0x1002, 0x95C0, "Mobility Radeon HD 3470(0x1002-0x95C0)"},
{0x1002, 0x95C0, 0x1028, 0x3243, "C120D(0x1028-0x3243)"},
{0x1002, 0x95C2, 0xFFFF, 0xFFFF, "RV620/M82 [Mobility Radeon HD 3410/3430](0x95C2)"},
{0x1002, 0x95C4, 0xFFFF, 0xFFFF, "RV620/M82 [Mobility Radeon HD 3450/3470](0x95C4)"},
{0x1002, 0x95C4, 0x1002, 0x95C4, "Mobility Radeon HD 3400(0x1002-0x95C4)"},
{0x1002, 0x95C5, 0xFFFF, 0xFFFF, "RV620 LE [Radeon HD 3450](0x95C5)"},
{0x1002, 0x95C5, 0x1028, 0x0342, "Radeon HD 3450 DMS-59(0x1028-0x0342)"},
{0x1002, 0x95C6, 0xFFFF, 0xFFFF, "RV620 LE [Radeon HD 3450 AGP](0x95C6)"},
{0x1002, 0x95C9, 0xFFFF, 0xFFFF, "RV620 LE [Radeon HD 3450 PCI](0x95C9)"},
{0x1002, 0x95CC, 0xFFFF, 0xFFFF, "RV620 GL [FirePro V3700](0x95CC)"},
{0x1002, 0x95CD, 0xFFFF, 0xFFFF, "RV620 GL [FirePro 2450](0x95CD)"},
{0x1002, 0x95CF, 0xFFFF, 0xFFFF, "RV620 GL [FirePro 2260](0x95CF)"},
{0x1002, 0x960F, 0xFFFF, 0xFFFF, "RS780 HDMI Audio [Radeon 3000/3100 / HD 3200/3300](0x960F)"},
{0x1002, 0x960F, 0x1462, 0x7596, "760GM-E51(MS-7596) Motherboard(0x1462-0x7596)"},
{0x1002, 0x9610, 0xFFFF, 0xFFFF, "RS780 [Radeon HD 3200](0x9610)"},
{0x1002, 0x9610, 0x1458, 0xD000, "GA-MA78GM-S2H Motherboard(0x1458-0xD000)"},
{0x1002, 0x9611, 0xFFFF, 0xFFFF, "RS780C [Radeon 3100](0x9611)"},
{0x1002, 0x9612, 0xFFFF, 0xFFFF, "RS780M [Mobility Radeon HD 3200](0x9612)"},
{0x1002, 0x9613, 0xFFFF, 0xFFFF, "RS780MC [Mobility Radeon HD 3100](0x9613)"},
{0x1002, 0x9614, 0xFFFF, 0xFFFF, "RS780D [Radeon HD 3300](0x9614)"},
{0x1002, 0x9615, 0xFFFF, 0xFFFF, "RS780E [Radeon HD 3200](0x9615)"},
{0x1002, 0x9616, 0xFFFF, 0xFFFF, "RS780L [Radeon 3000](0x9616)"},
{0x1002, 0x9616, 0x1462, 0x7501, "760GM-E51(MS-7596) Motherboard(0x1462-0x7501)"},
{0x1002, 0x9640, 0xFFFF, 0xFFFF, "Sumo [Radeon HD 6550D](0x9640)"},
{0x1002, 0x9641, 0xFFFF, 0xFFFF, "Sumo [Radeon HD 6620G](0x9641)"},
{0x1002, 0x9642, 0xFFFF, 0xFFFF, "SuperSumo [Radeon HD 6370D](0x9642)"},
{0x1002, 0x9643, 0xFFFF, 0xFFFF, "SuperSumo [Radeon HD 6380G](0x9643)"},
{0x1002, 0x9644, 0xFFFF, 0xFFFF, "SuperSumo [Radeon HD 6410D](0x9644)"},
{0x1002, 0x9645, 0xFFFF, 0xFFFF, "SuperSumo [Radeon HD 6410D](0x9645)"},
{0x1002, 0x9647, 0xFFFF, 0xFFFF, "Sumo [Radeon HD 6520G](0x9647)"},
{0x1002, 0x9648, 0xFFFF, 0xFFFF, "Sumo [Radeon HD 6480G](0x9648)"},
{0x1002, 0x9649, 0xFFFF, 0xFFFF, "SuperSumo [Radeon HD 6480G](0x9649)"},
{0x1002, 0x964A, 0xFFFF, 0xFFFF, "Sumo [Radeon HD 6530D](0x964A)"},
{0x1002, 0x964B, 0xFFFF, 0xFFFF, "Sumo(0x964B)"},
{0x1002, 0x964C, 0xFFFF, 0xFFFF, "Sumo(0x964C)"},
{0x1002, 0x964E, 0xFFFF, 0xFFFF, "Sumo(0x964E)"},
{0x1002, 0x964F, 0xFFFF, 0xFFFF, "Sumo(0x964F)"},
{0x1002, 0x970F, 0xFFFF, 0xFFFF, "RS880 HDMI Audio [Radeon HD 4200 Series](0x970F)"},
{0x1002, 0x970F, 0x1019, 0x2120, "A785GM-M(0x1019-0x2120)"},
{0x1002, 0x970F, 0x1043, 0x83A2, "M4A785TD Motherboard(0x1043-0x83A2)"},
{0x1002, 0x970F, 0x1043, 0x843E, "M5A88-V EVO(0x1043-0x843E)"},
{0x1002, 0x9710, 0xFFFF, 0xFFFF, "RS880 [Radeon HD 4200](0x9710)"},
{0x1002, 0x9710, 0x1019, 0x2120, "A785GM-M(0x1019-0x2120)"},
{0x1002, 0x9710, 0x1043, 0x83A2, "M4A785TD Motherboard(0x1043-0x83A2)"},
{0x1002, 0x9712, 0xFFFF, 0xFFFF, "RS880M [Mobility Radeon HD 4225/4250](0x9712)"},
{0x1002, 0x9712, 0x103C, 0x1609, "ProLiant MicroServer N36L(0x103C-0x1609)"},
{0x1002, 0x9713, 0xFFFF, 0xFFFF, "RS880M [Mobility Radeon HD 4100](0x9713)"},
{0x1002, 0x9714, 0xFFFF, 0xFFFF, "RS880 [Radeon HD 4290](0x9714)"},
{0x1002, 0x9715, 0xFFFF, 0xFFFF, "RS880 [Radeon HD 4250](0x9715)"},
{0x1002, 0x9715, 0x1043, 0x843E, "M5A88-V EVO(0x1043-0x843E)"},
{0x1002, 0x9802, 0xFFFF, 0xFFFF, "Wrestler [Radeon HD 6310](0x9802)"},
{0x1002, 0x9802, 0x174B, 0x1001, "PURE Fusion Mini(0x174B-0x1001)"},
{0x1002, 0x9803, 0xFFFF, 0xFFFF, "Wrestler [Radeon HD 6310](0x9803)"},
{0x1002, 0x9804, 0xFFFF, 0xFFFF, "Wrestler [Radeon HD 6250](0x9804)"},
{0x1002, 0x9805, 0xFFFF, 0xFFFF, "Wrestler [Radeon HD 6250](0x9805)"},
{0x1002, 0x9806, 0xFFFF, 0xFFFF, "Wrestler [Radeon HD 6320](0x9806)"},
{0x1002, 0x9807, 0xFFFF, 0xFFFF, "Wrestler [Radeon HD 6290](0x9807)"},
{0x1002, 0x9808, 0xFFFF, 0xFFFF, "Wrestler [Radeon HD 7340](0x9808)"},
{0x1002, 0x9809, 0xFFFF, 0xFFFF, "Wrestler [Radeon HD 7310](0x9809)"},
{0x1002, 0x980A, 0xFFFF, 0xFFFF, "Wrestler [Radeon HD 7290](0x980A)"},
{0x1002, 0x9830, 0xFFFF, 0xFFFF, "Kabini [Radeon HD 8400 / R3 Series](0x9830)"},
{0x1002, 0x9830, 0x1043, 0x8623, "AM1I-A Motherboard(0x1043-0x8623)"},
{0x1002, 0x9831, 0xFFFF, 0xFFFF, "Kabini [Radeon HD 8400E](0x9831)"},
{0x1002, 0x9832, 0xFFFF, 0xFFFF, "Kabini [Radeon HD 8330](0x9832)"},
{0x1002, 0x9832, 0x1849, 0x9832, "QC5000-ITX/PH(0x1849-0x9832)"},
{0x1002, 0x9833, 0xFFFF, 0xFFFF, "Kabini [Radeon HD 8330E](0x9833)"},
{0x1002, 0x9834, 0xFFFF, 0xFFFF, "Kabini [Radeon HD 8210](0x9834)"},
{0x1002, 0x9835, 0xFFFF, 0xFFFF, "Kabini [Radeon HD 8310E](0x9835)"},
{0x1002, 0x9836, 0xFFFF, 0xFFFF, "Kabini [Radeon HD 8280 / R3 Series](0x9836)"},
{0x1002, 0x9837, 0xFFFF, 0xFFFF, "Kabini [Radeon HD 8280E](0x9837)"},
{0x1002, 0x9838, 0xFFFF, 0xFFFF, "Kabini [Radeon HD 8240 / R3 Series](0x9838)"},
{0x1002, 0x9839, 0xFFFF, 0xFFFF, "Kabini [Radeon HD 8180](0x9839)"},
{0x1002, 0x983D, 0xFFFF, 0xFFFF, "Temash [Radeon HD 8250/8280G](0x983D)"},
{0x1002, 0x9840, 0xFFFF, 0xFFFF, "Kabini HDMI/DP Audio(0x9840)"},
{0x1002, 0x9840, 0x1043, 0x8623, "AM1I-A Motherboard(0x1043-0x8623)"},
{0x1002, 0x9840, 0x1849, 0x9840, "QC5000-ITX/PH(0x1849-0x9840)"},
{0x1002, 0x9850, 0xFFFF, 0xFFFF, "Mullins [Radeon R3 Graphics](0x9850)"},
{0x1002, 0x9851, 0xFFFF, 0xFFFF, "Mullins [Radeon R4/R5 Graphics](0x9851)"},
{0x1002, 0x9851, 0x1179, 0xF928, "Beema [Radeon R5 Graphics](0x1179-0xF928)"},
{0x1002, 0x9852, 0xFFFF, 0xFFFF, "Mullins [Radeon R2 Graphics](0x9852)"},
{0x1002, 0x9853, 0xFFFF, 0xFFFF, "Mullins [Radeon R2 Graphics](0x9853)"},
{0x1002, 0x9854, 0xFFFF, 0xFFFF, "Mullins [Radeon R3E Graphics](0x9854)"},
{0x1002, 0x9855, 0xFFFF, 0xFFFF, "Mullins [Radeon R6 Graphics](0x9855)"},
{0x1002, 0x9856, 0xFFFF, 0xFFFF, "Mullins [Radeon R1E/R2E Graphics](0x9856)"},
{0x1002, 0x9857, 0xFFFF, 0xFFFF, "Mullins [Radeon APU XX-2200M with R2 Graphics](0x9857)"},
{0x1002, 0x9858, 0xFFFF, 0xFFFF, "Mullins(0x9858)"},
{0x1002, 0x9859, 0xFFFF, 0xFFFF, "Mullins(0x9859)"},
{0x1002, 0x985A, 0xFFFF, 0xFFFF, "Mullins(0x985A)"},
{0x1002, 0x985B, 0xFFFF, 0xFFFF, "Mullins(0x985B)"},
{0x1002, 0x985C, 0xFFFF, 0xFFFF, "Mullins(0x985C)"},
{0x1002, 0x985D, 0xFFFF, 0xFFFF, "Mullins(0x985D)"},
{0x1002, 0x985E, 0xFFFF, 0xFFFF, "Mullins(0x985E)"},
{0x1002, 0x985F, 0xFFFF, 0xFFFF, "Mullins(0x985F)"},
{0x1002, 0x9874, 0xFFFF, 0xFFFF, "Wani [Radeon R5/R6/R7 Graphics](0x9874)"},
{0x1002, 0x9874, 0x1002, 0x1871, "Radeon R5 Graphics(0x1002-0x1871)"},
{0x1002, 0x9874, 0x1002, 0x1E20, "Radeon R7 Graphics(0x1002-0x1E20)"},
{0x1002, 0x9874, 0x1028, 0x06BD, "Radeon R6 Graphics(0x1028-0x06BD)"},
{0x1002, 0x9874, 0x103C, 0x2B44, "Radeon R6 Graphics(0x103C-0x2B44)"},
{0x1002, 0x9874, 0x103C, 0x8221, "Radeon R5 Graphics(0x103C-0x8221)"},
{0x1002, 0x9874, 0x103C, 0x8223, "Radeon R5 Graphics(0x103C-0x8223)"},
{0x1002, 0x9874, 0x103C, 0x8238, "Radeon R7 Graphics(0x103C-0x8238)"},
{0x1002, 0x9874, 0x103C, 0x8353, "Radeon R7 Graphics(0x103C-0x8353)"},
{0x1002, 0x9874, 0x1458, 0xD000, "Radeon R7 Graphics(0x1458-0xD000)"},
{0x1002, 0x9874, 0x17AA, 0x5113, "Radeon R6 Graphics(0x17AA-0x5113)"},
{0x1002, 0x9874, 0x17AA, 0x5116, "Radeon R6 Graphics(0x17AA-0x5116)"},
{0x1002, 0x9874, 0x17AA, 0x5118, "Radeon R5 Graphics(0x17AA-0x5118)"},
{0x1002, 0x9890, 0xFFFF, 0xFFFF, "Amur(0x9890)"},
{0x1002, 0x98C0, 0xFFFF, 0xFFFF, "Nolan(0x98C0)"},
{0x1002, 0x98E4, 0xFFFF, 0xFFFF, "Stoney [Radeon R2/R3/R4/R5 Graphics](0x98E4)"},
{0x1002, 0x9900, 0xFFFF, 0xFFFF, "Trinity [Radeon HD 7660G](0x9900)"},
{0x1002, 0x9900, 0x103C, 0x1985, "Pavilion 17-e163sg Notebook PC(0x103C-0x1985)"},
{0x1002, 0x9901, 0xFFFF, 0xFFFF, "Trinity [Radeon HD 7660D](0x9901)"},
{0x1002, 0x9902, 0xFFFF, 0xFFFF, "Trinity HDMI Audio Controller(0x9902)"},
{0x1002, 0x9902, 0x103C, 0x194E, "ProBook 455 G1 Notebook(0x103C-0x194E)"},
{0x1002, 0x9902, 0x103C, 0x1985, "Pavilion 17-e163sg Notebook PC(0x103C-0x1985)"},
{0x1002, 0x9903, 0xFFFF, 0xFFFF, "Trinity [Radeon HD 7640G](0x9903)"},
{0x1002, 0x9903, 0x103C, 0x194E, "ProBook 455 G1 Notebook(0x103C-0x194E)"},
{0x1002, 0x9903, 0x103C, 0x1952, "ProBook 455 G1 Notebook(0x103C-0x1952)"},
{0x1002, 0x9904, 0xFFFF, 0xFFFF, "Trinity [Radeon HD 7560D](0x9904)"},
{0x1002, 0x9905, 0xFFFF, 0xFFFF, "Trinity GL [FirePro A300](0x9905)"},
{0x1002, 0x9906, 0xFFFF, 0xFFFF, "Trinity GL [FirePro A320](0x9906)"},
{0x1002, 0x9907, 0xFFFF, 0xFFFF, "Trinity [Radeon HD 7620G](0x9907)"},
{0x1002, 0x9908, 0xFFFF, 0xFFFF, "Trinity [Radeon HD 7600G](0x9908)"},
{0x1002, 0x9909, 0xFFFF, 0xFFFF, "Trinity [Radeon HD 7500G](0x9909)"},
{0x1002, 0x990A, 0xFFFF, 0xFFFF, "Trinity [Radeon HD 7500G](0x990A)"},
{0x1002, 0x990B, 0xFFFF, 0xFFFF, "Richland [Radeon HD 8650G](0x990B)"},
{0x1002, 0x990C, 0xFFFF, 0xFFFF, "Richland [Radeon HD 8670D](0x990C)"},
{0x1002, 0x990D, 0xFFFF, 0xFFFF, "Richland [Radeon HD 8550G](0x990D)"},
{0x1002, 0x990E, 0xFFFF, 0xFFFF, "Richland [Radeon HD 8570D](0x990E)"},
{0x1002, 0x990F, 0xFFFF, 0xFFFF, "Richland [Radeon HD 8610G](0x990F)"},
{0x1002, 0x9910, 0xFFFF, 0xFFFF, "Trinity [Radeon HD 7660G](0x9910)"},
{0x1002, 0x9913, 0xFFFF, 0xFFFF, "Trinity [Radeon HD 7640G](0x9913)"},
{0x1002, 0x9917, 0xFFFF, 0xFFFF, "Trinity [Radeon HD 7620G](0x9917)"},
{0x1002, 0x9918, 0xFFFF, 0xFFFF, "Trinity [Radeon HD 7600G](0x9918)"},
{0x1002, 0x9919, 0xFFFF, 0xFFFF, "Trinity [Radeon HD 7500G](0x9919)"},
{0x1002, 0x991E, 0xFFFF, 0xFFFF, "Bishop [Xbox One S APU](0x991E)"},
{0x1002, 0x9920, 0xFFFF, 0xFFFF, "Liverpool [Playstation 4 APU](0x9920)"},
{0x1002, 0x9921, 0xFFFF, 0xFFFF, "Liverpool HDMI/DP Audio Controller(0x9921)"},
{0x1002, 0x9922, 0xFFFF, 0xFFFF, "Starshp(0x9922)"},
{0x1002, 0x9923, 0xFFFF, 0xFFFF, "Starsha2 [Kingston/Clayton](0x9923)"},
{0x1002, 0x9924, 0xFFFF, 0xFFFF, "Gladius(0x9924)"},
{0x1002, 0x9925, 0xFFFF, 0xFFFF, "Kingston/Clayton/Jupiter/Gladius/Montego HDMI Controller(0x9925)"},
{0x1002, 0x9926, 0xFFFF, 0xFFFF, "Jupiter(0x9926)"},
{0x1002, 0x9990, 0xFFFF, 0xFFFF, "Trinity 2 [Radeon HD 7520G](0x9990)"},
{0x1002, 0x9991, 0xFFFF, 0xFFFF, "Trinity 2 [Radeon HD 7540D](0x9991)"},
{0x1002, 0x9992, 0xFFFF, 0xFFFF, "Trinity 2 [Radeon HD 7420G](0x9992)"},
{0x1002, 0x9993, 0xFFFF, 0xFFFF, "Trinity 2 [Radeon HD 7480D](0x9993)"},
{0x1002, 0x9994, 0xFFFF, 0xFFFF, "Trinity 2 [Radeon HD 7400G](0x9994)"},
{0x1002, 0x9995, 0xFFFF, 0xFFFF, "Richland [Radeon HD 8450G](0x9995)"},
{0x1002, 0x9996, 0xFFFF, 0xFFFF, "Richland [Radeon HD 8470D](0x9996)"},
{0x1002, 0x9997, 0xFFFF, 0xFFFF, "Richland [Radeon HD 8350G](0x9997)"},
{0x1002, 0x9998, 0xFFFF, 0xFFFF, "Richland [Radeon HD 8370D](0x9998)"},
{0x1002, 0x9999, 0xFFFF, 0xFFFF, "Richland [Radeon HD 8510G](0x9999)"},
{0x1002, 0x999A, 0xFFFF, 0xFFFF, "Richland [Radeon HD 8410G](0x999A)"},
{0x1002, 0x999B, 0xFFFF, 0xFFFF, "Richland [Radeon HD 8310G](0x999B)"},
{0x1002, 0x999C, 0xFFFF, 0xFFFF, "Richland [Radeon HD 8650D](0x999C)"},
{0x1002, 0x999D, 0xFFFF, 0xFFFF, "Richland [Radeon HD 8550D](0x999D)"},
{0x1002, 0x99A0, 0xFFFF, 0xFFFF, "Trinity 2 [Radeon HD 7520G](0x99A0)"},
{0x1002, 0x99A2, 0xFFFF, 0xFFFF, "Trinity 2 [Radeon HD 7420G](0x99A2)"},
{0x1002, 0x99A4, 0xFFFF, 0xFFFF, "Trinity 2 [Radeon HD 7400G](0x99A4)"},
{0x1002, 0xAA00, 0xFFFF, 0xFFFF, "R600 HDMI Audio [Radeon HD 2900 GT/PRO/XT](0xAA00)"},
{0x1002, 0xAA01, 0xFFFF, 0xFFFF, "RV635 HDMI Audio [Radeon HD 3650/3730/3750](0xAA01)"},
{0x1002, 0xAA08, 0xFFFF, 0xFFFF, "RV630 HDMI Audio [Radeon HD 2600 PRO/XT / HD 3610](0xAA08)"},
{0x1002, 0xAA10, 0xFFFF, 0xFFFF, "RV610 HDMI Audio [Radeon HD 2350 PRO / 2400 PRO/XT / HD 3410](0xAA10)"},
{0x1002, 0xAA10, 0x174B, 0xAA10, "Radeon HD 2400 PRO(0x174B-0xAA10)"},
{0x1002, 0xAA10, 0x18BC, 0xAA10, "Radeon HD 2400 PRO(0x18BC-0xAA10)"},
{0x1002, 0xAA18, 0xFFFF, 0xFFFF, "RV670/680 HDMI Audio [Radeon HD 3690/3800 Series](0xAA18)"},
{0x1002, 0xAA20, 0xFFFF, 0xFFFF, "RV635 HDMI Audio [Radeon HD 3650/3730/3750](0xAA20)"},
{0x1002, 0xAA28, 0xFFFF, 0xFFFF, "RV620 HDMI Audio [Radeon HD 3450/3470/3550/3570](0xAA28)"},
{0x1002, 0xAA30, 0xFFFF, 0xFFFF, "RV770 HDMI Audio [Radeon HD 4850/4870](0xAA30)"},
{0x1002, 0xAA30, 0x174B, 0xAA30, "Radeon HD 4850 512MB GDDR3 PCI-E Dual Slot Fansink(0x174B-0xAA30)"},
{0x1002, 0xAA38, 0xFFFF, 0xFFFF, "RV710/730 HDMI Audio [Radeon HD 4000 series](0xAA38)"},
{0x1002, 0xAA38, 0x103C, 0x3628, "dv6-1190en(0x103C-0x3628)"},
{0x1002, 0xAA50, 0xFFFF, 0xFFFF, "Cypress HDMI Audio [Radeon HD 5830/5850/5870 / 6850/6870 Rebrand](0xAA50)"},
{0x1002, 0xAA58, 0xFFFF, 0xFFFF, "Juniper HDMI Audio [Radeon HD 5700 Series](0xAA58)"},
{0x1002, 0xAA60, 0xFFFF, 0xFFFF, "Redwood HDMI Audio [Radeon HD 5000 Series](0xAA60)"},
{0x1002, 0xAA60, 0x1025, 0x033D, "Mobility Radeon HD 5650(0x1025-0x033D)"},
{0x1002, 0xAA60, 0x1025, 0x0347, "Aspire 7740G(0x1025-0x0347)"},
{0x1002, 0xAA68, 0xFFFF, 0xFFFF, "Cedar HDMI Audio [Radeon HD 5400/6300/7300 Series](0xAA68)"},
{0x1002, 0xAA68, 0x1028, 0xAA68, "XPS 8300(0x1028-0xAA68)"},
{0x1002, 0xAA80, 0xFFFF, 0xFFFF, "Cayman/Antilles HDMI Audio [Radeon HD 6930/6950/6970/6990](0xAA80)"},
{0x1002, 0xAA88, 0xFFFF, 0xFFFF, "Barts HDMI Audio [Radeon HD 6790/6850/6870 / 7720 OEM](0xAA88)"},
{0x1002, 0xAA90, 0xFFFF, 0xFFFF, "Turks HDMI Audio [Radeon HD 6500/6600 / 6700M Series](0xAA90)"},
{0x1002, 0xAA90, 0x1028, 0x04A3, "Precision M4600(0x1028-0x04A3)"},
{0x1002, 0xAA98, 0xFFFF, 0xFFFF, "Caicos HDMI Audio [Radeon HD 6450 / 7450/8450/8490 OEM / R5 230/235/235X OEM](0xAA98)"},
{0x1002, 0xAA98, 0x1043, 0xAA98, "EAH6450 SILENT/DI/1GD3(LP)(0x1043-0xAA98)"},
{0x1002, 0xAA98, 0x174B, 0xAA98, "Radeon HD 6450 1GB DDR3(0x174B-0xAA98)"},
{0x1002, 0xAAA0, 0xFFFF, 0xFFFF, "Tahiti HDMI Audio [Radeon HD 7870 XT / 7950/7970](0xAAA0)"},
{0x1002, 0xAAB0, 0xFFFF, 0xFFFF, "Oland/Hainan/Cape Verde/Pitcairn HDMI Audio [Radeon HD 7000 Series](0xAAB0)"},
{0x1002, 0xAAB8, 0xFFFF, 0xFFFF, "Tiran HDMI Audio(0xAAB8)"},
{0x1002, 0xAAC0, 0xFFFF, 0xFFFF, "Tobago HDMI Audio [Radeon R7 360 / R9 360 OEM](0xAAC0)"},
{0x1002, 0xAAC0, 0x1043, 0xAAC0, "R7260X-DC2OC-2GD5(0x1043-0xAAC0)"},
{0x1002, 0xAAC8, 0xFFFF, 0xFFFF, "Hawaii HDMI Audio [Radeon R9 290/290X / 390/390X](0xAAC8)"},
{0x1002, 0xAAD8, 0xFFFF, 0xFFFF, "Tonga HDMI Audio [Radeon R9 285/380](0xAAD8)"},
{0x1002, 0xAAD8, 0x174B, 0xAAD8, "Radeon R9 285/380 HDMI Audio(0x174B-0xAAD8)"},
{0x1002, 0xAAE0, 0xFFFF, 0xFFFF, "Baffin HDMI/DP Audio [Radeon RX 550 640SP / RX 560/560X](0xAAE0)"},
{0x1002, 0xAAE8, 0xFFFF, 0xFFFF, "Fiji HDMI/DP Audio [Radeon R9 Nano / FURY/FURY X](0xAAE8)"},
{0x1002, 0xAAF0, 0xFFFF, 0xFFFF, "Ellesmere HDMI Audio [Radeon RX 470/480 / 570/580/590](0xAAF0)"},
{0x1002, 0xAAF8, 0xFFFF, 0xFFFF, "Vega 10 HDMI Audio [Radeon Vega 56/64](0xAAF8)"},
{0x1002, 0xAB00, 0xFFFF, 0xFFFF, "Baffin HDMI/DP Audio [Radeon RX 550 640SP / RX 560/560X](0xAB00)"},
{0x1002, 0xAB08, 0xFFFF, 0xFFFF, "Polaris 22 HDMI Audio(0xAB08)"},
{0x1002, 0xAB10, 0xFFFF, 0xFFFF, "Lexa HDMI Audio(0xAB10)"},
{0x1002, 0xAB18, 0xFFFF, 0xFFFF, "Vega 12 HDMI Audio(0xAB18)"},
{0x1002, 0xAB20, 0xFFFF, 0xFFFF, "Vega 20 HDMI Audio [Radeon VII](0xAB20)"},
{0x1002, 0xAB28, 0xFFFF, 0xFFFF, "Navi 21/23 HDMI/DP Audio Controller(0xAB28)"},
{0x1002, 0xAB30, 0xFFFF, 0xFFFF, "Navi 31 HDMI/DP Audio(0xAB30)"},
{0x1002, 0xAB38, 0xFFFF, 0xFFFF, "Navi 10 HDMI Audio(0xAB38)"},
{0x1002, 0xAC00, 0xFFFF, 0xFFFF, "Theater 506 World-Wide Analog Decoder(0xAC00)"},
{0x1002, 0xAC01, 0xFFFF, 0xFFFF, "Theater 506 World-Wide Analog Decoder(0xAC01)"},
{0x1002, 0xAC02, 0xFFFF, 0xFFFF, "TV Wonder HD 600 PCIe(0xAC02)"},
{0x1002, 0xAC03, 0xFFFF, 0xFFFF, "Theater 506 PCIe(0xAC03)"},
{0x1002, 0xAC04, 0xFFFF, 0xFFFF, "Theater 506 USB(0xAC04)"},
{0x1002, 0xAC05, 0xFFFF, 0xFFFF, "Theater 506 USB(0xAC05)"},
{0x1002, 0xAC06, 0xFFFF, 0xFFFF, "Theater 506 External USB(0xAC06)"},
{0x1002, 0xAC07, 0xFFFF, 0xFFFF, "Theater 506 External USB(0xAC07)"},
{0x1002, 0xAC08, 0xFFFF, 0xFFFF, "Theater 506A World-Wide Analog Decoder + Demodulator(0xAC08)"},
{0x1002, 0xAC09, 0xFFFF, 0xFFFF, "Theater 506A World-Wide Analog Decoder + Demodulator(0xAC09)"},
{0x1002, 0xAC0A, 0xFFFF, 0xFFFF, "Theater 506A PCIe(0xAC0A)"},
{0x1002, 0xAC0B, 0xFFFF, 0xFFFF, "Theater 506A PCIe(0xAC0B)"},
{0x1002, 0xAC0C, 0xFFFF, 0xFFFF, "Theater 506A USB(0xAC0C)"},
{0x1002, 0xAC0D, 0xFFFF, 0xFFFF, "Theater 506A USB(0xAC0D)"},
{0x1002, 0xAC0E, 0xFFFF, 0xFFFF, "Theater 506A External USB(0xAC0E)"},
{0x1002, 0xAC0F, 0xFFFF, 0xFFFF, "Theater 506A External USB(0xAC0F)"},
{0x1002, 0xAC12, 0xFFFF, 0xFFFF, "Theater HD T507 (DVB-T) TV tuner/capture device(0xAC12)"},
{0x1002, 0xCAB0, 0xFFFF, 0xFFFF, "RS100 Host Bridge(0xCAB0)"},
{0x1002, 0xCAB2, 0xFFFF, 0xFFFF, "RS200 Host Bridge(0xCAB2)"},
{0x1002, 0xCAB3, 0xFFFF, 0xFFFF, "RS250 Host Bridge(0xCAB3)"},
{0x1002, 0xCBB2, 0xFFFF, 0xFFFF, "RS200 Host Bridge(0xCBB2)"},
}; /* pci_vid_1002[] */

static pci_id_t const pci_vid_1003[] = {
{0x1003, 0xFFFF, 0xFFFF, 0xFFFF, "ULSI Systems(0x1003)"},
{0x1003, 0x0201, 0xFFFF, 0xFFFF, "US201(0x0201)"},
}; /* pci_vid_1003[] */

static pci_id_t const pci_vid_1004[] = {
{0x1004, 0xFFFF, 0xFFFF, 0xFFFF, "VLSI Technology Inc(0x1004)"},
{0x1004, 0x0005, 0xFFFF, 0xFFFF, "82C592-FC1(0x0005)"},
{0x1004, 0x0006, 0xFFFF, 0xFFFF, "82C593-FC1(0x0006)"},
{0x1004, 0x0007, 0xFFFF, 0xFFFF, "82C594-AFC2(0x0007)"},
{0x1004, 0x0008, 0xFFFF, 0xFFFF, "82C596/7 [Wildcat](0x0008)"},
{0x1004, 0x0009, 0xFFFF, 0xFFFF, "82C597-AFC2(0x0009)"},
{0x1004, 0x000C, 0xFFFF, 0xFFFF, "82C541 [Lynx](0x000C)"},
{0x1004, 0x000D, 0xFFFF, 0xFFFF, "82C543 [Lynx](0x000D)"},
{0x1004, 0x0101, 0xFFFF, 0xFFFF, "82C532(0x0101)"},
{0x1004, 0x0102, 0xFFFF, 0xFFFF, "82C534 [Eagle](0x0102)"},
{0x1004, 0x0103, 0xFFFF, 0xFFFF, "82C538(0x0103)"},
{0x1004, 0x0104, 0xFFFF, 0xFFFF, "82C535(0x0104)"},
{0x1004, 0x0105, 0xFFFF, 0xFFFF, "82C147(0x0105)"},
{0x1004, 0x0200, 0xFFFF, 0xFFFF, "82C975(0x0200)"},
{0x1004, 0x0280, 0xFFFF, 0xFFFF, "82C925(0x0280)"},
{0x1004, 0x0304, 0xFFFF, 0xFFFF, "QSound ThunderBird PCI Audio(0x0304)"},
{0x1004, 0x0304, 0x1004, 0x0304, "QSound ThunderBird PCI Audio(0x1004-0x0304)"},
{0x1004, 0x0304, 0x122D, 0x1206, "DSP368 Audio(0x122D-0x1206)"},
{0x1004, 0x0304, 0x1483, 0x5020, "XWave Thunder 3D Audio(0x1483-0x5020)"},
{0x1004, 0x0305, 0xFFFF, 0xFFFF, "QSound ThunderBird PCI Audio Gameport(0x0305)"},
{0x1004, 0x0305, 0x1004, 0x0305, "QSound ThunderBird PCI Audio Gameport(0x1004-0x0305)"},
{0x1004, 0x0305, 0x122D, 0x1207, "DSP368 Audio Gameport(0x122D-0x1207)"},
{0x1004, 0x0305, 0x1483, 0x5021, "XWave Thunder 3D Audio Gameport(0x1483-0x5021)"},
{0x1004, 0x0306, 0xFFFF, 0xFFFF, "QSound ThunderBird PCI Audio Support Registers(0x0306)"},
{0x1004, 0x0306, 0x1004, 0x0306, "QSound ThunderBird PCI Audio Support Registers(0x1004-0x0306)"},
{0x1004, 0x0306, 0x122D, 0x1208, "DSP368 Audio Support Registers(0x122D-0x1208)"},
{0x1004, 0x0306, 0x1483, 0x5022, "XWave Thunder 3D Audio Support Registers(0x1483-0x5022)"},
{0x1004, 0x0307, 0xFFFF, 0xFFFF, "SAA7785 ThunderBird PCI Audio(0x0307)"},
{0x1004, 0x0307, 0x1004, 0x0703, "Philips Rhythmic Edge PSC703(0x1004-0x0703)"},
{0x1004, 0x0307, 0x1004, 0x0705, "Philips Seismic Edge PSC705(0x1004-0x0705)"},
{0x1004, 0x0307, 0x1004, 0x0706, "Philips Acoustic Edge PSC706(0x1004-0x0706)"},
{0x1004, 0x0308, 0xFFFF, 0xFFFF, "SAA7785 ThunderBird PCI Audio Gameport(0x0308)"},
{0x1004, 0x0702, 0xFFFF, 0xFFFF, "VAS96011 [Golden Gate II](0x0702)"},
{0x1004, 0x0703, 0xFFFF, 0xFFFF, "Tollgate(0x0703)"},
}; /* pci_vid_1004[] */

static pci_id_t const pci_vid_1005[] = {
{0x1005, 0xFFFF, 0xFFFF, 0xFFFF, "Avance Logic Inc. [ALI](0x1005)"},
{0x1005, 0x2064, 0xFFFF, 0xFFFF, "ALG2032/2064(0x2064)"},
{0x1005, 0x2128, 0xFFFF, 0xFFFF, "ALG2364A(0x2128)"},
{0x1005, 0x2301, 0xFFFF, 0xFFFF, "ALG2301(0x2301)"},
{0x1005, 0x2302, 0xFFFF, 0xFFFF, "ALG2302(0x2302)"},
{0x1005, 0x2364, 0xFFFF, 0xFFFF, "ALG2364(0x2364)"},
{0x1005, 0x2464, 0xFFFF, 0xFFFF, "ALG2364A(0x2464)"},
{0x1005, 0x2501, 0xFFFF, 0xFFFF, "ALG2564A/25128A(0x2501)"},
}; /* pci_vid_1005[] */

static pci_id_t const pci_vid_1006[] = {
{0x1006, 0xFFFF, 0xFFFF, 0xFFFF, "Reply Group(0x1006)"},
}; /* pci_vid_1006[] */

static pci_id_t const pci_vid_1007[] = {
{0x1007, 0xFFFF, 0xFFFF, 0xFFFF, "NetFrame Systems Inc(0x1007)"},
}; /* pci_vid_1007[] */

static pci_id_t const pci_vid_1008[] = {
{0x1008, 0xFFFF, 0xFFFF, 0xFFFF, "Epson(0x1008)"},
}; /* pci_vid_1008[] */

static pci_id_t const pci_vid_100A[] = {
{0x100A, 0xFFFF, 0xFFFF, 0xFFFF, "Phoenix Technologies(0x100A)"},
}; /* pci_vid_100A[] */

static pci_id_t const pci_vid_100B[] = {
{0x100B, 0xFFFF, 0xFFFF, 0xFFFF, "National Semiconductor Corporation(0x100B)"},
{0x100B, 0x0001, 0xFFFF, 0xFFFF, "DP83810(0x0001)"},
{0x100B, 0x0002, 0xFFFF, 0xFFFF, "87415/87560 IDE(0x0002)"},
{0x100B, 0x000E, 0xFFFF, 0xFFFF, "87560 Legacy I/O(0x000E)"},
{0x100B, 0x000F, 0xFFFF, 0xFFFF, "FireWire Controller(0x000F)"},
{0x100B, 0x0011, 0xFFFF, 0xFFFF, "NS87560 National PCI System I/O(0x0011)"},
{0x100B, 0x0012, 0xFFFF, 0xFFFF, "USB Controller(0x0012)"},
{0x100B, 0x0020, 0xFFFF, 0xFFFF, "DP83815 (MacPhyter) Ethernet Controller(0x0020)"},
{0x100B, 0x0020, 0x103C, 0x0024, "Pavilion ze4400 builtin Network(0x103C-0x0024)"},
{0x100B, 0x0020, 0x12D9, 0x000C, "Aculab E1/T1 PMXc cPCI carrier card(0x12D9-0x000C)"},
{0x100B, 0x0020, 0x1385, 0xF311, "FA311 / FA312 (FA311 with WoL HW)(0x1385-0xF311)"},
{0x100B, 0x0020, 0x1385, 0xF312, "FA312 (rev. A1) Fast Ethernet PCI Adapter(0x1385-0xF312)"},
{0x100B, 0x0021, 0xFFFF, 0xFFFF, "PC87200 PCI to ISA Bridge(0x0021)"},
{0x100B, 0x0022, 0xFFFF, 0xFFFF, "DP83820 10/100/1000 Ethernet Controller(0x0022)"},
{0x100B, 0x0022, 0x1186, 0x4900, "DGE-500T(0x1186-0x4900)"},
{0x100B, 0x0022, 0x1385, 0x621A, "GA621(0x1385-0x621A)"},
{0x100B, 0x0022, 0x1385, 0x622A, "GA622T(0x1385-0x622A)"},
{0x100B, 0x0028, 0xFFFF, 0xFFFF, "Geode GX2 Host Bridge(0x0028)"},
{0x100B, 0x002A, 0xFFFF, 0xFFFF, "CS5535 South Bridge(0x002A)"},
{0x100B, 0x002B, 0xFFFF, 0xFFFF, "CS5535 ISA bridge(0x002B)"},
{0x100B, 0x002D, 0xFFFF, 0xFFFF, "CS5535 IDE(0x002D)"},
{0x100B, 0x002E, 0xFFFF, 0xFFFF, "CS5535 Audio(0x002E)"},
{0x100B, 0x002F, 0xFFFF, 0xFFFF, "CS5535 USB(0x002F)"},
{0x100B, 0x0030, 0xFFFF, 0xFFFF, "Geode GX2 Graphics Processor(0x0030)"},
{0x100B, 0x0035, 0xFFFF, 0xFFFF, "DP83065 [Saturn] 10/100/1000 Ethernet Controller(0x0035)"},
{0x100B, 0x0500, 0xFFFF, 0xFFFF, "SCx200 Bridge(0x0500)"},
{0x100B, 0x0501, 0xFFFF, 0xFFFF, "SCx200 SMI(0x0501)"},
{0x100B, 0x0502, 0xFFFF, 0xFFFF, "SCx200, SC1100 IDE controller(0x0502)"},
{0x100B, 0x0502, 0x100B, 0x0502, "IDE Controller(0x100B-0x0502)"},
{0x100B, 0x0503, 0xFFFF, 0xFFFF, "SCx200, SC1100 Audio Controller(0x0503)"},
{0x100B, 0x0503, 0x100B, 0x0503, "XpressAudio controller(0x100B-0x0503)"},
{0x100B, 0x0504, 0xFFFF, 0xFFFF, "SCx200 Video(0x0504)"},
{0x100B, 0x0505, 0xFFFF, 0xFFFF, "SCx200 XBus(0x0505)"},
{0x100B, 0x0510, 0xFFFF, 0xFFFF, "SC1100 Bridge(0x0510)"},
{0x100B, 0x0510, 0x100B, 0x0500, "GPIO and LPC support bridge(0x100B-0x0500)"},
{0x100B, 0x0511, 0xFFFF, 0xFFFF, "SC1100 SMI & ACPI(0x0511)"},
{0x100B, 0x0511, 0x100B, 0x0501, "SC1100 SMI & ACPI bridge(0x100B-0x0501)"},
{0x100B, 0x0515, 0xFFFF, 0xFFFF, "SC1100 XBus(0x0515)"},
{0x100B, 0x0515, 0x100B, 0x0505, "SC1100 PCI to XBus bridge(0x100B-0x0505)"},
{0x100B, 0xD001, 0xFFFF, 0xFFFF, "87410 IDE(0xD001)"},
}; /* pci_vid_100B[] */

static pci_id_t const pci_vid_100C[] = {
{0x100C, 0xFFFF, 0xFFFF, 0xFFFF, "Tseng Labs Inc(0x100C)"},
{0x100C, 0x3202, 0xFFFF, 0xFFFF, "ET4000/W32p rev A(0x3202)"},
{0x100C, 0x3205, 0xFFFF, 0xFFFF, "ET4000/W32p rev B(0x3205)"},
{0x100C, 0x3206, 0xFFFF, 0xFFFF, "ET4000/W32p rev C(0x3206)"},
{0x100C, 0x3207, 0xFFFF, 0xFFFF, "ET4000/W32p rev D(0x3207)"},
{0x100C, 0x3208, 0xFFFF, 0xFFFF, "ET6000(0x3208)"},
{0x100C, 0x4702, 0xFFFF, 0xFFFF, "ET6300(0x4702)"},
}; /* pci_vid_100C[] */

static pci_id_t const pci_vid_100D[] = {
{0x100D, 0xFFFF, 0xFFFF, 0xFFFF, "AST Research Inc(0x100D)"},
}; /* pci_vid_100D[] */

static pci_id_t const pci_vid_100E[] = {
{0x100E, 0xFFFF, 0xFFFF, 0xFFFF, "Weitek(0x100E)"},
{0x100E, 0x9000, 0xFFFF, 0xFFFF, "P9000 Viper(0x9000)"},
{0x100E, 0x9001, 0xFFFF, 0xFFFF, "P9000 Viper(0x9001)"},
{0x100E, 0x9002, 0xFFFF, 0xFFFF, "P9000 Viper(0x9002)"},
{0x100E, 0x9100, 0xFFFF, 0xFFFF, "P9100 Viper Pro/SE(0x9100)"},
}; /* pci_vid_100E[] */

static pci_id_t const pci_vid_1010[] = {
{0x1010, 0xFFFF, 0xFFFF, 0xFFFF, "Video Logic, Ltd.(0x1010)"},
}; /* pci_vid_1010[] */

static pci_id_t const pci_vid_1011[] = {
{0x1011, 0xFFFF, 0xFFFF, 0xFFFF, "Digital Equipment Corporation(0x1011)"},
{0x1011, 0x0001, 0xFFFF, 0xFFFF, "DECchip 21050(0x0001)"},
{0x1011, 0x0002, 0xFFFF, 0xFFFF, "DECchip 21040 [Tulip](0x0002)"},
{0x1011, 0x0004, 0xFFFF, 0xFFFF, "DECchip 21030 [TGA](0x0004)"},
{0x1011, 0x0007, 0xFFFF, 0xFFFF, "NVRAM [Zephyr NVRAM](0x0007)"},
{0x1011, 0x0008, 0xFFFF, 0xFFFF, "KZPSA [KZPSA](0x0008)"},
{0x1011, 0x0009, 0xFFFF, 0xFFFF, "DECchip 21140 [FasterNet](0x0009)"},
{0x1011, 0x0009, 0x1025, 0x0310, "21140 Fast Ethernet(0x1025-0x0310)"},
{0x1011, 0x0009, 0x10B8, 0x2001, "SMC9332BDT EtherPower 10/100(0x10B8-0x2001)"},
{0x1011, 0x0009, 0x10B8, 0x2002, "SMC9332BVT EtherPower T4 10/100(0x10B8-0x2002)"},
{0x1011, 0x0009, 0x10B8, 0x2003, "SMC9334BDT EtherPower 10/100 (1-port)(0x10B8-0x2003)"},
{0x1011, 0x0009, 0x1109, 0x2400, "ANA-6944A/TX Fast Ethernet(0x1109-0x2400)"},
{0x1011, 0x0009, 0x1112, 0x2300, "RNS2300 Fast Ethernet(0x1112-0x2300)"},
{0x1011, 0x0009, 0x1112, 0x2320, "RNS2320 Fast Ethernet(0x1112-0x2320)"},
{0x1011, 0x0009, 0x1112, 0x2340, "RNS2340 Fast Ethernet(0x1112-0x2340)"},
{0x1011, 0x0009, 0x1113, 0x1207, "EN-1207-TX Fast Ethernet(0x1113-0x1207)"},
{0x1011, 0x0009, 0x1186, 0x1100, "DFE-500TX Fast Ethernet(0x1186-0x1100)"},
{0x1011, 0x0009, 0x1186, 0x1112, "DFE-570TX Fast Ethernet(0x1186-0x1112)"},
{0x1011, 0x0009, 0x1186, 0x1140, "DFE-660 Cardbus Ethernet 10/100(0x1186-0x1140)"},
{0x1011, 0x0009, 0x1186, 0x1142, "DFE-660 Cardbus Ethernet 10/100(0x1186-0x1142)"},
{0x1011, 0x0009, 0x11F6, 0x0503, "Freedomline Fast Ethernet(0x11F6-0x0503)"},
{0x1011, 0x0009, 0x1282, 0x9100, "AEF-380TXD Fast Ethernet(0x1282-0x9100)"},
{0x1011, 0x0009, 0x1385, 0x1100, "FA310TX Fast Ethernet(0x1385-0x1100)"},
{0x1011, 0x0009, 0x2646, 0x0001, "KNE100TX Fast Ethernet(0x2646-0x0001)"},
{0x1011, 0x000A, 0xFFFF, 0xFFFF, "21230 Video Codec(0x000A)"},
{0x1011, 0x000D, 0xFFFF, 0xFFFF, "PBXGB [TGA2](0x000D)"},
{0x1011, 0x000F, 0xFFFF, 0xFFFF, "PCI-to-PDQ Interface Chip [PFI] FDDI (DEFPA)(0x000F)"},
{0x1011, 0x000F, 0x1011, 0xDEF1, "FDDIcontroller/PCI (DEFPA)(0x1011-0xDEF1)"},
{0x1011, 0x000F, 0x103C, 0xDEF1, "FDDIcontroller/PCI (3X-DEFPA)(0x103C-0xDEF1)"},
{0x1011, 0x0014, 0xFFFF, 0xFFFF, "DECchip 21041 [Tulip Pass 3](0x0014)"},
{0x1011, 0x0014, 0x1186, 0x0100, "DE-530+(0x1186-0x0100)"},
{0x1011, 0x0016, 0xFFFF, 0xFFFF, "ATMworks 350 Adapter [OPPO] (DGLPB)(0x0016)"},
{0x1011, 0x0017, 0xFFFF, 0xFFFF, "PV-PCI Graphics Controller (ZLXp-L)(0x0017)"},
{0x1011, 0x0018, 0xFFFF, 0xFFFF, "Memory Channel interface(0x0018)"},
{0x1011, 0x0019, 0xFFFF, 0xFFFF, "DECchip 21142/43(0x0019)"},
{0x1011, 0x0019, 0x1011, 0x500A, "DE500A Fast Ethernet(0x1011-0x500A)"},
{0x1011, 0x0019, 0x1011, 0x500B, "DE500B Fast Ethernet(0x1011-0x500B)"},
{0x1011, 0x0019, 0x1014, 0x0001, "10/100 EtherJet Cardbus(0x1014-0x0001)"},
{0x1011, 0x0019, 0x1025, 0x0315, "ALN315 Fast Ethernet(0x1025-0x0315)"},
{0x1011, 0x0019, 0x1033, 0x800C, "PC-9821-CS01 100BASE-TX Interface Card(0x1033-0x800C)"},
{0x1011, 0x0019, 0x1033, 0x800D, "PC-9821NR-B06 100BASE-TX Interface Card(0x1033-0x800D)"},
{0x1011, 0x0019, 0x103C, 0x125A, "10/100Base-TX (PCI) [A5506B](0x103C-0x125A)"},
{0x1011, 0x0019, 0x108D, 0x0016, "Rapidfire 2327 10/100 Ethernet(0x108D-0x0016)"},
{0x1011, 0x0019, 0x108D, 0x0017, "GoCard 2250 Ethernet 10/100 Cardbus(0x108D-0x0017)"},
{0x1011, 0x0019, 0x10B8, 0x2005, "SMC8032DT Extreme Ethernet 10/100(0x10B8-0x2005)"},
{0x1011, 0x0019, 0x10B8, 0x8034, "SMC8034 Extreme Ethernet 10/100(0x10B8-0x8034)"},
{0x1011, 0x0019, 0x10EF, 0x8169, "Cardbus Fast Ethernet(0x10EF-0x8169)"},
{0x1011, 0x0019, 0x1109, 0x2A00, "ANA-6911A/TX Fast Ethernet(0x1109-0x2A00)"},
{0x1011, 0x0019, 0x1109, 0x2B00, "ANA-6911A/TXC Fast Ethernet(0x1109-0x2B00)"},
{0x1011, 0x0019, 0x1109, 0x3000, "ANA-6922/TX Fast Ethernet(0x1109-0x3000)"},
{0x1011, 0x0019, 0x1113, 0x1207, "Cheetah Fast Ethernet(0x1113-0x1207)"},
{0x1011, 0x0019, 0x1113, 0x2220, "Cardbus Fast Ethernet(0x1113-0x2220)"},
{0x1011, 0x0019, 0x115D, 0x0002, "Cardbus Ethernet 10/100(0x115D-0x0002)"},
{0x1011, 0x0019, 0x1179, 0x0203, "Fast Ethernet(0x1179-0x0203)"},
{0x1011, 0x0019, 0x1179, 0x0204, "Cardbus Fast Ethernet(0x1179-0x0204)"},
{0x1011, 0x0019, 0x1186, 0x1100, "DFE-500TX Fast Ethernet(0x1186-0x1100)"},
{0x1011, 0x0019, 0x1186, 0x1101, "DFE-500TX Fast Ethernet(0x1186-0x1101)"},
{0x1011, 0x0019, 0x1186, 0x1102, "DFE-500TX Fast Ethernet(0x1186-0x1102)"},
{0x1011, 0x0019, 0x1186, 0x1112, "DFE-570TX Quad Fast Ethernet(0x1186-0x1112)"},
{0x1011, 0x0019, 0x11F0, 0x4235, "21143 [FASTLine-II UTP 10/100](0x11F0-0x4235)"},
{0x1011, 0x0019, 0x1259, 0x2800, "AT-2800Tx Fast Ethernet(0x1259-0x2800)"},
{0x1011, 0x0019, 0x1266, 0x0004, "Eagle Fast EtherMAX(0x1266-0x0004)"},
{0x1011, 0x0019, 0x12AF, 0x0019, "NetFlyer Cardbus Fast Ethernet(0x12AF-0x0019)"},
{0x1011, 0x0019, 0x1374, 0x0001, "Cardbus Ethernet Card 10/100(0x1374-0x0001)"},
{0x1011, 0x0019, 0x1374, 0x0002, "Cardbus Ethernet Card 10/100(0x1374-0x0002)"},
{0x1011, 0x0019, 0x1374, 0x0007, "Cardbus Ethernet Card 10/100(0x1374-0x0007)"},
{0x1011, 0x0019, 0x1374, 0x0008, "Cardbus Ethernet Card 10/100(0x1374-0x0008)"},
{0x1011, 0x0019, 0x1385, 0x2100, "FA510(0x1385-0x2100)"},
{0x1011, 0x0019, 0x1395, 0x0001, "10/100 Ethernet CardBus PC Card(0x1395-0x0001)"},
{0x1011, 0x0019, 0x13D1, 0xAB01, "EtherFast 10/100 Cardbus (PCMPC200)(0x13D1-0xAB01)"},
{0x1011, 0x0019, 0x1498, 0x000A, "TPMC880-10 10/100Base-T and 10Base2 PMC Ethernet Adapter(0x1498-0x000A)"},
{0x1011, 0x0019, 0x1498, 0x000B, "TPMC880-11 Single 10/100Base-T PMC Ethernet Adapter(0x1498-0x000B)"},
{0x1011, 0x0019, 0x1498, 0x000C, "TPMC880-12 Single 10Base2 PMC Ethernet Adapter(0x1498-0x000C)"},
{0x1011, 0x0019, 0x14CB, 0x0100, "LNDL-100N 100Base-TX Ethernet PC Card(0x14CB-0x0100)"},
{0x1011, 0x0019, 0x1668, 0x2000, "FastNet Pro (PE2000)(0x1668-0x2000)"},
{0x1011, 0x0019, 0x2646, 0x0001, "KNE100TX(0x2646-0x0001)"},
{0x1011, 0x0019, 0x2646, 0x0002, "KNE-CB4TX(0x2646-0x0002)"},
{0x1011, 0x0019, 0x8086, 0x0001, "EtherExpress PRO/100 Mobile CardBus 32(0x8086-0x0001)"},
{0x1011, 0x001A, 0xFFFF, 0xFFFF, "Farallon PN9000SX Gigabit Ethernet(0x001A)"},
{0x1011, 0x0021, 0xFFFF, 0xFFFF, "DECchip 21052(0x0021)"},
{0x1011, 0x0022, 0xFFFF, 0xFFFF, "DECchip 21150(0x0022)"},
{0x1011, 0x0023, 0xFFFF, 0xFFFF, "DECchip 21150(0x0023)"},
{0x1011, 0x0024, 0xFFFF, 0xFFFF, "DECchip 21152(0x0024)"},
{0x1011, 0x0025, 0xFFFF, 0xFFFF, "DECchip 21153(0x0025)"},
{0x1011, 0x0026, 0xFFFF, 0xFFFF, "DECchip 21154(0x0026)"},
{0x1011, 0x0034, 0xFFFF, 0xFFFF, "56k Modem Cardbus(0x0034)"},
{0x1011, 0x0034, 0x1374, 0x0003, "56k Modem Cardbus(0x1374-0x0003)"},
{0x1011, 0x0045, 0xFFFF, 0xFFFF, "DECchip 21553(0x0045)"},
{0x1011, 0x0046, 0xFFFF, 0xFFFF, "DECchip 21554(0x0046)"},
{0x1011, 0x0046, 0x0E11, 0x4050, "Smart Array 4200 Controller(0x0E11-0x4050)"},
{0x1011, 0x0046, 0x0E11, 0x4051, "Smart Array 4250ES Controller(0x0E11-0x4051)"},
{0x1011, 0x0046, 0x0E11, 0x4058, "Smart Array 431 Controller(0x0E11-0x4058)"},
{0x1011, 0x0046, 0x103C, 0x10C2, "NetRAID-4M(0x103C-0x10C2)"},
{0x1011, 0x0046, 0x12D9, 0x000A, "IP Telephony card(0x12D9-0x000A)"},
{0x1011, 0x0046, 0x4C53, 0x1050, "CT7 mainboard(0x4C53-0x1050)"},
{0x1011, 0x0046, 0x4C53, 0x1051, "CE7 mainboard(0x4C53-0x1051)"},
{0x1011, 0x0046, 0x9005, 0x0364, "5400S (Mustang)(0x9005-0x0364)"},
{0x1011, 0x0046, 0x9005, 0x0365, "5400S (Mustang)(0x9005-0x0365)"},
{0x1011, 0x0046, 0x9005, 0x1364, "Dell PowerEdge RAID Controller 2(0x9005-0x1364)"},
{0x1011, 0x0046, 0x9005, 0x1365, "Dell PowerEdge RAID Controller 2(0x9005-0x1365)"},
{0x1011, 0x0046, 0xE4BF, 0x1000, "CC8-1-BLUES(0xE4BF-0x1000)"},
{0x1011, 0x1065, 0xFFFF, 0xFFFF, "StrongARM DC21285(0x1065)"},
{0x1011, 0x1065, 0x1069, 0x0020, "DAC960P / DAC1164P(0x1069-0x0020)"},
}; /* pci_vid_1011[] */

static pci_id_t const pci_vid_1012[] = {
{0x1012, 0xFFFF, 0xFFFF, 0xFFFF, "Micronics Computers Inc(0x1012)"},
}; /* pci_vid_1012[] */

static pci_id_t const pci_vid_1013[] = {
{0x1013, 0xFFFF, 0xFFFF, 0xFFFF, "Cirrus Logic(0x1013)"},
{0x1013, 0x0038, 0xFFFF, 0xFFFF, "GD 7548(0x0038)"},
{0x1013, 0x0040, 0xFFFF, 0xFFFF, "GD 7555 Flat Panel GUI Accelerator(0x0040)"},
{0x1013, 0x004C, 0xFFFF, 0xFFFF, "GD 7556 Video/Graphics LCD/CRT Ctrlr(0x004C)"},
{0x1013, 0x00A0, 0xFFFF, 0xFFFF, "GD 5430/40 [Alpine](0x00A0)"},
{0x1013, 0x00A2, 0xFFFF, 0xFFFF, "GD 5432 [Alpine](0x00A2)"},
{0x1013, 0x00A4, 0xFFFF, 0xFFFF, "GD 5434-4 [Alpine](0x00A4)"},
{0x1013, 0x00A8, 0xFFFF, 0xFFFF, "GD 5434-8 [Alpine](0x00A8)"},
{0x1013, 0x00AC, 0xFFFF, 0xFFFF, "GD 5436 [Alpine](0x00AC)"},
{0x1013, 0x00B0, 0xFFFF, 0xFFFF, "GD 5440(0x00B0)"},
{0x1013, 0x00B8, 0xFFFF, 0xFFFF, "GD 5446(0x00B8)"},
{0x1013, 0x00B8, 0x1AF4, 0x1100, "QEMU Virtual Machine(0x1AF4-0x1100)"},
{0x1013, 0x00BC, 0xFFFF, 0xFFFF, "GD 5480(0x00BC)"},
{0x1013, 0x00BC, 0x1013, 0x00BC, "CL-GD5480(0x1013-0x00BC)"},
{0x1013, 0x00D0, 0xFFFF, 0xFFFF, "GD 5462(0x00D0)"},
{0x1013, 0x00D2, 0xFFFF, 0xFFFF, "GD 5462 [Laguna I](0x00D2)"},
{0x1013, 0x00D4, 0xFFFF, 0xFFFF, "GD 5464 [Laguna](0x00D4)"},
{0x1013, 0x00D5, 0xFFFF, 0xFFFF, "GD 5464 BD [Laguna](0x00D5)"},
{0x1013, 0x00D6, 0xFFFF, 0xFFFF, "GD 5465 [Laguna](0x00D6)"},
{0x1013, 0x00D6, 0x13CE, 0x8031, "Barco Metheus 2 Megapixel, Dual Head(0x13CE-0x8031)"},
{0x1013, 0x00D6, 0x13CF, 0x8031, "Barco Metheus 2 Megapixel, Dual Head(0x13CF-0x8031)"},
{0x1013, 0x00E8, 0xFFFF, 0xFFFF, "GD 5436U(0x00E8)"},
{0x1013, 0x1100, 0xFFFF, 0xFFFF, "CL 6729(0x1100)"},
{0x1013, 0x1110, 0xFFFF, 0xFFFF, "PD 6832 PCMCIA/CardBus Ctrlr(0x1110)"},
{0x1013, 0x1112, 0xFFFF, 0xFFFF, "PD 6834 PCMCIA/CardBus Ctrlr(0x1112)"},
{0x1013, 0x1113, 0xFFFF, 0xFFFF, "PD 6833 PCMCIA/CardBus Ctrlr(0x1113)"},
{0x1013, 0x1200, 0xFFFF, 0xFFFF, "GD 7542 [Nordic](0x1200)"},
{0x1013, 0x1202, 0xFFFF, 0xFFFF, "GD 7543 [Viking](0x1202)"},
{0x1013, 0x1204, 0xFFFF, 0xFFFF, "GD 7541 [Nordic Light](0x1204)"},
{0x1013, 0x4000, 0xFFFF, 0xFFFF, "MD 5620 [CLM Data Fax Voice](0x4000)"},
{0x1013, 0x4400, 0xFFFF, 0xFFFF, "CD 4400(0x4400)"},
{0x1013, 0x6001, 0xFFFF, 0xFFFF, "CS 4610/11 [CrystalClear SoundFusion Audio Accelerator](0x6001)"},
{0x1013, 0x6001, 0x1014, 0x1010, "CS4610 SoundFusion Audio Accelerator(0x1014-0x1010)"},
{0x1013, 0x6003, 0xFFFF, 0xFFFF, "CS 4614/22/24/30 [CrystalClear SoundFusion Audio Accelerator](0x6003)"},
{0x1013, 0x6003, 0x1013, 0x4280, "Crystal SoundFusion PCI Audio Accelerator(0x1013-0x4280)"},
{0x1013, 0x6003, 0x1014, 0x0153, "ThinkPad 600X/A20m(0x1014-0x0153)"},
{0x1013, 0x6003, 0x153B, 0x112E, "DMX XFire 1024(0x153B-0x112E)"},
{0x1013, 0x6003, 0x153B, 0x1136, "SiXPack 5.1+(0x153B-0x1136)"},
{0x1013, 0x6003, 0x1681, 0x0050, "Game Theater XP(0x1681-0x0050)"},
{0x1013, 0x6003, 0x1681, 0xA010, "Gamesurround Fortissimo II(0x1681-0xA010)"},
{0x1013, 0x6003, 0x1681, 0xA011, "Gamesurround Fortissimo III 7.1(0x1681-0xA011)"},
{0x1013, 0x6003, 0x5053, 0x3357, "Santa Cruz(0x5053-0x3357)"},
{0x1013, 0x6004, 0xFFFF, 0xFFFF, "CS 4614/22/24 [CrystalClear SoundFusion Audio Accelerator](0x6004)"},
{0x1013, 0x6005, 0xFFFF, 0xFFFF, "Crystal CS4281 PCI Audio(0x6005)"},
{0x1013, 0x6005, 0x1013, 0x4281, "Crystal CS4281 PCI Audio(0x1013-0x4281)"},
{0x1013, 0x6005, 0x10CF, 0x10A8, "Crystal CS4281 PCI Audio(0x10CF-0x10A8)"},
{0x1013, 0x6005, 0x10CF, 0x10A9, "Crystal CS4281 PCI Audio(0x10CF-0x10A9)"},
{0x1013, 0x6005, 0x10CF, 0x10AA, "Crystal CS4281 PCI Audio(0x10CF-0x10AA)"},
{0x1013, 0x6005, 0x10CF, 0x10AB, "Crystal CS4281 PCI Audio(0x10CF-0x10AB)"},
{0x1013, 0x6005, 0x10CF, 0x10AC, "Crystal CS4281 PCI Audio(0x10CF-0x10AC)"},
{0x1013, 0x6005, 0x10CF, 0x10AD, "Crystal CS4281 PCI Audio(0x10CF-0x10AD)"},
{0x1013, 0x6005, 0x10CF, 0x10B4, "Crystal CS4281 PCI Audio(0x10CF-0x10B4)"},
{0x1013, 0x6005, 0x1179, 0x0001, "Crystal CS4281 PCI Audio(0x1179-0x0001)"},
{0x1013, 0x6005, 0x14C0, 0x000C, "Crystal CS4281 PCI Audio(0x14C0-0x000C)"},
}; /* pci_vid_1013[] */

static pci_id_t const pci_vid_1014[] = {
{0x1014, 0xFFFF, 0xFFFF, 0xFFFF, "IBM(0x1014)"},
{0x1014, 0x0002, 0xFFFF, 0xFFFF, "PCI to MCA Bridge(0x0002)"},
{0x1014, 0x0005, 0xFFFF, 0xFFFF, "Processor to I/O Controller [Alta Lite](0x0005)"},
{0x1014, 0x0007, 0xFFFF, 0xFFFF, "Processor to I/O Controller [Alta MP](0x0007)"},
{0x1014, 0x000A, 0xFFFF, 0xFFFF, "PCI to ISA Bridge (IBM27-82376) [Fire Coral](0x000A)"},
{0x1014, 0x0017, 0xFFFF, 0xFFFF, "CPU to PCI Bridge(0x0017)"},
{0x1014, 0x0018, 0xFFFF, 0xFFFF, "TR Auto LANstreamer(0x0018)"},
{0x1014, 0x001B, 0xFFFF, 0xFFFF, "GXT-150P(0x001B)"},
{0x1014, 0x001C, 0xFFFF, 0xFFFF, "Carrera(0x001C)"},
{0x1014, 0x001D, 0xFFFF, 0xFFFF, "SCSI-2 FAST PCI Adapter (82G2675)(0x001D)"},
{0x1014, 0x0020, 0xFFFF, 0xFFFF, "GXT1000 Graphics Adapter(0x0020)"},
{0x1014, 0x0022, 0xFFFF, 0xFFFF, "PCI to PCI Bridge (IBM27-82351)(0x0022)"},
{0x1014, 0x002D, 0xFFFF, 0xFFFF, "Processor to I/O Controller [Python](0x002D)"},
{0x1014, 0x002E, 0xFFFF, 0xFFFF, "SCSI RAID Adapter [ServeRAID](0x002E)"},
{0x1014, 0x002E, 0x1014, 0x002E, "ServeRAID-3x(0x1014-0x002E)"},
{0x1014, 0x002E, 0x1014, 0x022E, "ServeRAID-4H(0x1014-0x022E)"},
{0x1014, 0x0031, 0xFFFF, 0xFFFF, "2 Port Serial Adapter(0x0031)"},
{0x1014, 0x0031, 0x1014, 0x0031, "2721 WAN IOA - 2 Port Sync Serial Adapter(0x1014-0x0031)"},
{0x1014, 0x0036, 0xFFFF, 0xFFFF, "PCI to 32-bit LocalBus Bridge [Miami](0x0036)"},
{0x1014, 0x0037, 0xFFFF, 0xFFFF, "PowerPC to PCI Bridge (IBM27-82660)(0x0037)"},
{0x1014, 0x003A, 0xFFFF, 0xFFFF, "CPU to PCI Bridge(0x003A)"},
{0x1014, 0x003C, 0xFFFF, 0xFFFF, "GXT250P/GXT255P Graphics Adapter(0x003C)"},
{0x1014, 0x003E, 0xFFFF, 0xFFFF, "16/4 Token ring UTP/STP controller(0x003E)"},
{0x1014, 0x003E, 0x1014, 0x003E, "Token-Ring Adapter(0x1014-0x003E)"},
{0x1014, 0x003E, 0x1014, 0x00CD, "Token-Ring Adapter + Wake-On-LAN(0x1014-0x00CD)"},
{0x1014, 0x003E, 0x1014, 0x00CE, "16/4 Token-Ring Adapter 2(0x1014-0x00CE)"},
{0x1014, 0x003E, 0x1014, 0x00CF, "16/4 Token-Ring Adapter Special(0x1014-0x00CF)"},
{0x1014, 0x003E, 0x1014, 0x00E4, "High-Speed 100/16/4 Token-Ring Adapter(0x1014-0x00E4)"},
{0x1014, 0x003E, 0x1014, 0x00E5, "16/4 Token-Ring Adapter 2 + Wake-On-LAN(0x1014-0x00E5)"},
{0x1014, 0x003E, 0x1014, 0x016D, "iSeries 2744 Card(0x1014-0x016D)"},
{0x1014, 0x0045, 0xFFFF, 0xFFFF, "SSA Adapter(0x0045)"},
{0x1014, 0x0046, 0xFFFF, 0xFFFF, "MPIC interrupt controller(0x0046)"},
{0x1014, 0x0047, 0xFFFF, 0xFFFF, "PCI to PCI Bridge(0x0047)"},
{0x1014, 0x0048, 0xFFFF, 0xFFFF, "PCI to PCI Bridge(0x0048)"},
{0x1014, 0x0049, 0xFFFF, 0xFFFF, "Warhead SCSI Controller(0x0049)"},
{0x1014, 0x004E, 0xFFFF, 0xFFFF, "ATM Controller (14104e00)(0x004E)"},
{0x1014, 0x004F, 0xFFFF, 0xFFFF, "ATM Controller (14104f00)(0x004F)"},
{0x1014, 0x0050, 0xFFFF, 0xFFFF, "ATM Controller (14105000)(0x0050)"},
{0x1014, 0x0053, 0xFFFF, 0xFFFF, "25 MBit ATM Controller(0x0053)"},
{0x1014, 0x0054, 0xFFFF, 0xFFFF, "GXT500P/GXT550P Graphics Adapter(0x0054)"},
{0x1014, 0x0057, 0xFFFF, 0xFFFF, "MPEG PCI Bridge(0x0057)"},
{0x1014, 0x0058, 0xFFFF, 0xFFFF, "SSA Adapter [Advanced SerialRAID/X](0x0058)"},
{0x1014, 0x005E, 0xFFFF, 0xFFFF, "GXT800P Graphics Adapter(0x005E)"},
{0x1014, 0x007C, 0xFFFF, 0xFFFF, "ATM Controller (14107c00)(0x007C)"},
{0x1014, 0x007D, 0xFFFF, 0xFFFF, "3780IDSP [MWave](0x007D)"},
{0x1014, 0x008B, 0xFFFF, 0xFFFF, "EADS PCI to PCI Bridge(0x008B)"},
{0x1014, 0x008E, 0xFFFF, 0xFFFF, "GXT3000P Graphics Adapter(0x008E)"},
{0x1014, 0x0090, 0xFFFF, 0xFFFF, "GXT 3000P(0x0090)"},
{0x1014, 0x0090, 0x1014, 0x008E, "GXT-3000P(0x1014-0x008E)"},
{0x1014, 0x0091, 0xFFFF, 0xFFFF, "SSA Adapter(0x0091)"},
{0x1014, 0x0095, 0xFFFF, 0xFFFF, "20H2999 PCI Docking Bridge(0x0095)"},
{0x1014, 0x0096, 0xFFFF, 0xFFFF, "Chukar chipset SCSI controller(0x0096)"},
{0x1014, 0x0096, 0x1014, 0x0097, "iSeries 2778 DASD IOA(0x1014-0x0097)"},
{0x1014, 0x0096, 0x1014, 0x0098, "iSeries 2763 DASD IOA(0x1014-0x0098)"},
{0x1014, 0x0096, 0x1014, 0x0099, "iSeries 2748 DASD IOA(0x1014-0x0099)"},
{0x1014, 0x009F, 0xFFFF, 0xFFFF, "PCI 4758 Cryptographic Accelerator(0x009F)"},
{0x1014, 0x00A5, 0xFFFF, 0xFFFF, "ATM Controller (1410a500)(0x00A5)"},
{0x1014, 0x00A6, 0xFFFF, 0xFFFF, "ATM 155MBPS MM Controller (1410a600)(0x00A6)"},
{0x1014, 0x00B7, 0xFFFF, 0xFFFF, "GXT2000P Graphics Adapter(0x00B7)"},
{0x1014, 0x00B7, 0x1092, 0x00B8, "FireGL1 AGP 32Mb(0x1092-0x00B8)"},
{0x1014, 0x00B8, 0xFFFF, 0xFFFF, "GXT2000P Graphics Adapter(0x00B8)"},
{0x1014, 0x00BE, 0xFFFF, 0xFFFF, "ATM 622MBPS Controller (1410be00)(0x00BE)"},
{0x1014, 0x00DC, 0xFFFF, 0xFFFF, "Advanced Systems Management Adapter (ASMA)(0x00DC)"},
{0x1014, 0x00FC, 0xFFFF, 0xFFFF, "CPC710 Dual Bridge and Memory Controller (PCI-64)(0x00FC)"},
{0x1014, 0x0105, 0xFFFF, 0xFFFF, "CPC710 Dual Bridge and Memory Controller (PCI-32)(0x0105)"},
{0x1014, 0x010F, 0xFFFF, 0xFFFF, "Remote Supervisor Adapter (RSA)(0x010F)"},
{0x1014, 0x0142, 0xFFFF, 0xFFFF, "Yotta Video Compositor Input(0x0142)"},
{0x1014, 0x0142, 0x1014, 0x0143, "Yotta Input Controller (ytin)(0x1014-0x0143)"},
{0x1014, 0x0144, 0xFFFF, 0xFFFF, "Yotta Video Compositor Output(0x0144)"},
{0x1014, 0x0144, 0x1014, 0x0145, "Yotta Output Controller (ytout)(0x1014-0x0145)"},
{0x1014, 0x0156, 0xFFFF, 0xFFFF, "405GP PLB to PCI Bridge(0x0156)"},
{0x1014, 0x015E, 0xFFFF, 0xFFFF, "622Mbps ATM PCI Adapter(0x015E)"},
{0x1014, 0x0160, 0xFFFF, 0xFFFF, "64bit/66MHz PCI ATM 155 MMF(0x0160)"},
{0x1014, 0x016E, 0xFFFF, 0xFFFF, "GXT4000P Graphics Adapter(0x016E)"},
{0x1014, 0x0170, 0xFFFF, 0xFFFF, "GXT6000P Graphics Adapter(0x0170)"},
{0x1014, 0x0170, 0x1092, 0x0172, "Fire GL2(0x1092-0x0172)"},
{0x1014, 0x0170, 0x1092, 0x0173, "Fire GL3(0x1092-0x0173)"},
{0x1014, 0x0170, 0x1092, 0x0174, "Fire GL4(0x1092-0x0174)"},
{0x1014, 0x0170, 0x1092, 0x0184, "Fire GL4s(0x1092-0x0184)"},
{0x1014, 0x017D, 0xFFFF, 0xFFFF, "GXT300P Graphics Adapter(0x017D)"},
{0x1014, 0x0180, 0xFFFF, 0xFFFF, "Snipe chipset SCSI controller(0x0180)"},
{0x1014, 0x0180, 0x1014, 0x0241, "iSeries 2757 DASD IOA(0x1014-0x0241)"},
{0x1014, 0x0180, 0x1014, 0x0264, "Quad Channel PCI-X U320 SCSI RAID Adapter (2780)(0x1014-0x0264)"},
{0x1014, 0x0188, 0xFFFF, 0xFFFF, "EADS-X PCI-X to PCI-X Bridge(0x0188)"},
{0x1014, 0x01A7, 0xFFFF, 0xFFFF, "PCI-X to PCI-X Bridge(0x01A7)"},
{0x1014, 0x01BD, 0xFFFF, 0xFFFF, "ServeRAID Controller(0x01BD)"},
{0x1014, 0x01BD, 0x1014, 0x01BD, "ServeRAID 4Lx(0x1014-0x01BD)"},
{0x1014, 0x01BD, 0x1014, 0x01BE, "ServeRAID-4M(0x1014-0x01BE)"},
{0x1014, 0x01BD, 0x1014, 0x01BF, "ServeRAID-4L(0x1014-0x01BF)"},
{0x1014, 0x01BD, 0x1014, 0x0208, "ServeRAID-4Mx(0x1014-0x0208)"},
{0x1014, 0x01BD, 0x1014, 0x020E, "ServeRAID-4Lx(0x1014-0x020E)"},
{0x1014, 0x01BD, 0x1014, 0x022E, "ServeRAID-4H(0x1014-0x022E)"},
{0x1014, 0x01BD, 0x1014, 0x0258, "ServeRAID-5i(0x1014-0x0258)"},
{0x1014, 0x01BD, 0x1014, 0x0259, "ServeRAID-5i(0x1014-0x0259)"},
{0x1014, 0x01C1, 0xFFFF, 0xFFFF, "64bit/66MHz PCI ATM 155 UTP(0x01C1)"},
{0x1014, 0x01E6, 0xFFFF, 0xFFFF, "Cryptographic Accelerator(0x01E6)"},
{0x1014, 0x01EF, 0xFFFF, 0xFFFF, "PowerPC 440GP PCI Bridge(0x01EF)"},
{0x1014, 0x01EF, 0x1734, 0x102B, "PCEAS PCI-X Dual Port ESCON Adapter(0x1734-0x102B)"},
{0x1014, 0x01EF, 0x1734, 0x10F8, "PCEAT PCI-Express Dual Port ESCON Adapter(0x1734-0x10F8)"},
{0x1014, 0x01FF, 0xFFFF, 0xFFFF, "10/100 Mbps Ethernet(0x01FF)"},
{0x1014, 0x0219, 0xFFFF, 0xFFFF, "Multiport Serial Adapter(0x0219)"},
{0x1014, 0x0219, 0x1014, 0x021A, "Dual RVX(0x1014-0x021A)"},
{0x1014, 0x0219, 0x1014, 0x0251, "Internal Modem/RVX(0x1014-0x0251)"},
{0x1014, 0x0219, 0x1014, 0x0252, "Quad Internal Modem(0x1014-0x0252)"},
{0x1014, 0x021B, 0xFFFF, 0xFFFF, "GXT6500P Graphics Adapter(0x021B)"},
{0x1014, 0x021C, 0xFFFF, 0xFFFF, "GXT4500P Graphics Adapter(0x021C)"},
{0x1014, 0x0233, 0xFFFF, 0xFFFF, "GXT135P Graphics Adapter(0x0233)"},
{0x1014, 0x025A, 0xFFFF, 0xFFFF, "Drone card(0x025A)"},
{0x1014, 0x028C, 0xFFFF, 0xFFFF, "Citrine chipset SCSI controller(0x028C)"},
{0x1014, 0x028C, 0x1014, 0x028D, "Dual Channel PCI-X DDR SAS RAID Adapter (572E)(0x1014-0x028D)"},
{0x1014, 0x028C, 0x1014, 0x02BE, "Dual Channel PCI-X DDR U320 SCSI RAID Adapter (571B)(0x1014-0x02BE)"},
{0x1014, 0x028C, 0x1014, 0x02C0, "Dual Channel PCI-X DDR U320 SCSI Adapter (571A)(0x1014-0x02C0)"},
{0x1014, 0x028C, 0x1014, 0x030D, "PCI-X DDR Auxiliary Cache Adapter (575B)(0x1014-0x030D)"},
{0x1014, 0x02A1, 0xFFFF, 0xFFFF, "Calgary PCI-X Host Bridge(0x02A1)"},
{0x1014, 0x02BD, 0xFFFF, 0xFFFF, "Obsidian chipset SCSI controller(0x02BD)"},
{0x1014, 0x02BD, 0x1014, 0x02C1, "PCI-X DDR 3Gb SAS Adapter (572A/572C)(0x1014-0x02C1)"},
{0x1014, 0x02BD, 0x1014, 0x02C2, "PCI-X DDR 3Gb SAS RAID Adapter (572B/571D)(0x1014-0x02C2)"},
{0x1014, 0x02BD, 0x1014, 0x0338, "PCI-X DDR Auxiliary Cache Adapter (575C)(0x1014-0x0338)"},
{0x1014, 0x0302, 0xFFFF, 0xFFFF, "Winnipeg PCI-X Host Bridge(0x0302)"},
{0x1014, 0x0308, 0xFFFF, 0xFFFF, "CalIOC2 PCI-E Root Port(0x0308)"},
{0x1014, 0x0311, 0xFFFF, 0xFFFF, "FC 5740/1954 4-Port 10/100/1000 Base-TX PCI-X Adapter for POWER(0x0311)"},
{0x1014, 0x0314, 0xFFFF, 0xFFFF, "ZISC 036 Neural accelerator card(0x0314)"},
{0x1014, 0x032D, 0xFFFF, 0xFFFF, "Axon - Cell Companion Chip(0x032D)"},
{0x1014, 0x032D, 0x1014, 0x03A1, "PCIe PowerXCell 8i Cell Accelerator Board(0x1014-0x03A1)"},
{0x1014, 0x0339, 0xFFFF, 0xFFFF, "Obsidian-E PCI-E SCSI controller(0x0339)"},
{0x1014, 0x0339, 0x1014, 0x030A, "PCIe 3Gb SAS RAID Adapter (574E)(0x1014-0x030A)"},
{0x1014, 0x0339, 0x1014, 0x033A, "PCIe 3Gb SAS Adapter (57B3)(0x1014-0x033A)"},
{0x1014, 0x0339, 0x1014, 0x035C, "PCIe x8 Internal 3Gb SAS adapter (57CC)(0x1014-0x035C)"},
{0x1014, 0x0339, 0x1014, 0x0360, "PCI-E Auxiliary Cache Adapter (57B7)(0x1014-0x0360)"},
{0x1014, 0x033D, 0xFFFF, 0xFFFF, "PCI-E IPR SAS Adapter (FPGA)(0x033D)"},
{0x1014, 0x033D, 0x1014, 0x033C, "PCIe2 1.8GB Cache 6Gb SAS RAID Adapter Tri-port (57B5)(0x1014-0x033C)"},
{0x1014, 0x033D, 0x1014, 0x0353, "PCIe2 3.1GB Cache 6Gb SAS RAID Enclosure (57C3)(0x1014-0x0353)"},
{0x1014, 0x033D, 0x1014, 0x0354, "PCIe2 6Gb SAS Adapter Dual-port (57C4)(0x1014-0x0354)"},
{0x1014, 0x033D, 0x1014, 0x0356, "PCIe2 1.8GB Cache 6Gb SAS RAID & SSD Adapter (574D)(0x1014-0x0356)"},
{0x1014, 0x033D, 0x1014, 0x035F, "PCIe2 6Gb SAS Adapter Quad-port (57B2)(0x1014-0x035F)"},
{0x1014, 0x034A, 0xFFFF, 0xFFFF, "PCI-E IPR SAS Adapter (ASIC)(0x034A)"},
{0x1014, 0x034A, 0x1014, 0x033B, "PCIe2 6Gb SAS RAID Adapter Quad-port (57B4)(0x1014-0x033B)"},
{0x1014, 0x034A, 0x1014, 0x0355, "PCIe2 3.6GB Cache 6Gb SAS RAID Adapter Quad-port (57B1)(0x1014-0x0355)"},
{0x1014, 0x034A, 0x1014, 0x0357, "PCIe2 6Gb SAS Adapter Quad-port (57C6)(0x1014-0x0357)"},
{0x1014, 0x034A, 0x1014, 0x035D, "PCIe3 1.8GB Cache RAID SAS Adapter Quad-port 6GB (57C8)(0x1014-0x035D)"},
{0x1014, 0x034A, 0x1014, 0x035E, "PCIe2 3.6GB Cache 6Gb SAS RAID Adapter Quad-port (57CE)(0x1014-0x035E)"},
{0x1014, 0x034A, 0x1014, 0x03FB, "PCIe3 28GB Cache RAID SAS Enclosure 6Gb x 16 (57D5)(0x1014-0x03FB)"},
{0x1014, 0x034A, 0x1014, 0x03FE, "PCIe3 x8 Cache SAS RAID Internal Adapter 6Gb (57D8)(0x1014-0x03FE)"},
{0x1014, 0x034A, 0x1014, 0x03FF, "PCIe3 x8 SAS RAID Internal Adapter 6Gb (57D7)(0x1014-0x03FF)"},
{0x1014, 0x034A, 0x1014, 0x0474, "PCIe3 x16 Cache SAS RAID Internal Adapter 6Gb (57EB)(0x1014-0x0474)"},
{0x1014, 0x034A, 0x1014, 0x0475, "PCIe3 x16 SAS RAID Internal Adapter 6Gb (57EC)(0x1014-0x0475)"},
{0x1014, 0x034A, 0x1014, 0x0499, "PCIe3 x16 Cache SAS RAID Internal Adapter 6Gb (57ED)(0x1014-0x0499)"},
{0x1014, 0x034A, 0x1014, 0x049A, "PCIe3 x16 SAS RAID Internal Adapter 6Gb (57EE)(0x1014-0x049A)"},
{0x1014, 0x034A, 0x1014, 0x04C7, "PCIe3 x 8 Cache SAS RAID Internal Adapter 6GB(2CCA)(0x1014-0x04C7)"},
{0x1014, 0x034A, 0x1014, 0x04C8, "PCIe3 x 8 Cache SAS RAID Internal Adapter 6GB(2CD2)(0x1014-0x04C8)"},
{0x1014, 0x034A, 0x1014, 0x04C9, "PCIe3 x 8 Cache SAS RAID Internal Adapter 6GB(2CCD)(0x1014-0x04C9)"},
{0x1014, 0x03DC, 0xFFFF, 0xFFFF, "POWER8 Host Bridge (PHB3)(0x03DC)"},
{0x1014, 0x044B, 0xFFFF, 0xFFFF, "GenWQE Accelerator Adapter(0x044B)"},
{0x1014, 0x04AA, 0xFFFF, 0xFFFF, "Flash Adapter 90 (PCIe2 0.9TB)(0x04AA)"},
{0x1014, 0x04C1, 0xFFFF, 0xFFFF, "POWER9 Host Bridge (PHB4)(0x04C1)"},
{0x1014, 0x04DA, 0xFFFF, 0xFFFF, "PCI-E IPR SAS+ Adapter (ASIC)(0x04DA)"},
{0x1014, 0x04DA, 0x1014, 0x04FB, "PCIe3 x16 20GB Cache 12Gb Quad SAS RAID+ Adapter(580B)(0x1014-0x04FB)"},
{0x1014, 0x04DA, 0x1014, 0x04FC, "PCIe3 x8 12Gb Quad SAS RAID+ Adapter(580A)(0x1014-0x04FC)"},
{0x1014, 0x04ED, 0xFFFF, 0xFFFF, "Internal Shared Memory (ISM) virtual PCI device(0x04ED)"},
{0x1014, 0x0611, 0xFFFF, 0xFFFF, "4769 Cryptographic Adapter(0x0611)"},
{0x1014, 0x3022, 0xFFFF, 0xFFFF, "QLA3022 Network Adapter(0x3022)"},
{0x1014, 0x4022, 0xFFFF, 0xFFFF, "QLA3022 Network Adapter(0x4022)"},
{0x1014, 0xFFFF, 0xFFFF, 0xFFFF, "MPIC-2 interrupt controller(0xFFFF)"},
}; /* pci_vid_1014[] */

static pci_id_t const pci_vid_1015[] = {
{0x1015, 0xFFFF, 0xFFFF, 0xFFFF, "LSI Logic Corp of Canada(0x1015)"},
}; /* pci_vid_1015[] */

static pci_id_t const pci_vid_1016[] = {
{0x1016, 0xFFFF, 0xFFFF, 0xFFFF, "ICL Personal Systems(0x1016)"},
}; /* pci_vid_1016[] */

static pci_id_t const pci_vid_1017[] = {
{0x1017, 0xFFFF, 0xFFFF, 0xFFFF, "SPEA Software AG(0x1017)"},
{0x1017, 0x5343, 0xFFFF, 0xFFFF, "SPEA 3D Accelerator(0x5343)"},
}; /* pci_vid_1017[] */

static pci_id_t const pci_vid_1018[] = {
{0x1018, 0xFFFF, 0xFFFF, 0xFFFF, "Unisys Systems(0x1018)"},
}; /* pci_vid_1018[] */

static pci_id_t const pci_vid_1019[] = {
{0x1019, 0xFFFF, 0xFFFF, 0xFFFF, "Elitegroup Computer Systems(0x1019)"},
{0x1019, 0x9602, 0xFFFF, 0xFFFF, "RS780/RS880 PCI to PCI bridge (int gfx)(0x9602)"},
}; /* pci_vid_1019[] */

static pci_id_t const pci_vid_101A[] = {
{0x101A, 0xFFFF, 0xFFFF, 0xFFFF, "AT&T GIS (NCR)(0x101A)"},
{0x101A, 0x0005, 0xFFFF, 0xFFFF, "100VG ethernet(0x0005)"},
{0x101A, 0x0007, 0xFFFF, 0xFFFF, "BYNET BIC4G/2C/2G(0x0007)"},
{0x101A, 0x0007, 0x101A, 0x0019, "BYNET BIC2C(0x101A-0x0019)"},
{0x101A, 0x0007, 0x101A, 0x001C, "BYNET BIC2G(0x101A-0x001C)"},
{0x101A, 0x0007, 0x101A, 0x001F, "BYNET BIC4G(0x101A-0x001F)"},
{0x101A, 0x0009, 0xFFFF, 0xFFFF, "PQS Memory Controller(0x0009)"},
{0x101A, 0x000A, 0xFFFF, 0xFFFF, "BYNET BPCI Adapter(0x000A)"},
{0x101A, 0x000B, 0xFFFF, 0xFFFF, "BYNET 4 Port BYA Switch (BYA4P)(0x000B)"},
{0x101A, 0x000C, 0xFFFF, 0xFFFF, "BYNET 4 Port BYA Switch (BYA4G)(0x000C)"},
{0x101A, 0x0010, 0xFFFF, 0xFFFF, "NCR AMC Memory Controller(0x0010)"},
{0x101A, 0x1DC1, 0xFFFF, 0xFFFF, "BYNET BIC2M/BIC4M/BYA4M(0x1DC1)"},
{0x101A, 0x1DC1, 0x101A, 0x0019, "BIC2M(0x101A-0x0019)"},
{0x101A, 0x1DC1, 0x101A, 0x001F, "BIC4M(0x101A-0x001F)"},
{0x101A, 0x1DC1, 0x101A, 0x0ECE, "BYA4M(0x101A-0x0ECE)"},
{0x101A, 0x1FA8, 0xFFFF, 0xFFFF, "BYNET Multi-port BIC Adapter (XBIC Based)(0x1FA8)"},
{0x101A, 0x1FA8, 0x101A, 0x00C3, "BYNET BIC2SE(0x101A-0x00C3)"},
}; /* pci_vid_101A[] */

static pci_id_t const pci_vid_101B[] = {
{0x101B, 0xFFFF, 0xFFFF, 0xFFFF, "Vitesse Semiconductor(0x101B)"},
{0x101B, 0x0452, 0xFFFF, 0xFFFF, "VSC452 [SuperBMC](0x0452)"},
}; /* pci_vid_101B[] */

static pci_id_t const pci_vid_101C[] = {
{0x101C, 0xFFFF, 0xFFFF, 0xFFFF, "Western Digital(0x101C)"},
{0x101C, 0x0193, 0xFFFF, 0xFFFF, "33C193A(0x0193)"},
{0x101C, 0x0196, 0xFFFF, 0xFFFF, "33C196A(0x0196)"},
{0x101C, 0x0197, 0xFFFF, 0xFFFF, "33C197A(0x0197)"},
{0x101C, 0x0296, 0xFFFF, 0xFFFF, "33C296A(0x0296)"},
{0x101C, 0x3193, 0xFFFF, 0xFFFF, "7193(0x3193)"},
{0x101C, 0x3197, 0xFFFF, 0xFFFF, "7197(0x3197)"},
{0x101C, 0x3296, 0xFFFF, 0xFFFF, "33C296A(0x3296)"},
{0x101C, 0x4296, 0xFFFF, 0xFFFF, "34C296(0x4296)"},
{0x101C, 0x9710, 0xFFFF, 0xFFFF, "Pipeline 9710(0x9710)"},
{0x101C, 0x9712, 0xFFFF, 0xFFFF, "Pipeline 9712(0x9712)"},
{0x101C, 0xC24A, 0xFFFF, 0xFFFF, "90C(0xC24A)"},
}; /* pci_vid_101C[] */

static pci_id_t const pci_vid_101D[] = {
{0x101D, 0xFFFF, 0xFFFF, 0xFFFF, "Maxim Integrated Products(0x101D)"},
}; /* pci_vid_101D[] */

static pci_id_t const pci_vid_101E[] = {
{0x101E, 0xFFFF, 0xFFFF, 0xFFFF, "American Megatrends Inc.(0x101E)"},
{0x101E, 0x0009, 0xFFFF, 0xFFFF, "MegaRAID 428 Ultra RAID Controller (rev 03)(0x0009)"},
{0x101E, 0x1960, 0xFFFF, 0xFFFF, "MegaRAID(0x1960)"},
{0x101E, 0x1960, 0x101E, 0x0471, "MegaRAID 471 Enterprise 1600 RAID Controller(0x101E-0x0471)"},
{0x101E, 0x1960, 0x101E, 0x0475, "MegaRAID 475 Express 500/500LC RAID Controller(0x101E-0x0475)"},
{0x101E, 0x1960, 0x101E, 0x0477, "MegaRAID 477 Elite 3100 RAID Controller(0x101E-0x0477)"},
{0x101E, 0x1960, 0x101E, 0x0493, "MegaRAID 493 Elite 1600 RAID Controller(0x101E-0x0493)"},
{0x101E, 0x1960, 0x101E, 0x0494, "MegaRAID 494 Elite 1650 RAID Controller(0x101E-0x0494)"},
{0x101E, 0x1960, 0x101E, 0x0503, "MegaRAID 503 Enterprise 1650 RAID Controller(0x101E-0x0503)"},
{0x101E, 0x1960, 0x101E, 0x0511, "MegaRAID 511 i4 IDE RAID Controller(0x101E-0x0511)"},
{0x101E, 0x1960, 0x101E, 0x0522, "MegaRAID 522 i4133 RAID Controller(0x101E-0x0522)"},
{0x101E, 0x1960, 0x1028, 0x0471, "PowerEdge RAID Controller 3/QC(0x1028-0x0471)"},
{0x101E, 0x1960, 0x1028, 0x0475, "PowerEdge RAID Controller 3/SC(0x1028-0x0475)"},
{0x101E, 0x1960, 0x1028, 0x0493, "PowerEdge RAID Controller 3/DC(0x1028-0x0493)"},
{0x101E, 0x1960, 0x1028, 0x0511, "PowerEdge Cost Effective RAID Controller ATA100/4Ch(0x1028-0x0511)"},
{0x101E, 0x1960, 0x103C, 0x60E7, "NetRAID-1M(0x103C-0x60E7)"},
{0x101E, 0x1960, 0x103C, 0x60E8, "NetRaid 2M [AMI MegaRaid 493](0x103C-0x60E8)"},
{0x101E, 0x9010, 0xFFFF, 0xFFFF, "MegaRAID 428 Ultra RAID Controller(0x9010)"},
{0x101E, 0x9030, 0xFFFF, 0xFFFF, "EIDE Controller(0x9030)"},
{0x101E, 0x9031, 0xFFFF, 0xFFFF, "EIDE Controller(0x9031)"},
{0x101E, 0x9032, 0xFFFF, 0xFFFF, "EIDE & SCSI Controller(0x9032)"},
{0x101E, 0x9033, 0xFFFF, 0xFFFF, "SCSI Controller(0x9033)"},
{0x101E, 0x9040, 0xFFFF, 0xFFFF, "Multimedia card(0x9040)"},
{0x101E, 0x9060, 0xFFFF, 0xFFFF, "MegaRAID 434 Ultra GT RAID Controller(0x9060)"},
{0x101E, 0x9063, 0xFFFF, 0xFFFF, "MegaRAC(0x9063)"},
{0x101E, 0x9063, 0x101E, 0x0767, "Dell Remote Assistant Card 2(0x101E-0x0767)"},
}; /* pci_vid_101E[] */

static pci_id_t const pci_vid_101F[] = {
{0x101F, 0xFFFF, 0xFFFF, 0xFFFF, "PictureTel(0x101F)"},
}; /* pci_vid_101F[] */

static pci_id_t const pci_vid_1020[] = {
{0x1020, 0xFFFF, 0xFFFF, 0xFFFF, "Hitachi Computer Products(0x1020)"},
}; /* pci_vid_1020[] */

static pci_id_t const pci_vid_1021[] = {
{0x1021, 0xFFFF, 0xFFFF, 0xFFFF, "OKI Electric Industry Co. Ltd.(0x1021)"},
}; /* pci_vid_1021[] */

static pci_id_t const pci_vid_1022[] = {
{0x1022, 0xFFFF, 0xFFFF, 0xFFFF, "Advanced Micro Devices, Inc. [AMD](0x1022)"},
{0x1022, 0x1100, 0xFFFF, 0xFFFF, "K8 [Athlon64/Opteron] HyperTransport Technology Configuration(0x1100)"},
{0x1022, 0x1101, 0xFFFF, 0xFFFF, "K8 [Athlon64/Opteron] Address Map(0x1101)"},
{0x1022, 0x1102, 0xFFFF, 0xFFFF, "K8 [Athlon64/Opteron] DRAM Controller(0x1102)"},
{0x1022, 0x1103, 0xFFFF, 0xFFFF, "K8 [Athlon64/Opteron] Miscellaneous Control(0x1103)"},
{0x1022, 0x1200, 0xFFFF, 0xFFFF, "Family 10h Processor HyperTransport Configuration(0x1200)"},
{0x1022, 0x1201, 0xFFFF, 0xFFFF, "Family 10h Processor Address Map(0x1201)"},
{0x1022, 0x1202, 0xFFFF, 0xFFFF, "Family 10h Processor DRAM Controller(0x1202)"},
{0x1022, 0x1203, 0xFFFF, 0xFFFF, "Family 10h Processor Miscellaneous Control(0x1203)"},
{0x1022, 0x1204, 0xFFFF, 0xFFFF, "Family 10h Processor Link Control(0x1204)"},
{0x1022, 0x1300, 0xFFFF, 0xFFFF, "Family 11h Processor HyperTransport Configuration(0x1300)"},
{0x1022, 0x1301, 0xFFFF, 0xFFFF, "Family 11h Processor Address Map(0x1301)"},
{0x1022, 0x1302, 0xFFFF, 0xFFFF, "Family 11h Processor DRAM Controller(0x1302)"},
{0x1022, 0x1303, 0xFFFF, 0xFFFF, "Family 11h Processor Miscellaneous Control(0x1303)"},
{0x1022, 0x1304, 0xFFFF, 0xFFFF, "Family 11h Processor Link Control(0x1304)"},
{0x1022, 0x1305, 0xFFFF, 0xFFFF, "Griffin Function 5(0x1305)"},
{0x1022, 0x1306, 0xFFFF, 0xFFFF, "Griffin Function 6(0x1306)"},
{0x1022, 0x1307, 0xFFFF, 0xFFFF, "Griffin Function 7(0x1307)"},
{0x1022, 0x1308, 0xFFFF, 0xFFFF, "Kaveri Audio Controller(0x1308)"},
{0x1022, 0x1314, 0xFFFF, 0xFFFF, "Wrestler/Bheem/Ontario/Krishna Audio Controller(0x1314)"},
{0x1022, 0x13E0, 0xFFFF, 0xFFFF, "Ariel Root Complex(0x13E0)"},
{0x1022, 0x13E1, 0xFFFF, 0xFFFF, "Ariel IOMMU(0x13E1)"},
{0x1022, 0x13E2, 0xFFFF, 0xFFFF, "Ariel PCIe Dummy Host Bridge(0x13E2)"},
{0x1022, 0x13E3, 0xFFFF, 0xFFFF, "Ariel PCIe GPP Bridge(0x13E3)"},
{0x1022, 0x13E4, 0xFFFF, 0xFFFF, "Ariel PCIe Dummy Host Bridge(0x13E4)"},
{0x1022, 0x13E5, 0xFFFF, 0xFFFF, "Ariel Internal PCIe GPP Bridge 0 to Bus A(0x13E5)"},
{0x1022, 0x13E6, 0xFFFF, 0xFFFF, "Ariel Internal PCIe GPP Bridge 0 to Bus B(0x13E6)"},
{0x1022, 0x13E7, 0xFFFF, 0xFFFF, "Ariel SMBus Controller(0x13E7)"},
{0x1022, 0x13E8, 0xFFFF, 0xFFFF, "Ariel LPC Bridge(0x13E8)"},
{0x1022, 0x13E9, 0xFFFF, 0xFFFF, "Ariel Internal GPU(0x13E9)"},
{0x1022, 0x13EA, 0xFFFF, 0xFFFF, "Ariel HD Audio Controller(0x13EA)"},
{0x1022, 0x13EB, 0xFFFF, 0xFFFF, "Ariel HD Audio Coprocessor(0x13EB)"},
{0x1022, 0x13EC, 0xFFFF, 0xFFFF, "Ariel Cryptographic Coprocessor(0x13EC)"},
{0x1022, 0x13ED, 0xFFFF, 0xFFFF, "Ariel USB 3.1 Type C: Gen2 x 1port + DP Alt Mode(0x13ED)"},
{0x1022, 0x13EE, 0xFFFF, 0xFFFF, "Ariel USB 3.1 Type A: Gen2 x 2 ports(0x13EE)"},
{0x1022, 0x13EF, 0xFFFF, 0xFFFF, "Ariel ZCN/MP4(0x13EF)"},
{0x1022, 0x13F0, 0xFFFF, 0xFFFF, "Ariel Device 24: Function 0(0x13F0)"},
{0x1022, 0x13F1, 0xFFFF, 0xFFFF, "Ariel Device 24: Function 1(0x13F1)"},
{0x1022, 0x13F2, 0xFFFF, 0xFFFF, "Ariel Device 24: Function 2(0x13F2)"},
{0x1022, 0x13F3, 0xFFFF, 0xFFFF, "Ariel Device 24: Function 3(0x13F3)"},
{0x1022, 0x13F4, 0xFFFF, 0xFFFF, "Ariel Device 24: Function 4(0x13F4)"},
{0x1022, 0x13F5, 0xFFFF, 0xFFFF, "Ariel Device 24: Function 5(0x13F5)"},
{0x1022, 0x13F6, 0xFFFF, 0xFFFF, "Ariel Device 24: Function 6(0x13F6)"},
{0x1022, 0x13F7, 0xFFFF, 0xFFFF, "Ariel Device 24: Function 7(0x13F7)"},
{0x1022, 0x1400, 0xFFFF, 0xFFFF, "Family 15h (Models 10h-1fh) Processor Function 0(0x1400)"},
{0x1022, 0x1401, 0xFFFF, 0xFFFF, "Family 15h (Models 10h-1fh) Processor Function 1(0x1401)"},
{0x1022, 0x1402, 0xFFFF, 0xFFFF, "Family 15h (Models 10h-1fh) Processor Function 2(0x1402)"},
{0x1022, 0x1403, 0xFFFF, 0xFFFF, "Family 15h (Models 10h-1fh) Processor Function 3(0x1403)"},
{0x1022, 0x1404, 0xFFFF, 0xFFFF, "Family 15h (Models 10h-1fh) Processor Function 4(0x1404)"},
{0x1022, 0x1405, 0xFFFF, 0xFFFF, "Family 15h (Models 10h-1fh) Processor Function 5(0x1405)"},
{0x1022, 0x1410, 0xFFFF, 0xFFFF, "Family 15h (Models 10h-1fh) Processor Root Complex(0x1410)"},
{0x1022, 0x1410, 0x103C, 0x1985, "Pavilion 17-e163sg Notebook PC(0x103C-0x1985)"},
{0x1022, 0x1412, 0xFFFF, 0xFFFF, "Family 15h (Models 10h-1fh) Processor Root Port(0x1412)"},
{0x1022, 0x1412, 0x1022, 0x1234, "Trinity A-series APU(0x1022-0x1234)"},
{0x1022, 0x1413, 0xFFFF, 0xFFFF, "Family 15h (Models 10h-1fh) Processor Root Port(0x1413)"},
{0x1022, 0x1414, 0xFFFF, 0xFFFF, "Family 15h (Models 10h-1fh) Processor Root Port(0x1414)"},
{0x1022, 0x1414, 0x1022, 0x1234, "Trinity A-series APU(0x1022-0x1234)"},
{0x1022, 0x1415, 0xFFFF, 0xFFFF, "Family 15h (Models 10h-1fh) Processor Root Port(0x1415)"},
{0x1022, 0x1416, 0xFFFF, 0xFFFF, "Family 15h (Models 10h-1fh) Processor Root Port(0x1416)"},
{0x1022, 0x1417, 0xFFFF, 0xFFFF, "Family 15h (Models 10h-1fh) Processor Root Port(0x1417)"},
{0x1022, 0x1418, 0xFFFF, 0xFFFF, "Family 15h (Models 10h-1fh) Processor Root Port(0x1418)"},
{0x1022, 0x1419, 0xFFFF, 0xFFFF, "Family 15h (Models 10h-1fh) I/O Memory Management Unit(0x1419)"},
{0x1022, 0x141A, 0xFFFF, 0xFFFF, "Family 15h (Models 30h-3fh) Processor Function 0(0x141A)"},
{0x1022, 0x141B, 0xFFFF, 0xFFFF, "Family 15h (Models 30h-3fh) Processor Function 1(0x141B)"},
{0x1022, 0x141C, 0xFFFF, 0xFFFF, "Family 15h (Models 30h-3fh) Processor Function 2(0x141C)"},
{0x1022, 0x141D, 0xFFFF, 0xFFFF, "Family 15h (Models 30h-3fh) Processor Function 3(0x141D)"},
{0x1022, 0x141E, 0xFFFF, 0xFFFF, "Family 15h (Models 30h-3fh) Processor Function 4(0x141E)"},
{0x1022, 0x141F, 0xFFFF, 0xFFFF, "Family 15h (Models 30h-3fh) Processor Function 5(0x141F)"},
{0x1022, 0x1422, 0xFFFF, 0xFFFF, "Family 15h (Models 30h-3fh) Processor Root Complex(0x1422)"},
{0x1022, 0x1423, 0xFFFF, 0xFFFF, "Family 15h (Models 30h-3fh) I/O Memory Management Unit(0x1423)"},
{0x1022, 0x1424, 0xFFFF, 0xFFFF, "Family 15h (Models 30h-3fh) Processor Root Port(0x1424)"},
{0x1022, 0x1425, 0xFFFF, 0xFFFF, "Kaveri P2P Bridge for GFX PCIe Port [1:0](0x1425)"},
{0x1022, 0x1426, 0xFFFF, 0xFFFF, "Family 15h (Models 30h-3fh) Processor Root Port(0x1426)"},
{0x1022, 0x142E, 0xFFFF, 0xFFFF, "Liverpool Processor HT configuration(0x142E)"},
{0x1022, 0x142F, 0xFFFF, 0xFFFF, "Liverpool Processor Address Maps(0x142F)"},
{0x1022, 0x1430, 0xFFFF, 0xFFFF, "Liverpool Processor DRAM configuration(0x1430)"},
{0x1022, 0x1431, 0xFFFF, 0xFFFF, "Liverpool Processor Misc configuration(0x1431)"},
{0x1022, 0x1432, 0xFFFF, 0xFFFF, "Liverpool Processor PM configuration(0x1432)"},
{0x1022, 0x1433, 0xFFFF, 0xFFFF, "Liverpool Processor NB Performance Monitor(0x1433)"},
{0x1022, 0x1434, 0xFFFF, 0xFFFF, "Liverpool Processor SPLL Configuration(0x1434)"},
{0x1022, 0x1436, 0xFFFF, 0xFFFF, "Liverpool Processor Root Complex(0x1436)"},
{0x1022, 0x1437, 0xFFFF, 0xFFFF, "Liverpool I/O Memory Management Unit(0x1437)"},
{0x1022, 0x1438, 0xFFFF, 0xFFFF, "Liverpool UMI PCIe Dummy Host Bridge(0x1438)"},
{0x1022, 0x1439, 0xFFFF, 0xFFFF, "Family 16h Processor Functions 5:1(0x1439)"},
{0x1022, 0x143A, 0xFFFF, 0xFFFF, "Kingston/Clayton/Gladius/Montego Root Complex(0x143A)"},
{0x1022, 0x143B, 0xFFFF, 0xFFFF, "Kingston/Clayton/Gladius/Montego P2P Bridge for UMI Link(0x143B)"},
{0x1022, 0x1440, 0xFFFF, 0xFFFF, "Matisse/Vermeer Data Fabric: Device 18h; Function 0(0x1440)"},
{0x1022, 0x1441, 0xFFFF, 0xFFFF, "Matisse/Vermeer Data Fabric: Device 18h; Function 1(0x1441)"},
{0x1022, 0x1442, 0xFFFF, 0xFFFF, "Matisse/Vermeer Data Fabric: Device 18h; Function 2(0x1442)"},
{0x1022, 0x1443, 0xFFFF, 0xFFFF, "Matisse/Vermeer Data Fabric: Device 18h; Function 3(0x1443)"},
{0x1022, 0x1444, 0xFFFF, 0xFFFF, "Matisse/Vermeer Data Fabric: Device 18h; Function 4(0x1444)"},
{0x1022, 0x1445, 0xFFFF, 0xFFFF, "Matisse/Vermeer Data Fabric: Device 18h; Function 5(0x1445)"},
{0x1022, 0x1446, 0xFFFF, 0xFFFF, "Matisse/Vermeer Data Fabric: Device 18h; Function 6(0x1446)"},
{0x1022, 0x1447, 0xFFFF, 0xFFFF, "Matisse/Vermeer Data Fabric: Device 18h; Function 7(0x1447)"},
{0x1022, 0x1448, 0xFFFF, 0xFFFF, "Renoir Device 24: Function 0(0x1448)"},
{0x1022, 0x1449, 0xFFFF, 0xFFFF, "Renoir Device 24: Function 1(0x1449)"},
{0x1022, 0x144A, 0xFFFF, 0xFFFF, "Renoir Device 24: Function 2(0x144A)"},
{0x1022, 0x144B, 0xFFFF, 0xFFFF, "Renoir Device 24: Function 3(0x144B)"},
{0x1022, 0x144C, 0xFFFF, 0xFFFF, "Renoir Device 24: Function 4(0x144C)"},
{0x1022, 0x144D, 0xFFFF, 0xFFFF, "Renoir Device 24: Function 5(0x144D)"},
{0x1022, 0x144E, 0xFFFF, 0xFFFF, "Renoir Device 24: Function 6(0x144E)"},
{0x1022, 0x144F, 0xFFFF, 0xFFFF, "Renoir Device 24: Function 7(0x144F)"},
{0x1022, 0x1450, 0xFFFF, 0xFFFF, "Family 17h (Models 00h-0fh) Root Complex(0x1450)"},
{0x1022, 0x1451, 0xFFFF, 0xFFFF, "Family 17h (Models 00h-0fh) I/O Memory Management Unit(0x1451)"},
{0x1022, 0x1452, 0xFFFF, 0xFFFF, "Family 17h (Models 00h-1fh) PCIe Dummy Host Bridge(0x1452)"},
{0x1022, 0x1452, 0xEA50, 0xCE19, "mCOM10-L1900(0xEA50-0xCE19)"},
{0x1022, 0x1453, 0xFFFF, 0xFFFF, "Family 17h (Models 00h-0fh) PCIe GPP Bridge(0x1453)"},
{0x1022, 0x1454, 0xFFFF, 0xFFFF, "Family 17h (Models 00h-0fh) Internal PCIe GPP Bridge 0 to Bus B(0x1454)"},
{0x1022, 0x1455, 0xFFFF, 0xFFFF, "Zeppelin/Renoir PCIe Dummy Function(0x1455)"},
{0x1022, 0x1456, 0xFFFF, 0xFFFF, "Family 17h (Models 00h-0fh) Platform Security Processor (PSP) 3.0 Device(0x1456)"},
{0x1022, 0x1457, 0xFFFF, 0xFFFF, "Family 17h (Models 00h-0fh) HD Audio Controller(0x1457)"},
{0x1022, 0x1458, 0xFFFF, 0xFFFF, "XGMAC 10GbE Controller(0x1458)"},
{0x1022, 0x1459, 0xFFFF, 0xFFFF, "XGMAC 10GbE Controller(0x1459)"},
{0x1022, 0x145A, 0xFFFF, 0xFFFF, "Zeppelin/Raven/Raven2 PCIe Dummy Function(0x145A)"},
{0x1022, 0x145B, 0xFFFF, 0xFFFF, "Zeppelin Non-Transparent Bridge(0x145B)"},
{0x1022, 0x145C, 0xFFFF, 0xFFFF, "Family 17h (Models 00h-0fh) USB 3.0 Host Controller(0x145C)"},
{0x1022, 0x145D, 0xFFFF, 0xFFFF, "Zeppelin Switch Upstream (PCIE SW.US)(0x145D)"},
{0x1022, 0x145E, 0xFFFF, 0xFFFF, "Zeppelin Switch Downstream (PCIE SW.DS)(0x145E)"},
{0x1022, 0x145F, 0xFFFF, 0xFFFF, "Zeppelin USB 3.0 xHCI Compliant Host Controller(0x145F)"},
{0x1022, 0x1460, 0xFFFF, 0xFFFF, "Family 17h (Models 00h-0fh) Data Fabric: Device 18h; Function 0(0x1460)"},
{0x1022, 0x1461, 0xFFFF, 0xFFFF, "Family 17h (Models 00h-0fh) Data Fabric: Device 18h; Function 1(0x1461)"},
{0x1022, 0x1462, 0xFFFF, 0xFFFF, "Family 17h (Models 00h-0fh) Data Fabric: Device 18h; Function 2(0x1462)"},
{0x1022, 0x1463, 0xFFFF, 0xFFFF, "Family 17h (Models 00h-0fh) Data Fabric: Device 18h; Function 3(0x1463)"},
{0x1022, 0x1464, 0xFFFF, 0xFFFF, "Family 17h (Models 00h-0fh) Data Fabric: Device 18h; Function 4(0x1464)"},
{0x1022, 0x1465, 0xFFFF, 0xFFFF, "Family 17h (Models 00h-0fh) Data Fabric: Device 18h; Function 5(0x1465)"},
{0x1022, 0x1466, 0xFFFF, 0xFFFF, "Family 17h (Models 00h-0fh) Data Fabric: Device 18h; Function 6(0x1466)"},
{0x1022, 0x1467, 0xFFFF, 0xFFFF, "Family 17h (Models 00h-0fh) Data Fabric: Device 18h; Function 7(0x1467)"},
{0x1022, 0x1468, 0xFFFF, 0xFFFF, "Zeppelin Cryptographic Coprocessor NTBCCP(0x1468)"},
{0x1022, 0x1470, 0xFFFF, 0xFFFF, "Vega 10 PCIe Bridge(0x1470)"},
{0x1022, 0x1471, 0xFFFF, 0xFFFF, "Vega 10 PCIe Bridge(0x1471)"},
{0x1022, 0x1480, 0xFFFF, 0xFFFF, "Starship/Matisse Root Complex(0x1480)"},
{0x1022, 0x1480, 0x1462, 0x7C37, "X570-A PRO motherboard(0x1462-0x7C37)"},
{0x1022, 0x1480, 0x15D9, 0x1B95, "H12SSL-i(0x15D9-0x1B95)"},
{0x1022, 0x1481, 0xFFFF, 0xFFFF, "Starship/Matisse IOMMU(0x1481)"},
{0x1022, 0x1482, 0xFFFF, 0xFFFF, "Starship/Matisse PCIe Dummy Host Bridge(0x1482)"},
{0x1022, 0x1483, 0xFFFF, 0xFFFF, "Starship/Matisse GPP Bridge(0x1483)"},
{0x1022, 0x1483, 0x01DE, 0xFFF9, "Gimlet Baseboard(0x01DE-0xFFF9)"},
{0x1022, 0x1484, 0xFFFF, 0xFFFF, "Starship/Matisse Internal PCIe GPP Bridge 0 to bus[E:B](0x1484)"},
{0x1022, 0x1485, 0xFFFF, 0xFFFF, "Starship/Matisse Reserved SPP(0x1485)"},
{0x1022, 0x1486, 0xFFFF, 0xFFFF, "Starship/Matisse Cryptographic Coprocessor PSPCPP(0x1486)"},
{0x1022, 0x1487, 0xFFFF, 0xFFFF, "Starship/Matisse HD Audio Controller(0x1487)"},
{0x1022, 0x1487, 0x1462, 0x9C37, "X570-A PRO motherboard(0x1462-0x9C37)"},
{0x1022, 0x1488, 0xFFFF, 0xFFFF, "Starship Reserved SSP(0x1488)"},
{0x1022, 0x1489, 0xFFFF, 0xFFFF, "Starship Reserved SSP(0x1489)"},
{0x1022, 0x148A, 0xFFFF, 0xFFFF, "Starship/Matisse PCIe Dummy Function(0x148A)"},
{0x1022, 0x148B, 0xFFFF, 0xFFFF, "Starship/Matisse Non-Transparent Bridge(0x148B)"},
{0x1022, 0x148C, 0xFFFF, 0xFFFF, "Starship USB 3.0 Host Controller(0x148C)"},
{0x1022, 0x148C, 0x15D9, 0x145C, "H12SSL-i(0x15D9-0x145C)"},
{0x1022, 0x148D, 0xFFFF, 0xFFFF, "Starship/Matisse Switch Upstream (PCIE SW.US)(0x148D)"},
{0x1022, 0x148E, 0xFFFF, 0xFFFF, "Starship/Matisse Switch Downstream (PCIE SW.DS)(0x148E)"},
{0x1022, 0x148F, 0xFFFF, 0xFFFF, "Starship Reserved SSP(0x148F)"},
{0x1022, 0x1490, 0xFFFF, 0xFFFF, "Starship Device 24; Function 0(0x1490)"},
{0x1022, 0x1491, 0xFFFF, 0xFFFF, "Starship Device 24; Function 1(0x1491)"},
{0x1022, 0x1492, 0xFFFF, 0xFFFF, "Starship Device 24; Function 2(0x1492)"},
{0x1022, 0x1493, 0xFFFF, 0xFFFF, "Starship Device 24; Function 3(0x1493)"},
{0x1022, 0x1494, 0xFFFF, 0xFFFF, "Starship Device 24; Function 4(0x1494)"},
{0x1022, 0x1495, 0xFFFF, 0xFFFF, "Starship Device 24; Function 5(0x1495)"},
{0x1022, 0x1496, 0xFFFF, 0xFFFF, "Starship Device 24; Function 6(0x1496)"},
{0x1022, 0x1497, 0xFFFF, 0xFFFF, "Starship Device 24; Function 7(0x1497)"},
{0x1022, 0x1498, 0xFFFF, 0xFFFF, "Starship/Matisse PTDMA(0x1498)"},
{0x1022, 0x1499, 0xFFFF, 0xFFFF, "Starship/Matisse NVMe(0x1499)"},
{0x1022, 0x149A, 0xFFFF, 0xFFFF, "Starship PCIe GPP Bridge [1:0](0x149A)"},
{0x1022, 0x149B, 0xFFFF, 0xFFFF, "Starship Reserved SSP(0x149B)"},
{0x1022, 0x149C, 0xFFFF, 0xFFFF, "Matisse USB 3.0 Host Controller(0x149C)"},
{0x1022, 0x149C, 0x1462, 0x7C37, "X570-A PRO motherboard(0x1462-0x7C37)"},
{0x1022, 0x149D, 0xFFFF, 0xFFFF, "Vangogh CVIP(0x149D)"},
{0x1022, 0x14B5, 0xFFFF, 0xFFFF, "Family 17h-19h PCIe Root Complex(0x14B5)"},
{0x1022, 0x14B6, 0xFFFF, 0xFFFF, "Family 17h-19h IOMMU(0x14B6)"},
{0x1022, 0x14B7, 0xFFFF, 0xFFFF, "Family 17h-19h PCIe Dummy Host Bridge(0x14B7)"},
{0x1022, 0x14B8, 0xFFFF, 0xFFFF, "Family 17h-19h PCIe GPP Bridge(0x14B8)"},
{0x1022, 0x14B9, 0xFFFF, 0xFFFF, "Family 17h-19h Internal PCIe GPP Bridge(0x14B9)"},
{0x1022, 0x14BA, 0xFFFF, 0xFFFF, "Family 17h-19h PCIe GPP Bridge(0x14BA)"},
{0x1022, 0x14CA, 0xFFFF, 0xFFFF, "Genoa CCP/PSP 4.0 Device(0x14CA)"},
{0x1022, 0x14CD, 0xFFFF, 0xFFFF, "Family 19h USB4/Thunderbolt PCIe tunnel(0x14CD)"},
{0x1022, 0x14DE, 0xFFFF, 0xFFFF, "Phoenix PCIe Dummy Function(0x14DE)"},
{0x1022, 0x14EF, 0xFFFF, 0xFFFF, "Family 19h USB4/Thunderbolt PCIe tunnel(0x14EF)"},
{0x1022, 0x1502, 0xFFFF, 0xFFFF, "AMD IPU Device(0x1502)"},
{0x1022, 0x1510, 0xFFFF, 0xFFFF, "Family 14h Processor Root Complex(0x1510)"},
{0x1022, 0x1510, 0x174B, 0x1001, "PURE Fusion Mini(0x174B-0x1001)"},
{0x1022, 0x1512, 0xFFFF, 0xFFFF, "Family 14h Processor Root Port(0x1512)"},
{0x1022, 0x1513, 0xFFFF, 0xFFFF, "Family 14h Processor Root Port(0x1513)"},
{0x1022, 0x1514, 0xFFFF, 0xFFFF, "Family 14h Processor Root Port(0x1514)"},
{0x1022, 0x1515, 0xFFFF, 0xFFFF, "Family 14h Processor Root Port(0x1515)"},
{0x1022, 0x1516, 0xFFFF, 0xFFFF, "Family 14h Processor Root Port(0x1516)"},
{0x1022, 0x1530, 0xFFFF, 0xFFFF, "Family 16h Processor Function 0(0x1530)"},
{0x1022, 0x1531, 0xFFFF, 0xFFFF, "Family 16h Processor Function 1(0x1531)"},
{0x1022, 0x1532, 0xFFFF, 0xFFFF, "Family 16h Processor Function 2(0x1532)"},
{0x1022, 0x1533, 0xFFFF, 0xFFFF, "Family 16h Processor Function 3(0x1533)"},
{0x1022, 0x1534, 0xFFFF, 0xFFFF, "Family 16h Processor Function 4(0x1534)"},
{0x1022, 0x1535, 0xFFFF, 0xFFFF, "Family 16h Processor Function 5(0x1535)"},
{0x1022, 0x1536, 0xFFFF, 0xFFFF, "Family 16h Processor Root Complex(0x1536)"},
{0x1022, 0x1536, 0x1043, 0x8623, "AM1I-A Motherboard(0x1043-0x8623)"},
{0x1022, 0x1536, 0x1849, 0x1536, "QC5000-ITX/PH(0x1849-0x1536)"},
{0x1022, 0x1537, 0xFFFF, 0xFFFF, "Kabini/Mullins PSP-Platform Security Processor(0x1537)"},
{0x1022, 0x1538, 0xFFFF, 0xFFFF, "Family 16h Processor Function 0(0x1538)"},
{0x1022, 0x1539, 0xFFFF, 0xFFFF, "Kabini P2P Bridge for PCIe Ports[4:0](0x1539)"},
{0x1022, 0x1540, 0xFFFF, 0xFFFF, "Kryptos/Cato/Garfield/Garfield+/Arlene/Pooky HT Configuration(0x1540)"},
{0x1022, 0x1541, 0xFFFF, 0xFFFF, "Kryptos/Cato/Garfield/Garfield+/Arlene/Pooky Address Maps(0x1541)"},
{0x1022, 0x1542, 0xFFFF, 0xFFFF, "Kryptos/Cato/Garfield/Garfield+/Arlene/Pooky DRAM Configuration(0x1542)"},
{0x1022, 0x1543, 0xFFFF, 0xFFFF, "Kryptos/Cato/Garfield/Garfield+/Arlene/Pooky Miscellaneous Configuration(0x1543)"},
{0x1022, 0x1544, 0xFFFF, 0xFFFF, "Kryptos/Cato/Garfield/Garfield+/Arlene/Pooky PM Configuration(0x1544)"},
{0x1022, 0x1545, 0xFFFF, 0xFFFF, "Kryptos/Cato/Garfield/Garfield+/Arlene/Pooky NB Performance Monitor(0x1545)"},
{0x1022, 0x1546, 0xFFFF, 0xFFFF, "Kryptos/Cato/Garfield/Garfield+/Arlene/Pooky Root Complex(0x1546)"},
{0x1022, 0x1547, 0xFFFF, 0xFFFF, "Kryptos/Cato/Garfield/Garfield+/Arlene/Pooky IOMMU(0x1547)"},
{0x1022, 0x1548, 0xFFFF, 0xFFFF, "Kryptos/Cato/Garfield/Garfield+/Arlene/Pooky UMI PCIe Dummy Host Bridge(0x1548)"},
{0x1022, 0x1549, 0xFFFF, 0xFFFF, "Kryptos/Cato/Garfield/Garfield+ P2P Bridge for PCIe Port [3:0](0x1549)"},
{0x1022, 0x154A, 0xFFFF, 0xFFFF, "Kryptos/Cato/Garfield/Garfield+/Arlene/Pooky Audio Processor(0x154A)"},
{0x1022, 0x154B, 0xFFFF, 0xFFFF, "Kryptos/Cato/Garfield/Garfield+/Arlene/Pooky Security Processor(0x154B)"},
{0x1022, 0x154D, 0xFFFF, 0xFFFF, "Kryptos/Cato/Garfield/Garfield+/Arlene/Pooky/Anubis HDMI Controller(0x154D)"},
{0x1022, 0x154F, 0xFFFF, 0xFFFF, "Anubis Audio Processor(0x154F)"},
{0x1022, 0x1550, 0xFFFF, 0xFFFF, "Garfield+/Arlene/Pooky/Anubis SPLL Configuration(0x1550)"},
{0x1022, 0x1553, 0xFFFF, 0xFFFF, "Arlene/Pooky P2P Bridge for PCIE (3:0)(0x1553)"},
{0x1022, 0x155B, 0xFFFF, 0xFFFF, "Anubis Root Complex(0x155B)"},
{0x1022, 0x155C, 0xFFFF, 0xFFFF, "Anubis IOMMU(0x155C)"},
{0x1022, 0x155D, 0xFFFF, 0xFFFF, "Anubis UMI PCIe Dummy Bridge(0x155D)"},
{0x1022, 0x155E, 0xFFFF, 0xFFFF, "Anubis P2P Bridge for PCIe Ports [4:0](0x155E)"},
{0x1022, 0x1560, 0xFFFF, 0xFFFF, "Anubis Security Processor(0x1560)"},
{0x1022, 0x1566, 0xFFFF, 0xFFFF, "Family 16h (Models 30h-3fh) Processor Root Complex(0x1566)"},
{0x1022, 0x1567, 0xFFFF, 0xFFFF, "Mullins IOMMU(0x1567)"},
{0x1022, 0x156B, 0xFFFF, 0xFFFF, "Family 16h (Models 30h-3fh) Host Bridge(0x156B)"},
{0x1022, 0x1570, 0xFFFF, 0xFFFF, "Family 15h (Models 60h-6fh) Processor Function 0(0x1570)"},
{0x1022, 0x1571, 0xFFFF, 0xFFFF, "Family 15h (Models 60h-6fh) Processor Function 1(0x1571)"},
{0x1022, 0x1572, 0xFFFF, 0xFFFF, "Family 15h (Models 60h-6fh) Processor Function 2(0x1572)"},
{0x1022, 0x1573, 0xFFFF, 0xFFFF, "Family 15h (Models 60h-6fh) Processor Function 3(0x1573)"},
{0x1022, 0x1574, 0xFFFF, 0xFFFF, "Family 15h (Models 60h-6fh) Processor Function 4(0x1574)"},
{0x1022, 0x1575, 0xFFFF, 0xFFFF, "Family 15h (Models 60h-6fh) Processor Function 5(0x1575)"},
{0x1022, 0x1576, 0xFFFF, 0xFFFF, "Family 15h (Models 60h-6fh) Processor Root Complex(0x1576)"},
{0x1022, 0x1577, 0xFFFF, 0xFFFF, "Family 15h (Models 60h-6fh) I/O Memory Management Unit(0x1577)"},
{0x1022, 0x1578, 0xFFFF, 0xFFFF, "Carrizo Platform Security Processor(0x1578)"},
{0x1022, 0x1579, 0xFFFF, 0xFFFF, "Carrizo Audio Processor(0x1579)"},
{0x1022, 0x157A, 0xFFFF, 0xFFFF, "Family 15h (Models 60h-6fh) Audio Controller(0x157A)"},
{0x1022, 0x157B, 0xFFFF, 0xFFFF, "Family 15h (Models 60h-6fh) Host Bridge(0x157B)"},
{0x1022, 0x157C, 0xFFFF, 0xFFFF, "Family 15h (Models 60h-6fh) Processor Root Port(0x157C)"},
{0x1022, 0x157D, 0xFFFF, 0xFFFF, "Carrizo Audio Dummy Host Bridge(0x157D)"},
{0x1022, 0x157E, 0xFFFF, 0xFFFF, "Carrizo Audio Controller(0x157E)"},
{0x1022, 0x1580, 0xFFFF, 0xFFFF, "Family 16h (Models 30h-3fh) Processor Function 0(0x1580)"},
{0x1022, 0x1581, 0xFFFF, 0xFFFF, "Family 16h (Models 30h-3fh) Processor Function 1(0x1581)"},
{0x1022, 0x1582, 0xFFFF, 0xFFFF, "Family 16h (Models 30h-3fh) Processor Function 2(0x1582)"},
{0x1022, 0x1583, 0xFFFF, 0xFFFF, "Family 16h (Models 30h-3fh) Processor Function 3(0x1583)"},
{0x1022, 0x1584, 0xFFFF, 0xFFFF, "Family 16h (Models 30h-3fh) Processor Function 4(0x1584)"},
{0x1022, 0x1585, 0xFFFF, 0xFFFF, "Family 16h (Models 30h-3fh) Processor Function 5(0x1585)"},
{0x1022, 0x1590, 0xFFFF, 0xFFFF, "Amur/Nolan HT Configuration(0x1590)"},
{0x1022, 0x1591, 0xFFFF, 0xFFFF, "Amur/Nolan Address Maps(0x1591)"},
{0x1022, 0x1592, 0xFFFF, 0xFFFF, "Amur/Nolan DRAM Configuration(0x1592)"},
{0x1022, 0x1593, 0xFFFF, 0xFFFF, "Amur/Nolan Miscellaneous Configuration(0x1593)"},
{0x1022, 0x1594, 0xFFFF, 0xFFFF, "Amur/Nolan PM Configuration(0x1594)"},
{0x1022, 0x1595, 0xFFFF, 0xFFFF, "Amur/Nolan NB Performance Monitor(0x1595)"},
{0x1022, 0x1596, 0xFFFF, 0xFFFF, "Amur/Nolan Root Complex(0x1596)"},
{0x1022, 0x1597, 0xFFFF, 0xFFFF, "Amur/Nolan IOMMU(0x1597)"},
{0x1022, 0x1598, 0xFFFF, 0xFFFF, "Amur/Nolan Platform Security Processor(0x1598)"},
{0x1022, 0x1599, 0xFFFF, 0xFFFF, "Amur/Nolan PCIe Dummy Host Bridge(0x1599)"},
{0x1022, 0x159D, 0xFFFF, 0xFFFF, "Amur Function 6: Gasket(0x159D)"},
{0x1022, 0x15B0, 0xFFFF, 0xFFFF, "Stoney HT Configuration(0x15B0)"},
{0x1022, 0x15B1, 0xFFFF, 0xFFFF, "Stoney Address Maps(0x15B1)"},
{0x1022, 0x15B2, 0xFFFF, 0xFFFF, "Stoney DRAM Configuration(0x15B2)"},
{0x1022, 0x15B3, 0xFFFF, 0xFFFF, "Stoney Miscellaneous Configuration(0x15B3)"},
{0x1022, 0x15B4, 0xFFFF, 0xFFFF, "Stoney PM Configuration(0x15B4)"},
{0x1022, 0x15B5, 0xFFFF, 0xFFFF, "Stoney NB Performance Monitor(0x15B5)"},
{0x1022, 0x15BC, 0xFFFF, 0xFFFF, "Stoney PCIe [GFX,GPP] Bridge [4:0](0x15BC)"},
{0x1022, 0x15BE, 0xFFFF, 0xFFFF, "Stoney Audio Processor(0x15BE)"},
{0x1022, 0x15C4, 0xFFFF, 0xFFFF, "Phoenix USB4/Thunderbolt NHI controller #1(0x15C4)"},
{0x1022, 0x15C5, 0xFFFF, 0xFFFF, "Phoenix USB4/Thunderbolt NHI controller #2(0x15C5)"},
{0x1022, 0x15C7, 0xFFFF, 0xFFFF, "Family 19h (Model 74h) CCP/PSP 3.0 Device(0x15C7)"},
{0x1022, 0x15D0, 0xFFFF, 0xFFFF, "Raven/Raven2 Root Complex(0x15D0)"},
{0x1022, 0x15D0, 0x103C, 0x8615, "Pavilion Laptop 15-cw1xxx(0x103C-0x8615)"},
{0x1022, 0x15D0, 0x1043, 0x876B, "PRIME B450M-A Motherboard(0x1043-0x876B)"},
{0x1022, 0x15D0, 0xEA50, 0xCE19, "mCOM10-L1900(0xEA50-0xCE19)"},
{0x1022, 0x15D1, 0xFFFF, 0xFFFF, "Raven/Raven2 IOMMU(0x15D1)"},
{0x1022, 0x15D1, 0x103C, 0x8615, "Pavilion Laptop 15-cw1xxx(0x103C-0x8615)"},
{0x1022, 0x15D1, 0x1043, 0x876B, "PRIME B450M-A Motherboard(0x1043-0x876B)"},
{0x1022, 0x15D1, 0xEA50, 0xCE19, "mCOM10-L1900(0xEA50-0xCE19)"},
{0x1022, 0x15D2, 0xFFFF, 0xFFFF, "Raven/Raven2 PCIe Dummy Host Bridge(0x15D2)"},
{0x1022, 0x15D3, 0xFFFF, 0xFFFF, "Raven/Raven2 PCIe GPP Bridge [6:0](0x15D3)"},
{0x1022, 0x15D3, 0xEA50, 0xCE19, "mCOM10-L1900(0xEA50-0xCE19)"},
{0x1022, 0x15D4, 0xFFFF, 0xFFFF, "FireFlight USB 3.1(0x15D4)"},
{0x1022, 0x15D5, 0xFFFF, 0xFFFF, "FireFlight USB 3.1(0x15D5)"},
{0x1022, 0x15D6, 0xFFFF, 0xFFFF, "Rembrandt USB4 XHCI controller #5(0x15D6)"},
{0x1022, 0x15D7, 0xFFFF, 0xFFFF, "Rembrandt USB4 XHCI controller #6(0x15D7)"},
{0x1022, 0x15DA, 0xFFFF, 0xFFFF, "Raven/Raven2 PCIe Dummy Host Bridge(0x15DA)"},
{0x1022, 0x15DB, 0xFFFF, 0xFFFF, "Raven/Raven2 Internal PCIe GPP Bridge 0 to Bus A(0x15DB)"},
{0x1022, 0x15DB, 0xEA50, 0xCE19, "mCOM10-L1900(0xEA50-0xCE19)"},
{0x1022, 0x15DC, 0xFFFF, 0xFFFF, "Raven/Raven2 Internal PCIe GPP Bridge 0 to Bus B(0x15DC)"},
{0x1022, 0x15DC, 0xEA50, 0xCE19, "mCOM10-L1900(0xEA50-0xCE19)"},
{0x1022, 0x15DE, 0xFFFF, 0xFFFF, "Raven/Raven2/FireFlight HD Audio Controller(0x15DE)"},
{0x1022, 0x15DF, 0xFFFF, 0xFFFF, "Family 17h (Models 10h-1fh) Platform Security Processor(0x15DF)"},
{0x1022, 0x15DF, 0x1043, 0x876B, "PRIME Motherboard(0x1043-0x876B)"},
{0x1022, 0x15DF, 0x17AA, 0x5124, "ThinkPad E595(0x17AA-0x5124)"},
{0x1022, 0x15DF, 0xEA50, 0xCE19, "mCOM10-L1900(0xEA50-0xCE19)"},
{0x1022, 0x15E0, 0xFFFF, 0xFFFF, "Raven USB 3.1(0x15E0)"},
{0x1022, 0x15E0, 0x103C, 0x8615, "Pavilion Laptop 15-cw1xxx(0x103C-0x8615)"},
{0x1022, 0x15E0, 0x1043, 0x876B, "PRIME Motherboard(0x1043-0x876B)"},
{0x1022, 0x15E0, 0x17AA, 0x5124, "ThinkPad E595(0x17AA-0x5124)"},
{0x1022, 0x15E0, 0xEA50, 0xCE19, "mCOM10-L1900(0xEA50-0xCE19)"},
{0x1022, 0x15E1, 0xFFFF, 0xFFFF, "Raven USB 3.1(0x15E1)"},
{0x1022, 0x15E1, 0x103C, 0x8615, "Pavilion Laptop 15-cw1xxx(0x103C-0x8615)"},
{0x1022, 0x15E1, 0x1043, 0x876B, "PRIME Motherboard(0x1043-0x876B)"},
{0x1022, 0x15E1, 0x17AA, 0x5124, "ThinkPad E595(0x17AA-0x5124)"},
{0x1022, 0x15E1, 0xEA50, 0xCE19, "mCOM10-L1900(0xEA50-0xCE19)"},
{0x1022, 0x15E2, 0xFFFF, 0xFFFF, "ACP/ACP3X/ACP6x Audio Coprocessor(0x15E2)"},
{0x1022, 0x15E2, 0x17AA, 0x5124, "ThinkPad E595(0x17AA-0x5124)"},
{0x1022, 0x15E2, 0xEA50, 0xCE19, "mCOM10-L1900(0xEA50-0xCE19)"},
{0x1022, 0x15E3, 0xFFFF, 0xFFFF, "Family 17h/19h HD Audio Controller(0x15E3)"},
{0x1022, 0x15E3, 0x103C, 0x8615, "Pavilion Laptop 15-cw1xxx(0x103C-0x8615)"},
{0x1022, 0x15E3, 0x103C, 0x8B17, "ProBook 445 G9/455 G9(0x103C-0x8B17)"},
{0x1022, 0x15E3, 0x1043, 0x86C7, "PRIME B450M-A Motherboard(0x1043-0x86C7)"},
{0x1022, 0x15E3, 0x17AA, 0x5124, "ThinkPad E595(0x17AA-0x5124)"},
{0x1022, 0x15E4, 0xFFFF, 0xFFFF, "Sensor Fusion Hub(0x15E4)"},
{0x1022, 0x15E5, 0xFFFF, 0xFFFF, "Raven2 USB 3.1(0x15E5)"},
{0x1022, 0x15E5, 0xEA50, 0xCE19, "mCOM10-L1900(0xEA50-0xCE19)"},
{0x1022, 0x15E6, 0xFFFF, 0xFFFF, "Raven/Raven2/Renoir Non-Sensor Fusion Hub KMDF driver(0x15E6)"},
{0x1022, 0x15E6, 0x1022, 0x15E4, "Raven/Raven2/Renoir Sensor Fusion Hub(0x1022-0x15E4)"},
{0x1022, 0x15E6, 0xEA50, 0xCE19, "mCOM10-L1900(0xEA50-0xCE19)"},
{0x1022, 0x15E8, 0xFFFF, 0xFFFF, "Raven/Raven2 Device 24: Function 0(0x15E8)"},
{0x1022, 0x15E9, 0xFFFF, 0xFFFF, "Raven/Raven2 Device 24: Function 1(0x15E9)"},
{0x1022, 0x15EA, 0xFFFF, 0xFFFF, "Raven/Raven2 Device 24: Function 2(0x15EA)"},
{0x1022, 0x15EB, 0xFFFF, 0xFFFF, "Raven/Raven2 Device 24: Function 3(0x15EB)"},
{0x1022, 0x15EC, 0xFFFF, 0xFFFF, "Raven/Raven2 Device 24: Function 4(0x15EC)"},
{0x1022, 0x15ED, 0xFFFF, 0xFFFF, "Raven/Raven2 Device 24: Function 5(0x15ED)"},
{0x1022, 0x15EE, 0xFFFF, 0xFFFF, "Raven/Raven2 Device 24: Function 6(0x15EE)"},
{0x1022, 0x15EF, 0xFFFF, 0xFFFF, "Raven/Raven2 Device 24: Function 7(0x15EF)"},
{0x1022, 0x15F0, 0xFFFF, 0xFFFF, "FireFlight Device 24: Function 0(0x15F0)"},
{0x1022, 0x15F1, 0xFFFF, 0xFFFF, "FireFlight Device 24: Function 1(0x15F1)"},
{0x1022, 0x15F2, 0xFFFF, 0xFFFF, "FireFlight Device 24: Function 2(0x15F2)"},
{0x1022, 0x15F3, 0xFFFF, 0xFFFF, "FireFlight Device 24: Function 3(0x15F3)"},
{0x1022, 0x15F4, 0xFFFF, 0xFFFF, "FireFlight Device 24: Function 4(0x15F4)"},
{0x1022, 0x15F5, 0xFFFF, 0xFFFF, "FireFlight Device 24: Function 5(0x15F5)"},
{0x1022, 0x15F6, 0xFFFF, 0xFFFF, "FireFlight Device 24: Function 6(0x15F6)"},
{0x1022, 0x15F7, 0xFFFF, 0xFFFF, "FireFlight Device 24: Function 7(0x15F7)"},
{0x1022, 0x15F8, 0xFFFF, 0xFFFF, "FireFlight Root Complex(0x15F8)"},
{0x1022, 0x15F9, 0xFFFF, 0xFFFF, "FireFlight IOMMU(0x15F9)"},
{0x1022, 0x15FA, 0xFFFF, 0xFFFF, "FireFlight PCIe Dummy Host Bridge(0x15FA)"},
{0x1022, 0x15FB, 0xFFFF, 0xFFFF, "FireFlight PCIe GPP Bride 3:0(0x15FB)"},
{0x1022, 0x15FC, 0xFFFF, 0xFFFF, "FireFlight PCIe Dummy Host Bridge(0x15FC)"},
{0x1022, 0x15FD, 0xFFFF, 0xFFFF, "FireFlight Internal PCIe GPP Bridge 0 to Bus A(0x15FD)"},
{0x1022, 0x15FE, 0xFFFF, 0xFFFF, "FireFlight Internal PCIe GPP Bridge 0 to Bus B(0x15FE)"},
{0x1022, 0x15FF, 0xFFFF, 0xFFFF, "FireFlight Bus A; Device 0: Function 0: Internal GPU(0x15FF)"},
{0x1022, 0x1600, 0xFFFF, 0xFFFF, "Family 15h Processor Function 0(0x1600)"},
{0x1022, 0x1601, 0xFFFF, 0xFFFF, "Family 15h Processor Function 1(0x1601)"},
{0x1022, 0x1602, 0xFFFF, 0xFFFF, "Family 15h Processor Function 2(0x1602)"},
{0x1022, 0x1603, 0xFFFF, 0xFFFF, "Family 15h Processor Function 3(0x1603)"},
{0x1022, 0x1604, 0xFFFF, 0xFFFF, "Family 15h Processor Function 4(0x1604)"},
{0x1022, 0x1605, 0xFFFF, 0xFFFF, "Family 15h Processor Function 5(0x1605)"},
{0x1022, 0x1606, 0xFFFF, 0xFFFF, "Arden Security Processor(0x1606)"},
{0x1022, 0x1608, 0xFFFF, 0xFFFF, "Arden Device 18h: Function 0(0x1608)"},
{0x1022, 0x1609, 0xFFFF, 0xFFFF, "Arden Device 18h: Function 1(0x1609)"},
{0x1022, 0x160A, 0xFFFF, 0xFFFF, "Arden Device 18h: Function 2(0x160A)"},
{0x1022, 0x160B, 0xFFFF, 0xFFFF, "Arden Device 18h: Function 3(0x160B)"},
{0x1022, 0x160C, 0xFFFF, 0xFFFF, "Arden Device 18h: Function 4(0x160C)"},
{0x1022, 0x160D, 0xFFFF, 0xFFFF, "Arden Device 18h: Function 5(0x160D)"},
{0x1022, 0x160E, 0xFFFF, 0xFFFF, "Arden Device 18h: Function 6(0x160E)"},
{0x1022, 0x160F, 0xFFFF, 0xFFFF, "Arden Device 18h: Function 7(0x160F)"},
{0x1022, 0x161A, 0xFFFF, 0xFFFF, "Rembrandt USB4 XHCI controller #1(0x161A)"},
{0x1022, 0x161B, 0xFFFF, 0xFFFF, "Rembrandt USB4 XHCI controller #2(0x161B)"},
{0x1022, 0x161C, 0xFFFF, 0xFFFF, "Rembrandt USB4 XHCI controller #7(0x161C)"},
{0x1022, 0x161D, 0xFFFF, 0xFFFF, "Rembrandt USB4 XHCI controller #3(0x161D)"},
{0x1022, 0x161E, 0xFFFF, 0xFFFF, "Rembrandt USB4 XHCI controller #4(0x161E)"},
{0x1022, 0x161F, 0xFFFF, 0xFFFF, "Rembrandt USB4 XHCI controller #8(0x161F)"},
{0x1022, 0x1620, 0xFFFF, 0xFFFF, "Anubis HT Configuration(0x1620)"},
{0x1022, 0x1621, 0xFFFF, 0xFFFF, "Anubis Address Maps(0x1621)"},
{0x1022, 0x1622, 0xFFFF, 0xFFFF, "Anubis DRAM Configuration(0x1622)"},
{0x1022, 0x1623, 0xFFFF, 0xFFFF, "Anubis Miscellaneous Configuration(0x1623)"},
{0x1022, 0x1624, 0xFFFF, 0xFFFF, "Anubis PM Configuration(0x1624)"},
{0x1022, 0x1625, 0xFFFF, 0xFFFF, "Anubis NB Performance Monitor(0x1625)"},
{0x1022, 0x1626, 0xFFFF, 0xFFFF, "Arden Root Complex(0x1626)"},
{0x1022, 0x1627, 0xFFFF, 0xFFFF, "Arden IOMMU(0x1627)"},
{0x1022, 0x1628, 0xFFFF, 0xFFFF, "Arden PCIe Dummy Host Bridge(0x1628)"},
{0x1022, 0x1629, 0xFFFF, 0xFFFF, "Arden PCIe GPP Bridge(0x1629)"},
{0x1022, 0x162A, 0xFFFF, 0xFFFF, "Arden Internal PCIe GPP Bridge 0 to bus X(0x162A)"},
{0x1022, 0x162B, 0xFFFF, 0xFFFF, "Arden PCIe Non-Transparent Bridge(0x162B)"},
{0x1022, 0x162C, 0xFFFF, 0xFFFF, "VanGogh USB2(0x162C)"},
{0x1022, 0x162E, 0xFFFF, 0xFFFF, "Rembrandt USB4/Thunderbolt NHI controller #1(0x162E)"},
{0x1022, 0x162F, 0xFFFF, 0xFFFF, "Rembrandt USB4/Thunderbolt NHI controller #2(0x162F)"},
{0x1022, 0x1630, 0xFFFF, 0xFFFF, "Renoir/Cezanne Root Complex(0x1630)"},
{0x1022, 0x1631, 0xFFFF, 0xFFFF, "Renoir/Cezanne IOMMU(0x1631)"},
{0x1022, 0x1632, 0xFFFF, 0xFFFF, "Renoir PCIe Dummy Host Bridge(0x1632)"},
{0x1022, 0x1633, 0xFFFF, 0xFFFF, "Renoir PCIe GPP Bridge(0x1633)"},
{0x1022, 0x1634, 0xFFFF, 0xFFFF, "Renoir/Cezanne PCIe GPP Bridge(0x1634)"},
{0x1022, 0x1635, 0xFFFF, 0xFFFF, "Renoir Internal PCIe GPP Bridge to Bus(0x1635)"},
{0x1022, 0x1637, 0xFFFF, 0xFFFF, "Renoir HD Audio Controller(0x1637)"},
{0x1022, 0x1639, 0xFFFF, 0xFFFF, "Renoir/Cezanne USB 3.1(0x1639)"},
{0x1022, 0x163A, 0xFFFF, 0xFFFF, "VanGogh USB0(0x163A)"},
{0x1022, 0x163B, 0xFFFF, 0xFFFF, "VanGogh USB1(0x163B)"},
{0x1022, 0x163C, 0xFFFF, 0xFFFF, "VanGogh SecUSB(0x163C)"},
{0x1022, 0x163D, 0xFFFF, 0xFFFF, "VanGogh SecureFunction(0x163D)"},
{0x1022, 0x163E, 0xFFFF, 0xFFFF, "VanGogh HSP(0x163E)"},
{0x1022, 0x1641, 0xFFFF, 0xFFFF, "Renoir 10GbE Controller Port 0 (XGBE0/1)(0x1641)"},
{0x1022, 0x1642, 0xFFFF, 0xFFFF, "Renoir WLAN(0x1642)"},
{0x1022, 0x1643, 0xFFFF, 0xFFFF, "Renoir BT(0x1643)"},
{0x1022, 0x1644, 0xFFFF, 0xFFFF, "Renoir I2S(0x1644)"},
{0x1022, 0x1645, 0xFFFF, 0xFFFF, "VanGogh Root Complex(0x1645)"},
{0x1022, 0x1646, 0xFFFF, 0xFFFF, "VanGogh IOMMU(0x1646)"},
{0x1022, 0x1647, 0xFFFF, 0xFFFF, "VanGogh PCIe GPP Bridge(0x1647)"},
{0x1022, 0x1648, 0xFFFF, 0xFFFF, "VanGogh Internal PCIe GPP Bridge to Bus(0x1648)"},
{0x1022, 0x1649, 0xFFFF, 0xFFFF, "Family 19h PSP/CCP(0x1649)"},
{0x1022, 0x164F, 0xFFFF, 0xFFFF, "Milan IOMMU(0x164F)"},
{0x1022, 0x1650, 0xFFFF, 0xFFFF, "Milan Data Fabric; Function 0(0x1650)"},
{0x1022, 0x1651, 0xFFFF, 0xFFFF, "Milan Data Fabric; Function 1(0x1651)"},
{0x1022, 0x1652, 0xFFFF, 0xFFFF, "Milan Data Fabric; Function 2(0x1652)"},
{0x1022, 0x1653, 0xFFFF, 0xFFFF, "Milan Data Fabric; Function 3(0x1653)"},
{0x1022, 0x1654, 0xFFFF, 0xFFFF, "Milan Data Fabric; Function 4(0x1654)"},
{0x1022, 0x1655, 0xFFFF, 0xFFFF, "Milan Data Fabric; Function 5(0x1655)"},
{0x1022, 0x1656, 0xFFFF, 0xFFFF, "Milan Data Fabric; Function 6(0x1656)"},
{0x1022, 0x1657, 0xFFFF, 0xFFFF, "Milan Data Fabric; Function 7(0x1657)"},
{0x1022, 0x1660, 0xFFFF, 0xFFFF, "VanGogh Data Fabric; Function 0(0x1660)"},
{0x1022, 0x1661, 0xFFFF, 0xFFFF, "VanGogh Data Fabric; Function 1(0x1661)"},
{0x1022, 0x1662, 0xFFFF, 0xFFFF, "VanGogh Data Fabric; Function 2(0x1662)"},
{0x1022, 0x1663, 0xFFFF, 0xFFFF, "VanGogh Data Fabric; Function 3(0x1663)"},
{0x1022, 0x1664, 0xFFFF, 0xFFFF, "VanGogh Data Fabric; Function 4(0x1664)"},
{0x1022, 0x1665, 0xFFFF, 0xFFFF, "VanGogh Data Fabric; Function 5(0x1665)"},
{0x1022, 0x1666, 0xFFFF, 0xFFFF, "VanGogh Data Fabric; Function 6(0x1666)"},
{0x1022, 0x1667, 0xFFFF, 0xFFFF, "VanGogh Data Fabric; Function 7(0x1667)"},
{0x1022, 0x1668, 0xFFFF, 0xFFFF, "Pink Sardine USB4/Thunderbolt NHI controller #1(0x1668)"},
{0x1022, 0x1669, 0xFFFF, 0xFFFF, "Pink Sardine USB4/Thunderbolt NHI controller #2(0x1669)"},
{0x1022, 0x166A, 0xFFFF, 0xFFFF, "Cezanne Data Fabric; Function 0(0x166A)"},
{0x1022, 0x166B, 0xFFFF, 0xFFFF, "Cezanne Data Fabric; Function 1(0x166B)"},
{0x1022, 0x166C, 0xFFFF, 0xFFFF, "Cezanne Data Fabric; Function 2(0x166C)"},
{0x1022, 0x166D, 0xFFFF, 0xFFFF, "Cezanne Data Fabric; Function 3(0x166D)"},
{0x1022, 0x166E, 0xFFFF, 0xFFFF, "Cezanne Data Fabric; Function 4(0x166E)"},
{0x1022, 0x166F, 0xFFFF, 0xFFFF, "Cezanne Data Fabric; Function 5(0x166F)"},
{0x1022, 0x1670, 0xFFFF, 0xFFFF, "Cezanne Data Fabric; Function 6(0x1670)"},
{0x1022, 0x1671, 0xFFFF, 0xFFFF, "Cezanne Data Fabric; Function 7(0x1671)"},
{0x1022, 0x1679, 0xFFFF, 0xFFFF, "Rembrandt Data Fabric: Device 18h; Function 0(0x1679)"},
{0x1022, 0x167A, 0xFFFF, 0xFFFF, "Rembrandt Data Fabric: Device 18h; Function 1(0x167A)"},
{0x1022, 0x167B, 0xFFFF, 0xFFFF, "Rembrandt Data Fabric: Device 18h; Function 2(0x167B)"},
{0x1022, 0x167C, 0xFFFF, 0xFFFF, "Rembrandt Data Fabric: Device 18h; Function 3(0x167C)"},
{0x1022, 0x167D, 0xFFFF, 0xFFFF, "Rembrandt Data Fabric: Device 18h; Function 4(0x167D)"},
{0x1022, 0x167E, 0xFFFF, 0xFFFF, "Rembrandt Data Fabric: Device 18h; Function 5(0x167E)"},
{0x1022, 0x167F, 0xFFFF, 0xFFFF, "Rembrandt Data Fabric: Device 18h; Function 6(0x167F)"},
{0x1022, 0x1680, 0xFFFF, 0xFFFF, "Rembrandt Data Fabric: Device 18h; Function 7(0x1680)"},
{0x1022, 0x1700, 0xFFFF, 0xFFFF, "Family 12h/14h Processor Function 0(0x1700)"},
{0x1022, 0x1701, 0xFFFF, 0xFFFF, "Family 12h/14h Processor Function 1(0x1701)"},
{0x1022, 0x1702, 0xFFFF, 0xFFFF, "Family 12h/14h Processor Function 2(0x1702)"},
{0x1022, 0x1703, 0xFFFF, 0xFFFF, "Family 12h/14h Processor Function 3(0x1703)"},
{0x1022, 0x1704, 0xFFFF, 0xFFFF, "Family 12h/14h Processor Function 4(0x1704)"},
{0x1022, 0x1705, 0xFFFF, 0xFFFF, "Family 12h Processor Root Complex(0x1705)"},
{0x1022, 0x1706, 0xFFFF, 0xFFFF, "Llano P2P Bridge to external GPU(0x1706)"},
{0x1022, 0x1707, 0xFFFF, 0xFFFF, "Family 12h Processor Root Port(0x1707)"},
{0x1022, 0x1708, 0xFFFF, 0xFFFF, "Family 12h Processor Root Port(0x1708)"},
{0x1022, 0x1709, 0xFFFF, 0xFFFF, "Family 12h Processor Root Port(0x1709)"},
{0x1022, 0x170A, 0xFFFF, 0xFFFF, "Family 12h Processor Root Port(0x170A)"},
{0x1022, 0x170B, 0xFFFF, 0xFFFF, "Family 12h Processor Root Port(0x170B)"},
{0x1022, 0x170C, 0xFFFF, 0xFFFF, "Family 12h Processor Root Port(0x170C)"},
{0x1022, 0x170D, 0xFFFF, 0xFFFF, "Family 12h Processor Root Port(0x170D)"},
{0x1022, 0x1716, 0xFFFF, 0xFFFF, "Family 12h/14h Processor Function 5(0x1716)"},
{0x1022, 0x1718, 0xFFFF, 0xFFFF, "Family 12h/14h Processor Function 6(0x1718)"},
{0x1022, 0x1719, 0xFFFF, 0xFFFF, "Family 12h/14h Processor Function 7(0x1719)"},
{0x1022, 0x2000, 0xFFFF, 0xFFFF, "79C97x [PCnet32 LANCE](0x2000)"},
{0x1022, 0x2000, 0x1014, 0x2000, "NetFinity 10/100 Fast Ethernet(0x1014-0x2000)"},
{0x1022, 0x2000, 0x1022, 0x2000, "PCnet - Fast 79C971(0x1022-0x2000)"},
{0x1022, 0x2000, 0x103C, 0x104C, "Ethernet with LAN remote power Adapter(0x103C-0x104C)"},
{0x1022, 0x2000, 0x103C, 0x1064, "Ethernet with LAN remote power Adapter(0x103C-0x1064)"},
{0x1022, 0x2000, 0x103C, 0x1065, "Ethernet with LAN remote power Adapter(0x103C-0x1065)"},
{0x1022, 0x2000, 0x103C, 0x106C, "Ethernet with LAN remote power Adapter(0x103C-0x106C)"},
{0x1022, 0x2000, 0x103C, 0x106E, "Ethernet with LAN remote power Adapter(0x103C-0x106E)"},
{0x1022, 0x2000, 0x103C, 0x10EA, "Ethernet with LAN remote power Adapter(0x103C-0x10EA)"},
{0x1022, 0x2000, 0x1113, 0x1220, "EN1220 10/100 Fast Ethernet(0x1113-0x1220)"},
{0x1022, 0x2000, 0x1259, 0x2450, "AT-2450 10/100 Fast Ethernet(0x1259-0x2450)"},
{0x1022, 0x2000, 0x1259, 0x2454, "AT-2450v4 10Mb Ethernet Adapter(0x1259-0x2454)"},
{0x1022, 0x2000, 0x1259, 0x2700, "AT-2700TX 10/100 Fast Ethernet(0x1259-0x2700)"},
{0x1022, 0x2000, 0x1259, 0x2701, "AT-2700FX 100Mb Ethernet(0x1259-0x2701)"},
{0x1022, 0x2000, 0x1259, 0x2702, "AT-2700FTX (AM79C976KD [PCnet-PRO] chipset) 10/100 Mb Fiber/Copper Fast Ethernet(0x1259-0x2702)"},
{0x1022, 0x2000, 0x1259, 0x2703, "AT-2701FX(0x1259-0x2703)"},
{0x1022, 0x2000, 0x1259, 0x2704, "AT-2701FTX 10/100 Mb Fiber/Copper Fast Ethernet(0x1259-0x2704)"},
{0x1022, 0x2000, 0x4C53, 0x1000, "CC7/CR7/CP7/VC7/VP7/VR7 mainboard(0x4C53-0x1000)"},
{0x1022, 0x2000, 0x4C53, 0x1010, "CP5/CR6 mainboard(0x4C53-0x1010)"},
{0x1022, 0x2000, 0x4C53, 0x1020, "VR6 mainboard(0x4C53-0x1020)"},
{0x1022, 0x2000, 0x4C53, 0x1030, "PC5 mainboard(0x4C53-0x1030)"},
{0x1022, 0x2000, 0x4C53, 0x1040, "CL7 mainboard(0x4C53-0x1040)"},
{0x1022, 0x2000, 0x4C53, 0x1060, "PC7 mainboard(0x4C53-0x1060)"},
{0x1022, 0x2001, 0xFFFF, 0xFFFF, "Am79C978 PCnet Home (HomePNA) 1/10 PCI Ethernet Adapter [Am79C971 PHY](0x2001)"},
{0x1022, 0x2001, 0x1092, 0x0A78, "Multimedia Home Network Adapter(0x1092-0x0A78)"},
{0x1022, 0x2001, 0x1668, 0x0299, "ActionLink Home Network Adapter(0x1668-0x0299)"},
{0x1022, 0x2003, 0xFFFF, 0xFFFF, "Am 1771 MBW [Alchemy](0x2003)"},
{0x1022, 0x2020, 0xFFFF, 0xFFFF, "AM53/79C974 [PC-SCSI](0x2020)"},
{0x1022, 0x2020, 0x1AF4, 0x1100, "QEMU Virtual Machine(0x1AF4-0x1100)"},
{0x1022, 0x2040, 0xFFFF, 0xFFFF, "79c974(0x2040)"},
{0x1022, 0x2080, 0xFFFF, 0xFFFF, "CS5536 [Geode companion] Host Bridge(0x2080)"},
{0x1022, 0x2081, 0xFFFF, 0xFFFF, "Geode LX Video(0x2081)"},
{0x1022, 0x2082, 0xFFFF, 0xFFFF, "Geode LX AES Security Block(0x2082)"},
{0x1022, 0x208F, 0xFFFF, 0xFFFF, "CS5536 GeodeLink PCI South Bridge(0x208F)"},
{0x1022, 0x2090, 0xFFFF, 0xFFFF, "CS5536 [Geode companion] ISA(0x2090)"},
{0x1022, 0x2091, 0xFFFF, 0xFFFF, "CS5536 [Geode companion] FLASH(0x2091)"},
{0x1022, 0x2093, 0xFFFF, 0xFFFF, "CS5536 [Geode companion] Audio(0x2093)"},
{0x1022, 0x2094, 0xFFFF, 0xFFFF, "CS5536 [Geode companion] OHC(0x2094)"},
{0x1022, 0x2095, 0xFFFF, 0xFFFF, "CS5536 [Geode companion] EHC(0x2095)"},
{0x1022, 0x2096, 0xFFFF, 0xFFFF, "CS5536 [Geode companion] UDC(0x2096)"},
{0x1022, 0x2097, 0xFFFF, 0xFFFF, "CS5536 [Geode companion] UOC(0x2097)"},
{0x1022, 0x209A, 0xFFFF, 0xFFFF, "CS5536 [Geode companion] IDE(0x209A)"},
{0x1022, 0x2625, 0xFFFF, 0xFFFF, "Am79C973 [Lance/PCI PCNet/32](0x2625)"},
{0x1022, 0x2627, 0xFFFF, 0xFFFF, "Am79C975 [Lance/PCI PCNet/32](0x2627)"},
{0x1022, 0x3000, 0xFFFF, 0xFFFF, "ELanSC520 Microcontroller(0x3000)"},
{0x1022, 0x43A0, 0xFFFF, 0xFFFF, "Hudson PCI to PCI bridge (PCIE port 0)(0x43A0)"},
{0x1022, 0x43A1, 0xFFFF, 0xFFFF, "Hudson PCI to PCI bridge (PCIE port 1)(0x43A1)"},
{0x1022, 0x43A2, 0xFFFF, 0xFFFF, "Hudson PCI to PCI bridge (PCIE port 2)(0x43A2)"},
{0x1022, 0x43A3, 0xFFFF, 0xFFFF, "Hudson PCI to PCI bridge (PCIE port 3)(0x43A3)"},
{0x1022, 0x43B0, 0xFFFF, 0xFFFF, "X370 Series Chipset PCIe Upstream Port(0x43B0)"},
{0x1022, 0x43B0, 0x1849, 0x43C6, "Fatal1ty X370 Professional Gaming(0x1849-0x43C6)"},
{0x1022, 0x43B1, 0xFFFF, 0xFFFF, "X399 Series Chipset PCIe Bridge(0x43B1)"},
{0x1022, 0x43B4, 0xFFFF, 0xFFFF, "300 Series Chipset PCIe Port(0x43B4)"},
{0x1022, 0x43B5, 0xFFFF, 0xFFFF, "X370 Series Chipset SATA Controller(0x43B5)"},
{0x1022, 0x43B5, 0x1849, 0x43C8, "Fatal1ty X370 Professional Gaming(0x1849-0x43C8)"},
{0x1022, 0x43B6, 0xFFFF, 0xFFFF, "X399 Series Chipset SATA Controller(0x43B6)"},
{0x1022, 0x43B7, 0xFFFF, 0xFFFF, "300 Series Chipset SATA Controller(0x43B7)"},
{0x1022, 0x43B8, 0xFFFF, 0xFFFF, "A320 Chipset SATA Controller [AHCI mode](0x43B8)"},
{0x1022, 0x43B9, 0xFFFF, 0xFFFF, "X370 Series Chipset USB 3.1 xHCI Controller(0x43B9)"},
{0x1022, 0x43B9, 0x1849, 0x43D0, "Fatal1ty X370 Professional Gaming(0x1849-0x43D0)"},
{0x1022, 0x43BA, 0xFFFF, 0xFFFF, "X399 Series Chipset USB 3.1 xHCI Controller(0x43BA)"},
{0x1022, 0x43BB, 0xFFFF, 0xFFFF, "300 Series Chipset USB 3.1 xHCI Controller(0x43BB)"},
{0x1022, 0x43BC, 0xFFFF, 0xFFFF, "A320 USB 3.1 XHCI Host Controller(0x43BC)"},
{0x1022, 0x43C6, 0xFFFF, 0xFFFF, "400 Series Chipset PCIe Bridge(0x43C6)"},
{0x1022, 0x43C7, 0xFFFF, 0xFFFF, "400 Series Chipset PCIe Port(0x43C7)"},
{0x1022, 0x43C8, 0xFFFF, 0xFFFF, "400 Series Chipset SATA Controller(0x43C8)"},
{0x1022, 0x43D5, 0xFFFF, 0xFFFF, "400 Series Chipset USB 3.1 xHCI Compliant Host Controller(0x43D5)"},
{0x1022, 0x43E9, 0xFFFF, 0xFFFF, "500 Series Chipset Switch Upstream Port(0x43E9)"},
{0x1022, 0x43EB, 0xFFFF, 0xFFFF, "500 Series Chipset SATA Controller(0x43EB)"},
{0x1022, 0x43EB, 0x1B21, 0x1062, "ASM1062 Serial ATA Controller(0x1B21-0x1062)"},
{0x1022, 0x43EE, 0xFFFF, 0xFFFF, "500 Series Chipset USB 3.1 XHCI Controller(0x43EE)"},
{0x1022, 0x43EE, 0x1B21, 0x1142, "ASM1042A USB 3.0 Host Controller(0x1B21-0x1142)"},
{0x1022, 0x43F4, 0xFFFF, 0xFFFF, "600 Series Chipset PCIe Switch Upstream Port(0x43F4)"},
{0x1022, 0x43F5, 0xFFFF, 0xFFFF, "600 Series Chipset PCIe Switch Downstream Port(0x43F5)"},
{0x1022, 0x43F6, 0xFFFF, 0xFFFF, "600 Series Chipset SATA Controller(0x43F6)"},
{0x1022, 0x43F7, 0xFFFF, 0xFFFF, "600 Series Chipset USB 3.2 Controller(0x43F7)"},
{0x1022, 0x57A3, 0xFFFF, 0xFFFF, "Matisse PCIe GPP Bridge(0x57A3)"},
{0x1022, 0x57A4, 0xFFFF, 0xFFFF, "Matisse PCIe GPP Bridge(0x57A4)"},
{0x1022, 0x57AD, 0xFFFF, 0xFFFF, "Matisse Switch Upstream(0x57AD)"},
{0x1022, 0x7006, 0xFFFF, 0xFFFF, "AMD-751 [Irongate] System Controller(0x7006)"},
{0x1022, 0x7007, 0xFFFF, 0xFFFF, "AMD-751 [Irongate] AGP Bridge(0x7007)"},
{0x1022, 0x700A, 0xFFFF, 0xFFFF, "AMD-IGR4 AGP Host to PCI Bridge(0x700A)"},
{0x1022, 0x700B, 0xFFFF, 0xFFFF, "AMD-IGR4 PCI to PCI Bridge(0x700B)"},
{0x1022, 0x700C, 0xFFFF, 0xFFFF, "AMD-760 MP [IGD4-2P] System Controller(0x700C)"},
{0x1022, 0x700D, 0xFFFF, 0xFFFF, "AMD-760 MP [IGD4-2P] AGP Bridge(0x700D)"},
{0x1022, 0x700E, 0xFFFF, 0xFFFF, "AMD-760 [IGD4-1P] System Controller(0x700E)"},
{0x1022, 0x700F, 0xFFFF, 0xFFFF, "AMD-760 [IGD4-1P] AGP Bridge(0x700F)"},
{0x1022, 0x7400, 0xFFFF, 0xFFFF, "AMD-755 [Cobra] ISA(0x7400)"},
{0x1022, 0x7401, 0xFFFF, 0xFFFF, "AMD-755 [Cobra] IDE(0x7401)"},
{0x1022, 0x7403, 0xFFFF, 0xFFFF, "AMD-755 [Cobra] ACPI(0x7403)"},
{0x1022, 0x7404, 0xFFFF, 0xFFFF, "AMD-755 [Cobra] USB(0x7404)"},
{0x1022, 0x7408, 0xFFFF, 0xFFFF, "AMD-756 [Viper] ISA(0x7408)"},
{0x1022, 0x7409, 0xFFFF, 0xFFFF, "AMD-756 [Viper] IDE(0x7409)"},
{0x1022, 0x740B, 0xFFFF, 0xFFFF, "AMD-756 [Viper] ACPI(0x740B)"},
{0x1022, 0x740C, 0xFFFF, 0xFFFF, "AMD-756 [Viper] USB(0x740C)"},
{0x1022, 0x7410, 0xFFFF, 0xFFFF, "AMD-766 [ViperPlus] ISA(0x7410)"},
{0x1022, 0x7411, 0xFFFF, 0xFFFF, "AMD-766 [ViperPlus] IDE(0x7411)"},
{0x1022, 0x7413, 0xFFFF, 0xFFFF, "AMD-766 [ViperPlus] ACPI(0x7413)"},
{0x1022, 0x7414, 0xFFFF, 0xFFFF, "AMD-766 [ViperPlus] USB(0x7414)"},
{0x1022, 0x7440, 0xFFFF, 0xFFFF, "AMD-768 [Opus] ISA(0x7440)"},
{0x1022, 0x7440, 0x1043, 0x8044, "A7M-D Mainboard(0x1043-0x8044)"},
{0x1022, 0x7441, 0xFFFF, 0xFFFF, "AMD-768 [Opus] IDE(0x7441)"},
{0x1022, 0x7443, 0xFFFF, 0xFFFF, "AMD-768 [Opus] ACPI(0x7443)"},
{0x1022, 0x7443, 0x1043, 0x8044, "A7M-D Mainboard(0x1043-0x8044)"},
{0x1022, 0x7445, 0xFFFF, 0xFFFF, "AMD-768 [Opus] Audio(0x7445)"},
{0x1022, 0x7446, 0xFFFF, 0xFFFF, "AMD-768 [Opus] MC97 Modem(0x7446)"},
{0x1022, 0x7448, 0xFFFF, 0xFFFF, "AMD-768 [Opus] PCI(0x7448)"},
{0x1022, 0x7449, 0xFFFF, 0xFFFF, "AMD-768 [Opus] USB(0x7449)"},
{0x1022, 0x7450, 0xFFFF, 0xFFFF, "AMD-8131 PCI-X Bridge(0x7450)"},
{0x1022, 0x7451, 0xFFFF, 0xFFFF, "AMD-8131 PCI-X IOAPIC(0x7451)"},
{0x1022, 0x7454, 0xFFFF, 0xFFFF, "AMD-8151 System Controller(0x7454)"},
{0x1022, 0x7455, 0xFFFF, 0xFFFF, "AMD-8151 AGP Bridge(0x7455)"},
{0x1022, 0x7458, 0xFFFF, 0xFFFF, "AMD-8132 PCI-X Bridge(0x7458)"},
{0x1022, 0x7459, 0xFFFF, 0xFFFF, "AMD-8132 PCI-X IOAPIC(0x7459)"},
{0x1022, 0x7460, 0xFFFF, 0xFFFF, "AMD-8111 PCI(0x7460)"},
{0x1022, 0x7460, 0x161F, 0x3017, "HDAMB(0x161F-0x3017)"},
{0x1022, 0x7461, 0xFFFF, 0xFFFF, "AMD-8111 USB(0x7461)"},
{0x1022, 0x7462, 0xFFFF, 0xFFFF, "AMD-8111 Ethernet(0x7462)"},
{0x1022, 0x7463, 0xFFFF, 0xFFFF, "AMD-8111 USB EHCI(0x7463)"},
{0x1022, 0x7464, 0xFFFF, 0xFFFF, "AMD-8111 USB OHCI(0x7464)"},
{0x1022, 0x7464, 0x161F, 0x3017, "HDAMB(0x161F-0x3017)"},
{0x1022, 0x7468, 0xFFFF, 0xFFFF, "AMD-8111 LPC(0x7468)"},
{0x1022, 0x7468, 0x161F, 0x3017, "HDAMB(0x161F-0x3017)"},
{0x1022, 0x7469, 0xFFFF, 0xFFFF, "AMD-8111 IDE(0x7469)"},
{0x1022, 0x7469, 0x1022, 0x2B80, "AMD-8111 IDE [Quartet](0x1022-0x2B80)"},
{0x1022, 0x7469, 0x161F, 0x3017, "HDAMB(0x161F-0x3017)"},
{0x1022, 0x746A, 0xFFFF, 0xFFFF, "AMD-8111 SMBus 2.0(0x746A)"},
{0x1022, 0x746B, 0xFFFF, 0xFFFF, "AMD-8111 ACPI(0x746B)"},
{0x1022, 0x746B, 0x161F, 0x3017, "HDAMB(0x161F-0x3017)"},
{0x1022, 0x746D, 0xFFFF, 0xFFFF, "AMD-8111 AC97 Audio(0x746D)"},
{0x1022, 0x746D, 0x161F, 0x3017, "HDAMB(0x161F-0x3017)"},
{0x1022, 0x746E, 0xFFFF, 0xFFFF, "AMD-8111 MC97 Modem(0x746E)"},
{0x1022, 0x756B, 0xFFFF, 0xFFFF, "AMD-8111 ACPI(0x756B)"},
{0x1022, 0x7800, 0xFFFF, 0xFFFF, "FCH SATA Controller [IDE mode](0x7800)"},
{0x1022, 0x7801, 0xFFFF, 0xFFFF, "FCH SATA Controller [AHCI mode](0x7801)"},
{0x1022, 0x7801, 0x103C, 0x168B, "ProBook 4535s Notebook(0x103C-0x168B)"},
{0x1022, 0x7801, 0x103C, 0x194E, "ProBook 455 G1 Notebook(0x103C-0x194E)"},
{0x1022, 0x7801, 0x1043, 0x8623, "AM1I-A Motherboard(0x1043-0x8623)"},
{0x1022, 0x7801, 0x17AA, 0x3988, "Z50-75(0x17AA-0x3988)"},
{0x1022, 0x7801, 0x1849, 0x7801, "QC5000-ITX/PH(0x1849-0x7801)"},
{0x1022, 0x7802, 0xFFFF, 0xFFFF, "FCH SATA Controller [RAID mode](0x7802)"},
{0x1022, 0x7803, 0xFFFF, 0xFFFF, "FCH SATA Controller [RAID mode](0x7803)"},
{0x1022, 0x7804, 0xFFFF, 0xFFFF, "FCH SATA Controller [AHCI mode](0x7804)"},
{0x1022, 0x7804, 0x103C, 0x1985, "Pavilion 17-e163sg Notebook PC(0x103C-0x1985)"},
{0x1022, 0x7805, 0xFFFF, 0xFFFF, "FCH SATA Controller [RAID mode](0x7805)"},
{0x1022, 0x7806, 0xFFFF, 0xFFFF, "FCH SD Flash Controller(0x7806)"},
{0x1022, 0x7807, 0xFFFF, 0xFFFF, "FCH USB OHCI Controller(0x7807)"},
{0x1022, 0x7807, 0x103C, 0x194E, "ProBook 455 G1 Notebook(0x103C-0x194E)"},
{0x1022, 0x7807, 0x103C, 0x1985, "Pavilion 17-e163sg Notebook PC(0x103C-0x1985)"},
{0x1022, 0x7807, 0x1043, 0x8623, "AM1I-A Motherboard(0x1043-0x8623)"},
{0x1022, 0x7807, 0x17AA, 0x3988, "Z50-75(0x17AA-0x3988)"},
{0x1022, 0x7807, 0x1849, 0x7807, "QC5000-ITX/PH(0x1849-0x7807)"},
{0x1022, 0x7808, 0xFFFF, 0xFFFF, "FCH USB EHCI Controller(0x7808)"},
{0x1022, 0x7808, 0x103C, 0x194E, "ProBook 455 G1 Notebook(0x103C-0x194E)"},
{0x1022, 0x7808, 0x103C, 0x1985, "Pavilion 17-e163sg Notebook PC(0x103C-0x1985)"},
{0x1022, 0x7808, 0x1043, 0x8623, "AM1I-A Motherboard(0x1043-0x8623)"},
{0x1022, 0x7808, 0x17AA, 0x3988, "Z50-75(0x17AA-0x3988)"},
{0x1022, 0x7808, 0x1849, 0x7808, "QC5000-ITX/PH(0x1849-0x7808)"},
{0x1022, 0x7809, 0xFFFF, 0xFFFF, "FCH USB OHCI Controller(0x7809)"},
{0x1022, 0x7809, 0x103C, 0x194E, "ProBook 455 G1 Notebook(0x103C-0x194E)"},
{0x1022, 0x7809, 0x17AA, 0x3988, "Z50-75(0x17AA-0x3988)"},
{0x1022, 0x780A, 0xFFFF, 0xFFFF, "Kabini/Mullins SATA Raid/AHCI Mode (DotHill driver)(0x780A)"},
{0x1022, 0x780B, 0xFFFF, 0xFFFF, "FCH SMBus Controller(0x780B)"},
{0x1022, 0x780B, 0x103C, 0x194E, "ProBook 455 G1 Notebook(0x103C-0x194E)"},
{0x1022, 0x780B, 0x103C, 0x1985, "Pavilion 17-e163sg Notebook PC(0x103C-0x1985)"},
{0x1022, 0x780B, 0x1043, 0x8623, "AM1I-A Motherboard(0x1043-0x8623)"},
{0x1022, 0x780B, 0x17AA, 0x3988, "Z50-75(0x17AA-0x3988)"},
{0x1022, 0x780B, 0x1849, 0x780B, "QC5000-ITX/PH(0x1849-0x780B)"},
{0x1022, 0x780C, 0xFFFF, 0xFFFF, "FCH IDE Controller(0x780C)"},
{0x1022, 0x780D, 0xFFFF, 0xFFFF, "FCH Azalia Controller(0x780D)"},
{0x1022, 0x780D, 0x103C, 0x194E, "ProBook 455 G1 Notebook(0x103C-0x194E)"},
{0x1022, 0x780D, 0x103C, 0x1985, "Pavilion 17-e163sg Notebook PC(0x103C-0x1985)"},
{0x1022, 0x780D, 0x1043, 0x8444, "F2A85-M Series(0x1043-0x8444)"},
{0x1022, 0x780D, 0x1043, 0x8576, "AM1I-A Motherboard(0x1043-0x8576)"},
{0x1022, 0x780D, 0x17AA, 0x3988, "Z50-75(0x17AA-0x3988)"},
{0x1022, 0x780D, 0x1849, 0x8892, "QC5000-ITX/PH(0x1849-0x8892)"},
{0x1022, 0x780E, 0xFFFF, 0xFFFF, "FCH LPC Bridge(0x780E)"},
{0x1022, 0x780E, 0x103C, 0x194E, "ProBook 455 G1 Notebook(0x103C-0x194E)"},
{0x1022, 0x780E, 0x103C, 0x1985, "Pavilion 17-e163sg Notebook PC(0x103C-0x1985)"},
{0x1022, 0x780E, 0x1043, 0x8623, "AM1I-A Motherboard(0x1043-0x8623)"},
{0x1022, 0x780E, 0x17AA, 0x3988, "Z50-75(0x17AA-0x3988)"},
{0x1022, 0x780E, 0x1849, 0x780E, "QC5000-ITX/PH(0x1849-0x780E)"},
{0x1022, 0x780F, 0xFFFF, 0xFFFF, "FCH PCI Bridge(0x780F)"},
{0x1022, 0x7812, 0xFFFF, 0xFFFF, "FCH USB XHCI Controller(0x7812)"},
{0x1022, 0x7813, 0xFFFF, 0xFFFF, "FCH SD Flash Controller(0x7813)"},
{0x1022, 0x7814, 0xFFFF, 0xFFFF, "FCH USB XHCI Controller(0x7814)"},
{0x1022, 0x7814, 0x103C, 0x194E, "ProBook 455 G1 Notebook(0x103C-0x194E)"},
{0x1022, 0x7814, 0x103C, 0x1985, "Pavilion 17-e163sg Notebook PC(0x103C-0x1985)"},
{0x1022, 0x7814, 0x1043, 0x8623, "AM1I-A Motherboard(0x1043-0x8623)"},
{0x1022, 0x7814, 0x17AA, 0x3988, "Z50-75(0x17AA-0x3988)"},
{0x1022, 0x7814, 0x1849, 0x7814, "QC5000-ITX/PH(0x1849-0x7814)"},
{0x1022, 0x7900, 0xFFFF, 0xFFFF, "FCH SATA Controller [IDE mode](0x7900)"},
{0x1022, 0x7901, 0xFFFF, 0xFFFF, "FCH SATA Controller [AHCI mode](0x7901)"},
{0x1022, 0x7901, 0x103C, 0x8615, "Pavilion Laptop 15-cw1xxx(0x103C-0x8615)"},
{0x1022, 0x7901, 0x1043, 0x876B, "PRIME Motherboard(0x1043-0x876B)"},
{0x1022, 0x7901, 0x1462, 0x7C37, "X570-A PRO motherboard(0x1462-0x7C37)"},
{0x1022, 0x7901, 0x15D9, 0x7901, "H12SSL-i(0x15D9-0x7901)"},
{0x1022, 0x7901, 0xEA50, 0xCE19, "mCOM10-L1900(0xEA50-0xCE19)"},
{0x1022, 0x7902, 0xFFFF, 0xFFFF, "FCH SATA Controller [RAID mode](0x7902)"},
{0x1022, 0x7903, 0xFFFF, 0xFFFF, "FCH SATA Controller [RAID mode](0x7903)"},
{0x1022, 0x7904, 0xFFFF, 0xFFFF, "FCH SATA Controller [AHCI mode](0x7904)"},
{0x1022, 0x7906, 0xFFFF, 0xFFFF, "FCH SD Flash Controller(0x7906)"},
{0x1022, 0x7908, 0xFFFF, 0xFFFF, "FCH USB EHCI Controller(0x7908)"},
{0x1022, 0x790B, 0xFFFF, 0xFFFF, "FCH SMBus Controller(0x790B)"},
{0x1022, 0x790B, 0x103C, 0x8615, "Pavilion Laptop 15-cw1xxx(0x103C-0x8615)"},
{0x1022, 0x790B, 0x103C, 0x8B17, "ProBook 445 G9/455 G9(0x103C-0x8B17)"},
{0x1022, 0x790B, 0x1043, 0x876B, "PRIME Motherboard(0x1043-0x876B)"},
{0x1022, 0x790B, 0x1462, 0x7C37, "X570-A PRO motherboard(0x1462-0x7C37)"},
{0x1022, 0x790B, 0x15D9, 0x790B, "H12SSL-i(0x15D9-0x790B)"},
{0x1022, 0x790B, 0x17AA, 0x5124, "ThinkPad E595(0x17AA-0x5124)"},
{0x1022, 0x790B, 0xEA50, 0xCE19, "mCOM10-L1900(0xEA50-0xCE19)"},
{0x1022, 0x790E, 0xFFFF, 0xFFFF, "FCH LPC Bridge(0x790E)"},
{0x1022, 0x790E, 0x103C, 0x8615, "Pavilion Laptop 15-cw1xxx(0x103C-0x8615)"},
{0x1022, 0x790E, 0x1043, 0x876B, "PRIME B450M-A Motherboard(0x1043-0x876B)"},
{0x1022, 0x790E, 0x1462, 0x7C37, "X570-A PRO motherboard(0x1462-0x7C37)"},
{0x1022, 0x790E, 0x15D9, 0x790E, "H12SSL-i(0x15D9-0x790E)"},
{0x1022, 0x790E, 0x17AA, 0x5124, "ThinkPad E595(0x17AA-0x5124)"},
{0x1022, 0x790E, 0xEA50, 0xCE19, "mCOM10-L1900(0xEA50-0xCE19)"},
{0x1022, 0x790F, 0xFFFF, 0xFFFF, "FCH PCI Bridge(0x790F)"},
{0x1022, 0x7914, 0xFFFF, 0xFFFF, "FCH USB XHCI Controller(0x7914)"},
{0x1022, 0x9600, 0xFFFF, 0xFFFF, "RS780 Host Bridge(0x9600)"},
{0x1022, 0x9600, 0x1043, 0x82EE, "M378A-CM Motherboard(0x1043-0x82EE)"},
{0x1022, 0x9600, 0x1043, 0x82F1, "M3A78-EH Motherboard(0x1043-0x82F1)"},
{0x1022, 0x9601, 0xFFFF, 0xFFFF, "RS880 Host Bridge(0x9601)"},
{0x1022, 0x9601, 0x1019, 0x2120, "A785GM-M(0x1019-0x2120)"},
{0x1022, 0x9601, 0x1028, 0x0433, "Optiplex 580(0x1028-0x0433)"},
{0x1022, 0x9601, 0x103C, 0x1609, "ProLiant MicroServer N36L(0x103C-0x1609)"},
{0x1022, 0x9601, 0x1043, 0x83A2, "M4A785-M Mainboard(0x1043-0x83A2)"},
{0x1022, 0x9601, 0x1043, 0x843E, "M5A88-V EVO(0x1043-0x843E)"},
{0x1022, 0x9602, 0xFFFF, 0xFFFF, "RS780/RS880 PCI to PCI bridge (int gfx)(0x9602)"},
{0x1022, 0x9603, 0xFFFF, 0xFFFF, "RS780 PCI to PCI bridge (ext gfx port 0)(0x9603)"},
{0x1022, 0x9603, 0x1028, 0x0433, "Optiplex 580(0x1028-0x0433)"},
{0x1022, 0x9603, 0x103C, 0x1609, "ProLiant MicroServer N36L(0x103C-0x1609)"},
{0x1022, 0x9604, 0xFFFF, 0xFFFF, "RS780/RS880 PCI to PCI bridge (PCIE port 0)(0x9604)"},
{0x1022, 0x9604, 0x1028, 0x0433, "OptiPlex 580(0x1028-0x0433)"},
{0x1022, 0x9605, 0xFFFF, 0xFFFF, "RS780/RS880 PCI to PCI bridge (PCIE port 1)(0x9605)"},
{0x1022, 0x9606, 0xFFFF, 0xFFFF, "RS780 PCI to PCI bridge (PCIE port 2)(0x9606)"},
{0x1022, 0x9606, 0x103C, 0x1609, "ProLiant MicroServer N36L(0x103C-0x1609)"},
{0x1022, 0x9607, 0xFFFF, 0xFFFF, "RS780/RS880 PCI to PCI bridge (PCIE port 3)(0x9607)"},
{0x1022, 0x9608, 0xFFFF, 0xFFFF, "RS780/RS880 PCI to PCI bridge (PCIE port 4)(0x9608)"},
{0x1022, 0x9608, 0x1028, 0x0433, "OptiPlex 580(0x1028-0x0433)"},
{0x1022, 0x9609, 0xFFFF, 0xFFFF, "RS780/RS880 PCI to PCI bridge (PCIE port 5)(0x9609)"},
{0x1022, 0x960A, 0xFFFF, 0xFFFF, "RS780 PCI to PCI bridge (NB-SB link)(0x960A)"},
{0x1022, 0x960B, 0xFFFF, 0xFFFF, "RS780 PCI to PCI bridge (ext gfx port 1)(0x960B)"},
{0x1022, 0xB000, 0xFFFF, 0xFFFF, "RAID Bottom Device(0xB000)"},
}; /* pci_vid_1022[] */

static pci_id_t const pci_vid_1023[] = {
{0x1023, 0xFFFF, 0xFFFF, 0xFFFF, "Trident Microsystems(0x1023)"},
{0x1023, 0x0194, 0xFFFF, 0xFFFF, "82C194(0x0194)"},
{0x1023, 0x2000, 0xFFFF, 0xFFFF, "4DWave DX(0x2000)"},
{0x1023, 0x2001, 0xFFFF, 0xFFFF, "4DWave NX(0x2001)"},
{0x1023, 0x2001, 0x122D, 0x1400, "Trident PCI288-Q3DII (NX)(0x122D-0x1400)"},
{0x1023, 0x2100, 0xFFFF, 0xFFFF, "CyberBlade XP4m32(0x2100)"},
{0x1023, 0x2200, 0xFFFF, 0xFFFF, "XGI Volari XP5(0x2200)"},
{0x1023, 0x8400, 0xFFFF, 0xFFFF, "CyberBlade/i7(0x8400)"},
{0x1023, 0x8400, 0x1023, 0x8400, "CyberBlade i7 AGP(0x1023-0x8400)"},
{0x1023, 0x8420, 0xFFFF, 0xFFFF, "CyberBlade/i7d(0x8420)"},
{0x1023, 0x8420, 0x0E11, 0xB15A, "CyberBlade i7 AGP(0x0E11-0xB15A)"},
{0x1023, 0x8500, 0xFFFF, 0xFFFF, "CyberBlade/i1(0x8500)"},
{0x1023, 0x8520, 0xFFFF, 0xFFFF, "CyberBlade i1(0x8520)"},
{0x1023, 0x8520, 0x0E11, 0xB16E, "CyberBlade i1 AGP(0x0E11-0xB16E)"},
{0x1023, 0x8520, 0x1023, 0x8520, "CyberBlade i1 AGP(0x1023-0x8520)"},
{0x1023, 0x8620, 0xFFFF, 0xFFFF, "CyberBlade/i1(0x8620)"},
{0x1023, 0x8620, 0x1014, 0x0502, "ThinkPad R30/T30(0x1014-0x0502)"},
{0x1023, 0x8620, 0x1014, 0x1025, "Travelmate 352TE(0x1014-0x1025)"},
{0x1023, 0x8820, 0xFFFF, 0xFFFF, "CyberBlade XPAi1(0x8820)"},
{0x1023, 0x9320, 0xFFFF, 0xFFFF, "TGUI 9320(0x9320)"},
{0x1023, 0x9350, 0xFFFF, 0xFFFF, "GUI Accelerator(0x9350)"},
{0x1023, 0x9360, 0xFFFF, 0xFFFF, "Flat panel GUI Accelerator(0x9360)"},
{0x1023, 0x9382, 0xFFFF, 0xFFFF, "Cyber 9382 [Reference design](0x9382)"},
{0x1023, 0x9383, 0xFFFF, 0xFFFF, "Cyber 9383 [Reference design](0x9383)"},
{0x1023, 0x9385, 0xFFFF, 0xFFFF, "Cyber 9385 [Reference design](0x9385)"},
{0x1023, 0x9386, 0xFFFF, 0xFFFF, "Cyber 9386(0x9386)"},
{0x1023, 0x9388, 0xFFFF, 0xFFFF, "Cyber 9388(0x9388)"},
{0x1023, 0x9397, 0xFFFF, 0xFFFF, "Cyber 9397(0x9397)"},
{0x1023, 0x939A, 0xFFFF, 0xFFFF, "Cyber 9397DVD(0x939A)"},
{0x1023, 0x9420, 0xFFFF, 0xFFFF, "TGUI 9420(0x9420)"},
{0x1023, 0x9430, 0xFFFF, 0xFFFF, "TGUI 9430(0x9430)"},
{0x1023, 0x9440, 0xFFFF, 0xFFFF, "TGUI 9440(0x9440)"},
{0x1023, 0x9460, 0xFFFF, 0xFFFF, "TGUI 9460(0x9460)"},
{0x1023, 0x9470, 0xFFFF, 0xFFFF, "TGUI 9470(0x9470)"},
{0x1023, 0x9520, 0xFFFF, 0xFFFF, "Cyber 9520(0x9520)"},
{0x1023, 0x9525, 0xFFFF, 0xFFFF, "Cyber 9525(0x9525)"},
{0x1023, 0x9540, 0xFFFF, 0xFFFF, "Cyber 9540(0x9540)"},
{0x1023, 0x9660, 0xFFFF, 0xFFFF, "TGUI 9660/938x/968x(0x9660)"},
{0x1023, 0x9680, 0xFFFF, 0xFFFF, "TGUI 9680(0x9680)"},
{0x1023, 0x9682, 0xFFFF, 0xFFFF, "TGUI 9682(0x9682)"},
{0x1023, 0x9683, 0xFFFF, 0xFFFF, "TGUI 9683(0x9683)"},
{0x1023, 0x9685, 0xFFFF, 0xFFFF, "ProVIDIA 9685(0x9685)"},
{0x1023, 0x9750, 0xFFFF, 0xFFFF, "3DImage 9750(0x9750)"},
{0x1023, 0x9750, 0x1014, 0x9750, "3DImage 9750(0x1014-0x9750)"},
{0x1023, 0x9750, 0x1023, 0x9750, "3DImage 9750(0x1023-0x9750)"},
{0x1023, 0x9753, 0xFFFF, 0xFFFF, "TGUI 9753(0x9753)"},
{0x1023, 0x9754, 0xFFFF, 0xFFFF, "TGUI 9754(0x9754)"},
{0x1023, 0x9759, 0xFFFF, 0xFFFF, "TGUI 975(0x9759)"},
{0x1023, 0x9783, 0xFFFF, 0xFFFF, "TGUI 9783(0x9783)"},
{0x1023, 0x9785, 0xFFFF, 0xFFFF, "TGUI 9785(0x9785)"},
{0x1023, 0x9850, 0xFFFF, 0xFFFF, "3DImage 9850(0x9850)"},
{0x1023, 0x9880, 0xFFFF, 0xFFFF, "Blade 3D PCI/AGP(0x9880)"},
{0x1023, 0x9880, 0x1023, 0x9880, "Blade 3D(0x1023-0x9880)"},
{0x1023, 0x9910, 0xFFFF, 0xFFFF, "CyberBlade/XP(0x9910)"},
{0x1023, 0x9930, 0xFFFF, 0xFFFF, "CyberBlade/XPm(0x9930)"},
{0x1023, 0x9960, 0xFFFF, 0xFFFF, "CyberBlade XP2(0x9960)"},
}; /* pci_vid_1023[] */

static pci_id_t const pci_vid_1024[] = {
{0x1024, 0xFFFF, 0xFFFF, 0xFFFF, "Beijing Dajia Internet Information Technology Co.(0x1024)"},
{0x1024, 0x0101, 0xFFFF, 0xFFFF, "StreamLake 200 AI-VPU(0x0101)"},
{0x1024, 0x0101, 0x1024, 0x0201, "SL200-NP(0x1024-0x0201)"},
{0x1024, 0x0101, 0x1024, 0x0301, "SL200-P(0x1024-0x0301)"},
}; /* pci_vid_1024[] */

static pci_id_t const pci_vid_1025[] = {
{0x1025, 0xFFFF, 0xFFFF, 0xFFFF, "Acer Incorporated [ALI](0x1025)"},
{0x1025, 0x1435, 0xFFFF, 0xFFFF, "M1435(0x1435)"},
{0x1025, 0x1445, 0xFFFF, 0xFFFF, "M1445(0x1445)"},
{0x1025, 0x1449, 0xFFFF, 0xFFFF, "M1449(0x1449)"},
{0x1025, 0x1451, 0xFFFF, 0xFFFF, "M1451(0x1451)"},
{0x1025, 0x1461, 0xFFFF, 0xFFFF, "M1461(0x1461)"},
{0x1025, 0x1489, 0xFFFF, 0xFFFF, "M1489(0x1489)"},
{0x1025, 0x1511, 0xFFFF, 0xFFFF, "M1511(0x1511)"},
{0x1025, 0x1512, 0xFFFF, 0xFFFF, "ALI M1512 Aladdin(0x1512)"},
{0x1025, 0x1513, 0xFFFF, 0xFFFF, "M1513(0x1513)"},
{0x1025, 0x1521, 0xFFFF, 0xFFFF, "ALI M1521 Aladdin III CPU Bridge(0x1521)"},
{0x1025, 0x1521, 0x10B9, 0x1521, "ALI M1521 Aladdin III CPU Bridge(0x10B9-0x1521)"},
{0x1025, 0x1523, 0xFFFF, 0xFFFF, "ALI M1523 ISA Bridge(0x1523)"},
{0x1025, 0x1523, 0x10B9, 0x1523, "ALI M1523 ISA Bridge(0x10B9-0x1523)"},
{0x1025, 0x1531, 0xFFFF, 0xFFFF, "M1531 Northbridge [Aladdin IV/IV+](0x1531)"},
{0x1025, 0x1533, 0xFFFF, 0xFFFF, "M1533 PCI-to-ISA Bridge(0x1533)"},
{0x1025, 0x1533, 0x10B9, 0x1533, "ALI M1533 Aladdin IV/V ISA South Bridge(0x10B9-0x1533)"},
{0x1025, 0x1535, 0xFFFF, 0xFFFF, "M1535 PCI Bridge + Super I/O + FIR(0x1535)"},
{0x1025, 0x1541, 0xFFFF, 0xFFFF, "M1541 Northbridge [Aladdin V](0x1541)"},
{0x1025, 0x1541, 0x10B9, 0x1541, "ALI M1541 Aladdin V/V+ AGP+PCI North Bridge(0x10B9-0x1541)"},
{0x1025, 0x1542, 0xFFFF, 0xFFFF, "M1542 Northbridge [Aladdin V](0x1542)"},
{0x1025, 0x1543, 0xFFFF, 0xFFFF, "M1543 PCI-to-ISA Bridge + Super I/O + FIR(0x1543)"},
{0x1025, 0x1561, 0xFFFF, 0xFFFF, "M1561 Northbridge [Aladdin 7](0x1561)"},
{0x1025, 0x1621, 0xFFFF, 0xFFFF, "M1621 Northbridge [Aladdin-Pro II](0x1621)"},
{0x1025, 0x1631, 0xFFFF, 0xFFFF, "M1631 Northbridge+3D Graphics [Aladdin TNT2](0x1631)"},
{0x1025, 0x1641, 0xFFFF, 0xFFFF, "M1641 Northbridge [Aladdin-Pro IV](0x1641)"},
{0x1025, 0x1647, 0xFFFF, 0xFFFF, "M1647 [MaGiK1] PCI North Bridge(0x1647)"},
{0x1025, 0x1671, 0xFFFF, 0xFFFF, "M1671 Northbridge [ALADDiN-P4](0x1671)"},
{0x1025, 0x1672, 0xFFFF, 0xFFFF, "Northbridge [CyberALADDiN-P4](0x1672)"},
{0x1025, 0x3141, 0xFFFF, 0xFFFF, "M3141(0x3141)"},
{0x1025, 0x3143, 0xFFFF, 0xFFFF, "M3143(0x3143)"},
{0x1025, 0x3145, 0xFFFF, 0xFFFF, "M3145(0x3145)"},
{0x1025, 0x3147, 0xFFFF, 0xFFFF, "M3147(0x3147)"},
{0x1025, 0x3149, 0xFFFF, 0xFFFF, "M3149(0x3149)"},
{0x1025, 0x3151, 0xFFFF, 0xFFFF, "M3151(0x3151)"},
{0x1025, 0x3307, 0xFFFF, 0xFFFF, "M3307 MPEG-I Video Controller(0x3307)"},
{0x1025, 0x3309, 0xFFFF, 0xFFFF, "M3309 MPEG-II Video w/ Software Audio Decoder(0x3309)"},
{0x1025, 0x3321, 0xFFFF, 0xFFFF, "M3321 MPEG-II Audio/Video Decoder(0x3321)"},
{0x1025, 0x5212, 0xFFFF, 0xFFFF, "M4803(0x5212)"},
{0x1025, 0x5215, 0xFFFF, 0xFFFF, "ALI PCI EIDE Controller(0x5215)"},
{0x1025, 0x5217, 0xFFFF, 0xFFFF, "M5217H(0x5217)"},
{0x1025, 0x5219, 0xFFFF, 0xFFFF, "M5219(0x5219)"},
{0x1025, 0x5225, 0xFFFF, 0xFFFF, "M5225(0x5225)"},
{0x1025, 0x5229, 0xFFFF, 0xFFFF, "M5229(0x5229)"},
{0x1025, 0x5235, 0xFFFF, 0xFFFF, "M5235(0x5235)"},
{0x1025, 0x5237, 0xFFFF, 0xFFFF, "M5237 PCI USB Host Controller(0x5237)"},
{0x1025, 0x5240, 0xFFFF, 0xFFFF, "EIDE Controller(0x5240)"},
{0x1025, 0x5241, 0xFFFF, 0xFFFF, "PCMCIA Bridge(0x5241)"},
{0x1025, 0x5242, 0xFFFF, 0xFFFF, "General Purpose Controller(0x5242)"},
{0x1025, 0x5243, 0xFFFF, 0xFFFF, "PCI to PCI Bridge Controller(0x5243)"},
{0x1025, 0x5244, 0xFFFF, 0xFFFF, "Floppy Disk Controller(0x5244)"},
{0x1025, 0x5247, 0xFFFF, 0xFFFF, "M1541 PCI to PCI Bridge(0x5247)"},
{0x1025, 0x5251, 0xFFFF, 0xFFFF, "M5251 P1394 Controller(0x5251)"},
{0x1025, 0x5427, 0xFFFF, 0xFFFF, "PCI to AGP Bridge(0x5427)"},
{0x1025, 0x5451, 0xFFFF, 0xFFFF, "M5451 PCI AC-Link Controller Audio Device(0x5451)"},
{0x1025, 0x5453, 0xFFFF, 0xFFFF, "M5453 PCI AC-Link Controller Modem Device(0x5453)"},
{0x1025, 0x7101, 0xFFFF, 0xFFFF, "M7101 PCI PMU Power Management Controller(0x7101)"},
{0x1025, 0x7101, 0x10B9, 0x7101, "M7101 PCI PMU Power Management Controller(0x10B9-0x7101)"},
{0x1025, 0x9602, 0xFFFF, 0xFFFF, "AMD RS780/RS880 PCI to PCI bridge (int gfx)(0x9602)"},
}; /* pci_vid_1025[] */

static pci_id_t const pci_vid_1028[] = {
{0x1028, 0xFFFF, 0xFFFF, 0xFFFF, "Dell(0x1028)"},
{0x1028, 0x0001, 0xFFFF, 0xFFFF, "PowerEdge Expandable RAID Controller 2/Si(0x0001)"},
{0x1028, 0x0001, 0x1028, 0x0001, "PowerEdge 2400(0x1028-0x0001)"},
{0x1028, 0x0002, 0xFFFF, 0xFFFF, "PowerEdge Expandable RAID Controller 3/Di(0x0002)"},
{0x1028, 0x0002, 0x1028, 0x0002, "PowerEdge 4400(0x1028-0x0002)"},
{0x1028, 0x0002, 0x1028, 0x00D1, "PERC 3/DiV [Viper](0x1028-0x00D1)"},
{0x1028, 0x0002, 0x1028, 0x00D9, "PERC 3/DiL [Lexus](0x1028-0x00D9)"},
{0x1028, 0x0003, 0xFFFF, 0xFFFF, "PowerEdge Expandable RAID Controller 3/Si(0x0003)"},
{0x1028, 0x0003, 0x1028, 0x0003, "PowerEdge 2450(0x1028-0x0003)"},
{0x1028, 0x0004, 0xFFFF, 0xFFFF, "PowerEdge Expandable RAID Controller 3/Di [Iguana](0x0004)"},
{0x1028, 0x0004, 0x1028, 0x0004, "PERC 3/DiF [Iguana](0x1028-0x0004)"},
{0x1028, 0x0006, 0xFFFF, 0xFFFF, "PowerEdge Expandable RAID Controller 3/Di(0x0006)"},
{0x1028, 0x0007, 0xFFFF, 0xFFFF, "Remote Access Card III(0x0007)"},
{0x1028, 0x0008, 0xFFFF, 0xFFFF, "Remote Access Card III(0x0008)"},
{0x1028, 0x0009, 0xFFFF, 0xFFFF, "Remote Access Card III: BMC/SMIC device not present(0x0009)"},
{0x1028, 0x000A, 0xFFFF, 0xFFFF, "PowerEdge Expandable RAID Controller 3/Di(0x000A)"},
{0x1028, 0x000A, 0x1028, 0x0106, "PERC 3/DiJ [Jaguar](0x1028-0x0106)"},
{0x1028, 0x000A, 0x1028, 0x011B, "PERC 3/DiD [Dagger](0x1028-0x011B)"},
{0x1028, 0x000A, 0x1028, 0x0121, "PERC 3/DiB [Boxster](0x1028-0x0121)"},
{0x1028, 0x000C, 0xFFFF, 0xFFFF, "Embedded Remote Access or ERA/O(0x000C)"},
{0x1028, 0x000D, 0xFFFF, 0xFFFF, "Embedded Remote Access: BMC/SMIC device(0x000D)"},
{0x1028, 0x000E, 0xFFFF, 0xFFFF, "PowerEdge Expandable RAID controller 4/Di(0x000E)"},
{0x1028, 0x000F, 0xFFFF, 0xFFFF, "PowerEdge Expandable RAID controller 4/Di(0x000F)"},
{0x1028, 0x000F, 0x1028, 0x014A, "PowerEdge 1750(0x1028-0x014A)"},
{0x1028, 0x0010, 0xFFFF, 0xFFFF, "Remote Access Card 4(0x0010)"},
{0x1028, 0x0011, 0xFFFF, 0xFFFF, "Remote Access Card 4 Daughter Card(0x0011)"},
{0x1028, 0x0012, 0xFFFF, 0xFFFF, "Remote Access Card 4 Daughter Card Virtual UART(0x0012)"},
{0x1028, 0x0013, 0xFFFF, 0xFFFF, "PowerEdge Expandable RAID controller 4(0x0013)"},
{0x1028, 0x0013, 0x1028, 0x016C, "PowerEdge Expandable RAID Controller 4e/Si(0x1028-0x016C)"},
{0x1028, 0x0013, 0x1028, 0x016D, "PowerEdge Expandable RAID Controller 4e/Di(0x1028-0x016D)"},
{0x1028, 0x0013, 0x1028, 0x016E, "PowerEdge Expandable RAID Controller 4e/Di(0x1028-0x016E)"},
{0x1028, 0x0013, 0x1028, 0x016F, "PowerEdge Expandable RAID Controller 4e/Di(0x1028-0x016F)"},
{0x1028, 0x0013, 0x1028, 0x0170, "PowerEdge Expandable RAID Controller 4e/Di(0x1028-0x0170)"},
{0x1028, 0x0014, 0xFFFF, 0xFFFF, "Remote Access Card 4 Daughter Card SMIC interface(0x0014)"},
{0x1028, 0x0015, 0xFFFF, 0xFFFF, "PowerEdge Expandable RAID controller 5(0x0015)"},
{0x1028, 0x0015, 0x1028, 0x1F01, "PERC 5/E Adapter RAID Controller(0x1028-0x1F01)"},
{0x1028, 0x0015, 0x1028, 0x1F02, "PERC 5/i Adapter RAID Controller(0x1028-0x1F02)"},
{0x1028, 0x0015, 0x1028, 0x1F03, "PERC 5/i Integrated RAID Controller(0x1028-0x1F03)"},
{0x1028, 0x0016, 0xFFFF, 0xFFFF, "PowerEdge Expandable RAID controller S300(0x0016)"},
{0x1028, 0x0016, 0x1028, 0x1F24, "PERC S300 Controller(0x1028-0x1F24)"},
{0x1028, 0x0073, 0xFFFF, 0xFFFF, "NV-RAM Adapter(0x0073)"},
{0x1028, 0x1028, 0xFFFF, 0xFFFF, "PCIe Bridge riser(0x1028)"},
{0x1028, 0x2600, 0xFFFF, 0xFFFF, "ENT NVMe RT1(0x2600)"},
{0x1028, 0x2600, 0x1028, 0x215E, "ENT NVMe RT1 RI 3.84TB(0x1028-0x215E)"},
{0x1028, 0x2600, 0x1028, 0x215F, "ENT NVMe RT1 RI 7.68TB(0x1028-0x215F)"},
{0x1028, 0x2600, 0x1028, 0x2160, "ENT NVMe RT1 FIPS RI 3.84TB(0x1028-0x2160)"},
{0x1028, 0x2600, 0x1028, 0x2161, "ENT NVMe RT1 FIPS RI 7.68TB(0x1028-0x2161)"},
{0x1028, 0x9602, 0xFFFF, 0xFFFF, "RS780/RS880 PCI to PCI bridge (int gfx)(0x9602)"},
}; /* pci_vid_1028[] */

static pci_id_t const pci_vid_1029[] = {
{0x1029, 0xFFFF, 0xFFFF, 0xFFFF, "Siemens Nixdorf IS(0x1029)"},
}; /* pci_vid_1029[] */

static pci_id_t const pci_vid_102A[] = {
{0x102A, 0xFFFF, 0xFFFF, 0xFFFF, "LSI Logic(0x102A)"},
{0x102A, 0x0000, 0xFFFF, 0xFFFF, "HYDRA(0x0000)"},
{0x102A, 0x0010, 0xFFFF, 0xFFFF, "ASPEN(0x0010)"},
{0x102A, 0x001F, 0xFFFF, 0xFFFF, "AHA-2940U2/U2W /7890/7891 SCSI Controllers(0x001F)"},
{0x102A, 0x001F, 0x9005, 0x000F, "2940U2W SCSI Controller(0x9005-0x000F)"},
{0x102A, 0x001F, 0x9005, 0x0106, "2940U2W SCSI Controller(0x9005-0x0106)"},
{0x102A, 0x001F, 0x9005, 0xA180, "2940U2W SCSI Controller(0x9005-0xA180)"},
{0x102A, 0x00C5, 0xFFFF, 0xFFFF, "AIC-7899 U160/m SCSI Controller(0x00C5)"},
{0x102A, 0x00C5, 0x1028, 0x00C5, "PowerEdge 2550/2650/4600(0x1028-0x00C5)"},
{0x102A, 0x00CF, 0xFFFF, 0xFFFF, "AIC-7899P U160/m(0x00CF)"},
{0x102A, 0x00CF, 0x1028, 0x0106, "PowerEdge 4600(0x1028-0x0106)"},
{0x102A, 0x00CF, 0x1028, 0x0121, "PowerEdge 2650(0x1028-0x0121)"},
}; /* pci_vid_102A[] */

static pci_id_t const pci_vid_102B[] = {
{0x102B, 0xFFFF, 0xFFFF, 0xFFFF, "Matrox Electronics Systems Ltd.(0x102B)"},
{0x102B, 0x0010, 0xFFFF, 0xFFFF, "MGA-I [Impression?-](0x0010)"},
{0x102B, 0x0100, 0xFFFF, 0xFFFF, "MGA 1064SG [Mystique](0x0100)"},
{0x102B, 0x0518, 0xFFFF, 0xFFFF, "MGA-II [Athena](0x0518)"},
{0x102B, 0x0519, 0xFFFF, 0xFFFF, "MGA 2064W [Millennium](0x0519)"},
{0x102B, 0x051A, 0xFFFF, 0xFFFF, "MGA 1064SG [Mystique](0x051A)"},
{0x102B, 0x051A, 0x102B, 0x0100, "MGA-1064SG Mystique(0x102B-0x0100)"},
{0x102B, 0x051A, 0x102B, 0x051A, "MGA-1164SG Mystique 220(0x102B-0x051A)"},
{0x102B, 0x051A, 0x102B, 0x1100, "MGA-1084SG Mystique(0x102B-0x1100)"},
{0x102B, 0x051A, 0x102B, 0x1200, "MGA-1084SG Mystique(0x102B-0x1200)"},
{0x102B, 0x051A, 0x1100, 0x102B, "MGA-1084SG Mystique(0x1100-0x102B)"},
{0x102B, 0x051A, 0x110A, 0x0018, "Scenic Pro C5 (D1025)(0x110A-0x0018)"},
{0x102B, 0x051B, 0xFFFF, 0xFFFF, "MGA 2164W [Millennium II](0x051B)"},
{0x102B, 0x051B, 0x102B, 0x051B, "MGA-2164W Millennium II(0x102B-0x051B)"},
{0x102B, 0x051B, 0x102B, 0x1100, "MGA-2164W Millennium II(0x102B-0x1100)"},
{0x102B, 0x051B, 0x102B, 0x1200, "MGA-2164W Millennium II(0x102B-0x1200)"},
{0x102B, 0x051B, 0x102B, 0x2100, "MGA-2164W Millennium II(0x102B-0x2100)"},
{0x102B, 0x051E, 0xFFFF, 0xFFFF, "MGA 1064SG [Mystique] AGP(0x051E)"},
{0x102B, 0x051F, 0xFFFF, 0xFFFF, "MGA 2164W [Millennium II] AGP(0x051F)"},
{0x102B, 0x051F, 0x102B, 0x2100, "MGA-2164WA [Millennium II A](0x102B-0x2100)"},
{0x102B, 0x0520, 0xFFFF, 0xFFFF, "MGA G200(0x0520)"},
{0x102B, 0x0520, 0x102B, 0xDBC2, "G200 Multi-Monitor(0x102B-0xDBC2)"},
{0x102B, 0x0520, 0x102B, 0xDBC8, "G200 Multi-Monitor(0x102B-0xDBC8)"},
{0x102B, 0x0520, 0x102B, 0xDBE2, "G200 Multi-Monitor(0x102B-0xDBE2)"},
{0x102B, 0x0520, 0x102B, 0xDBE8, "G200 Multi-Monitor(0x102B-0xDBE8)"},
{0x102B, 0x0520, 0x102B, 0xFF03, "Millennium G200 SD(0x102B-0xFF03)"},
{0x102B, 0x0520, 0x102B, 0xFF04, "Marvel G200(0x102B-0xFF04)"},
{0x102B, 0x0521, 0xFFFF, 0xFFFF, "MGA G200 AGP(0x0521)"},
{0x102B, 0x0521, 0x1014, 0xFF03, "Millennium G200 AGP(0x1014-0xFF03)"},
{0x102B, 0x0521, 0x102B, 0x48E9, "Mystique G200 AGP(0x102B-0x48E9)"},
{0x102B, 0x0521, 0x102B, 0x48F8, "Millennium G200 SD AGP(0x102B-0x48F8)"},
{0x102B, 0x0521, 0x102B, 0x4A60, "Millennium G200 LE AGP(0x102B-0x4A60)"},
{0x102B, 0x0521, 0x102B, 0x4A64, "Millennium G200 AGP(0x102B-0x4A64)"},
{0x102B, 0x0521, 0x102B, 0xC93C, "Millennium G200 AGP(0x102B-0xC93C)"},
{0x102B, 0x0521, 0x102B, 0xC9B0, "Millennium G200 AGP(0x102B-0xC9B0)"},
{0x102B, 0x0521, 0x102B, 0xC9BC, "Millennium G200 AGP(0x102B-0xC9BC)"},
{0x102B, 0x0521, 0x102B, 0xCA60, "Millennium G250 LE AGP(0x102B-0xCA60)"},
{0x102B, 0x0521, 0x102B, 0xCA6C, "Millennium G250 AGP(0x102B-0xCA6C)"},
{0x102B, 0x0521, 0x102B, 0xDBBC, "Millennium G200 AGP(0x102B-0xDBBC)"},
{0x102B, 0x0521, 0x102B, 0xDBC2, "Millennium G200 MMS (Dual G200)(0x102B-0xDBC2)"},
{0x102B, 0x0521, 0x102B, 0xDBC3, "G200 Multi-Monitor(0x102B-0xDBC3)"},
{0x102B, 0x0521, 0x102B, 0xDBC8, "Millennium G200 MMS (Dual G200)(0x102B-0xDBC8)"},
{0x102B, 0x0521, 0x102B, 0xDBD2, "G200 Multi-Monitor(0x102B-0xDBD2)"},
{0x102B, 0x0521, 0x102B, 0xDBD3, "G200 Multi-Monitor(0x102B-0xDBD3)"},
{0x102B, 0x0521, 0x102B, 0xDBD4, "G200 Multi-Monitor(0x102B-0xDBD4)"},
{0x102B, 0x0521, 0x102B, 0xDBD5, "G200 Multi-Monitor(0x102B-0xDBD5)"},
{0x102B, 0x0521, 0x102B, 0xDBD8, "G200 Multi-Monitor(0x102B-0xDBD8)"},
{0x102B, 0x0521, 0x102B, 0xDBD9, "G200 Multi-Monitor(0x102B-0xDBD9)"},
{0x102B, 0x0521, 0x102B, 0xDBE2, "Millennium G200 MMS (Quad G200)(0x102B-0xDBE2)"},
{0x102B, 0x0521, 0x102B, 0xDBE3, "G200 Multi-Monitor(0x102B-0xDBE3)"},
{0x102B, 0x0521, 0x102B, 0xDBE8, "Millennium G200 MMS (Quad G200)(0x102B-0xDBE8)"},
{0x102B, 0x0521, 0x102B, 0xDBF2, "G200 Multi-Monitor(0x102B-0xDBF2)"},
{0x102B, 0x0521, 0x102B, 0xDBF3, "G200 Multi-Monitor(0x102B-0xDBF3)"},
{0x102B, 0x0521, 0x102B, 0xDBF4, "G200 Multi-Monitor(0x102B-0xDBF4)"},
{0x102B, 0x0521, 0x102B, 0xDBF5, "G200 Multi-Monitor(0x102B-0xDBF5)"},
{0x102B, 0x0521, 0x102B, 0xDBF8, "G200 Multi-Monitor(0x102B-0xDBF8)"},
{0x102B, 0x0521, 0x102B, 0xDBF9, "G200 Multi-Monitor(0x102B-0xDBF9)"},
{0x102B, 0x0521, 0x102B, 0xF806, "Mystique G200 Video AGP(0x102B-0xF806)"},
{0x102B, 0x0521, 0x102B, 0xFF00, "MGA-G200 AGP(0x102B-0xFF00)"},
{0x102B, 0x0521, 0x102B, 0xFF02, "Mystique G200 AGP(0x102B-0xFF02)"},
{0x102B, 0x0521, 0x102B, 0xFF03, "Millennium G200A AGP(0x102B-0xFF03)"},
{0x102B, 0x0521, 0x102B, 0xFF04, "Marvel G200 AGP(0x102B-0xFF04)"},
{0x102B, 0x0521, 0x110A, 0x0032, "MGA-G200 AGP(0x110A-0x0032)"},
{0x102B, 0x0522, 0xFFFF, 0xFFFF, "MGA G200e [Pilot] ServerEngines (SEP1)(0x0522)"},
{0x102B, 0x0522, 0x103C, 0x31FA, "ProLiant DL140 G3(0x103C-0x31FA)"},
{0x102B, 0x0525, 0xFFFF, 0xFFFF, "MGA G400/G450(0x0525)"},
{0x102B, 0x0525, 0x0E11, 0xB16F, "MGA-G400 AGP(0x0E11-0xB16F)"},
{0x102B, 0x0525, 0x102B, 0x0328, "Millennium G400 16Mb SDRAM(0x102B-0x0328)"},
{0x102B, 0x0525, 0x102B, 0x0338, "Millennium G400 16Mb SDRAM(0x102B-0x0338)"},
{0x102B, 0x0525, 0x102B, 0x0378, "Millennium G400 32Mb SDRAM(0x102B-0x0378)"},
{0x102B, 0x0525, 0x102B, 0x0541, "Millennium G450 Dual Head(0x102B-0x0541)"},
{0x102B, 0x0525, 0x102B, 0x0542, "Millennium G450 Dual Head LX(0x102B-0x0542)"},
{0x102B, 0x0525, 0x102B, 0x0543, "Millennium G450 Single Head LX(0x102B-0x0543)"},
{0x102B, 0x0525, 0x102B, 0x0641, "Millennium G450 32Mb SDRAM Dual Head(0x102B-0x0641)"},
{0x102B, 0x0525, 0x102B, 0x0642, "Millennium G450 32Mb SDRAM Dual Head LX(0x102B-0x0642)"},
{0x102B, 0x0525, 0x102B, 0x0643, "Millennium G450 32Mb SDRAM Single Head LX(0x102B-0x0643)"},
{0x102B, 0x0525, 0x102B, 0x07C0, "Millennium G450 Dual Head LE(0x102B-0x07C0)"},
{0x102B, 0x0525, 0x102B, 0x07C1, "Millennium G450 SDR Dual Head LE(0x102B-0x07C1)"},
{0x102B, 0x0525, 0x102B, 0x0D41, "Millennium G450 Dual Head PCI(0x102B-0x0D41)"},
{0x102B, 0x0525, 0x102B, 0x0D42, "Millennium G450 Dual Head LX PCI(0x102B-0x0D42)"},
{0x102B, 0x0525, 0x102B, 0x0D43, "Millennium G450 32Mb Dual Head PCI(0x102B-0x0D43)"},
{0x102B, 0x0525, 0x102B, 0x0E00, "Marvel G450 eTV(0x102B-0x0E00)"},
{0x102B, 0x0525, 0x102B, 0x0E01, "Marvel G450 eTV(0x102B-0x0E01)"},
{0x102B, 0x0525, 0x102B, 0x0E02, "Marvel G450 eTV(0x102B-0x0E02)"},
{0x102B, 0x0525, 0x102B, 0x0E03, "Marvel G450 eTV(0x102B-0x0E03)"},
{0x102B, 0x0525, 0x102B, 0x0F80, "Millennium G450 Low Profile(0x102B-0x0F80)"},
{0x102B, 0x0525, 0x102B, 0x0F81, "Millennium G450 Low Profile(0x102B-0x0F81)"},
{0x102B, 0x0525, 0x102B, 0x0F82, "Millennium G450 Low Profile DVI(0x102B-0x0F82)"},
{0x102B, 0x0525, 0x102B, 0x0F83, "Millennium G450 Low Profile DVI(0x102B-0x0F83)"},
{0x102B, 0x0525, 0x102B, 0x19D8, "Millennium G400 16Mb SGRAM(0x102B-0x19D8)"},
{0x102B, 0x0525, 0x102B, 0x19F8, "Millennium G400 32Mb SGRAM(0x102B-0x19F8)"},
{0x102B, 0x0525, 0x102B, 0x2159, "Millennium G400 Dual Head 16Mb(0x102B-0x2159)"},
{0x102B, 0x0525, 0x102B, 0x2179, "Millennium G400 MAX/Dual Head 32Mb(0x102B-0x2179)"},
{0x102B, 0x0525, 0x102B, 0x217D, "Millennium G400 Dual Head Max(0x102B-0x217D)"},
{0x102B, 0x0525, 0x102B, 0x23C0, "Millennium G450(0x102B-0x23C0)"},
{0x102B, 0x0525, 0x102B, 0x23C1, "Millennium G450(0x102B-0x23C1)"},
{0x102B, 0x0525, 0x102B, 0x23C2, "Millennium G450 DVI(0x102B-0x23C2)"},
{0x102B, 0x0525, 0x102B, 0x23C3, "Millennium G450 DVI(0x102B-0x23C3)"},
{0x102B, 0x0525, 0x102B, 0x2F58, "Millennium G400(0x102B-0x2F58)"},
{0x102B, 0x0525, 0x102B, 0x2F78, "Millennium G400(0x102B-0x2F78)"},
{0x102B, 0x0525, 0x102B, 0x3693, "Marvel G400 AGP(0x102B-0x3693)"},
{0x102B, 0x0525, 0x102B, 0x5DD0, "4Sight II(0x102B-0x5DD0)"},
{0x102B, 0x0525, 0x102B, 0x5F50, "4Sight II(0x102B-0x5F50)"},
{0x102B, 0x0525, 0x102B, 0x5F51, "4Sight II(0x102B-0x5F51)"},
{0x102B, 0x0525, 0x102B, 0x5F52, "4Sight II(0x102B-0x5F52)"},
{0x102B, 0x0525, 0x102B, 0x9010, "Millennium G400 Dual Head(0x102B-0x9010)"},
{0x102B, 0x0525, 0x1458, 0x0400, "GA-G400(0x1458-0x0400)"},
{0x102B, 0x0525, 0x1705, 0x0001, "Millennium G450 32MB SGRAM(0x1705-0x0001)"},
{0x102B, 0x0525, 0x1705, 0x0002, "Millennium G450 16MB SGRAM(0x1705-0x0002)"},
{0x102B, 0x0525, 0x1705, 0x0003, "Millennium G450 32MB(0x1705-0x0003)"},
{0x102B, 0x0525, 0x1705, 0x0004, "Millennium G450 16MB(0x1705-0x0004)"},
{0x102B, 0x0527, 0xFFFF, 0xFFFF, "Parhelia(0x0527)"},
{0x102B, 0x0527, 0x102B, 0x0840, "Parhelia 128Mb(0x102B-0x0840)"},
{0x102B, 0x0527, 0x102B, 0x0850, "Parhelia 256MB(0x102B-0x0850)"},
{0x102B, 0x0527, 0x102B, 0x0870, "MED2mp-DVI(0x102B-0x0870)"},
{0x102B, 0x0527, 0x102B, 0x0880, "P-256 Edge Overlap Controller(0x102B-0x0880)"},
{0x102B, 0x0528, 0xFFFF, 0xFFFF, "Parhelia(0x0528)"},
{0x102B, 0x0528, 0x102B, 0x1020, "Parhelia 128MB(0x102B-0x1020)"},
{0x102B, 0x0528, 0x102B, 0x1030, "Parhelia 256 MB Dual DVI(0x102B-0x1030)"},
{0x102B, 0x0528, 0x102B, 0x1040, "MED2mp-DVI(0x102B-0x1040)"},
{0x102B, 0x0528, 0x102B, 0x1050, "Sono S20(0x102B-0x1050)"},
{0x102B, 0x0528, 0x102B, 0x1060, "PJ-30L(0x102B-0x1060)"},
{0x102B, 0x0528, 0x102B, 0x1070, "PJ-40L(0x102B-0x1070)"},
{0x102B, 0x0528, 0x102B, 0x1421, "MED5mp(0x102B-0x1421)"},
{0x102B, 0x0528, 0x102B, 0x1431, "MED3mp-DVI(0x102B-0x1431)"},
{0x102B, 0x0528, 0x102B, 0x1451, "MED5mp-DVI(0x102B-0x1451)"},
{0x102B, 0x0528, 0x102B, 0x1491, "MED2mp-DVI(0x102B-0x1491)"},
{0x102B, 0x0528, 0x102B, 0x14B1, "MED3mp-DVI(0x102B-0x14B1)"},
{0x102B, 0x0528, 0x102B, 0x14C1, "MED5mp-DVI(0x102B-0x14C1)"},
{0x102B, 0x0528, 0x102B, 0x14E1, "Parhelia PCI 256MB(0x102B-0x14E1)"},
{0x102B, 0x0528, 0x102B, 0x14F1, "Parhelia Precision SGT(0x102B-0x14F1)"},
{0x102B, 0x0528, 0x102B, 0x1501, "ATC-4MP(0x102B-0x1501)"},
{0x102B, 0x0528, 0x102B, 0x1511, "ATC-4MP(0x102B-0x1511)"},
{0x102B, 0x0528, 0x102B, 0x1521, "TheatreVUE T30(0x102B-0x1521)"},
{0x102B, 0x0528, 0x102B, 0x1531, "TheatreVUE T20(0x102B-0x1531)"},
{0x102B, 0x0528, 0x102B, 0x1541, "MED2mp-DVI(0x102B-0x1541)"},
{0x102B, 0x0528, 0x102B, 0x1551, "MED3mp-DVI(0x102B-0x1551)"},
{0x102B, 0x0528, 0x102B, 0x1561, "MED5mp-DVI(0x102B-0x1561)"},
{0x102B, 0x0528, 0x102B, 0x1571, "Parhelia DL256 PCI(0x102B-0x1571)"},
{0x102B, 0x0528, 0x102B, 0x1591, "Parhelia Precision SDT(0x102B-0x1591)"},
{0x102B, 0x0528, 0x102B, 0x15A1, "MED4mp-DVI(0x102B-0x15A1)"},
{0x102B, 0x0528, 0x102B, 0x2011, "Parhelia HR256(0x102B-0x2011)"},
{0x102B, 0x0528, 0x102B, 0x2021, "QID Pro(0x102B-0x2021)"},
{0x102B, 0x0528, 0x102B, 0x2061, "PJ-40LP(0x102B-0x2061)"},
{0x102B, 0x0528, 0x102B, 0x2081, "EWS Quad(0x102B-0x2081)"},
{0x102B, 0x0528, 0x102B, 0x2411, "PPX-OUT8(0x102B-0x2411)"},
{0x102B, 0x0528, 0x102B, 0x2421, "VPX-OUT8(0x102B-0x2421)"},
{0x102B, 0x0528, 0x102B, 0x2441, "PPX-OUT4(0x102B-0x2441)"},
{0x102B, 0x0528, 0x102B, 0x2451, "VPX-OUT4(0x102B-0x2451)"},
{0x102B, 0x0528, 0x102B, 0x2491, "LPX-OUT4(0x102B-0x2491)"},
{0x102B, 0x0530, 0xFFFF, 0xFFFF, "MGA G200EV(0x0530)"},
{0x102B, 0x0532, 0xFFFF, 0xFFFF, "MGA G200eW WPCM450(0x0532)"},
{0x102B, 0x0532, 0x1028, 0x0235, "PowerEdge R710 MGA G200eW WPCM450(0x1028-0x0235)"},
{0x102B, 0x0532, 0x1028, 0x0236, "PowerEdge R610 MGA G200eW WPCM450(0x1028-0x0236)"},
{0x102B, 0x0532, 0x1028, 0x0237, "PowerEdge T610 MGA G200eW WPCM450(0x1028-0x0237)"},
{0x102B, 0x0532, 0x1028, 0x0287, "PowerEdge M610 MGA G200eW WPCM450(0x1028-0x0287)"},
{0x102B, 0x0532, 0x1028, 0x028C, "PowerEdge R410 MGA G200eW WPCM450(0x1028-0x028C)"},
{0x102B, 0x0532, 0x1028, 0x028D, "PowerEdge T410 MGA G200eW WPCM450(0x1028-0x028D)"},
{0x102B, 0x0532, 0x1028, 0x029C, "PowerEdge M710 MGA G200eW WPCM450(0x1028-0x029C)"},
{0x102B, 0x0532, 0x1028, 0x02A4, "PowerEdge T310 MGA G200eW WPCM450(0x1028-0x02A4)"},
{0x102B, 0x0532, 0x15D9, 0x0605, "X8SIL(0x15D9-0x0605)"},
{0x102B, 0x0532, 0x15D9, 0x0624, "X9SCM-F Motherboard(0x15D9-0x0624)"},
{0x102B, 0x0532, 0x15D9, 0x066B, "X9SRL-F(0x15D9-0x066B)"},
{0x102B, 0x0532, 0x15D9, 0xA811, "H8DGU(0x15D9-0xA811)"},
{0x102B, 0x0533, 0xFFFF, 0xFFFF, "MGA G200EH(0x0533)"},
{0x102B, 0x0533, 0x103C, 0x3381, "iLO4(0x103C-0x3381)"},
{0x102B, 0x0534, 0xFFFF, 0xFFFF, "G200eR2(0x0534)"},
{0x102B, 0x0534, 0x1028, 0x04F7, "PowerEdge R320 server(0x1028-0x04F7)"},
{0x102B, 0x0536, 0xFFFF, 0xFFFF, "Integrated Matrox G200eW3 Graphics Controller(0x0536)"},
{0x102B, 0x0538, 0xFFFF, 0xFFFF, "MGA G200eH3(0x0538)"},
{0x102B, 0x0538, 0x1590, 0x00E4, "iLO5 VGA(0x1590-0x00E4)"},
{0x102B, 0x0540, 0xFFFF, 0xFFFF, "M91XX(0x0540)"},
{0x102B, 0x0540, 0x102B, 0x2080, "M9140 LP PCIe x16(0x102B-0x2080)"},
{0x102B, 0x0540, 0x102B, 0x20C0, "Xenia(0x102B-0x20C0)"},
{0x102B, 0x0540, 0x102B, 0x20C1, "Xenia Pro(0x102B-0x20C1)"},
{0x102B, 0x0540, 0x102B, 0x2100, "M9120 PCIe x16(0x102B-0x2100)"},
{0x102B, 0x0540, 0x102B, 0x2140, "M9125 PCIe x16(0x102B-0x2140)"},
{0x102B, 0x0540, 0x102B, 0x2180, "M9120 Plus LP PCIe x16(0x102B-0x2180)"},
{0x102B, 0x0540, 0x102B, 0x21C0, "M9120 Plus LP PCIe x1(0x102B-0x21C0)"},
{0x102B, 0x0540, 0x102B, 0x2200, "VDA1164 Output Board(0x102B-0x2200)"},
{0x102B, 0x0540, 0x102B, 0x2240, "M9148 LP PCIe x16(0x102B-0x2240)"},
{0x102B, 0x0540, 0x102B, 0x2241, "M9138 LP PCIe x16(0x102B-0x2241)"},
{0x102B, 0x0540, 0x102B, 0x2280, "M9188 ATX PCIe x16(0x102B-0x2280)"},
{0x102B, 0x0540, 0x102B, 0x22C0, "M9128 LP PCIe x16(0x102B-0x22C0)"},
{0x102B, 0x0550, 0xFFFF, 0xFFFF, "SV2(0x0550)"},
{0x102B, 0x0550, 0x102B, 0x00C0, "MURA-IPX-I4EF(0x102B-0x00C0)"},
{0x102B, 0x0550, 0x102B, 0x00C1, "MURA-IPX-I4DF(0x102B-0x00C1)"},
{0x102B, 0x0550, 0x102B, 0x00C3, "MURA-IPX-I4DHF(0x102B-0x00C3)"},
{0x102B, 0x0550, 0x102B, 0x00C5, "MURA-IPX-I4EHF(0x102B-0x00C5)"},
{0x102B, 0x0D10, 0xFFFF, 0xFFFF, "MGA Ultima/Impression(0x0D10)"},
{0x102B, 0x1000, 0xFFFF, 0xFFFF, "MGA G100 [Productiva](0x1000)"},
{0x102B, 0x1000, 0x102B, 0xFF01, "Productiva G100(0x102B-0xFF01)"},
{0x102B, 0x1000, 0x102B, 0xFF05, "Productiva G100 Multi-Monitor(0x102B-0xFF05)"},
{0x102B, 0x1001, 0xFFFF, 0xFFFF, "MGA G100 [Productiva] AGP(0x1001)"},
{0x102B, 0x1001, 0x102B, 0x1001, "MGA-G100 AGP(0x102B-0x1001)"},
{0x102B, 0x1001, 0x102B, 0xFF00, "MGA-G100 AGP(0x102B-0xFF00)"},
{0x102B, 0x1001, 0x102B, 0xFF01, "MGA-G100 Productiva AGP(0x102B-0xFF01)"},
{0x102B, 0x1001, 0x102B, 0xFF03, "Millennium G100 AGP(0x102B-0xFF03)"},
{0x102B, 0x1001, 0x102B, 0xFF04, "MGA-G100 AGP(0x102B-0xFF04)"},
{0x102B, 0x1001, 0x102B, 0xFF05, "MGA-G100 Productiva AGP Multi-Monitor(0x102B-0xFF05)"},
{0x102B, 0x1001, 0x110A, 0x001E, "MGA-G100 AGP(0x110A-0x001E)"},
{0x102B, 0x2007, 0xFFFF, 0xFFFF, "MGA Mistral(0x2007)"},
{0x102B, 0x2527, 0xFFFF, 0xFFFF, "Millennium G550(0x2527)"},
{0x102B, 0x2527, 0x102B, 0x0F42, "Matrox G550 Low Profile PCI(0x102B-0x0F42)"},
{0x102B, 0x2527, 0x102B, 0x0F83, "Millennium G550(0x102B-0x0F83)"},
{0x102B, 0x2527, 0x102B, 0x0F84, "Millennium G550 Dual Head DDR 32Mb(0x102B-0x0F84)"},
{0x102B, 0x2527, 0x102B, 0x1E41, "Millennium G550(0x102B-0x1E41)"},
{0x102B, 0x2527, 0x102B, 0x22C0, "G550 PCIe(0x102B-0x22C0)"},
{0x102B, 0x2527, 0x102B, 0x2300, "Millennium G550 LP PCIE(0x102B-0x2300)"},
{0x102B, 0x2537, 0xFFFF, 0xFFFF, "Millennium P650/P750(0x2537)"},
{0x102B, 0x2537, 0x102B, 0x1820, "Millennium P750 64MB(0x102B-0x1820)"},
{0x102B, 0x2537, 0x102B, 0x1830, "Millennium P650 64MB(0x102B-0x1830)"},
{0x102B, 0x2537, 0x102B, 0x1850, "RAD2mp(0x102B-0x1850)"},
{0x102B, 0x2537, 0x102B, 0x1860, "RAD3mp(0x102B-0x1860)"},
{0x102B, 0x2537, 0x102B, 0x1880, "Sono S10(0x102B-0x1880)"},
{0x102B, 0x2537, 0x102B, 0x1C10, "QID 128MB(0x102B-0x1C10)"},
{0x102B, 0x2537, 0x102B, 0x2811, "Millennium P650 Low-profile PCI 64MB(0x102B-0x2811)"},
{0x102B, 0x2537, 0x102B, 0x2821, "Millennium P650 Low-profile PCI(0x102B-0x2821)"},
{0x102B, 0x2537, 0x102B, 0x2841, "RAD PCI(0x102B-0x2841)"},
{0x102B, 0x2537, 0x102B, 0x2851, "Spectrum PCI(0x102B-0x2851)"},
{0x102B, 0x2537, 0x102B, 0x2871, "EpicA TC2(0x102B-0x2871)"},
{0x102B, 0x2537, 0x102B, 0x2C11, "QID Low-profile PCI(0x102B-0x2C11)"},
{0x102B, 0x2537, 0x102B, 0x2C21, "QID LP PCI LW(0x102B-0x2C21)"},
{0x102B, 0x2537, 0x102B, 0x2C31, "QID LP PCI(0x102B-0x2C31)"},
{0x102B, 0x2537, 0x102B, 0x2C41, "EpicA TC4(0x102B-0x2C41)"},
{0x102B, 0x2537, 0x102B, 0x3001, "Extio F1400(0x102B-0x3001)"},
{0x102B, 0x2537, 0x102B, 0x3011, "Extio F1220(0x102B-0x3011)"},
{0x102B, 0x2537, 0x102B, 0x3041, "RG-200DL(0x102B-0x3041)"},
{0x102B, 0x2537, 0x102B, 0x3051, "RG-400SL(0x102B-0x3051)"},
{0x102B, 0x2537, 0x102B, 0x3061, "Extio F1420(0x102B-0x3061)"},
{0x102B, 0x2537, 0x102B, 0x3081, "Extio F1240(0x102B-0x3081)"},
{0x102B, 0x2538, 0xFFFF, 0xFFFF, "Millennium P650 PCIe(0x2538)"},
{0x102B, 0x2538, 0x102B, 0x0847, "RAD PCIe(0x102B-0x0847)"},
{0x102B, 0x2538, 0x102B, 0x08C7, "Millennium P650 PCIe 128MB(0x102B-0x08C7)"},
{0x102B, 0x2538, 0x102B, 0x0907, "Millennium P650 PCIe 64MB(0x102B-0x0907)"},
{0x102B, 0x2538, 0x102B, 0x0947, "Parhelia APVe(0x102B-0x0947)"},
{0x102B, 0x2538, 0x102B, 0x0987, "ATC PCIe 4MP(0x102B-0x0987)"},
{0x102B, 0x2538, 0x102B, 0x1047, "Millennium P650 LP PCIe 128MB(0x102B-0x1047)"},
{0x102B, 0x2538, 0x102B, 0x1087, "Millennium P650 LP PCIe 64MB(0x102B-0x1087)"},
{0x102B, 0x2538, 0x102B, 0x1801, "Millennium P650 PCIe x1(0x102B-0x1801)"},
{0x102B, 0x2538, 0x102B, 0x2538, "Parhelia APVe(0x102B-0x2538)"},
{0x102B, 0x2538, 0x102B, 0x3007, "QID Low-profile PCIe(0x102B-0x3007)"},
{0x102B, 0x2538, 0x102B, 0x3087, "Aurora VX3mp(0x102B-0x3087)"},
{0x102B, 0x2538, 0x102B, 0x30C7, "QID LP PCIe(0x102B-0x30C7)"},
{0x102B, 0x2539, 0xFFFF, 0xFFFF, "Millennium P690(0x2539)"},
{0x102B, 0x2539, 0x102B, 0x0040, "Millennium P690 PCIe x16(0x102B-0x0040)"},
{0x102B, 0x2539, 0x102B, 0x0042, "ONYX(0x102B-0x0042)"},
{0x102B, 0x2539, 0x102B, 0x0043, "SPECTRA(0x102B-0x0043)"},
{0x102B, 0x2539, 0x102B, 0x0080, "Millennium P690 Plus LP PCIe x16(0x102B-0x0080)"},
{0x102B, 0x2539, 0x102B, 0x0081, "Millennium P690 LP PCIe x16(0x102B-0x0081)"},
{0x102B, 0x2539, 0x102B, 0x0082, "RAD LPX PCIe x16(0x102B-0x0082)"},
{0x102B, 0x2539, 0x102B, 0x00C0, "Millennium P690 Plus LP PCI(0x102B-0x00C0)"},
{0x102B, 0x2539, 0x102B, 0x00C2, "Millennium P690 LP PCI(0x102B-0x00C2)"},
{0x102B, 0x2539, 0x102B, 0x00C3, "RAD LPX PCI(0x102B-0x00C3)"},
{0x102B, 0x2539, 0x102B, 0x0101, "Millennium P690 PCI(0x102B-0x0101)"},
{0x102B, 0x2539, 0x102B, 0x0140, "Millennium P690 LP PCIe x1(0x102B-0x0140)"},
{0x102B, 0x2539, 0x102B, 0x0180, "Display Wall IP Decode 128 MB(0x102B-0x0180)"},
{0x102B, 0x4164, 0xFFFF, 0xFFFF, "Morphis QxT frame grabber(0x4164)"},
{0x102B, 0x43B4, 0xFFFF, 0xFFFF, "Morphis Qxt encoding engine(0x43B4)"},
{0x102B, 0x4510, 0xFFFF, 0xFFFF, "Morphis COM port(0x4510)"},
{0x102B, 0x4536, 0xFFFF, 0xFFFF, "VIA Framegrabber(0x4536)"},
{0x102B, 0x4686, 0xFFFF, 0xFFFF, "Concord GX (customized Intel 82541)(0x4686)"},
{0x102B, 0x475B, 0xFFFF, 0xFFFF, "Solios eCL/XCL-B frame grabber(0x475B)"},
{0x102B, 0x475D, 0xFFFF, 0xFFFF, "Vio frame grabber family(0x475D)"},
{0x102B, 0x475D, 0x102B, 0x4B90, "Vio Duo frame grabber (single channel)(0x102B-0x4B90)"},
{0x102B, 0x475D, 0x102B, 0x4B91, "Vio Duo frame grabber(0x102B-0x4B91)"},
{0x102B, 0x475D, 0x102B, 0x4B92, "Vio Analog frame grabber(0x102B-0x4B92)"},
{0x102B, 0x475D, 0x102B, 0x4B93, "Vio SDI Frame Grabber(0x102B-0x4B93)"},
{0x102B, 0x475D, 0x102B, 0x4B94, "Vio DVI-A frame grabber(0x102B-0x4B94)"},
{0x102B, 0x475F, 0xFFFF, 0xFFFF, "Solios (single-Full) CL frame grabber(0x475F)"},
{0x102B, 0x475F, 0x102B, 0x475F, "Solios eCL/XCL-F frame grabber(0x102B-0x475F)"},
{0x102B, 0x475F, 0x102B, 0x4D5F, "Solios eV-CL (single-Full) frame grabber(0x102B-0x4D5F)"},
{0x102B, 0x475F, 0x102B, 0x4E5F, "Solios eM-CL (single-Full) frame grabber(0x102B-0x4E5F)"},
{0x102B, 0x47A1, 0xFFFF, 0xFFFF, "Solios eA/XA frame grabber(0x47A1)"},
{0x102B, 0x47A1, 0x102B, 0x4BE0, "Solios eA/XA (single) frame grabber(0x102B-0x4BE0)"},
{0x102B, 0x47A1, 0x102B, 0x4BE1, "Solios eA/XA (dual) frame grabber(0x102B-0x4BE1)"},
{0x102B, 0x47A1, 0x102B, 0x4BE2, "Solios eA/XA (quad) frame grabber(0x102B-0x4BE2)"},
{0x102B, 0x47A2, 0xFFFF, 0xFFFF, "Solios COM port(0x47A2)"},
{0x102B, 0x47C1, 0xFFFF, 0xFFFF, "Solios (dual-Base/single-Medium) CL frame grabber(0x47C1)"},
{0x102B, 0x47C1, 0x102B, 0x0000, "Solios frame grabber(0x102B-0x0000)"},
{0x102B, 0x47C1, 0x102B, 0x4B80, "Solios eCL/XCL (single-Medium) frame grabber(0x102B-0x4B80)"},
{0x102B, 0x47C1, 0x102B, 0x4B81, "Solios eCL/XCL (dual-Base) frame grabber(0x102B-0x4B81)"},
{0x102B, 0x47C1, 0x102B, 0x4D80, "Solios eV-CL (single-Medium) frame grabber(0x102B-0x4D80)"},
{0x102B, 0x47C1, 0x102B, 0x4D81, "Solios eV-CL (dual-Base) frame grabber(0x102B-0x4D81)"},
{0x102B, 0x47C1, 0x102B, 0x4E80, "Solios eM-CL (single-Medium) frame grabber(0x102B-0x4E80)"},
{0x102B, 0x47C1, 0x102B, 0x4E81, "Solios eM-CL (dual-Base) frame grabber(0x102B-0x4E81)"},
{0x102B, 0x47C2, 0xFFFF, 0xFFFF, "Solios COM port(0x47C2)"},
{0x102B, 0x4949, 0xFFFF, 0xFFFF, "Radient frame grabber family(0x4949)"},
{0x102B, 0x4949, 0x102B, 0x0010, "Radient eCL (Single-full) frame grabber(0x102B-0x0010)"},
{0x102B, 0x4949, 0x102B, 0x0011, "Radient eCLV (Single-full) frame grabber(0x102B-0x0011)"},
{0x102B, 0x4949, 0x102B, 0x0020, "Radient eCL (Dual-base) frame grabber(0x102B-0x0020)"},
{0x102B, 0x4949, 0x102B, 0x0030, "Radient eCL (Dual-full) frame grabber(0x102B-0x0030)"},
{0x102B, 0x4949, 0x102B, 0x0040, "Radient eCL (Quad-base) frame grabber(0x102B-0x0040)"},
{0x102B, 0x4949, 0x102B, 0x0050, "Radient eCL (Golden) frame grabber(0x102B-0x0050)"},
{0x102B, 0x4949, 0x102B, 0x1010, "Radient eV-CXP (quad CXP-6) frame grabber(0x102B-0x1010)"},
{0x102B, 0x4949, 0x102B, 0x1015, "Radient eV-CXP (dual CXP-6) frame grabber(0x102B-0x1015)"},
{0x102B, 0x4949, 0x102B, 0x1020, "Radient eV-CXP (quad CXP-3) frame grabber(0x102B-0x1020)"},
{0x102B, 0x4949, 0x102B, 0x1050, "Radient eV-CXP (Golden) frame grabber(0x102B-0x1050)"},
{0x102B, 0x4CDC, 0xFFFF, 0xFFFF, "Morphis JPEG2000 accelerator(0x4CDC)"},
{0x102B, 0x4F54, 0xFFFF, 0xFFFF, "Morphis (e)Quad frame grabber(0x4F54)"},
{0x102B, 0x4FC5, 0xFFFF, 0xFFFF, "Morphis (e)Dual frame grabber(0x4FC5)"},
{0x102B, 0x5E10, 0xFFFF, 0xFFFF, "Morphis aux I/O(0x5E10)"},
{0x102B, 0x6573, 0xFFFF, 0xFFFF, "Shark 10/100 Multiport SwitchNIC(0x6573)"},
}; /* pci_vid_102B[] */

static pci_id_t const pci_vid_102C[] = {
{0x102C, 0xFFFF, 0xFFFF, 0xFFFF, "Chips and Technologies(0x102C)"},
{0x102C, 0x00B8, 0xFFFF, 0xFFFF, "F64310(0x00B8)"},
{0x102C, 0x00C0, 0xFFFF, 0xFFFF, "F69000 HiQVideo(0x00C0)"},
{0x102C, 0x00C0, 0x102C, 0x00C0, "F69000 HiQVideo(0x102C-0x00C0)"},
{0x102C, 0x00C0, 0x4C53, 0x1000, "CC7/CR7/CP7/VC7/VP7/VR7 mainboard(0x4C53-0x1000)"},
{0x102C, 0x00C0, 0x4C53, 0x1010, "CP5/CR6 mainboard(0x4C53-0x1010)"},
{0x102C, 0x00C0, 0x4C53, 0x1020, "VR6 mainboard(0x4C53-0x1020)"},
{0x102C, 0x00C0, 0x4C53, 0x1030, "PC5 mainboard(0x4C53-0x1030)"},
{0x102C, 0x00C0, 0x4C53, 0x1050, "CT7 mainboard(0x4C53-0x1050)"},
{0x102C, 0x00C0, 0x4C53, 0x1051, "CE7 mainboard(0x4C53-0x1051)"},
{0x102C, 0x00D0, 0xFFFF, 0xFFFF, "F65545(0x00D0)"},
{0x102C, 0x00D8, 0xFFFF, 0xFFFF, "F65545(0x00D8)"},
{0x102C, 0x00DC, 0xFFFF, 0xFFFF, "F65548(0x00DC)"},
{0x102C, 0x00E0, 0xFFFF, 0xFFFF, "F65550(0x00E0)"},
{0x102C, 0x00E4, 0xFFFF, 0xFFFF, "F65554(0x00E4)"},
{0x102C, 0x00E5, 0xFFFF, 0xFFFF, "F65555 HiQVPro(0x00E5)"},
{0x102C, 0x00E5, 0x0E11, 0xB049, "Armada 1700 Laptop Display Controller(0x0E11-0xB049)"},
{0x102C, 0x00E5, 0x1179, 0x0001, "Satellite Pro/Satellite(0x1179-0x0001)"},
{0x102C, 0x00F0, 0xFFFF, 0xFFFF, "F68554(0x00F0)"},
{0x102C, 0x00F4, 0xFFFF, 0xFFFF, "F68554 HiQVision(0x00F4)"},
{0x102C, 0x00F5, 0xFFFF, 0xFFFF, "F68555(0x00F5)"},
{0x102C, 0x0C30, 0xFFFF, 0xFFFF, "F69030(0x0C30)"},
{0x102C, 0x0C30, 0x4C53, 0x1000, "CC7/CR7/CP7/VC7/VP7/VR7 mainboard(0x4C53-0x1000)"},
{0x102C, 0x0C30, 0x4C53, 0x1050, "CT7 mainboard(0x4C53-0x1050)"},
{0x102C, 0x0C30, 0x4C53, 0x1051, "CE7 mainboard(0x4C53-0x1051)"},
{0x102C, 0x0C30, 0x4C53, 0x1080, "CT8 mainboard(0x4C53-0x1080)"},
}; /* pci_vid_102C[] */

static pci_id_t const pci_vid_102D[] = {
{0x102D, 0xFFFF, 0xFFFF, 0xFFFF, "Wyse Technology Inc.(0x102D)"},
{0x102D, 0x50DC, 0xFFFF, 0xFFFF, "3328 Audio(0x50DC)"},
}; /* pci_vid_102D[] */

static pci_id_t const pci_vid_102E[] = {
{0x102E, 0xFFFF, 0xFFFF, 0xFFFF, "Olivetti Advanced Technology(0x102E)"},
}; /* pci_vid_102E[] */

static pci_id_t const pci_vid_102F[] = {
{0x102F, 0xFFFF, 0xFFFF, 0xFFFF, "Toshiba America(0x102F)"},
{0x102F, 0x0009, 0xFFFF, 0xFFFF, "r4x00(0x0009)"},
{0x102F, 0x000A, 0xFFFF, 0xFFFF, "TX3927 MIPS RISC PCI Controller(0x000A)"},
{0x102F, 0x0020, 0xFFFF, 0xFFFF, "ATM Meteor 155(0x0020)"},
{0x102F, 0x0020, 0x102F, 0x00F8, "ATM Meteor 155(0x102F-0x00F8)"},
{0x102F, 0x0030, 0xFFFF, 0xFFFF, "TC35815CF PCI 10/100 Mbit Ethernet Controller(0x0030)"},
{0x102F, 0x0031, 0xFFFF, 0xFFFF, "TC35815CF PCI 10/100 Mbit Ethernet Controller with WOL(0x0031)"},
{0x102F, 0x0032, 0xFFFF, 0xFFFF, "TC35815CF PCI 10/100 Mbit Ethernet Controller on TX4939(0x0032)"},
{0x102F, 0x0105, 0xFFFF, 0xFFFF, "TC86C001 [goku-s] IDE(0x0105)"},
{0x102F, 0x0106, 0xFFFF, 0xFFFF, "TC86C001 [goku-s] USB 1.1 Host(0x0106)"},
{0x102F, 0x0107, 0xFFFF, 0xFFFF, "TC86C001 [goku-s] USB Device Controller(0x0107)"},
{0x102F, 0x0108, 0xFFFF, 0xFFFF, "TC86C001 [goku-s] I2C/SIO/GPIO Controller(0x0108)"},
{0x102F, 0x0180, 0xFFFF, 0xFFFF, "TX4927/38 MIPS RISC PCI Controller(0x0180)"},
{0x102F, 0x0181, 0xFFFF, 0xFFFF, "TX4925 MIPS RISC PCI Controller(0x0181)"},
{0x102F, 0x0182, 0xFFFF, 0xFFFF, "TX4937 MIPS RISC PCI Controller(0x0182)"},
{0x102F, 0x01B4, 0xFFFF, 0xFFFF, "Celleb platform IDE interface(0x01B4)"},
{0x102F, 0x01B5, 0xFFFF, 0xFFFF, "SCC USB 2.0 EHCI controller(0x01B5)"},
{0x102F, 0x01B6, 0xFFFF, 0xFFFF, "SCC USB 1.1 OHCI controller(0x01B6)"},
}; /* pci_vid_102F[] */

static pci_id_t const pci_vid_1030[] = {
{0x1030, 0xFFFF, 0xFFFF, 0xFFFF, "TMC Research(0x1030)"},
}; /* pci_vid_1030[] */

static pci_id_t const pci_vid_1031[] = {
{0x1031, 0xFFFF, 0xFFFF, 0xFFFF, "Miro Computer Products AG(0x1031)"},
{0x1031, 0x5601, 0xFFFF, 0xFFFF, "DC20 ASIC(0x5601)"},
{0x1031, 0x5607, 0xFFFF, 0xFFFF, "Video I/O & motion JPEG compressor(0x5607)"},
{0x1031, 0x5631, 0xFFFF, 0xFFFF, "Media 3D(0x5631)"},
{0x1031, 0x6057, 0xFFFF, 0xFFFF, "MiroVideo DC10/DC30+(0x6057)"},
}; /* pci_vid_1031[] */

static pci_id_t const pci_vid_1032[] = {
{0x1032, 0xFFFF, 0xFFFF, 0xFFFF, "Compaq(0x1032)"},
}; /* pci_vid_1032[] */

static pci_id_t const pci_vid_1033[] = {
{0x1033, 0xFFFF, 0xFFFF, 0xFFFF, "NEC Corporation(0x1033)"},
{0x1033, 0x0000, 0xFFFF, 0xFFFF, "Vr4181A USB Host or Function Control Unit(0x0000)"},
{0x1033, 0x0001, 0xFFFF, 0xFFFF, "PCI to 486-like bus Bridge(0x0001)"},
{0x1033, 0x0002, 0xFFFF, 0xFFFF, "PCI to VL98 Bridge(0x0002)"},
{0x1033, 0x0003, 0xFFFF, 0xFFFF, "ATM Controller(0x0003)"},
{0x1033, 0x0004, 0xFFFF, 0xFFFF, "R4000 PCI Bridge(0x0004)"},
{0x1033, 0x0005, 0xFFFF, 0xFFFF, "PCI to 486-like bus Bridge(0x0005)"},
{0x1033, 0x0006, 0xFFFF, 0xFFFF, "PC-9800 Graphic Accelerator(0x0006)"},
{0x1033, 0x0007, 0xFFFF, 0xFFFF, "PCI to UX-Bus Bridge(0x0007)"},
{0x1033, 0x0008, 0xFFFF, 0xFFFF, "PC-9800 Graphic Accelerator(0x0008)"},
{0x1033, 0x0009, 0xFFFF, 0xFFFF, "PCI to PC9800 Core-Graph Bridge(0x0009)"},
{0x1033, 0x0016, 0xFFFF, 0xFFFF, "PCI to VL Bridge(0x0016)"},
{0x1033, 0x001A, 0xFFFF, 0xFFFF, "[Nile II](0x001A)"},
{0x1033, 0x0021, 0xFFFF, 0xFFFF, "Vrc4373 [Nile I](0x0021)"},
{0x1033, 0x0029, 0xFFFF, 0xFFFF, "PowerVR PCX1(0x0029)"},
{0x1033, 0x002A, 0xFFFF, 0xFFFF, "PowerVR 3D(0x002A)"},
{0x1033, 0x002C, 0xFFFF, 0xFFFF, "Star Alpha 2(0x002C)"},
{0x1033, 0x002D, 0xFFFF, 0xFFFF, "PCI to C-bus Bridge(0x002D)"},
{0x1033, 0x0035, 0xFFFF, 0xFFFF, "OHCI USB Controller(0x0035)"},
{0x1033, 0x0035, 0x1033, 0x0035, "USB Controller(0x1033-0x0035)"},
{0x1033, 0x0035, 0x103C, 0x1293, "USB add-in card(0x103C-0x1293)"},
{0x1033, 0x0035, 0x103C, 0x1294, "USB 2.0 add-in card(0x103C-0x1294)"},
{0x1033, 0x0035, 0x1179, 0x0001, "USB(0x1179-0x0001)"},
{0x1033, 0x0035, 0x1186, 0x0035, "DUB-C2 USB 2.0 2-port 32-bit cardbus controller(0x1186-0x0035)"},
{0x1033, 0x0035, 0x12EE, 0x7000, "Root Hub(0x12EE-0x7000)"},
{0x1033, 0x0035, 0x14C2, 0x0105, "PTI-205N USB 2.0 Host Controller(0x14C2-0x0105)"},
{0x1033, 0x0035, 0x1799, 0x0001, "Root Hub(0x1799-0x0001)"},
{0x1033, 0x0035, 0x1931, 0x000A, "GlobeTrotter Fusion Quad Lite (PPP data)(0x1931-0x000A)"},
{0x1033, 0x0035, 0x1931, 0x000B, "GlobeTrotter Fusion Quad Lite (GSM data)(0x1931-0x000B)"},
{0x1033, 0x0035, 0x807D, 0x0035, "PCI-USB2 (OHCI subsystem)(0x807D-0x0035)"},
{0x1033, 0x0035, 0x8086, 0x4D44, "D850EMV2 motherboard(0x8086-0x4D44)"},
{0x1033, 0x003B, 0xFFFF, 0xFFFF, "PCI to C-bus Bridge(0x003B)"},
{0x1033, 0x003E, 0xFFFF, 0xFFFF, "NAPCCARD Cardbus Controller(0x003E)"},
{0x1033, 0x0046, 0xFFFF, 0xFFFF, "PowerVR PCX2 [midas](0x0046)"},
{0x1033, 0x005A, 0xFFFF, 0xFFFF, "Vrc5074 [Nile 4](0x005A)"},
{0x1033, 0x0063, 0xFFFF, 0xFFFF, "uPD72862 [Firewarden] IEEE1394 OHCI 1.0 Link Controller(0x0063)"},
{0x1033, 0x0067, 0xFFFF, 0xFFFF, "PowerVR Neon 250 Chipset(0x0067)"},
{0x1033, 0x0067, 0x1010, 0x0020, "PowerVR Neon 250 AGP 32Mb(0x1010-0x0020)"},
{0x1033, 0x0067, 0x1010, 0x0080, "PowerVR Neon 250 AGP 16Mb(0x1010-0x0080)"},
{0x1033, 0x0067, 0x1010, 0x0088, "PowerVR Neon 250 16Mb(0x1010-0x0088)"},
{0x1033, 0x0067, 0x1010, 0x0090, "PowerVR Neon 250 AGP 16Mb(0x1010-0x0090)"},
{0x1033, 0x0067, 0x1010, 0x0098, "PowerVR Neon 250 16Mb(0x1010-0x0098)"},
{0x1033, 0x0067, 0x1010, 0x00A0, "PowerVR Neon 250 AGP 32Mb(0x1010-0x00A0)"},
{0x1033, 0x0067, 0x1010, 0x00A8, "PowerVR Neon 250 32Mb(0x1010-0x00A8)"},
{0x1033, 0x0067, 0x1010, 0x0120, "PowerVR Neon 250 AGP 32Mb(0x1010-0x0120)"},
{0x1033, 0x0072, 0xFFFF, 0xFFFF, "uPD72874 IEEE1394 OHCI 1.1 3-port PHY-Link Ctrlr(0x0072)"},
{0x1033, 0x0074, 0xFFFF, 0xFFFF, "56k Voice Modem(0x0074)"},
{0x1033, 0x0074, 0x1033, 0x8014, "RCV56ACF 56k Voice Modem(0x1033-0x8014)"},
{0x1033, 0x009B, 0xFFFF, 0xFFFF, "Vrc5476(0x009B)"},
{0x1033, 0x00A5, 0xFFFF, 0xFFFF, "VRC4173(0x00A5)"},
{0x1033, 0x00A6, 0xFFFF, 0xFFFF, "VRC5477 AC97(0x00A6)"},
{0x1033, 0x00CD, 0xFFFF, 0xFFFF, "uPD72870 [Firewarden] IEEE1394a OHCI 1.0 Link/3-port PHY Controller(0x00CD)"},
{0x1033, 0x00CD, 0x12EE, 0x8011, "Root hub(0x12EE-0x8011)"},
{0x1033, 0x00CE, 0xFFFF, 0xFFFF, "uPD72871 [Firewarden] IEEE1394a OHCI 1.0 Link/1-port PHY Controller(0x00CE)"},
{0x1033, 0x00DF, 0xFFFF, 0xFFFF, "Vr4131(0x00DF)"},
{0x1033, 0x00E0, 0xFFFF, 0xFFFF, "uPD72010x USB 2.0 Controller(0x00E0)"},
{0x1033, 0x00E0, 0x1186, 0xF100, "DUB-C2 USB 2.0 2-port 32-bit cardbus controller(0x1186-0xF100)"},
{0x1033, 0x00E0, 0x12EE, 0x7001, "Root hub(0x12EE-0x7001)"},
{0x1033, 0x00E0, 0x14C2, 0x0205, "PTI-205N USB 2.0 Host Controller(0x14C2-0x0205)"},
{0x1033, 0x00E0, 0x1799, 0x0002, "Root Hub(0x1799-0x0002)"},
{0x1033, 0x00E0, 0x807D, 0x1043, "PCI-USB2 (EHCI subsystem)(0x807D-0x1043)"},
{0x1033, 0x00E0, 0x8086, 0x4D44, "D850EMV2 motherboard(0x8086-0x4D44)"},
{0x1033, 0x00E7, 0xFFFF, 0xFFFF, "uPD72873 [Firewarden] IEEE1394a OHCI 1.1 Link/2-port PHY Controller(0x00E7)"},
{0x1033, 0x00F2, 0xFFFF, 0xFFFF, "uPD72874 [Firewarden] IEEE1394a OHCI 1.1 Link/3-port PHY Controller(0x00F2)"},
{0x1033, 0x00F3, 0xFFFF, 0xFFFF, "uPD6113x Multimedia Decoder/Processor [EMMA2](0x00F3)"},
{0x1033, 0x010C, 0xFFFF, 0xFFFF, "VR7701(0x010C)"},
{0x1033, 0x0125, 0xFFFF, 0xFFFF, "uPD720400 PCI Express - PCI/PCI-X Bridge(0x0125)"},
{0x1033, 0x013A, 0xFFFF, 0xFFFF, "Dual Tuner/MPEG Encoder(0x013A)"},
{0x1033, 0x0194, 0xFFFF, 0xFFFF, "uPD720200 USB 3.0 Host Controller(0x0194)"},
{0x1033, 0x0194, 0x1028, 0x04A3, "Precision M4600(0x1028-0x04A3)"},
{0x1033, 0x0194, 0x1028, 0x04B2, "Vostro 3350(0x1028-0x04B2)"},
{0x1033, 0x0194, 0x1028, 0x04DA, "Vostro 3750(0x1028-0x04DA)"},
{0x1033, 0x0194, 0x1043, 0x8413, "P8P67 Deluxe Motherboard(0x1043-0x8413)"},
{0x1033, 0x0194, 0x104D, 0x907A, "Vaio VPCF1(0x104D-0x907A)"},
{0x1033, 0x0194, 0x1AF4, 0x1100, "QEMU Virtual Machine(0x1AF4-0x1100)"},
{0x1033, 0x0194, 0x1B96, 0x0001, "USB 3.0 PCIe Card(0x1B96-0x0001)"},
{0x1033, 0x01E7, 0xFFFF, 0xFFFF, "uPD72873 [Firewarden] IEEE1394a OHCI 1.1 Link/2-port PHY Controller(0x01E7)"},
{0x1033, 0x01F2, 0xFFFF, 0xFFFF, "uPD72874 [Firewarden] IEEE1394a OHCI 1.1 Link/3-port PHY Controller(0x01F2)"},
}; /* pci_vid_1033[] */

static pci_id_t const pci_vid_1034[] = {
{0x1034, 0xFFFF, 0xFFFF, 0xFFFF, "Framatome Connectors USA Inc.(0x1034)"},
}; /* pci_vid_1034[] */

static pci_id_t const pci_vid_1035[] = {
{0x1035, 0xFFFF, 0xFFFF, 0xFFFF, "Comp. & Comm. Research Lab(0x1035)"},
}; /* pci_vid_1035[] */

static pci_id_t const pci_vid_1036[] = {
{0x1036, 0xFFFF, 0xFFFF, 0xFFFF, "Future Domain Corp.(0x1036)"},
{0x1036, 0x0000, 0xFFFF, 0xFFFF, "TMC-18C30 [36C70](0x0000)"},
}; /* pci_vid_1036[] */

static pci_id_t const pci_vid_1037[] = {
{0x1037, 0xFFFF, 0xFFFF, 0xFFFF, "Hitachi Micro Systems(0x1037)"},
}; /* pci_vid_1037[] */

static pci_id_t const pci_vid_1038[] = {
{0x1038, 0xFFFF, 0xFFFF, 0xFFFF, "AMP, Inc(0x1038)"},
}; /* pci_vid_1038[] */

static pci_id_t const pci_vid_1039[] = {
{0x1039, 0xFFFF, 0xFFFF, 0xFFFF, "Silicon Integrated Systems [SiS](0x1039)"},
{0x1039, 0x0001, 0xFFFF, 0xFFFF, "AGP Port (virtual PCI-to-PCI bridge)(0x0001)"},
{0x1039, 0x0002, 0xFFFF, 0xFFFF, "AGP Port (virtual PCI-to-PCI bridge)(0x0002)"},
{0x1039, 0x0003, 0xFFFF, 0xFFFF, "AGP Port (virtual PCI-to-PCI bridge)(0x0003)"},
{0x1039, 0x0004, 0xFFFF, 0xFFFF, "PCI-to-PCI bridge(0x0004)"},
{0x1039, 0x0004, 0x1039, 0x0000, "PCIe x16 port(0x1039-0x0000)"},
{0x1039, 0x0006, 0xFFFF, 0xFFFF, "85C501/2/3(0x0006)"},
{0x1039, 0x0008, 0xFFFF, 0xFFFF, "SiS85C503/5513 (LPC Bridge)(0x0008)"},
{0x1039, 0x0009, 0xFFFF, 0xFFFF, "5595 Power Management Controller(0x0009)"},
{0x1039, 0x000A, 0xFFFF, 0xFFFF, "PCI-to-PCI bridge(0x000A)"},
{0x1039, 0x000A, 0x1039, 0x0000, "PCIe x1 port(0x1039-0x0000)"},
{0x1039, 0x0016, 0xFFFF, 0xFFFF, "SiS961/2/3 SMBus controller(0x0016)"},
{0x1039, 0x0018, 0xFFFF, 0xFFFF, "SiS85C503/5513 (LPC Bridge)(0x0018)"},
{0x1039, 0x0163, 0xFFFF, 0xFFFF, "163 802.11b/g Wireless LAN Adapter(0x0163)"},
{0x1039, 0x0180, 0xFFFF, 0xFFFF, "RAID bus controller 180 SATA/PATA  [SiS](0x0180)"},
{0x1039, 0x0181, 0xFFFF, 0xFFFF, "SATA(0x0181)"},
{0x1039, 0x0182, 0xFFFF, 0xFFFF, "182 SATA/RAID Controller(0x0182)"},
{0x1039, 0x0182, 0x1734, 0x1095, "D2030-A1(0x1734-0x1095)"},
{0x1039, 0x0186, 0xFFFF, 0xFFFF, "AHCI Controller (0106)(0x0186)"},
{0x1039, 0x0190, 0xFFFF, 0xFFFF, "190 Ethernet Adapter(0x0190)"},
{0x1039, 0x0191, 0xFFFF, 0xFFFF, "191 Gigabit Ethernet Adapter(0x0191)"},
{0x1039, 0x0191, 0x1043, 0x8139, "P5SD2-FM/S mainboard(0x1043-0x8139)"},
{0x1039, 0x0200, 0xFFFF, 0xFFFF, "5597/5598/6326 VGA(0x0200)"},
{0x1039, 0x0200, 0x1039, 0x0000, "SiS5597 SVGA (Shared RAM)(0x1039-0x0000)"},
{0x1039, 0x0204, 0xFFFF, 0xFFFF, "82C204(0x0204)"},
{0x1039, 0x0205, 0xFFFF, 0xFFFF, "SG86C205(0x0205)"},
{0x1039, 0x0300, 0xFFFF, 0xFFFF, "300/305 PCI/AGP VGA Display Adapter(0x0300)"},
{0x1039, 0x0300, 0x107D, 0x2720, "Leadtek WinFast VR300(0x107D-0x2720)"},
{0x1039, 0x0310, 0xFFFF, 0xFFFF, "315H PCI/AGP VGA Display Adapter(0x0310)"},
{0x1039, 0x0315, 0xFFFF, 0xFFFF, "315 PCI/AGP VGA Display Adapter(0x0315)"},
{0x1039, 0x0325, 0xFFFF, 0xFFFF, "315PRO PCI/AGP VGA Display Adapter(0x0325)"},
{0x1039, 0x0330, 0xFFFF, 0xFFFF, "330 [Xabre] PCI/AGP VGA Display Adapter(0x0330)"},
{0x1039, 0x0406, 0xFFFF, 0xFFFF, "85C501/2(0x0406)"},
{0x1039, 0x0496, 0xFFFF, 0xFFFF, "SiS85C496 PCI & CPU Memory Controller (PCM)(0x0496)"},
{0x1039, 0x0530, 0xFFFF, 0xFFFF, "530 Host(0x0530)"},
{0x1039, 0x0540, 0xFFFF, 0xFFFF, "540 Host(0x0540)"},
{0x1039, 0x0550, 0xFFFF, 0xFFFF, "550 Host(0x0550)"},
{0x1039, 0x0597, 0xFFFF, 0xFFFF, "5513C(0x0597)"},
{0x1039, 0x0601, 0xFFFF, 0xFFFF, "85C601(0x0601)"},
{0x1039, 0x0620, 0xFFFF, 0xFFFF, "620 Host(0x0620)"},
{0x1039, 0x0630, 0xFFFF, 0xFFFF, "630 Host(0x0630)"},
{0x1039, 0x0633, 0xFFFF, 0xFFFF, "633 Host(0x0633)"},
{0x1039, 0x0635, 0xFFFF, 0xFFFF, "635 Host(0x0635)"},
{0x1039, 0x0645, 0xFFFF, 0xFFFF, "SiS645 Host & Memory & AGP Controller(0x0645)"},
{0x1039, 0x0646, 0xFFFF, 0xFFFF, "SiS645DX Host & Memory & AGP Controller(0x0646)"},
{0x1039, 0x0648, 0xFFFF, 0xFFFF, "645xx(0x0648)"},
{0x1039, 0x0649, 0xFFFF, 0xFFFF, "SiS649 Host(0x0649)"},
{0x1039, 0x0650, 0xFFFF, 0xFFFF, "650/M650 Host(0x0650)"},
{0x1039, 0x0651, 0xFFFF, 0xFFFF, "651 Host(0x0651)"},
{0x1039, 0x0655, 0xFFFF, 0xFFFF, "655 Host(0x0655)"},
{0x1039, 0x0660, 0xFFFF, 0xFFFF, "660 Host(0x0660)"},
{0x1039, 0x0661, 0xFFFF, 0xFFFF, "661FX/M661FX/M661MX Host(0x0661)"},
{0x1039, 0x0662, 0xFFFF, 0xFFFF, "662 Host(0x0662)"},
{0x1039, 0x0671, 0xFFFF, 0xFFFF, "671MX(0x0671)"},
{0x1039, 0x0730, 0xFFFF, 0xFFFF, "730 Host(0x0730)"},
{0x1039, 0x0733, 0xFFFF, 0xFFFF, "733 Host(0x0733)"},
{0x1039, 0x0735, 0xFFFF, 0xFFFF, "735 Host(0x0735)"},
{0x1039, 0x0740, 0xFFFF, 0xFFFF, "740 Host(0x0740)"},
{0x1039, 0x0741, 0xFFFF, 0xFFFF, "741/741GX/M741 Host(0x0741)"},
{0x1039, 0x0741, 0x1849, 0x0741, "K7S41/K7S41GX motherboard(0x1849-0x0741)"},
{0x1039, 0x0745, 0xFFFF, 0xFFFF, "745 Host(0x0745)"},
{0x1039, 0x0746, 0xFFFF, 0xFFFF, "746 Host(0x0746)"},
{0x1039, 0x0755, 0xFFFF, 0xFFFF, "755 Host(0x0755)"},
{0x1039, 0x0760, 0xFFFF, 0xFFFF, "760/M760 Host(0x0760)"},
{0x1039, 0x0761, 0xFFFF, 0xFFFF, "761/M761 Host(0x0761)"},
{0x1039, 0x0761, 0x1734, 0x1099, "D2030-A1 Motherboard(0x1734-0x1099)"},
{0x1039, 0x0900, 0xFFFF, 0xFFFF, "SiS900 PCI Fast Ethernet(0x0900)"},
{0x1039, 0x0900, 0x1019, 0x0A14, "K7S5A motherboard(0x1019-0x0A14)"},
{0x1039, 0x0900, 0x1039, 0x0900, "SiS900 10/100 Ethernet Adapter onboard(0x1039-0x0900)"},
{0x1039, 0x0900, 0x1043, 0x8035, "CUSI-FX motherboard(0x1043-0x8035)"},
{0x1039, 0x0900, 0x1043, 0x80A7, "Motherboard P4S800D-X(0x1043-0x80A7)"},
{0x1039, 0x0900, 0x1462, 0x0900, "MS-6701 motherboard(0x1462-0x0900)"},
{0x1039, 0x0961, 0xFFFF, 0xFFFF, "SiS961 [MuTIOL Media IO](0x0961)"},
{0x1039, 0x0962, 0xFFFF, 0xFFFF, "SiS962 [MuTIOL Media IO] LPC Controller(0x0962)"},
{0x1039, 0x0963, 0xFFFF, 0xFFFF, "SiS963 [MuTIOL Media IO] LPC Controller(0x0963)"},
{0x1039, 0x0964, 0xFFFF, 0xFFFF, "SiS964 [MuTIOL Media IO] LPC Controller(0x0964)"},
{0x1039, 0x0965, 0xFFFF, 0xFFFF, "SiS965 [MuTIOL Media IO](0x0965)"},
{0x1039, 0x0966, 0xFFFF, 0xFFFF, "SiS966 [MuTIOL Media IO](0x0966)"},
{0x1039, 0x0968, 0xFFFF, 0xFFFF, "SiS968 [MuTIOL Media IO](0x0968)"},
{0x1039, 0x1180, 0xFFFF, 0xFFFF, "SATA Controller / IDE mode(0x1180)"},
{0x1039, 0x1182, 0xFFFF, 0xFFFF, "SATA Controller / RAID mode(0x1182)"},
{0x1039, 0x1182, 0x1039, 0x0180, "SiS 966 4-port SATA controller(0x1039-0x0180)"},
{0x1039, 0x1183, 0xFFFF, 0xFFFF, "SATA Controller / IDE mode(0x1183)"},
{0x1039, 0x1183, 0x1039, 0x0180, "SiS 966 4-port SATA controller(0x1039-0x0180)"},
{0x1039, 0x1184, 0xFFFF, 0xFFFF, "AHCI Controller / RAID mode(0x1184)"},
{0x1039, 0x1185, 0xFFFF, 0xFFFF, "AHCI IDE Controller (0106)(0x1185)"},
{0x1039, 0x3602, 0xFFFF, 0xFFFF, "83C602(0x3602)"},
{0x1039, 0x5107, 0xFFFF, 0xFFFF, "5107(0x5107)"},
{0x1039, 0x5300, 0xFFFF, 0xFFFF, "SiS540 PCI Display Adapter(0x5300)"},
{0x1039, 0x5315, 0xFFFF, 0xFFFF, "550 PCI/AGP VGA Display Adapter(0x5315)"},
{0x1039, 0x5401, 0xFFFF, 0xFFFF, "486 PCI Chipset(0x5401)"},
{0x1039, 0x5511, 0xFFFF, 0xFFFF, "5511/5512(0x5511)"},
{0x1039, 0x5513, 0xFFFF, 0xFFFF, "5513 IDE Controller(0x5513)"},
{0x1039, 0x5513, 0x1019, 0x0970, "P6STP-FL motherboard(0x1019-0x0970)"},
{0x1039, 0x5513, 0x1039, 0x5513, "SiS5513 EIDE Controller (A,B step)(0x1039-0x5513)"},
{0x1039, 0x5513, 0x1043, 0x8035, "CUSI-FX motherboard(0x1043-0x8035)"},
{0x1039, 0x5513, 0x1462, 0x7010, "MS-6701 motherboard(0x1462-0x7010)"},
{0x1039, 0x5513, 0x1631, 0x5513, "GA-8SIML Rev1.0 Motherboard(0x1631-0x5513)"},
{0x1039, 0x5513, 0x1734, 0x1095, "D2030-A1 Motherboard(0x1734-0x1095)"},
{0x1039, 0x5517, 0xFFFF, 0xFFFF, "5517(0x5517)"},
{0x1039, 0x5571, 0xFFFF, 0xFFFF, "5571(0x5571)"},
{0x1039, 0x5581, 0xFFFF, 0xFFFF, "5581 Pentium Chipset(0x5581)"},
{0x1039, 0x5582, 0xFFFF, 0xFFFF, "5582(0x5582)"},
{0x1039, 0x5591, 0xFFFF, 0xFFFF, "5591/5592 Host(0x5591)"},
{0x1039, 0x5596, 0xFFFF, 0xFFFF, "5596 Pentium Chipset(0x5596)"},
{0x1039, 0x5597, 0xFFFF, 0xFFFF, "5597 [SiS5582](0x5597)"},
{0x1039, 0x5600, 0xFFFF, 0xFFFF, "5600 Host(0x5600)"},
{0x1039, 0x6204, 0xFFFF, 0xFFFF, "Video decoder & MPEG interface(0x6204)"},
{0x1039, 0x6205, 0xFFFF, 0xFFFF, "VGA Controller(0x6205)"},
{0x1039, 0x6236, 0xFFFF, 0xFFFF, "6236 3D-AGP(0x6236)"},
{0x1039, 0x6300, 0xFFFF, 0xFFFF, "630/730 PCI/AGP VGA Display Adapter(0x6300)"},
{0x1039, 0x6300, 0x1019, 0x0970, "P6STP-FL motherboard(0x1019-0x0970)"},
{0x1039, 0x6300, 0x1043, 0x8035, "CUSI-FX motherboard(0x1043-0x8035)"},
{0x1039, 0x6300, 0x104D, 0x80E2, "VAIO PCV-J200(0x104D-0x80E2)"},
{0x1039, 0x6306, 0xFFFF, 0xFFFF, "530/620 PCI/AGP VGA Display Adapter(0x6306)"},
{0x1039, 0x6325, 0xFFFF, 0xFFFF, "65x/M650/740 PCI/AGP VGA Display Adapter(0x6325)"},
{0x1039, 0x6325, 0x1039, 0x6325, "SiS 651 onboard [Asus P4SC-EA](0x1039-0x6325)"},
{0x1039, 0x6325, 0x1631, 0x1004, "SiS 651C onboard [Gigabyte GA-8SIML Rev1.0](0x1631-0x1004)"},
{0x1039, 0x6326, 0xFFFF, 0xFFFF, "86C326 5598/6326(0x6326)"},
{0x1039, 0x6326, 0x1039, 0x6326, "SiS6326 GUI Accelerator(0x1039-0x6326)"},
{0x1039, 0x6326, 0x1092, 0x0A50, "SpeedStar A50(0x1092-0x0A50)"},
{0x1039, 0x6326, 0x1092, 0x0A70, "SpeedStar A70(0x1092-0x0A70)"},
{0x1039, 0x6326, 0x1092, 0x4910, "SpeedStar A70(0x1092-0x4910)"},
{0x1039, 0x6326, 0x1092, 0x4920, "SpeedStar A70(0x1092-0x4920)"},
{0x1039, 0x6326, 0x10B0, 0x6326, "S6110-B (AGP)(0x10B0-0x6326)"},
{0x1039, 0x6326, 0x1569, 0x6326, "SiS6326 GUI Accelerator(0x1569-0x6326)"},
{0x1039, 0x6330, 0xFFFF, 0xFFFF, "661/741/760 PCI/AGP or 662/761Gx PCIE VGA Display Adapter(0x6330)"},
{0x1039, 0x6330, 0x1039, 0x6330, "[M]661xX/[M]741[GX]/[M]760 PCI/AGP VGA Adapter(0x1039-0x6330)"},
{0x1039, 0x6330, 0x1043, 0x8113, "SiS Real 256E (ASUS P5S800-VM motherboard)(0x1043-0x8113)"},
{0x1039, 0x6330, 0x1458, 0xD000, "SiS661FX GUI 2D/3D Accelerator(0x1458-0xD000)"},
{0x1039, 0x6330, 0x1734, 0x1099, "D2030-A1(0x1734-0x1099)"},
{0x1039, 0x6350, 0xFFFF, 0xFFFF, "770/670 PCIE VGA Display Adapter(0x6350)"},
{0x1039, 0x6351, 0xFFFF, 0xFFFF, "771/671 PCIE VGA Display Adapter(0x6351)"},
{0x1039, 0x7001, 0xFFFF, 0xFFFF, "USB 1.1 Controller(0x7001)"},
{0x1039, 0x7001, 0x1019, 0x0A14, "K7S5A motherboard(0x1019-0x0A14)"},
{0x1039, 0x7001, 0x1039, 0x7000, "Onboard USB Controller(0x1039-0x7000)"},
{0x1039, 0x7001, 0x1462, 0x5470, "ECS K7SOM+ motherboard(0x1462-0x5470)"},
{0x1039, 0x7001, 0x1462, 0x7010, "MS-6701 motherboard(0x1462-0x7010)"},
{0x1039, 0x7001, 0x1734, 0x1095, "D2030-A1 Motherboard(0x1734-0x1095)"},
{0x1039, 0x7002, 0xFFFF, 0xFFFF, "USB 2.0 Controller(0x7002)"},
{0x1039, 0x7002, 0x1462, 0x5470, "K7SOM+ 5.2C Motherboard(0x1462-0x5470)"},
{0x1039, 0x7002, 0x1462, 0x7010, "MS-6701 motherboard(0x1462-0x7010)"},
{0x1039, 0x7002, 0x1509, 0x7002, "Onboard USB Controller(0x1509-0x7002)"},
{0x1039, 0x7002, 0x1734, 0x1095, "D2030-A1(0x1734-0x1095)"},
{0x1039, 0x7007, 0xFFFF, 0xFFFF, "FireWire Controller(0x7007)"},
{0x1039, 0x7007, 0x1462, 0x701D, "MS-6701(0x1462-0x701D)"},
{0x1039, 0x7012, 0xFFFF, 0xFFFF, "SiS7012 AC'97 Sound Controller(0x7012)"},
{0x1039, 0x7012, 0x1019, 0x0F05, "A928 (i-Buddie)(0x1019-0x0F05)"},
{0x1039, 0x7012, 0x1039, 0x7012, "SiS 7012 onboard [Asus P4SC-EA] AC'97 Sound Controller(0x1039-0x7012)"},
{0x1039, 0x7012, 0x1043, 0x818F, "A8S-X Motherboard(0x1043-0x818F)"},
{0x1039, 0x7012, 0x13F6, 0x0300, "CMI9739(A) on ECS K7S series motherboard(0x13F6-0x0300)"},
{0x1039, 0x7012, 0x1462, 0x5850, "MSI 648 Max (MS-6585)(0x1462-0x5850)"},
{0x1039, 0x7012, 0x1462, 0x7010, "MS-6701 motherboard(0x1462-0x7010)"},
{0x1039, 0x7012, 0x15BD, 0x1001, "DFI 661FX motherboard(0x15BD-0x1001)"},
{0x1039, 0x7012, 0x1734, 0x109F, "D2030-A1 Motherboard(0x1734-0x109F)"},
{0x1039, 0x7012, 0x1849, 0x7012, "K7S41GX motherboard(0x1849-0x7012)"},
{0x1039, 0x7013, 0xFFFF, 0xFFFF, "AC'97 Modem Controller(0x7013)"},
{0x1039, 0x7016, 0xFFFF, 0xFFFF, "SiS7016 PCI Fast Ethernet Adapter(0x7016)"},
{0x1039, 0x7016, 0x1039, 0x7016, "SiS7016 10/100 Ethernet Adapter(0x1039-0x7016)"},
{0x1039, 0x7018, 0xFFFF, 0xFFFF, "SiS PCI Audio Accelerator(0x7018)"},
{0x1039, 0x7018, 0x1014, 0x01B6, "SiS PCI Audio Accelerator(0x1014-0x01B6)"},
{0x1039, 0x7018, 0x1014, 0x01B7, "SiS PCI Audio Accelerator(0x1014-0x01B7)"},
{0x1039, 0x7018, 0x1019, 0x7018, "SiS PCI Audio Accelerator(0x1019-0x7018)"},
{0x1039, 0x7018, 0x1025, 0x000E, "SiS PCI Audio Accelerator(0x1025-0x000E)"},
{0x1039, 0x7018, 0x1025, 0x0018, "SiS PCI Audio Accelerator(0x1025-0x0018)"},
{0x1039, 0x7018, 0x1039, 0x7018, "SiS PCI Audio Accelerator(0x1039-0x7018)"},
{0x1039, 0x7018, 0x1043, 0x1453, "SiS PCI Audio Accelerator(0x1043-0x1453)"},
{0x1039, 0x7018, 0x1043, 0x800B, "SiS PCI Audio Accelerator(0x1043-0x800B)"},
{0x1039, 0x7018, 0x104D, 0x80E2, "VAIO PCV-J200(0x104D-0x80E2)"},
{0x1039, 0x7018, 0x1054, 0x7018, "SiS PCI Audio Accelerator(0x1054-0x7018)"},
{0x1039, 0x7018, 0x107D, 0x5330, "SiS PCI Audio Accelerator(0x107D-0x5330)"},
{0x1039, 0x7018, 0x107D, 0x5350, "SiS PCI Audio Accelerator(0x107D-0x5350)"},
{0x1039, 0x7018, 0x1170, 0x3209, "SiS PCI Audio Accelerator(0x1170-0x3209)"},
{0x1039, 0x7018, 0x1462, 0x400A, "SiS PCI Audio Accelerator(0x1462-0x400A)"},
{0x1039, 0x7018, 0x14A4, 0x2089, "SiS PCI Audio Accelerator(0x14A4-0x2089)"},
{0x1039, 0x7018, 0x14CD, 0x2194, "SiS PCI Audio Accelerator(0x14CD-0x2194)"},
{0x1039, 0x7018, 0x14FF, 0x1100, "SiS PCI Audio Accelerator(0x14FF-0x1100)"},
{0x1039, 0x7018, 0x152D, 0x8808, "SiS PCI Audio Accelerator(0x152D-0x8808)"},
{0x1039, 0x7018, 0x1558, 0x1103, "SiS PCI Audio Accelerator(0x1558-0x1103)"},
{0x1039, 0x7018, 0x1558, 0x2200, "SiS PCI Audio Accelerator(0x1558-0x2200)"},
{0x1039, 0x7018, 0x1563, 0x7018, "SiS PCI Audio Accelerator(0x1563-0x7018)"},
{0x1039, 0x7018, 0x15C5, 0x0111, "SiS PCI Audio Accelerator(0x15C5-0x0111)"},
{0x1039, 0x7018, 0x270F, 0xA171, "SiS PCI Audio Accelerator(0x270F-0xA171)"},
{0x1039, 0x7018, 0xA0A0, 0x0022, "SiS PCI Audio Accelerator(0xA0A0-0x0022)"},
{0x1039, 0x7019, 0xFFFF, 0xFFFF, "SiS7019 Audio Accelerator(0x7019)"},
{0x1039, 0x7502, 0xFFFF, 0xFFFF, "Azalia Audio Controller(0x7502)"},
{0x1039, 0x7502, 0x1043, 0x81A1, "P5SD2-FM/S mainboard(0x1043-0x81A1)"},
}; /* pci_vid_1039[] */

static pci_id_t const pci_vid_103A[] = {
{0x103A, 0xFFFF, 0xFFFF, 0xFFFF, "Seiko Epson Corporation(0x103A)"},
}; /* pci_vid_103A[] */

static pci_id_t const pci_vid_103B[] = {
{0x103B, 0xFFFF, 0xFFFF, 0xFFFF, "Tatung Corp. Of America(0x103B)"},
}; /* pci_vid_103B[] */

static pci_id_t const pci_vid_103C[] = {
{0x103C, 0xFFFF, 0xFFFF, 0xFFFF, "Hewlett-Packard Company(0x103C)"},
{0x103C, 0x1005, 0xFFFF, 0xFFFF, "A4977A Visualize EG(0x1005)"},
{0x103C, 0x1008, 0xFFFF, 0xFFFF, "Visualize FX(0x1008)"},
{0x103C, 0x1020, 0xFFFF, 0xFFFF, "548XX Scope Interface(0x1020)"},
{0x103C, 0x1028, 0xFFFF, 0xFFFF, "Tach TL Fibre Channel Host Adapter(0x1028)"},
{0x103C, 0x1029, 0xFFFF, 0xFFFF, "Tach XL2 Fibre Channel Host Adapter(0x1029)"},
{0x103C, 0x1029, 0x107E, 0x000F, "Interphase 5560 Fibre Channel Adapter(0x107E-0x000F)"},
{0x103C, 0x1029, 0x9004, 0x9210, "1Gb/2Gb Family Fibre Channel Controller(0x9004-0x9210)"},
{0x103C, 0x1029, 0x9004, 0x9211, "1Gb/2Gb Family Fibre Channel Controller(0x9004-0x9211)"},
{0x103C, 0x102A, 0xFFFF, 0xFFFF, "Tach TS Fibre Channel Host Adapter(0x102A)"},
{0x103C, 0x102A, 0x107E, 0x000E, "Interphase 5540/5541 Fibre Channel Adapter(0x107E-0x000E)"},
{0x103C, 0x102A, 0x9004, 0x9110, "1Gb/2Gb Family Fibre Channel Controller(0x9004-0x9110)"},
{0x103C, 0x102A, 0x9004, 0x9111, "1Gb/2Gb Family Fibre Channel Controller(0x9004-0x9111)"},
{0x103C, 0x1030, 0xFFFF, 0xFFFF, "J2585A DeskDirect 10/100VG NIC(0x1030)"},
{0x103C, 0x1031, 0xFFFF, 0xFFFF, "J2585B HP 10/100VG PCI LAN Adapter(0x1031)"},
{0x103C, 0x1031, 0x103C, 0x1040, "J2973A DeskDirect 10BaseT NIC(0x103C-0x1040)"},
{0x103C, 0x1031, 0x103C, 0x1041, "J2585B DeskDirect 10/100VG NIC(0x103C-0x1041)"},
{0x103C, 0x1031, 0x103C, 0x1042, "J2970A DeskDirect 10BaseT/2 NIC(0x103C-0x1042)"},
{0x103C, 0x1040, 0xFFFF, 0xFFFF, "J2973A DeskDirect 10BaseT NIC(0x1040)"},
{0x103C, 0x1041, 0xFFFF, 0xFFFF, "J2585B DeskDirect 10/100 NIC(0x1041)"},
{0x103C, 0x1042, 0xFFFF, 0xFFFF, "J2970A DeskDirect 10BaseT/2 NIC(0x1042)"},
{0x103C, 0x1048, 0xFFFF, 0xFFFF, "Diva Serial [GSP] Multiport UART(0x1048)"},
{0x103C, 0x1048, 0x103C, 0x1049, "Tosca Console(0x103C-0x1049)"},
{0x103C, 0x1048, 0x103C, 0x104A, "Tosca Secondary(0x103C-0x104A)"},
{0x103C, 0x1048, 0x103C, 0x104B, "Maestro SP2(0x103C-0x104B)"},
{0x103C, 0x1048, 0x103C, 0x1223, "Superdome Console(0x103C-0x1223)"},
{0x103C, 0x1048, 0x103C, 0x1226, "Keystone SP2(0x103C-0x1226)"},
{0x103C, 0x1048, 0x103C, 0x1227, "Powerbar SP2(0x103C-0x1227)"},
{0x103C, 0x1048, 0x103C, 0x1282, "Everest SP2(0x103C-0x1282)"},
{0x103C, 0x1048, 0x103C, 0x1301, "Diva RMP3(0x103C-0x1301)"},
{0x103C, 0x1054, 0xFFFF, 0xFFFF, "PCI Local Bus Adapter(0x1054)"},
{0x103C, 0x1064, 0xFFFF, 0xFFFF, "79C970 PCnet Ethernet Controller(0x1064)"},
{0x103C, 0x108B, 0xFFFF, 0xFFFF, "Visualize FXe(0x108B)"},
{0x103C, 0x10C1, 0xFFFF, 0xFFFF, "NetServer Smart IRQ Router(0x10C1)"},
{0x103C, 0x10ED, 0xFFFF, 0xFFFF, "TopTools Remote Control(0x10ED)"},
{0x103C, 0x10F0, 0xFFFF, 0xFFFF, "rio System Bus Adapter(0x10F0)"},
{0x103C, 0x10F1, 0xFFFF, 0xFFFF, "rio I/O Controller(0x10F1)"},
{0x103C, 0x1219, 0xFFFF, 0xFFFF, "NetServer PCI Hot-Plug Controller(0x1219)"},
{0x103C, 0x121A, 0xFFFF, 0xFFFF, "NetServer SMIC Controller(0x121A)"},
{0x103C, 0x121B, 0xFFFF, 0xFFFF, "NetServer Legacy COM Port Decoder(0x121B)"},
{0x103C, 0x121C, 0xFFFF, 0xFFFF, "NetServer PCI COM Port Decoder(0x121C)"},
{0x103C, 0x1229, 0xFFFF, 0xFFFF, "zx1 System Bus Adapter(0x1229)"},
{0x103C, 0x122A, 0xFFFF, 0xFFFF, "zx1 I/O Controller(0x122A)"},
{0x103C, 0x122E, 0xFFFF, 0xFFFF, "PCI-X Local Bus Adapter(0x122E)"},
{0x103C, 0x127B, 0xFFFF, 0xFFFF, "sx1000 System Bus Adapter(0x127B)"},
{0x103C, 0x127C, 0xFFFF, 0xFFFF, "sx1000 I/O Controller(0x127C)"},
{0x103C, 0x128D, 0xFFFF, 0xFFFF, "Diva [GSP] Management Board(0x128D)"},
{0x103C, 0x1290, 0xFFFF, 0xFFFF, "Auxiliary Diva Serial Port(0x1290)"},
{0x103C, 0x1290, 0x103C, 0x1291, "Diva SP2(0x103C-0x1291)"},
{0x103C, 0x1291, 0xFFFF, 0xFFFF, "Auxiliary Diva Serial Port(0x1291)"},
{0x103C, 0x12B4, 0xFFFF, 0xFFFF, "zx1 QuickSilver AGP8x Local Bus Adapter(0x12B4)"},
{0x103C, 0x12EB, 0xFFFF, 0xFFFF, "sx2000 System Bus Adapter(0x12EB)"},
{0x103C, 0x12EC, 0xFFFF, 0xFFFF, "sx2000 I/O Controller(0x12EC)"},
{0x103C, 0x12EE, 0xFFFF, 0xFFFF, "PCI-X 2.0 Local Bus Adapter(0x12EE)"},
{0x103C, 0x1302, 0xFFFF, 0xFFFF, "RMP-3 Shared Memory Driver(0x1302)"},
{0x103C, 0x1303, 0xFFFF, 0xFFFF, "RMP-3 (Remote Management Processor)(0x1303)"},
{0x103C, 0x22F6, 0xFFFF, 0xFFFF, "iLO5 Virtual USB Controller(0x22F6)"},
{0x103C, 0x22F6, 0x1590, 0x00E4, "iLO5 Standard Virtual USB Controller(0x1590-0x00E4)"},
{0x103C, 0x2910, 0xFFFF, 0xFFFF, "E2910A PCIBus Exerciser(0x2910)"},
{0x103C, 0x2925, 0xFFFF, 0xFFFF, "E2925A 32 Bit, 33 MHzPCI Exerciser & Analyzer(0x2925)"},
{0x103C, 0x3206, 0xFFFF, 0xFFFF, "Adaptec Embedded Serial ATA HostRAID(0x3206)"},
{0x103C, 0x3220, 0xFFFF, 0xFFFF, "Smart Array P600(0x3220)"},
{0x103C, 0x3220, 0x103C, 0x3225, "3 Gb/s SAS RAID(0x103C-0x3225)"},
{0x103C, 0x3230, 0xFFFF, 0xFFFF, "Smart Array Controller(0x3230)"},
{0x103C, 0x3230, 0x103C, 0x3223, "Smart Array P800(0x103C-0x3223)"},
{0x103C, 0x3230, 0x103C, 0x3234, "P400 SAS Controller(0x103C-0x3234)"},
{0x103C, 0x3230, 0x103C, 0x3235, "P400i SAS Controller(0x103C-0x3235)"},
{0x103C, 0x3230, 0x103C, 0x3237, "E500 SAS Controller(0x103C-0x3237)"},
{0x103C, 0x3230, 0x103C, 0x323D, "P700m SAS Controller(0x103C-0x323D)"},
{0x103C, 0x3238, 0xFFFF, 0xFFFF, "Smart Array E200i (SAS Controller)(0x3238)"},
{0x103C, 0x3238, 0x103C, 0x3211, "Smart Array E200i(0x103C-0x3211)"},
{0x103C, 0x3238, 0x103C, 0x3212, "Smart Array E200(0x103C-0x3212)"},
{0x103C, 0x3239, 0xFFFF, 0xFFFF, "Smart Array Gen9 Controllers(0x3239)"},
{0x103C, 0x3239, 0x103C, 0x21BD, "P244br(0x103C-0x21BD)"},
{0x103C, 0x3239, 0x103C, 0x21BE, "P741m(0x103C-0x21BE)"},
{0x103C, 0x3239, 0x103C, 0x21BF, "H240ar(0x103C-0x21BF)"},
{0x103C, 0x3239, 0x103C, 0x21C0, "P440ar(0x103C-0x21C0)"},
{0x103C, 0x3239, 0x103C, 0x21C1, "P840ar(0x103C-0x21C1)"},
{0x103C, 0x3239, 0x103C, 0x21C2, "P440(0x103C-0x21C2)"},
{0x103C, 0x3239, 0x103C, 0x21C3, "P441(0x103C-0x21C3)"},
{0x103C, 0x3239, 0x103C, 0x21C4, "Smart Array(0x103C-0x21C4)"},
{0x103C, 0x3239, 0x103C, 0x21C5, "P841(0x103C-0x21C5)"},
{0x103C, 0x3239, 0x103C, 0x21C6, "H244br(0x103C-0x21C6)"},
{0x103C, 0x3239, 0x103C, 0x21C7, "H240(0x103C-0x21C7)"},
{0x103C, 0x3239, 0x103C, 0x21C8, "H241(0x103C-0x21C8)"},
{0x103C, 0x3239, 0x103C, 0x21C9, "Smart Array(0x103C-0x21C9)"},
{0x103C, 0x3239, 0x103C, 0x21CA, "P246br(0x103C-0x21CA)"},
{0x103C, 0x3239, 0x103C, 0x21CB, "P840(0x103C-0x21CB)"},
{0x103C, 0x3239, 0x103C, 0x21CC, "Smart Array(0x103C-0x21CC)"},
{0x103C, 0x3239, 0x103C, 0x21CD, "P240nr(0x103C-0x21CD)"},
{0x103C, 0x3239, 0x103C, 0x21CE, "H240nr(0x103C-0x21CE)"},
{0x103C, 0x323A, 0xFFFF, 0xFFFF, "Smart Array G6 controllers(0x323A)"},
{0x103C, 0x323A, 0x103C, 0x3241, "Smart Array P212(0x103C-0x3241)"},
{0x103C, 0x323A, 0x103C, 0x3243, "Smart Array P410(0x103C-0x3243)"},
{0x103C, 0x323A, 0x103C, 0x3245, "Smart Array P410i(0x103C-0x3245)"},
{0x103C, 0x323A, 0x103C, 0x3247, "Smart Array P411(0x103C-0x3247)"},
{0x103C, 0x323A, 0x103C, 0x3249, "Smart Array P812(0x103C-0x3249)"},
{0x103C, 0x323A, 0x103C, 0x324A, "Smart Array 712m (Mezzanine RAID controller)(0x103C-0x324A)"},
{0x103C, 0x323A, 0x103C, 0x324B, "Smart Array P711m (Mezzanine RAID controller)(0x103C-0x324B)"},
{0x103C, 0x323B, 0xFFFF, 0xFFFF, "Smart Array Gen8 Controllers(0x323B)"},
{0x103C, 0x323B, 0x103C, 0x3350, "P222(0x103C-0x3350)"},
{0x103C, 0x323B, 0x103C, 0x3351, "P420(0x103C-0x3351)"},
{0x103C, 0x323B, 0x103C, 0x3352, "P421(0x103C-0x3352)"},
{0x103C, 0x323B, 0x103C, 0x3354, "P420i(0x103C-0x3354)"},
{0x103C, 0x323B, 0x103C, 0x3355, "P220i(0x103C-0x3355)"},
{0x103C, 0x323C, 0xFFFF, 0xFFFF, "Smart Array Gen8+ Controllers(0x323C)"},
{0x103C, 0x323C, 0x103C, 0x1920, "P430i(0x103C-0x1920)"},
{0x103C, 0x323C, 0x103C, 0x1921, "P830i(0x103C-0x1921)"},
{0x103C, 0x323C, 0x103C, 0x1922, "P430(0x103C-0x1922)"},
{0x103C, 0x323C, 0x103C, 0x1923, "P431(0x103C-0x1923)"},
{0x103C, 0x323C, 0x103C, 0x1924, "P830(0x103C-0x1924)"},
{0x103C, 0x323C, 0x103C, 0x1925, "Smart Array(0x103C-0x1925)"},
{0x103C, 0x323C, 0x103C, 0x1926, "P731m(0x103C-0x1926)"},
{0x103C, 0x323C, 0x103C, 0x1928, "P230i(0x103C-0x1928)"},
{0x103C, 0x3300, 0xFFFF, 0xFFFF, "Integrated Lights-Out Standard Virtual USB Controller(0x3300)"},
{0x103C, 0x3300, 0x103C, 0x3304, "iLO2(0x103C-0x3304)"},
{0x103C, 0x3300, 0x103C, 0x3305, "iLO2(0x103C-0x3305)"},
{0x103C, 0x3300, 0x103C, 0x3309, "iLO2 GXL/iLO3 GXE(0x103C-0x3309)"},
{0x103C, 0x3300, 0x103C, 0x330E, "iLO3(0x103C-0x330E)"},
{0x103C, 0x3300, 0x103C, 0x3381, "iLO4(0x103C-0x3381)"},
{0x103C, 0x3301, 0xFFFF, 0xFFFF, "Integrated Lights-Out Standard Serial Port(0x3301)"},
{0x103C, 0x3301, 0x103C, 0x3304, "iLO2(0x103C-0x3304)"},
{0x103C, 0x3301, 0x103C, 0x3305, "iLO2(0x103C-0x3305)"},
{0x103C, 0x3301, 0x103C, 0x330E, "iLO3(0x103C-0x330E)"},
{0x103C, 0x3301, 0x103C, 0x3381, "iLO4(0x103C-0x3381)"},
{0x103C, 0x3302, 0xFFFF, 0xFFFF, "Integrated Lights-Out Standard KCS Interface(0x3302)"},
{0x103C, 0x3302, 0x103C, 0x3304, "iLO2(0x103C-0x3304)"},
{0x103C, 0x3302, 0x103C, 0x3305, "iLO2(0x103C-0x3305)"},
{0x103C, 0x3302, 0x103C, 0x330E, "iLO3(0x103C-0x330E)"},
{0x103C, 0x3302, 0x103C, 0x3381, "iLO4(0x103C-0x3381)"},
{0x103C, 0x3305, 0xFFFF, 0xFFFF, "Integrated Lights-Out (iLO2) Controller(0x3305)"},
{0x103C, 0x3306, 0xFFFF, 0xFFFF, "Integrated Lights-Out Standard Slave Instrumentation & System Support(0x3306)"},
{0x103C, 0x3306, 0x103C, 0x330E, "iLO3(0x103C-0x330E)"},
{0x103C, 0x3306, 0x103C, 0x3381, "iLO4(0x103C-0x3381)"},
{0x103C, 0x3306, 0x1590, 0x00E4, "iLO5(0x1590-0x00E4)"},
{0x103C, 0x3307, 0xFFFF, 0xFFFF, "Integrated Lights-Out Standard Management Processor Support and Messaging(0x3307)"},
{0x103C, 0x3307, 0x103C, 0x3309, "iLO 2(0x103C-0x3309)"},
{0x103C, 0x3307, 0x103C, 0x330E, "iLO3(0x103C-0x330E)"},
{0x103C, 0x3307, 0x103C, 0x3381, "iLO4(0x103C-0x3381)"},
{0x103C, 0x3308, 0xFFFF, 0xFFFF, "Integrated Lights-Out Standard MS Watchdog Timer(0x3308)"},
{0x103C, 0x3308, 0x103C, 0x330E, "iLO3(0x103C-0x330E)"},
{0x103C, 0x3308, 0x103C, 0x3381, "iLO4(0x103C-0x3381)"},
{0x103C, 0x4030, 0xFFFF, 0xFFFF, "zx2 System Bus Adapter(0x4030)"},
{0x103C, 0x4031, 0xFFFF, 0xFFFF, "zx2 I/O Controller(0x4031)"},
{0x103C, 0x4037, 0xFFFF, 0xFFFF, "PCIe Local Bus Adapter(0x4037)"},
{0x103C, 0x9602, 0xFFFF, 0xFFFF, "AMD RS780/RS880 PCI to PCI bridge (int gfx)(0x9602)"},
{0x103C, 0x9602, 0x103C, 0x1609, "ProLiant MicroServer N36L(0x103C-0x1609)"},
}; /* pci_vid_103C[] */

static pci_id_t const pci_vid_103E[] = {
{0x103E, 0xFFFF, 0xFFFF, 0xFFFF, "Solliday Engineering(0x103E)"},
}; /* pci_vid_103E[] */

static pci_id_t const pci_vid_103F[] = {
{0x103F, 0xFFFF, 0xFFFF, 0xFFFF, "Synopsys/Logic Modeling Group(0x103F)"},
}; /* pci_vid_103F[] */

static pci_id_t const pci_vid_1040[] = {
{0x1040, 0xFFFF, 0xFFFF, 0xFFFF, "Accelgraphics Inc.(0x1040)"},
}; /* pci_vid_1040[] */

static pci_id_t const pci_vid_1041[] = {
{0x1041, 0xFFFF, 0xFFFF, 0xFFFF, "Computrend(0x1041)"},
}; /* pci_vid_1041[] */

static pci_id_t const pci_vid_1042[] = {
{0x1042, 0xFFFF, 0xFFFF, 0xFFFF, "Micron(0x1042)"},
{0x1042, 0x1000, 0xFFFF, 0xFFFF, "PC Tech RZ1000(0x1000)"},
{0x1042, 0x1001, 0xFFFF, 0xFFFF, "PC Tech RZ1001(0x1001)"},
{0x1042, 0x3000, 0xFFFF, 0xFFFF, "Samurai_0(0x3000)"},
{0x1042, 0x3010, 0xFFFF, 0xFFFF, "Samurai_1(0x3010)"},
{0x1042, 0x3020, 0xFFFF, 0xFFFF, "Samurai_IDE(0x3020)"},
}; /* pci_vid_1042[] */

static pci_id_t const pci_vid_1043[] = {
{0x1043, 0xFFFF, 0xFFFF, 0xFFFF, "ASUSTeK Computer Inc.(0x1043)"},
{0x1043, 0x0675, 0xFFFF, 0xFFFF, "ISDNLink P-IN100-ST-D(0x0675)"},
{0x1043, 0x0675, 0x0675, 0x1704, "ISDN Adapter (PCI Bus, D, C)(0x0675-0x1704)"},
{0x1043, 0x0675, 0x0675, 0x1707, "ISDN Adapter (PCI Bus, DV, W)(0x0675-0x1707)"},
{0x1043, 0x0675, 0x10CF, 0x105E, "ISDN Adapter (PCI Bus, DV, W)(0x10CF-0x105E)"},
{0x1043, 0x9602, 0xFFFF, 0xFFFF, "AMD RS780/RS880 PCI to PCI bridge (int gfx)(0x9602)"},
{0x1043, 0x9602, 0x1043, 0x83A2, "M4A785TD Motherboard(0x1043-0x83A2)"},
}; /* pci_vid_1043[] */

static pci_id_t const pci_vid_1044[] = {
{0x1044, 0xFFFF, 0xFFFF, 0xFFFF, "Adaptec (formerly DPT)(0x1044)"},
{0x1044, 0x1012, 0xFFFF, 0xFFFF, "Domino RAID Engine(0x1012)"},
{0x1044, 0xA400, 0xFFFF, 0xFFFF, "SmartCache/Raid I-IV Controller(0xA400)"},
{0x1044, 0xA500, 0xFFFF, 0xFFFF, "PCI Bridge(0xA500)"},
{0x1044, 0xA501, 0xFFFF, 0xFFFF, "SmartRAID V Controller(0xA501)"},
{0x1044, 0xA501, 0x1044, 0xC001, "PM1554U2 Ultra2 Single Channel(0x1044-0xC001)"},
{0x1044, 0xA501, 0x1044, 0xC002, "PM1654U2 Ultra2 Single Channel(0x1044-0xC002)"},
{0x1044, 0xA501, 0x1044, 0xC003, "PM1564U3 Ultra3 Single Channel(0x1044-0xC003)"},
{0x1044, 0xA501, 0x1044, 0xC004, "PM1564U3 Ultra3 Dual Channel(0x1044-0xC004)"},
{0x1044, 0xA501, 0x1044, 0xC005, "PM1554U2 Ultra2 Single Channel (NON ACPI)(0x1044-0xC005)"},
{0x1044, 0xA501, 0x1044, 0xC00A, "PM2554U2 Ultra2 Single Channel(0x1044-0xC00A)"},
{0x1044, 0xA501, 0x1044, 0xC00B, "PM2654U2 Ultra2 Single Channel(0x1044-0xC00B)"},
{0x1044, 0xA501, 0x1044, 0xC00C, "PM2664U3 Ultra3 Single Channel(0x1044-0xC00C)"},
{0x1044, 0xA501, 0x1044, 0xC00D, "PM2664U3 Ultra3 Dual Channel(0x1044-0xC00D)"},
{0x1044, 0xA501, 0x1044, 0xC00E, "PM2554U2 Ultra2 Single Channel (NON ACPI)(0x1044-0xC00E)"},
{0x1044, 0xA501, 0x1044, 0xC00F, "PM2654U2 Ultra2 Single Channel (NON ACPI)(0x1044-0xC00F)"},
{0x1044, 0xA501, 0x1044, 0xC014, "PM3754U2 Ultra2 Single Channel (NON ACPI)(0x1044-0xC014)"},
{0x1044, 0xA501, 0x1044, 0xC015, "PM3755U2B Ultra2 Single Channel (NON ACPI)(0x1044-0xC015)"},
{0x1044, 0xA501, 0x1044, 0xC016, "PM3755F Fibre Channel (NON ACPI)(0x1044-0xC016)"},
{0x1044, 0xA501, 0x1044, 0xC01E, "PM3757U2 Ultra2 Single Channel(0x1044-0xC01E)"},
{0x1044, 0xA501, 0x1044, 0xC01F, "PM3757U2 Ultra2 Dual Channel(0x1044-0xC01F)"},
{0x1044, 0xA501, 0x1044, 0xC020, "PM3767U3 Ultra3 Dual Channel(0x1044-0xC020)"},
{0x1044, 0xA501, 0x1044, 0xC021, "PM3767U3 Ultra3 Quad Channel(0x1044-0xC021)"},
{0x1044, 0xA501, 0x1044, 0xC028, "PM2865U3 Ultra3 Single Channel(0x1044-0xC028)"},
{0x1044, 0xA501, 0x1044, 0xC029, "PM2865U3 Ultra3 Dual Channel(0x1044-0xC029)"},
{0x1044, 0xA501, 0x1044, 0xC02A, "PM2865F Fibre Channel(0x1044-0xC02A)"},
{0x1044, 0xA501, 0x1044, 0xC03C, "2000S Ultra3 Single Channel(0x1044-0xC03C)"},
{0x1044, 0xA501, 0x1044, 0xC03D, "2000S Ultra3 Dual Channel(0x1044-0xC03D)"},
{0x1044, 0xA501, 0x1044, 0xC03E, "2000F Fibre Channel(0x1044-0xC03E)"},
{0x1044, 0xA501, 0x1044, 0xC046, "3000S Ultra3 Single Channel(0x1044-0xC046)"},
{0x1044, 0xA501, 0x1044, 0xC047, "3000S Ultra3 Dual Channel(0x1044-0xC047)"},
{0x1044, 0xA501, 0x1044, 0xC048, "3000F Fibre Channel(0x1044-0xC048)"},
{0x1044, 0xA501, 0x1044, 0xC050, "5000S Ultra3 Single Channel(0x1044-0xC050)"},
{0x1044, 0xA501, 0x1044, 0xC051, "5000S Ultra3 Dual Channel(0x1044-0xC051)"},
{0x1044, 0xA501, 0x1044, 0xC052, "5000F Fibre Channel(0x1044-0xC052)"},
{0x1044, 0xA501, 0x1044, 0xC05A, "2400A UDMA Four Channel(0x1044-0xC05A)"},
{0x1044, 0xA501, 0x1044, 0xC05B, "2400A UDMA Four Channel DAC(0x1044-0xC05B)"},
{0x1044, 0xA501, 0x1044, 0xC064, "3010S Ultra3 Dual Channel(0x1044-0xC064)"},
{0x1044, 0xA501, 0x1044, 0xC065, "3410S Ultra160 Four Channel(0x1044-0xC065)"},
{0x1044, 0xA501, 0x1044, 0xC066, "3010S Fibre Channel(0x1044-0xC066)"},
{0x1044, 0xA511, 0xFFFF, 0xFFFF, "SmartRAID V Controller(0xA511)"},
{0x1044, 0xA511, 0x1044, 0xC032, "ASR-2005S I2O Zero Channel(0x1044-0xC032)"},
{0x1044, 0xA511, 0x1044, 0xC035, "ASR-2010S I2O Zero Channel(0x1044-0xC035)"},
{0x1044, 0xC066, 0xFFFF, 0xFFFF, "3010S Ultra3 Dual Channel(0xC066)"},
}; /* pci_vid_1044[] */

static pci_id_t const pci_vid_1045[] = {
{0x1045, 0xFFFF, 0xFFFF, 0xFFFF, "OPTi Inc.(0x1045)"},
{0x1045, 0xA0F8, 0xFFFF, 0xFFFF, "82C750 [Vendetta] USB Controller(0xA0F8)"},
{0x1045, 0xC101, 0xFFFF, 0xFFFF, "92C264(0xC101)"},
{0x1045, 0xC178, 0xFFFF, 0xFFFF, "92C178(0xC178)"},
{0x1045, 0xC556, 0xFFFF, 0xFFFF, "82X556 [Viper](0xC556)"},
{0x1045, 0xC557, 0xFFFF, 0xFFFF, "82C557 [Viper-M](0xC557)"},
{0x1045, 0xC558, 0xFFFF, 0xFFFF, "82C558 [Viper-M ISA+IDE](0xC558)"},
{0x1045, 0xC567, 0xFFFF, 0xFFFF, "82C750 [Vendetta], device 0(0xC567)"},
{0x1045, 0xC568, 0xFFFF, 0xFFFF, "82C750 [Vendetta], device 1(0xC568)"},
{0x1045, 0xC569, 0xFFFF, 0xFFFF, "82C579 [Viper XPress+ Chipset](0xC569)"},
{0x1045, 0xC621, 0xFFFF, 0xFFFF, "82C621 [Viper-M/N+](0xC621)"},
{0x1045, 0xC700, 0xFFFF, 0xFFFF, "82C700 [FireStar](0xC700)"},
{0x1045, 0xC701, 0xFFFF, 0xFFFF, "82C701 [FireStar Plus](0xC701)"},
{0x1045, 0xC814, 0xFFFF, 0xFFFF, "82C814 [Firebridge 1](0xC814)"},
{0x1045, 0xC822, 0xFFFF, 0xFFFF, "82C822(0xC822)"},
{0x1045, 0xC824, 0xFFFF, 0xFFFF, "82C824(0xC824)"},
{0x1045, 0xC825, 0xFFFF, 0xFFFF, "82C825 [Firebridge 2](0xC825)"},
{0x1045, 0xC832, 0xFFFF, 0xFFFF, "82C832(0xC832)"},
{0x1045, 0xC861, 0xFFFF, 0xFFFF, "82C861 OHCI USB Host(0xC861)"},
{0x1045, 0xC881, 0xFFFF, 0xFFFF, "82C881 [FireLink] 1394 OHCI Link Controller(0xC881)"},
{0x1045, 0xC895, 0xFFFF, 0xFFFF, "82C895(0xC895)"},
{0x1045, 0xC935, 0xFFFF, 0xFFFF, "EV1935 ECTIVA MachOne PCIAudio(0xC935)"},
{0x1045, 0xD568, 0xFFFF, 0xFFFF, "82C825 [Firebridge 2](0xD568)"},
{0x1045, 0xD721, 0xFFFF, 0xFFFF, "IDE [FireStar](0xD721)"},
}; /* pci_vid_1045[] */

static pci_id_t const pci_vid_1046[] = {
{0x1046, 0xFFFF, 0xFFFF, 0xFFFF, "IPC Corporation, Ltd.(0x1046)"},
}; /* pci_vid_1046[] */

static pci_id_t const pci_vid_1047[] = {
{0x1047, 0xFFFF, 0xFFFF, 0xFFFF, "Genoa Systems Corp(0x1047)"},
}; /* pci_vid_1047[] */

static pci_id_t const pci_vid_1048[] = {
{0x1048, 0xFFFF, 0xFFFF, 0xFFFF, "Elsa AG(0x1048)"},
{0x1048, 0x0C60, 0xFFFF, 0xFFFF, "Gladiac MX(0x0C60)"},
{0x1048, 0x0D22, 0xFFFF, 0xFFFF, "Quadro4 900XGL [ELSA GLoria4 900XGL](0x0D22)"},
{0x1048, 0x1000, 0xFFFF, 0xFFFF, "QuickStep 1000(0x1000)"},
{0x1048, 0x3000, 0xFFFF, 0xFFFF, "QuickStep 3000(0x3000)"},
{0x1048, 0x8901, 0xFFFF, 0xFFFF, "Gloria XL(0x8901)"},
{0x1048, 0x8901, 0x1048, 0x0935, "GLoria XL (Virge)(0x1048-0x0935)"},
}; /* pci_vid_1048[] */

static pci_id_t const pci_vid_1049[] = {
{0x1049, 0xFFFF, 0xFFFF, 0xFFFF, "Fountain Technologies, Inc.(0x1049)"},
}; /* pci_vid_1049[] */

static pci_id_t const pci_vid_104A[] = {
{0x104A, 0xFFFF, 0xFFFF, 0xFFFF, "STMicroelectronics(0x104A)"},
{0x104A, 0x0000, 0xFFFF, 0xFFFF, "STLS2F Host Bridge(0x0000)"},
{0x104A, 0x0008, 0xFFFF, 0xFFFF, "STG 2000X(0x0008)"},
{0x104A, 0x0009, 0xFFFF, 0xFFFF, "STG 1764X(0x0009)"},
{0x104A, 0x0010, 0xFFFF, 0xFFFF, "STG4000 [3D Prophet Kyro Series](0x0010)"},
{0x104A, 0x0010, 0x104A, 0x4018, "ST PowerVR Kyro (64MB AGP TVO)(0x104A-0x4018)"},
{0x104A, 0x0010, 0x1681, 0x0010, "PowerVR Kyro II [3D Prophet 4500](0x1681-0x0010)"},
{0x104A, 0x0010, 0x1681, 0x0028, "3D Prophet 4000XT(0x1681-0x0028)"},
{0x104A, 0x0010, 0x1681, 0xC010, "3D Prophet 4500 TV-Out(0x1681-0xC010)"},
{0x104A, 0x0010, 0x1681, 0xC069, "3D Prophet 4000XT(0x1681-0xC069)"},
{0x104A, 0x0201, 0xFFFF, 0xFFFF, "STPC Vega Northbridge(0x0201)"},
{0x104A, 0x0209, 0xFFFF, 0xFFFF, "STPC Consumer/Industrial North- and Southbridge(0x0209)"},
{0x104A, 0x020A, 0xFFFF, 0xFFFF, "STPC Atlas/ConsumerS/Consumer IIA Northbridge(0x020A)"},
{0x104A, 0x020B, 0xFFFF, 0xFFFF, "STPC Consumer II ISA Bridge(0x020B)"},
{0x104A, 0x0210, 0xFFFF, 0xFFFF, "STPC Atlas ISA Bridge(0x0210)"},
{0x104A, 0x021A, 0xFFFF, 0xFFFF, "STPC Consumer S Southbridge(0x021A)"},
{0x104A, 0x021B, 0xFFFF, 0xFFFF, "STPC Consumer IIA Southbridge(0x021B)"},
{0x104A, 0x0220, 0xFFFF, 0xFFFF, "STPC Industrial PCI to PCCard bridge(0x0220)"},
{0x104A, 0x0228, 0xFFFF, 0xFFFF, "STPC Atlas IDE(0x0228)"},
{0x104A, 0x0229, 0xFFFF, 0xFFFF, "STPC Vega IDE(0x0229)"},
{0x104A, 0x0230, 0xFFFF, 0xFFFF, "STPC Atlas/Vega OHCI USB Controller(0x0230)"},
{0x104A, 0x0238, 0xFFFF, 0xFFFF, "STPC Vega LAN(0x0238)"},
{0x104A, 0x0500, 0xFFFF, 0xFFFF, "ST70137 [Unicorn] ADSL DMT Transceiver(0x0500)"},
{0x104A, 0x0500, 0x104A, 0x0500, "BeWAN ADSL PCI st(0x104A-0x0500)"},
{0x104A, 0x0564, 0xFFFF, 0xFFFF, "STPC Client Northbridge(0x0564)"},
{0x104A, 0x0981, 0xFFFF, 0xFFFF, "21x4x DEC-Tulip compatible 10/100 Ethernet(0x0981)"},
{0x104A, 0x1746, 0xFFFF, 0xFFFF, "STG 1764X(0x1746)"},
{0x104A, 0x2774, 0xFFFF, 0xFFFF, "21x4x DEC-Tulip compatible 10/100 Ethernet(0x2774)"},
{0x104A, 0x3520, 0xFFFF, 0xFFFF, "MPEG-II decoder card(0x3520)"},
{0x104A, 0x55CC, 0xFFFF, 0xFFFF, "STPC Client Southbridge(0x55CC)"},
}; /* pci_vid_104A[] */

static pci_id_t const pci_vid_104B[] = {
{0x104B, 0xFFFF, 0xFFFF, 0xFFFF, "BusLogic(0x104B)"},
{0x104B, 0x0140, 0xFFFF, 0xFFFF, "BT-946C (old) [multimaster  01](0x0140)"},
{0x104B, 0x1040, 0xFFFF, 0xFFFF, "BT-946C (BA80C30) [MultiMaster 10](0x1040)"},
{0x104B, 0x8130, 0xFFFF, 0xFFFF, "Flashpoint LT(0x8130)"},
}; /* pci_vid_104B[] */

static pci_id_t const pci_vid_104C[] = {
{0x104C, 0xFFFF, 0xFFFF, 0xFFFF, "Texas Instruments(0x104C)"},
{0x104C, 0x0500, 0xFFFF, 0xFFFF, "100 MBit LAN Controller(0x0500)"},
{0x104C, 0x0508, 0xFFFF, 0xFFFF, "TMS380C2X Compressor Interface(0x0508)"},
{0x104C, 0x1000, 0xFFFF, 0xFFFF, "Eagle i/f AS(0x1000)"},
{0x104C, 0x104C, 0xFFFF, 0xFFFF, "PCI1510 PC card Cardbus Controller(0x104C)"},
{0x104C, 0x3D04, 0xFFFF, 0xFFFF, "TVP4010 [Permedia](0x3D04)"},
{0x104C, 0x3D07, 0xFFFF, 0xFFFF, "TVP4020 [Permedia 2](0x3D07)"},
{0x104C, 0x3D07, 0x1011, 0x4D10, "Comet(0x1011-0x4D10)"},
{0x104C, 0x3D07, 0x1040, 0x000F, "AccelStar II(0x1040-0x000F)"},
{0x104C, 0x3D07, 0x1040, 0x0011, "AccelStar II(0x1040-0x0011)"},
{0x104C, 0x3D07, 0x1048, 0x0A31, "WINNER 2000(0x1048-0x0A31)"},
{0x104C, 0x3D07, 0x1048, 0x0A32, "GLoria Synergy(0x1048-0x0A32)"},
{0x104C, 0x3D07, 0x1048, 0x0A34, "GLoria Synergy(0x1048-0x0A34)"},
{0x104C, 0x3D07, 0x1048, 0x0A35, "GLoria Synergy(0x1048-0x0A35)"},
{0x104C, 0x3D07, 0x1048, 0x0A36, "GLoria Synergy(0x1048-0x0A36)"},
{0x104C, 0x3D07, 0x1048, 0x0A43, "GLoria Synergy(0x1048-0x0A43)"},
{0x104C, 0x3D07, 0x1048, 0x0A44, "GLoria Synergy(0x1048-0x0A44)"},
{0x104C, 0x3D07, 0x107D, 0x2633, "WinFast 3D L2300(0x107D-0x2633)"},
{0x104C, 0x3D07, 0x1092, 0x0126, "FIRE GL 1000 PRO(0x1092-0x0126)"},
{0x104C, 0x3D07, 0x1092, 0x0127, "FIRE GL 1000 PRO(0x1092-0x0127)"},
{0x104C, 0x3D07, 0x1092, 0x0136, "FIRE GL 1000 PRO(0x1092-0x0136)"},
{0x104C, 0x3D07, 0x1092, 0x0141, "FIRE GL 1000 PRO(0x1092-0x0141)"},
{0x104C, 0x3D07, 0x1092, 0x0146, "FIRE GL 1000 PRO(0x1092-0x0146)"},
{0x104C, 0x3D07, 0x1092, 0x0148, "FIRE GL 1000 PRO(0x1092-0x0148)"},
{0x104C, 0x3D07, 0x1092, 0x0149, "FIRE GL 1000 PRO(0x1092-0x0149)"},
{0x104C, 0x3D07, 0x1092, 0x0152, "FIRE GL 1000 PRO(0x1092-0x0152)"},
{0x104C, 0x3D07, 0x1092, 0x0154, "FIRE GL 1000 PRO(0x1092-0x0154)"},
{0x104C, 0x3D07, 0x1092, 0x0155, "FIRE GL 1000 PRO(0x1092-0x0155)"},
{0x104C, 0x3D07, 0x1092, 0x0156, "FIRE GL 1000 PRO(0x1092-0x0156)"},
{0x104C, 0x3D07, 0x1092, 0x0157, "FIRE GL 1000 PRO(0x1092-0x0157)"},
{0x104C, 0x3D07, 0x1097, 0x3D01, "Jeronimo Pro(0x1097-0x3D01)"},
{0x104C, 0x3D07, 0x1102, 0x100F, "Graphics Blaster Extreme(0x1102-0x100F)"},
{0x104C, 0x3D07, 0x3D3D, 0x0100, "Reference Permedia 2 3D(0x3D3D-0x0100)"},
{0x104C, 0x8000, 0xFFFF, 0xFFFF, "PCILynx/PCILynx2 IEEE 1394 Link Layer Controller(0x8000)"},
{0x104C, 0x8000, 0x105E, 0x8003, "FireBoard200(0x105E-0x8003)"},
{0x104C, 0x8000, 0x1443, 0x8003, "FireBoard200(0x1443-0x8003)"},
{0x104C, 0x8000, 0x1443, 0x8005, "FireBoard400(0x1443-0x8005)"},
{0x104C, 0x8000, 0x1443, 0x8006, "FireBoard400(0x1443-0x8006)"},
{0x104C, 0x8000, 0xE4BF, 0x1010, "CF1-1-SNARE(0xE4BF-0x1010)"},
{0x104C, 0x8000, 0xE4BF, 0x1020, "CF1-2-SNARE(0xE4BF-0x1020)"},
{0x104C, 0x8000, 0xE4BF, 0x1040, "FireCompact400(0xE4BF-0x1040)"},
{0x104C, 0x8009, 0xFFFF, 0xFFFF, "TSB12LV22 IEEE-1394 Controller(0x8009)"},
{0x104C, 0x8009, 0x104D, 0x8032, "8032 OHCI i.LINK (IEEE 1394) Controller(0x104D-0x8032)"},
{0x104C, 0x8009, 0x1443, 0x8010, "FireBoard400-OHCI(0x1443-0x8010)"},
{0x104C, 0x8017, 0xFFFF, 0xFFFF, "PCI4410 FireWire Controller(0x8017)"},
{0x104C, 0x8019, 0xFFFF, 0xFFFF, "TSB12LV23 IEEE-1394 Controller(0x8019)"},
{0x104C, 0x8019, 0x11BD, 0x000A, "Studio DV500-1394(0x11BD-0x000A)"},
{0x104C, 0x8019, 0x11BD, 0x000E, "Studio DV(0x11BD-0x000E)"},
{0x104C, 0x8019, 0x1443, 0x8010, "FireBoard400-OHCI(0x1443-0x8010)"},
{0x104C, 0x8019, 0xE4BF, 0x1010, "CF2-1-CYMBAL(0xE4BF-0x1010)"},
{0x104C, 0x8020, 0xFFFF, 0xFFFF, "TSB12LV26 IEEE-1394 Controller (Link)(0x8020)"},
{0x104C, 0x8020, 0x1028, 0x00D8, "Precision 530(0x1028-0x00D8)"},
{0x104C, 0x8020, 0x104D, 0x80E2, "VAIO PCV-J200(0x104D-0x80E2)"},
{0x104C, 0x8020, 0x11BD, 0x000F, "Studio DV500-1394(0x11BD-0x000F)"},
{0x104C, 0x8020, 0x11BD, 0x001C, "Excalibur 4.1(0x11BD-0x001C)"},
{0x104C, 0x8020, 0x1443, 0x8010, "FireBoard400-OHCI(0x1443-0x8010)"},
{0x104C, 0x8021, 0xFFFF, 0xFFFF, "TSB43AA22 IEEE-1394 Controller (PHY/Link Integrated)(0x8021)"},
{0x104C, 0x8021, 0x104D, 0x80DF, "Vaio PCG-FX403(0x104D-0x80DF)"},
{0x104C, 0x8021, 0x104D, 0x80E7, "VAIO PCG-GR214EP/GR214MP/GR215MP/GR314MP/GR315MP(0x104D-0x80E7)"},
{0x104C, 0x8022, 0xFFFF, 0xFFFF, "TSB43AB22 IEEE-1394a-2000 Controller (PHY/Link) [iOHCI-Lynx](0x8022)"},
{0x104C, 0x8022, 0x104C, 0x8023, "TSB43AB22/A IEEE-1394a-2000 Controller (PHY/Link)(0x104C-0x8023)"},
{0x104C, 0x8023, 0xFFFF, 0xFFFF, "TSB43AB22A IEEE-1394a-2000 Controller (PHY/Link) [iOHCI-Lynx](0x8023)"},
{0x104C, 0x8023, 0x1028, 0x0168, "Precision Workstation 670 Mainboard(0x1028-0x0168)"},
{0x104C, 0x8023, 0x103C, 0x088C, "NC8000 laptop(0x103C-0x088C)"},
{0x104C, 0x8023, 0x1043, 0x808B, "K8N4/A8N Series Mainboard(0x1043-0x808B)"},
{0x104C, 0x8023, 0x1043, 0x815B, "P5W DH Deluxe Motherboard(0x1043-0x815B)"},
{0x104C, 0x8023, 0x1443, 0x8023, "FireCard400(0x1443-0x8023)"},
{0x104C, 0x8023, 0x8086, 0x5044, "Desktop Board DP35DP(0x8086-0x5044)"},
{0x104C, 0x8024, 0xFFFF, 0xFFFF, "TSB43AB23 IEEE-1394a-2000 Controller (PHY/Link)(0x8024)"},
{0x104C, 0x8024, 0x107D, 0x6620, "Winfast DV2000 FireWire Controller(0x107D-0x6620)"},
{0x104C, 0x8024, 0x1443, 0x8024, "FireBoard Blue(0x1443-0x8024)"},
{0x104C, 0x8024, 0x1458, 0x1000, "Motherboard(0x1458-0x1000)"},
{0x104C, 0x8025, 0xFFFF, 0xFFFF, "TSB82AA2 IEEE-1394b Link Layer Controller(0x8025)"},
{0x104C, 0x8025, 0x1043, 0x813C, "P5P series mainboard(0x1043-0x813C)"},
{0x104C, 0x8025, 0x1443, 0x8025, "FireBoard800(0x1443-0x8025)"},
{0x104C, 0x8025, 0x1458, 0x1000, "GA-K8N Ultra-9 Mainboard(0x1458-0x1000)"},
{0x104C, 0x8025, 0x1546, 0x8025, "FWB-PCI01(0x1546-0x8025)"},
{0x104C, 0x8025, 0x17FC, 0x8025, "GIC3800(0x17FC-0x8025)"},
{0x104C, 0x8026, 0xFFFF, 0xFFFF, "TSB43AB21 IEEE-1394a-2000 Controller (PHY/Link)(0x8026)"},
{0x104C, 0x8026, 0x1025, 0x0035, "TravelMate 660(0x1025-0x0035)"},
{0x104C, 0x8026, 0x1025, 0x003C, "Aspire 2001WLCi (Compaq CL50 motherboard)(0x1025-0x003C)"},
{0x104C, 0x8026, 0x103C, 0x0025, "XE4500 Notebook(0x103C-0x0025)"},
{0x104C, 0x8026, 0x103C, 0x006A, "NX9500(0x103C-0x006A)"},
{0x104C, 0x8026, 0x1043, 0x808D, "A7V333 mainboard.(0x1043-0x808D)"},
{0x104C, 0x8027, 0xFFFF, 0xFFFF, "PCI4451 IEEE-1394 Controller(0x8027)"},
{0x104C, 0x8027, 0x1028, 0x00E5, "Latitude C810(0x1028-0x00E5)"},
{0x104C, 0x8027, 0x1028, 0x00E6, "PCI4451 IEEE-1394 Controller (Dell Inspiron 8100)(0x1028-0x00E6)"},
{0x104C, 0x8029, 0xFFFF, 0xFFFF, "PCI4510 IEEE-1394 Controller(0x8029)"},
{0x104C, 0x8029, 0x1028, 0x0163, "Latitude D505(0x1028-0x0163)"},
{0x104C, 0x8029, 0x1028, 0x0196, "Inspiron 5160(0x1028-0x0196)"},
{0x104C, 0x8029, 0x1071, 0x8160, "MIM2900(0x1071-0x8160)"},
{0x104C, 0x802B, 0xFFFF, 0xFFFF, "PCI7410,7510,7610 OHCI-Lynx Controller(0x802B)"},
{0x104C, 0x802B, 0x1028, 0x0139, "Latitude D400(0x1028-0x0139)"},
{0x104C, 0x802B, 0x1028, 0x014E, "PCI7410,7510,7610 OHCI-Lynx Controller (Latitude D800)(0x1028-0x014E)"},
{0x104C, 0x802E, 0xFFFF, 0xFFFF, "PCI7x20 1394a-2000 OHCI Two-Port PHY/Link-Layer Controller(0x802E)"},
{0x104C, 0x802E, 0x1028, 0x018D, "Inspiron 700m/710m(0x1028-0x018D)"},
{0x104C, 0x8031, 0xFFFF, 0xFFFF, "PCIxx21/PCIxx11/PCIx515 PC Card Controller(0x8031)"},
{0x104C, 0x8031, 0x1025, 0x0064, "Extensa 3000 series laptop(0x1025-0x0064)"},
{0x104C, 0x8031, 0x1025, 0x0080, "Aspire 5024WLMi(0x1025-0x0080)"},
{0x104C, 0x8031, 0x103C, 0x0934, "Compaq nw8240/nx8220(0x103C-0x0934)"},
{0x104C, 0x8031, 0x103C, 0x0944, "Compaq nc6220 Notebook PC(0x103C-0x0944)"},
{0x104C, 0x8031, 0x103C, 0x099C, "NX6110/NC6120(0x103C-0x099C)"},
{0x104C, 0x8031, 0x103C, 0x308B, "MX6125(0x103C-0x308B)"},
{0x104C, 0x8032, 0xFFFF, 0xFFFF, "OHCI Compliant IEEE 1394 Host Controller(0x8032)"},
{0x104C, 0x8032, 0x1025, 0x0064, "Extensa 3000 series laptop(0x1025-0x0064)"},
{0x104C, 0x8032, 0x1025, 0x0080, "Aspire 5024WLMi(0x1025-0x0080)"},
{0x104C, 0x8032, 0x103C, 0x0934, "Compaq nw8240/nx8220(0x103C-0x0934)"},
{0x104C, 0x8032, 0x103C, 0x099C, "NX6110/NC6120(0x103C-0x099C)"},
{0x104C, 0x8032, 0x103C, 0x308B, "MX6125(0x103C-0x308B)"},
{0x104C, 0x8033, 0xFFFF, 0xFFFF, "PCIxx21/PCIxx11 Flash Media Controller(0x8033)"},
{0x104C, 0x8033, 0x1025, 0x0064, "Extensa 3000 series laptop(0x1025-0x0064)"},
{0x104C, 0x8033, 0x1025, 0x0080, "Aspire 5024WLMi(0x1025-0x0080)"},
{0x104C, 0x8033, 0x103C, 0x0934, "Compaq nw8240/nx8220(0x103C-0x0934)"},
{0x104C, 0x8033, 0x103C, 0x0944, "Compaq nc6220 Notebook PC(0x103C-0x0944)"},
{0x104C, 0x8033, 0x103C, 0x099C, "NX6110/NC6120(0x103C-0x099C)"},
{0x104C, 0x8033, 0x103C, 0x308B, "MX6125(0x103C-0x308B)"},
{0x104C, 0x8034, 0xFFFF, 0xFFFF, "PCIxx21/PCIxx11 SD Host Controller(0x8034)"},
{0x104C, 0x8034, 0x1025, 0x0080, "Aspire 5024WLMi(0x1025-0x0080)"},
{0x104C, 0x8034, 0x103C, 0x0934, "Compaq nw8240/nx8220(0x103C-0x0934)"},
{0x104C, 0x8034, 0x103C, 0x0944, "Compaq nc6220 Notebook PC(0x103C-0x0944)"},
{0x104C, 0x8034, 0x103C, 0x099C, "NX6110/NC6120(0x103C-0x099C)"},
{0x104C, 0x8034, 0x103C, 0x308B, "MX6125(0x103C-0x308B)"},
{0x104C, 0x8035, 0xFFFF, 0xFFFF, "PCIxx21/PCIxx11 Smart Card Controller(0x8035)"},
{0x104C, 0x8035, 0x103C, 0x0934, "Compaq nw8240/nx8220(0x103C-0x0934)"},
{0x104C, 0x8035, 0x103C, 0x0944, "Compaq nc6220 Notebook PC(0x103C-0x0944)"},
{0x104C, 0x8035, 0x103C, 0x099C, "NX6110/NC6120(0x103C-0x099C)"},
{0x104C, 0x8036, 0xFFFF, 0xFFFF, "PCI6515 Cardbus Controller(0x8036)"},
{0x104C, 0x8038, 0xFFFF, 0xFFFF, "PCI6515 SmartCard Controller(0x8038)"},
{0x104C, 0x8039, 0xFFFF, 0xFFFF, "PCIxx12 Cardbus Controller(0x8039)"},
{0x104C, 0x8039, 0x103C, 0x309F, "Compaq nx9420 Notebook(0x103C-0x309F)"},
{0x104C, 0x8039, 0x103C, 0x30A1, "NC2400(0x103C-0x30A1)"},
{0x104C, 0x8039, 0x103C, 0x30A3, "Compaq nw8440(0x103C-0x30A3)"},
{0x104C, 0x8039, 0x104D, 0x902D, "VAIO VGN-NR120E(0x104D-0x902D)"},
{0x104C, 0x803A, 0xFFFF, 0xFFFF, "PCIxx12 OHCI Compliant IEEE 1394 Host Controller(0x803A)"},
{0x104C, 0x803A, 0x103C, 0x309F, "nx9420(0x103C-0x309F)"},
{0x104C, 0x803A, 0x103C, 0x30A1, "NC2400(0x103C-0x30A1)"},
{0x104C, 0x803A, 0x103C, 0x30A3, "Compaq nw8440(0x103C-0x30A3)"},
{0x104C, 0x803A, 0x104D, 0x902D, "VAIO VGN-NR120E(0x104D-0x902D)"},
{0x104C, 0x803B, 0xFFFF, 0xFFFF, "PCIxx12 Flash Media Controller(0x803B)"},
{0x104C, 0x803B, 0x103C, 0x309F, "nx9420(0x103C-0x309F)"},
{0x104C, 0x803B, 0x103C, 0x30A3, "Compaq nw8440(0x103C-0x30A3)"},
{0x104C, 0x803B, 0x104D, 0x8212, "VAIO VGN-N21E(0x104D-0x8212)"},
{0x104C, 0x803B, 0x104D, 0x902D, "VAIO VGN-NR120E(0x104D-0x902D)"},
{0x104C, 0x803C, 0xFFFF, 0xFFFF, "PCIxx12 SDA Standard Compliant SD Host Controller(0x803C)"},
{0x104C, 0x803C, 0x103C, 0x309F, "nx9420(0x103C-0x309F)"},
{0x104C, 0x803C, 0x103C, 0x30A3, "Compaq nw8440(0x103C-0x30A3)"},
{0x104C, 0x803D, 0xFFFF, 0xFFFF, "PCIxx12 GemCore based SmartCard controller(0x803D)"},
{0x104C, 0x803D, 0x103C, 0x309F, "Compaq nx9420 Notebook(0x103C-0x309F)"},
{0x104C, 0x803D, 0x103C, 0x30A1, "NC2400(0x103C-0x30A1)"},
{0x104C, 0x803D, 0x103C, 0x30A3, "nc8430(0x103C-0x30A3)"},
{0x104C, 0x803D, 0x103C, 0x30AA, "nc6310(0x103C-0x30AA)"},
{0x104C, 0x8101, 0xFFFF, 0xFFFF, "TSB43DB42 IEEE-1394a-2000 Controller (PHY/Link)(0x8101)"},
{0x104C, 0x8201, 0xFFFF, 0xFFFF, "PCI1620 Firmware Loading Function(0x8201)"},
{0x104C, 0x8204, 0xFFFF, 0xFFFF, "PCI7410/7510/7610 PCI Firmware Loading Function(0x8204)"},
{0x104C, 0x8204, 0x1028, 0x0139, "Latitude D400(0x1028-0x0139)"},
{0x104C, 0x8204, 0x1028, 0x014E, "Latitude D800(0x1028-0x014E)"},
{0x104C, 0x8231, 0xFFFF, 0xFFFF, "XIO2000(A)/XIO2200A PCI Express-to-PCI Bridge(0x8231)"},
{0x104C, 0x8231, 0x5678, 0x1234, "DC-1394 PCIe(0x5678-0x1234)"},
{0x104C, 0x8232, 0xFFFF, 0xFFFF, "XIO3130 PCI Express Switch (Upstream)(0x8232)"},
{0x104C, 0x8233, 0xFFFF, 0xFFFF, "XIO3130 PCI Express Switch (Downstream)(0x8233)"},
{0x104C, 0x8235, 0xFFFF, 0xFFFF, "XIO2200A IEEE-1394a-2000 Controller (PHY/Link)(0x8235)"},
{0x104C, 0x8235, 0x5678, 0x1234, "DC-1394 PCIe(0x5678-0x1234)"},
{0x104C, 0x823E, 0xFFFF, 0xFFFF, "XIO2213A/B/XIO2221 PCI Express to PCI Bridge [Cheetah Express](0x823E)"},
{0x104C, 0x823F, 0xFFFF, 0xFFFF, "XIO2213A/B/XIO2221 IEEE-1394b OHCI Controller [Cheetah Express](0x823F)"},
{0x104C, 0x823F, 0x1546, 0x803C, "FWB-PCIE1X11B(0x1546-0x803C)"},
{0x104C, 0x8240, 0xFFFF, 0xFFFF, "XIO2001 PCI Express-to-PCI Bridge(0x8240)"},
{0x104C, 0x8241, 0xFFFF, 0xFFFF, "TUSB73x0 SuperSpeed USB 3.0 xHCI Host Controller(0x8241)"},
{0x104C, 0x8241, 0x1014, 0x04B2, "S824 (8286-42A)(0x1014-0x04B2)"},
{0x104C, 0x8400, 0xFFFF, 0xFFFF, "ACX 100 22Mbps Wireless Interface(0x8400)"},
{0x104C, 0x8400, 0x1186, 0x3B00, "DWL-650+ PC Card cardbus 22Mbs Wireless Adapter [AirPlus](0x1186-0x3B00)"},
{0x104C, 0x8400, 0x1186, 0x3B01, "DWL-520+ 22Mbps PCI Wireless Adapter(0x1186-0x3B01)"},
{0x104C, 0x8400, 0x1395, 0x2201, "WL22-PC(0x1395-0x2201)"},
{0x104C, 0x8400, 0x16AB, 0x8501, "WL-8305 IEEE802.11b+ Wireless LAN PCI Adapter(0x16AB-0x8501)"},
{0x104C, 0x8401, 0xFFFF, 0xFFFF, "ACX 100 22Mbps Wireless Interface(0x8401)"},
{0x104C, 0x8888, 0xFFFF, 0xFFFF, "Multicore DSP+ARM KeyStone II SOC(0x8888)"},
{0x104C, 0x9000, 0xFFFF, 0xFFFF, "Wireless Interface (of unknown type)(0x9000)"},
{0x104C, 0x9065, 0xFFFF, 0xFFFF, "TMS320DM642(0x9065)"},
{0x104C, 0x9066, 0xFFFF, 0xFFFF, "ACX 111 54Mbps Wireless Interface(0x9066)"},
{0x104C, 0x9066, 0x0308, 0x3404, "G-102 v1 802.11g Wireless Cardbus Adapter(0x0308-0x3404)"},
{0x104C, 0x9066, 0x0308, 0x3406, "G-162 v2 802.11g Wireless Cardbus Adapter(0x0308-0x3406)"},
{0x104C, 0x9066, 0x104C, 0x9066, "WL212 Sitecom Wireless Network PCI-Card 100M (Version 1)(0x104C-0x9066)"},
{0x104C, 0x9066, 0x104C, 0x9067, "TNETW1130GVF(0x104C-0x9067)"},
{0x104C, 0x9066, 0x104C, 0x9096, "Trendnet TEW-412PC Wireless PCI Adapter (Version A)(0x104C-0x9096)"},
{0x104C, 0x9066, 0x1186, 0x3B04, "DWL-G520+ Wireless PCI Adapter(0x1186-0x3B04)"},
{0x104C, 0x9066, 0x1186, 0x3B05, "DWL-G650+ AirPlusG+ CardBus Wireless LAN(0x1186-0x3B05)"},
{0x104C, 0x9066, 0x1186, 0x3B08, "AirPlus G DWL-G630 Wireless Cardbus Adapter (rev.B1)(0x1186-0x3B08)"},
{0x104C, 0x9066, 0x1385, 0x4C00, "WG311v2 802.11g Wireless PCI Adapter(0x1385-0x4C00)"},
{0x104C, 0x9066, 0x13D1, 0xABA0, "SWLMP-54108 108Mbps Wireless mini PCI card 802.11g+(0x13D1-0xABA0)"},
{0x104C, 0x9066, 0x14EA, 0xAB07, "GW-NS54GM Wireless Cardbus Adapter(0x14EA-0xAB07)"},
{0x104C, 0x9066, 0x16EC, 0x010D, "USR5416 802.11g Wireless Turbo PCI Adapter(0x16EC-0x010D)"},
{0x104C, 0x9066, 0x16EC, 0x010E, "USR5410 802.11g Wireless Cardbus Adapter(0x16EC-0x010E)"},
{0x104C, 0x9066, 0x1737, 0x0033, "WPC54G v2 802.11g Wireless-G Notebook Adapter(0x1737-0x0033)"},
{0x104C, 0x9066, 0x17CF, 0x0032, "G-162 v1 802.11g Wireless Cardbus Adapter(0x17CF-0x0032)"},
{0x104C, 0x9066, 0x17CF, 0x0033, "Z-Com XG650 Wireless miniPCI 802.11b/g(0x17CF-0x0033)"},
{0x104C, 0x9066, 0x187E, 0x340B, "G-302 v2 802.11g Wireless PCI Adapter(0x187E-0x340B)"},
{0x104C, 0x9066, 0x187E, 0x340C, "G-360 v2 802.11g Wireless PCI Adapter(0x187E-0x340C)"},
{0x104C, 0xA001, 0xFFFF, 0xFFFF, "TDC1570(0xA001)"},
{0x104C, 0xA100, 0xFFFF, 0xFFFF, "TDC1561(0xA100)"},
{0x104C, 0xA102, 0xFFFF, 0xFFFF, "TNETA1575 HyperSAR Plus w/PCI Host i/f & UTOPIA i/f(0xA102)"},
{0x104C, 0xA106, 0xFFFF, 0xFFFF, "TMS320C6414 TMS320C6415 TMS320C6416(0xA106)"},
{0x104C, 0xA106, 0x175C, 0x5000, "ASI50xx Audio Adapter(0x175C-0x5000)"},
{0x104C, 0xA106, 0x175C, 0x6400, "ASI6400 Cobranet series(0x175C-0x6400)"},
{0x104C, 0xA106, 0x175C, 0x8700, "ASI87xx Radio Tuner card(0x175C-0x8700)"},
{0x104C, 0xAC10, 0xFFFF, 0xFFFF, "PCI1050(0xAC10)"},
{0x104C, 0xAC11, 0xFFFF, 0xFFFF, "PCI1053(0xAC11)"},
{0x104C, 0xAC12, 0xFFFF, 0xFFFF, "PCI1130(0xAC12)"},
{0x104C, 0xAC13, 0xFFFF, 0xFFFF, "PCI1031(0xAC13)"},
{0x104C, 0xAC15, 0xFFFF, 0xFFFF, "PCI1131(0xAC15)"},
{0x104C, 0xAC16, 0xFFFF, 0xFFFF, "PCI1250(0xAC16)"},
{0x104C, 0xAC16, 0x1014, 0x0092, "ThinkPad 600(0x1014-0x0092)"},
{0x104C, 0xAC17, 0xFFFF, 0xFFFF, "PCI1220(0xAC17)"},
{0x104C, 0xAC18, 0xFFFF, 0xFFFF, "PCI1260(0xAC18)"},
{0x104C, 0xAC19, 0xFFFF, 0xFFFF, "PCI1221(0xAC19)"},
{0x104C, 0xAC1A, 0xFFFF, 0xFFFF, "PCI1210(0xAC1A)"},
{0x104C, 0xAC1B, 0xFFFF, 0xFFFF, "PCI1450(0xAC1B)"},
{0x104C, 0xAC1B, 0x0E11, 0xB113, "Armada M700(0x0E11-0xB113)"},
{0x104C, 0xAC1B, 0x1014, 0x0130, "ThinkPad 600X/A21m/T20/T22(0x1014-0x0130)"},
{0x104C, 0xAC1C, 0xFFFF, 0xFFFF, "PCI1225(0xAC1C)"},
{0x104C, 0xAC1C, 0x0E11, 0xB121, "Armada E500(0x0E11-0xB121)"},
{0x104C, 0xAC1C, 0x1028, 0x0088, "Latitude CPi A400XT(0x1028-0x0088)"},
{0x104C, 0xAC1D, 0xFFFF, 0xFFFF, "PCI1251A(0xAC1D)"},
{0x104C, 0xAC1E, 0xFFFF, 0xFFFF, "PCI1211(0xAC1E)"},
{0x104C, 0xAC1F, 0xFFFF, 0xFFFF, "PCI1251B(0xAC1F)"},
{0x104C, 0xAC20, 0xFFFF, 0xFFFF, "TI 2030(0xAC20)"},
{0x104C, 0xAC21, 0xFFFF, 0xFFFF, "PCI2031(0xAC21)"},
{0x104C, 0xAC22, 0xFFFF, 0xFFFF, "PCI2032 PCI Docking Bridge(0xAC22)"},
{0x104C, 0xAC23, 0xFFFF, 0xFFFF, "PCI2250 PCI-to-PCI Bridge(0xAC23)"},
{0x104C, 0xAC28, 0xFFFF, 0xFFFF, "PCI2050 PCI-to-PCI Bridge(0xAC28)"},
{0x104C, 0xAC2C, 0xFFFF, 0xFFFF, "PCI2060 PCI-to-PCI Bridge(0xAC2C)"},
{0x104C, 0xAC30, 0xFFFF, 0xFFFF, "PCI1260 PC card Cardbus Controller(0xAC30)"},
{0x104C, 0xAC40, 0xFFFF, 0xFFFF, "PCI4450 PC card Cardbus Controller(0xAC40)"},
{0x104C, 0xAC41, 0xFFFF, 0xFFFF, "PCI4410 PC card Cardbus Controller(0xAC41)"},
{0x104C, 0xAC42, 0xFFFF, 0xFFFF, "PCI4451 PC card Cardbus Controller(0xAC42)"},
{0x104C, 0xAC42, 0x1028, 0x00E6, "PCI4451 PC card CardBus Controller (Inspiron 8100)(0x1028-0x00E6)"},
{0x104C, 0xAC44, 0xFFFF, 0xFFFF, "PCI4510 PC card Cardbus Controller(0xAC44)"},
{0x104C, 0xAC44, 0x1028, 0x0149, "Inspiron 5100(0x1028-0x0149)"},
{0x104C, 0xAC44, 0x1028, 0x0163, "Latitude D505(0x1028-0x0163)"},
{0x104C, 0xAC44, 0x1028, 0x0196, "Inspiron 5160(0x1028-0x0196)"},
{0x104C, 0xAC44, 0x1071, 0x8160, "MIM2000(0x1071-0x8160)"},
{0x104C, 0xAC46, 0xFFFF, 0xFFFF, "PCI4520 PC card Cardbus Controller(0xAC46)"},
{0x104C, 0xAC46, 0x1014, 0x0552, "ThinkPad(0x1014-0x0552)"},
{0x104C, 0xAC47, 0xFFFF, 0xFFFF, "PCI7510 PC card Cardbus Controller(0xAC47)"},
{0x104C, 0xAC47, 0x1028, 0x0139, "Latitude D400(0x1028-0x0139)"},
{0x104C, 0xAC47, 0x1028, 0x013F, "Precision M60(0x1028-0x013F)"},
{0x104C, 0xAC47, 0x1028, 0x014E, "Latitude D800(0x1028-0x014E)"},
{0x104C, 0xAC48, 0xFFFF, 0xFFFF, "PCI7610 PC Card Cardbus Controller(0xAC48)"},
{0x104C, 0xAC49, 0xFFFF, 0xFFFF, "PCI7410 PC Card Cardbus Controller(0xAC49)"},
{0x104C, 0xAC4A, 0xFFFF, 0xFFFF, "PCI7510/7610 CardBus Bridge(0xAC4A)"},
{0x104C, 0xAC4A, 0x1028, 0x0139, "Latitude D400(0x1028-0x0139)"},
{0x104C, 0xAC4A, 0x1028, 0x014E, "Latitude D800(0x1028-0x014E)"},
{0x104C, 0xAC4B, 0xFFFF, 0xFFFF, "PCI7610 SD/MMC controller(0xAC4B)"},
{0x104C, 0xAC4C, 0xFFFF, 0xFFFF, "PCI7610 Memory Stick controller(0xAC4C)"},
{0x104C, 0xAC50, 0xFFFF, 0xFFFF, "PCI1410 PC card Cardbus Controller(0xAC50)"},
{0x104C, 0xAC51, 0xFFFF, 0xFFFF, "PCI1420 PC card Cardbus Controller(0xAC51)"},
{0x104C, 0xAC51, 0x0E11, 0x004E, "Evo N600c(0x0E11-0x004E)"},
{0x104C, 0xAC51, 0x1014, 0x0148, "ThinkPad A20m(0x1014-0x0148)"},
{0x104C, 0xAC51, 0x1014, 0x023B, "ThinkPad T23(0x1014-0x023B)"},
{0x104C, 0xAC51, 0x1028, 0x00B1, "Latitude C600(0x1028-0x00B1)"},
{0x104C, 0xAC51, 0x1028, 0x012A, "Latitude C640(0x1028-0x012A)"},
{0x104C, 0xAC51, 0x1033, 0x80CD, "Versa Note VXi(0x1033-0x80CD)"},
{0x104C, 0xAC51, 0x10CF, 0x1095, "Lifebook S-4510/C6155(0x10CF-0x1095)"},
{0x104C, 0xAC51, 0xE4BF, 0x1000, "CP2-2-HIPHOP(0xE4BF-0x1000)"},
{0x104C, 0xAC52, 0xFFFF, 0xFFFF, "PCI1451 PC card Cardbus Controller(0xAC52)"},
{0x104C, 0xAC53, 0xFFFF, 0xFFFF, "PCI1421 PC card Cardbus Controller(0xAC53)"},
{0x104C, 0xAC54, 0xFFFF, 0xFFFF, "PCI1620 PC Card Controller(0xAC54)"},
{0x104C, 0xAC54, 0x103C, 0x08B0, "tc1100 tablet(0x103C-0x08B0)"},
{0x104C, 0xAC55, 0xFFFF, 0xFFFF, "PCI1520 PC card Cardbus Controller(0xAC55)"},
{0x104C, 0xAC55, 0x1014, 0x0512, "ThinkPad T30/T40(0x1014-0x0512)"},
{0x104C, 0xAC55, 0x103C, 0x0025, "XE4500 Notebook(0x103C-0x0025)"},
{0x104C, 0xAC56, 0xFFFF, 0xFFFF, "PCI1510 PC card Cardbus Controller(0xAC56)"},
{0x104C, 0xAC56, 0x1014, 0x0512, "ThinkPad R50e(0x1014-0x0512)"},
{0x104C, 0xAC56, 0x1014, 0x0528, "ThinkPad R40e(0x1014-0x0528)"},
{0x104C, 0xAC56, 0x17AA, 0x2012, "ThinkPad T60/R60 series(0x17AA-0x2012)"},
{0x104C, 0xAC60, 0xFFFF, 0xFFFF, "PCI2040 PCI to DSP Bridge Controller(0xAC60)"},
{0x104C, 0xAC60, 0x175C, 0x5100, "ASI51xx Audio Adapter(0x175C-0x5100)"},
{0x104C, 0xAC60, 0x175C, 0x6100, "ASI61xx Audio Adapter(0x175C-0x6100)"},
{0x104C, 0xAC60, 0x175C, 0x6200, "ASI62xx Audio Adapter(0x175C-0x6200)"},
{0x104C, 0xAC60, 0x175C, 0x8800, "ASI88xx Audio Adapter(0x175C-0x8800)"},
{0x104C, 0xAC60, 0x186F, 0x3001, "WR-G303 PCI radio receiver(0x186F-0x3001)"},
{0x104C, 0xAC60, 0x186F, 0x3005, "WR-G305 PCI radio receiver(0x186F-0x3005)"},
{0x104C, 0xAC60, 0x186F, 0x3101, "WR-G313 PCI radio receiver(0x186F-0x3101)"},
{0x104C, 0xAC60, 0x186F, 0x3105, "WR-G315 PCI radio receiver(0x186F-0x3105)"},
{0x104C, 0xAC8D, 0xFFFF, 0xFFFF, "PCI 7620(0xAC8D)"},
{0x104C, 0xAC8E, 0xFFFF, 0xFFFF, "PCI7420 CardBus Controller(0xAC8E)"},
{0x104C, 0xAC8E, 0x1028, 0x018D, "Inspiron 700m/710m(0x1028-0x018D)"},
{0x104C, 0xAC8F, 0xFFFF, 0xFFFF, "PCI7420/7620 SD/MS-Pro Controller(0xAC8F)"},
{0x104C, 0xAC8F, 0x1028, 0x018D, "Inspiron 700m/710m(0x1028-0x018D)"},
{0x104C, 0xB001, 0xFFFF, 0xFFFF, "TMS320C6424(0xB001)"},
{0x104C, 0xFE00, 0xFFFF, 0xFFFF, "FireWire Host Controller(0xFE00)"},
{0x104C, 0xFE03, 0xFFFF, 0xFFFF, "12C01A FireWire Host Controller(0xFE03)"},
}; /* pci_vid_104C[] */

static pci_id_t const pci_vid_104D[] = {
{0x104D, 0xFFFF, 0xFFFF, 0xFFFF, "Sony Corporation(0x104D)"},
{0x104D, 0x8004, 0xFFFF, 0xFFFF, "DTL-H2500 [Playstation development board](0x8004)"},
{0x104D, 0x8009, 0xFFFF, 0xFFFF, "CXD1947Q i.LINK Controller(0x8009)"},
{0x104D, 0x800C, 0xFFFF, 0xFFFF, "DTL-H800 [PS1 sound development board](0x800C)"},
{0x104D, 0x8039, 0xFFFF, 0xFFFF, "CXD3222 i.LINK Controller(0x8039)"},
{0x104D, 0x8047, 0xFFFF, 0xFFFF, "PS2 TOOL MRP(0x8047)"},
{0x104D, 0x8056, 0xFFFF, 0xFFFF, "Rockwell HCF 56K modem(0x8056)"},
{0x104D, 0x808A, 0xFFFF, 0xFFFF, "Memory Stick Controller(0x808A)"},
{0x104D, 0x80FF, 0xFFFF, 0xFFFF, "PS2 Performance Analyzer(0x80FF)"},
{0x104D, 0x814A, 0xFFFF, 0xFFFF, "PS2 Performance Analyzer(0x814A)"},
{0x104D, 0x8183, 0xFFFF, 0xFFFF, "ATHENS [PS3 prototype developer interface card](0x8183)"},
{0x104D, 0x81B0, 0xFFFF, 0xFFFF, "BM-1 [PSP TOOL Board Management Device](0x81B0)"},
{0x104D, 0x81C3, 0xFFFF, 0xFFFF, "VO-4 [PSP TOOL Video Output Device](0x81C3)"},
{0x104D, 0x81CE, 0xFFFF, 0xFFFF, "SxS Pro memory card(0x81CE)"},
{0x104D, 0x81FF, 0xFFFF, 0xFFFF, "PS3 TOOL MRP(0x81FF)"},
{0x104D, 0x8200, 0xFFFF, 0xFFFF, "PS3 TOOL RSX Tracing FPGA(0x8200)"},
{0x104D, 0x820E, 0xFFFF, 0xFFFF, "CXD9208GP [PS3 PS2 emulation subsystem adapter](0x820E)"},
{0x104D, 0x905C, 0xFFFF, 0xFFFF, "SxS Pro memory card(0x905C)"},
{0x104D, 0x907F, 0xFFFF, 0xFFFF, "SxS Pro+ memory card(0x907F)"},
{0x104D, 0x908F, 0xFFFF, 0xFFFF, "Aeolia ACPI(0x908F)"},
{0x104D, 0x909E, 0xFFFF, 0xFFFF, "Aeolia Ethernet Controller (Marvell Yukon 2 Family)(0x909E)"},
{0x104D, 0x909F, 0xFFFF, 0xFFFF, "Aeolia SATA AHCI Controller(0x909F)"},
{0x104D, 0x90A0, 0xFFFF, 0xFFFF, "Aeolia SD/MMC Host Controller(0x90A0)"},
{0x104D, 0x90A1, 0xFFFF, 0xFFFF, "Aeolia PCI Express Glue and Miscellaneous Devices(0x90A1)"},
{0x104D, 0x90A2, 0xFFFF, 0xFFFF, "Aeolia DMA Controller(0x90A2)"},
{0x104D, 0x90A3, 0xFFFF, 0xFFFF, "Aeolia Memory (DDR3/SPM)(0x90A3)"},
{0x104D, 0x90A4, 0xFFFF, 0xFFFF, "Aeolia USB 3.0 xHCI Host Controller(0x90A4)"},
{0x104D, 0x90BC, 0xFFFF, 0xFFFF, "SxS Pro+ memory card(0x90BC)"},
{0x104D, 0x90C0, 0xFFFF, 0xFFFF, "PCIe x8 XAVC Codec Board(0x90C0)"},
{0x104D, 0x90C8, 0xFFFF, 0xFFFF, "Belize ACPI(0x90C8)"},
{0x104D, 0x90C9, 0xFFFF, 0xFFFF, "Belize Ethernet Controller(0x90C9)"},
{0x104D, 0x90CA, 0xFFFF, 0xFFFF, "Belize SATA AHCI Controller(0x90CA)"},
{0x104D, 0x90CB, 0xFFFF, 0xFFFF, "Belize SD/MMC Host Controller(0x90CB)"},
{0x104D, 0x90CC, 0xFFFF, 0xFFFF, "Belize PCI Express Glue and Miscellaneous Devices(0x90CC)"},
{0x104D, 0x90CD, 0xFFFF, 0xFFFF, "Belize DMA Controller(0x90CD)"},
{0x104D, 0x90CE, 0xFFFF, 0xFFFF, "Belize Memory (DDR3/SPM)(0x90CE)"},
{0x104D, 0x90CF, 0xFFFF, 0xFFFF, "Belize USB 3.0 xHCI Host Controller(0x90CF)"},
{0x104D, 0x90D7, 0xFFFF, 0xFFFF, "Baikal ACPI(0x90D7)"},
{0x104D, 0x90D8, 0xFFFF, 0xFFFF, "Baikal Ethernet Controller(0x90D8)"},
{0x104D, 0x90D9, 0xFFFF, 0xFFFF, "Baikal SATA AHCI Controller(0x90D9)"},
{0x104D, 0x90DA, 0xFFFF, 0xFFFF, "Baikal SD/MMC Host Controller(0x90DA)"},
{0x104D, 0x90DB, 0xFFFF, 0xFFFF, "Baikal PCI Express Glue and Miscellaneous Devices(0x90DB)"},
{0x104D, 0x90DC, 0xFFFF, 0xFFFF, "Baikal DMA Controller(0x90DC)"},
{0x104D, 0x90DD, 0xFFFF, 0xFFFF, "Baikal Memory (DDR3/SPM)(0x90DD)"},
{0x104D, 0x90DE, 0xFFFF, 0xFFFF, "Baikal USB 3.0 xHCI Host Controller(0x90DE)"},
{0x104D, 0x90EB, 0xFFFF, 0xFFFF, "CXD90062GG(0x90EB)"},
{0x104D, 0x9121, 0xFFFF, 0xFFFF, "Nextorage NEM-PA NVMe SSD for PlayStation(0x9121)"},
}; /* pci_vid_104D[] */

static pci_id_t const pci_vid_104E[] = {
{0x104E, 0xFFFF, 0xFFFF, 0xFFFF, "Oak Technology, Inc(0x104E)"},
{0x104E, 0x0017, 0xFFFF, 0xFFFF, "OTI-64017(0x0017)"},
{0x104E, 0x0107, 0xFFFF, 0xFFFF, "OTI-107 [Spitfire](0x0107)"},
{0x104E, 0x0109, 0xFFFF, 0xFFFF, "Video Adapter(0x0109)"},
{0x104E, 0x0111, 0xFFFF, 0xFFFF, "OTI-64111 [Spitfire](0x0111)"},
{0x104E, 0x0217, 0xFFFF, 0xFFFF, "OTI-64217(0x0217)"},
{0x104E, 0x0317, 0xFFFF, 0xFFFF, "OTI-64317(0x0317)"},
}; /* pci_vid_104E[] */

static pci_id_t const pci_vid_104F[] = {
{0x104F, 0xFFFF, 0xFFFF, 0xFFFF, "Co-time Computer Ltd(0x104F)"},
}; /* pci_vid_104F[] */

static pci_id_t const pci_vid_1050[] = {
{0x1050, 0xFFFF, 0xFFFF, 0xFFFF, "Winbond Electronics Corp(0x1050)"},
{0x1050, 0x0000, 0xFFFF, 0xFFFF, "NE2000(0x0000)"},
{0x1050, 0x0001, 0xFFFF, 0xFFFF, "W83769F(0x0001)"},
{0x1050, 0x0033, 0xFFFF, 0xFFFF, "W89C33D 802.11 a/b/g BB/MAC(0x0033)"},
{0x1050, 0x0105, 0xFFFF, 0xFFFF, "W82C105(0x0105)"},
{0x1050, 0x0840, 0xFFFF, 0xFFFF, "W89C840(0x0840)"},
{0x1050, 0x0840, 0x1050, 0x0001, "W89C840 Ethernet Adapter(0x1050-0x0001)"},
{0x1050, 0x0840, 0x1050, 0x0840, "W89C840 Ethernet Adapter(0x1050-0x0840)"},
{0x1050, 0x0940, 0xFFFF, 0xFFFF, "W89C940(0x0940)"},
{0x1050, 0x5A5A, 0xFFFF, 0xFFFF, "W89C940F(0x5A5A)"},
{0x1050, 0x6692, 0xFFFF, 0xFFFF, "W6692(0x6692)"},
{0x1050, 0x6692, 0x1043, 0x1702, "ISDN Adapter (PCI Bus, D, W)(0x1043-0x1702)"},
{0x1050, 0x6692, 0x1043, 0x1703, "ISDN Adapter (PCI Bus, DV, W)(0x1043-0x1703)"},
{0x1050, 0x6692, 0x1043, 0x1707, "ISDN Adapter (PCI Bus, DV, W)(0x1043-0x1707)"},
{0x1050, 0x6692, 0x144F, 0x1702, "ISDN Adapter (PCI Bus, D, W)(0x144F-0x1702)"},
{0x1050, 0x6692, 0x144F, 0x1703, "ISDN Adapter (PCI Bus, DV, W)(0x144F-0x1703)"},
{0x1050, 0x6692, 0x144F, 0x1707, "ISDN Adapter (PCI Bus, DV, W)(0x144F-0x1707)"},
{0x1050, 0x9921, 0xFFFF, 0xFFFF, "W99200F MPEG-1 Video Encoder(0x9921)"},
{0x1050, 0x9922, 0xFFFF, 0xFFFF, "W99200F/W9922PF MPEG-1/2 Video Encoder(0x9922)"},
{0x1050, 0x9970, 0xFFFF, 0xFFFF, "W9970CF(0x9970)"},
}; /* pci_vid_1050[] */

static pci_id_t const pci_vid_1051[] = {
{0x1051, 0xFFFF, 0xFFFF, 0xFFFF, "Anigma, Inc.(0x1051)"},
}; /* pci_vid_1051[] */

static pci_id_t const pci_vid_1052[] = {
{0x1052, 0xFFFF, 0xFFFF, 0xFFFF, "?-Young Micro Systems(0x1052)"},
}; /* pci_vid_1052[] */

static pci_id_t const pci_vid_1053[] = {
{0x1053, 0xFFFF, 0xFFFF, 0xFFFF, "Young Micro Systems(0x1053)"},
}; /* pci_vid_1053[] */

static pci_id_t const pci_vid_1054[] = {
{0x1054, 0xFFFF, 0xFFFF, 0xFFFF, "Hitachi, Ltd(0x1054)"},
{0x1054, 0x3009, 0xFFFF, 0xFFFF, "2Gbps Fibre Channel to PCI HBA 3009(0x3009)"},
{0x1054, 0x300A, 0xFFFF, 0xFFFF, "4Gbps Fibre Channel to PCI-X HBA 300a(0x300A)"},
{0x1054, 0x300B, 0xFFFF, 0xFFFF, "4Gbps Fibre Channel to PCI-X HBA 300b(0x300B)"},
{0x1054, 0x300F, 0xFFFF, 0xFFFF, "ColdFusion 3 Chipset Processor to I/O Controller(0x300F)"},
{0x1054, 0x3010, 0xFFFF, 0xFFFF, "ColdFusion 3 Chipset Memory Controller Hub(0x3010)"},
{0x1054, 0x3011, 0xFFFF, 0xFFFF, "ColdFusion 3e Chipset Processor to I/O Controller(0x3011)"},
{0x1054, 0x3012, 0xFFFF, 0xFFFF, "ColdFusion 3e Chipset Memory Controller Hub(0x3012)"},
{0x1054, 0x3017, 0xFFFF, 0xFFFF, "Unassigned Hitachi Shared FC Device 3017(0x3017)"},
{0x1054, 0x301B, 0xFFFF, 0xFFFF, "Virtual VGA Device(0x301B)"},
{0x1054, 0x301D, 0xFFFF, 0xFFFF, "PCIe-to-PCIe Bridge with Virtualization IO Assist Feature(0x301D)"},
{0x1054, 0x3020, 0xFFFF, 0xFFFF, "FIVE-EX based Fibre Channel to PCIe HBA(0x3020)"},
{0x1054, 0x302C, 0xFFFF, 0xFFFF, "M001 PCI Express Switch Upstream Port(0x302C)"},
{0x1054, 0x302D, 0xFFFF, 0xFFFF, "M001 PCI Express Switch Downstream Port(0x302D)"},
{0x1054, 0x3070, 0xFFFF, 0xFFFF, "Hitachi FIVE-FX Fibre Channel to PCIe HBA(0x3070)"},
{0x1054, 0x3505, 0xFFFF, 0xFFFF, "SH7751 PCI Controller (PCIC)(0x3505)"},
{0x1054, 0x350E, 0xFFFF, 0xFFFF, "SH7751R PCI Controller (PCIC)(0x350E)"},
}; /* pci_vid_1054[] */

static pci_id_t const pci_vid_1055[] = {
{0x1055, 0xFFFF, 0xFFFF, 0xFFFF, "Microchip Technology / SMSC(0x1055)"},
{0x1055, 0x7430, 0xFFFF, 0xFFFF, "LAN7430(0x7430)"},
{0x1055, 0x7431, 0xFFFF, 0xFFFF, "LAN7431(0x7431)"},
{0x1055, 0x9130, 0xFFFF, 0xFFFF, "SLC90E66 [Victory66] IDE(0x9130)"},
{0x1055, 0x9460, 0xFFFF, 0xFFFF, "SLC90E66 [Victory66] ISA(0x9460)"},
{0x1055, 0x9462, 0xFFFF, 0xFFFF, "SLC90E66 [Victory66] USB(0x9462)"},
{0x1055, 0x9463, 0xFFFF, 0xFFFF, "SLC90E66 [Victory66] ACPI(0x9463)"},
{0x1055, 0xE420, 0xFFFF, 0xFFFF, "LAN9420/LAN9420i(0xE420)"},
}; /* pci_vid_1055[] */

static pci_id_t const pci_vid_1056[] = {
{0x1056, 0xFFFF, 0xFFFF, 0xFFFF, "ICL(0x1056)"},
}; /* pci_vid_1056[] */

static pci_id_t const pci_vid_1057[] = {
{0x1057, 0xFFFF, 0xFFFF, 0xFFFF, "Motorola(0x1057)"},
{0x1057, 0x0001, 0xFFFF, 0xFFFF, "MPC105 [Eagle](0x0001)"},
{0x1057, 0x0002, 0xFFFF, 0xFFFF, "MPC106 [Grackle](0x0002)"},
{0x1057, 0x0003, 0xFFFF, 0xFFFF, "MPC8240 [Kahlua](0x0003)"},
{0x1057, 0x0004, 0xFFFF, 0xFFFF, "MPC107(0x0004)"},
{0x1057, 0x0006, 0xFFFF, 0xFFFF, "MPC8245 [Unity](0x0006)"},
{0x1057, 0x0008, 0xFFFF, 0xFFFF, "MPC8540(0x0008)"},
{0x1057, 0x0009, 0xFFFF, 0xFFFF, "MPC8560(0x0009)"},
{0x1057, 0x0012, 0xFFFF, 0xFFFF, "MPC8548 [PowerQUICC III](0x0012)"},
{0x1057, 0x0100, 0xFFFF, 0xFFFF, "MC145575 [HFC-PCI](0x0100)"},
{0x1057, 0x0431, 0xFFFF, 0xFFFF, "KTI829c 100VG(0x0431)"},
{0x1057, 0x1073, 0xFFFF, 0xFFFF, "Nokia N770(0x1073)"},
{0x1057, 0x1219, 0xFFFF, 0xFFFF, "Nokia N800(0x1219)"},
{0x1057, 0x1801, 0xFFFF, 0xFFFF, "DSP56301 Digital Signal Processor(0x1801)"},
{0x1057, 0x1801, 0x14FB, 0x0101, "Transas Radar Imitator Board [RIM](0x14FB-0x0101)"},
{0x1057, 0x1801, 0x14FB, 0x0102, "Transas Radar Imitator Board [RIM-2](0x14FB-0x0102)"},
{0x1057, 0x1801, 0x14FB, 0x0202, "Transas Radar Integrator Board [RIB-2](0x14FB-0x0202)"},
{0x1057, 0x1801, 0x14FB, 0x0611, "1 channel CAN bus Controller [CanPci-1](0x14FB-0x0611)"},
{0x1057, 0x1801, 0x14FB, 0x0612, "2 channels CAN bus Controller [CanPci-2](0x14FB-0x0612)"},
{0x1057, 0x1801, 0x14FB, 0x0613, "3 channels CAN bus Controller [CanPci-3](0x14FB-0x0613)"},
{0x1057, 0x1801, 0x14FB, 0x0614, "4 channels CAN bus Controller [CanPci-4](0x14FB-0x0614)"},
{0x1057, 0x1801, 0x14FB, 0x0621, "1 channel CAN bus Controller [CanPci2-1](0x14FB-0x0621)"},
{0x1057, 0x1801, 0x14FB, 0x0622, "2 channels CAN bus Controller [CanPci2-2](0x14FB-0x0622)"},
{0x1057, 0x1801, 0x14FB, 0x0810, "Transas VTS Radar Integrator Board [RIB-4](0x14FB-0x0810)"},
{0x1057, 0x1801, 0x175C, 0x4200, "ASI4215 Audio Adapter(0x175C-0x4200)"},
{0x1057, 0x1801, 0x175C, 0x4300, "ASI43xx Audio Adapter(0x175C-0x4300)"},
{0x1057, 0x1801, 0x175C, 0x4400, "ASI4401 Audio Adapter(0x175C-0x4400)"},
{0x1057, 0x1801, 0xECC0, 0x0010, "Darla(0xECC0-0x0010)"},
{0x1057, 0x1801, 0xECC0, 0x0020, "Gina(0xECC0-0x0020)"},
{0x1057, 0x1801, 0xECC0, 0x0030, "Layla rev.0(0xECC0-0x0030)"},
{0x1057, 0x1801, 0xECC0, 0x0031, "Layla rev.1(0xECC0-0x0031)"},
{0x1057, 0x1801, 0xECC0, 0x0040, "Darla24 rev.0(0xECC0-0x0040)"},
{0x1057, 0x1801, 0xECC0, 0x0041, "Darla24 rev.1(0xECC0-0x0041)"},
{0x1057, 0x1801, 0xECC0, 0x0050, "Gina24 rev.0(0xECC0-0x0050)"},
{0x1057, 0x1801, 0xECC0, 0x0051, "Gina24 rev.1(0xECC0-0x0051)"},
{0x1057, 0x1801, 0xECC0, 0x0070, "Mona rev.0(0xECC0-0x0070)"},
{0x1057, 0x1801, 0xECC0, 0x0071, "Mona rev.1(0xECC0-0x0071)"},
{0x1057, 0x1801, 0xECC0, 0x0072, "Mona rev.2(0xECC0-0x0072)"},
{0x1057, 0x18C0, 0xFFFF, 0xFFFF, "MPC8265A/8266/8272(0x18C0)"},
{0x1057, 0x18C1, 0xFFFF, 0xFFFF, "MPC8271/MPC8272(0x18C1)"},
{0x1057, 0x3052, 0xFFFF, 0xFFFF, "SM56 Data Fax Modem(0x3052)"},
{0x1057, 0x3410, 0xFFFF, 0xFFFF, "DSP56361 Digital Signal Processor(0x3410)"},
{0x1057, 0x3410, 0xECC0, 0x0050, "Gina24 rev.0(0xECC0-0x0050)"},
{0x1057, 0x3410, 0xECC0, 0x0051, "Gina24 rev.1(0xECC0-0x0051)"},
{0x1057, 0x3410, 0xECC0, 0x0060, "Layla24(0xECC0-0x0060)"},
{0x1057, 0x3410, 0xECC0, 0x0070, "Mona rev.0(0xECC0-0x0070)"},
{0x1057, 0x3410, 0xECC0, 0x0071, "Mona rev.1(0xECC0-0x0071)"},
{0x1057, 0x3410, 0xECC0, 0x0072, "Mona rev.2(0xECC0-0x0072)"},
{0x1057, 0x3410, 0xECC0, 0x0080, "Mia rev.0(0xECC0-0x0080)"},
{0x1057, 0x3410, 0xECC0, 0x0081, "Mia rev.1(0xECC0-0x0081)"},
{0x1057, 0x3410, 0xECC0, 0x0090, "Indigo(0xECC0-0x0090)"},
{0x1057, 0x3410, 0xECC0, 0x00A0, "Indigo IO(0xECC0-0x00A0)"},
{0x1057, 0x3410, 0xECC0, 0x00B0, "Indigo DJ(0xECC0-0x00B0)"},
{0x1057, 0x3410, 0xECC0, 0x0100, "3G(0xECC0-0x0100)"},
{0x1057, 0x4801, 0xFFFF, 0xFFFF, "Raven(0x4801)"},
{0x1057, 0x4802, 0xFFFF, 0xFFFF, "Falcon(0x4802)"},
{0x1057, 0x4803, 0xFFFF, 0xFFFF, "Hawk(0x4803)"},
{0x1057, 0x4806, 0xFFFF, 0xFFFF, "CPX8216(0x4806)"},
{0x1057, 0x480B, 0xFFFF, 0xFFFF, "MPC7410(0x480B)"},
{0x1057, 0x4D68, 0xFFFF, 0xFFFF, "20268(0x4D68)"},
{0x1057, 0x5600, 0xFFFF, 0xFFFF, "SM56 PCI Modem(0x5600)"},
{0x1057, 0x5600, 0x1057, 0x0300, "SM56 PCI Speakerphone Modem(0x1057-0x0300)"},
{0x1057, 0x5600, 0x1057, 0x0301, "SM56 PCI Voice Modem(0x1057-0x0301)"},
{0x1057, 0x5600, 0x1057, 0x0302, "SM56 PCI Fax Modem(0x1057-0x0302)"},
{0x1057, 0x5600, 0x1057, 0x5600, "SM56 PCI Voice modem(0x1057-0x5600)"},
{0x1057, 0x5600, 0x13D2, 0x0300, "SM56 PCI Speakerphone Modem(0x13D2-0x0300)"},
{0x1057, 0x5600, 0x13D2, 0x0301, "SM56 PCI Voice modem(0x13D2-0x0301)"},
{0x1057, 0x5600, 0x13D2, 0x0302, "SM56 PCI Fax Modem(0x13D2-0x0302)"},
{0x1057, 0x5600, 0x1436, 0x0300, "SM56 PCI Speakerphone Modem(0x1436-0x0300)"},
{0x1057, 0x5600, 0x1436, 0x0301, "SM56 PCI Voice modem(0x1436-0x0301)"},
{0x1057, 0x5600, 0x1436, 0x0302, "SM56 PCI Fax Modem(0x1436-0x0302)"},
{0x1057, 0x5600, 0x144F, 0x100C, "SM56 PCI Fax Modem(0x144F-0x100C)"},
{0x1057, 0x5600, 0x1494, 0x0300, "SM56 PCI Speakerphone Modem(0x1494-0x0300)"},
{0x1057, 0x5600, 0x1494, 0x0301, "SM56 PCI Voice modem(0x1494-0x0301)"},
{0x1057, 0x5600, 0x14C8, 0x0300, "SM56 PCI Speakerphone Modem(0x14C8-0x0300)"},
{0x1057, 0x5600, 0x14C8, 0x0302, "SM56 PCI Fax Modem(0x14C8-0x0302)"},
{0x1057, 0x5600, 0x1668, 0x0300, "SM56 PCI Speakerphone Modem(0x1668-0x0300)"},
{0x1057, 0x5600, 0x1668, 0x0302, "SM56 PCI Fax Modem(0x1668-0x0302)"},
{0x1057, 0x5608, 0xFFFF, 0xFFFF, "Wildcard X100P(0x5608)"},
{0x1057, 0x5803, 0xFFFF, 0xFFFF, "MPC5200(0x5803)"},
{0x1057, 0x5806, 0xFFFF, 0xFFFF, "MCF54 Coldfire(0x5806)"},
{0x1057, 0x5808, 0xFFFF, 0xFFFF, "MPC8220(0x5808)"},
{0x1057, 0x5809, 0xFFFF, 0xFFFF, "MPC5200B(0x5809)"},
{0x1057, 0x6400, 0xFFFF, 0xFFFF, "MPC190 Security Processor (S1 family, encryption)(0x6400)"},
{0x1057, 0x6405, 0xFFFF, 0xFFFF, "MPC184 Security Processor (S1 family)(0x6405)"},
}; /* pci_vid_1057[] */

static pci_id_t const pci_vid_1058[] = {
{0x1058, 0xFFFF, 0xFFFF, 0xFFFF, "Electronics & Telecommunications RSH(0x1058)"},
}; /* pci_vid_1058[] */

static pci_id_t const pci_vid_1059[] = {
{0x1059, 0xFFFF, 0xFFFF, 0xFFFF, "Kontron(0x1059)"},
{0x1059, 0x0004, 0xFFFF, 0xFFFF, "FPGA M.2 (K20058)(0x0004)"},
{0x1059, 0x0004, 0x1059, 0x0000, "FPGA M.2 (K20058)(0x1059-0x0000)"},
}; /* pci_vid_1059[] */

static pci_id_t const pci_vid_105A[] = {
{0x105A, 0xFFFF, 0xFFFF, 0xFFFF, "Promise Technology, Inc.(0x105A)"},
{0x105A, 0x0D30, 0xFFFF, 0xFFFF, "PDC20265 (FastTrak100 Lite/Ultra100)(0x0D30)"},
{0x105A, 0x0D30, 0x1043, 0x8042, "AV7266-E South Bridge Promise RAID(0x1043-0x8042)"},
{0x105A, 0x0D30, 0x105A, 0x4D33, "Ultra100(0x105A-0x4D33)"},
{0x105A, 0x0D38, 0xFFFF, 0xFFFF, "20263(0x0D38)"},
{0x105A, 0x0D38, 0x105A, 0x4D39, "Fasttrak66(0x105A-0x4D39)"},
{0x105A, 0x1275, 0xFFFF, 0xFFFF, "20275(0x1275)"},
{0x105A, 0x3318, 0xFFFF, 0xFFFF, "PDC20318 (SATA150 TX4)(0x3318)"},
{0x105A, 0x3319, 0xFFFF, 0xFFFF, "PDC20319 (FastTrak S150 TX4)(0x3319)"},
{0x105A, 0x3319, 0x105A, 0x3319, "FastTrak S150 TX4 4 port SATA PCI board(0x105A-0x3319)"},
{0x105A, 0x3319, 0x8086, 0x3427, "S875WP1-E mainboard(0x8086-0x3427)"},
{0x105A, 0x3371, 0xFFFF, 0xFFFF, "PDC20371 (FastTrak S150 TX2plus)(0x3371)"},
{0x105A, 0x3373, 0xFFFF, 0xFFFF, "PDC20378 (FastTrak 378/SATA 378)(0x3373)"},
{0x105A, 0x3373, 0x1043, 0x80F5, "K8V Deluxe/PC-DL Deluxe motherboard(0x1043-0x80F5)"},
{0x105A, 0x3373, 0x1462, 0x590D, "KT6 Delta-FIS2R (MS-6590)(0x1462-0x590D)"},
{0x105A, 0x3373, 0x1462, 0x702E, "K8T NEO FIS2R motherboard(0x1462-0x702E)"},
{0x105A, 0x3375, 0xFFFF, 0xFFFF, "PDC20375 (SATA150 TX2plus)(0x3375)"},
{0x105A, 0x3376, 0xFFFF, 0xFFFF, "PDC20376 (FastTrak 376)(0x3376)"},
{0x105A, 0x3376, 0x1043, 0x809E, "A7V8X motherboard(0x1043-0x809E)"},
{0x105A, 0x3515, 0xFFFF, 0xFFFF, "PDC40719 [FastTrak TX4300/TX4310](0x3515)"},
{0x105A, 0x3519, 0xFFFF, 0xFFFF, "PDC40519 (FastTrak TX4200)(0x3519)"},
{0x105A, 0x3570, 0xFFFF, 0xFFFF, "PDC20771 [FastTrak TX2300](0x3570)"},
{0x105A, 0x3571, 0xFFFF, 0xFFFF, "PDC20571 (FastTrak TX2200)(0x3571)"},
{0x105A, 0x3574, 0xFFFF, 0xFFFF, "PDC20579 SATAII 150 IDE Controller(0x3574)"},
{0x105A, 0x3577, 0xFFFF, 0xFFFF, "PDC40779 (SATA 300 779)(0x3577)"},
{0x105A, 0x3D17, 0xFFFF, 0xFFFF, "PDC40718 (SATA 300 TX4)(0x3D17)"},
{0x105A, 0x3D18, 0xFFFF, 0xFFFF, "PDC20518/PDC40518 (SATAII 150 TX4)(0x3D18)"},
{0x105A, 0x3D73, 0xFFFF, 0xFFFF, "PDC40775 (SATA 300 TX2plus)(0x3D73)"},
{0x105A, 0x3D75, 0xFFFF, 0xFFFF, "PDC20575 (SATAII150 TX2plus)(0x3D75)"},
{0x105A, 0x3F20, 0xFFFF, 0xFFFF, "PDC42819 [FastTrak TX2650/TX4650](0x3F20)"},
{0x105A, 0x4302, 0xFFFF, 0xFFFF, "80333 [SuperTrak EX4350](0x4302)"},
{0x105A, 0x4D30, 0xFFFF, 0xFFFF, "PDC20267 (FastTrak100/Ultra100)(0x4D30)"},
{0x105A, 0x4D30, 0x105A, 0x4D33, "Ultra100(0x105A-0x4D33)"},
{0x105A, 0x4D30, 0x105A, 0x4D39, "FastTrak100(0x105A-0x4D39)"},
{0x105A, 0x4D30, 0x8086, 0x5744, "S845WD1-E mainboard(0x8086-0x5744)"},
{0x105A, 0x4D33, 0xFFFF, 0xFFFF, "20246(0x4D33)"},
{0x105A, 0x4D33, 0x105A, 0x4D33, "20246 IDE Controller(0x105A-0x4D33)"},
{0x105A, 0x4D38, 0xFFFF, 0xFFFF, "PDC20262 (FastTrak66/Ultra66)(0x4D38)"},
{0x105A, 0x4D38, 0x105A, 0x4D30, "Ultra Device on SuperTrak(0x105A-0x4D30)"},
{0x105A, 0x4D38, 0x105A, 0x4D33, "Ultra66(0x105A-0x4D33)"},
{0x105A, 0x4D38, 0x105A, 0x4D39, "FastTrak66(0x105A-0x4D39)"},
{0x105A, 0x4D68, 0xFFFF, 0xFFFF, "PDC20268 [Ultra100 TX2](0x4D68)"},
{0x105A, 0x4D68, 0x105A, 0x4D68, "Ultra100 TX2(0x105A-0x4D68)"},
{0x105A, 0x4D69, 0xFFFF, 0xFFFF, "20269(0x4D69)"},
{0x105A, 0x4D69, 0x105A, 0x4D68, "Ultra133TX2(0x105A-0x4D68)"},
{0x105A, 0x5275, 0xFFFF, 0xFFFF, "PDC20276 (MBFastTrak133 Lite)(0x5275)"},
{0x105A, 0x5275, 0x1043, 0x807E, "A7V333 motherboard.(0x1043-0x807E)"},
{0x105A, 0x5275, 0x105A, 0x0275, "SuperTrak SX6000 IDE(0x105A-0x0275)"},
{0x105A, 0x5275, 0x105A, 0x1275, "MBFastTrak133 Lite (tm) Controller (RAID mode)(0x105A-0x1275)"},
{0x105A, 0x5275, 0x1458, 0xB001, "MBUltra 133(0x1458-0xB001)"},
{0x105A, 0x5300, 0xFFFF, 0xFFFF, "DC5300(0x5300)"},
{0x105A, 0x6268, 0xFFFF, 0xFFFF, "PDC20270 (FastTrak100 LP/TX2/TX4)(0x6268)"},
{0x105A, 0x6268, 0x105A, 0x4D68, "FastTrak100 TX2(0x105A-0x4D68)"},
{0x105A, 0x6269, 0xFFFF, 0xFFFF, "PDC20271 (FastTrak TX2000)(0x6269)"},
{0x105A, 0x6269, 0x105A, 0x6269, "FastTrak TX2/TX2000(0x105A-0x6269)"},
{0x105A, 0x6300, 0xFFFF, 0xFFFF, "PDC81731 [FastTrak SX8300](0x6300)"},
{0x105A, 0x6621, 0xFFFF, 0xFFFF, "PDC20621 (FastTrak S150 SX4/FastTrak SX4000 lite)(0x6621)"},
{0x105A, 0x6622, 0xFFFF, 0xFFFF, "PDC20621 [SATA150 SX4] 4 Channel IDE RAID Controller(0x6622)"},
{0x105A, 0x6624, 0xFFFF, 0xFFFF, "PDC20621 [FastTrak SX4100](0x6624)"},
{0x105A, 0x6626, 0xFFFF, 0xFFFF, "PDC20618 (Ultra 618)(0x6626)"},
{0x105A, 0x6629, 0xFFFF, 0xFFFF, "PDC20619 (FastTrak TX4000)(0x6629)"},
{0x105A, 0x7275, 0xFFFF, 0xFFFF, "PDC20277 (SBFastTrak133 Lite)(0x7275)"},
{0x105A, 0x8002, 0xFFFF, 0xFFFF, "SATAII150 SX8(0x8002)"},
{0x105A, 0x8350, 0xFFFF, 0xFFFF, "80333 [SuperTrak EX8350/EX16350], 80331 [SuperTrak EX8300/EX16300](0x8350)"},
{0x105A, 0x8650, 0xFFFF, 0xFFFF, "81384 [SuperTrak EX SAS and SATA RAID Controller](0x8650)"},
{0x105A, 0x8650, 0x105A, 0x4600, "SuperTrak EX4650A(0x105A-0x4600)"},
{0x105A, 0x8650, 0x105A, 0x4601, "SuperTrak EX4650(0x105A-0x4601)"},
{0x105A, 0x8650, 0x105A, 0x4610, "SuperTrak EX4650EL(0x105A-0x4610)"},
{0x105A, 0x8650, 0x105A, 0x8600, "SuperTrak EX8650EL(0x105A-0x8600)"},
{0x105A, 0x8650, 0x105A, 0x8601, "SuperTrak EX8650A(0x105A-0x8601)"},
{0x105A, 0x8650, 0x105A, 0x8602, "SuperTrak EX8654(0x105A-0x8602)"},
{0x105A, 0x8650, 0x105A, 0x8603, "SuperTrak EX8658(0x105A-0x8603)"},
{0x105A, 0x8650, 0x105A, 0x8604, "SuperTrak EX8650(0x105A-0x8604)"},
{0x105A, 0x8650, 0x105A, 0x8610, "SuperTrak EX8650M(0x105A-0x8610)"},
{0x105A, 0x8650, 0x105A, 0xA600, "SuperTrak EX12650(0x105A-0xA600)"},
{0x105A, 0x8650, 0x105A, 0xB600, "SuperTrak EX16650(0x105A-0xB600)"},
{0x105A, 0x8650, 0x105A, 0xB601, "SuperTrak EX16654(0x105A-0xB601)"},
{0x105A, 0x8650, 0x105A, 0xB602, "SuperTrak EX16658(0x105A-0xB602)"},
{0x105A, 0x8760, 0xFFFF, 0xFFFF, "PM8010 [SuperTrak EX SAS and SATA 6G RAID Controller](0x8760)"},
{0x105A, 0xC350, 0xFFFF, 0xFFFF, "80333 [SuperTrak EX12350](0xC350)"},
{0x105A, 0xE350, 0xFFFF, 0xFFFF, "80333 [SuperTrak EX24350](0xE350)"},
}; /* pci_vid_105A[] */

static pci_id_t const pci_vid_105B[] = {
{0x105B, 0xFFFF, 0xFFFF, 0xFFFF, "Foxconn International, Inc.(0x105B)"},
{0x105B, 0x9602, 0xFFFF, 0xFFFF, "RS780/RS880 PCI to PCI bridge (int gfx)(0x9602)"},
{0x105B, 0xE0C3, 0xFFFF, 0xFFFF, "T99W175 5G Modem [Snapdragon X55](0xE0C3)"},
}; /* pci_vid_105B[] */

static pci_id_t const pci_vid_105C[] = {
{0x105C, 0xFFFF, 0xFFFF, 0xFFFF, "Wipro Infotech Limited(0x105C)"},
}; /* pci_vid_105C[] */

static pci_id_t const pci_vid_105D[] = {
{0x105D, 0xFFFF, 0xFFFF, 0xFFFF, "Number 9 Computer Company(0x105D)"},
{0x105D, 0x2309, 0xFFFF, 0xFFFF, "Imagine 128(0x2309)"},
{0x105D, 0x2339, 0xFFFF, 0xFFFF, "Imagine 128-II(0x2339)"},
{0x105D, 0x2339, 0x105D, 0x0000, "Imagine 128 series 2 4Mb VRAM(0x105D-0x0000)"},
{0x105D, 0x2339, 0x105D, 0x0001, "Imagine 128 series 2 4Mb VRAM(0x105D-0x0001)"},
{0x105D, 0x2339, 0x105D, 0x0002, "Imagine 128 series 2 4Mb VRAM(0x105D-0x0002)"},
{0x105D, 0x2339, 0x105D, 0x0003, "Imagine 128 series 2 4Mb VRAM(0x105D-0x0003)"},
{0x105D, 0x2339, 0x105D, 0x0004, "Imagine 128 series 2 4Mb VRAM(0x105D-0x0004)"},
{0x105D, 0x2339, 0x105D, 0x0005, "Imagine 128 series 2 4Mb VRAM(0x105D-0x0005)"},
{0x105D, 0x2339, 0x105D, 0x0006, "Imagine 128 series 2 4Mb VRAM(0x105D-0x0006)"},
{0x105D, 0x2339, 0x105D, 0x0007, "Imagine 128 series 2 4Mb VRAM(0x105D-0x0007)"},
{0x105D, 0x2339, 0x105D, 0x0008, "Imagine 128 series 2e 4Mb DRAM(0x105D-0x0008)"},
{0x105D, 0x2339, 0x105D, 0x0009, "Imagine 128 series 2e 4Mb DRAM(0x105D-0x0009)"},
{0x105D, 0x2339, 0x105D, 0x000A, "Imagine 128 series 2 8Mb VRAM(0x105D-0x000A)"},
{0x105D, 0x2339, 0x105D, 0x000B, "Imagine 128 series 2 8Mb H-VRAM(0x105D-0x000B)"},
{0x105D, 0x2339, 0x11A4, 0x000A, "Metheus 5 Megapixel(0x11A4-0x000A)"},
{0x105D, 0x2339, 0x13CC, 0x0000, "Metheus 5 Megapixel(0x13CC-0x0000)"},
{0x105D, 0x2339, 0x13CC, 0x0004, "Metheus 5 Megapixel(0x13CC-0x0004)"},
{0x105D, 0x2339, 0x13CC, 0x0005, "Metheus 5 Megapixel(0x13CC-0x0005)"},
{0x105D, 0x2339, 0x13CC, 0x0006, "Metheus 5 Megapixel(0x13CC-0x0006)"},
{0x105D, 0x2339, 0x13CC, 0x0008, "Metheus 5 Megapixel(0x13CC-0x0008)"},
{0x105D, 0x2339, 0x13CC, 0x0009, "Metheus 5 Megapixel(0x13CC-0x0009)"},
{0x105D, 0x2339, 0x13CC, 0x000A, "Metheus 5 Megapixel(0x13CC-0x000A)"},
{0x105D, 0x2339, 0x13CC, 0x000C, "Metheus 5 Megapixel(0x13CC-0x000C)"},
{0x105D, 0x493D, 0xFFFF, 0xFFFF, "Imagine 128 T2R [Ticket to Ride](0x493D)"},
{0x105D, 0x493D, 0x11A4, 0x000A, "Metheus 5 Megapixel, Dual Head(0x11A4-0x000A)"},
{0x105D, 0x493D, 0x11A4, 0x000B, "Metheus 5 Megapixel, Dual Head(0x11A4-0x000B)"},
{0x105D, 0x493D, 0x13CC, 0x0002, "Metheus 4 Megapixel, Dual Head(0x13CC-0x0002)"},
{0x105D, 0x493D, 0x13CC, 0x0003, "Metheus 5 Megapixel, Dual Head(0x13CC-0x0003)"},
{0x105D, 0x493D, 0x13CC, 0x0007, "Metheus 5 Megapixel, Dual Head(0x13CC-0x0007)"},
{0x105D, 0x493D, 0x13CC, 0x0008, "Metheus 5 Megapixel, Dual Head(0x13CC-0x0008)"},
{0x105D, 0x493D, 0x13CC, 0x0009, "Metheus 5 Megapixel, Dual Head(0x13CC-0x0009)"},
{0x105D, 0x493D, 0x13CC, 0x000A, "Metheus 5 Megapixel, Dual Head(0x13CC-0x000A)"},
{0x105D, 0x5348, 0xFFFF, 0xFFFF, "Revolution 4(0x5348)"},
{0x105D, 0x5348, 0x105D, 0x0037, "Revolution IV-FP AGP (For SGI 1600SW)(0x105D-0x0037)"},
{0x105D, 0x5348, 0x11A4, 0x0028, "PVS5600M(0x11A4-0x0028)"},
{0x105D, 0x5348, 0x11A4, 0x0038, "PVS5600D(0x11A4-0x0038)"},
}; /* pci_vid_105D[] */

static pci_id_t const pci_vid_105E[] = {
{0x105E, 0xFFFF, 0xFFFF, 0xFFFF, "Vtech Computers Ltd(0x105E)"},
}; /* pci_vid_105E[] */

static pci_id_t const pci_vid_105F[] = {
{0x105F, 0xFFFF, 0xFFFF, 0xFFFF, "Infotronic America Inc(0x105F)"},
}; /* pci_vid_105F[] */

static pci_id_t const pci_vid_1060[] = {
{0x1060, 0xFFFF, 0xFFFF, 0xFFFF, "United Microelectronics [UMC](0x1060)"},
{0x1060, 0x0001, 0xFFFF, 0xFFFF, "UM82C881(0x0001)"},
{0x1060, 0x0002, 0xFFFF, 0xFFFF, "UM82C886(0x0002)"},
{0x1060, 0x0101, 0xFFFF, 0xFFFF, "UM8673F(0x0101)"},
{0x1060, 0x0881, 0xFFFF, 0xFFFF, "UM8881(0x0881)"},
{0x1060, 0x0886, 0xFFFF, 0xFFFF, "UM8886F(0x0886)"},
{0x1060, 0x0891, 0xFFFF, 0xFFFF, "UM8891A(0x0891)"},
{0x1060, 0x1001, 0xFFFF, 0xFFFF, "UM886A(0x1001)"},
{0x1060, 0x673A, 0xFFFF, 0xFFFF, "UM8886BF(0x673A)"},
{0x1060, 0x673B, 0xFFFF, 0xFFFF, "EIDE Master/DMA(0x673B)"},
{0x1060, 0x8710, 0xFFFF, 0xFFFF, "UM8710(0x8710)"},
{0x1060, 0x886A, 0xFFFF, 0xFFFF, "UM8886A(0x886A)"},
{0x1060, 0x8881, 0xFFFF, 0xFFFF, "UM8881F(0x8881)"},
{0x1060, 0x8886, 0xFFFF, 0xFFFF, "UM8886F(0x8886)"},
{0x1060, 0x888A, 0xFFFF, 0xFFFF, "UM8886A(0x888A)"},
{0x1060, 0x8891, 0xFFFF, 0xFFFF, "UM8891A(0x8891)"},
{0x1060, 0x9017, 0xFFFF, 0xFFFF, "UM9017F(0x9017)"},
{0x1060, 0x9018, 0xFFFF, 0xFFFF, "UM9018(0x9018)"},
{0x1060, 0x9026, 0xFFFF, 0xFFFF, "UM9026(0x9026)"},
{0x1060, 0xE881, 0xFFFF, 0xFFFF, "UM8881N(0xE881)"},
{0x1060, 0xE886, 0xFFFF, 0xFFFF, "UM8886N(0xE886)"},
{0x1060, 0xE88A, 0xFFFF, 0xFFFF, "UM8886N(0xE88A)"},
{0x1060, 0xE891, 0xFFFF, 0xFFFF, "UM8891N(0xE891)"},
}; /* pci_vid_1060[] */

static pci_id_t const pci_vid_1061[] = {
{0x1061, 0xFFFF, 0xFFFF, 0xFFFF, "I.I.T.(0x1061)"},
{0x1061, 0x0001, 0xFFFF, 0xFFFF, "AGX016(0x0001)"},
{0x1061, 0x0002, 0xFFFF, 0xFFFF, "IIT3204/3501(0x0002)"},
}; /* pci_vid_1061[] */

static pci_id_t const pci_vid_1062[] = {
{0x1062, 0xFFFF, 0xFFFF, 0xFFFF, "Maspar Computer Corp(0x1062)"},
}; /* pci_vid_1062[] */

static pci_id_t const pci_vid_1063[] = {
{0x1063, 0xFFFF, 0xFFFF, 0xFFFF, "Ocean Office Automation(0x1063)"},
}; /* pci_vid_1063[] */

static pci_id_t const pci_vid_1064[] = {
{0x1064, 0xFFFF, 0xFFFF, 0xFFFF, "Alcatel(0x1064)"},
{0x1064, 0x1102, 0xFFFF, 0xFFFF, "Dynamite 2840 (ADSL PCI modem)(0x1102)"},
}; /* pci_vid_1064[] */

static pci_id_t const pci_vid_1065[] = {
{0x1065, 0xFFFF, 0xFFFF, 0xFFFF, "Texas Microsystems(0x1065)"},
}; /* pci_vid_1065[] */

static pci_id_t const pci_vid_1066[] = {
{0x1066, 0xFFFF, 0xFFFF, 0xFFFF, "PicoPower Technology(0x1066)"},
{0x1066, 0x0000, 0xFFFF, 0xFFFF, "PT80C826(0x0000)"},
{0x1066, 0x0001, 0xFFFF, 0xFFFF, "PT86C521 [Vesuvius v1] Host Bridge(0x0001)"},
{0x1066, 0x0002, 0xFFFF, 0xFFFF, "PT86C523 [Vesuvius v3] PCI-ISA Bridge Master(0x0002)"},
{0x1066, 0x0003, 0xFFFF, 0xFFFF, "PT86C524 [Nile] PCI-to-PCI Bridge(0x0003)"},
{0x1066, 0x0004, 0xFFFF, 0xFFFF, "PT86C525 [Nile-II] PCI-to-PCI Bridge(0x0004)"},
{0x1066, 0x0005, 0xFFFF, 0xFFFF, "National PC87550 System Controller(0x0005)"},
{0x1066, 0x8002, 0xFFFF, 0xFFFF, "PT86C523 [Vesuvius v3] PCI-ISA Bridge Slave(0x8002)"},
}; /* pci_vid_1066[] */

static pci_id_t const pci_vid_1067[] = {
{0x1067, 0xFFFF, 0xFFFF, 0xFFFF, "Mitsubishi Electric(0x1067)"},
{0x1067, 0x0301, 0xFFFF, 0xFFFF, "AccelGraphics AccelECLIPSE(0x0301)"},
{0x1067, 0x0304, 0xFFFF, 0xFFFF, "AccelGALAXY A2100 [OEM Evans & Sutherland](0x0304)"},
{0x1067, 0x0308, 0xFFFF, 0xFFFF, "Tornado 3000 [OEM Evans & Sutherland](0x0308)"},
{0x1067, 0x1002, 0xFFFF, 0xFFFF, "VG500 [VolumePro Volume Rendering Accelerator](0x1002)"},
}; /* pci_vid_1067[] */

static pci_id_t const pci_vid_1068[] = {
{0x1068, 0xFFFF, 0xFFFF, 0xFFFF, "Diversified Technology(0x1068)"},
}; /* pci_vid_1068[] */

static pci_id_t const pci_vid_1069[] = {
{0x1069, 0xFFFF, 0xFFFF, 0xFFFF, "Mylex Corporation(0x1069)"},
{0x1069, 0x0001, 0xFFFF, 0xFFFF, "DAC960P(0x0001)"},
{0x1069, 0x0002, 0xFFFF, 0xFFFF, "DAC960PD(0x0002)"},
{0x1069, 0x0010, 0xFFFF, 0xFFFF, "DAC960PG(0x0010)"},
{0x1069, 0x0020, 0xFFFF, 0xFFFF, "DAC960LA(0x0020)"},
{0x1069, 0x0050, 0xFFFF, 0xFFFF, "AcceleRAID 352/170/160 support Device(0x0050)"},
{0x1069, 0x0050, 0x1069, 0x0050, "AcceleRAID 352 support Device(0x1069-0x0050)"},
{0x1069, 0x0050, 0x1069, 0x0052, "AcceleRAID 170 support Device(0x1069-0x0052)"},
{0x1069, 0x0050, 0x1069, 0x0054, "AcceleRAID 160 support Device(0x1069-0x0054)"},
{0x1069, 0xB166, 0xFFFF, 0xFFFF, "AcceleRAID 600/500/400/Sapphire support Device(0xB166)"},
{0x1069, 0xB166, 0x1014, 0x0242, "iSeries 2872 DASD IOA(0x1014-0x0242)"},
{0x1069, 0xB166, 0x1014, 0x0266, "Dual Channel PCI-X U320 SCSI Adapter(0x1014-0x0266)"},
{0x1069, 0xB166, 0x1014, 0x0278, "Dual Channel PCI-X U320 SCSI RAID Adapter(0x1014-0x0278)"},
{0x1069, 0xB166, 0x1014, 0x02D3, "Dual Channel PCI-X U320 SCSI Adapter(0x1014-0x02D3)"},
{0x1069, 0xB166, 0x1014, 0x02D4, "Dual Channel PCI-X U320 SCSI RAID Adapter(0x1014-0x02D4)"},
{0x1069, 0xB166, 0x1069, 0x0200, "AcceleRAID 400, Single Channel, PCI-X, U320, SCSI RAID(0x1069-0x0200)"},
{0x1069, 0xB166, 0x1069, 0x0202, "AcceleRAID Sapphire, Dual Channel, PCI-X, U320, SCSI RAID(0x1069-0x0202)"},
{0x1069, 0xB166, 0x1069, 0x0204, "AcceleRAID 500, Dual Channel, Low-Profile, PCI-X, U320, SCSI RAID(0x1069-0x0204)"},
{0x1069, 0xB166, 0x1069, 0x0206, "AcceleRAID 600, Dual Channel, PCI-X, U320, SCSI RAID(0x1069-0x0206)"},
{0x1069, 0xBA55, 0xFFFF, 0xFFFF, "eXtremeRAID 1100 support Device(0xBA55)"},
{0x1069, 0xBA56, 0xFFFF, 0xFFFF, "eXtremeRAID 2000/3000 support Device(0xBA56)"},
{0x1069, 0xBA56, 0x1069, 0x0030, "eXtremeRAID 3000 support Device(0x1069-0x0030)"},
{0x1069, 0xBA56, 0x1069, 0x0040, "eXtremeRAID 2000 support Device(0x1069-0x0040)"},
{0x1069, 0xBA57, 0xFFFF, 0xFFFF, "eXtremeRAID 4000/5000 support Device(0xBA57)"},
{0x1069, 0xBA57, 0x1069, 0x0072, "eXtremeRAID 5000 support Device(0x1069-0x0072)"},
}; /* pci_vid_1069[] */

static pci_id_t const pci_vid_106A[] = {
{0x106A, 0xFFFF, 0xFFFF, 0xFFFF, "Aten Research Inc(0x106A)"},
}; /* pci_vid_106A[] */

static pci_id_t const pci_vid_106B[] = {
{0x106B, 0xFFFF, 0xFFFF, 0xFFFF, "Apple Inc.(0x106B)"},
{0x106B, 0x0001, 0xFFFF, 0xFFFF, "Bandit PowerPC host bridge(0x0001)"},
{0x106B, 0x0002, 0xFFFF, 0xFFFF, "Grand Central I/O(0x0002)"},
{0x106B, 0x0003, 0xFFFF, 0xFFFF, "Control Video(0x0003)"},
{0x106B, 0x0004, 0xFFFF, 0xFFFF, "PlanB Video-In(0x0004)"},
{0x106B, 0x0007, 0xFFFF, 0xFFFF, "O'Hare I/O(0x0007)"},
{0x106B, 0x000B, 0xFFFF, 0xFFFF, "Apple Camera(0x000B)"},
{0x106B, 0x000C, 0xFFFF, 0xFFFF, "DOS on Mac(0x000C)"},
{0x106B, 0x000E, 0xFFFF, 0xFFFF, "Hydra Mac I/O(0x000E)"},
{0x106B, 0x0010, 0xFFFF, 0xFFFF, "Heathrow Mac I/O(0x0010)"},
{0x106B, 0x0017, 0xFFFF, 0xFFFF, "Paddington Mac I/O(0x0017)"},
{0x106B, 0x0018, 0xFFFF, 0xFFFF, "UniNorth FireWire(0x0018)"},
{0x106B, 0x0019, 0xFFFF, 0xFFFF, "KeyLargo USB(0x0019)"},
{0x106B, 0x001E, 0xFFFF, 0xFFFF, "UniNorth Internal PCI(0x001E)"},
{0x106B, 0x001F, 0xFFFF, 0xFFFF, "UniNorth PCI(0x001F)"},
{0x106B, 0x0020, 0xFFFF, 0xFFFF, "UniNorth AGP(0x0020)"},
{0x106B, 0x0021, 0xFFFF, 0xFFFF, "UniNorth GMAC (Sun GEM)(0x0021)"},
{0x106B, 0x0022, 0xFFFF, 0xFFFF, "KeyLargo Mac I/O(0x0022)"},
{0x106B, 0x0024, 0xFFFF, 0xFFFF, "UniNorth/Pangea GMAC (Sun GEM)(0x0024)"},
{0x106B, 0x0025, 0xFFFF, 0xFFFF, "KeyLargo/Pangea Mac I/O(0x0025)"},
{0x106B, 0x0026, 0xFFFF, 0xFFFF, "KeyLargo/Pangea USB(0x0026)"},
{0x106B, 0x0027, 0xFFFF, 0xFFFF, "UniNorth/Pangea AGP(0x0027)"},
{0x106B, 0x0028, 0xFFFF, 0xFFFF, "UniNorth/Pangea PCI(0x0028)"},
{0x106B, 0x0029, 0xFFFF, 0xFFFF, "UniNorth/Pangea Internal PCI(0x0029)"},
{0x106B, 0x002D, 0xFFFF, 0xFFFF, "UniNorth 1.5 AGP(0x002D)"},
{0x106B, 0x002E, 0xFFFF, 0xFFFF, "UniNorth 1.5 PCI(0x002E)"},
{0x106B, 0x002F, 0xFFFF, 0xFFFF, "UniNorth 1.5 Internal PCI(0x002F)"},
{0x106B, 0x0030, 0xFFFF, 0xFFFF, "UniNorth/Pangea FireWire(0x0030)"},
{0x106B, 0x0031, 0xFFFF, 0xFFFF, "UniNorth 2 FireWire(0x0031)"},
{0x106B, 0x0031, 0x106B, 0x5811, "iBook G4 2004(0x106B-0x5811)"},
{0x106B, 0x0032, 0xFFFF, 0xFFFF, "UniNorth 2 GMAC (Sun GEM)(0x0032)"},
{0x106B, 0x0033, 0xFFFF, 0xFFFF, "UniNorth 2 ATA/100(0x0033)"},
{0x106B, 0x0034, 0xFFFF, 0xFFFF, "UniNorth 2 AGP(0x0034)"},
{0x106B, 0x0035, 0xFFFF, 0xFFFF, "UniNorth 2 PCI(0x0035)"},
{0x106B, 0x0036, 0xFFFF, 0xFFFF, "UniNorth 2 Internal PCI(0x0036)"},
{0x106B, 0x003B, 0xFFFF, 0xFFFF, "UniNorth/Intrepid ATA/100(0x003B)"},
{0x106B, 0x003E, 0xFFFF, 0xFFFF, "KeyLargo/Intrepid Mac I/O(0x003E)"},
{0x106B, 0x003F, 0xFFFF, 0xFFFF, "KeyLargo/Intrepid USB(0x003F)"},
{0x106B, 0x003F, 0x1AF4, 0x1100, "QEMU Virtual Machine(0x1AF4-0x1100)"},
{0x106B, 0x0040, 0xFFFF, 0xFFFF, "K2 KeyLargo USB(0x0040)"},
{0x106B, 0x0041, 0xFFFF, 0xFFFF, "K2 KeyLargo Mac/IO(0x0041)"},
{0x106B, 0x0042, 0xFFFF, 0xFFFF, "K2 FireWire(0x0042)"},
{0x106B, 0x0043, 0xFFFF, 0xFFFF, "K2 ATA/100(0x0043)"},
{0x106B, 0x0045, 0xFFFF, 0xFFFF, "K2 HT-PCI Bridge(0x0045)"},
{0x106B, 0x0046, 0xFFFF, 0xFFFF, "K2 HT-PCI Bridge(0x0046)"},
{0x106B, 0x0047, 0xFFFF, 0xFFFF, "K2 HT-PCI Bridge(0x0047)"},
{0x106B, 0x0048, 0xFFFF, 0xFFFF, "K2 HT-PCI Bridge(0x0048)"},
{0x106B, 0x0049, 0xFFFF, 0xFFFF, "K2 HT-PCI Bridge(0x0049)"},
{0x106B, 0x004A, 0xFFFF, 0xFFFF, "CPC945 HT Bridge(0x004A)"},
{0x106B, 0x004B, 0xFFFF, 0xFFFF, "U3 AGP(0x004B)"},
{0x106B, 0x004C, 0xFFFF, 0xFFFF, "K2 GMAC (Sun GEM)(0x004C)"},
{0x106B, 0x004F, 0xFFFF, 0xFFFF, "Shasta Mac I/O(0x004F)"},
{0x106B, 0x0050, 0xFFFF, 0xFFFF, "Shasta IDE(0x0050)"},
{0x106B, 0x0051, 0xFFFF, 0xFFFF, "Shasta (Sun GEM)(0x0051)"},
{0x106B, 0x0052, 0xFFFF, 0xFFFF, "Shasta Firewire(0x0052)"},
{0x106B, 0x0053, 0xFFFF, 0xFFFF, "Shasta PCI Bridge(0x0053)"},
{0x106B, 0x0054, 0xFFFF, 0xFFFF, "Shasta PCI Bridge(0x0054)"},
{0x106B, 0x0055, 0xFFFF, 0xFFFF, "Shasta PCI Bridge(0x0055)"},
{0x106B, 0x0056, 0xFFFF, 0xFFFF, "U4 PCIe(0x0056)"},
{0x106B, 0x0057, 0xFFFF, 0xFFFF, "U3 HT Bridge(0x0057)"},
{0x106B, 0x0058, 0xFFFF, 0xFFFF, "U3L AGP Bridge(0x0058)"},
{0x106B, 0x0059, 0xFFFF, 0xFFFF, "U3H AGP Bridge(0x0059)"},
{0x106B, 0x005B, 0xFFFF, 0xFFFF, "CPC945 PCIe Bridge(0x005B)"},
{0x106B, 0x0066, 0xFFFF, 0xFFFF, "Intrepid2 AGP Bridge(0x0066)"},
{0x106B, 0x0067, 0xFFFF, 0xFFFF, "Intrepid2 PCI Bridge(0x0067)"},
{0x106B, 0x0068, 0xFFFF, 0xFFFF, "Intrepid2 PCI Bridge(0x0068)"},
{0x106B, 0x0069, 0xFFFF, 0xFFFF, "Intrepid2 ATA/100(0x0069)"},
{0x106B, 0x006A, 0xFFFF, 0xFFFF, "Intrepid2 Firewire(0x006A)"},
{0x106B, 0x006B, 0xFFFF, 0xFFFF, "Intrepid2 GMAC (Sun GEM)(0x006B)"},
{0x106B, 0x0074, 0xFFFF, 0xFFFF, "U4 HT Bridge(0x0074)"},
{0x106B, 0x100C, 0xFFFF, 0xFFFF, "Apple Silicon PCI Express Root Port(0x100C)"},
{0x106B, 0x1010, 0xFFFF, 0xFFFF, "Apple Silicon USB4/Thunderbolt PCI Express Root Port(0x1010)"},
{0x106B, 0x1645, 0xFFFF, 0xFFFF, "Broadcom NetXtreme BCM5701 Gigabit Ethernet(0x1645)"},
{0x106B, 0x1801, 0xFFFF, 0xFFFF, "T2 Bridge Controller(0x1801)"},
{0x106B, 0x1802, 0xFFFF, 0xFFFF, "T2 Secure Enclave Processor(0x1802)"},
{0x106B, 0x1803, 0xFFFF, 0xFFFF, "Apple Audio Device(0x1803)"},
{0x106B, 0x2001, 0xFFFF, 0xFFFF, "S1X NVMe Controller(0x2001)"},
{0x106B, 0x2002, 0xFFFF, 0xFFFF, "S3ELab NVMe Controller(0x2002)"},
{0x106B, 0x2003, 0xFFFF, 0xFFFF, "S3X NVMe Controller(0x2003)"},
{0x106B, 0x2005, 0xFFFF, 0xFFFF, "ANS2 NVMe Controller(0x2005)"},
}; /* pci_vid_106B[] */

static pci_id_t const pci_vid_106C[] = {
{0x106C, 0xFFFF, 0xFFFF, 0xFFFF, "Hynix Semiconductor(0x106C)"},
{0x106C, 0x8139, 0xFFFF, 0xFFFF, "8139c 100BaseTX Ethernet Controller(0x8139)"},
{0x106C, 0x8801, 0xFFFF, 0xFFFF, "Dual Pentium ISA/PCI Motherboard(0x8801)"},
{0x106C, 0x8802, 0xFFFF, 0xFFFF, "PowerPC ISA/PCI Motherboard(0x8802)"},
{0x106C, 0x8803, 0xFFFF, 0xFFFF, "Dual Window Graphics Accelerator(0x8803)"},
{0x106C, 0x8804, 0xFFFF, 0xFFFF, "LAN Controller(0x8804)"},
{0x106C, 0x8805, 0xFFFF, 0xFFFF, "100-BaseT LAN(0x8805)"},
}; /* pci_vid_106C[] */

static pci_id_t const pci_vid_106D[] = {
{0x106D, 0xFFFF, 0xFFFF, 0xFFFF, "Sequent Computer Systems(0x106D)"},
}; /* pci_vid_106D[] */

static pci_id_t const pci_vid_106E[] = {
{0x106E, 0xFFFF, 0xFFFF, 0xFFFF, "DFI, Inc(0x106E)"},
}; /* pci_vid_106E[] */

static pci_id_t const pci_vid_106F[] = {
{0x106F, 0xFFFF, 0xFFFF, 0xFFFF, "City Gate Development Ltd(0x106F)"},
}; /* pci_vid_106F[] */

static pci_id_t const pci_vid_1070[] = {
{0x1070, 0xFFFF, 0xFFFF, 0xFFFF, "Daewoo Telecom Ltd(0x1070)"},
}; /* pci_vid_1070[] */

static pci_id_t const pci_vid_1071[] = {
{0x1071, 0xFFFF, 0xFFFF, 0xFFFF, "Mitac(0x1071)"},
{0x1071, 0x8160, 0xFFFF, 0xFFFF, "Mitac 8060B Mobile Platform(0x8160)"},
}; /* pci_vid_1071[] */

static pci_id_t const pci_vid_1072[] = {
{0x1072, 0xFFFF, 0xFFFF, 0xFFFF, "GIT Co Ltd(0x1072)"},
}; /* pci_vid_1072[] */

static pci_id_t const pci_vid_1073[] = {
{0x1073, 0xFFFF, 0xFFFF, 0xFFFF, "Yamaha Corporation(0x1073)"},
{0x1073, 0x0001, 0xFFFF, 0xFFFF, "3D GUI Accelerator(0x0001)"},
{0x1073, 0x0002, 0xFFFF, 0xFFFF, "YGV615 [RPA3 3D-Graphics Controller](0x0002)"},
{0x1073, 0x0003, 0xFFFF, 0xFFFF, "YMF-740(0x0003)"},
{0x1073, 0x0004, 0xFFFF, 0xFFFF, "YMF-724(0x0004)"},
{0x1073, 0x0004, 0x1073, 0x0004, "YMF724-Based PCI Audio Adapter(0x1073-0x0004)"},
{0x1073, 0x0005, 0xFFFF, 0xFFFF, "DS1 Audio(0x0005)"},
{0x1073, 0x0005, 0x1073, 0x0005, "DS-XG PCI Audio CODEC(0x1073-0x0005)"},
{0x1073, 0x0006, 0xFFFF, 0xFFFF, "DS1 Audio(0x0006)"},
{0x1073, 0x0008, 0xFFFF, 0xFFFF, "DS1 Audio(0x0008)"},
{0x1073, 0x0008, 0x1073, 0x0008, "DS-XG PCI Audio CODEC(0x1073-0x0008)"},
{0x1073, 0x000A, 0xFFFF, 0xFFFF, "DS1L Audio(0x000A)"},
{0x1073, 0x000A, 0x1073, 0x0004, "DS-XG PCI Audio CODEC(0x1073-0x0004)"},
{0x1073, 0x000A, 0x1073, 0x000A, "DS-XG PCI Audio CODEC(0x1073-0x000A)"},
{0x1073, 0x000A, 0x8086, 0x4D55, "DS-XG PCI Audio CODEC [Intel MU440EX](0x8086-0x4D55)"},
{0x1073, 0x000C, 0xFFFF, 0xFFFF, "YMF-740C [DS-1L Audio Controller](0x000C)"},
{0x1073, 0x000C, 0x107A, 0x000C, "DS-XG PCI Audio CODEC(0x107A-0x000C)"},
{0x1073, 0x000D, 0xFFFF, 0xFFFF, "YMF-724F [DS-1 Audio Controller](0x000D)"},
{0x1073, 0x000D, 0x1073, 0x000D, "DS-XG PCI Audio CODEC(0x1073-0x000D)"},
{0x1073, 0x0010, 0xFFFF, 0xFFFF, "YMF-744B [DS-1S Audio Controller](0x0010)"},
{0x1073, 0x0010, 0x1073, 0x0006, "DS-XG PCI Audio CODEC(0x1073-0x0006)"},
{0x1073, 0x0010, 0x1073, 0x0010, "DS-XG PCI Audio CODEC(0x1073-0x0010)"},
{0x1073, 0x0012, 0xFFFF, 0xFFFF, "YMF-754 [DS-1E Audio Controller](0x0012)"},
{0x1073, 0x0012, 0x1073, 0x0012, "DS-XG PCI Audio Codec(0x1073-0x0012)"},
{0x1073, 0x0020, 0xFFFF, 0xFFFF, "DS-1 Audio(0x0020)"},
{0x1073, 0x1000, 0xFFFF, 0xFFFF, "SW1000XG [XG Factory](0x1000)"},
{0x1073, 0x2000, 0xFFFF, 0xFFFF, "DS2416 Digital Mixing Card(0x2000)"},
{0x1073, 0x2000, 0x1073, 0x2000, "DS2416 Digital Mixing Card(0x1073-0x2000)"},
}; /* pci_vid_1073[] */

static pci_id_t const pci_vid_1074[] = {
{0x1074, 0xFFFF, 0xFFFF, 0xFFFF, "NexGen Microsystems(0x1074)"},
{0x1074, 0x4E78, 0xFFFF, 0xFFFF, "82c500/1(0x4E78)"},
}; /* pci_vid_1074[] */

static pci_id_t const pci_vid_1075[] = {
{0x1075, 0xFFFF, 0xFFFF, 0xFFFF, "Advanced Integrations Research(0x1075)"},
}; /* pci_vid_1075[] */

static pci_id_t const pci_vid_1076[] = {
{0x1076, 0xFFFF, 0xFFFF, 0xFFFF, "Chaintech Computer Co. Ltd(0x1076)"},
}; /* pci_vid_1076[] */

static pci_id_t const pci_vid_1077[] = {
{0x1077, 0xFFFF, 0xFFFF, 0xFFFF, "QLogic Corp.(0x1077)"},
{0x1077, 0x1016, 0xFFFF, 0xFFFF, "ISP10160 Single Channel Ultra3 SCSI Processor(0x1016)"},
{0x1077, 0x1020, 0xFFFF, 0xFFFF, "ISP1020/1040 Fast-wide SCSI(0x1020)"},
{0x1077, 0x1022, 0xFFFF, 0xFFFF, "ISP1022 Fast-wide SCSI(0x1022)"},
{0x1077, 0x1080, 0xFFFF, 0xFFFF, "ISP1080 SCSI Host Adapter(0x1080)"},
{0x1077, 0x1216, 0xFFFF, 0xFFFF, "ISP12160 Dual Channel Ultra3 SCSI Processor(0x1216)"},
{0x1077, 0x1216, 0x101E, 0x8471, "QLA12160 on AMI MegaRAID(0x101E-0x8471)"},
{0x1077, 0x1216, 0x101E, 0x8493, "QLA12160 on AMI MegaRAID(0x101E-0x8493)"},
{0x1077, 0x1240, 0xFFFF, 0xFFFF, "ISP1240 SCSI Host Adapter(0x1240)"},
{0x1077, 0x1280, 0xFFFF, 0xFFFF, "ISP1280 SCSI Host Adapter(0x1280)"},
{0x1077, 0x1634, 0xFFFF, 0xFFFF, "FastLinQ QL45000 Series 40GbE Controller(0x1634)"},
{0x1077, 0x1634, 0x1077, 0xE4F1, "FastLinQ QL45212H 40GbE Adapter(0x1077-0xE4F1)"},
{0x1077, 0x1634, 0x1077, 0xE4F2, "FastLinQ QL45211H 40GbE Adapter(0x1077-0xE4F2)"},
{0x1077, 0x1634, 0x1077, 0xE4F3, "FastLinQ QL45412H 40GbE Adapter(0x1077-0xE4F3)"},
{0x1077, 0x1634, 0x1077, 0xE4F4, "FastLinQ QL45411H 40GbE Adapter(0x1077-0xE4F4)"},
{0x1077, 0x1644, 0xFFFF, 0xFFFF, "FastLinQ QL45000 Series 100GbE Controller(0x1644)"},
{0x1077, 0x1644, 0x1077, 0xE4F8, "FastLinQ QL45611H 100GbE Adapter(0x1077-0xE4F8)"},
{0x1077, 0x1654, 0xFFFF, 0xFFFF, "FastLinQ QL45000 Series 50GbE Controller(0x1654)"},
{0x1077, 0x1654, 0x1077, 0x0032, "QL45212 Flex 50Gb 2-port Ethernet Adapter(0x1077-0x0032)"},
{0x1077, 0x1654, 0x1590, 0x0223, "Synergy 6810C 25/50Gb Ethernet Adapter(0x1590-0x0223)"},
{0x1077, 0x1654, 0x1590, 0x0287, "Synergy 6820C 25/50Gb CNA(0x1590-0x0287)"},
{0x1077, 0x1656, 0xFFFF, 0xFFFF, "FastLinQ QL45000 Series 25GbE Controller(0x1656)"},
{0x1077, 0x1656, 0x1077, 0x0033, "QL45214 Flex 25Gb 4-port Ethernet Adapter(0x1077-0x0033)"},
{0x1077, 0x1656, 0x1077, 0x02A7, "QL45212-DE 25GbE Adapter(0x1077-0x02A7)"},
{0x1077, 0x1656, 0x1077, 0xE4F6, "FastLinQ QL45211H 25GbE Adapter(0x1077-0xE4F6)"},
{0x1077, 0x1656, 0x1077, 0xE4F7, "FastLinQ QL45212H 25GbE Adapter(0x1077-0xE4F7)"},
{0x1077, 0x1656, 0x1590, 0x0245, "10/20/25GbE 2P 4820c CNA(0x1590-0x0245)"},
{0x1077, 0x165C, 0xFFFF, 0xFFFF, "FastLinQ QL45000 Series 10/25/40/50GbE Controller (FCoE)(0x165C)"},
{0x1077, 0x165C, 0x1077, 0x0034, "QL45262 Flex 50Gb 2-port Ethernet Adapter w/ iSCSI/FCoE(0x1077-0x0034)"},
{0x1077, 0x165C, 0x1077, 0xE4F1, "FastLinQ QL45462H 40GbE FCoE Adapter(0x1077-0xE4F1)"},
{0x1077, 0x165C, 0x1077, 0xE4F2, "FastLinQ QL45461H 40GbE FCoE Adapter(0x1077-0xE4F2)"},
{0x1077, 0x165C, 0x1590, 0x0245, "10/20/25GbE 2P 4820c CNA FCoE(0x1590-0x0245)"},
{0x1077, 0x165E, 0xFFFF, 0xFFFF, "FastLinQ QL45000 Series 10/25/40/50GbE Controller (iSCSI)(0x165E)"},
{0x1077, 0x165E, 0x1077, 0x0034, "QL45262 Flex 50Gb 2-port Ethernet Adapter w/ iSCSI/FCoE(0x1077-0x0034)"},
{0x1077, 0x165E, 0x1077, 0xE4F1, "FastLinQ QL45462H 40GbE iSCSI Adapter(0x1077-0xE4F1)"},
{0x1077, 0x165E, 0x1077, 0xE4F2, "FastLinQ QL45461H 40GbE iSCSI Adapter(0x1077-0xE4F2)"},
{0x1077, 0x165E, 0x1590, 0x0245, "10/20/25GbE 2P 4820c CNA iSCSI(0x1590-0x0245)"},
{0x1077, 0x1664, 0xFFFF, 0xFFFF, "FastLinQ QL45000 Series Gigabit Ethernet Controller (SR-IOV VF)(0x1664)"},
{0x1077, 0x1664, 0x1077, 0xE4F1, "FastLinQ QL45462H 40GbE Adapter (SR-IOV VF)(0x1077-0xE4F1)"},
{0x1077, 0x1664, 0x1077, 0xE4F2, "FastLinQ QL45461H 40GbE Adapter (SR-IOV VF)(0x1077-0xE4F2)"},
{0x1077, 0x1664, 0x1077, 0xE4F3, "FastLinQ QL45412H 40GbE Adapter (SR-IOV VF)(0x1077-0xE4F3)"},
{0x1077, 0x1664, 0x1077, 0xE4F4, "FastLinQ QL45411H 40GbE Adapter (SR-IOV VF)(0x1077-0xE4F4)"},
{0x1077, 0x1664, 0x1077, 0xE4F6, "FastLinQ QL45211H 25GbE Adapter (SR-IOV VF)(0x1077-0xE4F6)"},
{0x1077, 0x1664, 0x1077, 0xE4F7, "FastLinQ QL45212H 25GbE Adapter (SR-IOV VF)(0x1077-0xE4F7)"},
{0x1077, 0x1664, 0x1077, 0xE4F8, "FastLinQ QL45611H 100GbE Adapter (SR-IOV VF)(0x1077-0xE4F8)"},
{0x1077, 0x1664, 0x1590, 0x0245, "10/20/25GbE 2P 4820c CNA SRIOV(0x1590-0x0245)"},
{0x1077, 0x2020, 0xFFFF, 0xFFFF, "ISP2020A Fast!SCSI Basic Adapter(0x2020)"},
{0x1077, 0x2031, 0xFFFF, 0xFFFF, "ISP8324-based 16Gb Fibre Channel to PCI Express Adapter(0x2031)"},
{0x1077, 0x2031, 0x103C, 0x17E7, "SN1000Q 16Gb Single Port Fibre Channel Adapter(0x103C-0x17E7)"},
{0x1077, 0x2031, 0x103C, 0x17E8, "SN1000Q 16Gb Dual Port Fibre Channel Adapter(0x103C-0x17E8)"},
{0x1077, 0x2031, 0x103C, 0x1939, "QMH2672 16Gb Dual Port Fibre Channel Adapter(0x103C-0x1939)"},
{0x1077, 0x2031, 0x103C, 0x8002, "3830C 16G Fibre Channel Host Bus Adapter(0x103C-0x8002)"},
{0x1077, 0x2031, 0x1077, 0x0241, "QLE2670 16Gb Single Port Fibre Channel Adapter(0x1077-0x0241)"},
{0x1077, 0x2071, 0xFFFF, 0xFFFF, "ISP2714-based 16/32Gb Fibre Channel to PCIe Adapter(0x2071)"},
{0x1077, 0x2071, 0x1077, 0x0283, "QLE2764 Quad Port 32Gb Fibre Channel to PCIe Adapter(0x1077-0x0283)"},
{0x1077, 0x2071, 0x1077, 0x029E, "QLE2694 Quad Port 16Gb Fibre Channel to PCIe Adapter(0x1077-0x029E)"},
{0x1077, 0x2071, 0x1077, 0x02A2, "QLE2694L Quad Port 16Gb Fibre Channel to PCIe Adapter(0x1077-0x02A2)"},
{0x1077, 0x2071, 0x1077, 0x02AD, "QLE2694U Quad Port 16/32Gb Fibre Channel to PCIe Adapter(0x1077-0x02AD)"},
{0x1077, 0x2081, 0xFFFF, 0xFFFF, "ISP2814-based 64/32G Fibre Channel to PCIe Controller(0x2081)"},
{0x1077, 0x2081, 0x1077, 0x02E1, "QLE2874 Quad Port 64GFC PCIe Gen4 x16 Adapter(0x1077-0x02E1)"},
{0x1077, 0x2081, 0x1077, 0x02E3, "QLE2774 Quad Port 32GFC PCIe Gen4 x16 Adapter(0x1077-0x02E3)"},
{0x1077, 0x2089, 0xFFFF, 0xFFFF, "ISP2854-based 64/32G Fibre Channel to PCIe Controller with StorCryption(0x2089)"},
{0x1077, 0x2089, 0x1077, 0x02E8, "QLE2884 Quad Port 64GFC PCIe Gen4 x16 Adapter with StorCryption(0x1077-0x02E8)"},
{0x1077, 0x2089, 0x1077, 0x02EA, "QLE2784 Quad Port 32GFC PCIe Gen4 x16 Adapter with StorCryption(0x1077-0x02EA)"},
{0x1077, 0x2100, 0xFFFF, 0xFFFF, "QLA2100 64-bit Fibre Channel Adapter(0x2100)"},
{0x1077, 0x2100, 0x1077, 0x0001, "QLA2100 64-bit Fibre Channel Adapter(0x1077-0x0001)"},
{0x1077, 0x2200, 0xFFFF, 0xFFFF, "QLA2200 64-bit Fibre Channel Adapter(0x2200)"},
{0x1077, 0x2200, 0x1077, 0x0002, "QLA2200(0x1077-0x0002)"},
{0x1077, 0x2261, 0xFFFF, 0xFFFF, "ISP2722-based 16/32Gb Fibre Channel to PCIe Adapter(0x2261)"},
{0x1077, 0x2261, 0x1077, 0x0299, "QLE2740 Single Port 32Gb Fibre Channel to PCIe Adapter(0x1077-0x0299)"},
{0x1077, 0x2261, 0x1077, 0x029A, "QLE2742 Dual Port 32Gb Fibre Channel to PCIe Adapter(0x1077-0x029A)"},
{0x1077, 0x2261, 0x1077, 0x029B, "QLE2690 Single Port 16Gb Fibre Channel to PCIe Adapter(0x1077-0x029B)"},
{0x1077, 0x2261, 0x1077, 0x029C, "QLE2692 Dual Port 16Gb Fibre Channel to PCIe Adapter(0x1077-0x029C)"},
{0x1077, 0x2261, 0x1077, 0x02A7, "QLE2690 Single Port 16Gb FC to PCIe Gen3 x8 Adapter(0x1077-0x02A7)"},
{0x1077, 0x2261, 0x1077, 0x02A8, "QLE2692 Dual Port 16Gb FC to PCIe Gen3 x8 Adapter(0x1077-0x02A8)"},
{0x1077, 0x2261, 0x1077, 0x02AB, "QLE2740 Single Port 32Gb FC to PCIe Gen3 x8 Adapter(0x1077-0x02AB)"},
{0x1077, 0x2261, 0x1077, 0x02AC, "QLE2742 Dual Port 32Gb FC to PCIe Gen3 x8 Adapter(0x1077-0x02AC)"},
{0x1077, 0x2261, 0x1077, 0x02B8, "2x16Gb QME2692 FC HBA(0x1077-0x02B8)"},
{0x1077, 0x2261, 0x1077, 0x02B9, "2x32Gb QME2742 FC HBA(0x1077-0x02B9)"},
{0x1077, 0x2261, 0x1590, 0x00F9, "StoreFabric SN1100Q 16Gb Single Port Fibre Channel Host Bus Adapter(0x1590-0x00F9)"},
{0x1077, 0x2261, 0x1590, 0x00FA, "StoreFabric SN1100Q 16Gb Dual Port Fibre Channel Host Bus Adapter(0x1590-0x00FA)"},
{0x1077, 0x2261, 0x1590, 0x0203, "StoreFabric SN1600Q 32Gb Single Port Fibre Channel Host Bus Adapter(0x1590-0x0203)"},
{0x1077, 0x2261, 0x1590, 0x0204, "StoreFabric SN1600Q 32Gb Dual Port Fibre Channel Host Bus Adapter(0x1590-0x0204)"},
{0x1077, 0x2261, 0x1590, 0x022D, "5830C 32Gb Dual Port Fibre Channel Adapter(0x1590-0x022D)"},
{0x1077, 0x2261, 0x193D, 0x100D, "NIC-FC680i-Mb-2x16G(0x193D-0x100D)"},
{0x1077, 0x2281, 0xFFFF, 0xFFFF, "ISP2812-based 64/32G Fibre Channel to PCIe Controller(0x2281)"},
{0x1077, 0x2281, 0x1077, 0x02E2, "QLE2872 Dual Port 64GFC PCIe Gen4 x8 Adapter(0x1077-0x02E2)"},
{0x1077, 0x2281, 0x1077, 0x02E4, "QLE2772 Dual Port 32GFC PCIe Gen4 x8 Adapter(0x1077-0x02E4)"},
{0x1077, 0x2281, 0x1077, 0x02EE, "QLE2870 Single Port 64GFC PCIe Gen4 x8 Adapter(0x1077-0x02EE)"},
{0x1077, 0x2281, 0x1077, 0x02F0, "QLE2770 Single Port 32GFC PCIe Gen4 x8 Adapter(0x1077-0x02F0)"},
{0x1077, 0x2281, 0x1077, 0x02F2, "QLogic 1x32Gb QLE2770 FC HBA(0x1077-0x02F2)"},
{0x1077, 0x2281, 0x1077, 0x02F3, "QLogic 2x32Gb QLE2772 FC HBA(0x1077-0x02F3)"},
{0x1077, 0x2281, 0x1590, 0x02D3, "SN1610Q - 1P Enhanced 32GFC Single Port Fibre Channel Host Bus Adapter(0x1590-0x02D3)"},
{0x1077, 0x2281, 0x1590, 0x02D4, "SN1610Q - 2P Enhanced 32GFC Dual Port Fibre Channel Host Bus Adapter(0x1590-0x02D4)"},
{0x1077, 0x2289, 0xFFFF, 0xFFFF, "ISP2852-based 64/32G Fibre Channel to PCIe Controller with StorCryption(0x2289)"},
{0x1077, 0x2289, 0x1077, 0x02E9, "QLE2882 Dual Port 64GFC PCIe Gen4 x8 Adapter with StorCryption(0x1077-0x02E9)"},
{0x1077, 0x2289, 0x1077, 0x02EB, "QLE2782 Dual Port 32GFC PCIe Gen4 x8 Adapter with StorCryption(0x1077-0x02EB)"},
{0x1077, 0x2289, 0x1077, 0x02EF, "QLE2880 Single Port 64GFC PCIe Gen4 x8 Adapter with StorCryption(0x1077-0x02EF)"},
{0x1077, 0x2289, 0x1077, 0x02F1, "QLE2780 Single Port 32GFC PCIe Gen4 x8 Adapter with StorCryption(0x1077-0x02F1)"},
{0x1077, 0x2300, 0xFFFF, 0xFFFF, "QLA2300 64-bit Fibre Channel Adapter(0x2300)"},
{0x1077, 0x2312, 0xFFFF, 0xFFFF, "ISP2312-based 2Gb Fibre Channel to PCI-X HBA(0x2312)"},
{0x1077, 0x2312, 0x103C, 0x0131, "2Gb Fibre Channel - Single port [A7538A](0x103C-0x0131)"},
{0x1077, 0x2312, 0x103C, 0x12BA, "2Gb Fibre Channel - Dual port [A6826A](0x103C-0x12BA)"},
{0x1077, 0x2322, 0xFFFF, 0xFFFF, "ISP2322-based 2Gb Fibre Channel to PCI-X HBA(0x2322)"},
{0x1077, 0x2422, 0xFFFF, 0xFFFF, "ISP2422-based 4Gb Fibre Channel to PCI-X HBA(0x2422)"},
{0x1077, 0x2422, 0x103C, 0x12D7, "4Gb Fibre Channel [AB379A](0x103C-0x12D7)"},
{0x1077, 0x2422, 0x103C, 0x12DD, "4Gb Fibre Channel [AB429A](0x103C-0x12DD)"},
{0x1077, 0x2432, 0xFFFF, 0xFFFF, "ISP2432-based 4Gb Fibre Channel to PCI Express HBA(0x2432)"},
{0x1077, 0x2432, 0x103C, 0x7040, "FC1142SR 4Gb 1-port PCIe Fibre Channel Host Bus Adapter [HPAE311A](0x103C-0x7040)"},
{0x1077, 0x2432, 0x1077, 0x0137, "QLE2460 Single-Port 4Gbps FC-to-PCI-X/PCIe Host Bus Adapter(0x1077-0x0137)"},
{0x1077, 0x2432, 0x1077, 0x0138, "QLE2462 Dual-Port 4Gbps FC-to-PCI-X/PCIe Host Bus Adapter(0x1077-0x0138)"},
{0x1077, 0x2532, 0xFFFF, 0xFFFF, "ISP2532-based 8Gb Fibre Channel to PCI Express HBA(0x2532)"},
{0x1077, 0x2532, 0x1014, 0x041E, "FC EN0Y/EN12 PCIe2 LP 8 Gb 4-port Fibre Channel Adapter for POWER(0x1014-0x041E)"},
{0x1077, 0x2532, 0x103C, 0x3262, "StorageWorks 81Q(0x103C-0x3262)"},
{0x1077, 0x2532, 0x103C, 0x3263, "StorageWorks 82Q(0x103C-0x3263)"},
{0x1077, 0x2532, 0x1077, 0x015C, "QLE2560 PCI Express to 8Gb FC Single Channel(0x1077-0x015C)"},
{0x1077, 0x2532, 0x1077, 0x015D, "QLE2562 PCI Express to 8Gb FC Dual Channel(0x1077-0x015D)"},
{0x1077, 0x2532, 0x1077, 0x015E, "QLE2564 PCI Express to 8Gb FC Quad Channel(0x1077-0x015E)"},
{0x1077, 0x2532, 0x1077, 0x0167, "QME2572 Dual Port FC8 HBA Mezzanine(0x1077-0x0167)"},
{0x1077, 0x2532, 0x1590, 0x00FC, "StoreFabric 84Q 8Gb Quad Port Fibre Channel Host Bus Adapter(0x1590-0x00FC)"},
{0x1077, 0x2971, 0xFFFF, 0xFFFF, "ISP2684(0x2971)"},
{0x1077, 0x3022, 0xFFFF, 0xFFFF, "ISP4022-based Ethernet NIC(0x3022)"},
{0x1077, 0x3032, 0xFFFF, 0xFFFF, "ISP4032-based Ethernet IPv6 NIC(0x3032)"},
{0x1077, 0x4010, 0xFFFF, 0xFFFF, "ISP4010-based iSCSI TOE HBA(0x4010)"},
{0x1077, 0x4022, 0xFFFF, 0xFFFF, "ISP4022-based iSCSI TOE HBA(0x4022)"},
{0x1077, 0x4032, 0xFFFF, 0xFFFF, "ISP4032-based iSCSI TOE IPv6 HBA(0x4032)"},
{0x1077, 0x5432, 0xFFFF, 0xFFFF, "SP232-based 4Gb Fibre Channel to PCI Express HBA(0x5432)"},
{0x1077, 0x6312, 0xFFFF, 0xFFFF, "SP202-based 2Gb Fibre Channel to PCI-X HBA(0x6312)"},
{0x1077, 0x6322, 0xFFFF, 0xFFFF, "SP212-based 2Gb Fibre Channel to PCI-X HBA(0x6322)"},
{0x1077, 0x7220, 0xFFFF, 0xFFFF, "IBA7220 InfiniBand HCA(0x7220)"},
{0x1077, 0x7322, 0xFFFF, 0xFFFF, "IBA7322 QDR InfiniBand HCA(0x7322)"},
{0x1077, 0x8000, 0xFFFF, 0xFFFF, "10GbE Converged Network Adapter (TCP/IP Networking)(0x8000)"},
{0x1077, 0x8001, 0xFFFF, 0xFFFF, "10GbE Converged Network Adapter (FCoE)(0x8001)"},
{0x1077, 0x8001, 0x1014, 0x03AF, "FC 5708/5270 10 Gb FCoE PCIe Dual Port Adapter for POWER(0x1014-0x03AF)"},
{0x1077, 0x8020, 0xFFFF, 0xFFFF, "cLOM8214 1/10GbE Controller(0x8020)"},
{0x1077, 0x8020, 0x1028, 0x1F64, "QMD8262-k 10G DP bNDC KR(0x1028-0x1F64)"},
{0x1077, 0x8020, 0x103C, 0x3346, "CN1000Q Dual Port Converged Network Adapter(0x103C-0x3346)"},
{0x1077, 0x8020, 0x103C, 0x3733, "NC523SFP 10Gb 2-port Server Adapter(0x103C-0x3733)"},
{0x1077, 0x8020, 0x1077, 0x0203, "8200 Series Single Port 10GbE Converged Network Adapter (TCP/IP Networking)(0x1077-0x0203)"},
{0x1077, 0x8020, 0x1077, 0x0207, "8200 Series Dual Port 10GbE Converged Network Adapter (TCP/IP Networking)(0x1077-0x0207)"},
{0x1077, 0x8020, 0x1077, 0x020B, "3200 Series Dual Port 10Gb Intelligent Ethernet Adapter(0x1077-0x020B)"},
{0x1077, 0x8020, 0x1077, 0x020C, "3200 Series Quad Port 1Gb Intelligent Ethernet Adapter(0x1077-0x020C)"},
{0x1077, 0x8020, 0x1077, 0x020F, "3200 Series Single Port 10Gb Intelligent Ethernet Adapter(0x1077-0x020F)"},
{0x1077, 0x8020, 0x1077, 0x0210, "QME8242-k 10GbE Dual Port Mezzanine Card(0x1077-0x0210)"},
{0x1077, 0x8020, 0x1077, 0x0233, "QME8262-k 10GbE Dual Port Mezzanine Card(0x1077-0x0233)"},
{0x1077, 0x8021, 0xFFFF, 0xFFFF, "8200 Series 10GbE Converged Network Adapter (FCoE)(0x8021)"},
{0x1077, 0x8021, 0x103C, 0x3348, "CN1000Q Dual Port Converged Network Adapter(0x103C-0x3348)"},
{0x1077, 0x8021, 0x1077, 0x0211, "QME8242-k 10GbE Dual Port Mezzanine Card, FCoE(0x1077-0x0211)"},
{0x1077, 0x8022, 0xFFFF, 0xFFFF, "8200 Series 10GbE Converged Network Adapter (iSCSI)(0x8022)"},
{0x1077, 0x8022, 0x103C, 0x3347, "CN1000Q Dual Port Converged Network Adapter(0x103C-0x3347)"},
{0x1077, 0x8022, 0x1077, 0x0212, "QME8242-k 10GbE Dual Port Mezzanine Card, iSCSI(0x1077-0x0212)"},
{0x1077, 0x8030, 0xFFFF, 0xFFFF, "ISP8324 1/10GbE Converged Network Controller(0x8030)"},
{0x1077, 0x8030, 0x1077, 0x0243, "8300 Series Single Port 10GbE Converged Network Adapter (TCP/IP Networking)(0x1077-0x0243)"},
{0x1077, 0x8030, 0x1077, 0x0246, "8300 Series Dual Port 10GbE Converged Network Adapter (TCP/IP Networking)(0x1077-0x0246)"},
{0x1077, 0x8031, 0xFFFF, 0xFFFF, "8300 Series 10GbE Converged Network Adapter (FCoE)(0x8031)"},
{0x1077, 0x8032, 0xFFFF, 0xFFFF, "8300 Series 10GbE Converged Network Adapter (iSCSI)(0x8032)"},
{0x1077, 0x8070, 0xFFFF, 0xFFFF, "FastLinQ QL41000 Series 10/25/40/50GbE Controller(0x8070)"},
{0x1077, 0x8070, 0x1077, 0x0001, "10GE 2P QL41162HxRJ-DE Adapter(0x1077-0x0001)"},
{0x1077, 0x8070, 0x1077, 0x0002, "10GE 2P QL41112HxCU-DE Adapter(0x1077-0x0002)"},
{0x1077, 0x8070, 0x1077, 0x0004, "4x10GE QL41164HFCU CNA(0x1077-0x0004)"},
{0x1077, 0x8070, 0x1077, 0x0005, "QLogic 4x10GE QL41164HMRJ CNA(0x1077-0x0005)"},
{0x1077, 0x8070, 0x1077, 0x0006, "QLogic 4x10GE QL41164HMCU CNA(0x1077-0x0006)"},
{0x1077, 0x8070, 0x1077, 0x0007, "QLogic 2x1GE+2x10GE QL41264HMCU CNA(0x1077-0x0007)"},
{0x1077, 0x8070, 0x1077, 0x0009, "QLogic 2x1GE+2x10GE QL41162HMRJ CNA(0x1077-0x0009)"},
{0x1077, 0x8070, 0x1077, 0x000B, "25GE 2P QL41262HxCU-DE Adapter(0x1077-0x000B)"},
{0x1077, 0x8070, 0x1077, 0x000F, "2x25GE QL41262HMKR CNA(0x1077-0x000F)"},
{0x1077, 0x8070, 0x1077, 0x0010, "2x25GE QL41232HMKR NIC(0x1077-0x0010)"},
{0x1077, 0x8070, 0x1077, 0x0011, "FastLinQ QL41212HLCU 25GbE Adapter(0x1077-0x0011)"},
{0x1077, 0x8070, 0x1077, 0x0012, "FastLinQ QL41112H 10GbE Adapter(0x1077-0x0012)"},
{0x1077, 0x8070, 0x1077, 0x0019, "QL41232HOCU - Dual Port 25/10GbE SFP28 OCP Adapter(0x1077-0x0019)"},
{0x1077, 0x8070, 0x1077, 0x0039, "QLogic QL41262 PCIe 25Gb 2-Port SFP28 Ethernet Adapter(0x1077-0x0039)"},
{0x1077, 0x8070, 0x1077, 0x0053, "QLogic 2x25GE QL41232HQCU NIC(0x1077-0x0053)"},
{0x1077, 0x8070, 0x1077, 0x0054, "2x10GE QL41132HQRJ NIC(0x1077-0x0054)"},
{0x1077, 0x8070, 0x1077, 0x0055, "QLogic 2x10GE QL41132HQCU NIC(0x1077-0x0055)"},
{0x1077, 0x8070, 0x1077, 0x0056, "2x10GE QL41132HxRJ NIC(0x1077-0x0056)"},
{0x1077, 0x8070, 0x1077, 0x0057, "2x25GE QL41232HxCU NIC(0x1077-0x0057)"},
{0x1077, 0x8070, 0x1077, 0x0065, "QLogic 4x10GE QL41154HQRJ CNA(0x1077-0x0065)"},
{0x1077, 0x8070, 0x1077, 0x0066, "QLogic 4x10GE QL41154HQCU CNA(0x1077-0x0066)"},
{0x1077, 0x8070, 0x1077, 0x0068, "10GbE 2p SFP+ QL41132HLCU-HC Adapter(0x1077-0x0068)"},
{0x1077, 0x8070, 0x1077, 0x0069, "10GbE 2p BASE-T QL41132HQRJ-HC OCP3 Adapter(0x1077-0x0069)"},
{0x1077, 0x8070, 0x1077, 0x0070, "10GbE 2p BASE-T QL41132HLRJ-HC Adapter(0x1077-0x0070)"},
{0x1077, 0x8070, 0x1077, 0x0071, "10GbE 2p SFP+ QL41132HQCU-HC OCP3 Adapter(0x1077-0x0071)"},
{0x1077, 0x8070, 0x1077, 0x0072, "10GbE 4p SFP+ QL41134HLCU-HC Adapter(0x1077-0x0072)"},
{0x1077, 0x8070, 0x1077, 0x0073, "10/25GbE 2p SFP28 QL41232HQCU-HC OCP3 Adapter(0x1077-0x0073)"},
{0x1077, 0x8070, 0x1077, 0x0074, "10/25GbE 2p SFP28 QL41232HLCU-HC Adapter(0x1077-0x0074)"},
{0x1077, 0x8070, 0x1590, 0x021A, "10GbE 2P QL41162HLRJ-HP Adapter(0x1590-0x021A)"},
{0x1077, 0x8070, 0x1590, 0x021B, "10GbE 2P QL41162HLRJ-HP Adapter(0x1590-0x021B)"},
{0x1077, 0x8070, 0x1590, 0x021D, "10/25GbE 2P QL41222HLCU-HP Adapter(0x1590-0x021D)"},
{0x1077, 0x8070, 0x1590, 0x021E, "10/25GbE 2P QL41162HMRJ-HP Adapter(0x1590-0x021E)"},
{0x1077, 0x8070, 0x1590, 0x021F, "10/25GbE 2P QL41262HMCU-HP Adapter(0x1590-0x021F)"},
{0x1077, 0x8070, 0x1590, 0x0220, "10/25GbE 2P QL41122HLRJ-HP Adapter(0x1590-0x0220)"},
{0x1077, 0x8070, 0x1590, 0x02BD, "10Gb 2P 524SFP+ NIC(0x1590-0x02BD)"},
{0x1077, 0x8070, 0x193D, 0x1030, "NIC-ETH681i-Mb-2x25G(0x193D-0x1030)"},
{0x1077, 0x8070, 0x193D, 0x1032, "NIC-ETH682i-Mb-2x25G(0x193D-0x1032)"},
{0x1077, 0x8080, 0xFFFF, 0xFFFF, "FastLinQ QL41000 Series 10/25/40/50GbE Controller (FCoE)(0x8080)"},
{0x1077, 0x8080, 0x1077, 0x0001, "10GE 2P QL41162HxRJ-DE Adapter(0x1077-0x0001)"},
{0x1077, 0x8080, 0x1077, 0x0002, "10GE 2P QL41112HxCU-DE Adapter(0x1077-0x0002)"},
{0x1077, 0x8080, 0x1077, 0x0004, "4x10GE QL41164HFCU CNA(0x1077-0x0004)"},
{0x1077, 0x8080, 0x1077, 0x0005, "QLogic 4x10GE QL41164HMRJ CNA(0x1077-0x0005)"},
{0x1077, 0x8080, 0x1077, 0x0006, "QLogic 4x10GE QL41164HMCU CNA(0x1077-0x0006)"},
{0x1077, 0x8080, 0x1077, 0x0007, "QLogic 2x1GE+2x10GE QL41264HMCU CNA(0x1077-0x0007)"},
{0x1077, 0x8080, 0x1077, 0x0009, "QLogic 2x1GE+2x10GE QL41162HMRJ CNA(0x1077-0x0009)"},
{0x1077, 0x8080, 0x1077, 0x000B, "25GE 2P QL41262HxCU-DE Adapter(0x1077-0x000B)"},
{0x1077, 0x8080, 0x1077, 0x000C, "QLogic 2x25GE QL41262HMCU CNA(0x1077-0x000C)"},
{0x1077, 0x8080, 0x1077, 0x000D, "FastLinQ QL41262H 25GbE FCoE Adapter(0x1077-0x000D)"},
{0x1077, 0x8080, 0x1077, 0x000E, "FastLinQ QL41162H 10GbE FCoE Adapter(0x1077-0x000E)"},
{0x1077, 0x8080, 0x1077, 0x000F, "2x25GE QL41262HMKR CNA(0x1077-0x000F)"},
{0x1077, 0x8080, 0x1590, 0x021A, "10GbE 2P QL41162HLRJ-HP Adapter(0x1590-0x021A)"},
{0x1077, 0x8080, 0x1590, 0x021B, "10GbE 2P QL41162HLRJ-HP Adapter(0x1590-0x021B)"},
{0x1077, 0x8084, 0xFFFF, 0xFFFF, "FastLinQ QL41000 Series 10/25/40/50GbE Controller (iSCSI)(0x8084)"},
{0x1077, 0x8084, 0x1077, 0x0001, "10GE 2P QL41162HxRJ-DE Adapter(0x1077-0x0001)"},
{0x1077, 0x8084, 0x1077, 0x0002, "10GE 2P QL41112HxCU-DE Adapter(0x1077-0x0002)"},
{0x1077, 0x8084, 0x1077, 0x0003, "4x10GE QL41164HxRJ CNA(0x1077-0x0003)"},
{0x1077, 0x8084, 0x1077, 0x0004, "4x10GE QL41164HFCU CNA(0x1077-0x0004)"},
{0x1077, 0x8084, 0x1077, 0x0005, "QLogic 4x10GE QL41164HMRJ CNA(0x1077-0x0005)"},
{0x1077, 0x8084, 0x1077, 0x0006, "QLogic 4x10GE QL41164HMCU CNA(0x1077-0x0006)"},
{0x1077, 0x8084, 0x1077, 0x0007, "QLogic 2x25GE QL41262HMCU CNA(0x1077-0x0007)"},
{0x1077, 0x8084, 0x1077, 0x0009, "QLogic 2x1GE+2x10GE QL41162HMRJ CNA(0x1077-0x0009)"},
{0x1077, 0x8084, 0x1077, 0x000B, "25GE 2P QL41262HxCU-DE Adapter(0x1077-0x000B)"},
{0x1077, 0x8084, 0x1077, 0x000C, "QLogic 2x25GE QL41262HMCU CNA(0x1077-0x000C)"},
{0x1077, 0x8084, 0x1077, 0x000D, "FastLinQ QL41262H 25GbE iSCSI Adapter(0x1077-0x000D)"},
{0x1077, 0x8084, 0x1077, 0x000E, "FastLinQ QL41162H 10GbE iSCSI Adapter(0x1077-0x000E)"},
{0x1077, 0x8084, 0x1077, 0x000F, "2x25GE QL41262HMKR CNA(0x1077-0x000F)"},
{0x1077, 0x8084, 0x1077, 0x0065, "QLogic 4x10GE QL41154HQRJ CNA(0x1077-0x0065)"},
{0x1077, 0x8084, 0x1077, 0x0066, "QLogic 4x10GE QL41154HQCU CNA(0x1077-0x0066)"},
{0x1077, 0x8084, 0x1590, 0x021A, "10GbE 2P QL41162HLRJ-HP Adapter(0x1590-0x021A)"},
{0x1077, 0x8084, 0x1590, 0x021B, "10GbE 2P QL41162HLRJ-HP Adapter(0x1590-0x021B)"},
{0x1077, 0x8090, 0xFFFF, 0xFFFF, "FastLinQ QL41000 Series Gigabit Ethernet Controller (SR-IOV VF)(0x8090)"},
{0x1077, 0x8090, 0x1077, 0x0001, "25GE 2P QL41262HxCU-DE Adapter(0x1077-0x0001)"},
{0x1077, 0x8090, 0x1077, 0x0002, "10GE 2P QL41112HxCU-DE Adapter(0x1077-0x0002)"},
{0x1077, 0x8090, 0x1077, 0x0003, "4x10GE QL41164HxRJ CNA(0x1077-0x0003)"},
{0x1077, 0x8090, 0x1077, 0x0004, "4x10GE QL41164HFCU CNA(0x1077-0x0004)"},
{0x1077, 0x8090, 0x1077, 0x0005, "QLogic 4x10GE QL41164HMRJ CNA(0x1077-0x0005)"},
{0x1077, 0x8090, 0x1077, 0x0006, "QLogic 4x10GE QL41164HMCU CNA(0x1077-0x0006)"},
{0x1077, 0x8090, 0x1077, 0x0007, "QLogic 2x1GE+2x10GE QL41264HMCU CNA(0x1077-0x0007)"},
{0x1077, 0x8090, 0x1077, 0x0009, "QLogic 2x1GE+2x10GE QL41162HMRJ CNA(0x1077-0x0009)"},
{0x1077, 0x8090, 0x1077, 0x000B, "25GE 2P QL41262HxCU-DE Adapter(0x1077-0x000B)"},
{0x1077, 0x8090, 0x1077, 0x000C, "QLogic 2x25GE QL41262HMCU CNA(0x1077-0x000C)"},
{0x1077, 0x8090, 0x1077, 0x000D, "FastLinQ QL41262H 25GbE FCoE Adapter (SR-IOV VF)(0x1077-0x000D)"},
{0x1077, 0x8090, 0x1077, 0x000E, "FastLinQ QL41162H 10GbE iSCSI Adapter (SR-IOV VF)(0x1077-0x000E)"},
{0x1077, 0x8090, 0x1077, 0x000F, "2x25GE QL41262HMKR CNA(0x1077-0x000F)"},
{0x1077, 0x8090, 0x1077, 0x0010, "2x25GE QL41232HMKR NIC(0x1077-0x0010)"},
{0x1077, 0x8090, 0x1077, 0x0011, "FastLinQ QL41212H 25GbE Adapter (SR-IOV VF)(0x1077-0x0011)"},
{0x1077, 0x8090, 0x1077, 0x0012, "FastLinQ QL41112H 10GbE Adapter (SR-IOV VF)(0x1077-0x0012)"},
{0x1077, 0x8090, 0x1077, 0x0053, "QLogic 2x25GE QL41232HQCU NIC(0x1077-0x0053)"},
{0x1077, 0x8090, 0x1077, 0x0054, "QLogic 2x10GE QL41132HQRJ NIC(0x1077-0x0054)"},
{0x1077, 0x8090, 0x1077, 0x0055, "QLogic 2x10GE QL41132HQCU NIC(0x1077-0x0055)"},
{0x1077, 0x8090, 0x1077, 0x0056, "2x10GE QL41132HxRJ NIC(0x1077-0x0056)"},
{0x1077, 0x8090, 0x1077, 0x0057, "2x25GE QL41232HxCU NIC(0x1077-0x0057)"},
{0x1077, 0x8090, 0x1077, 0x0065, "QLogic 4x10GE QL41154HQRJ CNA(0x1077-0x0065)"},
{0x1077, 0x8090, 0x1077, 0x0066, "QLogic 4x10GE QL41154HQCU CNA(0x1077-0x0066)"},
{0x1077, 0x8090, 0x1590, 0x021A, "10GbE 2P QL41162HLRJ-HP Adapter(0x1590-0x021A)"},
{0x1077, 0x8090, 0x1590, 0x021B, "10GbE 2P QL41162HLRJ-HP Adapter(0x1590-0x021B)"},
{0x1077, 0x8090, 0x1590, 0x021E, "10/25GbE 2P QL41162HMRJ-HP Adapter(0x1590-0x021E)"},
{0x1077, 0x8090, 0x1590, 0x021F, "10/25GbE 2P QL41262HMCU-HP Adapter(0x1590-0x021F)"},
{0x1077, 0x8090, 0x1590, 0x02BD, "10Gb 2P 524SFP+ NIC(0x1590-0x02BD)"},
{0x1077, 0x8430, 0xFFFF, 0xFFFF, "ISP8324 1/10GbE Converged Network Controller (NIC VF)(0x8430)"},
{0x1077, 0x8431, 0xFFFF, 0xFFFF, "8300 Series 10GbE Converged Network Adapter (FCoE VF)(0x8431)"},
{0x1077, 0x8432, 0xFFFF, 0xFFFF, "ISP2432M-based 10GbE Converged Network Adapter (CNA)(0x8432)"},
}; /* pci_vid_1077[] */

static pci_id_t const pci_vid_1078[] = {
{0x1078, 0xFFFF, 0xFFFF, 0xFFFF, "Cyrix Corporation(0x1078)"},
{0x1078, 0x0000, 0xFFFF, 0xFFFF, "5510 [Grappa](0x0000)"},
{0x1078, 0x0001, 0xFFFF, 0xFFFF, "PCI Master(0x0001)"},
{0x1078, 0x0002, 0xFFFF, 0xFFFF, "5520 [Cognac](0x0002)"},
{0x1078, 0x0100, 0xFFFF, 0xFFFF, "5530 Legacy [Kahlua](0x0100)"},
{0x1078, 0x0101, 0xFFFF, 0xFFFF, "5530 SMI [Kahlua](0x0101)"},
{0x1078, 0x0102, 0xFFFF, 0xFFFF, "5530 IDE [Kahlua](0x0102)"},
{0x1078, 0x0103, 0xFFFF, 0xFFFF, "5530 Audio [Kahlua](0x0103)"},
{0x1078, 0x0104, 0xFFFF, 0xFFFF, "5530 Video [Kahlua](0x0104)"},
{0x1078, 0x0400, 0xFFFF, 0xFFFF, "ZFMicro PCI Bridge(0x0400)"},
{0x1078, 0x0401, 0xFFFF, 0xFFFF, "ZFMicro Chipset SMI(0x0401)"},
{0x1078, 0x0402, 0xFFFF, 0xFFFF, "ZFMicro Chipset IDE(0x0402)"},
{0x1078, 0x0403, 0xFFFF, 0xFFFF, "ZFMicro Expansion Bus(0x0403)"},
}; /* pci_vid_1078[] */

static pci_id_t const pci_vid_1079[] = {
{0x1079, 0xFFFF, 0xFFFF, 0xFFFF, "I-Bus(0x1079)"},
}; /* pci_vid_1079[] */

static pci_id_t const pci_vid_107A[] = {
{0x107A, 0xFFFF, 0xFFFF, 0xFFFF, "NetWorth(0x107A)"},
}; /* pci_vid_107A[] */

static pci_id_t const pci_vid_107B[] = {
{0x107B, 0xFFFF, 0xFFFF, 0xFFFF, "Gateway, Inc.(0x107B)"},
}; /* pci_vid_107B[] */

static pci_id_t const pci_vid_107C[] = {
{0x107C, 0xFFFF, 0xFFFF, 0xFFFF, "LG Electronics [Lucky Goldstar Co. Ltd](0x107C)"},
}; /* pci_vid_107C[] */

static pci_id_t const pci_vid_107D[] = {
{0x107D, 0xFFFF, 0xFFFF, 0xFFFF, "LeadTek Research Inc.(0x107D)"},
{0x107D, 0x0000, 0xFFFF, 0xFFFF, "P86C850(0x0000)"},
}; /* pci_vid_107D[] */

static pci_id_t const pci_vid_107E[] = {
{0x107E, 0xFFFF, 0xFFFF, 0xFFFF, "Interphase Corporation(0x107E)"},
{0x107E, 0x0001, 0xFFFF, 0xFFFF, "5515 ATM Adapter [Flipper](0x0001)"},
{0x107E, 0x0002, 0xFFFF, 0xFFFF, "100 VG AnyLan Controller(0x0002)"},
{0x107E, 0x0004, 0xFFFF, 0xFFFF, "5526 Fibre Channel Host Adapter(0x0004)"},
{0x107E, 0x0005, 0xFFFF, 0xFFFF, "x526 Fibre Channel Host Adapter(0x0005)"},
{0x107E, 0x0008, 0xFFFF, 0xFFFF, "5525/5575 ATM Adapter (155 Mbit) [Atlantic](0x0008)"},
{0x107E, 0x9003, 0xFFFF, 0xFFFF, "5535-4P-BRI-ST(0x9003)"},
{0x107E, 0x9007, 0xFFFF, 0xFFFF, "5535-4P-BRI-U(0x9007)"},
{0x107E, 0x9008, 0xFFFF, 0xFFFF, "5535-1P-SR(0x9008)"},
{0x107E, 0x900C, 0xFFFF, 0xFFFF, "5535-1P-SR-ST(0x900C)"},
{0x107E, 0x900E, 0xFFFF, 0xFFFF, "5535-1P-SR-U(0x900E)"},
{0x107E, 0x9011, 0xFFFF, 0xFFFF, "5535-1P-PRI(0x9011)"},
{0x107E, 0x9013, 0xFFFF, 0xFFFF, "5535-2P-PRI(0x9013)"},
{0x107E, 0x9023, 0xFFFF, 0xFFFF, "5536-4P-BRI-ST(0x9023)"},
{0x107E, 0x9027, 0xFFFF, 0xFFFF, "5536-4P-BRI-U(0x9027)"},
{0x107E, 0x9031, 0xFFFF, 0xFFFF, "5536-1P-PRI(0x9031)"},
{0x107E, 0x9033, 0xFFFF, 0xFFFF, "5536-2P-PRI(0x9033)"},
}; /* pci_vid_107E[] */

static pci_id_t const pci_vid_107F[] = {
{0x107F, 0xFFFF, 0xFFFF, 0xFFFF, "Data Technology Corporation(0x107F)"},
{0x107F, 0x0802, 0xFFFF, 0xFFFF, "SL82C105(0x0802)"},
}; /* pci_vid_107F[] */

static pci_id_t const pci_vid_1080[] = {
{0x1080, 0xFFFF, 0xFFFF, 0xFFFF, "Contaq Microsystems(0x1080)"},
{0x1080, 0x0600, 0xFFFF, 0xFFFF, "82C599(0x0600)"},
{0x1080, 0xC691, 0xFFFF, 0xFFFF, "Cypress CY82C691(0xC691)"},
{0x1080, 0xC693, 0xFFFF, 0xFFFF, "82c693(0xC693)"},
}; /* pci_vid_1080[] */

static pci_id_t const pci_vid_1081[] = {
{0x1081, 0xFFFF, 0xFFFF, 0xFFFF, "Supermac Technology(0x1081)"},
{0x1081, 0x0D47, 0xFFFF, 0xFFFF, "Radius PCI to NuBUS Bridge(0x0D47)"},
}; /* pci_vid_1081[] */

static pci_id_t const pci_vid_1082[] = {
{0x1082, 0xFFFF, 0xFFFF, 0xFFFF, "EFA Corporation of America(0x1082)"},
}; /* pci_vid_1082[] */

static pci_id_t const pci_vid_1083[] = {
{0x1083, 0xFFFF, 0xFFFF, 0xFFFF, "Forex Computer Corporation(0x1083)"},
{0x1083, 0x0001, 0xFFFF, 0xFFFF, "FR710(0x0001)"},
}; /* pci_vid_1083[] */

static pci_id_t const pci_vid_1084[] = {
{0x1084, 0xFFFF, 0xFFFF, 0xFFFF, "Parador(0x1084)"},
}; /* pci_vid_1084[] */

static pci_id_t const pci_vid_1086[] = {
{0x1086, 0xFFFF, 0xFFFF, 0xFFFF, "J. Bond Computer Systems(0x1086)"},
}; /* pci_vid_1086[] */

static pci_id_t const pci_vid_1087[] = {
{0x1087, 0xFFFF, 0xFFFF, 0xFFFF, "Cache Computer(0x1087)"},
}; /* pci_vid_1087[] */

static pci_id_t const pci_vid_1088[] = {
{0x1088, 0xFFFF, 0xFFFF, 0xFFFF, "Microcomputer Systems (M) Son(0x1088)"},
}; /* pci_vid_1088[] */

static pci_id_t const pci_vid_1089[] = {
{0x1089, 0xFFFF, 0xFFFF, 0xFFFF, "Data General Corporation(0x1089)"},
}; /* pci_vid_1089[] */

static pci_id_t const pci_vid_108A[] = {
{0x108A, 0xFFFF, 0xFFFF, 0xFFFF, "SBS Technologies(0x108A)"},
{0x108A, 0x0001, 0xFFFF, 0xFFFF, "VME Bridge Model 617(0x0001)"},
{0x108A, 0x0010, 0xFFFF, 0xFFFF, "VME Bridge Model 618(0x0010)"},
{0x108A, 0x0040, 0xFFFF, 0xFFFF, "dataBLIZZARD(0x0040)"},
{0x108A, 0x3000, 0xFFFF, 0xFFFF, "VME Bridge Model 2706(0x3000)"},
}; /* pci_vid_108A[] */

static pci_id_t const pci_vid_108C[] = {
{0x108C, 0xFFFF, 0xFFFF, 0xFFFF, "Oakleigh Systems Inc.(0x108C)"},
}; /* pci_vid_108C[] */

static pci_id_t const pci_vid_108D[] = {
{0x108D, 0xFFFF, 0xFFFF, 0xFFFF, "Olicom(0x108D)"},
{0x108D, 0x0001, 0xFFFF, 0xFFFF, "Token-Ring 16/4 PCI Adapter (3136/3137)(0x0001)"},
{0x108D, 0x0002, 0xFFFF, 0xFFFF, "16/4 Token Ring(0x0002)"},
{0x108D, 0x0004, 0xFFFF, 0xFFFF, "RapidFire OC-3139/3140 Token-Ring 16/4 PCI Adapter(0x0004)"},
{0x108D, 0x0004, 0x108D, 0x0004, "OC-3139/3140 RapidFire Token-Ring 16/4 Adapter(0x108D-0x0004)"},
{0x108D, 0x0005, 0xFFFF, 0xFFFF, "GoCard 3250 Token-Ring 16/4 CardBus PC Card(0x0005)"},
{0x108D, 0x0006, 0xFFFF, 0xFFFF, "OC-3530 RapidFire Token-Ring 100(0x0006)"},
{0x108D, 0x0007, 0xFFFF, 0xFFFF, "RapidFire 3141 Token-Ring 16/4 PCI Fiber Adapter(0x0007)"},
{0x108D, 0x0007, 0x108D, 0x0007, "OC-3141 RapidFire Token-Ring 16/4 Adapter(0x108D-0x0007)"},
{0x108D, 0x0008, 0xFFFF, 0xFFFF, "RapidFire 3540 HSTR 100/16/4 PCI Adapter(0x0008)"},
{0x108D, 0x0008, 0x108D, 0x0008, "OC-3540 RapidFire HSTR 100/16/4 Adapter(0x108D-0x0008)"},
{0x108D, 0x0011, 0xFFFF, 0xFFFF, "OC-2315(0x0011)"},
{0x108D, 0x0012, 0xFFFF, 0xFFFF, "OC-2325(0x0012)"},
{0x108D, 0x0013, 0xFFFF, 0xFFFF, "OC-2183/2185(0x0013)"},
{0x108D, 0x0014, 0xFFFF, 0xFFFF, "OC-2326(0x0014)"},
{0x108D, 0x0019, 0xFFFF, 0xFFFF, "OC-2327/2250 10/100 Ethernet Adapter(0x0019)"},
{0x108D, 0x0019, 0x108D, 0x0016, "OC-2327 Rapidfire 10/100 Ethernet Adapter(0x108D-0x0016)"},
{0x108D, 0x0019, 0x108D, 0x0017, "OC-2250 GoCard 10/100 Ethernet Adapter(0x108D-0x0017)"},
{0x108D, 0x0021, 0xFFFF, 0xFFFF, "OC-6151/6152 [RapidFire ATM 155](0x0021)"},
{0x108D, 0x0022, 0xFFFF, 0xFFFF, "ATM Adapter(0x0022)"},
}; /* pci_vid_108D[] */

static pci_id_t const pci_vid_108E[] = {
{0x108E, 0xFFFF, 0xFFFF, 0xFFFF, "Oracle/SUN(0x108E)"},
{0x108E, 0x0001, 0xFFFF, 0xFFFF, "EBUS(0x0001)"},
{0x108E, 0x1000, 0xFFFF, 0xFFFF, "STP2003QFP [PCIO] EBUS(0x1000)"},
{0x108E, 0x1001, 0xFFFF, 0xFFFF, "Happy Meal 10/100 Ethernet [hme](0x1001)"},
{0x108E, 0x1100, 0xFFFF, 0xFFFF, "RIO EBUS(0x1100)"},
{0x108E, 0x1100, 0x108E, 0x1100, "RIO EBUS on Blade 100 motherboard(0x108E-0x1100)"},
{0x108E, 0x1101, 0xFFFF, 0xFFFF, "RIO 10/100 Ethernet [eri](0x1101)"},
{0x108E, 0x1101, 0x108E, 0x1101, "RIO GEM on Blade 100 motherboard(0x108E-0x1101)"},
{0x108E, 0x1102, 0xFFFF, 0xFFFF, "RIO 1394(0x1102)"},
{0x108E, 0x1102, 0x108E, 0x1102, "RIO 1394 on Blade 100 motherboard(0x108E-0x1102)"},
{0x108E, 0x1103, 0xFFFF, 0xFFFF, "RIO USB(0x1103)"},
{0x108E, 0x1103, 0x108E, 0x1103, "RIO USB on Blade 100 motherboard(0x108E-0x1103)"},
{0x108E, 0x1647, 0xFFFF, 0xFFFF, "Broadcom 570x 10/100/1000 Ethernet [bge](0x1647)"},
{0x108E, 0x1648, 0xFFFF, 0xFFFF, "Broadcom 570x 10/100/1000 Ethernet [bge](0x1648)"},
{0x108E, 0x16A7, 0xFFFF, 0xFFFF, "Broadcom 570x 10/100/1000 Ethernet [bge](0x16A7)"},
{0x108E, 0x16A8, 0xFFFF, 0xFFFF, "Broadcom 570x 10/100/1000 Ethernet [bge](0x16A8)"},
{0x108E, 0x2BAD, 0xFFFF, 0xFFFF, "GEM 10/100/1000 Ethernet [ge](0x2BAD)"},
{0x108E, 0x5000, 0xFFFF, 0xFFFF, "Simba Advanced PCI Bridge(0x5000)"},
{0x108E, 0x5000, 0x108E, 0x5000, "Netra AX1105-500(0x108E-0x5000)"},
{0x108E, 0x5043, 0xFFFF, 0xFFFF, "SunPCI Co-processor(0x5043)"},
{0x108E, 0x5CA0, 0xFFFF, 0xFFFF, "Crypto Accelerator 6000 [mca](0x5CA0)"},
{0x108E, 0x6300, 0xFFFF, 0xFFFF, "Intel 21554 PCI-PCI bus bridge [db21554](0x6300)"},
{0x108E, 0x6301, 0xFFFF, 0xFFFF, "Intel 21554 PCI-PCI bus bridge [db21554](0x6301)"},
{0x108E, 0x6302, 0xFFFF, 0xFFFF, "Intel 21554 PCI-PCI bus bridge [db21554](0x6302)"},
{0x108E, 0x6303, 0xFFFF, 0xFFFF, "Intel 21554 PCI-PCI bus bridge [db21554](0x6303)"},
{0x108E, 0x6310, 0xFFFF, 0xFFFF, "Intel 21554 PCI-PCI bus bridge [db21554](0x6310)"},
{0x108E, 0x6311, 0xFFFF, 0xFFFF, "Intel 21554 PCI-PCI bus bridge [db21554](0x6311)"},
{0x108E, 0x6312, 0xFFFF, 0xFFFF, "Intel 21554 PCI-PCI bus bridge [db21554](0x6312)"},
{0x108E, 0x6313, 0xFFFF, 0xFFFF, "Intel 21554 PCI-PCI bus bridge [db21554](0x6313)"},
{0x108E, 0x6320, 0xFFFF, 0xFFFF, "Intel 21554 PCI-PCI bus bridge [db21554](0x6320)"},
{0x108E, 0x6323, 0xFFFF, 0xFFFF, "Intel 21554 PCI-PCI bus bridge [db21554](0x6323)"},
{0x108E, 0x6330, 0xFFFF, 0xFFFF, "Intel 21554 PCI-PCI bus bridge [db21554](0x6330)"},
{0x108E, 0x6331, 0xFFFF, 0xFFFF, "Intel 21554 PCI-PCI bus bridge [db21554](0x6331)"},
{0x108E, 0x6332, 0xFFFF, 0xFFFF, "Intel 21554 PCI-PCI bus bridge [db21554](0x6332)"},
{0x108E, 0x6333, 0xFFFF, 0xFFFF, "Intel 21554 PCI-PCI bus bridge [db21554](0x6333)"},
{0x108E, 0x6340, 0xFFFF, 0xFFFF, "Intel 21554 PCI-PCI bus bridge [db21554](0x6340)"},
{0x108E, 0x6343, 0xFFFF, 0xFFFF, "Intel 21554 PCI-PCI bus bridge [db21554](0x6343)"},
{0x108E, 0x6350, 0xFFFF, 0xFFFF, "Intel 21554 PCI-PCI bus bridge [db21554](0x6350)"},
{0x108E, 0x6353, 0xFFFF, 0xFFFF, "Intel 21554 PCI-PCI bus bridge [db21554](0x6353)"},
{0x108E, 0x6722, 0xFFFF, 0xFFFF, "Intel 21554 PCI-PCI bus bridge [db21554](0x6722)"},
{0x108E, 0x676E, 0xFFFF, 0xFFFF, "SunPCiIII(0x676E)"},
{0x108E, 0x7063, 0xFFFF, 0xFFFF, "SunPCiII / SunPCiIIpro(0x7063)"},
{0x108E, 0x8000, 0xFFFF, 0xFFFF, "Psycho PCI Bus Module(0x8000)"},
{0x108E, 0x8001, 0xFFFF, 0xFFFF, "Schizo PCI Bus Module(0x8001)"},
{0x108E, 0x8002, 0xFFFF, 0xFFFF, "Schizo+ PCI Bus Module(0x8002)"},
{0x108E, 0x80F0, 0xFFFF, 0xFFFF, "PCIe switch [px](0x80F0)"},
{0x108E, 0x80F8, 0xFFFF, 0xFFFF, "PCIe switch [px](0x80F8)"},
{0x108E, 0x9010, 0xFFFF, 0xFFFF, "PCIe/PCI bridge switch [pxb_plx](0x9010)"},
{0x108E, 0x9020, 0xFFFF, 0xFFFF, "PCIe/PCI bridge switch [pxb_plx](0x9020)"},
{0x108E, 0x9102, 0xFFFF, 0xFFFF, "Davicom Fast Ethernet driver for Davicom DM9102A [dmfe](0x9102)"},
{0x108E, 0xA000, 0xFFFF, 0xFFFF, "Psycho UPA-PCI Bus Module [pcipsy](0xA000)"},
{0x108E, 0xA001, 0xFFFF, 0xFFFF, "Psycho UPA-PCI Bus Module [pcipsy](0xA001)"},
{0x108E, 0xA001, 0x108E, 0xA001, "Ultra IIe on Blade 100 motherboard(0x108E-0xA001)"},
{0x108E, 0xA801, 0xFFFF, 0xFFFF, "Schizo Fireplane-PCI bus bridge module [pcisch](0xA801)"},
{0x108E, 0xAAAA, 0xFFFF, 0xFFFF, "Multithreaded Shared 10GbE Ethernet Network Controller(0xAAAA)"},
{0x108E, 0xABBA, 0xFFFF, 0xFFFF, "Cassini 10/100/1000(0xABBA)"},
{0x108E, 0xABCD, 0xFFFF, 0xFFFF, "Multithreaded 10-Gigabit Ethernet Network Controller(0xABCD)"},
{0x108E, 0xC416, 0xFFFF, 0xFFFF, "Sun Fire System/System Controller Interface chip [sbbc](0xC416)"},
}; /* pci_vid_108E[] */

static pci_id_t const pci_vid_108F[] = {
{0x108F, 0xFFFF, 0xFFFF, 0xFFFF, "Systemsoft(0x108F)"},
}; /* pci_vid_108F[] */

static pci_id_t const pci_vid_1090[] = {
{0x1090, 0xFFFF, 0xFFFF, 0xFFFF, "Compro Computer Services, Inc.(0x1090)"},
{0x1090, 0x4610, 0xFFFF, 0xFFFF, "PCI RTOM(0x4610)"},
{0x1090, 0x4620, 0xFFFF, 0xFFFF, "GPIO HSD(0x4620)"},
}; /* pci_vid_1090[] */

static pci_id_t const pci_vid_1091[] = {
{0x1091, 0xFFFF, 0xFFFF, 0xFFFF, "Intergraph Corporation(0x1091)"},
{0x1091, 0x0020, 0xFFFF, 0xFFFF, "3D graphics processor(0x0020)"},
{0x1091, 0x0021, 0xFFFF, 0xFFFF, "3D graphics processor w/Texturing(0x0021)"},
{0x1091, 0x0040, 0xFFFF, 0xFFFF, "3D graphics frame buffer(0x0040)"},
{0x1091, 0x0041, 0xFFFF, 0xFFFF, "3D graphics frame buffer(0x0041)"},
{0x1091, 0x0060, 0xFFFF, 0xFFFF, "Proprietary bus bridge(0x0060)"},
{0x1091, 0x00E4, 0xFFFF, 0xFFFF, "Powerstorm 4D50T(0x00E4)"},
{0x1091, 0x0720, 0xFFFF, 0xFFFF, "Motion JPEG codec(0x0720)"},
{0x1091, 0x0780, 0xFFFF, 0xFFFF, "Intense3D Wildcat 3410 (MSMT496)(0x0780)"},
{0x1091, 0x07A0, 0xFFFF, 0xFFFF, "Sun Expert3D-Lite Graphics Accelerator(0x07A0)"},
{0x1091, 0x1091, 0xFFFF, 0xFFFF, "Sun Expert3D Graphics Accelerator(0x1091)"},
}; /* pci_vid_1091[] */

static pci_id_t const pci_vid_1092[] = {
{0x1092, 0xFFFF, 0xFFFF, 0xFFFF, "Diamond Multimedia Systems(0x1092)"},
{0x1092, 0x0028, 0xFFFF, 0xFFFF, "Viper V770(0x0028)"},
{0x1092, 0x0028, 0x1092, 0x4A00, "Viper V770 32MB(0x1092-0x4A00)"},
{0x1092, 0x00A0, 0xFFFF, 0xFFFF, "Speedstar Pro SE(0x00A0)"},
{0x1092, 0x00A8, 0xFFFF, 0xFFFF, "Speedstar 64(0x00A8)"},
{0x1092, 0x0550, 0xFFFF, 0xFFFF, "Viper V550(0x0550)"},
{0x1092, 0x08D4, 0xFFFF, 0xFFFF, "Supra 2260 Modem(0x08D4)"},
{0x1092, 0x094C, 0xFFFF, 0xFFFF, "SupraExpress 56i Pro(0x094C)"},
{0x1092, 0x1001, 0xFFFF, 0xFFFF, "Video Crunch It 1001 capture card(0x1001)"},
{0x1092, 0x1092, 0xFFFF, 0xFFFF, "Viper V330(0x1092)"},
{0x1092, 0x6120, 0xFFFF, 0xFFFF, "Maximum DVD(0x6120)"},
{0x1092, 0x8810, 0xFFFF, 0xFFFF, "Stealth SE(0x8810)"},
{0x1092, 0x8811, 0xFFFF, 0xFFFF, "Stealth 64/SE(0x8811)"},
{0x1092, 0x8880, 0xFFFF, 0xFFFF, "Stealth(0x8880)"},
{0x1092, 0x8881, 0xFFFF, 0xFFFF, "Stealth(0x8881)"},
{0x1092, 0x88B0, 0xFFFF, 0xFFFF, "Stealth 64(0x88B0)"},
{0x1092, 0x88B1, 0xFFFF, 0xFFFF, "Stealth 64(0x88B1)"},
{0x1092, 0x88C0, 0xFFFF, 0xFFFF, "Stealth 64(0x88C0)"},
{0x1092, 0x88C1, 0xFFFF, 0xFFFF, "Stealth 64(0x88C1)"},
{0x1092, 0x88D0, 0xFFFF, 0xFFFF, "Stealth 64(0x88D0)"},
{0x1092, 0x88D1, 0xFFFF, 0xFFFF, "Stealth 64(0x88D1)"},
{0x1092, 0x88F0, 0xFFFF, 0xFFFF, "Stealth 64(0x88F0)"},
{0x1092, 0x88F1, 0xFFFF, 0xFFFF, "Stealth 64(0x88F1)"},
{0x1092, 0x9999, 0xFFFF, 0xFFFF, "DMD-I0928-1 \"Monster sound\" sound chip(0x9999)"},
}; /* pci_vid_1092[] */

static pci_id_t const pci_vid_1093[] = {
{0x1093, 0xFFFF, 0xFFFF, 0xFFFF, "National Instruments(0x1093)"},
{0x1093, 0x0160, 0xFFFF, 0xFFFF, "PCI-DIO-96(0x0160)"},
{0x1093, 0x0162, 0xFFFF, 0xFFFF, "PCI-MIO-16XE-50(0x0162)"},
{0x1093, 0x0FE1, 0xFFFF, 0xFFFF, "PXI-8320(0x0FE1)"},
{0x1093, 0x1150, 0xFFFF, 0xFFFF, "PCI-6533 (PCI-DIO-32HS)(0x1150)"},
{0x1093, 0x1170, 0xFFFF, 0xFFFF, "PCI-MIO-16XE-10(0x1170)"},
{0x1093, 0x1180, 0xFFFF, 0xFFFF, "PCI-MIO-16E-1(0x1180)"},
{0x1093, 0x1190, 0xFFFF, 0xFFFF, "PCI-MIO-16E-4(0x1190)"},
{0x1093, 0x11B0, 0xFFFF, 0xFFFF, "PXI-6070E(0x11B0)"},
{0x1093, 0x11C0, 0xFFFF, 0xFFFF, "PXI-6040E(0x11C0)"},
{0x1093, 0x11D0, 0xFFFF, 0xFFFF, "PXI-6030E(0x11D0)"},
{0x1093, 0x1270, 0xFFFF, 0xFFFF, "PCI-6032E(0x1270)"},
{0x1093, 0x1290, 0xFFFF, 0xFFFF, "PCI-6704(0x1290)"},
{0x1093, 0x12B0, 0xFFFF, 0xFFFF, "PCI-6534(0x12B0)"},
{0x1093, 0x1310, 0xFFFF, 0xFFFF, "PCI-6602(0x1310)"},
{0x1093, 0x1320, 0xFFFF, 0xFFFF, "PXI-6533(0x1320)"},
{0x1093, 0x1330, 0xFFFF, 0xFFFF, "PCI-6031E(0x1330)"},
{0x1093, 0x1340, 0xFFFF, 0xFFFF, "PCI-6033E(0x1340)"},
{0x1093, 0x1350, 0xFFFF, 0xFFFF, "PCI-6071E(0x1350)"},
{0x1093, 0x1360, 0xFFFF, 0xFFFF, "PXI-6602(0x1360)"},
{0x1093, 0x13C0, 0xFFFF, 0xFFFF, "PXI-6508(0x13C0)"},
{0x1093, 0x1490, 0xFFFF, 0xFFFF, "PXI-6534(0x1490)"},
{0x1093, 0x14E0, 0xFFFF, 0xFFFF, "PCI-6110(0x14E0)"},
{0x1093, 0x14F0, 0xFFFF, 0xFFFF, "PCI-6111(0x14F0)"},
{0x1093, 0x1580, 0xFFFF, 0xFFFF, "PXI-6031E(0x1580)"},
{0x1093, 0x15B0, 0xFFFF, 0xFFFF, "PXI-6071E(0x15B0)"},
{0x1093, 0x1710, 0xFFFF, 0xFFFF, "PXI-6509(0x1710)"},
{0x1093, 0x17C0, 0xFFFF, 0xFFFF, "PXI-5690(0x17C0)"},
{0x1093, 0x17D0, 0xFFFF, 0xFFFF, "PCI-6503(0x17D0)"},
{0x1093, 0x1870, 0xFFFF, 0xFFFF, "PCI-6713(0x1870)"},
{0x1093, 0x1880, 0xFFFF, 0xFFFF, "PCI-6711(0x1880)"},
{0x1093, 0x18B0, 0xFFFF, 0xFFFF, "PCI-6052E(0x18B0)"},
{0x1093, 0x18C0, 0xFFFF, 0xFFFF, "PXI-6052E(0x18C0)"},
{0x1093, 0x1920, 0xFFFF, 0xFFFF, "PXI-6704(0x1920)"},
{0x1093, 0x1930, 0xFFFF, 0xFFFF, "PCI-6040E(0x1930)"},
{0x1093, 0x19C0, 0xFFFF, 0xFFFF, "PCI-4472(0x19C0)"},
{0x1093, 0x1AA0, 0xFFFF, 0xFFFF, "PXI-4110(0x1AA0)"},
{0x1093, 0x1AD0, 0xFFFF, 0xFFFF, "PCI-6133(0x1AD0)"},
{0x1093, 0x1AE0, 0xFFFF, 0xFFFF, "PXI-6133(0x1AE0)"},
{0x1093, 0x1E30, 0xFFFF, 0xFFFF, "PCI-6624(0x1E30)"},
{0x1093, 0x1E40, 0xFFFF, 0xFFFF, "PXI-6624(0x1E40)"},
{0x1093, 0x1E50, 0xFFFF, 0xFFFF, "PXI-5404(0x1E50)"},
{0x1093, 0x2410, 0xFFFF, 0xFFFF, "PCI-6733(0x2410)"},
{0x1093, 0x2420, 0xFFFF, 0xFFFF, "PXI-6733(0x2420)"},
{0x1093, 0x2430, 0xFFFF, 0xFFFF, "PCI-6731(0x2430)"},
{0x1093, 0x2470, 0xFFFF, 0xFFFF, "PCI-4474(0x2470)"},
{0x1093, 0x24A0, 0xFFFF, 0xFFFF, "PCI-4065(0x24A0)"},
{0x1093, 0x24B0, 0xFFFF, 0xFFFF, "PXI-4200(0x24B0)"},
{0x1093, 0x24F0, 0xFFFF, 0xFFFF, "PXI-4472(0x24F0)"},
{0x1093, 0x2510, 0xFFFF, 0xFFFF, "PCI-4472(0x2510)"},
{0x1093, 0x2520, 0xFFFF, 0xFFFF, "PCI-4474(0x2520)"},
{0x1093, 0x27A0, 0xFFFF, 0xFFFF, "PCI-6123(0x27A0)"},
{0x1093, 0x27B0, 0xFFFF, 0xFFFF, "PXI-6123(0x27B0)"},
{0x1093, 0x2880, 0xFFFF, 0xFFFF, "DAQCard-6601(0x2880)"},
{0x1093, 0x2890, 0xFFFF, 0xFFFF, "PCI-6036E(0x2890)"},
{0x1093, 0x28A0, 0xFFFF, 0xFFFF, "PXI-4461(0x28A0)"},
{0x1093, 0x28B0, 0xFFFF, 0xFFFF, "PCI-6013(0x28B0)"},
{0x1093, 0x28C0, 0xFFFF, 0xFFFF, "PCI-6014(0x28C0)"},
{0x1093, 0x28D0, 0xFFFF, 0xFFFF, "PCI-5122(0x28D0)"},
{0x1093, 0x28E0, 0xFFFF, 0xFFFF, "PXI-5122(0x28E0)"},
{0x1093, 0x29F0, 0xFFFF, 0xFFFF, "PXI-7334(0x29F0)"},
{0x1093, 0x2A00, 0xFFFF, 0xFFFF, "PXI-7344(0x2A00)"},
{0x1093, 0x2A60, 0xFFFF, 0xFFFF, "PCI-6023E(0x2A60)"},
{0x1093, 0x2A70, 0xFFFF, 0xFFFF, "PCI-6024E(0x2A70)"},
{0x1093, 0x2A80, 0xFFFF, 0xFFFF, "PCI-6025E(0x2A80)"},
{0x1093, 0x2AB0, 0xFFFF, 0xFFFF, "PXI-6025E(0x2AB0)"},
{0x1093, 0x2B10, 0xFFFF, 0xFFFF, "PXI-6527(0x2B10)"},
{0x1093, 0x2B20, 0xFFFF, 0xFFFF, "PCI-6527(0x2B20)"},
{0x1093, 0x2B80, 0xFFFF, 0xFFFF, "PXI-6713(0x2B80)"},
{0x1093, 0x2B90, 0xFFFF, 0xFFFF, "PXI-6711(0x2B90)"},
{0x1093, 0x2C60, 0xFFFF, 0xFFFF, "PCI-6601(0x2C60)"},
{0x1093, 0x2C70, 0xFFFF, 0xFFFF, "PXI-6601(0x2C70)"},
{0x1093, 0x2C80, 0xFFFF, 0xFFFF, "PCI-6035E(0x2C80)"},
{0x1093, 0x2C90, 0xFFFF, 0xFFFF, "PCI-6703(0x2C90)"},
{0x1093, 0x2CA0, 0xFFFF, 0xFFFF, "PCI-6034E(0x2CA0)"},
{0x1093, 0x2CB0, 0xFFFF, 0xFFFF, "PCI-7344(0x2CB0)"},
{0x1093, 0x2CC0, 0xFFFF, 0xFFFF, "PXI-6608(0x2CC0)"},
{0x1093, 0x2D20, 0xFFFF, 0xFFFF, "PXI-5600(0x2D20)"},
{0x1093, 0x2DB0, 0xFFFF, 0xFFFF, "PCI-6608(0x2DB0)"},
{0x1093, 0x2DC0, 0xFFFF, 0xFFFF, "PCI-4070(0x2DC0)"},
{0x1093, 0x2DD0, 0xFFFF, 0xFFFF, "PXI-4070(0x2DD0)"},
{0x1093, 0x2EB0, 0xFFFF, 0xFFFF, "PXI-4472(0x2EB0)"},
{0x1093, 0x2EC0, 0xFFFF, 0xFFFF, "PXI-6115(0x2EC0)"},
{0x1093, 0x2ED0, 0xFFFF, 0xFFFF, "PCI-6115(0x2ED0)"},
{0x1093, 0x2EE0, 0xFFFF, 0xFFFF, "PXI-6120(0x2EE0)"},
{0x1093, 0x2EF0, 0xFFFF, 0xFFFF, "PCI-6120(0x2EF0)"},
{0x1093, 0x2FD1, 0xFFFF, 0xFFFF, "PCI-7334(0x2FD1)"},
{0x1093, 0x2FD2, 0xFFFF, 0xFFFF, "PCI-7350(0x2FD2)"},
{0x1093, 0x2FD3, 0xFFFF, 0xFFFF, "PCI-7342(0x2FD3)"},
{0x1093, 0x2FD5, 0xFFFF, 0xFFFF, "PXI-7350(0x2FD5)"},
{0x1093, 0x2FD6, 0xFFFF, 0xFFFF, "PXI-7342(0x2FD6)"},
{0x1093, 0x7003, 0xFFFF, 0xFFFF, "PCI-6551(0x7003)"},
{0x1093, 0x7004, 0xFFFF, 0xFFFF, "PXI-6551(0x7004)"},
{0x1093, 0x700B, 0xFFFF, 0xFFFF, "PXI-5421(0x700B)"},
{0x1093, 0x700C, 0xFFFF, 0xFFFF, "PCI-5421(0x700C)"},
{0x1093, 0x701A, 0xFFFF, 0xFFFF, "VXIpc-87xB(0x701A)"},
{0x1093, 0x701B, 0xFFFF, 0xFFFF, "VXIpc-770(0x701B)"},
{0x1093, 0x7023, 0xFFFF, 0xFFFF, "PXI-2593(0x7023)"},
{0x1093, 0x7027, 0xFFFF, 0xFFFF, "PCI-MXI-2 Universal(0x7027)"},
{0x1093, 0x702C, 0xFFFF, 0xFFFF, "PXI-7831R(0x702C)"},
{0x1093, 0x702D, 0xFFFF, 0xFFFF, "PCI-7831R(0x702D)"},
{0x1093, 0x702E, 0xFFFF, 0xFFFF, "PXI-7811R(0x702E)"},
{0x1093, 0x702F, 0xFFFF, 0xFFFF, "PCI-7811R(0x702F)"},
{0x1093, 0x7030, 0xFFFF, 0xFFFF, "PCI-CAN (Series 2)(0x7030)"},
{0x1093, 0x7031, 0xFFFF, 0xFFFF, "PCI-CAN/2 (Series 2)(0x7031)"},
{0x1093, 0x7032, 0xFFFF, 0xFFFF, "PCI-CAN/LS (Series 2)(0x7032)"},
{0x1093, 0x7033, 0xFFFF, 0xFFFF, "PCI-CAN/LS2 (Series 2)(0x7033)"},
{0x1093, 0x7034, 0xFFFF, 0xFFFF, "PCI-CAN/DS (Series 2)(0x7034)"},
{0x1093, 0x7035, 0xFFFF, 0xFFFF, "PXI-8460 (Series 2, 1 port)(0x7035)"},
{0x1093, 0x7036, 0xFFFF, 0xFFFF, "PXI-8460 (Series 2, 2 ports)(0x7036)"},
{0x1093, 0x7037, 0xFFFF, 0xFFFF, "PXI-8461 (Series 2, 1 port)(0x7037)"},
{0x1093, 0x7038, 0xFFFF, 0xFFFF, "PXI-8461 (Series 2, 2 ports)(0x7038)"},
{0x1093, 0x7039, 0xFFFF, 0xFFFF, "PXI-8462 (Series 2)(0x7039)"},
{0x1093, 0x703F, 0xFFFF, 0xFFFF, "PXI-2566(0x703F)"},
{0x1093, 0x7040, 0xFFFF, 0xFFFF, "PXI-2567(0x7040)"},
{0x1093, 0x7044, 0xFFFF, 0xFFFF, "MXI-4 Connection Monitor(0x7044)"},
{0x1093, 0x7047, 0xFFFF, 0xFFFF, "PXI-6653(0x7047)"},
{0x1093, 0x704C, 0xFFFF, 0xFFFF, "PXI-2530(0x704C)"},
{0x1093, 0x704F, 0xFFFF, 0xFFFF, "PXI-4220(0x704F)"},
{0x1093, 0x7050, 0xFFFF, 0xFFFF, "PXI-4204(0x7050)"},
{0x1093, 0x7055, 0xFFFF, 0xFFFF, "PXI-7830R(0x7055)"},
{0x1093, 0x7056, 0xFFFF, 0xFFFF, "PCI-7830R(0x7056)"},
{0x1093, 0x705A, 0xFFFF, 0xFFFF, "PCI-CAN/XS (Series 2)(0x705A)"},
{0x1093, 0x705B, 0xFFFF, 0xFFFF, "PCI-CAN/XS2 (Series 2)(0x705B)"},
{0x1093, 0x705C, 0xFFFF, 0xFFFF, "PXI-8464 (Series 2, 1 port)(0x705C)"},
{0x1093, 0x705D, 0xFFFF, 0xFFFF, "PXI-8464 (Series 2, 2 ports)(0x705D)"},
{0x1093, 0x705E, 0xFFFF, 0xFFFF, "cRIO-9102(0x705E)"},
{0x1093, 0x7060, 0xFFFF, 0xFFFF, "PXI-5610(0x7060)"},
{0x1093, 0x7064, 0xFFFF, 0xFFFF, "PXI-1045 Trigger Routing Module(0x7064)"},
{0x1093, 0x7065, 0xFFFF, 0xFFFF, "PXI-6652(0x7065)"},
{0x1093, 0x7066, 0xFFFF, 0xFFFF, "PXI-6651(0x7066)"},
{0x1093, 0x7067, 0xFFFF, 0xFFFF, "PXI-2529(0x7067)"},
{0x1093, 0x7068, 0xFFFF, 0xFFFF, "PCI-CAN/SW (Series 2)(0x7068)"},
{0x1093, 0x7069, 0xFFFF, 0xFFFF, "PCI-CAN/SW2 (Series 2)(0x7069)"},
{0x1093, 0x706A, 0xFFFF, 0xFFFF, "PXI-8463 (Series 2, 1 port)(0x706A)"},
{0x1093, 0x706B, 0xFFFF, 0xFFFF, "PXI-8463 (Series 2, 2 ports)(0x706B)"},
{0x1093, 0x7073, 0xFFFF, 0xFFFF, "PCI-6723(0x7073)"},
{0x1093, 0x7074, 0xFFFF, 0xFFFF, "PXI-7833R(0x7074)"},
{0x1093, 0x7075, 0xFFFF, 0xFFFF, "PXI-6552(0x7075)"},
{0x1093, 0x7076, 0xFFFF, 0xFFFF, "PCI-6552(0x7076)"},
{0x1093, 0x707C, 0xFFFF, 0xFFFF, "PXI-1428(0x707C)"},
{0x1093, 0x707E, 0xFFFF, 0xFFFF, "PXI-4462(0x707E)"},
{0x1093, 0x7080, 0xFFFF, 0xFFFF, "PXI-8430/2 (RS-232) Interface(0x7080)"},
{0x1093, 0x7081, 0xFFFF, 0xFFFF, "PXI-8431/2 (RS-485) Interface(0x7081)"},
{0x1093, 0x7083, 0xFFFF, 0xFFFF, "PCI-7833R(0x7083)"},
{0x1093, 0x7085, 0xFFFF, 0xFFFF, "PCI-6509(0x7085)"},
{0x1093, 0x7086, 0xFFFF, 0xFFFF, "PXI-6528(0x7086)"},
{0x1093, 0x7087, 0xFFFF, 0xFFFF, "PCI-6515(0x7087)"},
{0x1093, 0x7088, 0xFFFF, 0xFFFF, "PCI-6514(0x7088)"},
{0x1093, 0x708C, 0xFFFF, 0xFFFF, "PXI-2568(0x708C)"},
{0x1093, 0x708D, 0xFFFF, 0xFFFF, "PXI-2569(0x708D)"},
{0x1093, 0x70A9, 0xFFFF, 0xFFFF, "PCI-6528(0x70A9)"},
{0x1093, 0x70AA, 0xFFFF, 0xFFFF, "PCI-6229(0x70AA)"},
{0x1093, 0x70AB, 0xFFFF, 0xFFFF, "PCI-6259(0x70AB)"},
{0x1093, 0x70AC, 0xFFFF, 0xFFFF, "PCI-6289(0x70AC)"},
{0x1093, 0x70AD, 0xFFFF, 0xFFFF, "PXI-6251(0x70AD)"},
{0x1093, 0x70AE, 0xFFFF, 0xFFFF, "PXI-6220(0x70AE)"},
{0x1093, 0x70AF, 0xFFFF, 0xFFFF, "PCI-6221(0x70AF)"},
{0x1093, 0x70B0, 0xFFFF, 0xFFFF, "PCI-6220(0x70B0)"},
{0x1093, 0x70B1, 0xFFFF, 0xFFFF, "PXI-6229(0x70B1)"},
{0x1093, 0x70B2, 0xFFFF, 0xFFFF, "PXI-6259(0x70B2)"},
{0x1093, 0x70B3, 0xFFFF, 0xFFFF, "PXI-6289(0x70B3)"},
{0x1093, 0x70B4, 0xFFFF, 0xFFFF, "PCI-6250(0x70B4)"},
{0x1093, 0x70B5, 0xFFFF, 0xFFFF, "PXI-6221(0x70B5)"},
{0x1093, 0x70B6, 0xFFFF, 0xFFFF, "PCI-6280(0x70B6)"},
{0x1093, 0x70B7, 0xFFFF, 0xFFFF, "PCI-6254(0x70B7)"},
{0x1093, 0x70B8, 0xFFFF, 0xFFFF, "PCI-6251(0x70B8)"},
{0x1093, 0x70B9, 0xFFFF, 0xFFFF, "PXI-6250(0x70B9)"},
{0x1093, 0x70BA, 0xFFFF, 0xFFFF, "PXI-6254(0x70BA)"},
{0x1093, 0x70BB, 0xFFFF, 0xFFFF, "PXI-6280(0x70BB)"},
{0x1093, 0x70BC, 0xFFFF, 0xFFFF, "PCI-6284(0x70BC)"},
{0x1093, 0x70BD, 0xFFFF, 0xFFFF, "PCI-6281(0x70BD)"},
{0x1093, 0x70BE, 0xFFFF, 0xFFFF, "PXI-6284(0x70BE)"},
{0x1093, 0x70BF, 0xFFFF, 0xFFFF, "PXI-6281(0x70BF)"},
{0x1093, 0x70C0, 0xFFFF, 0xFFFF, "PCI-6143(0x70C0)"},
{0x1093, 0x70C3, 0xFFFF, 0xFFFF, "PCI-6511(0x70C3)"},
{0x1093, 0x70C4, 0xFFFF, 0xFFFF, "PXI-7330(0x70C4)"},
{0x1093, 0x70C5, 0xFFFF, 0xFFFF, "PXI-7340(0x70C5)"},
{0x1093, 0x70C6, 0xFFFF, 0xFFFF, "PCI-7330(0x70C6)"},
{0x1093, 0x70C7, 0xFFFF, 0xFFFF, "PCI-7340(0x70C7)"},
{0x1093, 0x70C8, 0xFFFF, 0xFFFF, "PCI-6513(0x70C8)"},
{0x1093, 0x70C9, 0xFFFF, 0xFFFF, "PXI-6515(0x70C9)"},
{0x1093, 0x70CA, 0xFFFF, 0xFFFF, "PCI-1405(0x70CA)"},
{0x1093, 0x70CC, 0xFFFF, 0xFFFF, "PCI-6512(0x70CC)"},
{0x1093, 0x70CD, 0xFFFF, 0xFFFF, "PXI-6514(0x70CD)"},
{0x1093, 0x70CE, 0xFFFF, 0xFFFF, "PXI-1405(0x70CE)"},
{0x1093, 0x70CF, 0xFFFF, 0xFFFF, "PCIe-GPIB(0x70CF)"},
{0x1093, 0x70D0, 0xFFFF, 0xFFFF, "PXI-2570(0x70D0)"},
{0x1093, 0x70D1, 0xFFFF, 0xFFFF, "PXI-6513(0x70D1)"},
{0x1093, 0x70D2, 0xFFFF, 0xFFFF, "PXI-6512(0x70D2)"},
{0x1093, 0x70D3, 0xFFFF, 0xFFFF, "PXI-6511(0x70D3)"},
{0x1093, 0x70D4, 0xFFFF, 0xFFFF, "PCI-6722(0x70D4)"},
{0x1093, 0x70D6, 0xFFFF, 0xFFFF, "PXI-4072(0x70D6)"},
{0x1093, 0x70D7, 0xFFFF, 0xFFFF, "PXI-6541(0x70D7)"},
{0x1093, 0x70D8, 0xFFFF, 0xFFFF, "PXI-6542(0x70D8)"},
{0x1093, 0x70D9, 0xFFFF, 0xFFFF, "PCI-6541(0x70D9)"},
{0x1093, 0x70DA, 0xFFFF, 0xFFFF, "PCI-6542(0x70DA)"},
{0x1093, 0x70DB, 0xFFFF, 0xFFFF, "PCI-8430/2 (RS-232) Interface(0x70DB)"},
{0x1093, 0x70DC, 0xFFFF, 0xFFFF, "PCI-8431/2 (RS-485) Interface(0x70DC)"},
{0x1093, 0x70DD, 0xFFFF, 0xFFFF, "PXI-8430/4 (RS-232) Interface(0x70DD)"},
{0x1093, 0x70DE, 0xFFFF, 0xFFFF, "PXI-8431/4 (RS-485) Interface(0x70DE)"},
{0x1093, 0x70DF, 0xFFFF, 0xFFFF, "PCI-8430/4 (RS-232) Interface(0x70DF)"},
{0x1093, 0x70E0, 0xFFFF, 0xFFFF, "PCI-8431/4 (RS-485) Interface(0x70E0)"},
{0x1093, 0x70E1, 0xFFFF, 0xFFFF, "PXI-2532(0x70E1)"},
{0x1093, 0x70E2, 0xFFFF, 0xFFFF, "PXI-8430/8 (RS-232) Interface(0x70E2)"},
{0x1093, 0x70E3, 0xFFFF, 0xFFFF, "PXI-8431/8 (RS-485) Interface(0x70E3)"},
{0x1093, 0x70E4, 0xFFFF, 0xFFFF, "PCI-8430/8 (RS-232) Interface(0x70E4)"},
{0x1093, 0x70E5, 0xFFFF, 0xFFFF, "PCI-8431/8 (RS-485) Interface(0x70E5)"},
{0x1093, 0x70E6, 0xFFFF, 0xFFFF, "PXI-8430/16 (RS-232) Interface(0x70E6)"},
{0x1093, 0x70E7, 0xFFFF, 0xFFFF, "PCI-8430/16 (RS-232) Interface(0x70E7)"},
{0x1093, 0x70E8, 0xFFFF, 0xFFFF, "PXI-8432/2 (Isolated RS-232) Interface(0x70E8)"},
{0x1093, 0x70E9, 0xFFFF, 0xFFFF, "PXI-8433/2 (Isolated RS-485) Interface(0x70E9)"},
{0x1093, 0x70EA, 0xFFFF, 0xFFFF, "PCI-8432/2 (Isolated RS-232) Interface(0x70EA)"},
{0x1093, 0x70EB, 0xFFFF, 0xFFFF, "PCI-8433/2 (Isolated RS-485) Interface(0x70EB)"},
{0x1093, 0x70EC, 0xFFFF, 0xFFFF, "PXI-8432/4 (Isolated RS-232) Interface(0x70EC)"},
{0x1093, 0x70ED, 0xFFFF, 0xFFFF, "PXI-8433/4 (Isolated RS-485) Interface(0x70ED)"},
{0x1093, 0x70EE, 0xFFFF, 0xFFFF, "PCI-8432/4 (Isolated RS-232) Interface(0x70EE)"},
{0x1093, 0x70EF, 0xFFFF, 0xFFFF, "PCI-8433/4 (Isolated RS-485) Interface(0x70EF)"},
{0x1093, 0x70F0, 0xFFFF, 0xFFFF, "PXI-5922(0x70F0)"},
{0x1093, 0x70F1, 0xFFFF, 0xFFFF, "PCI-5922(0x70F1)"},
{0x1093, 0x70F2, 0xFFFF, 0xFFFF, "PCI-6224(0x70F2)"},
{0x1093, 0x70F3, 0xFFFF, 0xFFFF, "PXI-6224(0x70F3)"},
{0x1093, 0x70F6, 0xFFFF, 0xFFFF, "cRIO-9101(0x70F6)"},
{0x1093, 0x70F7, 0xFFFF, 0xFFFF, "cRIO-9103(0x70F7)"},
{0x1093, 0x70F8, 0xFFFF, 0xFFFF, "cRIO-9104(0x70F8)"},
{0x1093, 0x70FF, 0xFFFF, 0xFFFF, "PXI-6723(0x70FF)"},
{0x1093, 0x7100, 0xFFFF, 0xFFFF, "PXI-6722(0x7100)"},
{0x1093, 0x7104, 0xFFFF, 0xFFFF, "PCIx-1429(0x7104)"},
{0x1093, 0x7105, 0xFFFF, 0xFFFF, "PCIe-1429(0x7105)"},
{0x1093, 0x710A, 0xFFFF, 0xFFFF, "PXI-4071(0x710A)"},
{0x1093, 0x710D, 0xFFFF, 0xFFFF, "PXI-6143(0x710D)"},
{0x1093, 0x710E, 0xFFFF, 0xFFFF, "PCIe-GPIB(0x710E)"},
{0x1093, 0x710F, 0xFFFF, 0xFFFF, "PXI-5422(0x710F)"},
{0x1093, 0x7110, 0xFFFF, 0xFFFF, "PCI-5422(0x7110)"},
{0x1093, 0x7111, 0xFFFF, 0xFFFF, "PXI-5441(0x7111)"},
{0x1093, 0x7119, 0xFFFF, 0xFFFF, "PXI-6561(0x7119)"},
{0x1093, 0x711A, 0xFFFF, 0xFFFF, "PXI-6562(0x711A)"},
{0x1093, 0x711B, 0xFFFF, 0xFFFF, "PCI-6561(0x711B)"},
{0x1093, 0x711C, 0xFFFF, 0xFFFF, "PCI-6562(0x711C)"},
{0x1093, 0x7120, 0xFFFF, 0xFFFF, "PCI-7390(0x7120)"},
{0x1093, 0x7121, 0xFFFF, 0xFFFF, "PXI-5122EX(0x7121)"},
{0x1093, 0x7122, 0xFFFF, 0xFFFF, "PCI-5122EX(0x7122)"},
{0x1093, 0x7123, 0xFFFF, 0xFFFF, "PXIe-5653(0x7123)"},
{0x1093, 0x7124, 0xFFFF, 0xFFFF, "PCI-6510(0x7124)"},
{0x1093, 0x7125, 0xFFFF, 0xFFFF, "PCI-6516(0x7125)"},
{0x1093, 0x7126, 0xFFFF, 0xFFFF, "PCI-6517(0x7126)"},
{0x1093, 0x7127, 0xFFFF, 0xFFFF, "PCI-6518(0x7127)"},
{0x1093, 0x7128, 0xFFFF, 0xFFFF, "PCI-6519(0x7128)"},
{0x1093, 0x7137, 0xFFFF, 0xFFFF, "PXI-2575(0x7137)"},
{0x1093, 0x713C, 0xFFFF, 0xFFFF, "PXI-2585(0x713C)"},
{0x1093, 0x713D, 0xFFFF, 0xFFFF, "PXI-2586(0x713D)"},
{0x1093, 0x7142, 0xFFFF, 0xFFFF, "PXI-4224(0x7142)"},
{0x1093, 0x7144, 0xFFFF, 0xFFFF, "PXI-5124(0x7144)"},
{0x1093, 0x7145, 0xFFFF, 0xFFFF, "PCI-5124(0x7145)"},
{0x1093, 0x7146, 0xFFFF, 0xFFFF, "PCI-6132(0x7146)"},
{0x1093, 0x7147, 0xFFFF, 0xFFFF, "PXI-6132(0x7147)"},
{0x1093, 0x7148, 0xFFFF, 0xFFFF, "PCI-6122(0x7148)"},
{0x1093, 0x7149, 0xFFFF, 0xFFFF, "PXI-6122(0x7149)"},
{0x1093, 0x714C, 0xFFFF, 0xFFFF, "PXI-5114(0x714C)"},
{0x1093, 0x714D, 0xFFFF, 0xFFFF, "PCI-5114(0x714D)"},
{0x1093, 0x7150, 0xFFFF, 0xFFFF, "PXI-2564(0x7150)"},
{0x1093, 0x7152, 0xFFFF, 0xFFFF, "PCI-5640R(0x7152)"},
{0x1093, 0x7156, 0xFFFF, 0xFFFF, "PXI-1044 Trigger Routing Module(0x7156)"},
{0x1093, 0x715D, 0xFFFF, 0xFFFF, "PCI-1426(0x715D)"},
{0x1093, 0x7167, 0xFFFF, 0xFFFF, "PXI-5412(0x7167)"},
{0x1093, 0x7168, 0xFFFF, 0xFFFF, "PCI-5412(0x7168)"},
{0x1093, 0x716B, 0xFFFF, 0xFFFF, "PCI-6230(0x716B)"},
{0x1093, 0x716C, 0xFFFF, 0xFFFF, "PCI-6225(0x716C)"},
{0x1093, 0x716D, 0xFFFF, 0xFFFF, "PXI-6225(0x716D)"},
{0x1093, 0x716F, 0xFFFF, 0xFFFF, "PCI-4461(0x716F)"},
{0x1093, 0x7170, 0xFFFF, 0xFFFF, "PCI-4462(0x7170)"},
{0x1093, 0x7171, 0xFFFF, 0xFFFF, "PCI-6010(0x7171)"},
{0x1093, 0x7174, 0xFFFF, 0xFFFF, "PXI-8360(0x7174)"},
{0x1093, 0x7177, 0xFFFF, 0xFFFF, "PXI-6230(0x7177)"},
{0x1093, 0x717D, 0xFFFF, 0xFFFF, "PCIe-6251(0x717D)"},
{0x1093, 0x717F, 0xFFFF, 0xFFFF, "PCIe-6259(0x717F)"},
{0x1093, 0x7187, 0xFFFF, 0xFFFF, "PCI-1410(0x7187)"},
{0x1093, 0x718B, 0xFFFF, 0xFFFF, "PCI-6521(0x718B)"},
{0x1093, 0x718C, 0xFFFF, 0xFFFF, "PXI-6521(0x718C)"},
{0x1093, 0x7191, 0xFFFF, 0xFFFF, "PCI-6154(0x7191)"},
{0x1093, 0x7193, 0xFFFF, 0xFFFF, "PXI-7813R(0x7193)"},
{0x1093, 0x7194, 0xFFFF, 0xFFFF, "PCI-7813R(0x7194)"},
{0x1093, 0x7195, 0xFFFF, 0xFFFF, "PCI-8254R(0x7195)"},
{0x1093, 0x7197, 0xFFFF, 0xFFFF, "PXI-5402(0x7197)"},
{0x1093, 0x7198, 0xFFFF, 0xFFFF, "PCI-5402(0x7198)"},
{0x1093, 0x719F, 0xFFFF, 0xFFFF, "PCIe-6535(0x719F)"},
{0x1093, 0x71A0, 0xFFFF, 0xFFFF, "PCIe-6536(0x71A0)"},
{0x1093, 0x71A3, 0xFFFF, 0xFFFF, "PXI-5650(0x71A3)"},
{0x1093, 0x71A4, 0xFFFF, 0xFFFF, "PXI-5652(0x71A4)"},
{0x1093, 0x71A5, 0xFFFF, 0xFFFF, "PXI-2594(0x71A5)"},
{0x1093, 0x71A7, 0xFFFF, 0xFFFF, "PXI-2595(0x71A7)"},
{0x1093, 0x71A9, 0xFFFF, 0xFFFF, "PXI-2596(0x71A9)"},
{0x1093, 0x71AA, 0xFFFF, 0xFFFF, "PXI-2597(0x71AA)"},
{0x1093, 0x71AB, 0xFFFF, 0xFFFF, "PXI-2598(0x71AB)"},
{0x1093, 0x71AC, 0xFFFF, 0xFFFF, "PXI-2599(0x71AC)"},
{0x1093, 0x71AD, 0xFFFF, 0xFFFF, "PCI-GPIB+(0x71AD)"},
{0x1093, 0x71AE, 0xFFFF, 0xFFFF, "PCIe-1430(0x71AE)"},
{0x1093, 0x71B7, 0xFFFF, 0xFFFF, "PXI-1056 Trigger Routing Module(0x71B7)"},
{0x1093, 0x71B8, 0xFFFF, 0xFFFF, "PXI-1045 Trigger Routing Module(0x71B8)"},
{0x1093, 0x71B9, 0xFFFF, 0xFFFF, "PXI-1044 Trigger Routing Module(0x71B9)"},
{0x1093, 0x71BB, 0xFFFF, 0xFFFF, "PXI-2584(0x71BB)"},
{0x1093, 0x71BC, 0xFFFF, 0xFFFF, "PCI-6221 (37-pin)(0x71BC)"},
{0x1093, 0x71BF, 0xFFFF, 0xFFFF, "PCIe-1427(0x71BF)"},
{0x1093, 0x71C5, 0xFFFF, 0xFFFF, "PCI-6520(0x71C5)"},
{0x1093, 0x71C6, 0xFFFF, 0xFFFF, "PXI-2576(0x71C6)"},
{0x1093, 0x71C7, 0xFFFF, 0xFFFF, "cRIO-9072(0x71C7)"},
{0x1093, 0x71DC, 0xFFFF, 0xFFFF, "PCI-1588(0x71DC)"},
{0x1093, 0x71E0, 0xFFFF, 0xFFFF, "PCI-6255(0x71E0)"},
{0x1093, 0x71E1, 0xFFFF, 0xFFFF, "PXI-6255(0x71E1)"},
{0x1093, 0x71E2, 0xFFFF, 0xFFFF, "PXI-5406(0x71E2)"},
{0x1093, 0x71E3, 0xFFFF, 0xFFFF, "PCI-5406(0x71E3)"},
{0x1093, 0x71FC, 0xFFFF, 0xFFFF, "PXI-4022(0x71FC)"},
{0x1093, 0x7209, 0xFFFF, 0xFFFF, "PCI-6233(0x7209)"},
{0x1093, 0x720A, 0xFFFF, 0xFFFF, "PXI-6233(0x720A)"},
{0x1093, 0x720B, 0xFFFF, 0xFFFF, "PCI-6238(0x720B)"},
{0x1093, 0x720C, 0xFFFF, 0xFFFF, "PXI-6238(0x720C)"},
{0x1093, 0x7260, 0xFFFF, 0xFFFF, "PXI-5142(0x7260)"},
{0x1093, 0x7261, 0xFFFF, 0xFFFF, "PCI-5142(0x7261)"},
{0x1093, 0x726D, 0xFFFF, 0xFFFF, "PXI-5651(0x726D)"},
{0x1093, 0x7273, 0xFFFF, 0xFFFF, "PXI-4461(0x7273)"},
{0x1093, 0x7274, 0xFFFF, 0xFFFF, "PXI-4462(0x7274)"},
{0x1093, 0x7279, 0xFFFF, 0xFFFF, "PCI-6232(0x7279)"},
{0x1093, 0x727A, 0xFFFF, 0xFFFF, "PXI-6232(0x727A)"},
{0x1093, 0x727B, 0xFFFF, 0xFFFF, "PCI-6239(0x727B)"},
{0x1093, 0x727C, 0xFFFF, 0xFFFF, "PXI-6239(0x727C)"},
{0x1093, 0x727E, 0xFFFF, 0xFFFF, "SMBus Controller(0x727E)"},
{0x1093, 0x727E, 0x1093, 0x75AC, "PXIe-8388(0x1093-0x75AC)"},
{0x1093, 0x727E, 0x1093, 0x75AD, "PXIe-8389(0x1093-0x75AD)"},
{0x1093, 0x727E, 0x1093, 0x7650, "PXIe-8381(0x1093-0x7650)"},
{0x1093, 0x727E, 0x1093, 0x8360, "PXIe-8360(0x1093-0x8360)"},
{0x1093, 0x727E, 0x1093, 0x8370, "PXIe-8370(0x1093-0x8370)"},
{0x1093, 0x727E, 0x1093, 0x8375, "PXIe-8375(0x1093-0x8375)"},
{0x1093, 0x7281, 0xFFFF, 0xFFFF, "PCI-6236(0x7281)"},
{0x1093, 0x7282, 0xFFFF, 0xFFFF, "PXI-6236(0x7282)"},
{0x1093, 0x7283, 0xFFFF, 0xFFFF, "PXI-2554(0x7283)"},
{0x1093, 0x7288, 0xFFFF, 0xFFFF, "PXIe-5611(0x7288)"},
{0x1093, 0x7293, 0xFFFF, 0xFFFF, "PCIe-8255R(0x7293)"},
{0x1093, 0x729D, 0xFFFF, 0xFFFF, "cRIO-9074(0x729D)"},
{0x1093, 0x72A4, 0xFFFF, 0xFFFF, "PCIe-4065(0x72A4)"},
{0x1093, 0x72A7, 0xFFFF, 0xFFFF, "PCIe-6537(0x72A7)"},
{0x1093, 0x72A8, 0xFFFF, 0xFFFF, "PXI-5152(0x72A8)"},
{0x1093, 0x72A9, 0xFFFF, 0xFFFF, "PCI-5152(0x72A9)"},
{0x1093, 0x72AA, 0xFFFF, 0xFFFF, "PXI-5105(0x72AA)"},
{0x1093, 0x72AB, 0xFFFF, 0xFFFF, "PCI-5105(0x72AB)"},
{0x1093, 0x72B8, 0xFFFF, 0xFFFF, "PXI-6682(0x72B8)"},
{0x1093, 0x72D0, 0xFFFF, 0xFFFF, "PXI-2545(0x72D0)"},
{0x1093, 0x72D1, 0xFFFF, 0xFFFF, "PXI-2546(0x72D1)"},
{0x1093, 0x72D2, 0xFFFF, 0xFFFF, "PXI-2547(0x72D2)"},
{0x1093, 0x72D3, 0xFFFF, 0xFFFF, "PXI-2548(0x72D3)"},
{0x1093, 0x72D4, 0xFFFF, 0xFFFF, "PXI-2549(0x72D4)"},
{0x1093, 0x72D5, 0xFFFF, 0xFFFF, "PXI-2555(0x72D5)"},
{0x1093, 0x72D6, 0xFFFF, 0xFFFF, "PXI-2556(0x72D6)"},
{0x1093, 0x72D7, 0xFFFF, 0xFFFF, "PXI-2557(0x72D7)"},
{0x1093, 0x72D8, 0xFFFF, 0xFFFF, "PXI-2558(0x72D8)"},
{0x1093, 0x72D9, 0xFFFF, 0xFFFF, "PXI-2559(0x72D9)"},
{0x1093, 0x72E8, 0xFFFF, 0xFFFF, "PXIe-6251(0x72E8)"},
{0x1093, 0x72E9, 0xFFFF, 0xFFFF, "PXIe-6259(0x72E9)"},
{0x1093, 0x72EF, 0xFFFF, 0xFFFF, "PXI-4498(0x72EF)"},
{0x1093, 0x72F0, 0xFFFF, 0xFFFF, "PXI-4496(0x72F0)"},
{0x1093, 0x72FB, 0xFFFF, 0xFFFF, "PXIe-6672(0x72FB)"},
{0x1093, 0x730E, 0xFFFF, 0xFFFF, "PXI-4130(0x730E)"},
{0x1093, 0x730F, 0xFFFF, 0xFFFF, "PXI-5922EX(0x730F)"},
{0x1093, 0x7310, 0xFFFF, 0xFFFF, "PCI-5922EX(0x7310)"},
{0x1093, 0x731C, 0xFFFF, 0xFFFF, "PXI-2535(0x731C)"},
{0x1093, 0x731D, 0xFFFF, 0xFFFF, "PXI-2536(0x731D)"},
{0x1093, 0x7322, 0xFFFF, 0xFFFF, "PXIe-6124(0x7322)"},
{0x1093, 0x7327, 0xFFFF, 0xFFFF, "PXI-6529(0x7327)"},
{0x1093, 0x732C, 0xFFFF, 0xFFFF, "VXI-8360T(0x732C)"},
{0x1093, 0x7331, 0xFFFF, 0xFFFF, "PXIe-5602(0x7331)"},
{0x1093, 0x7332, 0xFFFF, 0xFFFF, "PXIe-5601(0x7332)"},
{0x1093, 0x7333, 0xFFFF, 0xFFFF, "PXI-5900(0x7333)"},
{0x1093, 0x7335, 0xFFFF, 0xFFFF, "PXI-2533(0x7335)"},
{0x1093, 0x7336, 0xFFFF, 0xFFFF, "PXI-2534(0x7336)"},
{0x1093, 0x7342, 0xFFFF, 0xFFFF, "PXI-4461(0x7342)"},
{0x1093, 0x7349, 0xFFFF, 0xFFFF, "PXI-5154(0x7349)"},
{0x1093, 0x734A, 0xFFFF, 0xFFFF, "PCI-5154(0x734A)"},
{0x1093, 0x7357, 0xFFFF, 0xFFFF, "PXI-4065(0x7357)"},
{0x1093, 0x7359, 0xFFFF, 0xFFFF, "PXI-4495(0x7359)"},
{0x1093, 0x7370, 0xFFFF, 0xFFFF, "PXI-4461(0x7370)"},
{0x1093, 0x7373, 0xFFFF, 0xFFFF, "sbRIO-9601(0x7373)"},
{0x1093, 0x7374, 0xFFFF, 0xFFFF, "IOtech-9601(0x7374)"},
{0x1093, 0x7375, 0xFFFF, 0xFFFF, "sbRIO-9602(0x7375)"},
{0x1093, 0x7378, 0xFFFF, 0xFFFF, "sbRIO-9641(0x7378)"},
{0x1093, 0x737D, 0xFFFF, 0xFFFF, "PXI-5124EX(0x737D)"},
{0x1093, 0x7384, 0xFFFF, 0xFFFF, "PXI-7851R(0x7384)"},
{0x1093, 0x7385, 0xFFFF, 0xFFFF, "PXI-7852R(0x7385)"},
{0x1093, 0x7386, 0xFFFF, 0xFFFF, "PCIe-7851R(0x7386)"},
{0x1093, 0x7387, 0xFFFF, 0xFFFF, "PCIe-7852R(0x7387)"},
{0x1093, 0x7390, 0xFFFF, 0xFFFF, "PXI-7841R(0x7390)"},
{0x1093, 0x7391, 0xFFFF, 0xFFFF, "PXI-7842R(0x7391)"},
{0x1093, 0x7392, 0xFFFF, 0xFFFF, "PXI-7853R(0x7392)"},
{0x1093, 0x7393, 0xFFFF, 0xFFFF, "PCIe-7841R(0x7393)"},
{0x1093, 0x7394, 0xFFFF, 0xFFFF, "PCIe-7842R(0x7394)"},
{0x1093, 0x7397, 0xFFFF, 0xFFFF, "sbRIO-9611(0x7397)"},
{0x1093, 0x7398, 0xFFFF, 0xFFFF, "sbRIO-9612(0x7398)"},
{0x1093, 0x7399, 0xFFFF, 0xFFFF, "sbRIO-9631(0x7399)"},
{0x1093, 0x739A, 0xFFFF, 0xFFFF, "sbRIO-9632(0x739A)"},
{0x1093, 0x739B, 0xFFFF, 0xFFFF, "sbRIO-9642(0x739B)"},
{0x1093, 0x73A1, 0xFFFF, 0xFFFF, "PXIe-4498(0x73A1)"},
{0x1093, 0x73A2, 0xFFFF, 0xFFFF, "PXIe-4496(0x73A2)"},
{0x1093, 0x73A5, 0xFFFF, 0xFFFF, "PXIe-5641R(0x73A5)"},
{0x1093, 0x73A7, 0xFFFF, 0xFFFF, "PXI-8250 Chassis Monitor Module(0x73A7)"},
{0x1093, 0x73A8, 0xFFFF, 0xFFFF, "PXI-8511 CAN/LS(0x73A8)"},
{0x1093, 0x73A9, 0xFFFF, 0xFFFF, "PXI-8511 CAN/LS(0x73A9)"},
{0x1093, 0x73AA, 0xFFFF, 0xFFFF, "PXI-8512 CAN/HS(0x73AA)"},
{0x1093, 0x73AB, 0xFFFF, 0xFFFF, "PXI-8512 CAN/HS(0x73AB)"},
{0x1093, 0x73AC, 0xFFFF, 0xFFFF, "PXI-8513 CAN/XS(0x73AC)"},
{0x1093, 0x73AD, 0xFFFF, 0xFFFF, "PXI-8513 CAN/XS(0x73AD)"},
{0x1093, 0x73AF, 0xFFFF, 0xFFFF, "PXI-8516 LIN(0x73AF)"},
{0x1093, 0x73B1, 0xFFFF, 0xFFFF, "PXI-8517 FlexRay(0x73B1)"},
{0x1093, 0x73B2, 0xFFFF, 0xFFFF, "PXI-8531 CANopen(0x73B2)"},
{0x1093, 0x73B3, 0xFFFF, 0xFFFF, "PXI-8531 CANopen(0x73B3)"},
{0x1093, 0x73B4, 0xFFFF, 0xFFFF, "PXI-8532 DeviceNet(0x73B4)"},
{0x1093, 0x73B5, 0xFFFF, 0xFFFF, "PXI-8532 DeviceNet(0x73B5)"},
{0x1093, 0x73B6, 0xFFFF, 0xFFFF, "PCI-8511 CAN/LS(0x73B6)"},
{0x1093, 0x73B7, 0xFFFF, 0xFFFF, "PCI-8511 CAN/LS(0x73B7)"},
{0x1093, 0x73B8, 0xFFFF, 0xFFFF, "PCI-8512 CAN/HS(0x73B8)"},
{0x1093, 0x73B9, 0xFFFF, 0xFFFF, "PCI-8512 CAN/HS(0x73B9)"},
{0x1093, 0x73BA, 0xFFFF, 0xFFFF, "PCI-8513 CAN/XS(0x73BA)"},
{0x1093, 0x73BB, 0xFFFF, 0xFFFF, "PCI-8513 CAN/XS(0x73BB)"},
{0x1093, 0x73BD, 0xFFFF, 0xFFFF, "PCI-8516 LIN(0x73BD)"},
{0x1093, 0x73BF, 0xFFFF, 0xFFFF, "PCI-8517 FlexRay(0x73BF)"},
{0x1093, 0x73C0, 0xFFFF, 0xFFFF, "PCI-8531 CANopen(0x73C0)"},
{0x1093, 0x73C1, 0xFFFF, 0xFFFF, "PCI-8531 CANopen(0x73C1)"},
{0x1093, 0x73C2, 0xFFFF, 0xFFFF, "PCI-8532 DeviceNet(0x73C2)"},
{0x1093, 0x73C3, 0xFFFF, 0xFFFF, "PCI-8532 DeviceNet(0x73C3)"},
{0x1093, 0x73C5, 0xFFFF, 0xFFFF, "PXIe-2527(0x73C5)"},
{0x1093, 0x73C6, 0xFFFF, 0xFFFF, "PXIe-2529(0x73C6)"},
{0x1093, 0x73C8, 0xFFFF, 0xFFFF, "PXIe-2530(0x73C8)"},
{0x1093, 0x73C9, 0xFFFF, 0xFFFF, "PXIe-2532(0x73C9)"},
{0x1093, 0x73CA, 0xFFFF, 0xFFFF, "PXIe-2569(0x73CA)"},
{0x1093, 0x73CB, 0xFFFF, 0xFFFF, "PXIe-2575(0x73CB)"},
{0x1093, 0x73CC, 0xFFFF, 0xFFFF, "PXIe-2593(0x73CC)"},
{0x1093, 0x73D5, 0xFFFF, 0xFFFF, "PXI-7951R(0x73D5)"},
{0x1093, 0x73D6, 0xFFFF, 0xFFFF, "PXI-7952R(0x73D6)"},
{0x1093, 0x73D7, 0xFFFF, 0xFFFF, "PXI-7953R(0x73D7)"},
{0x1093, 0x73E1, 0xFFFF, 0xFFFF, "PXI-7854R(0x73E1)"},
{0x1093, 0x73EC, 0xFFFF, 0xFFFF, "PXI-7954R(0x73EC)"},
{0x1093, 0x73ED, 0xFFFF, 0xFFFF, "cRIO-9073(0x73ED)"},
{0x1093, 0x73F0, 0xFFFF, 0xFFFF, "PXI-5153(0x73F0)"},
{0x1093, 0x73F1, 0xFFFF, 0xFFFF, "PCI-5153(0x73F1)"},
{0x1093, 0x73F4, 0xFFFF, 0xFFFF, "PXI-2515(0x73F4)"},
{0x1093, 0x73F6, 0xFFFF, 0xFFFF, "cRIO-9111(0x73F6)"},
{0x1093, 0x73F7, 0xFFFF, 0xFFFF, "cRIO-9112(0x73F7)"},
{0x1093, 0x73F8, 0xFFFF, 0xFFFF, "cRIO-9113(0x73F8)"},
{0x1093, 0x73F9, 0xFFFF, 0xFFFF, "cRIO-9114(0x73F9)"},
{0x1093, 0x73FA, 0xFFFF, 0xFFFF, "cRIO-9116(0x73FA)"},
{0x1093, 0x73FB, 0xFFFF, 0xFFFF, "cRIO-9118(0x73FB)"},
{0x1093, 0x7404, 0xFFFF, 0xFFFF, "PXI-4132(0x7404)"},
{0x1093, 0x7405, 0xFFFF, 0xFFFF, "PXIe-6674T(0x7405)"},
{0x1093, 0x7406, 0xFFFF, 0xFFFF, "PXIe-6674(0x7406)"},
{0x1093, 0x740E, 0xFFFF, 0xFFFF, "PCIe-8430/16 (RS-232) Interface(0x740E)"},
{0x1093, 0x740F, 0xFFFF, 0xFFFF, "PCIe-8430/8 (RS-232) Interface(0x740F)"},
{0x1093, 0x7410, 0xFFFF, 0xFFFF, "PCIe-8431/16 (RS-485) Interface(0x7410)"},
{0x1093, 0x7411, 0xFFFF, 0xFFFF, "PCIe-8431/8 (RS-485) Interface(0x7411)"},
{0x1093, 0x7414, 0xFFFF, 0xFFFF, "PCIe-GPIB+(0x7414)"},
{0x1093, 0x741C, 0xFFFF, 0xFFFF, "PXI-5691(0x741C)"},
{0x1093, 0x741D, 0xFFFF, 0xFFFF, "PXI-5695(0x741D)"},
{0x1093, 0x743C, 0xFFFF, 0xFFFF, "CSC-3059(0x743C)"},
{0x1093, 0x7448, 0xFFFF, 0xFFFF, "PXI-2510(0x7448)"},
{0x1093, 0x7454, 0xFFFF, 0xFFFF, "PXI-2512(0x7454)"},
{0x1093, 0x7455, 0xFFFF, 0xFFFF, "PXI-2514(0x7455)"},
{0x1093, 0x7456, 0xFFFF, 0xFFFF, "PXIe-2512(0x7456)"},
{0x1093, 0x7457, 0xFFFF, 0xFFFF, "PXIe-2514(0x7457)"},
{0x1093, 0x745A, 0xFFFF, 0xFFFF, "PXI-6682H(0x745A)"},
{0x1093, 0x745E, 0xFFFF, 0xFFFF, "PXI-5153EX(0x745E)"},
{0x1093, 0x745F, 0xFFFF, 0xFFFF, "PCI-5153EX(0x745F)"},
{0x1093, 0x7460, 0xFFFF, 0xFFFF, "PXI-5154EX(0x7460)"},
{0x1093, 0x7461, 0xFFFF, 0xFFFF, "PCI-5154EX(0x7461)"},
{0x1093, 0x746D, 0xFFFF, 0xFFFF, "PXIe-5650(0x746D)"},
{0x1093, 0x746E, 0xFFFF, 0xFFFF, "PXIe-5651(0x746E)"},
{0x1093, 0x746F, 0xFFFF, 0xFFFF, "PXIe-5652(0x746F)"},
{0x1093, 0x7472, 0xFFFF, 0xFFFF, "PXI-2800(0x7472)"},
{0x1093, 0x7495, 0xFFFF, 0xFFFF, "PXIe-5603(0x7495)"},
{0x1093, 0x7497, 0xFFFF, 0xFFFF, "PXIe-5605(0x7497)"},
{0x1093, 0x74AE, 0xFFFF, 0xFFFF, "PXIe-2515(0x74AE)"},
{0x1093, 0x74B4, 0xFFFF, 0xFFFF, "PXI-2531(0x74B4)"},
{0x1093, 0x74B5, 0xFFFF, 0xFFFF, "PXIe-2531(0x74B5)"},
{0x1093, 0x74C1, 0xFFFF, 0xFFFF, "PXIe-8430/16 (RS-232) Interface(0x74C1)"},
{0x1093, 0x74C2, 0xFFFF, 0xFFFF, "PXIe-8430/8 (RS-232) Interface(0x74C2)"},
{0x1093, 0x74C3, 0xFFFF, 0xFFFF, "PXIe-8431/16 (RS-485) Interface(0x74C3)"},
{0x1093, 0x74C4, 0xFFFF, 0xFFFF, "PXIe-8431/8 (RS-485) Interface(0x74C4)"},
{0x1093, 0x74D5, 0xFFFF, 0xFFFF, "PXIe-5630(0x74D5)"},
{0x1093, 0x74D9, 0xFFFF, 0xFFFF, "PCIe-8432/2 (Isolated RS-232) Interface(0x74D9)"},
{0x1093, 0x74DA, 0xFFFF, 0xFFFF, "PCIe-8433/2 (Isolated RS-485) Interface(0x74DA)"},
{0x1093, 0x74DB, 0xFFFF, 0xFFFF, "PCIe-8432/4 (Isolated RS-232) Interface(0x74DB)"},
{0x1093, 0x74DC, 0xFFFF, 0xFFFF, "PCIe-8433/4 (Isolated RS-485) Interface(0x74DC)"},
{0x1093, 0x74E8, 0xFFFF, 0xFFFF, "NI 9148(0x74E8)"},
{0x1093, 0x7515, 0xFFFF, 0xFFFF, "PCIe-8430/2 (RS-232) Interface(0x7515)"},
{0x1093, 0x7516, 0xFFFF, 0xFFFF, "PCIe-8430/4 (RS-232) Interface(0x7516)"},
{0x1093, 0x7517, 0xFFFF, 0xFFFF, "PCIe-8431/2 (RS-485) Interface(0x7517)"},
{0x1093, 0x7518, 0xFFFF, 0xFFFF, "PCIe-8431/4 (RS-485) Interface(0x7518)"},
{0x1093, 0x751B, 0xFFFF, 0xFFFF, "cRIO-9081(0x751B)"},
{0x1093, 0x751C, 0xFFFF, 0xFFFF, "cRIO-9082(0x751C)"},
{0x1093, 0x7528, 0xFFFF, 0xFFFF, "PXIe-4497(0x7528)"},
{0x1093, 0x7529, 0xFFFF, 0xFFFF, "PXIe-4499(0x7529)"},
{0x1093, 0x752A, 0xFFFF, 0xFFFF, "PXIe-4492(0x752A)"},
{0x1093, 0x7539, 0xFFFF, 0xFFFF, "NI 9157(0x7539)"},
{0x1093, 0x753A, 0xFFFF, 0xFFFF, "NI 9159(0x753A)"},
{0x1093, 0x7598, 0xFFFF, 0xFFFF, "PXI-2571(0x7598)"},
{0x1093, 0x75A4, 0xFFFF, 0xFFFF, "PXI-4131A(0x75A4)"},
{0x1093, 0x75B1, 0xFFFF, 0xFFFF, "PCIe-7854R(0x75B1)"},
{0x1093, 0x75BA, 0xFFFF, 0xFFFF, "PXI-2543(0x75BA)"},
{0x1093, 0x75BB, 0xFFFF, 0xFFFF, "PXIe-2543(0x75BB)"},
{0x1093, 0x75E5, 0xFFFF, 0xFFFF, "PXI-6683(0x75E5)"},
{0x1093, 0x75E6, 0xFFFF, 0xFFFF, "PXI-6683H(0x75E6)"},
{0x1093, 0x75EF, 0xFFFF, 0xFFFF, "PXIe-5632(0x75EF)"},
{0x1093, 0x761C, 0xFFFF, 0xFFFF, "VXI-8360LT(0x761C)"},
{0x1093, 0x761F, 0xFFFF, 0xFFFF, "PXI-2540(0x761F)"},
{0x1093, 0x7620, 0xFFFF, 0xFFFF, "PXIe-2540(0x7620)"},
{0x1093, 0x7621, 0xFFFF, 0xFFFF, "PXI-2541(0x7621)"},
{0x1093, 0x7622, 0xFFFF, 0xFFFF, "PXIe-2541(0x7622)"},
{0x1093, 0x7626, 0xFFFF, 0xFFFF, "NI 9154(0x7626)"},
{0x1093, 0x7627, 0xFFFF, 0xFFFF, "NI 9155(0x7627)"},
{0x1093, 0x7638, 0xFFFF, 0xFFFF, "PXI-2720(0x7638)"},
{0x1093, 0x7639, 0xFFFF, 0xFFFF, "PXI-2722(0x7639)"},
{0x1093, 0x763A, 0xFFFF, 0xFFFF, "PXIe-2725(0x763A)"},
{0x1093, 0x763B, 0xFFFF, 0xFFFF, "PXIe-2727(0x763B)"},
{0x1093, 0x763C, 0xFFFF, 0xFFFF, "PXI-4465(0x763C)"},
{0x1093, 0x764B, 0xFFFF, 0xFFFF, "PXIe-2790(0x764B)"},
{0x1093, 0x764C, 0xFFFF, 0xFFFF, "PXI-2520(0x764C)"},
{0x1093, 0x764D, 0xFFFF, 0xFFFF, "PXI-2521(0x764D)"},
{0x1093, 0x764E, 0xFFFF, 0xFFFF, "PXI-2522(0x764E)"},
{0x1093, 0x764F, 0xFFFF, 0xFFFF, "PXI-2523(0x764F)"},
{0x1093, 0x7652, 0xFFFF, 0xFFFF, "PXIe-4080(0x7652)"},
{0x1093, 0x7654, 0xFFFF, 0xFFFF, "PXI-2796(0x7654)"},
{0x1093, 0x7655, 0xFFFF, 0xFFFF, "PXI-2797(0x7655)"},
{0x1093, 0x7656, 0xFFFF, 0xFFFF, "PXI-2798(0x7656)"},
{0x1093, 0x7657, 0xFFFF, 0xFFFF, "PXI-2799(0x7657)"},
{0x1093, 0x765D, 0xFFFF, 0xFFFF, "PXI-2542(0x765D)"},
{0x1093, 0x765E, 0xFFFF, 0xFFFF, "PXIe-2542(0x765E)"},
{0x1093, 0x765F, 0xFFFF, 0xFFFF, "PXI-2544(0x765F)"},
{0x1093, 0x7660, 0xFFFF, 0xFFFF, "PXIe-2544(0x7660)"},
{0x1093, 0x766D, 0xFFFF, 0xFFFF, "PCIe-6535B(0x766D)"},
{0x1093, 0x766E, 0xFFFF, 0xFFFF, "PCIe-6536B(0x766E)"},
{0x1093, 0x766F, 0xFFFF, 0xFFFF, "PCIe-6537B(0x766F)"},
{0x1093, 0x76A3, 0xFFFF, 0xFFFF, "PXIe-6535B(0x76A3)"},
{0x1093, 0x76A4, 0xFFFF, 0xFFFF, "PXIe-6536B(0x76A4)"},
{0x1093, 0x76A5, 0xFFFF, 0xFFFF, "PXIe-6537B(0x76A5)"},
{0x1093, 0x76D8, 0xFFFF, 0xFFFF, "PXIe-4081(0x76D8)"},
{0x1093, 0x76D9, 0xFFFF, 0xFFFF, "PXIe-4082(0x76D9)"},
{0x1093, 0x77A8, 0xFFFF, 0xFFFF, "PXIe-6375(0x77A8)"},
{0x1093, 0x783E, 0xFFFF, 0xFFFF, "PXI-8368(0x783E)"},
{0x1093, 0x7882, 0xFFFF, 0xFFFF, "PXIe-6376(0x7882)"},
{0x1093, 0x7883, 0xFFFF, 0xFFFF, "PXIe-6378(0x7883)"},
{0x1093, 0x799E, 0xFFFF, 0xFFFF, "PXIe-6386(0x799E)"},
{0x1093, 0x799F, 0xFFFF, 0xFFFF, "PXIe-6396(0x799F)"},
{0x1093, 0x9020, 0xFFFF, 0xFFFF, "PXI-2501(0x9020)"},
{0x1093, 0x9030, 0xFFFF, 0xFFFF, "PXI-2503(0x9030)"},
{0x1093, 0x9040, 0xFFFF, 0xFFFF, "PXI-2527(0x9040)"},
{0x1093, 0x9050, 0xFFFF, 0xFFFF, "PXI-2565(0x9050)"},
{0x1093, 0x9060, 0xFFFF, 0xFFFF, "PXI-2590(0x9060)"},
{0x1093, 0x9070, 0xFFFF, 0xFFFF, "PXI-2591(0x9070)"},
{0x1093, 0x9080, 0xFFFF, 0xFFFF, "PXI-2580(0x9080)"},
{0x1093, 0x9090, 0xFFFF, 0xFFFF, "PCI-4021(0x9090)"},
{0x1093, 0x90A0, 0xFFFF, 0xFFFF, "PXI-4021(0x90A0)"},
{0x1093, 0xA001, 0xFFFF, 0xFFFF, "PCI-MXI-2(0xA001)"},
{0x1093, 0xB001, 0xFFFF, 0xFFFF, "PCI-1408(0xB001)"},
{0x1093, 0xB011, 0xFFFF, 0xFFFF, "PXI-1408(0xB011)"},
{0x1093, 0xB021, 0xFFFF, 0xFFFF, "PCI-1424(0xB021)"},
{0x1093, 0xB022, 0xFFFF, 0xFFFF, "PXI-1424(0xB022)"},
{0x1093, 0xB031, 0xFFFF, 0xFFFF, "PCI-1413(0xB031)"},
{0x1093, 0xB041, 0xFFFF, 0xFFFF, "PCI-1407(0xB041)"},
{0x1093, 0xB051, 0xFFFF, 0xFFFF, "PXI-1407(0xB051)"},
{0x1093, 0xB061, 0xFFFF, 0xFFFF, "PCI-1411(0xB061)"},
{0x1093, 0xB071, 0xFFFF, 0xFFFF, "PCI-1422(0xB071)"},
{0x1093, 0xB081, 0xFFFF, 0xFFFF, "PXI-1422(0xB081)"},
{0x1093, 0xB091, 0xFFFF, 0xFFFF, "PXI-1411(0xB091)"},
{0x1093, 0xB0B1, 0xFFFF, 0xFFFF, "PCI-1409(0xB0B1)"},
{0x1093, 0xB0C1, 0xFFFF, 0xFFFF, "PXI-1409(0xB0C1)"},
{0x1093, 0xB0E1, 0xFFFF, 0xFFFF, "PCI-1428(0xB0E1)"},
{0x1093, 0xC4C4, 0xFFFF, 0xFFFF, "PXIe/PCIe Device(0xC4C4)"},
{0x1093, 0xC4C4, 0x1093, 0x728A, "PXIe-5421(0x1093-0x728A)"},
{0x1093, 0xC4C4, 0x1093, 0x728B, "PXIe-5442(0x1093-0x728B)"},
{0x1093, 0xC4C4, 0x1093, 0x728D, "PXIe-5451(0x1093-0x728D)"},
{0x1093, 0xC4C4, 0x1093, 0x72A2, "PXIe-5122(0x1093-0x72A2)"},
{0x1093, 0xC4C4, 0x1093, 0x72DA, "PXIe-5422(0x1093-0x72DA)"},
{0x1093, 0xC4C4, 0x1093, 0x72F7, "PXIe-6535(0x1093-0x72F7)"},
{0x1093, 0xC4C4, 0x1093, 0x72F8, "PXIe-6536(0x1093-0x72F8)"},
{0x1093, 0xC4C4, 0x1093, 0x72F9, "PXIe-6537(0x1093-0x72F9)"},
{0x1093, 0xC4C4, 0x1093, 0x7326, "PCIe-6509(0x1093-0x7326)"},
{0x1093, 0xC4C4, 0x1093, 0x736C, "PXIe-4140(0x1093-0x736C)"},
{0x1093, 0xC4C4, 0x1093, 0x738B, "PXIe-5622(0x1093-0x738B)"},
{0x1093, 0xC4C4, 0x1093, 0x73C4, "PXIe-5450(0x1093-0x73C4)"},
{0x1093, 0xC4C4, 0x1093, 0x73C7, "PXIe-6545(0x1093-0x73C7)"},
{0x1093, 0xC4C4, 0x1093, 0x73D4, "PXIe-6544(0x1093-0x73D4)"},
{0x1093, 0xC4C4, 0x1093, 0x7425, "PCIe-6320(0x1093-0x7425)"},
{0x1093, 0xC4C4, 0x1093, 0x7427, "PCIe-6321(0x1093-0x7427)"},
{0x1093, 0xC4C4, 0x1093, 0x7428, "PXIe-6323(0x1093-0x7428)"},
{0x1093, 0xC4C4, 0x1093, 0x7429, "PCIe-6323(0x1093-0x7429)"},
{0x1093, 0xC4C4, 0x1093, 0x742A, "PXIe-6341(0x1093-0x742A)"},
{0x1093, 0xC4C4, 0x1093, 0x742B, "PCIe-6341(0x1093-0x742B)"},
{0x1093, 0xC4C4, 0x1093, 0x742C, "PXIe-6343(0x1093-0x742C)"},
{0x1093, 0xC4C4, 0x1093, 0x742D, "PCIe-6343(0x1093-0x742D)"},
{0x1093, 0xC4C4, 0x1093, 0x742F, "PCIe-6351(0x1093-0x742F)"},
{0x1093, 0xC4C4, 0x1093, 0x7431, "PCIe-6353(0x1093-0x7431)"},
{0x1093, 0xC4C4, 0x1093, 0x7432, "PXIe-6361(0x1093-0x7432)"},
{0x1093, 0xC4C4, 0x1093, 0x7433, "PCIe-6361(0x1093-0x7433)"},
{0x1093, 0xC4C4, 0x1093, 0x7434, "PXIe-6363(0x1093-0x7434)"},
{0x1093, 0xC4C4, 0x1093, 0x7435, "PCIe-6363(0x1093-0x7435)"},
{0x1093, 0xC4C4, 0x1093, 0x7436, "PXIe-6356(0x1093-0x7436)"},
{0x1093, 0xC4C4, 0x1093, 0x7437, "PXIe-6358(0x1093-0x7437)"},
{0x1093, 0xC4C4, 0x1093, 0x7438, "PXIe-6366(0x1093-0x7438)"},
{0x1093, 0xC4C4, 0x1093, 0x7439, "PXIe-6368(0x1093-0x7439)"},
{0x1093, 0xC4C4, 0x1093, 0x7468, "PXIe-5185(0x1093-0x7468)"},
{0x1093, 0xC4C4, 0x1093, 0x7469, "PXIe-5186(0x1093-0x7469)"},
{0x1093, 0xC4C4, 0x1093, 0x7492, "PXIe-4300(0x1093-0x7492)"},
{0x1093, 0xC4C4, 0x1093, 0x7498, "PXIe-6548(0x1093-0x7498)"},
{0x1093, 0xC4C4, 0x1093, 0x7499, "PXIe-6547(0x1093-0x7499)"},
{0x1093, 0xC4C4, 0x1093, 0x74A8, "PXIe-4330(0x1093-0x74A8)"},
{0x1093, 0xC4C4, 0x1093, 0x74A9, "PXIe-4331(0x1093-0x74A9)"},
{0x1093, 0xC4C4, 0x1093, 0x74B1, "PXIe-4154(0x1093-0x74B1)"},
{0x1093, 0xC4C4, 0x1093, 0x74B2, "PXIe-4353(0x1093-0x74B2)"},
{0x1093, 0xC4C4, 0x1093, 0x74B6, "PCIe-1433(0x1093-0x74B6)"},
{0x1093, 0xC4C4, 0x1093, 0x74CD, "PXIe-5643R(0x1093-0x74CD)"},
{0x1093, 0xC4C4, 0x1093, 0x74D0, "PXIe-7961R(0x1093-0x74D0)"},
{0x1093, 0xC4C4, 0x1093, 0x74DD, "PXIe-6376(0x1093-0x74DD)"},
{0x1093, 0xC4C4, 0x1093, 0x74DE, "PXIe-6378(0x1093-0x74DE)"},
{0x1093, 0xC4C4, 0x1093, 0x74E2, "PXIe-7962R(0x1093-0x74E2)"},
{0x1093, 0xC4C4, 0x1093, 0x74E3, "PXIe-7965R(0x1093-0x74E3)"},
{0x1093, 0xC4C4, 0x1093, 0x74E5, "PXIe-4844(0x1093-0x74E5)"},
{0x1093, 0xC4C4, 0x1093, 0x74F3, "PCIe-5140(0x1093-0x74F3)"},
{0x1093, 0xC4C4, 0x1093, 0x753C, "PXIe-1435(0x1093-0x753C)"},
{0x1093, 0xC4C4, 0x1093, 0x7548, "PXIe-5622 (25MHz DDC)(0x1093-0x7548)"},
{0x1093, 0xC4C4, 0x1093, 0x754D, "PCIe-5155(0x1093-0x754D)"},
{0x1093, 0xC4C4, 0x1093, 0x7551, "PXIe-6556(0x1093-0x7551)"},
{0x1093, 0xC4C4, 0x1093, 0x7553, "PCIe-1473R(0x1093-0x7553)"},
{0x1093, 0xC4C4, 0x1093, 0x7570, "PCIe-1474R(0x1093-0x7570)"},
{0x1093, 0xC4C4, 0x1093, 0x7571, "PXIe-1475R(0x1093-0x7571)"},
{0x1093, 0xC4C4, 0x1093, 0x7572, "PXIe-1476R(0x1093-0x7572)"},
{0x1093, 0xC4C4, 0x1093, 0x75A2, "PXIe-5693(0x1093-0x75A2)"},
{0x1093, 0xC4C4, 0x1093, 0x75A3, "PXIe-5694(0x1093-0x75A3)"},
{0x1093, 0xC4C4, 0x1093, 0x75A5, "PXIe-4141(0x1093-0x75A5)"},
{0x1093, 0xC4C4, 0x1093, 0x75CE, "PXIe-7966R(0x1093-0x75CE)"},
{0x1093, 0xC4C4, 0x1093, 0x75CF, "PXIe-4357(0x1093-0x75CF)"},
{0x1093, 0xC4C4, 0x1093, 0x75D2, "PXIe-RevB-5643R(0x1093-0x75D2)"},
{0x1093, 0xC4C4, 0x1093, 0x75D3, "PXIe-5644R(0x1093-0x75D3)"},
{0x1093, 0xC4C4, 0x1093, 0x75EE, "PXIe-5645R(0x1093-0x75EE)"},
{0x1093, 0xC4C4, 0x1093, 0x7613, "PXIe-6555(0x1093-0x7613)"},
{0x1093, 0xC4C4, 0x1093, 0x7619, "PXIe-5185(0x1093-0x7619)"},
{0x1093, 0xC4C4, 0x1093, 0x761A, "PXIe-5186(0x1093-0x761A)"},
{0x1093, 0xC4C4, 0x1093, 0x7629, "PXIe-4142(0x1093-0x7629)"},
{0x1093, 0xC4C4, 0x1093, 0x762A, "PXIe-4143(0x1093-0x762A)"},
{0x1093, 0xC4C4, 0x1093, 0x762B, "PXIe-4138(0x1093-0x762B)"},
{0x1093, 0xC4C4, 0x1093, 0x762C, "PXIe-4144(0x1093-0x762C)"},
{0x1093, 0xC4C4, 0x1093, 0x762D, "PXIe-4145(0x1093-0x762D)"},
{0x1093, 0xC4C4, 0x1093, 0x762E, "PXIe-5606(0x1093-0x762E)"},
{0x1093, 0xC4C4, 0x1093, 0x7644, "PXIe-4841(0x1093-0x7644)"},
{0x1093, 0xC4C4, 0x1093, 0x764A, "PCIe-8237R-S(0x1093-0x764A)"},
{0x1093, 0xC4C4, 0x1093, 0x7658, "PXIe-5162 (4CH)(0x1093-0x7658)"},
{0x1093, 0xC4C4, 0x1093, 0x76AB, "PXIe-4322(0x1093-0x76AB)"},
{0x1093, 0xC4C4, 0x1093, 0x76AD, "PXIe-4112(0x1093-0x76AD)"},
{0x1093, 0xC4C4, 0x1093, 0x76AE, "PXIe-4113(0x1093-0x76AE)"},
{0x1093, 0xC4C4, 0x1093, 0x76B5, "PXIe-7971R(0x1093-0x76B5)"},
{0x1093, 0xC4C4, 0x1093, 0x76B6, "PXIe-7972R(0x1093-0x76B6)"},
{0x1093, 0xC4C4, 0x1093, 0x76B7, "PXIe-7975R(0x1093-0x76B7)"},
{0x1093, 0xC4C4, 0x1093, 0x76B8, "PXIe-5696(0x1093-0x76B8)"},
{0x1093, 0xC4C4, 0x1093, 0x76B9, "PXIe-5654(0x1093-0x76B9)"},
{0x1093, 0xC4C4, 0x1093, 0x76C8, "PXIe-6614(0x1093-0x76C8)"},
{0x1093, 0xC4C4, 0x1093, 0x76C9, "PXIe-6612(0x1093-0x76C9)"},
{0x1093, 0xC4C4, 0x1093, 0x76CB, "PXIe-5646R(0x1093-0x76CB)"},
{0x1093, 0xC4C4, 0x1093, 0x76CC, "PXIe-5162 (2CH)(0x1093-0x76CC)"},
{0x1093, 0xC4C4, 0x1093, 0x76CE, "CVS-1459(0x1093-0x76CE)"},
{0x1093, 0xC4C4, 0x1093, 0x76D0, "PXIe-5160 (2CH)(0x1093-0x76D0)"},
{0x1093, 0xC4C4, 0x1093, 0x76D1, "PXIe-5160 (4CH)(0x1093-0x76D1)"},
{0x1093, 0xC4C4, 0x1093, 0x76DC, "PXIe-4610(0x1093-0x76DC)"},
{0x1093, 0xC4C4, 0x1093, 0x76EC, "PXIe-2524(0x1093-0x76EC)"},
{0x1093, 0xC4C4, 0x1093, 0x76ED, "PXIe-2525(0x1093-0x76ED)"},
{0x1093, 0xC4C4, 0x1093, 0x76EE, "PXIe-2526(0x1093-0x76EE)"},
{0x1093, 0xC4C4, 0x1093, 0x76EF, "PXIe-2737(0x1093-0x76EF)"},
{0x1093, 0xC4C4, 0x1093, 0x76F0, "PXIe-2738(0x1093-0x76F0)"},
{0x1093, 0xC4C4, 0x1093, 0x76F1, "PXIe-2739(0x1093-0x76F1)"},
{0x1093, 0xC4C4, 0x1093, 0x76FB, "PCIe-1473R-LX110(0x1093-0x76FB)"},
{0x1093, 0xC4C4, 0x1093, 0x76FC, "PXIe-5105(0x1093-0x76FC)"},
{0x1093, 0xC4C4, 0x1093, 0x76FD, "PXIe-5114(0x1093-0x76FD)"},
{0x1093, 0xC4C4, 0x1093, 0x76FE, "PXIe-5644R(0x1093-0x76FE)"},
{0x1093, 0xC4C4, 0x1093, 0x76FF, "PXIe-5644R(0x1093-0x76FF)"},
{0x1093, 0xC4C4, 0x1093, 0x7700, "PXIe-5644R(0x1093-0x7700)"},
{0x1093, 0xC4C4, 0x1093, 0x7701, "PXIe-5645R(0x1093-0x7701)"},
{0x1093, 0xC4C4, 0x1093, 0x7702, "PXIe-5645R(0x1093-0x7702)"},
{0x1093, 0xC4C4, 0x1093, 0x7703, "PXIe-5645R(0x1093-0x7703)"},
{0x1093, 0xC4C4, 0x1093, 0x770C, "PXIe-4139(0x1093-0x770C)"},
{0x1093, 0xC4C4, 0x1093, 0x7711, "PXIe-4464(0x1093-0x7711)"},
{0x1093, 0xC4C4, 0x1093, 0x7712, "PXIe-4463(0x1093-0x7712)"},
{0x1093, 0xC4C4, 0x1093, 0x7716, "PCIe-6612(0x1093-0x7716)"},
{0x1093, 0xC4C4, 0x1093, 0x771D, "Unconfigured CA4 Switch(0x1093-0x771D)"},
{0x1093, 0xC4C4, 0x1093, 0x771E, "PXIe-4339(0x1093-0x771E)"},
{0x1093, 0xC4C4, 0x1093, 0x7735, "cRIO-9033(0x1093-0x7735)"},
{0x1093, 0xC4C4, 0x1093, 0x773E, "PXIe-5624R(0x1093-0x773E)"},
{0x1093, 0xC4C4, 0x1093, 0x774B, "cRIO-9031(0x1093-0x774B)"},
{0x1093, 0xC4C4, 0x1093, 0x774D, "cRIO-9034(0x1093-0x774D)"},
{0x1093, 0xC4C4, 0x1093, 0x7755, "cRIO-9030(0x1093-0x7755)"},
{0x1093, 0xC4C4, 0x1093, 0x7768, "PXIe-2747(0x1093-0x7768)"},
{0x1093, 0xC4C4, 0x1093, 0x7769, "PXIe-2748(0x1093-0x7769)"},
{0x1093, 0xC4C4, 0x1093, 0x776A, "PXIe-2746(0x1093-0x776A)"},
{0x1093, 0xC4C4, 0x1093, 0x7777, "PXIe-7976R(0x1093-0x7777)"},
{0x1093, 0xC4C4, 0x1093, 0x7782, "PXIe-5646R(0x1093-0x7782)"},
{0x1093, 0xC4C4, 0x1093, 0x7783, "PXIe-5646R(0x1093-0x7783)"},
{0x1093, 0xC4C4, 0x1093, 0x7784, "PXIe-5646R(0x1093-0x7784)"},
{0x1093, 0xC4C4, 0x1093, 0x7790, "PXIe-5170R (4CH)(0x1093-0x7790)"},
{0x1093, 0xC4C4, 0x1093, 0x7791, "PXIe-5170R (8CH)(0x1093-0x7791)"},
{0x1093, 0xC4C4, 0x1093, 0x7793, "PXIe-5171R (8CH)(0x1093-0x7793)"},
{0x1093, 0xC4C4, 0x1093, 0x77A5, "PXIe-6345(0x1093-0x77A5)"},
{0x1093, 0xC4C4, 0x1093, 0x77A6, "PXIe-6355(0x1093-0x77A6)"},
{0x1093, 0xC4C4, 0x1093, 0x77A7, "PXIe-6365(0x1093-0x77A7)"},
{0x1093, 0xC4C4, 0x1093, 0x77A8, "PXIe-6375(0x1093-0x77A8)"},
{0x1093, 0xC4C4, 0x1093, 0x77AA, "CVS-1458(0x1093-0x77AA)"},
{0x1093, 0xC4C4, 0x1093, 0x77AD, "IC-3173(0x1093-0x77AD)"},
{0x1093, 0xC4C4, 0x1093, 0x77B4, "PXIe-7820R(0x1093-0x77B4)"},
{0x1093, 0xC4C4, 0x1093, 0x77B5, "PXIe-7821R(0x1093-0x77B5)"},
{0x1093, 0xC4C4, 0x1093, 0x77B6, "PXIe-7822R(0x1093-0x77B6)"},
{0x1093, 0xC4C4, 0x1093, 0x77B9, "cRIO-9038(0x1093-0x77B9)"},
{0x1093, 0xC4C4, 0x1093, 0x77BA, "PXIe-4136(0x1093-0x77BA)"},
{0x1093, 0xC4C4, 0x1093, 0x77BB, "PXIe-4137(0x1093-0x77BB)"},
{0x1093, 0xC4C4, 0x1093, 0x77C0, "PXIe-5624R(0x1093-0x77C0)"},
{0x1093, 0xC4C4, 0x1093, 0x77C1, "PXIe-5624R(0x1093-0x77C1)"},
{0x1093, 0xC4C4, 0x1093, 0x77C2, "PXIe-5624R(0x1093-0x77C2)"},
{0x1093, 0xC4C4, 0x1093, 0x77CA, "PXIe-6738(0x1093-0x77CA)"},
{0x1093, 0xC4C4, 0x1093, 0x77CB, "PXIe-6739(0x1093-0x77CB)"},
{0x1093, 0xC4C4, 0x1093, 0x77DB, "cRIO-9035(0x1093-0x77DB)"},
{0x1093, 0xC4C4, 0x1093, 0x77DC, "cRIO-9036(0x1093-0x77DC)"},
{0x1093, 0xC4C4, 0x1093, 0x77DD, "cRIO-9039(0x1093-0x77DD)"},
{0x1093, 0xC4C4, 0x1093, 0x7802, "PXIe-4302(0x1093-0x7802)"},
{0x1093, 0xC4C4, 0x1093, 0x7803, "PXIe-4303(0x1093-0x7803)"},
{0x1093, 0xC4C4, 0x1093, 0x7805, "PXIe-4305(0x1093-0x7805)"},
{0x1093, 0xC4C4, 0x1093, 0x786F, "PXIe-4163(0x1093-0x786F)"},
{0x1093, 0xC4C4, 0x1093, 0x788E, "PXIe-4304(0x1093-0x788E)"},
{0x1093, 0xC4C4, 0x1093, 0x78F8, "NI FlexRIO Module (KU035)(0x1093-0x78F8)"},
{0x1093, 0xC4C4, 0x1093, 0x78F9, "NI FlexRIO Module (KU040)(0x1093-0x78F9)"},
{0x1093, 0xC4C4, 0x1093, 0x78FA, "NI FlexRIO Module (KU060)(0x1093-0x78FA)"},
{0x1093, 0xC4C4, 0x1093, 0x78FF, "PXIe-4162(0x1093-0x78FF)"},
{0x1093, 0xC4C4, 0x1093, 0x7995, "PXIe-7911R(0x1093-0x7995)"},
{0x1093, 0xC4C4, 0x1093, 0x7996, "PXIe-7912R(0x1093-0x7996)"},
{0x1093, 0xC4C4, 0x1093, 0x7997, "PXIe-7915R(0x1093-0x7997)"},
{0x1093, 0xC4C4, 0x1093, 0x79D3, "NI FlexRIO PCIe Module (KU035)(0x1093-0x79D3)"},
{0x1093, 0xC4C4, 0x1093, 0x79D4, "NI FlexRIO PCIe Module (KU040)(0x1093-0x79D4)"},
{0x1093, 0xC4C4, 0x1093, 0x79D5, "NI FlexRIO PCIe Module (KU060)(0x1093-0x79D5)"},
{0x1093, 0xC801, 0xFFFF, 0xFFFF, "PCI-GPIB(0xC801)"},
{0x1093, 0xC811, 0xFFFF, 0xFFFF, "PCI-GPIB+(0xC811)"},
{0x1093, 0xC821, 0xFFFF, 0xFFFF, "PXI-GPIB(0xC821)"},
{0x1093, 0xC831, 0xFFFF, 0xFFFF, "PMC-GPIB(0xC831)"},
{0x1093, 0xC840, 0xFFFF, 0xFFFF, "PCI-GPIB(0xC840)"},
{0x1093, 0xD130, 0xFFFF, 0xFFFF, "PCI-232/2 Interface(0xD130)"},
{0x1093, 0xD140, 0xFFFF, 0xFFFF, "PCI-232/4 Interface(0xD140)"},
{0x1093, 0xD150, 0xFFFF, 0xFFFF, "PCI-232/8 Interface(0xD150)"},
{0x1093, 0xD160, 0xFFFF, 0xFFFF, "PCI-485/2 Interface(0xD160)"},
{0x1093, 0xD170, 0xFFFF, 0xFFFF, "PCI-485/4 Interface(0xD170)"},
{0x1093, 0xD190, 0xFFFF, 0xFFFF, "PXI-8422/2 (Isolated RS-232) Interface(0xD190)"},
{0x1093, 0xD1A0, 0xFFFF, 0xFFFF, "PXI-8422/4 (Isolated RS-232) Interface(0xD1A0)"},
{0x1093, 0xD1B0, 0xFFFF, 0xFFFF, "PXI-8423/2 (Isolated RS-485) Interface(0xD1B0)"},
{0x1093, 0xD1C0, 0xFFFF, 0xFFFF, "PXI-8423/4 (Isolated RS-485) Interface(0xD1C0)"},
{0x1093, 0xD1D0, 0xFFFF, 0xFFFF, "PXI-8420/2 (RS-232) Interface(0xD1D0)"},
{0x1093, 0xD1E0, 0xFFFF, 0xFFFF, "PXI-8420/4 (RS-232) Interface(0xD1E0)"},
{0x1093, 0xD1F0, 0xFFFF, 0xFFFF, "PXI-8420/8 (RS-232) Interface(0xD1F0)"},
{0x1093, 0xD1F1, 0xFFFF, 0xFFFF, "PXI-8420/16 (RS-232) Interface(0xD1F1)"},
{0x1093, 0xD230, 0xFFFF, 0xFFFF, "PXI-8421/2 (RS-485) Interface(0xD230)"},
{0x1093, 0xD240, 0xFFFF, 0xFFFF, "PXI-8421/4 (RS-485) Interface(0xD240)"},
{0x1093, 0xD250, 0xFFFF, 0xFFFF, "PCI-232/2 (Isolated) Interface(0xD250)"},
{0x1093, 0xD260, 0xFFFF, 0xFFFF, "PCI-485/2 (Isolated) Interface(0xD260)"},
{0x1093, 0xD270, 0xFFFF, 0xFFFF, "PCI-232/4 (Isolated) Interface(0xD270)"},
{0x1093, 0xD280, 0xFFFF, 0xFFFF, "PCI-485/4 (Isolated) Interface(0xD280)"},
{0x1093, 0xD290, 0xFFFF, 0xFFFF, "PCI-485/8 Interface(0xD290)"},
{0x1093, 0xD2A0, 0xFFFF, 0xFFFF, "PXI-8421/8 (RS-485) Interface(0xD2A0)"},
{0x1093, 0xD2B0, 0xFFFF, 0xFFFF, "PCI-232/16 Interface(0xD2B0)"},
{0x1093, 0xE111, 0xFFFF, 0xFFFF, "PCI-CAN(0xE111)"},
{0x1093, 0xE131, 0xFFFF, 0xFFFF, "PXI-8461 (1 port)(0xE131)"},
{0x1093, 0xE141, 0xFFFF, 0xFFFF, "PCI-CAN/LS(0xE141)"},
{0x1093, 0xE151, 0xFFFF, 0xFFFF, "PXI-8460 (1 port)(0xE151)"},
{0x1093, 0xE211, 0xFFFF, 0xFFFF, "PCI-CAN/2(0xE211)"},
{0x1093, 0xE231, 0xFFFF, 0xFFFF, "PXI-8461 (2 ports)(0xE231)"},
{0x1093, 0xE241, 0xFFFF, 0xFFFF, "PCI-CAN/LS2(0xE241)"},
{0x1093, 0xE251, 0xFFFF, 0xFFFF, "PXI-8460 (2 ports)(0xE251)"},
{0x1093, 0xE261, 0xFFFF, 0xFFFF, "PCI-CAN/DS(0xE261)"},
{0x1093, 0xE271, 0xFFFF, 0xFFFF, "PXI-8462(0xE271)"},
{0x1093, 0xF110, 0xFFFF, 0xFFFF, "VMEpc-650(0xF110)"},
{0x1093, 0xF120, 0xFFFF, 0xFFFF, "VXIpc-650(0xF120)"},
{0x1093, 0xFE00, 0xFFFF, 0xFFFF, "VXIpc-87x(0xFE00)"},
{0x1093, 0xFE41, 0xFFFF, 0xFFFF, "VXIpc-860(0xFE41)"},
{0x1093, 0xFE51, 0xFFFF, 0xFFFF, "VXIpc-74x(0xFE51)"},
{0x1093, 0xFE61, 0xFFFF, 0xFFFF, "VXIpc-850(0xFE61)"},
{0x1093, 0xFE70, 0xFFFF, 0xFFFF, "VXIpc-880(0xFE70)"},
}; /* pci_vid_1093[] */

static pci_id_t const pci_vid_1094[] = {
{0x1094, 0xFFFF, 0xFFFF, 0xFFFF, "First International Computers [FIC](0x1094)"},
}; /* pci_vid_1094[] */

static pci_id_t const pci_vid_1095[] = {
{0x1095, 0xFFFF, 0xFFFF, 0xFFFF, "Silicon Image, Inc.(0x1095)"},
{0x1095, 0x0240, 0xFFFF, 0xFFFF, "Adaptec AAR-1210SA SATA HostRAID Controller(0x0240)"},
{0x1095, 0x0242, 0xFFFF, 0xFFFF, "AAR-1220SA SATA RAID Controller(0x0242)"},
{0x1095, 0x0640, 0xFFFF, 0xFFFF, "PCI0640(0x0640)"},
{0x1095, 0x0643, 0xFFFF, 0xFFFF, "PCI0643(0x0643)"},
{0x1095, 0x0646, 0xFFFF, 0xFFFF, "PCI0646(0x0646)"},
{0x1095, 0x0647, 0xFFFF, 0xFFFF, "PCI0647(0x0647)"},
{0x1095, 0x0648, 0xFFFF, 0xFFFF, "PCI0648(0x0648)"},
{0x1095, 0x0648, 0x1043, 0x8025, "CUBX motherboard(0x1043-0x8025)"},
{0x1095, 0x0649, 0xFFFF, 0xFFFF, "SiI 0649 Ultra ATA/100 PCI to ATA Host Controller(0x0649)"},
{0x1095, 0x0649, 0x0E11, 0x005D, "Integrated Ultra ATA-100 Dual Channel Controller(0x0E11-0x005D)"},
{0x1095, 0x0649, 0x0E11, 0x007E, "Integrated Ultra ATA-100 IDE RAID Controller(0x0E11-0x007E)"},
{0x1095, 0x0649, 0x101E, 0x0649, "AMI MegaRAID IDE 100 Controller(0x101E-0x0649)"},
{0x1095, 0x0650, 0xFFFF, 0xFFFF, "PBC0650A(0x0650)"},
{0x1095, 0x0670, 0xFFFF, 0xFFFF, "USB0670(0x0670)"},
{0x1095, 0x0670, 0x1095, 0x0670, "USB0670(0x1095-0x0670)"},
{0x1095, 0x0673, 0xFFFF, 0xFFFF, "USB0673(0x0673)"},
{0x1095, 0x0680, 0xFFFF, 0xFFFF, "PCI0680 Ultra ATA-133 Host Controller(0x0680)"},
{0x1095, 0x0680, 0x1095, 0x0680, "SiI 0680 ATA/133 Controller(0x1095-0x0680)"},
{0x1095, 0x0680, 0x1095, 0x3680, "Winic W-680 (Silicon Image 680 based)(0x1095-0x3680)"},
{0x1095, 0x3112, 0xFFFF, 0xFFFF, "SiI 3112 [SATALink/SATARaid] Serial ATA Controller(0x3112)"},
{0x1095, 0x3112, 0x1095, 0x3112, "SiI 3112 SATALink Controller(0x1095-0x3112)"},
{0x1095, 0x3112, 0x1095, 0x6112, "SiI 3112 SATARaid Controller(0x1095-0x6112)"},
{0x1095, 0x3112, 0x9005, 0x0250, "SATAConnect 1205SA Host Controller(0x9005-0x0250)"},
{0x1095, 0x3114, 0xFFFF, 0xFFFF, "SiI 3114 [SATALink/SATARaid] Serial ATA Controller(0x3114)"},
{0x1095, 0x3114, 0x1043, 0x8167, "A8N-SLI Deluxe/Premium Mainboard(0x1043-0x8167)"},
{0x1095, 0x3114, 0x1095, 0x3114, "SiI 3114 SATALink Controller(0x1095-0x3114)"},
{0x1095, 0x3114, 0x1095, 0x6114, "SiI 3114 SATARaid Controller(0x1095-0x6114)"},
{0x1095, 0x3124, 0xFFFF, 0xFFFF, "SiI 3124 PCI-X Serial ATA Controller(0x3124)"},
{0x1095, 0x3124, 0x1095, 0x3124, "SiI 3124 PCI-X Serial ATA Controller(0x1095-0x3124)"},
{0x1095, 0x3132, 0xFFFF, 0xFFFF, "SiI 3132 Serial ATA Raid II Controller(0x3132)"},
{0x1095, 0x3512, 0xFFFF, 0xFFFF, "SiI 3512 [SATALink/SATARaid] Serial ATA Controller(0x3512)"},
{0x1095, 0x3512, 0x1095, 0x3512, "SiI 3512 SATALink Controller(0x1095-0x3512)"},
{0x1095, 0x3512, 0x1095, 0x6512, "SiI 3512 SATARaid Controller(0x1095-0x6512)"},
{0x1095, 0x3531, 0xFFFF, 0xFFFF, "SiI 3531 [SATALink/SATARaid] Serial ATA Controller(0x3531)"},
{0x1095, 0x3531, 0x17C0, 0x4083, "Medion WIM 2210 Notebook PC [MD96850](0x17C0-0x4083)"},
}; /* pci_vid_1095[] */

static pci_id_t const pci_vid_1096[] = {
{0x1096, 0xFFFF, 0xFFFF, 0xFFFF, "Alacron(0x1096)"},
}; /* pci_vid_1096[] */

static pci_id_t const pci_vid_1097[] = {
{0x1097, 0xFFFF, 0xFFFF, 0xFFFF, "Appian Technology(0x1097)"},
}; /* pci_vid_1097[] */

static pci_id_t const pci_vid_1098[] = {
{0x1098, 0xFFFF, 0xFFFF, 0xFFFF, "Quantum Designs (H.K.) Ltd(0x1098)"},
{0x1098, 0x0001, 0xFFFF, 0xFFFF, "QD-8500(0x0001)"},
{0x1098, 0x0002, 0xFFFF, 0xFFFF, "QD-8580(0x0002)"},
}; /* pci_vid_1098[] */

static pci_id_t const pci_vid_1099[] = {
{0x1099, 0xFFFF, 0xFFFF, 0xFFFF, "Samsung Electronics Co., Ltd(0x1099)"},
}; /* pci_vid_1099[] */

static pci_id_t const pci_vid_109A[] = {
{0x109A, 0xFFFF, 0xFFFF, 0xFFFF, "Packard Bell(0x109A)"},
}; /* pci_vid_109A[] */

static pci_id_t const pci_vid_109B[] = {
{0x109B, 0xFFFF, 0xFFFF, 0xFFFF, "Gemlight Computer Ltd.(0x109B)"},
}; /* pci_vid_109B[] */

static pci_id_t const pci_vid_109C[] = {
{0x109C, 0xFFFF, 0xFFFF, 0xFFFF, "Megachips Corporation(0x109C)"},
}; /* pci_vid_109C[] */

static pci_id_t const pci_vid_109D[] = {
{0x109D, 0xFFFF, 0xFFFF, 0xFFFF, "Zida Technologies Ltd.(0x109D)"},
}; /* pci_vid_109D[] */

static pci_id_t const pci_vid_109E[] = {
{0x109E, 0xFFFF, 0xFFFF, 0xFFFF, "Brooktree Corporation(0x109E)"},
{0x109E, 0x0310, 0xFFFF, 0xFFFF, "Bt848 Video Capture(0x0310)"},
{0x109E, 0x032E, 0xFFFF, 0xFFFF, "Bt878 Video Capture(0x032E)"},
{0x109E, 0x0350, 0xFFFF, 0xFFFF, "Bt848 Video Capture(0x0350)"},
{0x109E, 0x0351, 0xFFFF, 0xFFFF, "Bt849A Video capture(0x0351)"},
{0x109E, 0x0369, 0xFFFF, 0xFFFF, "Bt878 Video Capture(0x0369)"},
{0x109E, 0x0369, 0x1002, 0x0001, "TV-Wonder(0x1002-0x0001)"},
{0x109E, 0x0369, 0x1002, 0x0003, "TV-Wonder/VE(0x1002-0x0003)"},
{0x109E, 0x036C, 0xFFFF, 0xFFFF, "Bt879(?-?-) Video Capture(0x036C)"},
{0x109E, 0x036C, 0x13E9, 0x0070, "Win/TV (Video Section)(0x13E9-0x0070)"},
{0x109E, 0x036E, 0xFFFF, 0xFFFF, "Bt878 Video Capture(0x036E)"},
{0x109E, 0x036E, 0x0000, 0x0001, "Euresys Picolo PCIe(0x0000-0x0001)"},
{0x109E, 0x036E, 0x0000, 0x0002, "Euresys PICOLO Pro 2(0x0000-0x0002)"},
{0x109E, 0x036E, 0x0000, 0x0004, "Euresys PICOLO Pro 3E(0x0000-0x0004)"},
{0x109E, 0x036E, 0x0070, 0x13EB, "WinTV Series(0x0070-0x13EB)"},
{0x109E, 0x036E, 0x0070, 0xFF01, "Viewcast Osprey 200(0x0070-0xFF01)"},
{0x109E, 0x036E, 0x0071, 0x0101, "DigiTV PCI(0x0071-0x0101)"},
{0x109E, 0x036E, 0x107D, 0x6606, "WinFast TV 2000(0x107D-0x6606)"},
{0x109E, 0x036E, 0x11BD, 0x0012, "PCTV pro (TV + FM stereo receiver)(0x11BD-0x0012)"},
{0x109E, 0x036E, 0x11BD, 0x001C, "PCTV Sat (DBC receiver)(0x11BD-0x001C)"},
{0x109E, 0x036E, 0x127A, 0x0001, "Bt878 Mediastream Controller NTSC(0x127A-0x0001)"},
{0x109E, 0x036E, 0x127A, 0x0002, "Bt878 Mediastream Controller PAL BG(0x127A-0x0002)"},
{0x109E, 0x036E, 0x127A, 0x0003, "Bt878a Mediastream Controller PAL BG(0x127A-0x0003)"},
{0x109E, 0x036E, 0x127A, 0x0048, "Bt878/832 Mediastream Controller(0x127A-0x0048)"},
{0x109E, 0x036E, 0x144F, 0x3000, "MagicTView CPH060 - Video(0x144F-0x3000)"},
{0x109E, 0x036E, 0x1461, 0x0002, "TV98 Series (TV/No FM/Remote)(0x1461-0x0002)"},
{0x109E, 0x036E, 0x1461, 0x0003, "AverMedia UltraTV PCI 350(0x1461-0x0003)"},
{0x109E, 0x036E, 0x1461, 0x0004, "AVerTV WDM Video Capture(0x1461-0x0004)"},
{0x109E, 0x036E, 0x1461, 0x0761, "AverTV DVB-T(0x1461-0x0761)"},
{0x109E, 0x036E, 0x1461, 0x0771, "AverMedia AVerTV DVB-T 771(0x1461-0x0771)"},
{0x109E, 0x036E, 0x14F1, 0x0001, "Bt878 Mediastream Controller NTSC(0x14F1-0x0001)"},
{0x109E, 0x036E, 0x14F1, 0x0002, "Bt878 Mediastream Controller PAL BG(0x14F1-0x0002)"},
{0x109E, 0x036E, 0x14F1, 0x0003, "Bt878a Mediastream Controller PAL BG(0x14F1-0x0003)"},
{0x109E, 0x036E, 0x14F1, 0x0048, "Bt878/832 Mediastream Controller(0x14F1-0x0048)"},
{0x109E, 0x036E, 0x1805, 0x0101, "Euresys PICOLO Tetra(0x1805-0x0101)"},
{0x109E, 0x036E, 0x1805, 0x0102, "Euresys PICOLO Tetra(0x1805-0x0102)"},
{0x109E, 0x036E, 0x1805, 0x0103, "Euresys PICOLO Tetra(0x1805-0x0103)"},
{0x109E, 0x036E, 0x1805, 0x0104, "Euresys PICOLO Tetra(0x1805-0x0104)"},
{0x109E, 0x036E, 0x1805, 0x0105, "Euresys PICOLO Tetra(0x1805-0x0105)"},
{0x109E, 0x036E, 0x1805, 0x0106, "Euresys PICOLO Tetra(0x1805-0x0106)"},
{0x109E, 0x036E, 0x1805, 0x0107, "Euresys PICOLO Tetra(0x1805-0x0107)"},
{0x109E, 0x036E, 0x1805, 0x0108, "Euresys PICOLO Tetra(0x1805-0x0108)"},
{0x109E, 0x036E, 0x1805, 0x0201, "Euresys PICOLO Tetra-X(0x1805-0x0201)"},
{0x109E, 0x036E, 0x1805, 0x0202, "Euresys PICOLO Tetra-X(0x1805-0x0202)"},
{0x109E, 0x036E, 0x1805, 0x0203, "Euresys PICOLO Tetra-X(0x1805-0x0203)"},
{0x109E, 0x036E, 0x1805, 0x0204, "Euresys PICOLO Tetra-X(0x1805-0x0204)"},
{0x109E, 0x036E, 0x1805, 0x0401, "Euresys PICOLO Tymo(0x1805-0x0401)"},
{0x109E, 0x036E, 0x1805, 0x0402, "Euresys PICOLO Tymo(0x1805-0x0402)"},
{0x109E, 0x036E, 0x1805, 0x0403, "Euresys PICOLO Tymo(0x1805-0x0403)"},
{0x109E, 0x036E, 0x1805, 0x0404, "Euresys PICOLO Tymo(0x1805-0x0404)"},
{0x109E, 0x036E, 0x1805, 0x1001, "Euresys PICOLO Junior 4(0x1805-0x1001)"},
{0x109E, 0x036E, 0x1822, 0x0001, "VisionPlus DVB card(0x1822-0x0001)"},
{0x109E, 0x036E, 0x1851, 0x1850, "FlyVideo'98 - Video(0x1851-0x1850)"},
{0x109E, 0x036E, 0x1851, 0x1851, "FlyVideo II(0x1851-0x1851)"},
{0x109E, 0x036E, 0x1852, 0x1852, "FlyVideo'98 - Video (with FM Tuner)(0x1852-0x1852)"},
{0x109E, 0x036E, 0x18AC, 0xD500, "DViCO FusionHDTV5 Lite(0x18AC-0xD500)"},
{0x109E, 0x036E, 0x270F, 0xFC00, "Digitop DTT-1000(0x270F-0xFC00)"},
{0x109E, 0x036E, 0xAA00, 0x1460, "Spectra8 CardA Input0(0xAA00-0x1460)"},
{0x109E, 0x036E, 0xAA01, 0x1461, "Spectra8 CardA Input1(0xAA01-0x1461)"},
{0x109E, 0x036E, 0xAA02, 0x1462, "Spectra8 CardA Input2(0xAA02-0x1462)"},
{0x109E, 0x036E, 0xAA03, 0x1463, "Spectra8 CardA Input3(0xAA03-0x1463)"},
{0x109E, 0x036E, 0xAA04, 0x1464, "Spectra8 CardB Input0(0xAA04-0x1464)"},
{0x109E, 0x036E, 0xAA05, 0x1465, "Spectra8 CardB Input1(0xAA05-0x1465)"},
{0x109E, 0x036E, 0xAA06, 0x1466, "Spectra8 CardB Input2(0xAA06-0x1466)"},
{0x109E, 0x036E, 0xAA07, 0x1467, "Spectra8 CardB Input3(0xAA07-0x1467)"},
{0x109E, 0x036E, 0xAA08, 0x1468, "Spectra8 CardC Input0(0xAA08-0x1468)"},
{0x109E, 0x036E, 0xAA09, 0x1469, "Spectra8 CardC Input1(0xAA09-0x1469)"},
{0x109E, 0x036E, 0xAA0A, 0x146A, "Spectra8 CardC Input2(0xAA0A-0x146A)"},
{0x109E, 0x036E, 0xAA0B, 0x146B, "Spectra8 CardC Input3(0xAA0B-0x146B)"},
{0x109E, 0x036E, 0xAA0C, 0x146C, "Spectra8 CardD Input0(0xAA0C-0x146C)"},
{0x109E, 0x036E, 0xAA0D, 0x146D, "Spectra8 CardD Input1(0xAA0D-0x146D)"},
{0x109E, 0x036E, 0xAA0E, 0x146E, "Spectra8 CardD Input2(0xAA0E-0x146E)"},
{0x109E, 0x036E, 0xAA0F, 0x146F, "Spectra8 CardD Input3(0xAA0F-0x146F)"},
{0x109E, 0x036E, 0xBD11, 0x1200, "PCTV pro (TV + FM stereo receiver)(0xBD11-0x1200)"},
{0x109E, 0x036F, 0xFFFF, 0xFFFF, "Bt879 Video Capture(0x036F)"},
{0x109E, 0x036F, 0x127A, 0x0044, "Bt879 Video Capture NTSC(0x127A-0x0044)"},
{0x109E, 0x036F, 0x127A, 0x0122, "Bt879 Video Capture PAL I(0x127A-0x0122)"},
{0x109E, 0x036F, 0x127A, 0x0144, "Bt879 Video Capture NTSC(0x127A-0x0144)"},
{0x109E, 0x036F, 0x127A, 0x0222, "Bt879 Video Capture PAL BG(0x127A-0x0222)"},
{0x109E, 0x036F, 0x127A, 0x0244, "Bt879a Video Capture NTSC(0x127A-0x0244)"},
{0x109E, 0x036F, 0x127A, 0x0322, "Bt879 Video Capture NTSC(0x127A-0x0322)"},
{0x109E, 0x036F, 0x127A, 0x0422, "Bt879 Video Capture NTSC(0x127A-0x0422)"},
{0x109E, 0x036F, 0x127A, 0x1122, "Bt879 Video Capture PAL I(0x127A-0x1122)"},
{0x109E, 0x036F, 0x127A, 0x1222, "Bt879 Video Capture PAL BG(0x127A-0x1222)"},
{0x109E, 0x036F, 0x127A, 0x1322, "Bt879 Video Capture NTSC(0x127A-0x1322)"},
{0x109E, 0x036F, 0x127A, 0x1522, "Bt879a Video Capture PAL I(0x127A-0x1522)"},
{0x109E, 0x036F, 0x127A, 0x1622, "Bt879a Video Capture PAL BG(0x127A-0x1622)"},
{0x109E, 0x036F, 0x127A, 0x1722, "Bt879a Video Capture NTSC(0x127A-0x1722)"},
{0x109E, 0x036F, 0x14F1, 0x0044, "Bt879 Video Capture NTSC(0x14F1-0x0044)"},
{0x109E, 0x036F, 0x14F1, 0x0122, "Bt879 Video Capture PAL I(0x14F1-0x0122)"},
{0x109E, 0x036F, 0x14F1, 0x0144, "Bt879 Video Capture NTSC(0x14F1-0x0144)"},
{0x109E, 0x036F, 0x14F1, 0x0222, "Bt879 Video Capture PAL BG(0x14F1-0x0222)"},
{0x109E, 0x036F, 0x14F1, 0x0244, "Bt879a Video Capture NTSC(0x14F1-0x0244)"},
{0x109E, 0x036F, 0x14F1, 0x0322, "Bt879 Video Capture NTSC(0x14F1-0x0322)"},
{0x109E, 0x036F, 0x14F1, 0x0422, "Bt879 Video Capture NTSC(0x14F1-0x0422)"},
{0x109E, 0x036F, 0x14F1, 0x1122, "Bt879 Video Capture PAL I(0x14F1-0x1122)"},
{0x109E, 0x036F, 0x14F1, 0x1222, "Bt879 Video Capture PAL BG(0x14F1-0x1222)"},
{0x109E, 0x036F, 0x14F1, 0x1322, "Bt879 Video Capture NTSC(0x14F1-0x1322)"},
{0x109E, 0x036F, 0x14F1, 0x1522, "Bt879a Video Capture PAL I(0x14F1-0x1522)"},
{0x109E, 0x036F, 0x14F1, 0x1622, "Bt879a Video Capture PAL BG(0x14F1-0x1622)"},
{0x109E, 0x036F, 0x14F1, 0x1722, "Bt879a Video Capture NTSC(0x14F1-0x1722)"},
{0x109E, 0x036F, 0x1851, 0x1850, "FlyVideo'98 - Video(0x1851-0x1850)"},
{0x109E, 0x036F, 0x1851, 0x1851, "FlyVideo II(0x1851-0x1851)"},
{0x109E, 0x036F, 0x1852, 0x1852, "FlyVideo'98 - Video (with FM Tuner)(0x1852-0x1852)"},
{0x109E, 0x0370, 0xFFFF, 0xFFFF, "Bt880 Video Capture(0x0370)"},
{0x109E, 0x0370, 0x1851, 0x1850, "FlyVideo'98(0x1851-0x1850)"},
{0x109E, 0x0370, 0x1851, 0x1851, "FlyVideo'98 EZ - video(0x1851-0x1851)"},
{0x109E, 0x0370, 0x1852, 0x1852, "FlyVideo'98 (with FM Tuner)(0x1852-0x1852)"},
{0x109E, 0x0878, 0xFFFF, 0xFFFF, "Bt878 Audio Capture(0x0878)"},
{0x109E, 0x0878, 0x0000, 0x0001, "Euresys Picolo PCIe(0x0000-0x0001)"},
{0x109E, 0x0878, 0x0000, 0x0002, "Euresys PICOLO Pro 2 (Audio Section)(0x0000-0x0002)"},
{0x109E, 0x0878, 0x0000, 0x0004, "Euresys PICOLO Pro 3E (Audio Section)(0x0000-0x0004)"},
{0x109E, 0x0878, 0x0070, 0x13EB, "WinTV Series(0x0070-0x13EB)"},
{0x109E, 0x0878, 0x0070, 0xFF01, "Viewcast Osprey 200(0x0070-0xFF01)"},
{0x109E, 0x0878, 0x0071, 0x0101, "DigiTV PCI(0x0071-0x0101)"},
{0x109E, 0x0878, 0x1002, 0x0001, "TV-Wonder(0x1002-0x0001)"},
{0x109E, 0x0878, 0x1002, 0x0003, "TV-Wonder/VE(0x1002-0x0003)"},
{0x109E, 0x0878, 0x11BD, 0x0012, "PCTV pro (TV + FM stereo receiver, audio section)(0x11BD-0x0012)"},
{0x109E, 0x0878, 0x11BD, 0x001C, "PCTV Sat (DBC receiver)(0x11BD-0x001C)"},
{0x109E, 0x0878, 0x127A, 0x0001, "Bt878 Video Capture (Audio Section)(0x127A-0x0001)"},
{0x109E, 0x0878, 0x127A, 0x0002, "Bt878 Video Capture (Audio Section)(0x127A-0x0002)"},
{0x109E, 0x0878, 0x127A, 0x0003, "Bt878 Video Capture (Audio Section)(0x127A-0x0003)"},
{0x109E, 0x0878, 0x127A, 0x0048, "Bt878 Video Capture (Audio Section)(0x127A-0x0048)"},
{0x109E, 0x0878, 0x13E9, 0x0070, "Win/TV (Audio Section)(0x13E9-0x0070)"},
{0x109E, 0x0878, 0x144F, 0x3000, "MagicTView CPH060 - Audio(0x144F-0x3000)"},
{0x109E, 0x0878, 0x1461, 0x0002, "Avermedia PCTV98 Audio Capture(0x1461-0x0002)"},
{0x109E, 0x0878, 0x1461, 0x0003, "UltraTV PCI 350(0x1461-0x0003)"},
{0x109E, 0x0878, 0x1461, 0x0004, "AVerTV WDM Audio Capture(0x1461-0x0004)"},
{0x109E, 0x0878, 0x1461, 0x0761, "AVerTV DVB-T(0x1461-0x0761)"},
{0x109E, 0x0878, 0x1461, 0x0771, "AverMedia AVerTV DVB-T 771(0x1461-0x0771)"},
{0x109E, 0x0878, 0x14F1, 0x0001, "Bt878 Video Capture (Audio Section)(0x14F1-0x0001)"},
{0x109E, 0x0878, 0x14F1, 0x0002, "Bt878 Video Capture (Audio Section)(0x14F1-0x0002)"},
{0x109E, 0x0878, 0x14F1, 0x0003, "Bt878 Video Capture (Audio Section)(0x14F1-0x0003)"},
{0x109E, 0x0878, 0x14F1, 0x0048, "Bt878 Video Capture (Audio Section)(0x14F1-0x0048)"},
{0x109E, 0x0878, 0x1805, 0x0101, "Euresys PICOLO Tetra (Audio Section)(0x1805-0x0101)"},
{0x109E, 0x0878, 0x1805, 0x0102, "Euresys PICOLO Tetra (Audio Section)(0x1805-0x0102)"},
{0x109E, 0x0878, 0x1805, 0x0103, "Euresys PICOLO Tetra (Audio Section)(0x1805-0x0103)"},
{0x109E, 0x0878, 0x1805, 0x0104, "Euresys PICOLO Tetra (Audio Section)(0x1805-0x0104)"},
{0x109E, 0x0878, 0x1805, 0x0105, "Euresys PICOLO Tetra (Audio Section)(0x1805-0x0105)"},
{0x109E, 0x0878, 0x1805, 0x0106, "Euresys PICOLO Tetra (Audio Section)(0x1805-0x0106)"},
{0x109E, 0x0878, 0x1805, 0x0107, "Euresys PICOLO Tetra (Audio Section)(0x1805-0x0107)"},
{0x109E, 0x0878, 0x1805, 0x0108, "Euresys PICOLO Tetra (Audio Section)(0x1805-0x0108)"},
{0x109E, 0x0878, 0x1805, 0x0201, "Euresys PICOLO Tetra-X (Audio Section)(0x1805-0x0201)"},
{0x109E, 0x0878, 0x1805, 0x0202, "Euresys PICOLO Tetra-X (Audio Section)(0x1805-0x0202)"},
{0x109E, 0x0878, 0x1805, 0x0203, "Euresys PICOLO Tetra-X (Audio Section)(0x1805-0x0203)"},
{0x109E, 0x0878, 0x1805, 0x0204, "Euresys PICOLO Tetra-X (Audio Section)(0x1805-0x0204)"},
{0x109E, 0x0878, 0x1805, 0x0401, "Euresys PICOLO Tymo (Audio Section)(0x1805-0x0401)"},
{0x109E, 0x0878, 0x1805, 0x0402, "Euresys PICOLO Tymo (Audio Section)(0x1805-0x0402)"},
{0x109E, 0x0878, 0x1805, 0x0403, "Euresys PICOLO Tymo (Audio Section)(0x1805-0x0403)"},
{0x109E, 0x0878, 0x1805, 0x0404, "Euresys PICOLO Tymo (Audio Section)(0x1805-0x0404)"},
{0x109E, 0x0878, 0x1805, 0x1001, "Euresys PICOLO Junior 4 (Audio Section)(0x1805-0x1001)"},
{0x109E, 0x0878, 0x1822, 0x0001, "VisionPlus DVB Card(0x1822-0x0001)"},
{0x109E, 0x0878, 0x18AC, 0xD500, "DViCO FusionHDTV5 Lite(0x18AC-0xD500)"},
{0x109E, 0x0878, 0x270F, 0xFC00, "Digitop DTT-1000(0x270F-0xFC00)"},
{0x109E, 0x0878, 0xBD11, 0x1200, "PCTV pro (TV + FM stereo receiver, audio section)(0xBD11-0x1200)"},
{0x109E, 0x0879, 0xFFFF, 0xFFFF, "Bt879 Audio Capture(0x0879)"},
{0x109E, 0x0879, 0x127A, 0x0044, "Bt879 Video Capture (Audio Section)(0x127A-0x0044)"},
{0x109E, 0x0879, 0x127A, 0x0122, "Bt879 Video Capture (Audio Section)(0x127A-0x0122)"},
{0x109E, 0x0879, 0x127A, 0x0144, "Bt879 Video Capture (Audio Section)(0x127A-0x0144)"},
{0x109E, 0x0879, 0x127A, 0x0222, "Bt879 Video Capture (Audio Section)(0x127A-0x0222)"},
{0x109E, 0x0879, 0x127A, 0x0244, "Bt879 Video Capture (Audio Section)(0x127A-0x0244)"},
{0x109E, 0x0879, 0x127A, 0x0322, "Bt879 Video Capture (Audio Section)(0x127A-0x0322)"},
{0x109E, 0x0879, 0x127A, 0x0422, "Bt879 Video Capture (Audio Section)(0x127A-0x0422)"},
{0x109E, 0x0879, 0x127A, 0x1122, "Bt879 Video Capture (Audio Section)(0x127A-0x1122)"},
{0x109E, 0x0879, 0x127A, 0x1222, "Bt879 Video Capture (Audio Section)(0x127A-0x1222)"},
{0x109E, 0x0879, 0x127A, 0x1322, "Bt879 Video Capture (Audio Section)(0x127A-0x1322)"},
{0x109E, 0x0879, 0x127A, 0x1522, "Bt879 Video Capture (Audio Section)(0x127A-0x1522)"},
{0x109E, 0x0879, 0x127A, 0x1622, "Bt879 Video Capture (Audio Section)(0x127A-0x1622)"},
{0x109E, 0x0879, 0x127A, 0x1722, "Bt879 Video Capture (Audio Section)(0x127A-0x1722)"},
{0x109E, 0x0879, 0x14F1, 0x0044, "Bt879 Video Capture (Audio Section)(0x14F1-0x0044)"},
{0x109E, 0x0879, 0x14F1, 0x0122, "Bt879 Video Capture (Audio Section)(0x14F1-0x0122)"},
{0x109E, 0x0879, 0x14F1, 0x0144, "Bt879 Video Capture (Audio Section)(0x14F1-0x0144)"},
{0x109E, 0x0879, 0x14F1, 0x0222, "Bt879 Video Capture (Audio Section)(0x14F1-0x0222)"},
{0x109E, 0x0879, 0x14F1, 0x0244, "Bt879 Video Capture (Audio Section)(0x14F1-0x0244)"},
{0x109E, 0x0879, 0x14F1, 0x0322, "Bt879 Video Capture (Audio Section)(0x14F1-0x0322)"},
{0x109E, 0x0879, 0x14F1, 0x0422, "Bt879 Video Capture (Audio Section)(0x14F1-0x0422)"},
{0x109E, 0x0879, 0x14F1, 0x1122, "Bt879 Video Capture (Audio Section)(0x14F1-0x1122)"},
{0x109E, 0x0879, 0x14F1, 0x1222, "Bt879 Video Capture (Audio Section)(0x14F1-0x1222)"},
{0x109E, 0x0879, 0x14F1, 0x1322, "Bt879 Video Capture (Audio Section)(0x14F1-0x1322)"},
{0x109E, 0x0879, 0x14F1, 0x1522, "Bt879 Video Capture (Audio Section)(0x14F1-0x1522)"},
{0x109E, 0x0879, 0x14F1, 0x1622, "Bt879 Video Capture (Audio Section)(0x14F1-0x1622)"},
{0x109E, 0x0879, 0x14F1, 0x1722, "Bt879 Video Capture (Audio Section)(0x14F1-0x1722)"},
{0x109E, 0x0880, 0xFFFF, 0xFFFF, "Bt880 Audio Capture(0x0880)"},
{0x109E, 0x2115, 0xFFFF, 0xFFFF, "BtV 2115 Mediastream controller(0x2115)"},
{0x109E, 0x2125, 0xFFFF, 0xFFFF, "BtV 2125 Mediastream controller(0x2125)"},
{0x109E, 0x2164, 0xFFFF, 0xFFFF, "BtV 2164(0x2164)"},
{0x109E, 0x2165, 0xFFFF, 0xFFFF, "BtV 2165(0x2165)"},
{0x109E, 0x8230, 0xFFFF, 0xFFFF, "Bt8230 ATM Segment/Reassembly Ctrlr (SRC)(0x8230)"},
{0x109E, 0x8472, 0xFFFF, 0xFFFF, "Bt8472(0x8472)"},
{0x109E, 0x8474, 0xFFFF, 0xFFFF, "Bt8474(0x8474)"},
}; /* pci_vid_109E[] */

static pci_id_t const pci_vid_109F[] = {
{0x109F, 0xFFFF, 0xFFFF, 0xFFFF, "Trigem Computer Inc.(0x109F)"},
}; /* pci_vid_109F[] */

static pci_id_t const pci_vid_10A0[] = {
{0x10A0, 0xFFFF, 0xFFFF, 0xFFFF, "Meidensha Corporation(0x10A0)"},
}; /* pci_vid_10A0[] */

static pci_id_t const pci_vid_10A1[] = {
{0x10A1, 0xFFFF, 0xFFFF, 0xFFFF, "Juko Electronics Ind. Co. Ltd(0x10A1)"},
}; /* pci_vid_10A1[] */

static pci_id_t const pci_vid_10A2[] = {
{0x10A2, 0xFFFF, 0xFFFF, 0xFFFF, "Quantum Corporation(0x10A2)"},
}; /* pci_vid_10A2[] */

static pci_id_t const pci_vid_10A3[] = {
{0x10A3, 0xFFFF, 0xFFFF, 0xFFFF, "Everex Systems Inc(0x10A3)"},
}; /* pci_vid_10A3[] */

static pci_id_t const pci_vid_10A4[] = {
{0x10A4, 0xFFFF, 0xFFFF, 0xFFFF, "Globe Manufacturing Sales(0x10A4)"},
}; /* pci_vid_10A4[] */

static pci_id_t const pci_vid_10A5[] = {
{0x10A5, 0xFFFF, 0xFFFF, 0xFFFF, "Smart Link Ltd.(0x10A5)"},
{0x10A5, 0x3052, 0xFFFF, 0xFFFF, "SmartPCI562 56K Modem(0x3052)"},
{0x10A5, 0x5449, 0xFFFF, 0xFFFF, "SmartPCI561 modem(0x5449)"},
}; /* pci_vid_10A5[] */

static pci_id_t const pci_vid_10A6[] = {
{0x10A6, 0xFFFF, 0xFFFF, 0xFFFF, "Informtech Industrial Ltd.(0x10A6)"},
}; /* pci_vid_10A6[] */

static pci_id_t const pci_vid_10A7[] = {
{0x10A7, 0xFFFF, 0xFFFF, 0xFFFF, "Benchmarq Microelectronics(0x10A7)"},
}; /* pci_vid_10A7[] */

static pci_id_t const pci_vid_10A8[] = {
{0x10A8, 0xFFFF, 0xFFFF, 0xFFFF, "Sierra Semiconductor(0x10A8)"},
{0x10A8, 0x0000, 0xFFFF, 0xFFFF, "STB Horizon 64(0x0000)"},
}; /* pci_vid_10A8[] */

static pci_id_t const pci_vid_10A9[] = {
{0x10A9, 0xFFFF, 0xFFFF, 0xFFFF, "Silicon Graphics Intl. Corp.(0x10A9)"},
{0x10A9, 0x0001, 0xFFFF, 0xFFFF, "Crosstalk to PCI Bridge(0x0001)"},
{0x10A9, 0x0002, 0xFFFF, 0xFFFF, "Linc I/O controller(0x0002)"},
{0x10A9, 0x0003, 0xFFFF, 0xFFFF, "IOC3 I/O controller(0x0003)"},
{0x10A9, 0x0004, 0xFFFF, 0xFFFF, "O2 MACE(0x0004)"},
{0x10A9, 0x0005, 0xFFFF, 0xFFFF, "RAD Audio(0x0005)"},
{0x10A9, 0x0006, 0xFFFF, 0xFFFF, "HPCEX(0x0006)"},
{0x10A9, 0x0007, 0xFFFF, 0xFFFF, "RPCEX(0x0007)"},
{0x10A9, 0x0008, 0xFFFF, 0xFFFF, "DiVO VIP(0x0008)"},
{0x10A9, 0x0009, 0xFFFF, 0xFFFF, "AceNIC Gigabit Ethernet(0x0009)"},
{0x10A9, 0x0009, 0x10A9, 0x8002, "AceNIC Gigabit Ethernet(0x10A9-0x8002)"},
{0x10A9, 0x0010, 0xFFFF, 0xFFFF, "AMP Video I/O(0x0010)"},
{0x10A9, 0x0011, 0xFFFF, 0xFFFF, "GRIP(0x0011)"},
{0x10A9, 0x0012, 0xFFFF, 0xFFFF, "SGH PSHAC GSN(0x0012)"},
{0x10A9, 0x0208, 0xFFFF, 0xFFFF, "SSIM1 SAS Adapter(0x0208)"},
{0x10A9, 0x1001, 0xFFFF, 0xFFFF, "Magic Carpet(0x1001)"},
{0x10A9, 0x1002, 0xFFFF, 0xFFFF, "Lithium(0x1002)"},
{0x10A9, 0x1003, 0xFFFF, 0xFFFF, "Dual JPEG 1(0x1003)"},
{0x10A9, 0x1004, 0xFFFF, 0xFFFF, "Dual JPEG 2(0x1004)"},
{0x10A9, 0x1005, 0xFFFF, 0xFFFF, "Dual JPEG 3(0x1005)"},
{0x10A9, 0x1006, 0xFFFF, 0xFFFF, "Dual JPEG 4(0x1006)"},
{0x10A9, 0x1007, 0xFFFF, 0xFFFF, "Dual JPEG 5(0x1007)"},
{0x10A9, 0x1008, 0xFFFF, 0xFFFF, "Cesium(0x1008)"},
{0x10A9, 0x100A, 0xFFFF, 0xFFFF, "IOC4 I/O controller(0x100A)"},
{0x10A9, 0x1504, 0xFFFF, 0xFFFF, "SSIM1 Fibre Channel Adapter(0x1504)"},
{0x10A9, 0x2001, 0xFFFF, 0xFFFF, "Fibre Channel(0x2001)"},
{0x10A9, 0x2002, 0xFFFF, 0xFFFF, "ASDE(0x2002)"},
{0x10A9, 0x4001, 0xFFFF, 0xFFFF, "TIO-CE PCI Express Bridge(0x4001)"},
{0x10A9, 0x4002, 0xFFFF, 0xFFFF, "TIO-CE PCI Express Port(0x4002)"},
{0x10A9, 0x8001, 0xFFFF, 0xFFFF, "O2 1394(0x8001)"},
{0x10A9, 0x8002, 0xFFFF, 0xFFFF, "G-net NT(0x8002)"},
{0x10A9, 0x802B, 0xFFFF, 0xFFFF, "REACT external interrupt controller(0x802B)"},
}; /* pci_vid_10A9[] */

static pci_id_t const pci_vid_10AA[] = {
{0x10AA, 0xFFFF, 0xFFFF, 0xFFFF, "ACC Microelectronics(0x10AA)"},
{0x10AA, 0x0000, 0xFFFF, 0xFFFF, "ACCM 2188(0x0000)"},
{0x10AA, 0x2051, 0xFFFF, 0xFFFF, "2051 CPU bridge(0x2051)"},
{0x10AA, 0x5842, 0xFFFF, 0xFFFF, "2051 ISA bridge(0x5842)"},
}; /* pci_vid_10AA[] */

static pci_id_t const pci_vid_10AB[] = {
{0x10AB, 0xFFFF, 0xFFFF, 0xFFFF, "Digicom(0x10AB)"},
}; /* pci_vid_10AB[] */

static pci_id_t const pci_vid_10AC[] = {
{0x10AC, 0xFFFF, 0xFFFF, 0xFFFF, "Honeywell IAC(0x10AC)"},
}; /* pci_vid_10AC[] */

static pci_id_t const pci_vid_10AD[] = {
{0x10AD, 0xFFFF, 0xFFFF, 0xFFFF, "Symphony Labs(0x10AD)"},
{0x10AD, 0x0001, 0xFFFF, 0xFFFF, "W83769F(0x0001)"},
{0x10AD, 0x0003, 0xFFFF, 0xFFFF, "SL82C103(0x0003)"},
{0x10AD, 0x0005, 0xFFFF, 0xFFFF, "SL82C105(0x0005)"},
{0x10AD, 0x0103, 0xFFFF, 0xFFFF, "SL82c103(0x0103)"},
{0x10AD, 0x0105, 0xFFFF, 0xFFFF, "SL82c105(0x0105)"},
{0x10AD, 0x0565, 0xFFFF, 0xFFFF, "W83C553F/W83C554F(0x0565)"},
}; /* pci_vid_10AD[] */

static pci_id_t const pci_vid_10AE[] = {
{0x10AE, 0xFFFF, 0xFFFF, 0xFFFF, "Cornerstone Technology(0x10AE)"},
}; /* pci_vid_10AE[] */

static pci_id_t const pci_vid_10AF[] = {
{0x10AF, 0xFFFF, 0xFFFF, 0xFFFF, "Micro Computer Systems Inc(0x10AF)"},
}; /* pci_vid_10AF[] */

static pci_id_t const pci_vid_10B0[] = {
{0x10B0, 0xFFFF, 0xFFFF, 0xFFFF, "CardExpert Technology(0x10B0)"},
}; /* pci_vid_10B0[] */

static pci_id_t const pci_vid_10B1[] = {
{0x10B1, 0xFFFF, 0xFFFF, 0xFFFF, "Cabletron Systems Inc(0x10B1)"},
}; /* pci_vid_10B1[] */

static pci_id_t const pci_vid_10B2[] = {
{0x10B2, 0xFFFF, 0xFFFF, 0xFFFF, "Raytheon Company(0x10B2)"},
}; /* pci_vid_10B2[] */

static pci_id_t const pci_vid_10B3[] = {
{0x10B3, 0xFFFF, 0xFFFF, 0xFFFF, "Databook Inc(0x10B3)"},
{0x10B3, 0x3106, 0xFFFF, 0xFFFF, "DB87144(0x3106)"},
{0x10B3, 0xB106, 0xFFFF, 0xFFFF, "DB87144(0xB106)"},
}; /* pci_vid_10B3[] */

static pci_id_t const pci_vid_10B4[] = {
{0x10B4, 0xFFFF, 0xFFFF, 0xFFFF, "STB Systems Inc(0x10B4)"},
{0x10B4, 0x1B1D, 0xFFFF, 0xFFFF, "Velocity 128 3D(0x1B1D)"},
{0x10B4, 0x1B1D, 0x10B4, 0x237E, "Velocity 4400(0x10B4-0x237E)"},
}; /* pci_vid_10B4[] */

static pci_id_t const pci_vid_10B5[] = {
{0x10B5, 0xFFFF, 0xFFFF, 0xFFFF, "PLX Technology, Inc.(0x10B5)"},
{0x10B5, 0x0001, 0xFFFF, 0xFFFF, "i960 PCI bus interface(0x0001)"},
{0x10B5, 0x0557, 0xFFFF, 0xFFFF, "PCI9030 32-bit 33MHz PCI <-> IOBus Bridge(0x0557)"},
{0x10B5, 0x0557, 0x10B5, 0x9030, "Digium Tormenta 2 T400P-SS7 or E400P-SS7 Quad T1 or E1 PCI card(0x10B5-0x9030)"},
{0x10B5, 0x1000, 0xFFFF, 0xFFFF, "PCI9030 32-bit 33MHz PCI <-> IOBus Bridge(0x1000)"},
{0x10B5, 0x1000, 0x10B5, 0x9030, "ATCOM AT400P Quad T1 PCI card(0x10B5-0x9030)"},
{0x10B5, 0x1024, 0xFFFF, 0xFFFF, "Acromag, Inc. IndustryPack Carrier Card(0x1024)"},
{0x10B5, 0x1042, 0xFFFF, 0xFFFF, "Brandywine / jxi2, Inc. - PMC-SyncClock32, IRIG A & B, Nasa 36(0x1042)"},
{0x10B5, 0x106A, 0xFFFF, 0xFFFF, "Dual OX16C952 4 port serial adapter [Megawolf Romulus/4](0x106A)"},
{0x10B5, 0x1076, 0xFFFF, 0xFFFF, "VScom 800 8 port serial adaptor(0x1076)"},
{0x10B5, 0x1077, 0xFFFF, 0xFFFF, "VScom 400 4 port serial adaptor(0x1077)"},
{0x10B5, 0x1078, 0xFFFF, 0xFFFF, "VScom 210 2 port serial and 1 port parallel adaptor(0x1078)"},
{0x10B5, 0x1103, 0xFFFF, 0xFFFF, "VScom 200 2 port serial adaptor(0x1103)"},
{0x10B5, 0x1146, 0xFFFF, 0xFFFF, "VScom 010 1 port parallel adaptor(0x1146)"},
{0x10B5, 0x1147, 0xFFFF, 0xFFFF, "VScom 020 2 port parallel adaptor(0x1147)"},
{0x10B5, 0x2000, 0xFFFF, 0xFFFF, "PCI9030 32-bit 33MHz PCI <-> IOBus Bridge(0x2000)"},
{0x10B5, 0x2000, 0x10B5, 0x9030, "ATCOM AE400P Quad E1 PCI card(0x10B5-0x9030)"},
{0x10B5, 0x2300, 0xFFFF, 0xFFFF, "Euresys DOMINO Gamma(0x2300)"},
{0x10B5, 0x2374, 0xFFFF, 0xFFFF, "Euresys DOMINO Alpha(0x2374)"},
{0x10B5, 0x2491, 0xFFFF, 0xFFFF, "Euresys GRABLINK Value(0x2491)"},
{0x10B5, 0x2493, 0xFFFF, 0xFFFF, "Euresys GRABLINK Expert(0x2493)"},
{0x10B5, 0x2540, 0xFFFF, 0xFFFF, "IXXAT CAN-Interface PC-I 04/PCI(0x2540)"},
{0x10B5, 0x2724, 0xFFFF, 0xFFFF, "Thales PCSM Security Card(0x2724)"},
{0x10B5, 0x3376, 0xFFFF, 0xFFFF, "Cosateq 4 Port CAN Card(0x3376)"},
{0x10B5, 0x4000, 0xFFFF, 0xFFFF, "PCI9030 32-bit 33MHz PCI <-> IOBus Bridge(0x4000)"},
{0x10B5, 0x4000, 0x10B5, 0x9030, "Tormenta 3 Varion V400P/ATCOM TE400P Quad E1/T1/J1 PCI card(0x10B5-0x9030)"},
{0x10B5, 0x4001, 0xFFFF, 0xFFFF, "PCI9030 32-bit 33MHz PCI <-> IOBus Bridge(0x4001)"},
{0x10B5, 0x4001, 0x10B5, 0x9030, "ATCOM A400PE Quad E1 PCI card(0x10B5-0x9030)"},
{0x10B5, 0x4002, 0xFFFF, 0xFFFF, "PCI9030 32-bit 33MHz PCI <-> IOBus Bridge(0x4002)"},
{0x10B5, 0x4002, 0x10B5, 0x9030, "ATCOM A400PT Quad T1 PCI card(0x10B5-0x9030)"},
{0x10B5, 0x6140, 0xFFFF, 0xFFFF, "PCI6140 32-bit 33MHz PCI-to-PCI Bridge(0x6140)"},
{0x10B5, 0x6150, 0xFFFF, 0xFFFF, "PCI6150 32-bit 33MHz PCI-to-PCI Bridge(0x6150)"},
{0x10B5, 0x6152, 0xFFFF, 0xFFFF, "PCI6152 32-bit 66MHz PCI-to-PCI Bridge(0x6152)"},
{0x10B5, 0x6154, 0xFFFF, 0xFFFF, "PCI6154 64-bit 66MHz PCI-to-PCI Bridge(0x6154)"},
{0x10B5, 0x6254, 0xFFFF, 0xFFFF, "PCI6254 64-bit 66MHz PCI-to-PCI Bridge(0x6254)"},
{0x10B5, 0x6466, 0xFFFF, 0xFFFF, "PCI6466 64-bit 66MHz PCI-to-PCI Bridge(0x6466)"},
{0x10B5, 0x6520, 0xFFFF, 0xFFFF, "PCI6520 64-bit 133MHz PCI-X-to-PCI-X Bridge(0x6520)"},
{0x10B5, 0x6540, 0xFFFF, 0xFFFF, "PCI6540 64-bit 133MHz PCI-X-to-PCI-X Bridge(0x6540)"},
{0x10B5, 0x6540, 0x1775, 0x1100, "CR11 Single Board Computer(0x1775-0x1100)"},
{0x10B5, 0x6540, 0x4C53, 0x10E0, "PSL09 PrPMC(0x4C53-0x10E0)"},
{0x10B5, 0x6541, 0xFFFF, 0xFFFF, "PCI6540/6466 PCI-PCI bridge (non-transparent mode, primary side)(0x6541)"},
{0x10B5, 0x6541, 0x1775, 0x1100, "CR11 Single Board Computer(0x1775-0x1100)"},
{0x10B5, 0x6541, 0x4C53, 0x10E0, "PSL09 PrPMC(0x4C53-0x10E0)"},
{0x10B5, 0x6542, 0xFFFF, 0xFFFF, "PCI6540/6466 PCI-PCI bridge (non-transparent mode, secondary side)(0x6542)"},
{0x10B5, 0x6542, 0x1775, 0x1100, "CR11 Single Board Computer(0x1775-0x1100)"},
{0x10B5, 0x6542, 0x4C53, 0x10E0, "PSL09 PrPMC(0x4C53-0x10E0)"},
{0x10B5, 0x8111, 0xFFFF, 0xFFFF, "PEX 8111 PCI Express-to-PCI Bridge(0x8111)"},
{0x10B5, 0x8112, 0xFFFF, 0xFFFF, "PEX8112 x1 Lane PCI Express-to-PCI Bridge(0x8112)"},
{0x10B5, 0x8114, 0xFFFF, 0xFFFF, "PEX 8114 PCI Express-to-PCI/PCI-X Bridge(0x8114)"},
{0x10B5, 0x8311, 0xFFFF, 0xFFFF, "PEX8311 x1 Lane PCI Express-to-Generic Local Bus Bridge(0x8311)"},
{0x10B5, 0x8505, 0xFFFF, 0xFFFF, "PEX 8505 5-lane, 5-port PCI Express Switch(0x8505)"},
{0x10B5, 0x8508, 0xFFFF, 0xFFFF, "PEX 8508 8-lane, 5-port PCI Express Switch(0x8508)"},
{0x10B5, 0x8509, 0xFFFF, 0xFFFF, "PEX 8509 8-lane, 8-port PCI Express Switch(0x8509)"},
{0x10B5, 0x8512, 0xFFFF, 0xFFFF, "PEX 8512 12-lane, 5-port PCI Express Switch(0x8512)"},
{0x10B5, 0x8516, 0xFFFF, 0xFFFF, "PEX 8516  Versatile PCI Express Switch(0x8516)"},
{0x10B5, 0x8517, 0xFFFF, 0xFFFF, "PEX 8517 16-lane, 5-port PCI Express Switch(0x8517)"},
{0x10B5, 0x8518, 0xFFFF, 0xFFFF, "PEX 8518 16-lane, 5-port PCI Express Switch(0x8518)"},
{0x10B5, 0x8524, 0xFFFF, 0xFFFF, "PEX 8524 24-lane, 6-port PCI Express Switch(0x8524)"},
{0x10B5, 0x8525, 0xFFFF, 0xFFFF, "PEX 8525 24-lane, 5-port PCI Express Switch(0x8525)"},
{0x10B5, 0x8532, 0xFFFF, 0xFFFF, "PEX 8532  Versatile PCI Express Switch(0x8532)"},
{0x10B5, 0x8533, 0xFFFF, 0xFFFF, "PEX 8533 32-lane, 6-port PCI Express Switch(0x8533)"},
{0x10B5, 0x8547, 0xFFFF, 0xFFFF, "PEX 8547 48-lane, 3-port PCI Express Switch(0x8547)"},
{0x10B5, 0x8548, 0xFFFF, 0xFFFF, "PEX 8548 48-lane, 9-port PCI Express Switch(0x8548)"},
{0x10B5, 0x8603, 0xFFFF, 0xFFFF, "PEX 8603 3-lane, 3-Port PCI Express Gen 2 (5.0 GT/s) Switch(0x8603)"},
{0x10B5, 0x8604, 0xFFFF, 0xFFFF, "PEX 8604 4-lane, 4-Port PCI Express Gen 2 (5.0 GT/s) Switch(0x8604)"},
{0x10B5, 0x8605, 0xFFFF, 0xFFFF, "PEX 8605 PCI Express 4-port Gen2 Switch(0x8605)"},
{0x10B5, 0x8606, 0xFFFF, 0xFFFF, "PEX 8606 6 Lane, 6 Port PCI Express Gen 2 (5.0 GT/s) Switch(0x8606)"},
{0x10B5, 0x8608, 0xFFFF, 0xFFFF, "PEX 8608 8-lane, 8-Port PCI Express Gen 2 (5.0 GT/s) Switch(0x8608)"},
{0x10B5, 0x8609, 0xFFFF, 0xFFFF, "PEX 8609 8-lane, 8-Port PCI Express Gen 2 (5.0 GT/s) Switch with DMA(0x8609)"},
{0x10B5, 0x8612, 0xFFFF, 0xFFFF, "PEX 8612 12-lane, 4-Port PCI Express Gen 2 (5.0 GT/s) Switch(0x8612)"},
{0x10B5, 0x8613, 0xFFFF, 0xFFFF, "PEX 8613 12-lane, 3-Port PCI Express Gen 2 (5.0 GT/s) Switch(0x8613)"},
{0x10B5, 0x8614, 0xFFFF, 0xFFFF, "PEX 8614 12-lane, 12-Port PCI Express Gen 2 (5.0 GT/s) Switch(0x8614)"},
{0x10B5, 0x8615, 0xFFFF, 0xFFFF, "PEX 8615 12-lane, 12-Port PCI Express Gen 2 (5.0 GT/s) Switch with DMA(0x8615)"},
{0x10B5, 0x8616, 0xFFFF, 0xFFFF, "PEX 8616 16-lane, 4-Port PCI Express Gen 2 (5.0 GT/s) Switch(0x8616)"},
{0x10B5, 0x8617, 0xFFFF, 0xFFFF, "PEX 8617 16-lane, 4-Port PCI Express Gen 2 (5.0 GT/s) Switch with P2P(0x8617)"},
{0x10B5, 0x8618, 0xFFFF, 0xFFFF, "PEX 8618 16-lane, 16-Port PCI Express Gen 2 (5.0 GT/s) Switch(0x8618)"},
{0x10B5, 0x8619, 0xFFFF, 0xFFFF, "PEX 8619 16-lane, 16-Port PCI Express Gen 2 (5.0 GT/s) Switch with DMA(0x8619)"},
{0x10B5, 0x8624, 0xFFFF, 0xFFFF, "PEX 8624 24-lane, 6-Port PCI Express Gen 2 (5.0 GT/s) Switch [ExpressLane](0x8624)"},
{0x10B5, 0x8624, 0x13A3, 0x1845, "DX1845 Acceleration Card(0x13A3-0x1845)"},
{0x10B5, 0x8625, 0xFFFF, 0xFFFF, "PEX 8625 24-lane, 24-Port PCI Express Gen 2 (5.0 GT/s) Switch(0x8625)"},
{0x10B5, 0x8632, 0xFFFF, 0xFFFF, "PEX 8632 32-lane, 12-Port PCI Express Gen 2 (5.0 GT/s) Switch(0x8632)"},
{0x10B5, 0x8636, 0xFFFF, 0xFFFF, "PEX 8636 36-lane, 24-Port PCI Express Gen 2 (5.0 GT/s) Switch(0x8636)"},
{0x10B5, 0x8647, 0xFFFF, 0xFFFF, "PEX 8647 48-Lane, 3-Port PCI Express Gen 2 (5.0 GT/s) Switch(0x8647)"},
{0x10B5, 0x8648, 0xFFFF, 0xFFFF, "PEX 8648 48-lane, 12-Port PCI Express Gen 2 (5.0 GT/s) Switch(0x8648)"},
{0x10B5, 0x8649, 0xFFFF, 0xFFFF, "PEX 8649 48-lane, 12-Port PCI Express Gen 2 (5.0 GT/s) Switch(0x8649)"},
{0x10B5, 0x8664, 0xFFFF, 0xFFFF, "PEX 8664 64-lane, 16-Port PCI Express Gen 2 (5.0 GT/s) Switch(0x8664)"},
{0x10B5, 0x8680, 0xFFFF, 0xFFFF, "PEX 8680 80-lane, 20-Port PCI Express Gen 2 (5.0 GT/s) Multi-Root Switch(0x8680)"},
{0x10B5, 0x8696, 0xFFFF, 0xFFFF, "PEX 8696 96-lane, 24-Port PCI Express Gen 2 (5.0 GT/s) Multi-Root Switch(0x8696)"},
{0x10B5, 0x8717, 0xFFFF, 0xFFFF, "PEX 8717 16-lane, 8-Port PCI Express Gen 3 (8.0 GT/s) Switch with DMA(0x8717)"},
{0x10B5, 0x8718, 0xFFFF, 0xFFFF, "PEX 8718 16-Lane, 5-Port PCI Express Gen 3 (8.0 GT/s) Switch(0x8718)"},
{0x10B5, 0x8724, 0xFFFF, 0xFFFF, "PEX 8724 24-Lane, 6-Port PCI Express Gen 3 (8 GT/s) Switch, 19 x 19mm FCBGA(0x8724)"},
{0x10B5, 0x8724, 0x4C52, 0x9234, "LRNV9324 2-port Built-in 8643 NVMe Exchange Adapter(0x4C52-0x9234)"},
{0x10B5, 0x8724, 0x4C52, 0x9524, "LRNV9524 2-port M.2 NVMe SSD Exchange Adapter(0x4C52-0x9524)"},
{0x10B5, 0x8725, 0xFFFF, 0xFFFF, "PEX 8725 24-Lane, 10-Port PCI Express Gen 3 (8.0 GT/s) Multi-Root Switch with DMA(0x8725)"},
{0x10B5, 0x8732, 0xFFFF, 0xFFFF, "PEX 8732 32-lane, 8-Port PCI Express Gen 3 (8.0 GT/s) Switch(0x8732)"},
{0x10B5, 0x8734, 0xFFFF, 0xFFFF, "PEX 8734 32-lane, 8-Port PCI Express Gen 3 (8.0GT/s) Switch(0x8734)"},
{0x10B5, 0x8747, 0xFFFF, 0xFFFF, "PEX 8747 48-Lane, 5-Port PCI Express Gen 3 (8.0 GT/s) Switch(0x8747)"},
{0x10B5, 0x8747, 0x4C52, 0x9347, "LRNV9347L 2-port Built-in 8643 NVMe Switching Adapter(0x4C52-0x9347)"},
{0x10B5, 0x8747, 0x4C52, 0x9547, "LRNV9547 4-port M.2 NVMe SSD Exchange Adapter(0x4C52-0x9547)"},
{0x10B5, 0x8748, 0xFFFF, 0xFFFF, "PEX 8748 48-Lane, 12-Port PCI Express Gen 3 (8 GT/s) Switch, 27 x 27mm FCBGA(0x8748)"},
{0x10B5, 0x8749, 0xFFFF, 0xFFFF, "PEX 8749 48-Lane, 18-Port PCI Express Gen 3 (8.0 GT/s) Multi-Root Switch with DMA(0x8749)"},
{0x10B5, 0x8749, 0x4C52, 0x9349, "LRNV9349 8-port SFF-8643 NVMe SSD Exchange Adapter(0x4C52-0x9349)"},
{0x10B5, 0x87A0, 0xFFFF, 0xFFFF, "PEX PCI Express Switch NT0 Port Link Interface(0x87A0)"},
{0x10B5, 0x87A1, 0xFFFF, 0xFFFF, "PEX PCI Express Switch NT1 Port Link Interface(0x87A1)"},
{0x10B5, 0x87B0, 0xFFFF, 0xFFFF, "PEX PCI Express Switch NT0 Port Virtual Interface(0x87B0)"},
{0x10B5, 0x87B0, 0x1093, 0x7761, "PXIe-8830mc(0x1093-0x7761)"},
{0x10B5, 0x87B1, 0xFFFF, 0xFFFF, "PEX PCI Express Switch NT1 Port Virtual Interface(0x87B1)"},
{0x10B5, 0x87D0, 0xFFFF, 0xFFFF, "PEX PCI Express Switch DMA interface(0x87D0)"},
{0x10B5, 0x9016, 0xFFFF, 0xFFFF, "PLX 9016 8-port serial controller(0x9016)"},
{0x10B5, 0x9030, 0xFFFF, 0xFFFF, "PCI9030 32-bit 33MHz PCI <-> IOBus Bridge(0x9030)"},
{0x10B5, 0x9030, 0x10B5, 0x1205, "Becker & Hickl MSA-1000(0x10B5-0x1205)"},
{0x10B5, 0x9030, 0x10B5, 0x2695, "Hilscher CIF50-PB/DPS Profibus(0x10B5-0x2695)"},
{0x10B5, 0x9030, 0x10B5, 0x2862, "Alpermann+Velte PCL PCI LV (3V/5V): Timecode Reader Board(0x10B5-0x2862)"},
{0x10B5, 0x9030, 0x10B5, 0x2906, "Alpermann+Velte PCI TS (3V/5V): Time Synchronisation Board(0x10B5-0x2906)"},
{0x10B5, 0x9030, 0x10B5, 0x2940, "Alpermann+Velte PCL PCI D (3V/5V): Timecode Reader Board(0x10B5-0x2940)"},
{0x10B5, 0x9030, 0x10B5, 0x2977, "IXXAT iPC-I XC16/PCI CAN Board(0x10B5-0x2977)"},
{0x10B5, 0x9030, 0x10B5, 0x2978, "SH ARC-PCIu/SH ARC-PCI104/SH ARC-PCIe SOHARD ARCNET card(0x10B5-0x2978)"},
{0x10B5, 0x9030, 0x10B5, 0x3025, "Alpermann+Velte PCL PCI L (3V/5V): Timecode Reader Board(0x10B5-0x3025)"},
{0x10B5, 0x9030, 0x10B5, 0x3068, "Alpermann+Velte PCL PCI HD (3V/5V): Timecode Reader Board(0x10B5-0x3068)"},
{0x10B5, 0x9030, 0x10B5, 0x3463, "Alpermann+Velte PCL PCI D (v2) (3V/5V): Timecode Reader Board(0x10B5-0x3463)"},
{0x10B5, 0x9030, 0x10B5, 0x3591, "PLURA PCL PCI L (v2) (3.3V/5V): Time Code Reader Board(0x10B5-0x3591)"},
{0x10B5, 0x9030, 0x12FE, 0x0111, "CPCI-ASIO4 (ESD 4-port Serial Interface Board)(0x12FE-0x0111)"},
{0x10B5, 0x9030, 0x1369, 0x9C01, "VX222v2(0x1369-0x9C01)"},
{0x10B5, 0x9030, 0x1369, 0x9D01, "VX222-Mic(0x1369-0x9D01)"},
{0x10B5, 0x9030, 0x1369, 0x9D02, "VX222-Mic(0x1369-0x9D02)"},
{0x10B5, 0x9030, 0x1369, 0x9E01, "PCX924v2(0x1369-0x9E01)"},
{0x10B5, 0x9030, 0x1369, 0x9F01, "PCX924-Mic(0x1369-0x9F01)"},
{0x10B5, 0x9030, 0x1369, 0x9F02, "PCX924-Mic(0x1369-0x9F02)"},
{0x10B5, 0x9030, 0x1369, 0xA001, "PCX22v2(0x1369-0xA001)"},
{0x10B5, 0x9030, 0x1369, 0xA701, "LCM220v2(0x1369-0xA701)"},
{0x10B5, 0x9030, 0x1369, 0xA801, "LCM200(0x1369-0xA801)"},
{0x10B5, 0x9030, 0x1397, 0x3136, "4xS0-ISDN PCI Adapter(0x1397-0x3136)"},
{0x10B5, 0x9030, 0x1397, 0x3137, "S2M-E1-ISDN PCI Adapter(0x1397-0x3137)"},
{0x10B5, 0x9030, 0x1518, 0x0200, "ThinkIO-C(0x1518-0x0200)"},
{0x10B5, 0x9030, 0x15ED, 0x1002, "MCCS 8-port Serial Hot Swap(0x15ED-0x1002)"},
{0x10B5, 0x9030, 0x15ED, 0x1003, "MCCS 16-port Serial Hot Swap(0x15ED-0x1003)"},
{0x10B5, 0x9030, 0xE1C5, 0x0001, "TE1-PCI(0xE1C5-0x0001)"},
{0x10B5, 0x9030, 0xE1C5, 0x0005, "TA1-PCI(0xE1C5-0x0005)"},
{0x10B5, 0x9030, 0xE1C5, 0x0006, "TA1-PCI4(0xE1C5-0x0006)"},
{0x10B5, 0x9036, 0xFFFF, 0xFFFF, "9036(0x9036)"},
{0x10B5, 0x9050, 0xFFFF, 0xFFFF, "PCI <-> IOBus Bridge(0x9050)"},
{0x10B5, 0x9050, 0x103C, 0x10B0, "82350 PCI GPIB(0x103C-0x10B0)"},
{0x10B5, 0x9050, 0x10B5, 0x1067, "IXXAT CAN i165(0x10B5-0x1067)"},
{0x10B5, 0x9050, 0x10B5, 0x114E, "Wasco WITIO PCI168extended(0x10B5-0x114E)"},
{0x10B5, 0x9050, 0x10B5, 0x1169, "Wasco OPTOIO32standard 32 digital in, 32 digital out(0x10B5-0x1169)"},
{0x10B5, 0x9050, 0x10B5, 0x1171, "Becker & Hickl PMS-400(0x10B5-0x1171)"},
{0x10B5, 0x9050, 0x10B5, 0x1172, "IK220 (Heidenhain)(0x10B5-0x1172)"},
{0x10B5, 0x9050, 0x10B5, 0x1201, "Becker & Hickl SPC-6x0(0x10B5-0x1201)"},
{0x10B5, 0x9050, 0x10B5, 0x1202, "Becker & Hickl SPC-7x0(0x10B5-0x1202)"},
{0x10B5, 0x9050, 0x10B5, 0x1203, "Becker & Hickl MSA-300(0x10B5-0x1203)"},
{0x10B5, 0x9050, 0x10B5, 0x1206, "Becker & Hickl DCC-100(0x10B5-0x1206)"},
{0x10B5, 0x9050, 0x10B5, 0x120A, "Becker & Hickl STP-340(0x10B5-0x120A)"},
{0x10B5, 0x9050, 0x10B5, 0x2036, "SatPak GPS(0x10B5-0x2036)"},
{0x10B5, 0x9050, 0x10B5, 0x2221, "Alpermann+Velte PCL PCI LV: Timecode Reader Board(0x10B5-0x2221)"},
{0x10B5, 0x9050, 0x10B5, 0x2273, "SH ARC-PCI SOHARD ARCNET card(0x10B5-0x2273)"},
{0x10B5, 0x9050, 0x10B5, 0x2431, "Alpermann+Velte PCL PCI D: Timecode Reader Board(0x10B5-0x2431)"},
{0x10B5, 0x9050, 0x10B5, 0x2905, "Alpermann+Velte PCI TS: Time Synchronisation Board(0x10B5-0x2905)"},
{0x10B5, 0x9050, 0x10B5, 0x3196, "Goramo PLX200SYN sync serial card(0x10B5-0x3196)"},
{0x10B5, 0x9050, 0x10B5, 0x9050, "PCI-I04 PCI Passive PC/CAN Interface(0x10B5-0x9050)"},
{0x10B5, 0x9050, 0x11A9, 0x5334, "PDS4(0x11A9-0x5334)"},
{0x10B5, 0x9050, 0x12FE, 0x0001, "CAN-PCI/331 CAN bus controller(0x12FE-0x0001)"},
{0x10B5, 0x9050, 0x1369, 0x8901, "PCX11+ PCI(0x1369-0x8901)"},
{0x10B5, 0x9050, 0x1369, 0x8F01, "VX222(0x1369-0x8F01)"},
{0x10B5, 0x9050, 0x1369, 0x9401, "PCX924(0x1369-0x9401)"},
{0x10B5, 0x9050, 0x1369, 0x9501, "PCX22(0x1369-0x9501)"},
{0x10B5, 0x9050, 0x1498, 0x0362, "TPMC866 8 Channel Serial Card(0x1498-0x0362)"},
{0x10B5, 0x9050, 0x1522, 0x0001, "RockForce 4 Port V.90 Data/Fax/Voice Modem(0x1522-0x0001)"},
{0x10B5, 0x9050, 0x1522, 0x0002, "RockForce 2 Port V.90 Data/Fax/Voice Modem(0x1522-0x0002)"},
{0x10B5, 0x9050, 0x1522, 0x0003, "RockForce 6 Port V.90 Data/Fax/Voice Modem(0x1522-0x0003)"},
{0x10B5, 0x9050, 0x1522, 0x0004, "RockForce 8 Port V.90 Data/Fax/Voice Modem(0x1522-0x0004)"},
{0x10B5, 0x9050, 0x1522, 0x0010, "RockForce2000 4 Port V.90 Data/Fax/Voice Modem(0x1522-0x0010)"},
{0x10B5, 0x9050, 0x1522, 0x0020, "RockForce2000 2 Port V.90 Data/Fax/Voice Modem(0x1522-0x0020)"},
{0x10B5, 0x9050, 0x15ED, 0x1000, "Macrolink MCCS 8-port Serial(0x15ED-0x1000)"},
{0x10B5, 0x9050, 0x15ED, 0x1001, "Macrolink MCCS 16-port Serial(0x15ED-0x1001)"},
{0x10B5, 0x9050, 0x15ED, 0x1002, "Macrolink MCCS 8-port Serial Hot Swap(0x15ED-0x1002)"},
{0x10B5, 0x9050, 0x15ED, 0x1003, "Macrolink MCCS 16-port Serial Hot Swap(0x15ED-0x1003)"},
{0x10B5, 0x9050, 0x5654, 0x2036, "OpenSwitch 6 Telephony card(0x5654-0x2036)"},
{0x10B5, 0x9050, 0x5654, 0x3132, "OpenSwitch 12 Telephony card(0x5654-0x3132)"},
{0x10B5, 0x9050, 0x5654, 0x5634, "OpenLine4 Telephony Card(0x5654-0x5634)"},
{0x10B5, 0x9050, 0xD531, 0xC002, "PCIntelliCAN 2xSJA1000 CAN bus(0xD531-0xC002)"},
{0x10B5, 0x9050, 0xD84D, 0x4006, "EX-4006 1P(0xD84D-0x4006)"},
{0x10B5, 0x9050, 0xD84D, 0x4008, "EX-4008 1P EPP/ECP(0xD84D-0x4008)"},
{0x10B5, 0x9050, 0xD84D, 0x4014, "EX-4014 2P(0xD84D-0x4014)"},
{0x10B5, 0x9050, 0xD84D, 0x4018, "EX-4018 3P EPP/ECP(0xD84D-0x4018)"},
{0x10B5, 0x9050, 0xD84D, 0x4025, "EX-4025 1S(16C550) RS-232(0xD84D-0x4025)"},
{0x10B5, 0x9050, 0xD84D, 0x4027, "EX-4027 1S(16C650) RS-232(0xD84D-0x4027)"},
{0x10B5, 0x9050, 0xD84D, 0x4028, "EX-4028 1S(16C850) RS-232(0xD84D-0x4028)"},
{0x10B5, 0x9050, 0xD84D, 0x4036, "EX-4036 2S(16C650) RS-232(0xD84D-0x4036)"},
{0x10B5, 0x9050, 0xD84D, 0x4037, "EX-4037 2S(16C650) RS-232(0xD84D-0x4037)"},
{0x10B5, 0x9050, 0xD84D, 0x4038, "EX-4038 2S(16C850) RS-232(0xD84D-0x4038)"},
{0x10B5, 0x9050, 0xD84D, 0x4052, "EX-4052 1S(16C550) RS-422/485(0xD84D-0x4052)"},
{0x10B5, 0x9050, 0xD84D, 0x4053, "EX-4053 2S(16C550) RS-422/485(0xD84D-0x4053)"},
{0x10B5, 0x9050, 0xD84D, 0x4055, "EX-4055 4S(16C550) RS-232(0xD84D-0x4055)"},
{0x10B5, 0x9050, 0xD84D, 0x4058, "EX-4055 4S(16C650) RS-232(0xD84D-0x4058)"},
{0x10B5, 0x9050, 0xD84D, 0x4065, "EX-4065 8S(16C550) RS-232(0xD84D-0x4065)"},
{0x10B5, 0x9050, 0xD84D, 0x4068, "EX-4068 8S(16C650) RS-232(0xD84D-0x4068)"},
{0x10B5, 0x9050, 0xD84D, 0x4078, "EX-4078 2S(16C552) RS-232+1P(0xD84D-0x4078)"},
{0x10B5, 0x9052, 0xFFFF, 0xFFFF, "PCI9052 PCI <-> IOBus Bridge(0x9052)"},
{0x10B5, 0x9054, 0xFFFF, 0xFFFF, "PCI9054 32-bit 33MHz PCI <-> IOBus Bridge(0x9054)"},
{0x10B5, 0x9054, 0x10B5, 0x1171, "Becker & Hickl PMS-400A(0x10B5-0x1171)"},
{0x10B5, 0x9054, 0x10B5, 0x1208, "Becker & Hickl SPC-830(0x10B5-0x1208)"},
{0x10B5, 0x9054, 0x10B5, 0x120E, "Becker & Hickl SPC-930(0x10B5-0x120E)"},
{0x10B5, 0x9054, 0x10B5, 0x120F, "Becker & Hickl SPC-150(0x10B5-0x120F)"},
{0x10B5, 0x9054, 0x10B5, 0x1210, "Becker & Hickl DPC-230(0x10B5-0x1210)"},
{0x10B5, 0x9054, 0x10B5, 0x2455, "Wessex Techology PHIL-PCI(0x10B5-0x2455)"},
{0x10B5, 0x9054, 0x10B5, 0x2696, "Innes Corp AM Radcap card(0x10B5-0x2696)"},
{0x10B5, 0x9054, 0x10B5, 0x2717, "Innes Corp Auricon card(0x10B5-0x2717)"},
{0x10B5, 0x9054, 0x10B5, 0x2844, "Innes Corp TVS Encoder card(0x10B5-0x2844)"},
{0x10B5, 0x9054, 0x12C7, 0x4001, "Intel Dialogic DM/V960-4T1 PCI(0x12C7-0x4001)"},
{0x10B5, 0x9054, 0x12D9, 0x0002, "PCI Prosody Card rev 1.5(0x12D9-0x0002)"},
{0x10B5, 0x9054, 0x14B4, 0xD100, "Dektec DTA-100(0x14B4-0xD100)"},
{0x10B5, 0x9054, 0x14B4, 0xD114, "Dektec DTA-120(0x14B4-0xD114)"},
{0x10B5, 0x9054, 0x16DF, 0x0011, "PIKA PrimeNet MM PCI(0x16DF-0x0011)"},
{0x10B5, 0x9054, 0x16DF, 0x0012, "PIKA PrimeNet MM cPCI 8(0x16DF-0x0012)"},
{0x10B5, 0x9054, 0x16DF, 0x0013, "PIKA PrimeNet MM cPCI 8 (without CAS Signaling)(0x16DF-0x0013)"},
{0x10B5, 0x9054, 0x16DF, 0x0014, "PIKA PrimeNet MM cPCI 4(0x16DF-0x0014)"},
{0x10B5, 0x9054, 0x16DF, 0x0015, "PIKA Daytona MM(0x16DF-0x0015)"},
{0x10B5, 0x9054, 0x16DF, 0x0016, "PIKA InLine MM(0x16DF-0x0016)"},
{0x10B5, 0x9056, 0xFFFF, 0xFFFF, "PCI9056 32-bit 66MHz PCI <-> IOBus Bridge(0x9056)"},
{0x10B5, 0x9056, 0x10B5, 0x2979, "CellinkBlade 11 - CPCI board VoATM AAL1(0x10B5-0x2979)"},
{0x10B5, 0x9056, 0x10B5, 0x3268, "IXXAT iPC-I XC16/PCIe CAN Board(0x10B5-0x3268)"},
{0x10B5, 0x9056, 0x10B5, 0x3334, "Cambridge Pixel HPx Radar Input Card(0x10B5-0x3334)"},
{0x10B5, 0x9056, 0x10B5, 0x3352, "Alpermann+Velte PCL PCIe HD: Timecode Reader Board(0x10B5-0x3352)"},
{0x10B5, 0x9056, 0x10B5, 0x3353, "Alpermann+Velte PCL PCIe D: Timecode Reader Board(0x10B5-0x3353)"},
{0x10B5, 0x9056, 0x10B5, 0x3354, "Plura PCL PCIe LV: Timecode Reader Board(0x10B5-0x3354)"},
{0x10B5, 0x9056, 0x10B5, 0x3355, "Plura PCL PCIe L: Timecode Reader Board(0x10B5-0x3355)"},
{0x10B5, 0x9056, 0x10B5, 0x3415, "Plura PCIe TS: Time Synchronisation Board(0x10B5-0x3415)"},
{0x10B5, 0x9056, 0x10B5, 0x3493, "Plura PCL PCIe 3G: Timecode Reader Board(0x10B5-0x3493)"},
{0x10B5, 0x9056, 0x10B5, 0x3565, "Cambridge Pixel HPx Radar Output Card(0x10B5-0x3565)"},
{0x10B5, 0x9056, 0x1369, 0xC001, "LX6464ES(0x1369-0xC001)"},
{0x10B5, 0x9056, 0x1369, 0xC201, "LX1616ES(0x1369-0xC201)"},
{0x10B5, 0x9056, 0x14B4, 0xD10A, "DekTec DTA-110T(0x14B4-0xD10A)"},
{0x10B5, 0x9056, 0x14B4, 0xD128, "Dektec DTA-140(0x14B4-0xD128)"},
{0x10B5, 0x9056, 0x14B4, 0xD140, "Dektec DTA-140(0x14B4-0xD140)"},
{0x10B5, 0x9056, 0x1A0E, 0x006F, "Dektec DTA-111(0x1A0E-0x006F)"},
{0x10B5, 0x9060, 0xFFFF, 0xFFFF, "PCI9060 32-bit 33MHz PCI <-> IOBus Bridge(0x9060)"},
{0x10B5, 0x906D, 0xFFFF, 0xFFFF, "9060SD(0x906D)"},
{0x10B5, 0x906D, 0x125C, 0x0640, "Aries 16000P(0x125C-0x0640)"},
{0x10B5, 0x906E, 0xFFFF, 0xFFFF, "9060ES(0x906E)"},
{0x10B5, 0x9080, 0xFFFF, 0xFFFF, "PCI9080 32-bit; 33MHz PCI <-> IOBus Bridge(0x9080)"},
{0x10B5, 0x9080, 0x103C, 0x10EB, "(Agilent) E2777B 83K Series Optical Communication Interface(0x103C-0x10EB)"},
{0x10B5, 0x9080, 0x103C, 0x10EC, "(Agilent) E6978-66442 PCI CIC(0x103C-0x10EC)"},
{0x10B5, 0x9080, 0x10B5, 0x1123, "Sectra KK631 encryption board(0x10B5-0x1123)"},
{0x10B5, 0x9080, 0x10B5, 0x9080, "9080 [real subsystem ID not set](0x10B5-0x9080)"},
{0x10B5, 0x9080, 0x12D9, 0x0002, "PCI Prosody Card(0x12D9-0x0002)"},
{0x10B5, 0x9080, 0x12DF, 0x4422, "4422PCI [\"Do-All\" Telemetry Data Acquisition System](0x12DF-0x4422)"},
{0x10B5, 0x9080, 0x1369, 0x9601, "PCX822np(0x1369-0x9601)"},
{0x10B5, 0x9080, 0x1369, 0xA102, "PCX822v2(0x1369-0xA102)"},
{0x10B5, 0x9080, 0x1369, 0xA201, "PCX442(0x1369-0xA201)"},
{0x10B5, 0x9080, 0x1369, 0xA301, "LCM440v2(0x1369-0xA301)"},
{0x10B5, 0x9080, 0x1369, 0xA401, "VX822(0x1369-0xA401)"},
{0x10B5, 0x9080, 0x1369, 0xA402, "VX822v2(0x1369-0xA402)"},
{0x10B5, 0x9080, 0x1369, 0xA901, "LCM420(0x1369-0xA901)"},
{0x10B5, 0x9080, 0x1369, 0xAA01, "VX820v2(0x1369-0xAA01)"},
{0x10B5, 0x9080, 0x1517, 0x000B, "ECSG-1R3ADC-PMC Clock synthesizer(0x1517-0x000B)"},
{0x10B5, 0x9656, 0xFFFF, 0xFFFF, "PCI9656 PCI <-> IOBus Bridge(0x9656)"},
{0x10B5, 0x9656, 0x1517, 0x000F, "ECDR-GC314-PMC Receiver(0x1517-0x000F)"},
{0x10B5, 0x9656, 0x1885, 0x0700, "Tsunami FPGA PMC with Altera Stratix S40(0x1885-0x0700)"},
{0x10B5, 0x9656, 0x1885, 0x0701, "Tsunami FPGA PMC with Altera Stratix S30(0x1885-0x0701)"},
{0x10B5, 0x9733, 0xFFFF, 0xFFFF, "PEX 9733 33-lane, 9-port PCI Express Gen 3 (8.0 GT/s) Switch(0x9733)"},
{0x10B5, 0x9733, 0x1D49, 0x0001, "ThinkSystem 1610-4P NVMe Switch Adapter(0x1D49-0x0001)"},
{0x10B5, 0x9733, 0x1D49, 0x0002, "ThinkSystem 810-4P NVMe Switch Adapter(0x1D49-0x0002)"},
{0x10B5, 0x9749, 0xFFFF, 0xFFFF, "PEX 9749 49-lane, 13-port PCI Express Gen 3 (8.0 GT/s) Switch(0x9749)"},
{0x10B5, 0x9749, 0x1D49, 0x0004, "ThinkSystem 1610-8P NVMe Switch Adapter(0x1D49-0x0004)"},
{0x10B5, 0xA100, 0xFFFF, 0xFFFF, "Blackmagic Design DeckLink(0xA100)"},
{0x10B5, 0xBB04, 0xFFFF, 0xFFFF, "B&B 3PCIOSD1A Isolated PCI Serial(0xBB04)"},
{0x10B5, 0xC001, 0xFFFF, 0xFFFF, "CronyxOmega-PCI (8-port RS232)(0xC001)"},
{0x10B5, 0xD00D, 0xFFFF, 0xFFFF, "PCI9030 32-bit 33MHz PCI <-> IOBus Bridge(0xD00D)"},
{0x10B5, 0xD00D, 0x10B5, 0x9030, "Digium Tormenta 2 T400P or E400P Quad T1 or E1 PCI card(0x10B5-0x9030)"},
{0x10B5, 0xD33D, 0xFFFF, 0xFFFF, "PCI9030 32-bit 33MHz PCI <-> IOBus Bridge(0xD33D)"},
{0x10B5, 0xD33D, 0x10B5, 0x9030, "Tormenta 3 Varion V401PT Quad T1/J1 PCI card(0x10B5-0x9030)"},
{0x10B5, 0xD44D, 0xFFFF, 0xFFFF, "PCI9030 32-bit 33MHz PCI <-> IOBus Bridge(0xD44D)"},
{0x10B5, 0xD44D, 0x10B5, 0x17F6, "Allo CP100P/E 1-port E1/T1/J1 PCI/PCIe card(0x10B5-0x17F6)"},
{0x10B5, 0xD44D, 0x10B5, 0x17F7, "Allo CP400P/E 4-port E1/T1/J1 PCI/PCIe card(0x10B5-0x17F7)"},
{0x10B5, 0xD44D, 0x10B5, 0x17F8, "Allo CP200P/E 2-port E1/T1/J1 PCI/PCIe card(0x10B5-0x17F8)"},
{0x10B5, 0xD44D, 0x10B5, 0x9030, "Tormenta 3 Varion V401PE Quad E1 PCI card(0x10B5-0x9030)"},
}; /* pci_vid_10B5[] */

static pci_id_t const pci_vid_10B6[] = {
{0x10B6, 0xFFFF, 0xFFFF, 0xFFFF, "Madge Networks(0x10B6)"},
{0x10B6, 0x0001, 0xFFFF, 0xFFFF, "Smart 16/4 PCI Ringnode(0x0001)"},
{0x10B6, 0x0002, 0xFFFF, 0xFFFF, "Smart 16/4 PCI Ringnode Mk2(0x0002)"},
{0x10B6, 0x0002, 0x10B6, 0x0002, "Smart 16/4 PCI Ringnode Mk2(0x10B6-0x0002)"},
{0x10B6, 0x0002, 0x10B6, 0x0006, "16/4 CardBus Adapter(0x10B6-0x0006)"},
{0x10B6, 0x0003, 0xFFFF, 0xFFFF, "Smart 16/4 PCI Ringnode Mk3(0x0003)"},
{0x10B6, 0x0003, 0x0E11, 0xB0FD, "Compaq NC4621 PCI, 4/16, WOL(0x0E11-0xB0FD)"},
{0x10B6, 0x0003, 0x10B6, 0x0003, "Smart 16/4 PCI Ringnode Mk3(0x10B6-0x0003)"},
{0x10B6, 0x0003, 0x10B6, 0x0007, "Presto PCI Plus Adapter(0x10B6-0x0007)"},
{0x10B6, 0x0004, 0xFFFF, 0xFFFF, "Smart 16/4 PCI Ringnode Mk1(0x0004)"},
{0x10B6, 0x0006, 0xFFFF, 0xFFFF, "16/4 Cardbus Adapter(0x0006)"},
{0x10B6, 0x0006, 0x10B6, 0x0006, "16/4 CardBus Adapter(0x10B6-0x0006)"},
{0x10B6, 0x0007, 0xFFFF, 0xFFFF, "Presto PCI Adapter(0x0007)"},
{0x10B6, 0x0007, 0x10B6, 0x0007, "Presto PCI(0x10B6-0x0007)"},
{0x10B6, 0x0009, 0xFFFF, 0xFFFF, "Smart 100/16/4 PCI-HS Ringnode(0x0009)"},
{0x10B6, 0x0009, 0x10B6, 0x0009, "Smart 100/16/4 PCI-HS Ringnode(0x10B6-0x0009)"},
{0x10B6, 0x000A, 0xFFFF, 0xFFFF, "Token Ring 100/16/4 Ringnode/Ringrunner(0x000A)"},
{0x10B6, 0x000A, 0x10B6, 0x000A, "Token Ring 100/16/4 Ringnode/Ringrunner(0x10B6-0x000A)"},
{0x10B6, 0x000B, 0xFFFF, 0xFFFF, "16/4 CardBus Adapter Mk2(0x000B)"},
{0x10B6, 0x000B, 0x10B6, 0x0008, "16/4 CardBus Adapter Mk2(0x10B6-0x0008)"},
{0x10B6, 0x000B, 0x10B6, 0x000B, "16/4 Cardbus Adapter Mk2(0x10B6-0x000B)"},
{0x10B6, 0x000C, 0xFFFF, 0xFFFF, "RapidFire 3140V2 16/4 TR Adapter(0x000C)"},
{0x10B6, 0x000C, 0x10B6, 0x000C, "RapidFire 3140V2 16/4 TR Adapter(0x10B6-0x000C)"},
{0x10B6, 0x1000, 0xFFFF, 0xFFFF, "Collage 25/155 ATM Client Adapter(0x1000)"},
{0x10B6, 0x1001, 0xFFFF, 0xFFFF, "Collage 155 ATM Server Adapter(0x1001)"},
}; /* pci_vid_10B6[] */

static pci_id_t const pci_vid_10B7[] = {
{0x10B7, 0xFFFF, 0xFFFF, 0xFFFF, "3Com Corporation(0x10B7)"},
{0x10B7, 0x0001, 0xFFFF, 0xFFFF, "3c985 1000BaseSX (SX/TX)(0x0001)"},
{0x10B7, 0x0001, 0x9850, 0x0001, "3c985B-SX(0x9850-0x0001)"},
{0x10B7, 0x0013, 0xFFFF, 0xFFFF, "AR5212 802.11abg NIC (3CRDAG675)(0x0013)"},
{0x10B7, 0x0013, 0x10B7, 0x2031, "3CRDAG675 11a/b/g Wireless PCI Adapter(0x10B7-0x2031)"},
{0x10B7, 0x0910, 0xFFFF, 0xFFFF, "3C910-A01(0x0910)"},
{0x10B7, 0x1006, 0xFFFF, 0xFFFF, "MINI PCI type 3B Data Fax Modem(0x1006)"},
{0x10B7, 0x1007, 0xFFFF, 0xFFFF, "Mini PCI 56k Winmodem(0x1007)"},
{0x10B7, 0x1007, 0x10B7, 0x615B, "Mini PCI 56K Modem(0x10B7-0x615B)"},
{0x10B7, 0x1007, 0x10B7, 0x615C, "Mini PCI 56K Modem(0x10B7-0x615C)"},
{0x10B7, 0x1201, 0xFFFF, 0xFFFF, "3c982-TXM 10/100baseTX Dual Port A [Hydra](0x1201)"},
{0x10B7, 0x1202, 0xFFFF, 0xFFFF, "3c982-TXM 10/100baseTX Dual Port B [Hydra](0x1202)"},
{0x10B7, 0x1700, 0xFFFF, 0xFFFF, "3c940 10/100/1000Base-T [Marvell](0x1700)"},
{0x10B7, 0x1700, 0x1043, 0x80EB, "A7V600/P4P800/K8V motherboard(0x1043-0x80EB)"},
{0x10B7, 0x1700, 0x10B7, 0x0010, "3C940 Gigabit LOM Ethernet Adapter(0x10B7-0x0010)"},
{0x10B7, 0x1700, 0x10B7, 0x0020, "3C941 Gigabit LOM Ethernet Adapter(0x10B7-0x0020)"},
{0x10B7, 0x1700, 0x147B, 0x1407, "KV8-MAX3 motherboard(0x147B-0x1407)"},
{0x10B7, 0x3390, 0xFFFF, 0xFFFF, "3c339 TokenLink Velocity(0x3390)"},
{0x10B7, 0x3590, 0xFFFF, 0xFFFF, "3c359 TokenLink Velocity XL(0x3590)"},
{0x10B7, 0x3590, 0x10B7, 0x3590, "TokenLink Velocity XL Adapter (3C359/359B)(0x10B7-0x3590)"},
{0x10B7, 0x4500, 0xFFFF, 0xFFFF, "3c450 HomePNA [Tornado](0x4500)"},
{0x10B7, 0x5055, 0xFFFF, 0xFFFF, "3c555 Laptop Hurricane(0x5055)"},
{0x10B7, 0x5057, 0xFFFF, 0xFFFF, "3c575 Megahertz 10/100 LAN CardBus [Boomerang](0x5057)"},
{0x10B7, 0x5057, 0x10B7, 0x5A57, "3C575 Megahertz 10/100 LAN Cardbus PC Card(0x10B7-0x5A57)"},
{0x10B7, 0x5157, 0xFFFF, 0xFFFF, "3cCFE575BT Megahertz 10/100 LAN CardBus [Cyclone](0x5157)"},
{0x10B7, 0x5157, 0x10B7, 0x5B57, "3C575 Megahertz 10/100 LAN Cardbus PC Card(0x10B7-0x5B57)"},
{0x10B7, 0x5257, 0xFFFF, 0xFFFF, "3cCFE575CT CardBus [Cyclone](0x5257)"},
{0x10B7, 0x5257, 0x10B7, 0x5C57, "FE575C-3Com 10/100 LAN CardBus-Fast Ethernet(0x10B7-0x5C57)"},
{0x10B7, 0x5900, 0xFFFF, 0xFFFF, "3c590 10BaseT [Vortex](0x5900)"},
{0x10B7, 0x5920, 0xFFFF, 0xFFFF, "3c592 EISA 10mbps Demon/Vortex(0x5920)"},
{0x10B7, 0x5950, 0xFFFF, 0xFFFF, "3c595 100BaseTX [Vortex](0x5950)"},
{0x10B7, 0x5951, 0xFFFF, 0xFFFF, "3c595 100BaseT4 [Vortex](0x5951)"},
{0x10B7, 0x5952, 0xFFFF, 0xFFFF, "3c595 100Base-MII [Vortex](0x5952)"},
{0x10B7, 0x5970, 0xFFFF, 0xFFFF, "3c597 EISA Fast Demon/Vortex(0x5970)"},
{0x10B7, 0x5B57, 0xFFFF, 0xFFFF, "3c595 Megahertz 10/100 LAN CardBus [Boomerang](0x5B57)"},
{0x10B7, 0x5B57, 0x10B7, 0x5B57, "3C575 Megahertz 10/100 LAN Cardbus PC Card(0x10B7-0x5B57)"},
{0x10B7, 0x6000, 0xFFFF, 0xFFFF, "3CRSHPW796 [OfficeConnect Wireless CardBus](0x6000)"},
{0x10B7, 0x6001, 0xFFFF, 0xFFFF, "3com 3CRWE154G72 [Office Connect Wireless LAN Adapter](0x6001)"},
{0x10B7, 0x6055, 0xFFFF, 0xFFFF, "3c556 Hurricane CardBus [Cyclone](0x6055)"},
{0x10B7, 0x6056, 0xFFFF, 0xFFFF, "3c556B CardBus [Tornado](0x6056)"},
{0x10B7, 0x6056, 0x10B7, 0x6556, "10/100 Mini PCI Ethernet Adapter(0x10B7-0x6556)"},
{0x10B7, 0x6560, 0xFFFF, 0xFFFF, "3cCFE656 CardBus [Cyclone](0x6560)"},
{0x10B7, 0x6560, 0x10B7, 0x656A, "3CCFEM656 10/100 LAN+56K Modem CardBus(0x10B7-0x656A)"},
{0x10B7, 0x6561, 0xFFFF, 0xFFFF, "3cCFEM656 10/100 LAN+56K Modem CardBus(0x6561)"},
{0x10B7, 0x6561, 0x10B7, 0x656B, "3CCFEM656 10/100 LAN+56K Modem CardBus(0x10B7-0x656B)"},
{0x10B7, 0x6562, 0xFFFF, 0xFFFF, "3cCFEM656B 10/100 LAN+Winmodem CardBus [Cyclone](0x6562)"},
{0x10B7, 0x6562, 0x10B7, 0x656B, "3CCFEM656B 10/100 LAN+56K Modem CardBus(0x10B7-0x656B)"},
{0x10B7, 0x6563, 0xFFFF, 0xFFFF, "3cCFEM656B 10/100 LAN+56K Modem CardBus(0x6563)"},
{0x10B7, 0x6563, 0x10B7, 0x656B, "3CCFEM656 10/100 LAN+56K Modem CardBus(0x10B7-0x656B)"},
{0x10B7, 0x6564, 0xFFFF, 0xFFFF, "3cXFEM656C 10/100 LAN+Winmodem CardBus [Tornado](0x6564)"},
{0x10B7, 0x7646, 0xFFFF, 0xFFFF, "3cSOHO100-TX Hurricane(0x7646)"},
{0x10B7, 0x7770, 0xFFFF, 0xFFFF, "3CRWE777 PCI Wireless Adapter [Airconnect](0x7770)"},
{0x10B7, 0x7940, 0xFFFF, 0xFFFF, "3c803 FDDILink UTP Controller(0x7940)"},
{0x10B7, 0x7980, 0xFFFF, 0xFFFF, "3c804 FDDILink SAS Controller(0x7980)"},
{0x10B7, 0x7990, 0xFFFF, 0xFFFF, "3c805 FDDILink DAS Controller(0x7990)"},
{0x10B7, 0x80EB, 0xFFFF, 0xFFFF, "3c940B 10/100/1000Base-T(0x80EB)"},
{0x10B7, 0x8811, 0xFFFF, 0xFFFF, "Token ring(0x8811)"},
{0x10B7, 0x9000, 0xFFFF, 0xFFFF, "3c900 10BaseT [Boomerang](0x9000)"},
{0x10B7, 0x9001, 0xFFFF, 0xFFFF, "3c900 10Mbps Combo [Boomerang](0x9001)"},
{0x10B7, 0x9004, 0xFFFF, 0xFFFF, "3c900B-TPO Etherlink XL [Cyclone](0x9004)"},
{0x10B7, 0x9004, 0x10B7, 0x9004, "3C900B-TPO Etherlink XL TPO 10Mb(0x10B7-0x9004)"},
{0x10B7, 0x9005, 0xFFFF, 0xFFFF, "3c900B-Combo Etherlink XL [Cyclone](0x9005)"},
{0x10B7, 0x9005, 0x10B7, 0x9005, "3C900B-Combo Etherlink XL Combo(0x10B7-0x9005)"},
{0x10B7, 0x9006, 0xFFFF, 0xFFFF, "3c900B-TPC Etherlink XL [Cyclone](0x9006)"},
{0x10B7, 0x900A, 0xFFFF, 0xFFFF, "3c900B-FL 10base-FL [Cyclone](0x900A)"},
{0x10B7, 0x9050, 0xFFFF, 0xFFFF, "3c905 100BaseTX [Boomerang](0x9050)"},
{0x10B7, 0x9051, 0xFFFF, 0xFFFF, "3c905 100BaseT4 [Boomerang](0x9051)"},
{0x10B7, 0x9054, 0xFFFF, 0xFFFF, "3C905B-TX Fast Etherlink XL PCI(0x9054)"},
{0x10B7, 0x9054, 0x10B7, 0x9054, "3C905B-TX Fast Etherlink XL PCI(0x10B7-0x9054)"},
{0x10B7, 0x9055, 0xFFFF, 0xFFFF, "3c905B 100BaseTX [Cyclone](0x9055)"},
{0x10B7, 0x9055, 0x1028, 0x0080, "3C905B Fast Etherlink XL 10/100(0x1028-0x0080)"},
{0x10B7, 0x9055, 0x1028, 0x0081, "3C905B Fast Etherlink XL 10/100(0x1028-0x0081)"},
{0x10B7, 0x9055, 0x1028, 0x0082, "3C905B Fast Etherlink XL 10/100(0x1028-0x0082)"},
{0x10B7, 0x9055, 0x1028, 0x0083, "3C905B Fast Etherlink XL 10/100(0x1028-0x0083)"},
{0x10B7, 0x9055, 0x1028, 0x0084, "3C905B Fast Etherlink XL 10/100(0x1028-0x0084)"},
{0x10B7, 0x9055, 0x1028, 0x0085, "3C905B Fast Etherlink XL 10/100(0x1028-0x0085)"},
{0x10B7, 0x9055, 0x1028, 0x0086, "3C905B Fast Etherlink XL 10/100(0x1028-0x0086)"},
{0x10B7, 0x9055, 0x1028, 0x0087, "3C905B Fast Etherlink XL 10/100(0x1028-0x0087)"},
{0x10B7, 0x9055, 0x1028, 0x0088, "3C905B Fast Etherlink XL 10/100(0x1028-0x0088)"},
{0x10B7, 0x9055, 0x1028, 0x0089, "3C905B Fast Etherlink XL 10/100(0x1028-0x0089)"},
{0x10B7, 0x9055, 0x1028, 0x0090, "3C905B Fast Etherlink XL 10/100(0x1028-0x0090)"},
{0x10B7, 0x9055, 0x1028, 0x0091, "3C905B Fast Etherlink XL 10/100(0x1028-0x0091)"},
{0x10B7, 0x9055, 0x1028, 0x0092, "3C905B Fast Etherlink XL 10/100(0x1028-0x0092)"},
{0x10B7, 0x9055, 0x1028, 0x0093, "3C905B Fast Etherlink XL 10/100(0x1028-0x0093)"},
{0x10B7, 0x9055, 0x1028, 0x0094, "3C905B Fast Etherlink XL 10/100(0x1028-0x0094)"},
{0x10B7, 0x9055, 0x1028, 0x0095, "3C905B Fast Etherlink XL 10/100(0x1028-0x0095)"},
{0x10B7, 0x9055, 0x1028, 0x0096, "3C905B Fast Etherlink XL 10/100(0x1028-0x0096)"},
{0x10B7, 0x9055, 0x1028, 0x0097, "3C905B Fast Etherlink XL 10/100(0x1028-0x0097)"},
{0x10B7, 0x9055, 0x1028, 0x0098, "3C905B Fast Etherlink XL 10/100(0x1028-0x0098)"},
{0x10B7, 0x9055, 0x1028, 0x0099, "3C905B Fast Etherlink XL 10/100(0x1028-0x0099)"},
{0x10B7, 0x9055, 0x10B7, 0x9055, "3C905B Fast Etherlink XL 10/100(0x10B7-0x9055)"},
{0x10B7, 0x9056, 0xFFFF, 0xFFFF, "3c905B-T4 Fast EtherLink XL [Cyclone](0x9056)"},
{0x10B7, 0x9058, 0xFFFF, 0xFFFF, "3c905B Deluxe Etherlink 10/100/BNC [Cyclone](0x9058)"},
{0x10B7, 0x905A, 0xFFFF, 0xFFFF, "3c905B-FX Fast Etherlink XL FX 100baseFx [Cyclone](0x905A)"},
{0x10B7, 0x9200, 0xFFFF, 0xFFFF, "3c905C-TX/TX-M [Tornado](0x9200)"},
{0x10B7, 0x9200, 0x1028, 0x0095, "3C920 Integrated Fast Ethernet Controller(0x1028-0x0095)"},
{0x10B7, 0x9200, 0x1028, 0x0097, "3C920 Integrated Fast Ethernet Controller(0x1028-0x0097)"},
{0x10B7, 0x9200, 0x1028, 0x00B4, "OptiPlex GX110(0x1028-0x00B4)"},
{0x10B7, 0x9200, 0x1028, 0x00D8, "Precision 530(0x1028-0x00D8)"},
{0x10B7, 0x9200, 0x1028, 0x00FE, "Optiplex GX240(0x1028-0x00FE)"},
{0x10B7, 0x9200, 0x1028, 0x012A, "3C920 Integrated Fast Ethernet Controller [Latitude C640](0x1028-0x012A)"},
{0x10B7, 0x9200, 0x10B7, 0x1000, "3C905CX-TX/TX-M Fast Etherlink for PC Management NIC(0x10B7-0x1000)"},
{0x10B7, 0x9200, 0x10B7, 0x7000, "10/100 Mini PCI Ethernet Adapter(0x10B7-0x7000)"},
{0x10B7, 0x9200, 0x10F1, 0x2466, "Tiger MPX S2466 (3C920 Integrated Fast Ethernet Controller)(0x10F1-0x2466)"},
{0x10B7, 0x9200, 0x144D, 0xC005, "X10 Laptop(0x144D-0xC005)"},
{0x10B7, 0x9201, 0xFFFF, 0xFFFF, "3C920B-EMB Integrated Fast Ethernet Controller [Tornado](0x9201)"},
{0x10B7, 0x9201, 0x1043, 0x80AB, "A7N8X Deluxe onboard 3C920B-EMB Integrated Fast Ethernet Controller(0x1043-0x80AB)"},
{0x10B7, 0x9202, 0xFFFF, 0xFFFF, "3Com 3C920B-EMB-WNM Integrated Fast Ethernet Controller(0x9202)"},
{0x10B7, 0x9210, 0xFFFF, 0xFFFF, "3C920B-EMB-WNM Integrated Fast Ethernet Controller(0x9210)"},
{0x10B7, 0x9300, 0xFFFF, 0xFFFF, "3CSOHO100B-TX 910-A01 [tulip](0x9300)"},
{0x10B7, 0x9800, 0xFFFF, 0xFFFF, "3c980-TX Fast Etherlink XL Server Adapter [Cyclone](0x9800)"},
{0x10B7, 0x9800, 0x10B7, 0x9800, "3c980-TX Fast Etherlink XL Server Adapter(0x10B7-0x9800)"},
{0x10B7, 0x9805, 0xFFFF, 0xFFFF, "3c980-C 10/100baseTX NIC [Python-T](0x9805)"},
{0x10B7, 0x9805, 0x10B7, 0x1201, "EtherLink Server 10/100 Dual Port A(0x10B7-0x1201)"},
{0x10B7, 0x9805, 0x10B7, 0x1202, "EtherLink Server 10/100 Dual Port B(0x10B7-0x1202)"},
{0x10B7, 0x9805, 0x10B7, 0x9805, "3c980 10/100baseTX NIC [Python-T](0x10B7-0x9805)"},
{0x10B7, 0x9805, 0x10F1, 0x2462, "Thunder K7 S2462(0x10F1-0x2462)"},
{0x10B7, 0x9900, 0xFFFF, 0xFFFF, "3C990-TX [Typhoon](0x9900)"},
{0x10B7, 0x9902, 0xFFFF, 0xFFFF, "3CR990-TX-95 [Typhoon 56-bit](0x9902)"},
{0x10B7, 0x9903, 0xFFFF, 0xFFFF, "3CR990-TX-97 [Typhoon 168-bit](0x9903)"},
{0x10B7, 0x9904, 0xFFFF, 0xFFFF, "3C990B-TX-M/3C990BSVR [Typhoon2](0x9904)"},
{0x10B7, 0x9904, 0x10B7, 0x1000, "3CR990B-TX-M [Typhoon2](0x10B7-0x1000)"},
{0x10B7, 0x9904, 0x10B7, 0x2000, "3CR990BSVR [Typhoon2 Server](0x10B7-0x2000)"},
{0x10B7, 0x9905, 0xFFFF, 0xFFFF, "3CR990-FX-95/97/95 [Typhon Fiber](0x9905)"},
{0x10B7, 0x9905, 0x10B7, 0x1101, "3CR990-FX-95 [Typhoon Fiber 56-bit](0x10B7-0x1101)"},
{0x10B7, 0x9905, 0x10B7, 0x1102, "3CR990-FX-97 [Typhoon Fiber 168-bit](0x10B7-0x1102)"},
{0x10B7, 0x9905, 0x10B7, 0x2101, "3CR990-FX-95 Server [Typhoon Fiber 56-bit](0x10B7-0x2101)"},
{0x10B7, 0x9905, 0x10B7, 0x2102, "3CR990-FX-97 Server [Typhoon Fiber 168-bit](0x10B7-0x2102)"},
{0x10B7, 0x9908, 0xFFFF, 0xFFFF, "3CR990SVR95 [Typhoon Server 56-bit](0x9908)"},
{0x10B7, 0x9909, 0xFFFF, 0xFFFF, "3CR990SVR97 [Typhoon Server 168-bit](0x9909)"},
{0x10B7, 0x990A, 0xFFFF, 0xFFFF, "3C990SVR [Typhoon Server](0x990A)"},
{0x10B7, 0x990B, 0xFFFF, 0xFFFF, "3C990SVR [Typhoon Server](0x990B)"},
}; /* pci_vid_10B7[] */

static pci_id_t const pci_vid_10B8[] = {
{0x10B8, 0xFFFF, 0xFFFF, 0xFFFF, "Standard Microsystems Corp [SMC](0x10B8)"},
{0x10B8, 0x0005, 0xFFFF, 0xFFFF, "83c170 EPIC/100 Fast Ethernet Adapter(0x0005)"},
{0x10B8, 0x0005, 0x1055, 0xE000, "LANEPIC 10/100 [EVB171Q-PCI](0x1055-0xE000)"},
{0x10B8, 0x0005, 0x1055, 0xE002, "LANEPIC 10/100 [EVB171G-PCI](0x1055-0xE002)"},
{0x10B8, 0x0005, 0x10B8, 0xA011, "EtherPower II 10/100(0x10B8-0xA011)"},
{0x10B8, 0x0005, 0x10B8, 0xA014, "EtherPower II 10/100(0x10B8-0xA014)"},
{0x10B8, 0x0005, 0x10B8, 0xA015, "EtherPower II 10/100(0x10B8-0xA015)"},
{0x10B8, 0x0005, 0x10B8, 0xA016, "EtherPower II 10/100(0x10B8-0xA016)"},
{0x10B8, 0x0005, 0x10B8, 0xA017, "EtherPower II 10/100(0x10B8-0xA017)"},
{0x10B8, 0x0006, 0xFFFF, 0xFFFF, "83c175 EPIC/100 Fast Ethernet Adapter(0x0006)"},
{0x10B8, 0x0006, 0x1055, 0xE100, "LANEPIC Cardbus Fast Ethernet Adapter(0x1055-0xE100)"},
{0x10B8, 0x0006, 0x1055, 0xE102, "LANEPIC Cardbus Fast Ethernet Adapter(0x1055-0xE102)"},
{0x10B8, 0x0006, 0x1055, 0xE300, "LANEPIC Cardbus Fast Ethernet Adapter(0x1055-0xE300)"},
{0x10B8, 0x0006, 0x1055, 0xE302, "LANEPIC Cardbus Fast Ethernet Adapter(0x1055-0xE302)"},
{0x10B8, 0x0006, 0x10B8, 0xA012, "LANEPIC Cardbus Fast Ethernet Adapter(0x10B8-0xA012)"},
{0x10B8, 0x0006, 0x13A2, 0x8002, "LANEPIC Cardbus Fast Ethernet Adapter(0x13A2-0x8002)"},
{0x10B8, 0x0006, 0x13A2, 0x8006, "LANEPIC Cardbus Fast Ethernet Adapter(0x13A2-0x8006)"},
{0x10B8, 0x1000, 0xFFFF, 0xFFFF, "FDC 37c665(0x1000)"},
{0x10B8, 0x1001, 0xFFFF, 0xFFFF, "FDC 37C922(0x1001)"},
{0x10B8, 0xA011, 0xFFFF, 0xFFFF, "83C170QF(0xA011)"},
{0x10B8, 0xB106, 0xFFFF, 0xFFFF, "SMC34C90(0xB106)"},
}; /* pci_vid_10B8[] */

static pci_id_t const pci_vid_10B9[] = {
{0x10B9, 0xFFFF, 0xFFFF, 0xFFFF, "ULi Electronics Inc.(0x10B9)"},
{0x10B9, 0x0101, 0xFFFF, 0xFFFF, "CMI8338/C3DX PCI Audio Device(0x0101)"},
{0x10B9, 0x0111, 0xFFFF, 0xFFFF, "C-Media CMI8738/C3DX Audio Device (OEM)(0x0111)"},
{0x10B9, 0x0111, 0x10B9, 0x0111, "C-Media CMI8738/C3DX Audio Device (OEM)(0x10B9-0x0111)"},
{0x10B9, 0x0780, 0xFFFF, 0xFFFF, "Multi-IO Card(0x0780)"},
{0x10B9, 0x0782, 0xFFFF, 0xFFFF, "Multi-IO Card(0x0782)"},
{0x10B9, 0x1435, 0xFFFF, 0xFFFF, "M1435(0x1435)"},
{0x10B9, 0x1445, 0xFFFF, 0xFFFF, "M1445(0x1445)"},
{0x10B9, 0x1449, 0xFFFF, 0xFFFF, "M1449(0x1449)"},
{0x10B9, 0x1451, 0xFFFF, 0xFFFF, "M1451(0x1451)"},
{0x10B9, 0x1461, 0xFFFF, 0xFFFF, "M1461(0x1461)"},
{0x10B9, 0x1489, 0xFFFF, 0xFFFF, "M1489 Cache-Memory PCI Controller (CMP) [FinALi 486] CPU to PCI bridge(0x1489)"},
{0x10B9, 0x1511, 0xFFFF, 0xFFFF, "M1511 [Aladdin](0x1511)"},
{0x10B9, 0x1512, 0xFFFF, 0xFFFF, "M1512 [Aladdin](0x1512)"},
{0x10B9, 0x1513, 0xFFFF, 0xFFFF, "M1513 [Aladdin](0x1513)"},
{0x10B9, 0x1521, 0xFFFF, 0xFFFF, "M1521 [Aladdin III](0x1521)"},
{0x10B9, 0x1521, 0x10B9, 0x1521, "ALI M1521 Aladdin III CPU Bridge(0x10B9-0x1521)"},
{0x10B9, 0x1523, 0xFFFF, 0xFFFF, "M1523(0x1523)"},
{0x10B9, 0x1523, 0x10B9, 0x1523, "ALI M1523 ISA Bridge(0x10B9-0x1523)"},
{0x10B9, 0x1531, 0xFFFF, 0xFFFF, "M1531 [Aladdin IV](0x1531)"},
{0x10B9, 0x1533, 0xFFFF, 0xFFFF, "M1533/M1535/M1543 PCI to ISA Bridge [Aladdin IV/V/V+](0x1533)"},
{0x10B9, 0x1533, 0x1014, 0x053B, "ThinkPad R40e(0x1014-0x053B)"},
{0x10B9, 0x1533, 0x10B9, 0x1533, "ALi M1533 Aladdin IV/V ISA Bridge(0x10B9-0x1533)"},
{0x10B9, 0x1541, 0xFFFF, 0xFFFF, "M1541(0x1541)"},
{0x10B9, 0x1541, 0x10B9, 0x1541, "ALI M1541 Aladdin V/V+ AGP System Controller(0x10B9-0x1541)"},
{0x10B9, 0x1543, 0xFFFF, 0xFFFF, "M1543(0x1543)"},
{0x10B9, 0x1563, 0xFFFF, 0xFFFF, "M1563 HyperTransport South Bridge(0x1563)"},
{0x10B9, 0x1563, 0x10B9, 0x1563, "ASRock 939Dual-SATA2 Motherboard(0x10B9-0x1563)"},
{0x10B9, 0x1563, 0x1849, 0x1563, "ASRock 939Dual-SATA2 Motherboard(0x1849-0x1563)"},
{0x10B9, 0x1573, 0xFFFF, 0xFFFF, "PCI to LPC Controller(0x1573)"},
{0x10B9, 0x1575, 0xFFFF, 0xFFFF, "M1575 South Bridge(0x1575)"},
{0x10B9, 0x1621, 0xFFFF, 0xFFFF, "M1621(0x1621)"},
{0x10B9, 0x1631, 0xFFFF, 0xFFFF, "ALI M1631 PCI North Bridge Aladdin Pro III(0x1631)"},
{0x10B9, 0x1632, 0xFFFF, 0xFFFF, "M1632M Northbridge+Trident(0x1632)"},
{0x10B9, 0x1641, 0xFFFF, 0xFFFF, "ALI M1641 PCI North Bridge Aladdin Pro IV(0x1641)"},
{0x10B9, 0x1644, 0xFFFF, 0xFFFF, "M1644/M1644T Northbridge+Trident(0x1644)"},
{0x10B9, 0x1646, 0xFFFF, 0xFFFF, "M1646 Northbridge+Trident(0x1646)"},
{0x10B9, 0x1647, 0xFFFF, 0xFFFF, "M1647 Northbridge [MAGiK 1 / MobileMAGiK 1](0x1647)"},
{0x10B9, 0x1651, 0xFFFF, 0xFFFF, "M1651/M1651T Northbridge [Aladdin-Pro 5/5M,Aladdin-Pro 5T/5TM](0x1651)"},
{0x10B9, 0x1671, 0xFFFF, 0xFFFF, "M1671 Super P4 Northbridge [AGP4X,PCI and SDR/DDR](0x1671)"},
{0x10B9, 0x1672, 0xFFFF, 0xFFFF, "M1672 Northbridge [CyberALADDiN-P4](0x1672)"},
{0x10B9, 0x1681, 0xFFFF, 0xFFFF, "M1681 P4 Northbridge [AGP8X,HyperTransport and SDR/DDR](0x1681)"},
{0x10B9, 0x1687, 0xFFFF, 0xFFFF, "M1687 K8 Northbridge [AGP8X and HyperTransport](0x1687)"},
{0x10B9, 0x1689, 0xFFFF, 0xFFFF, "M1689 K8 Northbridge [Super K8 Single Chip](0x1689)"},
{0x10B9, 0x1695, 0xFFFF, 0xFFFF, "M1695 Host Bridge(0x1695)"},
{0x10B9, 0x1697, 0xFFFF, 0xFFFF, "M1697 HTT Host Bridge(0x1697)"},
{0x10B9, 0x3141, 0xFFFF, 0xFFFF, "M3141(0x3141)"},
{0x10B9, 0x3143, 0xFFFF, 0xFFFF, "M3143(0x3143)"},
{0x10B9, 0x3145, 0xFFFF, 0xFFFF, "M3145(0x3145)"},
{0x10B9, 0x3147, 0xFFFF, 0xFFFF, "M3147(0x3147)"},
{0x10B9, 0x3149, 0xFFFF, 0xFFFF, "M3149(0x3149)"},
{0x10B9, 0x3151, 0xFFFF, 0xFFFF, "M3151(0x3151)"},
{0x10B9, 0x3307, 0xFFFF, 0xFFFF, "M3307(0x3307)"},
{0x10B9, 0x3309, 0xFFFF, 0xFFFF, "M3309(0x3309)"},
{0x10B9, 0x3323, 0xFFFF, 0xFFFF, "M3325 Video/Audio Decoder(0x3323)"},
{0x10B9, 0x5212, 0xFFFF, 0xFFFF, "M4803(0x5212)"},
{0x10B9, 0x5215, 0xFFFF, 0xFFFF, "MS4803(0x5215)"},
{0x10B9, 0x5217, 0xFFFF, 0xFFFF, "M5217H(0x5217)"},
{0x10B9, 0x5219, 0xFFFF, 0xFFFF, "M5219(0x5219)"},
{0x10B9, 0x5225, 0xFFFF, 0xFFFF, "M5225(0x5225)"},
{0x10B9, 0x5228, 0xFFFF, 0xFFFF, "M5228 ALi ATA/RAID Controller(0x5228)"},
{0x10B9, 0x5229, 0xFFFF, 0xFFFF, "M5229 IDE(0x5229)"},
{0x10B9, 0x5229, 0x1014, 0x050F, "ThinkPad R30(0x1014-0x050F)"},
{0x10B9, 0x5229, 0x1014, 0x053D, "ThinkPad R40e(0x1014-0x053D)"},
{0x10B9, 0x5229, 0x103C, 0x0024, "Pavilion ze4400 builtin IDE(0x103C-0x0024)"},
{0x10B9, 0x5229, 0x103C, 0x0025, "XE4500 Notebook(0x103C-0x0025)"},
{0x10B9, 0x5229, 0x1043, 0x8053, "A7A266 Motherboard IDE(0x1043-0x8053)"},
{0x10B9, 0x5229, 0x1849, 0x5229, "ASRock 939Dual-SATA2 Motherboard IDE (PATA)(0x1849-0x5229)"},
{0x10B9, 0x5235, 0xFFFF, 0xFFFF, "M5225(0x5235)"},
{0x10B9, 0x5237, 0xFFFF, 0xFFFF, "USB 1.1 Controller(0x5237)"},
{0x10B9, 0x5237, 0x1014, 0x0540, "ThinkPad R40e(0x1014-0x0540)"},
{0x10B9, 0x5237, 0x103C, 0x0024, "Pavilion ze4400 builtin USB(0x103C-0x0024)"},
{0x10B9, 0x5237, 0x103C, 0x0025, "XE4500 Notebook(0x103C-0x0025)"},
{0x10B9, 0x5237, 0x104D, 0x810F, "VAIO PCG-U1 USB/OHCI Revision 1.0(0x104D-0x810F)"},
{0x10B9, 0x5237, 0x10B9, 0x5237, "M5273 USB OHCI PCI adapter(0x10B9-0x5237)"},
{0x10B9, 0x5237, 0x1849, 0x5237, "ASRock 939Dual-SATA2 Motherboard(0x1849-0x5237)"},
{0x10B9, 0x5239, 0xFFFF, 0xFFFF, "USB 2.0 Controller(0x5239)"},
{0x10B9, 0x5239, 0x10B9, 0x5239, "M5273 USB PCI adapter(0x10B9-0x5239)"},
{0x10B9, 0x5239, 0x1849, 0x5239, "ASRock 939Dual-SATA2 Motherboard(0x1849-0x5239)"},
{0x10B9, 0x5243, 0xFFFF, 0xFFFF, "M1541 PCI to AGP Controller(0x5243)"},
{0x10B9, 0x5246, 0xFFFF, 0xFFFF, "AGP8X Controller(0x5246)"},
{0x10B9, 0x5247, 0xFFFF, 0xFFFF, "PCI to AGP Controller(0x5247)"},
{0x10B9, 0x5249, 0xFFFF, 0xFFFF, "M5249 HTT to PCI Bridge(0x5249)"},
{0x10B9, 0x524B, 0xFFFF, 0xFFFF, "PCI Express Root Port(0x524B)"},
{0x10B9, 0x524C, 0xFFFF, 0xFFFF, "PCI Express Root Port(0x524C)"},
{0x10B9, 0x524D, 0xFFFF, 0xFFFF, "PCI Express Root Port(0x524D)"},
{0x10B9, 0x524E, 0xFFFF, 0xFFFF, "PCI Express Root Port(0x524E)"},
{0x10B9, 0x5251, 0xFFFF, 0xFFFF, "M5251 P1394 OHCI 1.0 Controller(0x5251)"},
{0x10B9, 0x5253, 0xFFFF, 0xFFFF, "M5253 P1394 OHCI 1.1 Controller(0x5253)"},
{0x10B9, 0x5261, 0xFFFF, 0xFFFF, "M5261 Ethernet Controller(0x5261)"},
{0x10B9, 0x5263, 0xFFFF, 0xFFFF, "ULi 1689,1573 integrated ethernet.(0x5263)"},
{0x10B9, 0x5281, 0xFFFF, 0xFFFF, "ALi M5281 Serial ATA / RAID Host Controller(0x5281)"},
{0x10B9, 0x5287, 0xFFFF, 0xFFFF, "ULi 5287 SATA(0x5287)"},
{0x10B9, 0x5288, 0xFFFF, 0xFFFF, "ULi M5288 SATA(0x5288)"},
{0x10B9, 0x5288, 0x1043, 0x8056, "A8R-MVP Mainboard(0x1043-0x8056)"},
{0x10B9, 0x5289, 0xFFFF, 0xFFFF, "ULi 5289 SATA(0x5289)"},
{0x10B9, 0x5450, 0xFFFF, 0xFFFF, "Lucent Technologies Soft Modem AMR(0x5450)"},
{0x10B9, 0x5451, 0xFFFF, 0xFFFF, "M5451 PCI AC-Link Controller Audio Device(0x5451)"},
{0x10B9, 0x5451, 0x1014, 0x0506, "ThinkPad R30(0x1014-0x0506)"},
{0x10B9, 0x5451, 0x1014, 0x053E, "ThinkPad R40e(0x1014-0x053E)"},
{0x10B9, 0x5451, 0x103C, 0x0024, "Pavilion ze4400 builtin Audio(0x103C-0x0024)"},
{0x10B9, 0x5451, 0x103C, 0x0025, "XE4500 Notebook(0x103C-0x0025)"},
{0x10B9, 0x5453, 0xFFFF, 0xFFFF, "M5453 PCI AC-Link Controller Modem Device(0x5453)"},
{0x10B9, 0x5455, 0xFFFF, 0xFFFF, "M5455 PCI AC-Link Controller Audio Device(0x5455)"},
{0x10B9, 0x5455, 0x10B9, 0x5455, "ASRock 939Dual-SATA2 Motherboard(0x10B9-0x5455)"},
{0x10B9, 0x5455, 0x1849, 0x0850, "ASRock 939Dual-SATA2 Motherboard(0x1849-0x0850)"},
{0x10B9, 0x5457, 0xFFFF, 0xFFFF, "M5457 AC'97 Modem Controller(0x5457)"},
{0x10B9, 0x5457, 0x1014, 0x0535, "ThinkPad R40e(0x1014-0x0535)"},
{0x10B9, 0x5457, 0x103C, 0x0024, "Pavilion ze4400 builtin Modem Device(0x103C-0x0024)"},
{0x10B9, 0x5457, 0x103C, 0x0025, "XE4500 Notebook(0x103C-0x0025)"},
{0x10B9, 0x5459, 0xFFFF, 0xFFFF, "SmartLink SmartPCI561 56K Modem(0x5459)"},
{0x10B9, 0x545A, 0xFFFF, 0xFFFF, "SmartLink SmartPCI563 56K Modem(0x545A)"},
{0x10B9, 0x5461, 0xFFFF, 0xFFFF, "HD Audio Controller(0x5461)"},
{0x10B9, 0x5471, 0xFFFF, 0xFFFF, "M5471 Memory Stick Controller(0x5471)"},
{0x10B9, 0x5473, 0xFFFF, 0xFFFF, "M5473 SD-MMC Controller(0x5473)"},
{0x10B9, 0x7101, 0xFFFF, 0xFFFF, "M7101 Power Management Controller [PMU](0x7101)"},
{0x10B9, 0x7101, 0x1014, 0x0510, "ThinkPad R30(0x1014-0x0510)"},
{0x10B9, 0x7101, 0x1014, 0x053C, "ThinkPad R40e(0x1014-0x053C)"},
{0x10B9, 0x7101, 0x103C, 0x0024, "Pavilion ze4400(0x103C-0x0024)"},
{0x10B9, 0x7101, 0x103C, 0x0025, "XE4500 Notebook(0x103C-0x0025)"},
{0x10B9, 0x7101, 0x1849, 0x7101, "ASRock 939Dual-SATA2 Motherboard(0x1849-0x7101)"},
}; /* pci_vid_10B9[] */

static pci_id_t const pci_vid_10BA[] = {
{0x10BA, 0xFFFF, 0xFFFF, 0xFFFF, "Mitsubishi Electric Corp.(0x10BA)"},
{0x10BA, 0x0301, 0xFFFF, 0xFFFF, "AccelGraphics AccelECLIPSE(0x0301)"},
{0x10BA, 0x0304, 0xFFFF, 0xFFFF, "AccelGALAXY A2100 [OEM Evans & Sutherland](0x0304)"},
{0x10BA, 0x0308, 0xFFFF, 0xFFFF, "Tornado 3000 [OEM Evans & Sutherland](0x0308)"},
{0x10BA, 0x0308, 0x10DD, 0x0024, "Tornado 3000(0x10DD-0x0024)"},
{0x10BA, 0x1002, 0xFFFF, 0xFFFF, "VG500 [VolumePro Volume Rendering Accelerator](0x1002)"},
}; /* pci_vid_10BA[] */

static pci_id_t const pci_vid_10BB[] = {
{0x10BB, 0xFFFF, 0xFFFF, 0xFFFF, "Dapha Electronics Corporation(0x10BB)"},
}; /* pci_vid_10BB[] */

static pci_id_t const pci_vid_10BC[] = {
{0x10BC, 0xFFFF, 0xFFFF, 0xFFFF, "Advanced Logic Research(0x10BC)"},
}; /* pci_vid_10BC[] */

static pci_id_t const pci_vid_10BD[] = {
{0x10BD, 0xFFFF, 0xFFFF, 0xFFFF, "Surecom Technology(0x10BD)"},
{0x10BD, 0x0E34, 0xFFFF, 0xFFFF, "NE-34(0x0E34)"},
}; /* pci_vid_10BD[] */

static pci_id_t const pci_vid_10BE[] = {
{0x10BE, 0xFFFF, 0xFFFF, 0xFFFF, "Tseng Labs International Co.(0x10BE)"},
}; /* pci_vid_10BE[] */

static pci_id_t const pci_vid_10BF[] = {
{0x10BF, 0xFFFF, 0xFFFF, 0xFFFF, "Most Inc(0x10BF)"},
}; /* pci_vid_10BF[] */

static pci_id_t const pci_vid_10C0[] = {
{0x10C0, 0xFFFF, 0xFFFF, 0xFFFF, "Boca Research Inc.(0x10C0)"},
{0x10C0, 0x9135, 0xFFFF, 0xFFFF, "iX3D Ultimate Rez(0x9135)"},
}; /* pci_vid_10C0[] */

static pci_id_t const pci_vid_10C1[] = {
{0x10C1, 0xFFFF, 0xFFFF, 0xFFFF, "ICM Co., Ltd.(0x10C1)"},
}; /* pci_vid_10C1[] */

static pci_id_t const pci_vid_10C2[] = {
{0x10C2, 0xFFFF, 0xFFFF, 0xFFFF, "Auspex Systems Inc.(0x10C2)"},
}; /* pci_vid_10C2[] */

static pci_id_t const pci_vid_10C3[] = {
{0x10C3, 0xFFFF, 0xFFFF, 0xFFFF, "Samsung Semiconductors, Inc.(0x10C3)"},
}; /* pci_vid_10C3[] */

static pci_id_t const pci_vid_10C4[] = {
{0x10C4, 0xFFFF, 0xFFFF, 0xFFFF, "Award Software International Inc.(0x10C4)"},
}; /* pci_vid_10C4[] */

static pci_id_t const pci_vid_10C5[] = {
{0x10C5, 0xFFFF, 0xFFFF, 0xFFFF, "Xerox Corporation(0x10C5)"},
}; /* pci_vid_10C5[] */

static pci_id_t const pci_vid_10C6[] = {
{0x10C6, 0xFFFF, 0xFFFF, 0xFFFF, "Rambus Inc.(0x10C6)"},
}; /* pci_vid_10C6[] */

static pci_id_t const pci_vid_10C7[] = {
{0x10C7, 0xFFFF, 0xFFFF, 0xFFFF, "Media Vision(0x10C7)"},
}; /* pci_vid_10C7[] */

static pci_id_t const pci_vid_10C8[] = {
{0x10C8, 0xFFFF, 0xFFFF, 0xFFFF, "Neomagic Corporation(0x10C8)"},
{0x10C8, 0x0001, 0xFFFF, 0xFFFF, "NM2070 [MagicGraph 128](0x0001)"},
{0x10C8, 0x0002, 0xFFFF, 0xFFFF, "NM2090 [MagicGraph 128V](0x0002)"},
{0x10C8, 0x0003, 0xFFFF, 0xFFFF, "NM2093 [MagicGraph 128ZV](0x0003)"},
{0x10C8, 0x0004, 0xFFFF, 0xFFFF, "NM2160 [MagicGraph 128XD](0x0004)"},
{0x10C8, 0x0004, 0x1014, 0x00BA, "MagicGraph 128XD(0x1014-0x00BA)"},
{0x10C8, 0x0004, 0x1025, 0x1007, "MagicGraph 128XD(0x1025-0x1007)"},
{0x10C8, 0x0004, 0x1028, 0x0074, "MagicGraph 128XD(0x1028-0x0074)"},
{0x10C8, 0x0004, 0x1028, 0x0075, "MagicGraph 128XD(0x1028-0x0075)"},
{0x10C8, 0x0004, 0x1028, 0x007D, "MagicGraph 128XD(0x1028-0x007D)"},
{0x10C8, 0x0004, 0x1028, 0x007E, "MagicGraph 128XD(0x1028-0x007E)"},
{0x10C8, 0x0004, 0x1033, 0x802F, "MagicGraph 128XD(0x1033-0x802F)"},
{0x10C8, 0x0004, 0x104D, 0x801B, "MagicGraph 128XD(0x104D-0x801B)"},
{0x10C8, 0x0004, 0x104D, 0x802F, "MagicGraph 128XD(0x104D-0x802F)"},
{0x10C8, 0x0004, 0x104D, 0x830B, "MagicGraph 128XD(0x104D-0x830B)"},
{0x10C8, 0x0004, 0x10BA, 0x0E00, "MagicGraph 128XD(0x10BA-0x0E00)"},
{0x10C8, 0x0004, 0x10C8, 0x0004, "MagicGraph 128XD(0x10C8-0x0004)"},
{0x10C8, 0x0004, 0x10CF, 0x1029, "MagicGraph 128XD(0x10CF-0x1029)"},
{0x10C8, 0x0004, 0x10F7, 0x8308, "MagicGraph 128XD(0x10F7-0x8308)"},
{0x10C8, 0x0004, 0x10F7, 0x8309, "MagicGraph 128XD(0x10F7-0x8309)"},
{0x10C8, 0x0004, 0x10F7, 0x830B, "MagicGraph 128XD(0x10F7-0x830B)"},
{0x10C8, 0x0004, 0x10F7, 0x830D, "MagicGraph 128XD(0x10F7-0x830D)"},
{0x10C8, 0x0004, 0x10F7, 0x8312, "MagicGraph 128XD(0x10F7-0x8312)"},
{0x10C8, 0x0005, 0xFFFF, 0xFFFF, "NM2200 [MagicGraph 256AV](0x0005)"},
{0x10C8, 0x0005, 0x1014, 0x00DD, "ThinkPad 570(0x1014-0x00DD)"},
{0x10C8, 0x0005, 0x1028, 0x0088, "Latitude CPi A(0x1028-0x0088)"},
{0x10C8, 0x0006, 0xFFFF, 0xFFFF, "NM2360 [MagicMedia 256ZX](0x0006)"},
{0x10C8, 0x0006, 0x1014, 0x0152, "ThinkPad 600X(0x1014-0x0152)"},
{0x10C8, 0x0016, 0xFFFF, 0xFFFF, "NM2380 [MagicMedia 256XL+](0x0016)"},
{0x10C8, 0x0016, 0x10C8, 0x0016, "MagicMedia 256XL+(0x10C8-0x0016)"},
{0x10C8, 0x0025, 0xFFFF, 0xFFFF, "NM2230 [MagicGraph 256AV+](0x0025)"},
{0x10C8, 0x0083, 0xFFFF, 0xFFFF, "NM2093 [MagicGraph 128ZV+](0x0083)"},
{0x10C8, 0x8005, 0xFFFF, 0xFFFF, "NM2200 [MagicMedia 256AV Audio](0x8005)"},
{0x10C8, 0x8005, 0x0E11, 0xB0D1, "MagicMedia 256AV Audio Device on Discovery(0x0E11-0xB0D1)"},
{0x10C8, 0x8005, 0x0E11, 0xB126, "MagicMedia 256AV Audio Device on Durango(0x0E11-0xB126)"},
{0x10C8, 0x8005, 0x1014, 0x00DD, "ThinkPad 390/i1720/i1721(0x1014-0x00DD)"},
{0x10C8, 0x8005, 0x1025, 0x1003, "MagicMedia 256AV Audio Device on TravelMate 720(0x1025-0x1003)"},
{0x10C8, 0x8005, 0x1028, 0x0088, "Latitude CPi A(0x1028-0x0088)"},
{0x10C8, 0x8005, 0x1028, 0x008F, "MagicMedia 256AV Audio Device on Colorado Inspiron(0x1028-0x008F)"},
{0x10C8, 0x8005, 0x103C, 0x0007, "MagicMedia 256AV Audio Device on Voyager II(0x103C-0x0007)"},
{0x10C8, 0x8005, 0x103C, 0x0008, "MagicMedia 256AV Audio Device on Voyager III(0x103C-0x0008)"},
{0x10C8, 0x8005, 0x103C, 0x000D, "MagicMedia 256AV Audio Device on Omnibook 900(0x103C-0x000D)"},
{0x10C8, 0x8005, 0x10C8, 0x8005, "MagicMedia 256AV Audio Device on FireAnt(0x10C8-0x8005)"},
{0x10C8, 0x8005, 0x110A, 0x8005, "MagicMedia 256AV Audio Device(0x110A-0x8005)"},
{0x10C8, 0x8005, 0x14C0, 0x0004, "MagicMedia 256AV Audio Device(0x14C0-0x0004)"},
{0x10C8, 0x8006, 0xFFFF, 0xFFFF, "NM2360 [MagicMedia 256ZX Audio](0x8006)"},
{0x10C8, 0x8016, 0xFFFF, 0xFFFF, "NM2380 [MagicMedia 256XL+ Audio](0x8016)"},
}; /* pci_vid_10C8[] */

static pci_id_t const pci_vid_10C9[] = {
{0x10C9, 0xFFFF, 0xFFFF, 0xFFFF, "Dataexpert Corporation(0x10C9)"},
}; /* pci_vid_10C9[] */

static pci_id_t const pci_vid_10CA[] = {
{0x10CA, 0xFFFF, 0xFFFF, 0xFFFF, "Fujitsu Microelectr., Inc.(0x10CA)"},
}; /* pci_vid_10CA[] */

static pci_id_t const pci_vid_10CB[] = {
{0x10CB, 0xFFFF, 0xFFFF, 0xFFFF, "Omron Corporation(0x10CB)"},
}; /* pci_vid_10CB[] */

static pci_id_t const pci_vid_10CC[] = {
{0x10CC, 0xFFFF, 0xFFFF, 0xFFFF, "Mai Logic Incorporated(0x10CC)"},
{0x10CC, 0x0660, 0xFFFF, 0xFFFF, "Articia S Host Bridge(0x0660)"},
{0x10CC, 0x0661, 0xFFFF, 0xFFFF, "Articia S PCI Bridge(0x0661)"},
}; /* pci_vid_10CC[] */

static pci_id_t const pci_vid_10CD[] = {
{0x10CD, 0xFFFF, 0xFFFF, 0xFFFF, "Advanced System Products, Inc(0x10CD)"},
{0x10CD, 0x1100, 0xFFFF, 0xFFFF, "ASC1100(0x1100)"},
{0x10CD, 0x1200, 0xFFFF, 0xFFFF, "ASC1200 [(abp940) Fast SCSI-II](0x1200)"},
{0x10CD, 0x1300, 0xFFFF, 0xFFFF, "ASC1300 / ASC3030 [ABP940-U / ABP960-U / ABP3925](0x1300)"},
{0x10CD, 0x1300, 0x10CD, 0x1310, "ASC1300/3030 SCSI adapter(0x10CD-0x1310)"},
{0x10CD, 0x1300, 0x1195, 0x1320, "Ultra-SCSI CardBus PC Card REX CB31(0x1195-0x1320)"},
{0x10CD, 0x2300, 0xFFFF, 0xFFFF, "ABP940-UW(0x2300)"},
{0x10CD, 0x2500, 0xFFFF, 0xFFFF, "ABP940-U2W(0x2500)"},
{0x10CD, 0x2700, 0xFFFF, 0xFFFF, "ABP3950-U3W(0x2700)"},
}; /* pci_vid_10CD[] */

static pci_id_t const pci_vid_10CE[] = {
{0x10CE, 0xFFFF, 0xFFFF, 0xFFFF, "Radius(0x10CE)"},
}; /* pci_vid_10CE[] */

static pci_id_t const pci_vid_10CF[] = {
{0x10CF, 0xFFFF, 0xFFFF, 0xFFFF, "Fujitsu Limited.(0x10CF)"},
{0x10CF, 0x01EF, 0xFFFF, 0xFFFF, "PCEA4 PCI-Express Dual Port ESCON Adapter(0x01EF)"},
{0x10CF, 0x1414, 0xFFFF, 0xFFFF, "On-board USB 1.1 companion controller(0x1414)"},
{0x10CF, 0x1415, 0xFFFF, 0xFFFF, "On-board USB 2.0 EHCI controller(0x1415)"},
{0x10CF, 0x1422, 0xFFFF, 0xFFFF, "E8410 nVidia graphics adapter(0x1422)"},
{0x10CF, 0x142D, 0xFFFF, 0xFFFF, "HD audio (Realtek ALC262)(0x142D)"},
{0x10CF, 0x1430, 0xFFFF, 0xFFFF, "82566MM Intel 1Gb copper LAN interface(0x1430)"},
{0x10CF, 0x1623, 0xFFFF, 0xFFFF, "PCEA4 PCI-Express Dual Port ESCON Adapter(0x1623)"},
{0x10CF, 0x2001, 0xFFFF, 0xFFFF, "mb86605(0x2001)"},
{0x10CF, 0x200C, 0xFFFF, 0xFFFF, "MB86613L IEEE1394 OHCI 1.0 Controller(0x200C)"},
{0x10CF, 0x2010, 0xFFFF, 0xFFFF, "MB86613S IEEE1394 OHCI 1.1 Controller(0x2010)"},
{0x10CF, 0x2019, 0xFFFF, 0xFFFF, "MB86295S [CORAL P](0x2019)"},
{0x10CF, 0x201E, 0xFFFF, 0xFFFF, "MB86296S [CORAL PA](0x201E)"},
{0x10CF, 0x202B, 0xFFFF, 0xFFFF, "MB86297A [Carmine Graphics Controller](0x202B)"},
}; /* pci_vid_10CF[] */

static pci_id_t const pci_vid_10D1[] = {
{0x10D1, 0xFFFF, 0xFFFF, 0xFFFF, "FuturePlus Systems Corp.(0x10D1)"},
}; /* pci_vid_10D1[] */

static pci_id_t const pci_vid_10D2[] = {
{0x10D2, 0xFFFF, 0xFFFF, 0xFFFF, "Molex Incorporated(0x10D2)"},
}; /* pci_vid_10D2[] */

static pci_id_t const pci_vid_10D3[] = {
{0x10D3, 0xFFFF, 0xFFFF, 0xFFFF, "Jabil Circuit Inc(0x10D3)"},
}; /* pci_vid_10D3[] */

static pci_id_t const pci_vid_10D4[] = {
{0x10D4, 0xFFFF, 0xFFFF, 0xFFFF, "Hualon Microelectronics(0x10D4)"},
}; /* pci_vid_10D4[] */

static pci_id_t const pci_vid_10D5[] = {
{0x10D5, 0xFFFF, 0xFFFF, 0xFFFF, "Autologic Inc.(0x10D5)"},
}; /* pci_vid_10D5[] */

static pci_id_t const pci_vid_10D6[] = {
{0x10D6, 0xFFFF, 0xFFFF, 0xFFFF, "Cetia(0x10D6)"},
}; /* pci_vid_10D6[] */

static pci_id_t const pci_vid_10D7[] = {
{0x10D7, 0xFFFF, 0xFFFF, 0xFFFF, "BCM Advanced Research(0x10D7)"},
}; /* pci_vid_10D7[] */

static pci_id_t const pci_vid_10D8[] = {
{0x10D8, 0xFFFF, 0xFFFF, 0xFFFF, "Advanced Peripherals Labs(0x10D8)"},
}; /* pci_vid_10D8[] */

static pci_id_t const pci_vid_10D9[] = {
{0x10D9, 0xFFFF, 0xFFFF, 0xFFFF, "Macronix, Inc. [MXIC](0x10D9)"},
{0x10D9, 0x0431, 0xFFFF, 0xFFFF, "MX98715(0x0431)"},
{0x10D9, 0x0512, 0xFFFF, 0xFFFF, "MX98713(0x0512)"},
{0x10D9, 0x0531, 0xFFFF, 0xFFFF, "MX987x5(0x0531)"},
{0x10D9, 0x0531, 0x1186, 0x1200, "DFE-540TX ProFAST 10/100 Adapter(0x1186-0x1200)"},
{0x10D9, 0x8625, 0xFFFF, 0xFFFF, "MX86250(0x8625)"},
{0x10D9, 0x8626, 0xFFFF, 0xFFFF, "Macronix MX86251 + 3Dfx Voodoo Rush(0x8626)"},
{0x10D9, 0x8888, 0xFFFF, 0xFFFF, "MX86200(0x8888)"},
}; /* pci_vid_10D9[] */

static pci_id_t const pci_vid_10DA[] = {
{0x10DA, 0xFFFF, 0xFFFF, 0xFFFF, "Compaq IPG-Austin(0x10DA)"},
{0x10DA, 0x0508, 0xFFFF, 0xFFFF, "TC4048 Token Ring 4/16(0x0508)"},
{0x10DA, 0x3390, 0xFFFF, 0xFFFF, "Tl3c3x9(0x3390)"},
}; /* pci_vid_10DA[] */

static pci_id_t const pci_vid_10DB[] = {
{0x10DB, 0xFFFF, 0xFFFF, 0xFFFF, "Rohm LSI Systems, Inc.(0x10DB)"},
}; /* pci_vid_10DB[] */

static pci_id_t const pci_vid_10DC[] = {
{0x10DC, 0xFFFF, 0xFFFF, 0xFFFF, "CERN/ECP/EDU(0x10DC)"},
{0x10DC, 0x0001, 0xFFFF, 0xFFFF, "STAR/RD24 SCI-PCI (PMC)(0x0001)"},
{0x10DC, 0x0002, 0xFFFF, 0xFFFF, "TAR/RD24 SCI-PCI (PMC)(0x0002)"},
{0x10DC, 0x0021, 0xFFFF, 0xFFFF, "HIPPI destination(0x0021)"},
{0x10DC, 0x0022, 0xFFFF, 0xFFFF, "HIPPI source(0x0022)"},
{0x10DC, 0x10DC, 0xFFFF, 0xFFFF, "ATT2C15-3 FPGA(0x10DC)"},
}; /* pci_vid_10DC[] */

static pci_id_t const pci_vid_10DD[] = {
{0x10DD, 0xFFFF, 0xFFFF, 0xFFFF, "Evans & Sutherland(0x10DD)"},
{0x10DD, 0x0100, 0xFFFF, 0xFFFF, "Lightning 1200(0x0100)"},
{0x10DD, 0x0100, 0x10DD, 0x0023, "Lightning 1200 15+16M(0x10DD-0x0023)"},
}; /* pci_vid_10DD[] */

static pci_id_t const pci_vid_10DE[] = {
{0x10DE, 0xFFFF, 0xFFFF, 0xFFFF, "NVIDIA Corporation(0x10DE)"},
{0x10DE, 0x0008, 0xFFFF, 0xFFFF, "NV1 [STG2000X-B Series](0x0008)"},
{0x10DE, 0x0009, 0xFFFF, 0xFFFF, "NV1 [NV1 Series](0x0009)"},
{0x10DE, 0x0018, 0xFFFF, 0xFFFF, "NV3 [Riva 128](0x0018)"},
{0x10DE, 0x0019, 0xFFFF, 0xFFFF, "NV3 [Riva 128ZX](0x0019)"},
{0x10DE, 0x0020, 0xFFFF, 0xFFFF, "NV4 [Riva TNT](0x0020)"},
{0x10DE, 0x0020, 0x1043, 0x0200, "V3400 TNT(0x1043-0x0200)"},
{0x10DE, 0x0020, 0x1048, 0x0C18, "Erazor II SGRAM(0x1048-0x0C18)"},
{0x10DE, 0x0020, 0x1048, 0x0C19, "Erazor II(0x1048-0x0C19)"},
{0x10DE, 0x0020, 0x1048, 0x0C1B, "Erazor II(0x1048-0x0C1B)"},
{0x10DE, 0x0020, 0x1048, 0x0C1C, "Erazor II(0x1048-0x0C1C)"},
{0x10DE, 0x0020, 0x1092, 0x0550, "Viper V550(0x1092-0x0550)"},
{0x10DE, 0x0020, 0x1092, 0x0552, "Viper V550(0x1092-0x0552)"},
{0x10DE, 0x0020, 0x1092, 0x4804, "Viper V550(0x1092-0x4804)"},
{0x10DE, 0x0020, 0x1092, 0x4808, "Viper V550(0x1092-0x4808)"},
{0x10DE, 0x0020, 0x1092, 0x4810, "Viper V550(0x1092-0x4810)"},
{0x10DE, 0x0020, 0x1092, 0x4812, "Viper V550(0x1092-0x4812)"},
{0x10DE, 0x0020, 0x1092, 0x4815, "Viper V550(0x1092-0x4815)"},
{0x10DE, 0x0020, 0x1092, 0x4820, "Viper V550 with TV out(0x1092-0x4820)"},
{0x10DE, 0x0020, 0x1092, 0x4822, "Viper V550(0x1092-0x4822)"},
{0x10DE, 0x0020, 0x1092, 0x4904, "Viper V550(0x1092-0x4904)"},
{0x10DE, 0x0020, 0x1092, 0x4914, "Viper V550(0x1092-0x4914)"},
{0x10DE, 0x0020, 0x1092, 0x8225, "Viper V550(0x1092-0x8225)"},
{0x10DE, 0x0020, 0x10B4, 0x273D, "Velocity 4400(0x10B4-0x273D)"},
{0x10DE, 0x0020, 0x10B4, 0x273E, "Velocity 4400(0x10B4-0x273E)"},
{0x10DE, 0x0020, 0x10B4, 0x2740, "Velocity 4400(0x10B4-0x2740)"},
{0x10DE, 0x0020, 0x10DE, 0x0020, "Riva TNT(0x10DE-0x0020)"},
{0x10DE, 0x0020, 0x1102, 0x1015, "Graphics Blaster CT6710(0x1102-0x1015)"},
{0x10DE, 0x0020, 0x1102, 0x1016, "Graphics Blaster RIVA TNT(0x1102-0x1016)"},
{0x10DE, 0x0028, 0xFFFF, 0xFFFF, "NV5 [Riva TNT2 / TNT2 Pro](0x0028)"},
{0x10DE, 0x0028, 0x1043, 0x0200, "AGP-V3800 SGRAM(0x1043-0x0200)"},
{0x10DE, 0x0028, 0x1043, 0x0201, "AGP-V3800 SDRAM(0x1043-0x0201)"},
{0x10DE, 0x0028, 0x1043, 0x0205, "PCI-V3800(0x1043-0x0205)"},
{0x10DE, 0x0028, 0x1043, 0x4000, "AGP-V3800PRO(0x1043-0x4000)"},
{0x10DE, 0x0028, 0x1048, 0x0C21, "Synergy II(0x1048-0x0C21)"},
{0x10DE, 0x0028, 0x1048, 0x0C28, "Erazor III(0x1048-0x0C28)"},
{0x10DE, 0x0028, 0x1048, 0x0C29, "Erazor III(0x1048-0x0C29)"},
{0x10DE, 0x0028, 0x1048, 0x0C2A, "Erazor III(0x1048-0x0C2A)"},
{0x10DE, 0x0028, 0x1048, 0x0C2B, "Erazor III(0x1048-0x0C2B)"},
{0x10DE, 0x0028, 0x1048, 0x0C31, "Erazor III Pro(0x1048-0x0C31)"},
{0x10DE, 0x0028, 0x1048, 0x0C32, "Erazor III Pro(0x1048-0x0C32)"},
{0x10DE, 0x0028, 0x1048, 0x0C33, "Erazor III Pro(0x1048-0x0C33)"},
{0x10DE, 0x0028, 0x1048, 0x0C34, "Erazor III Pro(0x1048-0x0C34)"},
{0x10DE, 0x0028, 0x107D, 0x2134, "WinFast 3D S320 II + TV-Out(0x107D-0x2134)"},
{0x10DE, 0x0028, 0x1092, 0x4804, "Viper V770(0x1092-0x4804)"},
{0x10DE, 0x0028, 0x1092, 0x4A00, "Viper V770(0x1092-0x4A00)"},
{0x10DE, 0x0028, 0x1092, 0x4A02, "Viper V770 Ultra(0x1092-0x4A02)"},
{0x10DE, 0x0028, 0x1092, 0x5A00, "RIVA TNT2/TNT2 Pro(0x1092-0x5A00)"},
{0x10DE, 0x0028, 0x1092, 0x5A40, "Viper V770D AGP(0x1092-0x5A40)"},
{0x10DE, 0x0028, 0x1092, 0x6A02, "Viper V770 Ultra(0x1092-0x6A02)"},
{0x10DE, 0x0028, 0x1092, 0x7A02, "Viper V770 Ultra(0x1092-0x7A02)"},
{0x10DE, 0x0028, 0x10DE, 0x0005, "RIVA TNT2 Pro(0x10DE-0x0005)"},
{0x10DE, 0x0028, 0x10DE, 0x000F, "Compaq NVIDIA TNT2 Pro(0x10DE-0x000F)"},
{0x10DE, 0x0028, 0x1102, 0x1020, "3D Blaster RIVA TNT2(0x1102-0x1020)"},
{0x10DE, 0x0028, 0x1102, 0x1026, "3D Blaster RIVA TNT2 Digital(0x1102-0x1026)"},
{0x10DE, 0x0028, 0x1462, 0x8806, "MS-8806 AGPhantom Graphics Card(0x1462-0x8806)"},
{0x10DE, 0x0028, 0x14AF, 0x5810, "Maxi Gamer Xentor(0x14AF-0x5810)"},
{0x10DE, 0x0029, 0xFFFF, 0xFFFF, "NV5 [Riva TNT2 Ultra](0x0029)"},
{0x10DE, 0x0029, 0x1043, 0x0200, "AGP-V3800 Deluxe(0x1043-0x0200)"},
{0x10DE, 0x0029, 0x1043, 0x0201, "AGP-V3800 Ultra SDRAM(0x1043-0x0201)"},
{0x10DE, 0x0029, 0x1043, 0x0205, "PCI-V3800 Ultra(0x1043-0x0205)"},
{0x10DE, 0x0029, 0x1048, 0x0C2E, "Erazor III Ultra(0x1048-0x0C2E)"},
{0x10DE, 0x0029, 0x1048, 0x0C2F, "Erazor III Ultra(0x1048-0x0C2F)"},
{0x10DE, 0x0029, 0x1048, 0x0C30, "Erazor III Ultra(0x1048-0x0C30)"},
{0x10DE, 0x0029, 0x1102, 0x1021, "3D Blaster RIVA TNT2 Ultra(0x1102-0x1021)"},
{0x10DE, 0x0029, 0x1102, 0x1029, "3D Blaster RIVA TNT2 Ultra(0x1102-0x1029)"},
{0x10DE, 0x0029, 0x1102, 0x102F, "3D Blaster RIVA TNT2 Ultra(0x1102-0x102F)"},
{0x10DE, 0x0029, 0x14AF, 0x5820, "Maxi Gamer Xentor 32(0x14AF-0x5820)"},
{0x10DE, 0x0029, 0x4843, 0x4F34, "Dynamite(0x4843-0x4F34)"},
{0x10DE, 0x002A, 0xFFFF, 0xFFFF, "NV5 [Riva TNT2](0x002A)"},
{0x10DE, 0x002B, 0xFFFF, 0xFFFF, "NV5 [Riva TNT2](0x002B)"},
{0x10DE, 0x002C, 0xFFFF, 0xFFFF, "NV5 [Vanta / Vanta LT](0x002C)"},
{0x10DE, 0x002C, 0x1043, 0x0200, "AGP-V3800 Combat SDRAM(0x1043-0x0200)"},
{0x10DE, 0x002C, 0x1043, 0x0201, "AGP-V3800 Combat(0x1043-0x0201)"},
{0x10DE, 0x002C, 0x1048, 0x0C20, "TNT2 Vanta(0x1048-0x0C20)"},
{0x10DE, 0x002C, 0x1048, 0x0C21, "TNT2 Vanta(0x1048-0x0C21)"},
{0x10DE, 0x002C, 0x1048, 0x0C25, "TNT2 Vanta 16MB(0x1048-0x0C25)"},
{0x10DE, 0x002C, 0x1092, 0x6820, "Viper V730(0x1092-0x6820)"},
{0x10DE, 0x002C, 0x1102, 0x1031, "CT6938 VANTA 8MB(0x1102-0x1031)"},
{0x10DE, 0x002C, 0x1102, 0x1034, "CT6894 VANTA 16MB(0x1102-0x1034)"},
{0x10DE, 0x002C, 0x14AF, 0x5008, "Maxi Gamer Phoenix 2(0x14AF-0x5008)"},
{0x10DE, 0x002D, 0xFFFF, 0xFFFF, "NV5 [Riva TNT2 Model 64 / Model 64 Pro](0x002D)"},
{0x10DE, 0x002D, 0x1043, 0x0200, "AGP-V3800M(0x1043-0x0200)"},
{0x10DE, 0x002D, 0x1043, 0x0201, "AGP-V3800M(0x1043-0x0201)"},
{0x10DE, 0x002D, 0x1048, 0x0C3A, "Erazor III LT(0x1048-0x0C3A)"},
{0x10DE, 0x002D, 0x1048, 0x0C3B, "Erazor III LT(0x1048-0x0C3B)"},
{0x10DE, 0x002D, 0x107D, 0x2137, "WinFast 3D S325(0x107D-0x2137)"},
{0x10DE, 0x002D, 0x10DE, 0x0006, "RIVA TNT2 Model 64/Model 64 Pro(0x10DE-0x0006)"},
{0x10DE, 0x002D, 0x10DE, 0x001E, "M64 AGP4x(0x10DE-0x001E)"},
{0x10DE, 0x002D, 0x1102, 0x1023, "CT6892 RIVA TNT2 Value(0x1102-0x1023)"},
{0x10DE, 0x002D, 0x1102, 0x1024, "CT6932 RIVA TNT2 Value 32Mb(0x1102-0x1024)"},
{0x10DE, 0x002D, 0x1102, 0x102C, "CT6931 RIVA TNT2 Value [Jumper](0x1102-0x102C)"},
{0x10DE, 0x002D, 0x1102, 0x1030, "CT6931 RIVA TNT2 Value(0x1102-0x1030)"},
{0x10DE, 0x002D, 0x110A, 0x006F, "GM1000-16(0x110A-0x006F)"},
{0x10DE, 0x002D, 0x110A, 0x0081, "GM1000-16(0x110A-0x0081)"},
{0x10DE, 0x002D, 0x1462, 0x8808, "MSI-8808(0x1462-0x8808)"},
{0x10DE, 0x002D, 0x14AF, 0x5620, "Gamer Cougar Video Edition(0x14AF-0x5620)"},
{0x10DE, 0x002D, 0x1554, 0x1041, "Pixelview RIVA TNT2 M64(0x1554-0x1041)"},
{0x10DE, 0x002D, 0x1569, 0x002D, "Palit Microsystems Daytona TNT2 M64(0x1569-0x002D)"},
{0x10DE, 0x0034, 0xFFFF, 0xFFFF, "MCP04 SMBus(0x0034)"},
{0x10DE, 0x0035, 0xFFFF, 0xFFFF, "MCP04 IDE(0x0035)"},
{0x10DE, 0x0036, 0xFFFF, 0xFFFF, "MCP04 Serial ATA Controller(0x0036)"},
{0x10DE, 0x0037, 0xFFFF, 0xFFFF, "MCP04 Ethernet Controller(0x0037)"},
{0x10DE, 0x0038, 0xFFFF, 0xFFFF, "MCP04 Ethernet Controller(0x0038)"},
{0x10DE, 0x003A, 0xFFFF, 0xFFFF, "MCP04 AC'97 Audio Controller(0x003A)"},
{0x10DE, 0x003B, 0xFFFF, 0xFFFF, "MCP04 USB Controller(0x003B)"},
{0x10DE, 0x003C, 0xFFFF, 0xFFFF, "MCP04 USB Controller(0x003C)"},
{0x10DE, 0x003D, 0xFFFF, 0xFFFF, "MCP04 PCI Bridge(0x003D)"},
{0x10DE, 0x003E, 0xFFFF, 0xFFFF, "MCP04 Serial ATA Controller(0x003E)"},
{0x10DE, 0x0040, 0xFFFF, 0xFFFF, "NV40 [GeForce 6800 Ultra](0x0040)"},
{0x10DE, 0x0041, 0xFFFF, 0xFFFF, "NV40 [GeForce 6800](0x0041)"},
{0x10DE, 0x0041, 0x1043, 0x817B, "V9999 Gamer Edition(0x1043-0x817B)"},
{0x10DE, 0x0041, 0x107D, 0x2992, "WinFast A400(0x107D-0x2992)"},
{0x10DE, 0x0041, 0x1458, 0x310F, "Geforce 6800 GV-N6812(0x1458-0x310F)"},
{0x10DE, 0x0042, 0xFFFF, 0xFFFF, "NV40 [GeForce 6800 LE](0x0042)"},
{0x10DE, 0x0042, 0x107D, 0x299B, "WinFast A400 LE(0x107D-0x299B)"},
{0x10DE, 0x0043, 0xFFFF, 0xFFFF, "NV40 [GeForce 6800 XE](0x0043)"},
{0x10DE, 0x0044, 0xFFFF, 0xFFFF, "NV40 [GeForce 6800 XT](0x0044)"},
{0x10DE, 0x0045, 0xFFFF, 0xFFFF, "NV40 [GeForce 6800 GT](0x0045)"},
{0x10DE, 0x0045, 0x1043, 0x817D, "V9999GT(0x1043-0x817D)"},
{0x10DE, 0x0045, 0x1458, 0x3140, "GV-N68T256D(0x1458-0x3140)"},
{0x10DE, 0x0047, 0xFFFF, 0xFFFF, "NV40 [GeForce 6800 GS](0x0047)"},
{0x10DE, 0x0047, 0x1682, 0x2109, "GeForce 6800 GS(0x1682-0x2109)"},
{0x10DE, 0x0048, 0xFFFF, 0xFFFF, "NV40 [GeForce 6800 XT](0x0048)"},
{0x10DE, 0x004E, 0xFFFF, 0xFFFF, "NV40GL [Quadro FX 4000](0x004E)"},
{0x10DE, 0x0050, 0xFFFF, 0xFFFF, "CK804 ISA Bridge(0x0050)"},
{0x10DE, 0x0050, 0x1043, 0x815A, "K8N4/A8N Series Mainboard(0x1043-0x815A)"},
{0x10DE, 0x0050, 0x10F1, 0x2865, "Tomcat K8E (S2865)(0x10F1-0x2865)"},
{0x10DE, 0x0050, 0x1458, 0x0C11, "GA-K8N Ultra-9 Mainboard(0x1458-0x0C11)"},
{0x10DE, 0x0050, 0x1462, 0x7100, "MSI K8N Diamond(0x1462-0x7100)"},
{0x10DE, 0x0050, 0x1462, 0x7125, "K8N Neo4-F mainboard(0x1462-0x7125)"},
{0x10DE, 0x0050, 0x147B, 0x1C1A, "KN8-Ultra Mainboard(0x147B-0x1C1A)"},
{0x10DE, 0x0050, 0x1565, 0x3402, "NF4 AM2L Mainboard(0x1565-0x3402)"},
{0x10DE, 0x0051, 0xFFFF, 0xFFFF, "CK804 ISA Bridge(0x0051)"},
{0x10DE, 0x0051, 0x1028, 0x0225, "PowerEdge T105 ISA Bridge(0x1028-0x0225)"},
{0x10DE, 0x0052, 0xFFFF, 0xFFFF, "CK804 SMBus(0x0052)"},
{0x10DE, 0x0052, 0x1028, 0x0225, "PowerEdge T105 SMBus(0x1028-0x0225)"},
{0x10DE, 0x0052, 0x1043, 0x815A, "K8N4/A8N Series Mainboard(0x1043-0x815A)"},
{0x10DE, 0x0052, 0x10F1, 0x2865, "Tomcat K8E (S2865)(0x10F1-0x2865)"},
{0x10DE, 0x0052, 0x1458, 0x0C11, "GA-K8N Ultra-9 Mainboard(0x1458-0x0C11)"},
{0x10DE, 0x0052, 0x1462, 0x7100, "MSI K8N Diamond(0x1462-0x7100)"},
{0x10DE, 0x0052, 0x1462, 0x7125, "K8N Neo4-F mainboard(0x1462-0x7125)"},
{0x10DE, 0x0052, 0x147B, 0x1C1A, "KN8-Ultra Mainboard(0x147B-0x1C1A)"},
{0x10DE, 0x0052, 0x1565, 0x3402, "NF4 AM2L Mainboard(0x1565-0x3402)"},
{0x10DE, 0x0053, 0xFFFF, 0xFFFF, "CK804 IDE(0x0053)"},
{0x10DE, 0x0053, 0x1043, 0x815A, "K8N4/A8N Series Mainboard(0x1043-0x815A)"},
{0x10DE, 0x0053, 0x10F1, 0x2865, "Tomcat K8E (S2865)(0x10F1-0x2865)"},
{0x10DE, 0x0053, 0x1458, 0x5002, "GA-K8N Ultra-9 Mainboard(0x1458-0x5002)"},
{0x10DE, 0x0053, 0x1462, 0x7100, "MSI K8N Diamond(0x1462-0x7100)"},
{0x10DE, 0x0053, 0x1462, 0x7125, "K8N Neo4-F mainboard(0x1462-0x7125)"},
{0x10DE, 0x0053, 0x147B, 0x1C1A, "KN8-Ultra Mainboard(0x147B-0x1C1A)"},
{0x10DE, 0x0053, 0x1565, 0x3402, "NF4 AM2L Mainboard(0x1565-0x3402)"},
{0x10DE, 0x0054, 0xFFFF, 0xFFFF, "CK804 Serial ATA Controller(0x0054)"},
{0x10DE, 0x0054, 0x1028, 0x0225, "PowerEdge T105 Serial ATA(0x1028-0x0225)"},
{0x10DE, 0x0054, 0x1043, 0x815A, "A8N Series Mainboard(0x1043-0x815A)"},
{0x10DE, 0x0054, 0x10F1, 0x2865, "Tomcat K8E (S2865)(0x10F1-0x2865)"},
{0x10DE, 0x0054, 0x1458, 0xB003, "GA-K8N Ultra-9 Mainboard(0x1458-0xB003)"},
{0x10DE, 0x0054, 0x1462, 0x7100, "MSI K8N Diamond(0x1462-0x7100)"},
{0x10DE, 0x0054, 0x1462, 0x7125, "K8N Neo4-F mainboard(0x1462-0x7125)"},
{0x10DE, 0x0054, 0x147B, 0x1C1A, "KN8-Ultra Mainboard(0x147B-0x1C1A)"},
{0x10DE, 0x0054, 0x1565, 0x5401, "NF4 AM2L Mainboard(0x1565-0x5401)"},
{0x10DE, 0x0055, 0xFFFF, 0xFFFF, "CK804 Serial ATA Controller(0x0055)"},
{0x10DE, 0x0055, 0x1028, 0x0225, "PowerEdge T105 Serial ATA(0x1028-0x0225)"},
{0x10DE, 0x0055, 0x1043, 0x815A, "K8N4/A8N Series Mainboard(0x1043-0x815A)"},
{0x10DE, 0x0055, 0x10F1, 0x2865, "Tomcat K8E (S2865)(0x10F1-0x2865)"},
{0x10DE, 0x0055, 0x1458, 0xB003, "GA-K8N Ultra-9 Mainboard(0x1458-0xB003)"},
{0x10DE, 0x0055, 0x1462, 0x7125, "K8N Neo4-F mainboard(0x1462-0x7125)"},
{0x10DE, 0x0055, 0x147B, 0x1C1A, "KN8-Ultra Mainboard(0x147B-0x1C1A)"},
{0x10DE, 0x0055, 0x1565, 0x5401, "NF4 AM2L Mainboard(0x1565-0x5401)"},
{0x10DE, 0x0056, 0xFFFF, 0xFFFF, "CK804 Ethernet Controller(0x0056)"},
{0x10DE, 0x0057, 0xFFFF, 0xFFFF, "CK804 Ethernet Controller(0x0057)"},
{0x10DE, 0x0057, 0x1043, 0x8141, "K8N4/A8N Series Mainboard(0x1043-0x8141)"},
{0x10DE, 0x0057, 0x10DE, 0xCB84, "NF4 Lanparty(0x10DE-0xCB84)"},
{0x10DE, 0x0057, 0x10F1, 0x2865, "Tomcat K8E (S2865)(0x10F1-0x2865)"},
{0x10DE, 0x0057, 0x1458, 0xE000, "GA-K8N Ultra-9 Mainboard(0x1458-0xE000)"},
{0x10DE, 0x0057, 0x1462, 0x7100, "MSI K8N Diamond(0x1462-0x7100)"},
{0x10DE, 0x0057, 0x1462, 0x7125, "K8N Neo4-F mainboard(0x1462-0x7125)"},
{0x10DE, 0x0057, 0x147B, 0x1C1A, "KN8-Ultra Mainboard(0x147B-0x1C1A)"},
{0x10DE, 0x0057, 0x1565, 0x2501, "NF4 AM2L Mainboard(0x1565-0x2501)"},
{0x10DE, 0x0058, 0xFFFF, 0xFFFF, "CK804 AC'97 Modem(0x0058)"},
{0x10DE, 0x0059, 0xFFFF, 0xFFFF, "CK804 AC'97 Audio Controller(0x0059)"},
{0x10DE, 0x0059, 0x1043, 0x812A, "K8N4/A8N Series Mainboard(0x1043-0x812A)"},
{0x10DE, 0x0059, 0x10F1, 0x2865, "Tomcat K8E (S2865)(0x10F1-0x2865)"},
{0x10DE, 0x0059, 0x1462, 0x7585, "K8N Neo4-F mainboard(0x1462-0x7585)"},
{0x10DE, 0x0059, 0x147B, 0x1C1A, "KN8-Ultra Mainboard(0x147B-0x1C1A)"},
{0x10DE, 0x0059, 0x1565, 0x8211, "NF4 AM2L Mainboard(0x1565-0x8211)"},
{0x10DE, 0x005A, 0xFFFF, 0xFFFF, "CK804 USB Controller(0x005A)"},
{0x10DE, 0x005A, 0x1028, 0x0225, "PowerEdge T105 onboard USB(0x1028-0x0225)"},
{0x10DE, 0x005A, 0x1043, 0x815A, "K8N4/A8N Series Mainboard(0x1043-0x815A)"},
{0x10DE, 0x005A, 0x10F1, 0x2865, "Tomcat K8E (S2865)(0x10F1-0x2865)"},
{0x10DE, 0x005A, 0x1458, 0x5004, "GA-K8N Ultra-9 Mainboard(0x1458-0x5004)"},
{0x10DE, 0x005A, 0x1462, 0x7100, "MSI K8N Diamond(0x1462-0x7100)"},
{0x10DE, 0x005A, 0x1462, 0x7125, "K8N Neo4-F mainboard(0x1462-0x7125)"},
{0x10DE, 0x005A, 0x147B, 0x1C1A, "KN8-Ultra Mainboard(0x147B-0x1C1A)"},
{0x10DE, 0x005A, 0x1565, 0x3402, "NF4 AM2L Mainboard(0x1565-0x3402)"},
{0x10DE, 0x005B, 0xFFFF, 0xFFFF, "CK804 USB Controller(0x005B)"},
{0x10DE, 0x005B, 0x1028, 0x0225, "PowerEdge T105 onboard USB(0x1028-0x0225)"},
{0x10DE, 0x005B, 0x1043, 0x815A, "K8N4/A8N Series Mainboard(0x1043-0x815A)"},
{0x10DE, 0x005B, 0x10F1, 0x2865, "Tomcat K8E (S2865)(0x10F1-0x2865)"},
{0x10DE, 0x005B, 0x1458, 0x5004, "GA-K8N Ultra-9 Mainboard(0x1458-0x5004)"},
{0x10DE, 0x005B, 0x1462, 0x7100, "MSI K8N Diamond(0x1462-0x7100)"},
{0x10DE, 0x005B, 0x1462, 0x7125, "K8N Neo4-F mainboard(0x1462-0x7125)"},
{0x10DE, 0x005B, 0x147B, 0x1C1A, "KN8-Ultra Mainboard(0x147B-0x1C1A)"},
{0x10DE, 0x005B, 0x1565, 0x3402, "NF4 AM2L Mainboard(0x1565-0x3402)"},
{0x10DE, 0x005C, 0xFFFF, 0xFFFF, "CK804 PCI Bridge(0x005C)"},
{0x10DE, 0x005D, 0xFFFF, 0xFFFF, "CK804 PCIE Bridge(0x005D)"},
{0x10DE, 0x005E, 0xFFFF, 0xFFFF, "CK804 Memory Controller(0x005E)"},
{0x10DE, 0x005E, 0x1028, 0x0225, "PowerEdge T105 Memory Controller(0x1028-0x0225)"},
{0x10DE, 0x005E, 0x1043, 0x815A, "A8N Series Mainboard(0x1043-0x815A)"},
{0x10DE, 0x005E, 0x10DE, 0x005E, "ECS Elitegroup NFORCE3-A939 motherboard.(0x10DE-0x005E)"},
{0x10DE, 0x005E, 0x10F1, 0x2865, "Tomcat K8E (S2865)(0x10F1-0x2865)"},
{0x10DE, 0x005E, 0x10F1, 0x2891, "Thunder K8SRE Mainboard(0x10F1-0x2891)"},
{0x10DE, 0x005E, 0x1458, 0x5000, "GA-K8N Ultra-9 Mainboard(0x1458-0x5000)"},
{0x10DE, 0x005E, 0x1462, 0x7100, "K8N Diamond Mainboard(0x1462-0x7100)"},
{0x10DE, 0x005E, 0x1462, 0x7125, "K8N Neo4-F Mainboard(0x1462-0x7125)"},
{0x10DE, 0x005E, 0x147B, 0x1C1A, "KN8-Ultra Mainboard(0x147B-0x1C1A)"},
{0x10DE, 0x005E, 0x1565, 0x3402, "NF4 AM2L Mainboard(0x1565-0x3402)"},
{0x10DE, 0x005F, 0xFFFF, 0xFFFF, "CK804 Memory Controller(0x005F)"},
{0x10DE, 0x0060, 0xFFFF, 0xFFFF, "nForce2 ISA Bridge(0x0060)"},
{0x10DE, 0x0060, 0x1043, 0x80AD, "A7N8X Mainboard(0x1043-0x80AD)"},
{0x10DE, 0x0060, 0x147B, 0x1C02, "NF7-S/NF7 (nVidia-nForce2) 2.X(0x147B-0x1C02)"},
{0x10DE, 0x0060, 0xA0A0, 0x03BA, "UK79G-1394 motherboard(0xA0A0-0x03BA)"},
{0x10DE, 0x0064, 0xFFFF, 0xFFFF, "nForce2 SMBus (MCP)(0x0064)"},
{0x10DE, 0x0064, 0x147B, 0x1C02, "NF7-S/NF7 (nVidia-nForce2) 2.X(0x147B-0x1C02)"},
{0x10DE, 0x0064, 0xA0A0, 0x03BB, "UK79G-1394 motherboard(0xA0A0-0x03BB)"},
{0x10DE, 0x0065, 0xFFFF, 0xFFFF, "nForce2 IDE(0x0065)"},
{0x10DE, 0x0065, 0x10DE, 0x0C11, "nForce 2 EIDE Controller(0x10DE-0x0C11)"},
{0x10DE, 0x0065, 0xA0A0, 0x03B2, "UK79G-1394 motherboard(0xA0A0-0x03B2)"},
{0x10DE, 0x0066, 0xFFFF, 0xFFFF, "nForce2 Ethernet Controller(0x0066)"},
{0x10DE, 0x0066, 0x1043, 0x80A7, "A7N8X Mainboard onboard nForce2 Ethernet(0x1043-0x80A7)"},
{0x10DE, 0x0066, 0x10DE, 0x0C11, "nForce MCP-T Networking Adapter(0x10DE-0x0C11)"},
{0x10DE, 0x0066, 0xA0A0, 0x03B3, "UK79G-1394 motherboard(0xA0A0-0x03B3)"},
{0x10DE, 0x0067, 0xFFFF, 0xFFFF, "nForce2 USB Controller(0x0067)"},
{0x10DE, 0x0067, 0x1043, 0x0C11, "A7N8X Mainboard(0x1043-0x0C11)"},
{0x10DE, 0x0067, 0xA0A0, 0x03B4, "UK79G-1394 motherboard(0xA0A0-0x03B4)"},
{0x10DE, 0x0068, 0xFFFF, 0xFFFF, "nForce2 USB Controller(0x0068)"},
{0x10DE, 0x0068, 0x1043, 0x0C11, "A7N8X Mainboard(0x1043-0x0C11)"},
{0x10DE, 0x0068, 0xA0A0, 0x03B4, "UK79G-1394 motherboard(0xA0A0-0x03B4)"},
{0x10DE, 0x006A, 0xFFFF, 0xFFFF, "nForce2 AC97 Audio Controler (MCP)(0x006A)"},
{0x10DE, 0x006A, 0x1043, 0x8095, "nForce2 AC97 Audio Controller (MCP)(0x1043-0x8095)"},
{0x10DE, 0x006A, 0xA0A0, 0x0304, "UK79G-1394 motherboard(0xA0A0-0x0304)"},
{0x10DE, 0x006B, 0xFFFF, 0xFFFF, "nForce Audio Processing Unit(0x006B)"},
{0x10DE, 0x006B, 0x10DE, 0x006B, "nForce2 MCP Audio Processing Unit(0x10DE-0x006B)"},
{0x10DE, 0x006B, 0xA0A0, 0x0304, "UK79G-1394 motherboard(0xA0A0-0x0304)"},
{0x10DE, 0x006C, 0xFFFF, 0xFFFF, "nForce2 External PCI Bridge(0x006C)"},
{0x10DE, 0x006D, 0xFFFF, 0xFFFF, "nForce2 PCI Bridge(0x006D)"},
{0x10DE, 0x006E, 0xFFFF, 0xFFFF, "nForce2 FireWire (IEEE 1394) Controller(0x006E)"},
{0x10DE, 0x006E, 0xA0A0, 0x0306, "UK79G-1394 motherboard(0xA0A0-0x0306)"},
{0x10DE, 0x0080, 0xFFFF, 0xFFFF, "MCP2A ISA bridge(0x0080)"},
{0x10DE, 0x0080, 0x147B, 0x1C09, "NV7 Motherboard(0x147B-0x1C09)"},
{0x10DE, 0x0084, 0xFFFF, 0xFFFF, "MCP2A SMBus(0x0084)"},
{0x10DE, 0x0084, 0x147B, 0x1C09, "NV7 Motherboard(0x147B-0x1C09)"},
{0x10DE, 0x0085, 0xFFFF, 0xFFFF, "MCP2A IDE(0x0085)"},
{0x10DE, 0x0085, 0x147B, 0x1C09, "NV7 Motherboard(0x147B-0x1C09)"},
{0x10DE, 0x0086, 0xFFFF, 0xFFFF, "MCP2A Ethernet Controller(0x0086)"},
{0x10DE, 0x0087, 0xFFFF, 0xFFFF, "MCP2A USB Controller(0x0087)"},
{0x10DE, 0x0087, 0x147B, 0x1C09, "NV7 Motherboard(0x147B-0x1C09)"},
{0x10DE, 0x0088, 0xFFFF, 0xFFFF, "MCP2A USB Controller(0x0088)"},
{0x10DE, 0x0088, 0x147B, 0x1C09, "NV7 Motherboard(0x147B-0x1C09)"},
{0x10DE, 0x008A, 0xFFFF, 0xFFFF, "MCP2S AC'97 Audio Controller(0x008A)"},
{0x10DE, 0x008A, 0x147B, 0x1C09, "NV7 Motherboard(0x147B-0x1C09)"},
{0x10DE, 0x008B, 0xFFFF, 0xFFFF, "MCP2A PCI Bridge(0x008B)"},
{0x10DE, 0x008C, 0xFFFF, 0xFFFF, "MCP2A Ethernet Controller(0x008C)"},
{0x10DE, 0x008E, 0xFFFF, 0xFFFF, "nForce2 Serial ATA Controller(0x008E)"},
{0x10DE, 0x0090, 0xFFFF, 0xFFFF, "G70 [GeForce 7800 GTX](0x0090)"},
{0x10DE, 0x0091, 0xFFFF, 0xFFFF, "G70 [GeForce 7800 GTX](0x0091)"},
{0x10DE, 0x0092, 0xFFFF, 0xFFFF, "G70 [GeForce 7800 GT](0x0092)"},
{0x10DE, 0x0093, 0xFFFF, 0xFFFF, "G70 [GeForce 7800 GS](0x0093)"},
{0x10DE, 0x0094, 0xFFFF, 0xFFFF, "High Definition Audio(0x0094)"},
{0x10DE, 0x0095, 0xFFFF, 0xFFFF, "G70 [GeForce 7800 SLI](0x0095)"},
{0x10DE, 0x0097, 0xFFFF, 0xFFFF, "G70 [GeForce GTS 250](0x0097)"},
{0x10DE, 0x0098, 0xFFFF, 0xFFFF, "G70M [GeForce Go 7800](0x0098)"},
{0x10DE, 0x0099, 0xFFFF, 0xFFFF, "G70M [GeForce Go 7800 GTX](0x0099)"},
{0x10DE, 0x009D, 0xFFFF, 0xFFFF, "G70GL [Quadro FX 4500](0x009D)"},
{0x10DE, 0x00A0, 0xFFFF, 0xFFFF, "NV0A [Aladdin TNT2 IGP](0x00A0)"},
{0x10DE, 0x00A0, 0x14AF, 0x5810, "Maxi Gamer Xentor(0x14AF-0x5810)"},
{0x10DE, 0x00C0, 0xFFFF, 0xFFFF, "NV41 [GeForce 6800 GS](0x00C0)"},
{0x10DE, 0x00C1, 0xFFFF, 0xFFFF, "NV41 [GeForce 6800](0x00C1)"},
{0x10DE, 0x00C2, 0xFFFF, 0xFFFF, "NV41 [GeForce 6800 LE](0x00C2)"},
{0x10DE, 0x00C3, 0xFFFF, 0xFFFF, "NV41 [GeForce 6800 XT](0x00C3)"},
{0x10DE, 0x00C5, 0xFFFF, 0xFFFF, "NV41(0x00C5)"},
{0x10DE, 0x00C6, 0xFFFF, 0xFFFF, "NV41(0x00C6)"},
{0x10DE, 0x00C7, 0xFFFF, 0xFFFF, "NV41(0x00C7)"},
{0x10DE, 0x00C8, 0xFFFF, 0xFFFF, "NV41M [GeForce Go 6800](0x00C8)"},
{0x10DE, 0x00C9, 0xFFFF, 0xFFFF, "NV41M [GeForce Go 6800 Ultra](0x00C9)"},
{0x10DE, 0x00CC, 0xFFFF, 0xFFFF, "NV41GLM [Quadro FX Go1400](0x00CC)"},
{0x10DE, 0x00CD, 0xFFFF, 0xFFFF, "NV42GL [Quadro FX 3450/4000 SDI](0x00CD)"},
{0x10DE, 0x00CD, 0x10DE, 0x029B, "Quadro FX 3450(0x10DE-0x029B)"},
{0x10DE, 0x00CE, 0xFFFF, 0xFFFF, "NV41GL [Quadro FX 1400](0x00CE)"},
{0x10DE, 0x00CF, 0xFFFF, 0xFFFF, "NV41(0x00CF)"},
{0x10DE, 0x00D0, 0xFFFF, 0xFFFF, "nForce3 LPC Bridge(0x00D0)"},
{0x10DE, 0x00D1, 0xFFFF, 0xFFFF, "nForce3 Host Bridge(0x00D1)"},
{0x10DE, 0x00D2, 0xFFFF, 0xFFFF, "nForce3 AGP Bridge(0x00D2)"},
{0x10DE, 0x00D3, 0xFFFF, 0xFFFF, "CK804 Memory Controller(0x00D3)"},
{0x10DE, 0x00D4, 0xFFFF, 0xFFFF, "nForce3 SMBus(0x00D4)"},
{0x10DE, 0x00D5, 0xFFFF, 0xFFFF, "nForce3 IDE(0x00D5)"},
{0x10DE, 0x00D6, 0xFFFF, 0xFFFF, "nForce3 Ethernet(0x00D6)"},
{0x10DE, 0x00D7, 0xFFFF, 0xFFFF, "nForce3 USB 1.1(0x00D7)"},
{0x10DE, 0x00D8, 0xFFFF, 0xFFFF, "nForce3 USB 2.0(0x00D8)"},
{0x10DE, 0x00D9, 0xFFFF, 0xFFFF, "nForce3 Audio(0x00D9)"},
{0x10DE, 0x00DA, 0xFFFF, 0xFFFF, "nForce3 Audio(0x00DA)"},
{0x10DE, 0x00DD, 0xFFFF, 0xFFFF, "nForce3 PCI Bridge(0x00DD)"},
{0x10DE, 0x00DF, 0xFFFF, 0xFFFF, "CK8S Ethernet Controller(0x00DF)"},
{0x10DE, 0x00DF, 0x1043, 0x80A7, "K8N-E(0x1043-0x80A7)"},
{0x10DE, 0x00DF, 0x105B, 0x0C43, "Winfast NF3250K8AA(0x105B-0x0C43)"},
{0x10DE, 0x00DF, 0x147B, 0x1C0B, "NF8 Mainboard(0x147B-0x1C0B)"},
{0x10DE, 0x00E0, 0xFFFF, 0xFFFF, "nForce3 250Gb LPC Bridge(0x00E0)"},
{0x10DE, 0x00E0, 0x1043, 0x813F, "K8N-E(0x1043-0x813F)"},
{0x10DE, 0x00E0, 0x10DE, 0x0C11, "Winfast NF3250K8AA(0x10DE-0x0C11)"},
{0x10DE, 0x00E0, 0x1462, 0x7030, "K8N Neo-FSR v2.0(0x1462-0x7030)"},
{0x10DE, 0x00E0, 0x147B, 0x1C0B, "NF8 Mainboard(0x147B-0x1C0B)"},
{0x10DE, 0x00E0, 0x1849, 0x00E0, "Motherboard (one of many)(0x1849-0x00E0)"},
{0x10DE, 0x00E1, 0xFFFF, 0xFFFF, "nForce3 250Gb Host Bridge(0x00E1)"},
{0x10DE, 0x00E1, 0x1043, 0x813F, "K8N-E(0x1043-0x813F)"},
{0x10DE, 0x00E1, 0x1462, 0x7030, "K8N Neo-FSR v2.0(0x1462-0x7030)"},
{0x10DE, 0x00E1, 0x147B, 0x1C0B, "NF8 Mainboard(0x147B-0x1C0B)"},
{0x10DE, 0x00E1, 0x1849, 0x00E1, "Motherboard (one of many)(0x1849-0x00E1)"},
{0x10DE, 0x00E2, 0xFFFF, 0xFFFF, "nForce3 250Gb AGP Host to PCI Bridge(0x00E2)"},
{0x10DE, 0x00E3, 0xFFFF, 0xFFFF, "nForce3 Serial ATA Controller(0x00E3)"},
{0x10DE, 0x00E3, 0x1043, 0x813F, "K8N-E(0x1043-0x813F)"},
{0x10DE, 0x00E3, 0x105B, 0x0C43, "Winfast NF3250K8AA(0x105B-0x0C43)"},
{0x10DE, 0x00E3, 0x147B, 0x1C0B, "NF8 Mainboard(0x147B-0x1C0B)"},
{0x10DE, 0x00E3, 0x1849, 0x00E3, "Motherboard (one of many)(0x1849-0x00E3)"},
{0x10DE, 0x00E4, 0xFFFF, 0xFFFF, "nForce 250Gb PCI System Management(0x00E4)"},
{0x10DE, 0x00E4, 0x1043, 0x813F, "K8N-E(0x1043-0x813F)"},
{0x10DE, 0x00E4, 0x105B, 0x0C43, "Winfast NF3250K8AA(0x105B-0x0C43)"},
{0x10DE, 0x00E4, 0x1462, 0x7030, "K8N Neo-FSR v2.0(0x1462-0x7030)"},
{0x10DE, 0x00E4, 0x147B, 0x1C0B, "NF8 Mainboard(0x147B-0x1C0B)"},
{0x10DE, 0x00E4, 0x1849, 0x00E4, "Motherboard (one of many)(0x1849-0x00E4)"},
{0x10DE, 0x00E5, 0xFFFF, 0xFFFF, "CK8S Parallel ATA Controller (v2.5)(0x00E5)"},
{0x10DE, 0x00E5, 0x1043, 0x813F, "K8N-E(0x1043-0x813F)"},
{0x10DE, 0x00E5, 0x105B, 0x0C43, "Winfast NF3250K8AA(0x105B-0x0C43)"},
{0x10DE, 0x00E5, 0x1462, 0x7030, "K8N Neo-FSR v2.0(0x1462-0x7030)"},
{0x10DE, 0x00E5, 0x147B, 0x1C0B, "NF8 Mainboard(0x147B-0x1C0B)"},
{0x10DE, 0x00E5, 0x1849, 0x00E5, "Motherboard (one of many)(0x1849-0x00E5)"},
{0x10DE, 0x00E5, 0xF849, 0x00E5, "Motherboard (one of many)(0xF849-0x00E5)"},
{0x10DE, 0x00E6, 0xFFFF, 0xFFFF, "CK8S Ethernet Controller(0x00E6)"},
{0x10DE, 0x00E7, 0xFFFF, 0xFFFF, "CK8S USB Controller(0x00E7)"},
{0x10DE, 0x00E7, 0x1043, 0x813F, "K8N-E(0x1043-0x813F)"},
{0x10DE, 0x00E7, 0x105B, 0x0C43, "Winfast NF3250K8AA(0x105B-0x0C43)"},
{0x10DE, 0x00E7, 0x1462, 0x7030, "K8N Neo-FSR v2.0(0x1462-0x7030)"},
{0x10DE, 0x00E7, 0x147B, 0x1C0B, "NF8 Mainboard(0x147B-0x1C0B)"},
{0x10DE, 0x00E7, 0x1849, 0x00E7, "Motherboard (one of many)(0x1849-0x00E7)"},
{0x10DE, 0x00E8, 0xFFFF, 0xFFFF, "nForce3 EHCI USB 2.0 Controller(0x00E8)"},
{0x10DE, 0x00E8, 0x1043, 0x813F, "K8N-E(0x1043-0x813F)"},
{0x10DE, 0x00E8, 0x105B, 0x0C43, "Winfast NF3250K8AA(0x105B-0x0C43)"},
{0x10DE, 0x00E8, 0x1462, 0x7030, "K8N Neo-FSR v2.0(0x1462-0x7030)"},
{0x10DE, 0x00E8, 0x147B, 0x1C0B, "NF8 Mainboard(0x147B-0x1C0B)"},
{0x10DE, 0x00E8, 0x1849, 0x00E8, "Motherboard (one of many)(0x1849-0x00E8)"},
{0x10DE, 0x00EA, 0xFFFF, 0xFFFF, "nForce3 250Gb AC'97 Audio Controller(0x00EA)"},
{0x10DE, 0x00EA, 0x1043, 0x819D, "K8N-E(0x1043-0x819D)"},
{0x10DE, 0x00EA, 0x105B, 0x0C43, "Winfast NF3250K8AA(0x105B-0x0C43)"},
{0x10DE, 0x00EA, 0x1462, 0xB010, "K8N Neo-FSR v2.0(0x1462-0xB010)"},
{0x10DE, 0x00EA, 0x147B, 0x1C0B, "NF8 Mainboard(0x147B-0x1C0B)"},
{0x10DE, 0x00ED, 0xFFFF, 0xFFFF, "nForce3 250Gb PCI-to-PCI Bridge(0x00ED)"},
{0x10DE, 0x00EE, 0xFFFF, 0xFFFF, "nForce3 Serial ATA Controller 2(0x00EE)"},
{0x10DE, 0x00F1, 0xFFFF, 0xFFFF, "NV43 [GeForce 6600 GT](0x00F1)"},
{0x10DE, 0x00F1, 0x1043, 0x81A6, "N6600GT TD 128M AGP(0x1043-0x81A6)"},
{0x10DE, 0x00F1, 0x1043, 0x81C6, "N6600GT TD 128M AGP(0x1043-0x81C6)"},
{0x10DE, 0x00F1, 0x1458, 0x3150, "GV-N66T128VP(0x1458-0x3150)"},
{0x10DE, 0x00F1, 0x1554, 0x1191, "PixelView PV-N43UA (128KD)(0x1554-0x1191)"},
{0x10DE, 0x00F1, 0x1682, 0x2119, "GeForce 6600 GT AGP(0x1682-0x2119)"},
{0x10DE, 0x00F2, 0xFFFF, 0xFFFF, "NV43 [GeForce 6600](0x00F2)"},
{0x10DE, 0x00F2, 0x1554, 0x1194, "PixelView PV-N43AT (256KD)(0x1554-0x1194)"},
{0x10DE, 0x00F2, 0x1682, 0x211C, "GeForce 6600 256MB DDR DUAL DVI TV(0x1682-0x211C)"},
{0x10DE, 0x00F3, 0xFFFF, 0xFFFF, "NV43 [GeForce 6200](0x00F3)"},
{0x10DE, 0x00F4, 0xFFFF, 0xFFFF, "NV43 [GeForce 6600 LE](0x00F4)"},
{0x10DE, 0x00F5, 0xFFFF, 0xFFFF, "G70/G71 [GeForce 7800 GS AGP](0x00F5)"},
{0x10DE, 0x00F6, 0xFFFF, 0xFFFF, "NV43 [GeForce 6800 GS/XT](0x00F6)"},
{0x10DE, 0x00F6, 0x1682, 0x217E, "XFX GeForce 6800 XTreme 256MB DDR3 AGP(0x1682-0x217E)"},
{0x10DE, 0x00F8, 0xFFFF, 0xFFFF, "NV45GL [Quadro FX 3400/4400](0x00F8)"},
{0x10DE, 0x00F9, 0xFFFF, 0xFFFF, "NV40 [GeForce 6800 GT/GTO/Ultra](0x00F9)"},
{0x10DE, 0x00F9, 0x10DE, 0x00F9, "NV40 [GeForce 6800 GT](0x10DE-0x00F9)"},
{0x10DE, 0x00F9, 0x1682, 0x2120, "GEFORCE 6800 GT PCI-E(0x1682-0x2120)"},
{0x10DE, 0x00FA, 0xFFFF, 0xFFFF, "NV39 [GeForce PCX 5750](0x00FA)"},
{0x10DE, 0x00FB, 0xFFFF, 0xFFFF, "NV35 [GeForce PCX 5900](0x00FB)"},
{0x10DE, 0x00FC, 0xFFFF, 0xFFFF, "NV37GL [Quadro FX 330/GeForce PCX 5300](0x00FC)"},
{0x10DE, 0x00FD, 0xFFFF, 0xFFFF, "NV37GL [Quadro PCI-E Series](0x00FD)"},
{0x10DE, 0x00FE, 0xFFFF, 0xFFFF, "NV38GL [Quadro FX 1300](0x00FE)"},
{0x10DE, 0x00FF, 0xFFFF, 0xFFFF, "NV19 [GeForce PCX 4300](0x00FF)"},
{0x10DE, 0x0100, 0xFFFF, 0xFFFF, "NV10 [GeForce 256 SDR](0x0100)"},
{0x10DE, 0x0100, 0x1043, 0x0200, "AGP-V6600 SGRAM(0x1043-0x0200)"},
{0x10DE, 0x0100, 0x1043, 0x0201, "AGP-V6600 SDRAM(0x1043-0x0201)"},
{0x10DE, 0x0100, 0x1043, 0x4008, "AGP-V6600 SGRAM(0x1043-0x4008)"},
{0x10DE, 0x0100, 0x1043, 0x4009, "AGP-V6600 SDRAM(0x1043-0x4009)"},
{0x10DE, 0x0100, 0x1048, 0x0C41, "Erazor X(0x1048-0x0C41)"},
{0x10DE, 0x0100, 0x1048, 0x0C43, "ERAZOR X PCI(0x1048-0x0C43)"},
{0x10DE, 0x0100, 0x1048, 0x0C48, "Synergy Force(0x1048-0x0C48)"},
{0x10DE, 0x0100, 0x1102, 0x102D, "CT6941 GeForce 256(0x1102-0x102D)"},
{0x10DE, 0x0100, 0x14AF, 0x5022, "3D Prophet SE(0x14AF-0x5022)"},
{0x10DE, 0x0101, 0xFFFF, 0xFFFF, "NV10 [GeForce 256 DDR](0x0101)"},
{0x10DE, 0x0101, 0x1043, 0x0202, "AGP-V6800 DDR(0x1043-0x0202)"},
{0x10DE, 0x0101, 0x1043, 0x400A, "AGP-V6800 DDR SGRAM(0x1043-0x400A)"},
{0x10DE, 0x0101, 0x1043, 0x400B, "AGP-V6800 DDR SDRAM(0x1043-0x400B)"},
{0x10DE, 0x0101, 0x1048, 0x0C42, "Erazor X(0x1048-0x0C42)"},
{0x10DE, 0x0101, 0x107D, 0x2822, "WinFast GeForce 256(0x107D-0x2822)"},
{0x10DE, 0x0101, 0x1102, 0x102E, "CT6970/CT6971(0x1102-0x102E)"},
{0x10DE, 0x0101, 0x14AF, 0x5021, "3D Prophet DDR-DVI(0x14AF-0x5021)"},
{0x10DE, 0x0103, 0xFFFF, 0xFFFF, "NV10GL [Quadro](0x0103)"},
{0x10DE, 0x0103, 0x1048, 0x0C40, "GLoria II-64(0x1048-0x0C40)"},
{0x10DE, 0x0103, 0x1048, 0x0C44, "GLoria II(0x1048-0x0C44)"},
{0x10DE, 0x0103, 0x1048, 0x0C45, "GLoria II(0x1048-0x0C45)"},
{0x10DE, 0x0103, 0x1048, 0x0C4A, "GLoria II-64 Pro(0x1048-0x0C4A)"},
{0x10DE, 0x0103, 0x1048, 0x0C4B, "GLoria II-64 Pro DVII(0x1048-0x0C4B)"},
{0x10DE, 0x0103, 0x10A9, 0x9002, "VPro VR3(0x10A9-0x9002)"},
{0x10DE, 0x0110, 0xFFFF, 0xFFFF, "NV11 [GeForce2 MX/MX 400](0x0110)"},
{0x10DE, 0x0110, 0x1043, 0x4015, "AGP-V7100 Pro(0x1043-0x4015)"},
{0x10DE, 0x0110, 0x1043, 0x4021, "V7100 Deluxe Combo(0x1043-0x4021)"},
{0x10DE, 0x0110, 0x1043, 0x4031, "V7100 Pro with TV output(0x1043-0x4031)"},
{0x10DE, 0x0110, 0x1048, 0x0C60, "Gladiac MX(0x1048-0x0C60)"},
{0x10DE, 0x0110, 0x1048, 0x0C61, "Gladiac 511PCI(0x1048-0x0C61)"},
{0x10DE, 0x0110, 0x1048, 0x0C63, "Gladiac 511TV-OUT 32MB(0x1048-0x0C63)"},
{0x10DE, 0x0110, 0x1048, 0x0C64, "Gladiac 511TV-OUT 64MB(0x1048-0x0C64)"},
{0x10DE, 0x0110, 0x1048, 0x0C65, "Gladiac 511TWIN(0x1048-0x0C65)"},
{0x10DE, 0x0110, 0x1048, 0x0C66, "Gladiac 311(0x1048-0x0C66)"},
{0x10DE, 0x0110, 0x10B0, 0x0001, "GeForce2 MX Jumbo TV(0x10B0-0x0001)"},
{0x10DE, 0x0110, 0x10DE, 0x0091, "Dell OEM GeForce 2 MX 400(0x10DE-0x0091)"},
{0x10DE, 0x0110, 0x10DE, 0x00A1, "Apple OEM GeForce2 MX(0x10DE-0x00A1)"},
{0x10DE, 0x0110, 0x1462, 0x8523, "MS-8852(0x1462-0x8523)"},
{0x10DE, 0x0110, 0x1462, 0x8817, "MSI GeForce2 MX400 Pro32S [MS-8817](0x1462-0x8817)"},
{0x10DE, 0x0110, 0x14AF, 0x7102, "3D Prophet II MX(0x14AF-0x7102)"},
{0x10DE, 0x0110, 0x14AF, 0x7103, "3D Prophet II MX Dual-Display(0x14AF-0x7103)"},
{0x10DE, 0x0110, 0x1545, 0x0023, "Xtasy Rev. B2(0x1545-0x0023)"},
{0x10DE, 0x0110, 0x1554, 0x1081, "MVGA-NVG11AM(400)(0x1554-0x1081)"},
{0x10DE, 0x0111, 0xFFFF, 0xFFFF, "NV11 [GeForce2 MX200](0x0111)"},
{0x10DE, 0x0112, 0xFFFF, 0xFFFF, "NV11M [GeForce2 Go](0x0112)"},
{0x10DE, 0x0113, 0xFFFF, 0xFFFF, "NV11GL [Quadro2 MXR/EX/Go](0x0113)"},
{0x10DE, 0x0113, 0x1028, 0x00E5, "Quadro2 Go(0x1028-0x00E5)"},
{0x10DE, 0x0140, 0xFFFF, 0xFFFF, "NV43 [GeForce 6600 GT](0x0140)"},
{0x10DE, 0x0140, 0x1458, 0x3125, "GV-NX66T128D(0x1458-0x3125)"},
{0x10DE, 0x0140, 0x1458, 0x3126, "GV-NX66T256DE(0x1458-0x3126)"},
{0x10DE, 0x0140, 0x1462, 0x8939, "MS-8983(0x1462-0x8939)"},
{0x10DE, 0x0141, 0xFFFF, 0xFFFF, "NV43 [GeForce 6600](0x0141)"},
{0x10DE, 0x0141, 0x1043, 0x81B0, "EN6600 Silencer(0x1043-0x81B0)"},
{0x10DE, 0x0141, 0x107D, 0x593A, "LR2A22 128MB TV OUT(0x107D-0x593A)"},
{0x10DE, 0x0141, 0x107D, 0x597B, "WINFAST PX6600(0x107D-0x597B)"},
{0x10DE, 0x0141, 0x1458, 0x3124, "GV-NX66128DP Turbo Force Edition(0x1458-0x3124)"},
{0x10DE, 0x0142, 0xFFFF, 0xFFFF, "NV43 [GeForce 6600 LE](0x0142)"},
{0x10DE, 0x0143, 0xFFFF, 0xFFFF, "NV43 [GeForce 6600 VE](0x0143)"},
{0x10DE, 0x0144, 0xFFFF, 0xFFFF, "NV43M [GeForce Go 6600](0x0144)"},
{0x10DE, 0x0145, 0xFFFF, 0xFFFF, "NV43 [GeForce 6610 XL](0x0145)"},
{0x10DE, 0x0146, 0xFFFF, 0xFFFF, "NV43M [GeForce Go6200 TE / 6600 TE](0x0146)"},
{0x10DE, 0x0147, 0xFFFF, 0xFFFF, "NV43 [GeForce 6700 XL](0x0147)"},
{0x10DE, 0x0148, 0xFFFF, 0xFFFF, "NV43M [GeForce Go 6600](0x0148)"},
{0x10DE, 0x0149, 0xFFFF, 0xFFFF, "NV43M [GeForce Go 6600 GT](0x0149)"},
{0x10DE, 0x014A, 0xFFFF, 0xFFFF, "NV43 [Quadro NVS 440](0x014A)"},
{0x10DE, 0x014B, 0xFFFF, 0xFFFF, "NV43(0x014B)"},
{0x10DE, 0x014D, 0xFFFF, 0xFFFF, "NV43GL [Quadro FX 550](0x014D)"},
{0x10DE, 0x014E, 0xFFFF, 0xFFFF, "NV43GL [Quadro FX 540](0x014E)"},
{0x10DE, 0x014F, 0xFFFF, 0xFFFF, "NV43 [GeForce 6200](0x014F)"},
{0x10DE, 0x0150, 0xFFFF, 0xFFFF, "NV15 [GeForce2 GTS/Pro](0x0150)"},
{0x10DE, 0x0150, 0x1043, 0x4016, "V7700 AGP Video Card(0x1043-0x4016)"},
{0x10DE, 0x0150, 0x1043, 0x402A, "AGP-V7700(0x1043-0x402A)"},
{0x10DE, 0x0150, 0x1048, 0x0C50, "Gladiac(0x1048-0x0C50)"},
{0x10DE, 0x0150, 0x1048, 0x0C52, "Gladiac-64(0x1048-0x0C52)"},
{0x10DE, 0x0150, 0x107D, 0x2840, "WinFast GeForce2 GTS with TV output(0x107D-0x2840)"},
{0x10DE, 0x0150, 0x107D, 0x2842, "WinFast GeForce 2 Pro(0x107D-0x2842)"},
{0x10DE, 0x0150, 0x10DE, 0x002E, "GeForce2 GTS(0x10DE-0x002E)"},
{0x10DE, 0x0150, 0x1462, 0x815A, "MS-8815(0x1462-0x815A)"},
{0x10DE, 0x0150, 0x1462, 0x8831, "Creative GeForce2 Pro(0x1462-0x8831)"},
{0x10DE, 0x0151, 0xFFFF, 0xFFFF, "NV15 [GeForce2 Ti](0x0151)"},
{0x10DE, 0x0151, 0x1043, 0x405F, "V7700Ti(0x1043-0x405F)"},
{0x10DE, 0x0151, 0x1462, 0x5506, "Creative 3D Blaster GeForce2 Titanium(0x1462-0x5506)"},
{0x10DE, 0x0151, 0x1462, 0x8364, "MS-8836(0x1462-0x8364)"},
{0x10DE, 0x0152, 0xFFFF, 0xFFFF, "NV15 [GeForce2 Ultra](0x0152)"},
{0x10DE, 0x0152, 0x1048, 0x0C56, "GLADIAC Ultra(0x1048-0x0C56)"},
{0x10DE, 0x0153, 0xFFFF, 0xFFFF, "NV15GL [Quadro2 Pro](0x0153)"},
{0x10DE, 0x0160, 0xFFFF, 0xFFFF, "NV44 [GeForce 6500](0x0160)"},
{0x10DE, 0x0161, 0xFFFF, 0xFFFF, "NV44 [GeForce 6200 TurboCache](0x0161)"},
{0x10DE, 0x0162, 0xFFFF, 0xFFFF, "NV44 [GeForce 6200 SE TurboCache](0x0162)"},
{0x10DE, 0x0163, 0xFFFF, 0xFFFF, "NV44 [GeForce 6200 LE](0x0163)"},
{0x10DE, 0x0164, 0xFFFF, 0xFFFF, "NV44M [GeForce Go 6200](0x0164)"},
{0x10DE, 0x0165, 0xFFFF, 0xFFFF, "NV44 [Quadro NVS 285](0x0165)"},
{0x10DE, 0x0166, 0xFFFF, 0xFFFF, "NV44M [GeForce Go 6400](0x0166)"},
{0x10DE, 0x0167, 0xFFFF, 0xFFFF, "NV44M [GeForce Go 6200](0x0167)"},
{0x10DE, 0x0168, 0xFFFF, 0xFFFF, "NV44M [GeForce Go 6400](0x0168)"},
{0x10DE, 0x0169, 0xFFFF, 0xFFFF, "NV44 [GeForce 6250](0x0169)"},
{0x10DE, 0x016A, 0xFFFF, 0xFFFF, "NV44 [GeForce 7100 GS](0x016A)"},
{0x10DE, 0x016D, 0xFFFF, 0xFFFF, "NV44(0x016D)"},
{0x10DE, 0x016E, 0xFFFF, 0xFFFF, "NV44(0x016E)"},
{0x10DE, 0x016F, 0xFFFF, 0xFFFF, "NV44(0x016F)"},
{0x10DE, 0x0170, 0xFFFF, 0xFFFF, "NV17 [GeForce4 MX 460](0x0170)"},
{0x10DE, 0x0170, 0x1462, 0x8630, "MS-8863(0x1462-0x8630)"},
{0x10DE, 0x0171, 0xFFFF, 0xFFFF, "NV17 [GeForce4 MX 440](0x0171)"},
{0x10DE, 0x0171, 0x10B0, 0x0002, "Gainward Pro/600 TV(0x10B0-0x0002)"},
{0x10DE, 0x0171, 0x10DE, 0x0008, "Apple OEM GeForce4 MX 440(0x10DE-0x0008)"},
{0x10DE, 0x0171, 0x1462, 0x8661, "G4MX440-VTP(0x1462-0x8661)"},
{0x10DE, 0x0171, 0x1462, 0x8730, "MX440SES-T (MS-8873)(0x1462-0x8730)"},
{0x10DE, 0x0171, 0x1462, 0x8743, "MS-8874(0x1462-0x8743)"},
{0x10DE, 0x0171, 0x1462, 0x8852, "GeForce4 MX440 PCI(0x1462-0x8852)"},
{0x10DE, 0x0171, 0x147B, 0x8F00, "Abit Siluro GeForce4MX440(0x147B-0x8F00)"},
{0x10DE, 0x0172, 0xFFFF, 0xFFFF, "NV17 [GeForce4 MX 420](0x0172)"},
{0x10DE, 0x0172, 0x1462, 0x8730, "MS-8873(0x1462-0x8730)"},
{0x10DE, 0x0172, 0x1462, 0x8784, "MS-8878(0x1462-0x8784)"},
{0x10DE, 0x0173, 0xFFFF, 0xFFFF, "NV17 [GeForce4 MX 440-SE](0x0173)"},
{0x10DE, 0x0174, 0xFFFF, 0xFFFF, "NV17M [GeForce4 440 Go](0x0174)"},
{0x10DE, 0x0175, 0xFFFF, 0xFFFF, "NV17M [GeForce4 420 Go](0x0175)"},
{0x10DE, 0x0176, 0xFFFF, 0xFFFF, "NV17M [GeForce4 420 Go 32M](0x0176)"},
{0x10DE, 0x0176, 0x103C, 0x08B0, "tc1100 tablet(0x103C-0x08B0)"},
{0x10DE, 0x0176, 0x144D, 0xC005, "X10 Laptop(0x144D-0xC005)"},
{0x10DE, 0x0176, 0x4C53, 0x1090, "Cx9 / Vx9 mainboard(0x4C53-0x1090)"},
{0x10DE, 0x0177, 0xFFFF, 0xFFFF, "NV17M [GeForce4 460 Go](0x0177)"},
{0x10DE, 0x0178, 0xFFFF, 0xFFFF, "NV17GL [Quadro4 550 XGL](0x0178)"},
{0x10DE, 0x0179, 0xFFFF, 0xFFFF, "NV17M [GeForce4 440 Go 64M](0x0179)"},
{0x10DE, 0x0179, 0x10DE, 0x0179, "GeForce4 MX (Mac)(0x10DE-0x0179)"},
{0x10DE, 0x017A, 0xFFFF, 0xFFFF, "NV17GL [Quadro NVS](0x017A)"},
{0x10DE, 0x017B, 0xFFFF, 0xFFFF, "NV17GL [Quadro4 550 XGL](0x017B)"},
{0x10DE, 0x017C, 0xFFFF, 0xFFFF, "NV17GL [Quadro4 500 GoGL](0x017C)"},
{0x10DE, 0x017F, 0xFFFF, 0xFFFF, "NV17(0x017F)"},
{0x10DE, 0x0181, 0xFFFF, 0xFFFF, "NV18 [GeForce4 MX 440 AGP 8x](0x0181)"},
{0x10DE, 0x0181, 0x1043, 0x8063, "GeForce4 MX 440 AGP 8X(0x1043-0x8063)"},
{0x10DE, 0x0181, 0x1043, 0x806F, "V9180 Magic(0x1043-0x806F)"},
{0x10DE, 0x0181, 0x1462, 0x8880, "MS-StarForce GeForce4 MX 440 with AGP8X(0x1462-0x8880)"},
{0x10DE, 0x0181, 0x1462, 0x8900, "MS-8890 GeForce 4 MX440 AGP8X(0x1462-0x8900)"},
{0x10DE, 0x0181, 0x1462, 0x9350, "MSI GeForce4 MX T8X with AGP8X(0x1462-0x9350)"},
{0x10DE, 0x0181, 0x147B, 0x8F0D, "Siluro GF4 MX-8X(0x147B-0x8F0D)"},
{0x10DE, 0x0181, 0x1554, 0x1111, "PixelView MVGA-NVG18A(0x1554-0x1111)"},
{0x10DE, 0x0182, 0xFFFF, 0xFFFF, "NV18 [GeForce4 MX 440SE AGP 8x](0x0182)"},
{0x10DE, 0x0183, 0xFFFF, 0xFFFF, "NV18 [GeForce4 MX 420 AGP 8x](0x0183)"},
{0x10DE, 0x0184, 0xFFFF, 0xFFFF, "NV18 [GeForce4 MX](0x0184)"},
{0x10DE, 0x0185, 0xFFFF, 0xFFFF, "NV18 [GeForce4 MX 4000](0x0185)"},
{0x10DE, 0x0186, 0xFFFF, 0xFFFF, "NV18M [GeForce4 448 Go](0x0186)"},
{0x10DE, 0x0187, 0xFFFF, 0xFFFF, "NV18M [GeForce4 488 Go](0x0187)"},
{0x10DE, 0x0188, 0xFFFF, 0xFFFF, "NV18GL [Quadro4 580 XGL](0x0188)"},
{0x10DE, 0x0189, 0xFFFF, 0xFFFF, "NV18 [GeForce4 MX with AGP8X (Mac)](0x0189)"},
{0x10DE, 0x018A, 0xFFFF, 0xFFFF, "NV18GL [Quadro NVS 280 SD](0x018A)"},
{0x10DE, 0x018B, 0xFFFF, 0xFFFF, "NV18GL [Quadro4 380 XGL](0x018B)"},
{0x10DE, 0x018C, 0xFFFF, 0xFFFF, "NV18GL [Quadro NVS 50 PCI](0x018C)"},
{0x10DE, 0x018D, 0xFFFF, 0xFFFF, "NV18M [GeForce4 448 Go](0x018D)"},
{0x10DE, 0x0190, 0xFFFF, 0xFFFF, "G80 [GeForce 8800 GTS / 8800 GTX](0x0190)"},
{0x10DE, 0x0191, 0xFFFF, 0xFFFF, "G80 [GeForce 8800 GTX](0x0191)"},
{0x10DE, 0x0192, 0xFFFF, 0xFFFF, "G80 [GeForce 8800 GTS](0x0192)"},
{0x10DE, 0x0193, 0xFFFF, 0xFFFF, "G80 [GeForce 8800 GTS](0x0193)"},
{0x10DE, 0x0193, 0x107D, 0x20BD, "WinFast PX 8800 GTS TDH(0x107D-0x20BD)"},
{0x10DE, 0x0194, 0xFFFF, 0xFFFF, "G80 [GeForce 8800 Ultra](0x0194)"},
{0x10DE, 0x0197, 0xFFFF, 0xFFFF, "G80GL [Tesla C870](0x0197)"},
{0x10DE, 0x019D, 0xFFFF, 0xFFFF, "G80GL [Quadro FX 5600](0x019D)"},
{0x10DE, 0x019E, 0xFFFF, 0xFFFF, "G80GL [Quadro FX 4600](0x019E)"},
{0x10DE, 0x01A0, 0xFFFF, 0xFFFF, "nForce 220/420 NV1A [GeForce2 MX](0x01A0)"},
{0x10DE, 0x01A4, 0xFFFF, 0xFFFF, "nForce CPU bridge(0x01A4)"},
{0x10DE, 0x01AB, 0xFFFF, 0xFFFF, "nForce 420 Memory Controller (DDR)(0x01AB)"},
{0x10DE, 0x01AC, 0xFFFF, 0xFFFF, "nForce 220/420 Memory Controller(0x01AC)"},
{0x10DE, 0x01AD, 0xFFFF, 0xFFFF, "nForce 220/420 Memory Controller(0x01AD)"},
{0x10DE, 0x01B0, 0xFFFF, 0xFFFF, "nForce Audio Processing Unit(0x01B0)"},
{0x10DE, 0x01B1, 0xFFFF, 0xFFFF, "nForce AC'97 Audio Controller(0x01B1)"},
{0x10DE, 0x01B2, 0xFFFF, 0xFFFF, "nForce ISA Bridge(0x01B2)"},
{0x10DE, 0x01B4, 0xFFFF, 0xFFFF, "nForce PCI System Management(0x01B4)"},
{0x10DE, 0x01B7, 0xFFFF, 0xFFFF, "nForce AGP to PCI Bridge(0x01B7)"},
{0x10DE, 0x01B8, 0xFFFF, 0xFFFF, "nForce PCI-to-PCI bridge(0x01B8)"},
{0x10DE, 0x01BC, 0xFFFF, 0xFFFF, "nForce IDE(0x01BC)"},
{0x10DE, 0x01C1, 0xFFFF, 0xFFFF, "nForce AC'97 Modem Controller(0x01C1)"},
{0x10DE, 0x01C2, 0xFFFF, 0xFFFF, "nForce USB Controller(0x01C2)"},
{0x10DE, 0x01C3, 0xFFFF, 0xFFFF, "nForce Ethernet Controller(0x01C3)"},
{0x10DE, 0x01D0, 0xFFFF, 0xFFFF, "G72 [GeForce 7350 LE](0x01D0)"},
{0x10DE, 0x01D1, 0xFFFF, 0xFFFF, "G72 [GeForce 7300 LE](0x01D1)"},
{0x10DE, 0x01D1, 0x107D, 0x5EFA, "WinFast PX7300LE-TD128(0x107D-0x5EFA)"},
{0x10DE, 0x01D1, 0x107D, 0x5EFB, "WinFast PX7300LE-TD256(0x107D-0x5EFB)"},
{0x10DE, 0x01D1, 0x1462, 0x0345, "7300LE PCI Express Graphics Adapter(0x1462-0x0345)"},
{0x10DE, 0x01D2, 0xFFFF, 0xFFFF, "G72 [GeForce 7550 LE](0x01D2)"},
{0x10DE, 0x01D3, 0xFFFF, 0xFFFF, "G72 [GeForce 7200 GS / 7300 SE](0x01D3)"},
{0x10DE, 0x01D3, 0x1043, 0x8203, "EN7300SE(0x1043-0x8203)"},
{0x10DE, 0x01D3, 0x1043, 0x8250, "EN7200GS(0x1043-0x8250)"},
{0x10DE, 0x01D5, 0xFFFF, 0xFFFF, "G72(0x01D5)"},
{0x10DE, 0x01D6, 0xFFFF, 0xFFFF, "G72M [GeForce Go 7200](0x01D6)"},
{0x10DE, 0x01D7, 0xFFFF, 0xFFFF, "G72M [Quadro NVS 110M/GeForce Go 7300](0x01D7)"},
{0x10DE, 0x01D8, 0xFFFF, 0xFFFF, "G72M [GeForce Go 7400](0x01D8)"},
{0x10DE, 0x01D8, 0x1028, 0x01D7, "XPS M1210(0x1028-0x01D7)"},
{0x10DE, 0x01D9, 0xFFFF, 0xFFFF, "G72M [GeForce Go 7450](0x01D9)"},
{0x10DE, 0x01DA, 0xFFFF, 0xFFFF, "G72M [Quadro NVS 110M](0x01DA)"},
{0x10DE, 0x01DB, 0xFFFF, 0xFFFF, "G72M [Quadro NVS 120M](0x01DB)"},
{0x10DE, 0x01DC, 0xFFFF, 0xFFFF, "G72GLM [Quadro FX 350M](0x01DC)"},
{0x10DE, 0x01DD, 0xFFFF, 0xFFFF, "G72 [GeForce 7500 LE](0x01DD)"},
{0x10DE, 0x01DE, 0xFFFF, 0xFFFF, "G72GL [Quadro FX 350](0x01DE)"},
{0x10DE, 0x01DE, 0x10DE, 0x01DC, "Quadro  FX Go350M(0x10DE-0x01DC)"},
{0x10DE, 0x01DF, 0xFFFF, 0xFFFF, "G72 [GeForce 7300 GS](0x01DF)"},
{0x10DE, 0x01E0, 0xFFFF, 0xFFFF, "nForce2 IGP2(0x01E0)"},
{0x10DE, 0x01E0, 0x147B, 0x1C09, "NV7 Motherboard(0x147B-0x1C09)"},
{0x10DE, 0x01E8, 0xFFFF, 0xFFFF, "nForce2 AGP(0x01E8)"},
{0x10DE, 0x01EA, 0xFFFF, 0xFFFF, "nForce2 Memory Controller 0(0x01EA)"},
{0x10DE, 0x01EA, 0xA0A0, 0x03B9, "UK79G-1394 motherboard(0xA0A0-0x03B9)"},
{0x10DE, 0x01EB, 0xFFFF, 0xFFFF, "nForce2 Memory Controller 1(0x01EB)"},
{0x10DE, 0x01EB, 0xA0A0, 0x03B9, "UK79G-1394 motherboard(0xA0A0-0x03B9)"},
{0x10DE, 0x01EC, 0xFFFF, 0xFFFF, "nForce2 Memory Controller 2(0x01EC)"},
{0x10DE, 0x01EC, 0xA0A0, 0x03B9, "UK79G-1394 motherboard(0xA0A0-0x03B9)"},
{0x10DE, 0x01ED, 0xFFFF, 0xFFFF, "nForce2 Memory Controller 3(0x01ED)"},
{0x10DE, 0x01ED, 0xA0A0, 0x03B9, "UK79G-1394 motherboard(0xA0A0-0x03B9)"},
{0x10DE, 0x01EE, 0xFFFF, 0xFFFF, "nForce2 Memory Controller 4(0x01EE)"},
{0x10DE, 0x01EE, 0x10DE, 0x01EE, "MSI Delta-L nForce2 memory controller(0x10DE-0x01EE)"},
{0x10DE, 0x01EE, 0xA0A0, 0x03B9, "UK79G-1394 motherboard(0xA0A0-0x03B9)"},
{0x10DE, 0x01EF, 0xFFFF, 0xFFFF, "nForce2 Memory Controller 5(0x01EF)"},
{0x10DE, 0x01EF, 0xA0A0, 0x03B9, "UK79G-1394 motherboard(0xA0A0-0x03B9)"},
{0x10DE, 0x01F0, 0xFFFF, 0xFFFF, "NV1F C17 [GeForce4 MX IGP](0x01F0)"},
{0x10DE, 0x01F0, 0xA0A0, 0x03B5, "UK79G-1394 motherboard(0xA0A0-0x03B5)"},
{0x10DE, 0x0200, 0xFFFF, 0xFFFF, "NV20 [GeForce3](0x0200)"},
{0x10DE, 0x0200, 0x1043, 0x402F, "AGP-V8200 DDR(0x1043-0x402F)"},
{0x10DE, 0x0200, 0x1048, 0x0C70, "GLADIAC 920(0x1048-0x0C70)"},
{0x10DE, 0x0201, 0xFFFF, 0xFFFF, "NV20 [GeForce3 Ti 200](0x0201)"},
{0x10DE, 0x0201, 0x1462, 0x8503, "G3Ti200 Pro VT128(0x1462-0x8503)"},
{0x10DE, 0x0202, 0xFFFF, 0xFFFF, "NV20 [GeForce3 Ti 500](0x0202)"},
{0x10DE, 0x0202, 0x1043, 0x405B, "V8200 T5(0x1043-0x405B)"},
{0x10DE, 0x0202, 0x1545, 0x002F, "Xtasy 6964(0x1545-0x002F)"},
{0x10DE, 0x0203, 0xFFFF, 0xFFFF, "NV20GL [Quadro DCC](0x0203)"},
{0x10DE, 0x0211, 0xFFFF, 0xFFFF, "NV48 [GeForce 6800](0x0211)"},
{0x10DE, 0x0212, 0xFFFF, 0xFFFF, "NV48 [GeForce 6800 LE](0x0212)"},
{0x10DE, 0x0215, 0xFFFF, 0xFFFF, "NV48 [GeForce 6800 GT](0x0215)"},
{0x10DE, 0x0218, 0xFFFF, 0xFFFF, "NV48 [GeForce 6800 XT](0x0218)"},
{0x10DE, 0x0221, 0xFFFF, 0xFFFF, "NV44A [GeForce 6200](0x0221)"},
{0x10DE, 0x0221, 0x1043, 0x81E1, "N6200/TD/256M/A(0x1043-0x81E1)"},
{0x10DE, 0x0221, 0x3842, 0xA341, "256A8N341DX(0x3842-0xA341)"},
{0x10DE, 0x0222, 0xFFFF, 0xFFFF, "NV44 [GeForce 6200 A-LE](0x0222)"},
{0x10DE, 0x0224, 0xFFFF, 0xFFFF, "NV44(0x0224)"},
{0x10DE, 0x0240, 0xFFFF, 0xFFFF, "C51PV [GeForce 6150](0x0240)"},
{0x10DE, 0x0240, 0x1043, 0x81CD, "A8N-VM CSM(0x1043-0x81CD)"},
{0x10DE, 0x0240, 0x1462, 0x7207, "K8NGM2 series(0x1462-0x7207)"},
{0x10DE, 0x0241, 0xFFFF, 0xFFFF, "C51 [GeForce 6150 LE](0x0241)"},
{0x10DE, 0x0242, 0xFFFF, 0xFFFF, "C51G [GeForce 6100](0x0242)"},
{0x10DE, 0x0242, 0x105B, 0x0CAD, "Winfast 6100K8MB(0x105B-0x0CAD)"},
{0x10DE, 0x0243, 0xFFFF, 0xFFFF, "C51 PCI Express Bridge(0x0243)"},
{0x10DE, 0x0244, 0xFFFF, 0xFFFF, "C51 [GeForce Go 6150](0x0244)"},
{0x10DE, 0x0244, 0x103C, 0x30B5, "Presario V3242AU(0x103C-0x30B5)"},
{0x10DE, 0x0244, 0x103C, 0x30B7, "Presario V6133CL(0x103C-0x30B7)"},
{0x10DE, 0x0244, 0x10DE, 0x0244, "GeForce Go 6150(0x10DE-0x0244)"},
{0x10DE, 0x0245, 0xFFFF, 0xFFFF, "C51 [Quadro NVS 210S/GeForce 6150LE](0x0245)"},
{0x10DE, 0x0246, 0xFFFF, 0xFFFF, "C51 PCI Express Bridge(0x0246)"},
{0x10DE, 0x0247, 0xFFFF, 0xFFFF, "C51 [GeForce Go 6100](0x0247)"},
{0x10DE, 0x0247, 0x1043, 0x1382, "MCP51 PCI-X GeForce Go 6100(0x1043-0x1382)"},
{0x10DE, 0x0248, 0xFFFF, 0xFFFF, "C51 PCI Express Bridge(0x0248)"},
{0x10DE, 0x0249, 0xFFFF, 0xFFFF, "C51 PCI Express Bridge(0x0249)"},
{0x10DE, 0x024A, 0xFFFF, 0xFFFF, "C51 PCI Express Bridge(0x024A)"},
{0x10DE, 0x024B, 0xFFFF, 0xFFFF, "C51 PCI Express Bridge(0x024B)"},
{0x10DE, 0x024C, 0xFFFF, 0xFFFF, "C51 PCI Express Bridge(0x024C)"},
{0x10DE, 0x024D, 0xFFFF, 0xFFFF, "C51 PCI Express Bridge(0x024D)"},
{0x10DE, 0x024E, 0xFFFF, 0xFFFF, "C51 PCI Express Bridge(0x024E)"},
{0x10DE, 0x024F, 0xFFFF, 0xFFFF, "C51 PCI Express Bridge(0x024F)"},
{0x10DE, 0x0250, 0xFFFF, 0xFFFF, "NV25 [GeForce4 Ti 4600](0x0250)"},
{0x10DE, 0x0251, 0xFFFF, 0xFFFF, "NV25 [GeForce4 Ti 4400](0x0251)"},
{0x10DE, 0x0251, 0x1043, 0x8023, "v8440 GeForce 4 Ti4400(0x1043-0x8023)"},
{0x10DE, 0x0251, 0x10DE, 0x0251, "PNY GeForce4 Ti 4400(0x10DE-0x0251)"},
{0x10DE, 0x0251, 0x1462, 0x8710, "PNY GeForce4 Ti 4400(0x1462-0x8710)"},
{0x10DE, 0x0252, 0xFFFF, 0xFFFF, "NV25 [GeForce4 Ti](0x0252)"},
{0x10DE, 0x0253, 0xFFFF, 0xFFFF, "NV25 [GeForce4 Ti 4200](0x0253)"},
{0x10DE, 0x0253, 0x107D, 0x2896, "WinFast A250 LE TD (Dual VGA/TV-out/DVI)(0x107D-0x2896)"},
{0x10DE, 0x0253, 0x147B, 0x8F09, "Siluro (Dual VGA/TV-out/DVI)(0x147B-0x8F09)"},
{0x10DE, 0x0258, 0xFFFF, 0xFFFF, "NV25GL [Quadro4 900 XGL](0x0258)"},
{0x10DE, 0x0259, 0xFFFF, 0xFFFF, "NV25GL [Quadro4 750 XGL](0x0259)"},
{0x10DE, 0x025B, 0xFFFF, 0xFFFF, "NV25GL [Quadro4 700 XGL](0x025B)"},
{0x10DE, 0x0260, 0xFFFF, 0xFFFF, "MCP51 LPC Bridge(0x0260)"},
{0x10DE, 0x0260, 0x103C, 0x2A34, "Pavilion a1677c(0x103C-0x2A34)"},
{0x10DE, 0x0260, 0x103C, 0x30B7, "Presario V6133CL(0x103C-0x30B7)"},
{0x10DE, 0x0260, 0x1043, 0x81BC, "A8N-VM CSM Mainboard(0x1043-0x81BC)"},
{0x10DE, 0x0260, 0x1458, 0x5001, "GA-M55plus-S3G(0x1458-0x5001)"},
{0x10DE, 0x0260, 0x1462, 0x7207, "K8NGM2 series(0x1462-0x7207)"},
{0x10DE, 0x0261, 0xFFFF, 0xFFFF, "MCP51 LPC Bridge(0x0261)"},
{0x10DE, 0x0261, 0x105B, 0x0CAD, "Winfast 6100K8MB(0x105B-0x0CAD)"},
{0x10DE, 0x0262, 0xFFFF, 0xFFFF, "MCP51 LPC Bridge(0x0262)"},
{0x10DE, 0x0263, 0xFFFF, 0xFFFF, "MCP51 LPC Bridge(0x0263)"},
{0x10DE, 0x0264, 0xFFFF, 0xFFFF, "MCP51 SMBus(0x0264)"},
{0x10DE, 0x0264, 0x103C, 0x2A34, "Pavilion a1677c(0x103C-0x2A34)"},
{0x10DE, 0x0264, 0x103C, 0x30B7, "Presario V6133CL(0x103C-0x30B7)"},
{0x10DE, 0x0264, 0x1043, 0x81BC, "A8N-VM CSM Mainboard(0x1043-0x81BC)"},
{0x10DE, 0x0264, 0x105B, 0x0CAD, "Winfast 6100K8MB(0x105B-0x0CAD)"},
{0x10DE, 0x0264, 0x1462, 0x7207, "K8NGM2 series(0x1462-0x7207)"},
{0x10DE, 0x0265, 0xFFFF, 0xFFFF, "MCP51 IDE(0x0265)"},
{0x10DE, 0x0265, 0x103C, 0x2A34, "Pavilion a1677c(0x103C-0x2A34)"},
{0x10DE, 0x0265, 0x103C, 0x30B7, "Presario V6133CL(0x103C-0x30B7)"},
{0x10DE, 0x0265, 0x1043, 0x81BC, "A8N-VM CSM Mainboard(0x1043-0x81BC)"},
{0x10DE, 0x0265, 0x1462, 0x7207, "K8NGM2 series(0x1462-0x7207)"},
{0x10DE, 0x0265, 0xF05B, 0x0CAD, "Winfast 6100K8MB(0xF05B-0x0CAD)"},
{0x10DE, 0x0266, 0xFFFF, 0xFFFF, "MCP51 Serial ATA Controller(0x0266)"},
{0x10DE, 0x0266, 0x103C, 0x2A34, "Pavilion a1677c(0x103C-0x2A34)"},
{0x10DE, 0x0266, 0x103C, 0x30B7, "Presario V6133CL(0x103C-0x30B7)"},
{0x10DE, 0x0266, 0x1043, 0x81BC, "A8N-VM CSM Mainboard(0x1043-0x81BC)"},
{0x10DE, 0x0266, 0x1462, 0x7207, "K8NGM2 series(0x1462-0x7207)"},
{0x10DE, 0x0267, 0xFFFF, 0xFFFF, "MCP51 Serial ATA Controller(0x0267)"},
{0x10DE, 0x0267, 0x103C, 0x2A34, "Pavilion a1677c(0x103C-0x2A34)"},
{0x10DE, 0x0267, 0x1043, 0x81BC, "A8N-VM CSM Mainboard(0x1043-0x81BC)"},
{0x10DE, 0x0267, 0x1462, 0x7207, "K8NGM2 series(0x1462-0x7207)"},
{0x10DE, 0x0268, 0xFFFF, 0xFFFF, "MCP51 Ethernet Controller(0x0268)"},
{0x10DE, 0x0269, 0xFFFF, 0xFFFF, "MCP51 Ethernet Controller(0x0269)"},
{0x10DE, 0x0269, 0x103C, 0x2A34, "Pavilion a1677c(0x103C-0x2A34)"},
{0x10DE, 0x0269, 0x103C, 0x30B7, "Presario V6133CL(0x103C-0x30B7)"},
{0x10DE, 0x0269, 0x1043, 0x8141, "A8N-VM CSM Mainboard(0x1043-0x8141)"},
{0x10DE, 0x0269, 0x1462, 0x7207, "K8NGM2 series(0x1462-0x7207)"},
{0x10DE, 0x026A, 0xFFFF, 0xFFFF, "MCP51 MCI(0x026A)"},
{0x10DE, 0x026B, 0xFFFF, 0xFFFF, "MCP51 AC97 Audio Controller(0x026B)"},
{0x10DE, 0x026B, 0x105B, 0x0CAD, "Winfast 6100K8MB(0x105B-0x0CAD)"},
{0x10DE, 0x026C, 0xFFFF, 0xFFFF, "MCP51 High Definition Audio(0x026C)"},
{0x10DE, 0x026C, 0x103C, 0x2A34, "Pavilion a1677c(0x103C-0x2A34)"},
{0x10DE, 0x026C, 0x103C, 0x30B5, "Presario V3242AU(0x103C-0x30B5)"},
{0x10DE, 0x026C, 0x103C, 0x30B7, "Presario V6133CL(0x103C-0x30B7)"},
{0x10DE, 0x026C, 0x10DE, 0xCB84, "ASUSTeK Computer Inc. A8N-VM CSM Mainboard(0x10DE-0xCB84)"},
{0x10DE, 0x026C, 0x1462, 0x7207, "K8NGM2 series(0x1462-0x7207)"},
{0x10DE, 0x026D, 0xFFFF, 0xFFFF, "MCP51 USB Controller(0x026D)"},
{0x10DE, 0x026D, 0x103C, 0x2A34, "Pavilion a1677c(0x103C-0x2A34)"},
{0x10DE, 0x026D, 0x103C, 0x30B7, "Presario V6133CL(0x103C-0x30B7)"},
{0x10DE, 0x026D, 0x1043, 0x81BC, "A8N-VM CSM Mainboard(0x1043-0x81BC)"},
{0x10DE, 0x026D, 0x105B, 0x0CAD, "Winfast 6100K8MB(0x105B-0x0CAD)"},
{0x10DE, 0x026D, 0x1462, 0x7207, "K8NGM2 series(0x1462-0x7207)"},
{0x10DE, 0x026E, 0xFFFF, 0xFFFF, "MCP51 USB Controller(0x026E)"},
{0x10DE, 0x026E, 0x103C, 0x2A34, "Pavilion a1677c(0x103C-0x2A34)"},
{0x10DE, 0x026E, 0x103C, 0x30B7, "Presario V6133CL(0x103C-0x30B7)"},
{0x10DE, 0x026E, 0x1043, 0x81BC, "A8N-VM CSM Mainboard(0x1043-0x81BC)"},
{0x10DE, 0x026E, 0x105B, 0x0CAD, "Winfast 6100K8MB(0x105B-0x0CAD)"},
{0x10DE, 0x026E, 0x1462, 0x7207, "K8NGM2 series(0x1462-0x7207)"},
{0x10DE, 0x026F, 0xFFFF, 0xFFFF, "MCP51 PCI Bridge(0x026F)"},
{0x10DE, 0x026F, 0x103C, 0x30B7, "Presario V6133CL(0x103C-0x30B7)"},
{0x10DE, 0x0270, 0xFFFF, 0xFFFF, "MCP51 Host Bridge(0x0270)"},
{0x10DE, 0x0270, 0x103C, 0x2A34, "Pavilion a1677c(0x103C-0x2A34)"},
{0x10DE, 0x0270, 0x103C, 0x30B7, "Presario V6133CL(0x103C-0x30B7)"},
{0x10DE, 0x0270, 0x1043, 0x81BC, "A8N-VM CSM Mainboard(0x1043-0x81BC)"},
{0x10DE, 0x0270, 0x105B, 0x0CAD, "Winfast 6100K8MB(0x105B-0x0CAD)"},
{0x10DE, 0x0270, 0x1458, 0x5001, "GA-M55plus-S3G(0x1458-0x5001)"},
{0x10DE, 0x0270, 0x1462, 0x7207, "K8NGM2 series(0x1462-0x7207)"},
{0x10DE, 0x0271, 0xFFFF, 0xFFFF, "MCP51 PMU(0x0271)"},
{0x10DE, 0x0271, 0x103C, 0x30B5, "Presario V3242AU(0x103C-0x30B5)"},
{0x10DE, 0x0271, 0x103C, 0x30B7, "Presario V6133CL(0x103C-0x30B7)"},
{0x10DE, 0x0272, 0xFFFF, 0xFFFF, "MCP51 Memory Controller 0(0x0272)"},
{0x10DE, 0x0272, 0x103C, 0x2A34, "Pavilion a1677c(0x103C-0x2A34)"},
{0x10DE, 0x0272, 0x105B, 0x0CAD, "Winfast 6100K8MB(0x105B-0x0CAD)"},
{0x10DE, 0x027E, 0xFFFF, 0xFFFF, "C51 Memory Controller 2(0x027E)"},
{0x10DE, 0x027E, 0x103C, 0x2A34, "Pavilion a1677c(0x103C-0x2A34)"},
{0x10DE, 0x027E, 0x103C, 0x30B7, "Presario V6133CL(0x103C-0x30B7)"},
{0x10DE, 0x027E, 0x1043, 0x81CD, "A8N-VM CSM Mainboard(0x1043-0x81CD)"},
{0x10DE, 0x027E, 0x1458, 0x5000, "GA-M55plus-S3G(0x1458-0x5000)"},
{0x10DE, 0x027E, 0x1462, 0x7207, "K8NGM2 series(0x1462-0x7207)"},
{0x10DE, 0x027F, 0xFFFF, 0xFFFF, "C51 Memory Controller 3(0x027F)"},
{0x10DE, 0x027F, 0x103C, 0x2A34, "Pavilion a1677c(0x103C-0x2A34)"},
{0x10DE, 0x027F, 0x103C, 0x30B7, "Presario V6133CL(0x103C-0x30B7)"},
{0x10DE, 0x027F, 0x1043, 0x81CD, "A8N-VM CSM Mainboard(0x1043-0x81CD)"},
{0x10DE, 0x027F, 0x1458, 0x5000, "GA-M55plus-S3G(0x1458-0x5000)"},
{0x10DE, 0x027F, 0x1462, 0x7207, "K8NGM2 series(0x1462-0x7207)"},
{0x10DE, 0x0280, 0xFFFF, 0xFFFF, "NV28 [GeForce4 Ti 4800](0x0280)"},
{0x10DE, 0x0281, 0xFFFF, 0xFFFF, "NV28 [GeForce4 Ti 4200 AGP 8x](0x0281)"},
{0x10DE, 0x0282, 0xFFFF, 0xFFFF, "NV28 [GeForce4 Ti 4800 SE](0x0282)"},
{0x10DE, 0x0286, 0xFFFF, 0xFFFF, "NV28M [GeForce4 Ti 4200 Go AGP 8x](0x0286)"},
{0x10DE, 0x0288, 0xFFFF, 0xFFFF, "NV28GL [Quadro4 980 XGL](0x0288)"},
{0x10DE, 0x0289, 0xFFFF, 0xFFFF, "NV28GL [Quadro4 780 XGL](0x0289)"},
{0x10DE, 0x028C, 0xFFFF, 0xFFFF, "NV28GLM [Quadro4 Go700](0x028C)"},
{0x10DE, 0x0290, 0xFFFF, 0xFFFF, "G71 [GeForce 7900 GTX](0x0290)"},
{0x10DE, 0x0291, 0xFFFF, 0xFFFF, "G71 [GeForce 7900 GT/GTO](0x0291)"},
{0x10DE, 0x0291, 0x10DE, 0x042B, "NX7900GTO-T2D512E [7900 GTO](0x10DE-0x042B)"},
{0x10DE, 0x0292, 0xFFFF, 0xFFFF, "G71 [GeForce 7900 GS](0x0292)"},
{0x10DE, 0x0293, 0xFFFF, 0xFFFF, "G71 [GeForce 7900 GX2](0x0293)"},
{0x10DE, 0x0294, 0xFFFF, 0xFFFF, "G71 [GeForce 7950 GX2](0x0294)"},
{0x10DE, 0x0295, 0xFFFF, 0xFFFF, "G71 [GeForce 7950 GT](0x0295)"},
{0x10DE, 0x0295, 0x1043, 0x8225, "GeForce 7950 GT(0x1043-0x8225)"},
{0x10DE, 0x0295, 0x107D, 0x2A68, "WinFast PX7950GT TDH(0x107D-0x2A68)"},
{0x10DE, 0x0295, 0x1462, 0x0663, "NX7950GT-VT2D512EZ-HD(0x1462-0x0663)"},
{0x10DE, 0x0297, 0xFFFF, 0xFFFF, "G71M [GeForce Go 7950 GTX](0x0297)"},
{0x10DE, 0x0298, 0xFFFF, 0xFFFF, "G71M [GeForce Go 7900 GS](0x0298)"},
{0x10DE, 0x0299, 0xFFFF, 0xFFFF, "G71M [GeForce Go 7900 GTX](0x0299)"},
{0x10DE, 0x029A, 0xFFFF, 0xFFFF, "G71GLM [Quadro FX 2500M](0x029A)"},
{0x10DE, 0x029B, 0xFFFF, 0xFFFF, "G71GLM [Quadro FX 1500M](0x029B)"},
{0x10DE, 0x029C, 0xFFFF, 0xFFFF, "G71GL [Quadro FX 5500](0x029C)"},
{0x10DE, 0x029D, 0xFFFF, 0xFFFF, "G71GL [Quadro FX 3500](0x029D)"},
{0x10DE, 0x029D, 0x1028, 0x019B, "G71GLM [Quadro FX 3500M](0x1028-0x019B)"},
{0x10DE, 0x029E, 0xFFFF, 0xFFFF, "G71GL [Quadro FX 1500](0x029E)"},
{0x10DE, 0x029F, 0xFFFF, 0xFFFF, "G71GL [Quadro FX 4500 X2](0x029F)"},
{0x10DE, 0x02A0, 0xFFFF, 0xFFFF, "NV2A [XGPU](0x02A0)"},
{0x10DE, 0x02A5, 0xFFFF, 0xFFFF, "MCPX CPU Bridge(0x02A5)"},
{0x10DE, 0x02A6, 0xFFFF, 0xFFFF, "MCPX Memory Controller(0x02A6)"},
{0x10DE, 0x02E0, 0xFFFF, 0xFFFF, "G73 [GeForce 7600 GT AGP](0x02E0)"},
{0x10DE, 0x02E0, 0x02E0, 0x2249, "GF 7600GT 560M 256MB DDR3 DUAL DVI TV(0x02E0-0x2249)"},
{0x10DE, 0x02E1, 0xFFFF, 0xFFFF, "G73 [GeForce 7600 GS AGP](0x02E1)"},
{0x10DE, 0x02E1, 0x1682, 0x222B, "PV-T73K-UAL3 (256MB)(0x1682-0x222B)"},
{0x10DE, 0x02E1, 0x1682, 0x2247, "GF 7600GS 512MB DDR2(0x1682-0x2247)"},
{0x10DE, 0x02E2, 0xFFFF, 0xFFFF, "G73 [GeForce 7300 GT AGP](0x02E2)"},
{0x10DE, 0x02E3, 0xFFFF, 0xFFFF, "G71 [GeForce 7900 GS AGP](0x02E3)"},
{0x10DE, 0x02E4, 0xFFFF, 0xFFFF, "G71 [GeForce 7950 GT AGP](0x02E4)"},
{0x10DE, 0x02E4, 0x1682, 0x2271, "PV-T71A-YDF7 (512MB)(0x1682-0x2271)"},
{0x10DE, 0x02E5, 0xFFFF, 0xFFFF, "G71 [GeForce 7600 GS AGP](0x02E5)"},
{0x10DE, 0x02F0, 0xFFFF, 0xFFFF, "C51 Host Bridge(0x02F0)"},
{0x10DE, 0x02F0, 0x103C, 0x2A34, "Pavilion a1677c(0x103C-0x2A34)"},
{0x10DE, 0x02F0, 0x103C, 0x30B7, "Presario V6133CL(0x103C-0x30B7)"},
{0x10DE, 0x02F0, 0x1043, 0x81CD, "A8N-VM CSM Mainboard(0x1043-0x81CD)"},
{0x10DE, 0x02F0, 0x1462, 0x7207, "K8NGM2 series(0x1462-0x7207)"},
{0x10DE, 0x02F1, 0xFFFF, 0xFFFF, "C51 Host Bridge(0x02F1)"},
{0x10DE, 0x02F1, 0x1458, 0x5000, "GA-M55plus-S3G(0x1458-0x5000)"},
{0x10DE, 0x02F2, 0xFFFF, 0xFFFF, "C51 Host Bridge(0x02F2)"},
{0x10DE, 0x02F3, 0xFFFF, 0xFFFF, "C51 Host Bridge(0x02F3)"},
{0x10DE, 0x02F4, 0xFFFF, 0xFFFF, "C51 Host Bridge(0x02F4)"},
{0x10DE, 0x02F5, 0xFFFF, 0xFFFF, "C51 Host Bridge(0x02F5)"},
{0x10DE, 0x02F6, 0xFFFF, 0xFFFF, "C51 Host Bridge(0x02F6)"},
{0x10DE, 0x02F7, 0xFFFF, 0xFFFF, "C51 Host Bridge(0x02F7)"},
{0x10DE, 0x02F8, 0xFFFF, 0xFFFF, "C51 Memory Controller 5(0x02F8)"},
{0x10DE, 0x02F8, 0x103C, 0x2A34, "Pavilion a1677c(0x103C-0x2A34)"},
{0x10DE, 0x02F8, 0x103C, 0x30B7, "Presario V6133CL(0x103C-0x30B7)"},
{0x10DE, 0x02F8, 0x1043, 0x81CD, "A8N-VM CSM Mainboard(0x1043-0x81CD)"},
{0x10DE, 0x02F8, 0x1458, 0x5000, "GA-M55plus-S3G(0x1458-0x5000)"},
{0x10DE, 0x02F8, 0x1462, 0x7207, "K8NGM2 series(0x1462-0x7207)"},
{0x10DE, 0x02F9, 0xFFFF, 0xFFFF, "C51 Memory Controller 4(0x02F9)"},
{0x10DE, 0x02F9, 0x103C, 0x2A34, "Pavilion a1677c(0x103C-0x2A34)"},
{0x10DE, 0x02F9, 0x103C, 0x30B7, "Presario V6133CL(0x103C-0x30B7)"},
{0x10DE, 0x02F9, 0x1043, 0x81CD, "A8N-VM CSM Mainboard(0x1043-0x81CD)"},
{0x10DE, 0x02F9, 0x1458, 0x5000, "GA-M55plus-S3G(0x1458-0x5000)"},
{0x10DE, 0x02F9, 0x1462, 0x7207, "K8NGM2 series(0x1462-0x7207)"},
{0x10DE, 0x02FA, 0xFFFF, 0xFFFF, "C51 Memory Controller 0(0x02FA)"},
{0x10DE, 0x02FA, 0x103C, 0x2A34, "Pavilion a1677c(0x103C-0x2A34)"},
{0x10DE, 0x02FA, 0x103C, 0x30B7, "Presario V6133CL(0x103C-0x30B7)"},
{0x10DE, 0x02FA, 0x1043, 0x81CD, "A8N-VM CSM Mainboard(0x1043-0x81CD)"},
{0x10DE, 0x02FA, 0x1458, 0x5000, "GA-M55plus-S3G(0x1458-0x5000)"},
{0x10DE, 0x02FA, 0x1462, 0x7207, "K8NGM2 series(0x1462-0x7207)"},
{0x10DE, 0x02FB, 0xFFFF, 0xFFFF, "C51 PCI Express Bridge(0x02FB)"},
{0x10DE, 0x02FC, 0xFFFF, 0xFFFF, "C51 PCI Express Bridge(0x02FC)"},
{0x10DE, 0x02FC, 0x103C, 0x30B7, "Presario V6133CL(0x103C-0x30B7)"},
{0x10DE, 0x02FD, 0xFFFF, 0xFFFF, "C51 PCI Express Bridge(0x02FD)"},
{0x10DE, 0x02FD, 0x103C, 0x30B7, "Presario V6133CL(0x103C-0x30B7)"},
{0x10DE, 0x02FE, 0xFFFF, 0xFFFF, "C51 Memory Controller 1(0x02FE)"},
{0x10DE, 0x02FE, 0x103C, 0x2A34, "Pavilion a1677c(0x103C-0x2A34)"},
{0x10DE, 0x02FE, 0x103C, 0x30B7, "Presario V6133CL(0x103C-0x30B7)"},
{0x10DE, 0x02FE, 0x1043, 0x81CD, "A8N-VM CSM Mainboard(0x1043-0x81CD)"},
{0x10DE, 0x02FE, 0x1458, 0x5000, "GA-M55plus-S3G(0x1458-0x5000)"},
{0x10DE, 0x02FE, 0x1462, 0x7207, "K8NGM2 series(0x1462-0x7207)"},
{0x10DE, 0x02FF, 0xFFFF, 0xFFFF, "C51 Host Bridge(0x02FF)"},
{0x10DE, 0x02FF, 0x103C, 0x2A34, "Pavilion a1677c(0x103C-0x2A34)"},
{0x10DE, 0x02FF, 0x103C, 0x30B7, "Presario V6133CL(0x103C-0x30B7)"},
{0x10DE, 0x02FF, 0x1043, 0x81CD, "A8N-VM CSM Mainboard(0x1043-0x81CD)"},
{0x10DE, 0x02FF, 0x1458, 0x5000, "GA-M55plus-S3G(0x1458-0x5000)"},
{0x10DE, 0x02FF, 0x1462, 0x7207, "K8NGM2 series(0x1462-0x7207)"},
{0x10DE, 0x0300, 0xFFFF, 0xFFFF, "NV30 [GeForce FX](0x0300)"},
{0x10DE, 0x0301, 0xFFFF, 0xFFFF, "NV30 [GeForce FX 5800 Ultra](0x0301)"},
{0x10DE, 0x0302, 0xFFFF, 0xFFFF, "NV30 [GeForce FX 5800](0x0302)"},
{0x10DE, 0x0308, 0xFFFF, 0xFFFF, "NV30GL [Quadro FX 2000](0x0308)"},
{0x10DE, 0x0309, 0xFFFF, 0xFFFF, "NV30GL [Quadro FX 1000](0x0309)"},
{0x10DE, 0x0311, 0xFFFF, 0xFFFF, "NV31 [GeForce FX 5600 Ultra](0x0311)"},
{0x10DE, 0x0312, 0xFFFF, 0xFFFF, "NV31 [GeForce FX 5600](0x0312)"},
{0x10DE, 0x0314, 0xFFFF, 0xFFFF, "NV31 [GeForce FX 5600XT](0x0314)"},
{0x10DE, 0x0314, 0x1043, 0x814A, "V9560XT/TD(0x1043-0x814A)"},
{0x10DE, 0x0316, 0xFFFF, 0xFFFF, "NV31M(0x0316)"},
{0x10DE, 0x0318, 0xFFFF, 0xFFFF, "NV31GL(0x0318)"},
{0x10DE, 0x031A, 0xFFFF, 0xFFFF, "NV31M [GeForce FX Go5600](0x031A)"},
{0x10DE, 0x031B, 0xFFFF, 0xFFFF, "NV31M [GeForce FX Go5650](0x031B)"},
{0x10DE, 0x031C, 0xFFFF, 0xFFFF, "NV31GLM [Quadro FX Go700](0x031C)"},
{0x10DE, 0x0320, 0xFFFF, 0xFFFF, "NV34 [GeForce FX 5200](0x0320)"},
{0x10DE, 0x0321, 0xFFFF, 0xFFFF, "NV34 [GeForce FX 5200 Ultra](0x0321)"},
{0x10DE, 0x0322, 0xFFFF, 0xFFFF, "NV34 [GeForce FX 5200](0x0322)"},
{0x10DE, 0x0322, 0x1043, 0x02FB, "V9250 Magic(0x1043-0x02FB)"},
{0x10DE, 0x0322, 0x1043, 0x8180, "V9520-X/TD/128M(0x1043-0x8180)"},
{0x10DE, 0x0322, 0x107D, 0x2967, "WinFast A340T 128MB(0x107D-0x2967)"},
{0x10DE, 0x0322, 0x1462, 0x9110, "MS-8911 (FX5200-TD128)(0x1462-0x9110)"},
{0x10DE, 0x0322, 0x1462, 0x9171, "MS-8917 (FX5200-T128)(0x1462-0x9171)"},
{0x10DE, 0x0322, 0x1462, 0x9360, "MS-8936 (FX5200-T128)(0x1462-0x9360)"},
{0x10DE, 0x0322, 0x1682, 0x1351, "GeForce FX 5200(0x1682-0x1351)"},
{0x10DE, 0x0323, 0xFFFF, 0xFFFF, "NV34 [GeForce FX 5200LE](0x0323)"},
{0x10DE, 0x0324, 0xFFFF, 0xFFFF, "NV34M [GeForce FX Go5200 64M](0x0324)"},
{0x10DE, 0x0324, 0x1028, 0x0196, "Inspiron 5160(0x1028-0x0196)"},
{0x10DE, 0x0324, 0x103C, 0x006A, "Pavilion ZD7000 laptop(0x103C-0x006A)"},
{0x10DE, 0x0324, 0x1071, 0x8160, "MIM2000(0x1071-0x8160)"},
{0x10DE, 0x0325, 0xFFFF, 0xFFFF, "NV34M [GeForce FX Go5250](0x0325)"},
{0x10DE, 0x0326, 0xFFFF, 0xFFFF, "NV34 [GeForce FX 5500](0x0326)"},
{0x10DE, 0x0326, 0x1458, 0x310D, "GeForce FX 5500 128 MB(0x1458-0x310D)"},
{0x10DE, 0x0326, 0x1682, 0x2034, "GeForce 5500 256 MB(0x1682-0x2034)"},
{0x10DE, 0x0327, 0xFFFF, 0xFFFF, "NV34 [GeForce FX 5100](0x0327)"},
{0x10DE, 0x0328, 0xFFFF, 0xFFFF, "NV34M [GeForce FX Go5200 32M/64M](0x0328)"},
{0x10DE, 0x0329, 0xFFFF, 0xFFFF, "NV34M [GeForce FX Go5200](0x0329)"},
{0x10DE, 0x0329, 0x10DE, 0x0010, "Powerbook G4(0x10DE-0x0010)"},
{0x10DE, 0x032A, 0xFFFF, 0xFFFF, "NV34GL [Quadro NVS 280 PCI](0x032A)"},
{0x10DE, 0x032B, 0xFFFF, 0xFFFF, "NV34GL [Quadro FX 500/600 PCI](0x032B)"},
{0x10DE, 0x032C, 0xFFFF, 0xFFFF, "NV34M [GeForce FX Go5300 / Go5350](0x032C)"},
{0x10DE, 0x032D, 0xFFFF, 0xFFFF, "NV34M [GeForce FX Go5100](0x032D)"},
{0x10DE, 0x032E, 0xFFFF, 0xFFFF, "NV34(0x032E)"},
{0x10DE, 0x032F, 0xFFFF, 0xFFFF, "NV34 [GeForce FX 5200](0x032F)"},
{0x10DE, 0x0330, 0xFFFF, 0xFFFF, "NV35 [GeForce FX 5900 Ultra](0x0330)"},
{0x10DE, 0x0330, 0x1043, 0x8137, "V9950 Ultra / 256 MB(0x1043-0x8137)"},
{0x10DE, 0x0331, 0xFFFF, 0xFFFF, "NV35 [GeForce FX 5900](0x0331)"},
{0x10DE, 0x0331, 0x1043, 0x8145, "V9950GE(0x1043-0x8145)"},
{0x10DE, 0x0332, 0xFFFF, 0xFFFF, "NV35 [GeForce FX 5900XT](0x0332)"},
{0x10DE, 0x0333, 0xFFFF, 0xFFFF, "NV38 [GeForce FX 5950 Ultra](0x0333)"},
{0x10DE, 0x0334, 0xFFFF, 0xFFFF, "NV35 [GeForce FX 5900ZT](0x0334)"},
{0x10DE, 0x0334, 0x1462, 0x9373, "FX5900ZT-VTD128 (MS-8937)(0x1462-0x9373)"},
{0x10DE, 0x0338, 0xFFFF, 0xFFFF, "NV35GL [Quadro FX 3000](0x0338)"},
{0x10DE, 0x033F, 0xFFFF, 0xFFFF, "NV35GL [Quadro FX 700](0x033F)"},
{0x10DE, 0x0341, 0xFFFF, 0xFFFF, "NV36 [GeForce FX 5700 Ultra](0x0341)"},
{0x10DE, 0x0341, 0x1462, 0x9380, "MS-8938 (FX5700U-TD128)(0x1462-0x9380)"},
{0x10DE, 0x0342, 0xFFFF, 0xFFFF, "NV36 [GeForce FX 5700](0x0342)"},
{0x10DE, 0x0343, 0xFFFF, 0xFFFF, "NV36 [GeForce FX 5700LE](0x0343)"},
{0x10DE, 0x0344, 0xFFFF, 0xFFFF, "NV36 [GeForce FX 5700VE](0x0344)"},
{0x10DE, 0x0347, 0xFFFF, 0xFFFF, "NV36M [GeForce FX Go5700](0x0347)"},
{0x10DE, 0x0347, 0x103C, 0x006A, "NX9500(0x103C-0x006A)"},
{0x10DE, 0x0348, 0xFFFF, 0xFFFF, "NV36M [GeForce FX Go5700](0x0348)"},
{0x10DE, 0x034C, 0xFFFF, 0xFFFF, "NV36 [Quadro FX Go1000](0x034C)"},
{0x10DE, 0x034D, 0xFFFF, 0xFFFF, "NV36(0x034D)"},
{0x10DE, 0x034E, 0xFFFF, 0xFFFF, "NV36GL [Quadro FX 1100](0x034E)"},
{0x10DE, 0x0360, 0xFFFF, 0xFFFF, "MCP55 LPC Bridge(0x0360)"},
{0x10DE, 0x0361, 0xFFFF, 0xFFFF, "MCP55 LPC Bridge(0x0361)"},
{0x10DE, 0x0361, 0x1028, 0x0221, "PowerEdge R805 MCP55 LPC Bridge(0x1028-0x0221)"},
{0x10DE, 0x0362, 0xFFFF, 0xFFFF, "MCP55 LPC Bridge(0x0362)"},
{0x10DE, 0x0362, 0x147B, 0x1C24, "KN9 series mainboard(0x147B-0x1C24)"},
{0x10DE, 0x0363, 0xFFFF, 0xFFFF, "MCP55 LPC Bridge(0x0363)"},
{0x10DE, 0x0364, 0xFFFF, 0xFFFF, "MCP55 LPC Bridge(0x0364)"},
{0x10DE, 0x0364, 0x1028, 0x0221, "PowerEdge R805 MCP55 LPC Bridge(0x1028-0x0221)"},
{0x10DE, 0x0365, 0xFFFF, 0xFFFF, "MCP55 LPC Bridge(0x0365)"},
{0x10DE, 0x0366, 0xFFFF, 0xFFFF, "MCP55 LPC Bridge(0x0366)"},
{0x10DE, 0x0367, 0xFFFF, 0xFFFF, "MCP55 LPC Bridge(0x0367)"},
{0x10DE, 0x0368, 0xFFFF, 0xFFFF, "MCP55 SMBus Controller(0x0368)"},
{0x10DE, 0x0368, 0x1028, 0x020C, "PowerEdge M605 MCP55 SMBus(0x1028-0x020C)"},
{0x10DE, 0x0368, 0x1028, 0x0221, "PowerEdge R805 MCP55 SMBus(0x1028-0x0221)"},
{0x10DE, 0x0368, 0x147B, 0x1C24, "KN9 series mainboard(0x147B-0x1C24)"},
{0x10DE, 0x0369, 0xFFFF, 0xFFFF, "MCP55 Memory Controller(0x0369)"},
{0x10DE, 0x0369, 0x147B, 0x1C24, "KN9 series mainboard(0x147B-0x1C24)"},
{0x10DE, 0x036A, 0xFFFF, 0xFFFF, "MCP55 Memory Controller(0x036A)"},
{0x10DE, 0x036B, 0xFFFF, 0xFFFF, "MCP55 SMU(0x036B)"},
{0x10DE, 0x036C, 0xFFFF, 0xFFFF, "MCP55 USB Controller(0x036C)"},
{0x10DE, 0x036C, 0x1028, 0x020C, "PowerEdge M605 MCP55 USB Controller(0x1028-0x020C)"},
{0x10DE, 0x036C, 0x1028, 0x0221, "PowerEdge R805 MCP55 USB Controller(0x1028-0x0221)"},
{0x10DE, 0x036C, 0x147B, 0x1C24, "KN9 series mainboard(0x147B-0x1C24)"},
{0x10DE, 0x036D, 0xFFFF, 0xFFFF, "MCP55 USB Controller(0x036D)"},
{0x10DE, 0x036D, 0x1028, 0x020C, "PowerEdge M605 MCP55 USB Controller(0x1028-0x020C)"},
{0x10DE, 0x036D, 0x1028, 0x0221, "PowerEdge R805 MCP55 USB Controller(0x1028-0x0221)"},
{0x10DE, 0x036D, 0x147B, 0x1C24, "KN9 series mainboard(0x147B-0x1C24)"},
{0x10DE, 0x036E, 0xFFFF, 0xFFFF, "MCP55 IDE(0x036E)"},
{0x10DE, 0x036E, 0x147B, 0x1C24, "KN9 series mainboard(0x147B-0x1C24)"},
{0x10DE, 0x0370, 0xFFFF, 0xFFFF, "MCP55 PCI bridge(0x0370)"},
{0x10DE, 0x0371, 0xFFFF, 0xFFFF, "MCP55 High Definition Audio(0x0371)"},
{0x10DE, 0x0371, 0x147B, 0x1C24, "KN9 series mainboard(0x147B-0x1C24)"},
{0x10DE, 0x0372, 0xFFFF, 0xFFFF, "MCP55 Ethernet(0x0372)"},
{0x10DE, 0x0373, 0xFFFF, 0xFFFF, "MCP55 Ethernet(0x0373)"},
{0x10DE, 0x0373, 0x147B, 0x1C24, "KN9 series mainboard(0x147B-0x1C24)"},
{0x10DE, 0x0374, 0xFFFF, 0xFFFF, "MCP55 PCI Express bridge(0x0374)"},
{0x10DE, 0x0375, 0xFFFF, 0xFFFF, "MCP55 PCI Express bridge(0x0375)"},
{0x10DE, 0x0376, 0xFFFF, 0xFFFF, "MCP55 PCI Express bridge(0x0376)"},
{0x10DE, 0x0377, 0xFFFF, 0xFFFF, "MCP55 PCI Express bridge(0x0377)"},
{0x10DE, 0x0378, 0xFFFF, 0xFFFF, "MCP55 PCI Express bridge(0x0378)"},
{0x10DE, 0x037A, 0xFFFF, 0xFFFF, "MCP55 Memory Controller(0x037A)"},
{0x10DE, 0x037E, 0xFFFF, 0xFFFF, "MCP55 SATA Controller(0x037E)"},
{0x10DE, 0x037F, 0xFFFF, 0xFFFF, "MCP55 SATA Controller(0x037F)"},
{0x10DE, 0x037F, 0x1028, 0x0221, "PowerEdge R805 MCP55 SATA Controller(0x1028-0x0221)"},
{0x10DE, 0x037F, 0x147B, 0x1C24, "KN9 series mainboard(0x147B-0x1C24)"},
{0x10DE, 0x038B, 0xFFFF, 0xFFFF, "G73 [GeForce 7650 GS](0x038B)"},
{0x10DE, 0x0390, 0xFFFF, 0xFFFF, "G73 [GeForce 7650 GS](0x0390)"},
{0x10DE, 0x0391, 0xFFFF, 0xFFFF, "G73 [GeForce 7600 GT](0x0391)"},
{0x10DE, 0x0391, 0x1458, 0x3427, "GV-NX76T128D-RH(0x1458-0x3427)"},
{0x10DE, 0x0391, 0x1462, 0x0452, "NX7600GT-VT2D256E(0x1462-0x0452)"},
{0x10DE, 0x0392, 0xFFFF, 0xFFFF, "G73 [GeForce 7600 GS](0x0392)"},
{0x10DE, 0x0392, 0x1462, 0x0622, "NX7600GS-T2D256EH(0x1462-0x0622)"},
{0x10DE, 0x0393, 0xFFFF, 0xFFFF, "G73 [GeForce 7300 GT](0x0393)"},
{0x10DE, 0x0393, 0x10DE, 0x0412, "NX7300GT-TD256EH(0x10DE-0x0412)"},
{0x10DE, 0x0393, 0x1462, 0x0412, "NX7300GT-TD256EH(0x1462-0x0412)"},
{0x10DE, 0x0394, 0xFFFF, 0xFFFF, "G73 [GeForce 7600 LE](0x0394)"},
{0x10DE, 0x0395, 0xFFFF, 0xFFFF, "G73 [GeForce 7300 GT](0x0395)"},
{0x10DE, 0x0396, 0xFFFF, 0xFFFF, "G73(0x0396)"},
{0x10DE, 0x0397, 0xFFFF, 0xFFFF, "G73M [GeForce Go 7700](0x0397)"},
{0x10DE, 0x0398, 0xFFFF, 0xFFFF, "G73M [GeForce Go 7600](0x0398)"},
{0x10DE, 0x0398, 0x1025, 0x006C, "Aspire 9814WKMi(0x1025-0x006C)"},
{0x10DE, 0x0399, 0xFFFF, 0xFFFF, "G73M [GeForce Go 7600 GT](0x0399)"},
{0x10DE, 0x039A, 0xFFFF, 0xFFFF, "G73M [Quadro NVS 300M](0x039A)"},
{0x10DE, 0x039B, 0xFFFF, 0xFFFF, "G73M [GeForce Go 7900 SE](0x039B)"},
{0x10DE, 0x039C, 0xFFFF, 0xFFFF, "G73GLM [Quadro FX 550M](0x039C)"},
{0x10DE, 0x039C, 0x10DE, 0x039C, "Quadro FX 560M(0x10DE-0x039C)"},
{0x10DE, 0x039D, 0xFFFF, 0xFFFF, "G73(0x039D)"},
{0x10DE, 0x039E, 0xFFFF, 0xFFFF, "G73GL [Quadro FX 560](0x039E)"},
{0x10DE, 0x039F, 0xFFFF, 0xFFFF, "G73(0x039F)"},
{0x10DE, 0x03A0, 0xFFFF, 0xFFFF, "C55 Host Bridge(0x03A0)"},
{0x10DE, 0x03A1, 0xFFFF, 0xFFFF, "C55 Host Bridge(0x03A1)"},
{0x10DE, 0x03A2, 0xFFFF, 0xFFFF, "C55 Host Bridge(0x03A2)"},
{0x10DE, 0x03A3, 0xFFFF, 0xFFFF, "C55 Host Bridge(0x03A3)"},
{0x10DE, 0x03A4, 0xFFFF, 0xFFFF, "C55 Host Bridge(0x03A4)"},
{0x10DE, 0x03A5, 0xFFFF, 0xFFFF, "C55 Host Bridge(0x03A5)"},
{0x10DE, 0x03A6, 0xFFFF, 0xFFFF, "C55 Host Bridge(0x03A6)"},
{0x10DE, 0x03A7, 0xFFFF, 0xFFFF, "C55 Host Bridge(0x03A7)"},
{0x10DE, 0x03A8, 0xFFFF, 0xFFFF, "C55 Memory Controller(0x03A8)"},
{0x10DE, 0x03A9, 0xFFFF, 0xFFFF, "C55 Memory Controller(0x03A9)"},
{0x10DE, 0x03AA, 0xFFFF, 0xFFFF, "C55 Memory Controller(0x03AA)"},
{0x10DE, 0x03AB, 0xFFFF, 0xFFFF, "C55 Memory Controller(0x03AB)"},
{0x10DE, 0x03AC, 0xFFFF, 0xFFFF, "C55 Memory Controller(0x03AC)"},
{0x10DE, 0x03AD, 0xFFFF, 0xFFFF, "C55 Memory Controller(0x03AD)"},
{0x10DE, 0x03AE, 0xFFFF, 0xFFFF, "C55 Memory Controller(0x03AE)"},
{0x10DE, 0x03AF, 0xFFFF, 0xFFFF, "C55 Memory Controller(0x03AF)"},
{0x10DE, 0x03B0, 0xFFFF, 0xFFFF, "C55 Memory Controller(0x03B0)"},
{0x10DE, 0x03B1, 0xFFFF, 0xFFFF, "C55 Memory Controller(0x03B1)"},
{0x10DE, 0x03B2, 0xFFFF, 0xFFFF, "C55 Memory Controller(0x03B2)"},
{0x10DE, 0x03B3, 0xFFFF, 0xFFFF, "C55 Memory Controller(0x03B3)"},
{0x10DE, 0x03B4, 0xFFFF, 0xFFFF, "C55 Memory Controller(0x03B4)"},
{0x10DE, 0x03B5, 0xFFFF, 0xFFFF, "C55 Memory Controller(0x03B5)"},
{0x10DE, 0x03B6, 0xFFFF, 0xFFFF, "C55 Memory Controller(0x03B6)"},
{0x10DE, 0x03B7, 0xFFFF, 0xFFFF, "C55 PCI Express bridge(0x03B7)"},
{0x10DE, 0x03B8, 0xFFFF, 0xFFFF, "C55 PCI Express bridge(0x03B8)"},
{0x10DE, 0x03B9, 0xFFFF, 0xFFFF, "C55 PCI Express bridge(0x03B9)"},
{0x10DE, 0x03BA, 0xFFFF, 0xFFFF, "C55 Memory Controller(0x03BA)"},
{0x10DE, 0x03BB, 0xFFFF, 0xFFFF, "C55 PCI Express bridge(0x03BB)"},
{0x10DE, 0x03BC, 0xFFFF, 0xFFFF, "C55 Memory Controller(0x03BC)"},
{0x10DE, 0x03D0, 0xFFFF, 0xFFFF, "C61 [GeForce 6150SE nForce 430](0x03D0)"},
{0x10DE, 0x03D0, 0x1028, 0x020E, "Inspiron 531(0x1028-0x020E)"},
{0x10DE, 0x03D1, 0xFFFF, 0xFFFF, "C61 [GeForce 6100 nForce 405](0x03D1)"},
{0x10DE, 0x03D2, 0xFFFF, 0xFFFF, "C61 [GeForce 6100 nForce 400](0x03D2)"},
{0x10DE, 0x03D5, 0xFFFF, 0xFFFF, "C61 [GeForce 6100 nForce 420](0x03D5)"},
{0x10DE, 0x03D6, 0xFFFF, 0xFFFF, "C61 [GeForce 7025 / nForce 630a](0x03D6)"},
{0x10DE, 0x03E0, 0xFFFF, 0xFFFF, "MCP61 LPC Bridge(0x03E0)"},
{0x10DE, 0x03E0, 0x1028, 0x020E, "Inspiron 531(0x1028-0x020E)"},
{0x10DE, 0x03E0, 0x1849, 0x03E0, "939NF6G-VSTA Board(0x1849-0x03E0)"},
{0x10DE, 0x03E1, 0xFFFF, 0xFFFF, "MCP61 LPC Bridge(0x03E1)"},
{0x10DE, 0x03E1, 0x1043, 0x83A4, "M4N68T series motherboard(0x1043-0x83A4)"},
{0x10DE, 0x03E2, 0xFFFF, 0xFFFF, "MCP61 Host Bridge(0x03E2)"},
{0x10DE, 0x03E2, 0x1043, 0x83A4, "M4N68T series motherboard(0x1043-0x83A4)"},
{0x10DE, 0x03E3, 0xFFFF, 0xFFFF, "MCP61 LPC Bridge(0x03E3)"},
{0x10DE, 0x03E4, 0xFFFF, 0xFFFF, "MCP61 High Definition Audio(0x03E4)"},
{0x10DE, 0x03E5, 0xFFFF, 0xFFFF, "MCP61 Ethernet(0x03E5)"},
{0x10DE, 0x03E6, 0xFFFF, 0xFFFF, "MCP61 Ethernet(0x03E6)"},
{0x10DE, 0x03E7, 0xFFFF, 0xFFFF, "MCP61 SATA Controller(0x03E7)"},
{0x10DE, 0x03E8, 0xFFFF, 0xFFFF, "MCP61 PCI Express bridge(0x03E8)"},
{0x10DE, 0x03E8, 0x1028, 0x020E, "Inspiron 531(0x1028-0x020E)"},
{0x10DE, 0x03E8, 0x1849, 0x03E8, "939NF6G-VSTA Board(0x1849-0x03E8)"},
{0x10DE, 0x03E9, 0xFFFF, 0xFFFF, "MCP61 PCI Express bridge(0x03E9)"},
{0x10DE, 0x03E9, 0x1028, 0x020E, "Inspiron 531(0x1028-0x020E)"},
{0x10DE, 0x03E9, 0x1849, 0x03E9, "939NF6G-VSTA Board(0x1849-0x03E9)"},
{0x10DE, 0x03EA, 0xFFFF, 0xFFFF, "MCP61 Memory Controller(0x03EA)"},
{0x10DE, 0x03EA, 0x1028, 0x020E, "Inspiron 531(0x1028-0x020E)"},
{0x10DE, 0x03EA, 0x1849, 0x03EA, "939NF6G-VSTA Board(0x1849-0x03EA)"},
{0x10DE, 0x03EB, 0xFFFF, 0xFFFF, "MCP61 SMBus(0x03EB)"},
{0x10DE, 0x03EB, 0x1028, 0x020E, "Inspiron 531(0x1028-0x020E)"},
{0x10DE, 0x03EB, 0x1043, 0x83A4, "M4N68T series motherboard(0x1043-0x83A4)"},
{0x10DE, 0x03EB, 0x1849, 0x03EB, "939NF6G-VSTA Board(0x1849-0x03EB)"},
{0x10DE, 0x03EC, 0xFFFF, 0xFFFF, "MCP61 IDE(0x03EC)"},
{0x10DE, 0x03EC, 0x1025, 0x0392, "ET1350(0x1025-0x0392)"},
{0x10DE, 0x03EC, 0x1028, 0x020E, "Inspiron 531(0x1028-0x020E)"},
{0x10DE, 0x03EC, 0x1043, 0x83A4, "M4N68T series motherboard(0x1043-0x83A4)"},
{0x10DE, 0x03EC, 0x1849, 0x03EC, "939NF6G-VSTA Board(0x1849-0x03EC)"},
{0x10DE, 0x03EE, 0xFFFF, 0xFFFF, "MCP61 Ethernet(0x03EE)"},
{0x10DE, 0x03EF, 0xFFFF, 0xFFFF, "MCP61 Ethernet(0x03EF)"},
{0x10DE, 0x03EF, 0x1025, 0x8000, "ET1350(0x1025-0x8000)"},
{0x10DE, 0x03EF, 0x1028, 0x020E, "Inspiron 531(0x1028-0x020E)"},
{0x10DE, 0x03EF, 0x1043, 0x83A4, "M4N68T series motherboard(0x1043-0x83A4)"},
{0x10DE, 0x03EF, 0x1849, 0x03EF, "939NF6G-VSTA Board(0x1849-0x03EF)"},
{0x10DE, 0x03F0, 0xFFFF, 0xFFFF, "MCP61 High Definition Audio(0x03F0)"},
{0x10DE, 0x03F0, 0x1028, 0x020E, "Inspiron 531(0x1028-0x020E)"},
{0x10DE, 0x03F0, 0x1043, 0x8415, "M4N68T series motherboard(0x1043-0x8415)"},
{0x10DE, 0x03F0, 0x1849, 0x0888, "939NF6G-VSTA Board(0x1849-0x0888)"},
{0x10DE, 0x03F1, 0xFFFF, 0xFFFF, "MCP61 USB 1.1 Controller(0x03F1)"},
{0x10DE, 0x03F1, 0x1028, 0x020E, "Inspiron 531(0x1028-0x020E)"},
{0x10DE, 0x03F1, 0x1043, 0x83A4, "M4N68T series motherboard(0x1043-0x83A4)"},
{0x10DE, 0x03F1, 0x1849, 0x03F1, "939NF6G-VSTA Board(0x1849-0x03F1)"},
{0x10DE, 0x03F2, 0xFFFF, 0xFFFF, "MCP61 USB 2.0 Controller(0x03F2)"},
{0x10DE, 0x03F2, 0x1028, 0x020E, "Inspiron 531(0x1028-0x020E)"},
{0x10DE, 0x03F2, 0x1043, 0x83A4, "M4N68T series motherboard(0x1043-0x83A4)"},
{0x10DE, 0x03F2, 0x1849, 0x03F2, "939NF6G-VSTA Board(0x1849-0x03F2)"},
{0x10DE, 0x03F3, 0xFFFF, 0xFFFF, "MCP61 PCI bridge(0x03F3)"},
{0x10DE, 0x03F3, 0x1028, 0x020E, "Inspiron 531(0x1028-0x020E)"},
{0x10DE, 0x03F3, 0x1849, 0x03F3, "939NF6G-VSTA Board(0x1849-0x03F3)"},
{0x10DE, 0x03F4, 0xFFFF, 0xFFFF, "MCP61 SMU(0x03F4)"},
{0x10DE, 0x03F5, 0xFFFF, 0xFFFF, "MCP61 Memory Controller(0x03F5)"},
{0x10DE, 0x03F5, 0x1028, 0x020E, "Inspiron 531(0x1028-0x020E)"},
{0x10DE, 0x03F5, 0x1043, 0x83A4, "M4N68T series motherboard(0x1043-0x83A4)"},
{0x10DE, 0x03F5, 0x1849, 0x03EB, "939NF6G-VSTA Board(0x1849-0x03EB)"},
{0x10DE, 0x03F6, 0xFFFF, 0xFFFF, "MCP61 SATA Controller(0x03F6)"},
{0x10DE, 0x03F6, 0x1028, 0x020E, "Inspiron 531(0x1028-0x020E)"},
{0x10DE, 0x03F6, 0x1043, 0x83A4, "M4N68T series motherboard(0x1043-0x83A4)"},
{0x10DE, 0x03F6, 0x1849, 0x03F6, "939NF6G-VSTA Board(0x1849-0x03F6)"},
{0x10DE, 0x03F7, 0xFFFF, 0xFFFF, "MCP61 SATA Controller(0x03F7)"},
{0x10DE, 0x0400, 0xFFFF, 0xFFFF, "G84 [GeForce 8600 GTS](0x0400)"},
{0x10DE, 0x0400, 0x1043, 0x8241, "EN8600GTS(0x1043-0x8241)"},
{0x10DE, 0x0401, 0xFFFF, 0xFFFF, "G84 [GeForce 8600 GT](0x0401)"},
{0x10DE, 0x0402, 0xFFFF, 0xFFFF, "G84 [GeForce 8600 GT](0x0402)"},
{0x10DE, 0x0402, 0x1458, 0x3455, "GV-NX86T512H(0x1458-0x3455)"},
{0x10DE, 0x0402, 0x1462, 0x0910, "NX8600GT-T2D256EZ(0x1462-0x0910)"},
{0x10DE, 0x0403, 0xFFFF, 0xFFFF, "G84 [GeForce 8600 GS](0x0403)"},
{0x10DE, 0x0404, 0xFFFF, 0xFFFF, "G84 [GeForce 8400 GS](0x0404)"},
{0x10DE, 0x0404, 0x1462, 0x1230, "NX8400GS-TD256E(0x1462-0x1230)"},
{0x10DE, 0x0405, 0xFFFF, 0xFFFF, "G84M [GeForce 9500M GS](0x0405)"},
{0x10DE, 0x0406, 0xFFFF, 0xFFFF, "G84 [GeForce 8300 GS](0x0406)"},
{0x10DE, 0x0407, 0xFFFF, 0xFFFF, "G84M [GeForce 8600M GT](0x0407)"},
{0x10DE, 0x0408, 0xFFFF, 0xFFFF, "G84M [GeForce 9650M GS](0x0408)"},
{0x10DE, 0x0409, 0xFFFF, 0xFFFF, "G84M [GeForce 8700M GT](0x0409)"},
{0x10DE, 0x040A, 0xFFFF, 0xFFFF, "G84GL [Quadro FX 370](0x040A)"},
{0x10DE, 0x040B, 0xFFFF, 0xFFFF, "G84GLM [Quadro NVS 320M](0x040B)"},
{0x10DE, 0x040C, 0xFFFF, 0xFFFF, "G84GLM [Quadro FX 570M](0x040C)"},
{0x10DE, 0x040C, 0x17AA, 0x20D9, "ThinkPad T61p(0x17AA-0x20D9)"},
{0x10DE, 0x040D, 0xFFFF, 0xFFFF, "G84GLM [Quadro FX 1600M](0x040D)"},
{0x10DE, 0x040E, 0xFFFF, 0xFFFF, "G84GL [Quadro FX 570](0x040E)"},
{0x10DE, 0x040F, 0xFFFF, 0xFFFF, "G84GL [Quadro FX 1700](0x040F)"},
{0x10DE, 0x0410, 0xFFFF, 0xFFFF, "G92 [GeForce GT 330](0x0410)"},
{0x10DE, 0x0414, 0xFFFF, 0xFFFF, "G92 [GeForce 9800 GT](0x0414)"},
{0x10DE, 0x0418, 0xFFFF, 0xFFFF, "G92 [GeForce GT 330 OEM](0x0418)"},
{0x10DE, 0x0420, 0xFFFF, 0xFFFF, "G86 [GeForce 8400 SE](0x0420)"},
{0x10DE, 0x0421, 0xFFFF, 0xFFFF, "G86 [GeForce 8500 GT](0x0421)"},
{0x10DE, 0x0421, 0x1462, 0x0960, "NX8500GT-TD512EH/M2(0x1462-0x0960)"},
{0x10DE, 0x0422, 0xFFFF, 0xFFFF, "G86 [GeForce 8400 GS](0x0422)"},
{0x10DE, 0x0423, 0xFFFF, 0xFFFF, "G86 [GeForce 8300 GS](0x0423)"},
{0x10DE, 0x0424, 0xFFFF, 0xFFFF, "G86 [GeForce 8400 GS](0x0424)"},
{0x10DE, 0x0425, 0xFFFF, 0xFFFF, "G86M [GeForce 8600M GS](0x0425)"},
{0x10DE, 0x0425, 0x1025, 0x0121, "Aspire 5920G(0x1025-0x0121)"},
{0x10DE, 0x0425, 0x1043, 0x1514, "F3SV(0x1043-0x1514)"},
{0x10DE, 0x0426, 0xFFFF, 0xFFFF, "G86M [GeForce 8400M GT](0x0426)"},
{0x10DE, 0x0427, 0xFFFF, 0xFFFF, "G86M [GeForce 8400M GS](0x0427)"},
{0x10DE, 0x0427, 0x103C, 0x30CC, "Pavilion dv6700(0x103C-0x30CC)"},
{0x10DE, 0x0427, 0x103C, 0x30CF, "Pavilion dv9668eg Laptop(0x103C-0x30CF)"},
{0x10DE, 0x0428, 0xFFFF, 0xFFFF, "G86M [GeForce 8400M G](0x0428)"},
{0x10DE, 0x0429, 0xFFFF, 0xFFFF, "G86M [Quadro NVS 140M](0x0429)"},
{0x10DE, 0x0429, 0x17AA, 0x20D8, "ThinkPad T61(0x17AA-0x20D8)"},
{0x10DE, 0x042A, 0xFFFF, 0xFFFF, "G86M [Quadro NVS 130M](0x042A)"},
{0x10DE, 0x042B, 0xFFFF, 0xFFFF, "G86M [Quadro NVS 135M](0x042B)"},
{0x10DE, 0x042C, 0xFFFF, 0xFFFF, "G86 [GeForce 9400 GT](0x042C)"},
{0x10DE, 0x042D, 0xFFFF, 0xFFFF, "G86GLM [Quadro FX 360M](0x042D)"},
{0x10DE, 0x042E, 0xFFFF, 0xFFFF, "G86M [GeForce 9300M G](0x042E)"},
{0x10DE, 0x042F, 0xFFFF, 0xFFFF, "G86 [Quadro NVS 290](0x042F)"},
{0x10DE, 0x0440, 0xFFFF, 0xFFFF, "MCP65 LPC Bridge(0x0440)"},
{0x10DE, 0x0441, 0xFFFF, 0xFFFF, "MCP65 LPC Bridge(0x0441)"},
{0x10DE, 0x0442, 0xFFFF, 0xFFFF, "MCP65 LPC Bridge(0x0442)"},
{0x10DE, 0x0442, 0x103C, 0x30CF, "Pavilion dv9668eg Laptop(0x103C-0x30CF)"},
{0x10DE, 0x0443, 0xFFFF, 0xFFFF, "MCP65 LPC Bridge(0x0443)"},
{0x10DE, 0x0444, 0xFFFF, 0xFFFF, "MCP65 Memory Controller(0x0444)"},
{0x10DE, 0x0444, 0x103C, 0x30CF, "Pavilion dv9668eg Laptop(0x103C-0x30CF)"},
{0x10DE, 0x0445, 0xFFFF, 0xFFFF, "MCP65 Memory Controller(0x0445)"},
{0x10DE, 0x0446, 0xFFFF, 0xFFFF, "MCP65 SMBus(0x0446)"},
{0x10DE, 0x0446, 0x103C, 0x30CF, "Pavilion dv9668eg Laptop(0x103C-0x30CF)"},
{0x10DE, 0x0447, 0xFFFF, 0xFFFF, "MCP65 SMU(0x0447)"},
{0x10DE, 0x0447, 0x103C, 0x30CF, "Pavilion dv9500/9600/9700 series(0x103C-0x30CF)"},
{0x10DE, 0x0448, 0xFFFF, 0xFFFF, "MCP65 IDE(0x0448)"},
{0x10DE, 0x0448, 0x103C, 0x30CF, "Pavilion dv9668eg Laptop(0x103C-0x30CF)"},
{0x10DE, 0x0449, 0xFFFF, 0xFFFF, "MCP65 PCI bridge(0x0449)"},
{0x10DE, 0x0449, 0x10DE, 0xCB84, "HP Pavilion dv9668eg Laptop(0x10DE-0xCB84)"},
{0x10DE, 0x044A, 0xFFFF, 0xFFFF, "MCP65 High Definition Audio(0x044A)"},
{0x10DE, 0x044A, 0x103C, 0x30CF, "Pavilion dv9668eg Laptop(0x103C-0x30CF)"},
{0x10DE, 0x044B, 0xFFFF, 0xFFFF, "MCP65 High Definition Audio(0x044B)"},
{0x10DE, 0x044C, 0xFFFF, 0xFFFF, "MCP65 AHCI Controller(0x044C)"},
{0x10DE, 0x044D, 0xFFFF, 0xFFFF, "MCP65 AHCI Controller(0x044D)"},
{0x10DE, 0x044E, 0xFFFF, 0xFFFF, "MCP65 AHCI Controller(0x044E)"},
{0x10DE, 0x044F, 0xFFFF, 0xFFFF, "MCP65 AHCI Controller(0x044F)"},
{0x10DE, 0x0450, 0xFFFF, 0xFFFF, "MCP65 Ethernet(0x0450)"},
{0x10DE, 0x0450, 0x103C, 0x30CF, "Pavilion dv9668eg Laptop(0x103C-0x30CF)"},
{0x10DE, 0x0451, 0xFFFF, 0xFFFF, "MCP65 Ethernet(0x0451)"},
{0x10DE, 0x0452, 0xFFFF, 0xFFFF, "MCP65 Ethernet(0x0452)"},
{0x10DE, 0x0453, 0xFFFF, 0xFFFF, "MCP65 Ethernet(0x0453)"},
{0x10DE, 0x0454, 0xFFFF, 0xFFFF, "MCP65 USB 1.1 OHCI Controller(0x0454)"},
{0x10DE, 0x0454, 0x103C, 0x30CF, "Pavilion dv9668eg Laptop(0x103C-0x30CF)"},
{0x10DE, 0x0455, 0xFFFF, 0xFFFF, "MCP65 USB 2.0 EHCI Controller(0x0455)"},
{0x10DE, 0x0455, 0x103C, 0x30CF, "Pavilion dv9668eg Laptop(0x103C-0x30CF)"},
{0x10DE, 0x0456, 0xFFFF, 0xFFFF, "MCP65 USB Controller(0x0456)"},
{0x10DE, 0x0457, 0xFFFF, 0xFFFF, "MCP65 USB Controller(0x0457)"},
{0x10DE, 0x0458, 0xFFFF, 0xFFFF, "MCP65 PCI Express bridge(0x0458)"},
{0x10DE, 0x0458, 0x10DE, 0x0000, "MCP65 PCI Express bridge(0x10DE-0x0000)"},
{0x10DE, 0x0459, 0xFFFF, 0xFFFF, "MCP65 PCI Express bridge(0x0459)"},
{0x10DE, 0x0459, 0x10DE, 0x0000, "MCP65 PCI Express bridge(0x10DE-0x0000)"},
{0x10DE, 0x045A, 0xFFFF, 0xFFFF, "MCP65 PCI Express bridge(0x045A)"},
{0x10DE, 0x045A, 0x10DE, 0x0000, "MCP65 PCI Express bridge(0x10DE-0x0000)"},
{0x10DE, 0x045B, 0xFFFF, 0xFFFF, "MCP65 PCI Express bridge(0x045B)"},
{0x10DE, 0x045B, 0x10DE, 0x0000, "MCP65 PCI Express bridge(0x10DE-0x0000)"},
{0x10DE, 0x045C, 0xFFFF, 0xFFFF, "MCP65 SATA Controller(0x045C)"},
{0x10DE, 0x045D, 0xFFFF, 0xFFFF, "MCP65 SATA Controller(0x045D)"},
{0x10DE, 0x045D, 0x103C, 0x30CF, "Pavilion dv9668eg Laptop(0x103C-0x30CF)"},
{0x10DE, 0x045E, 0xFFFF, 0xFFFF, "MCP65 SATA Controller(0x045E)"},
{0x10DE, 0x045F, 0xFFFF, 0xFFFF, "MCP65 SATA Controller(0x045F)"},
{0x10DE, 0x0531, 0xFFFF, 0xFFFF, "C67 [GeForce 7150M / nForce 630M](0x0531)"},
{0x10DE, 0x0533, 0xFFFF, 0xFFFF, "C67 [GeForce 7000M / nForce 610M](0x0533)"},
{0x10DE, 0x053A, 0xFFFF, 0xFFFF, "C68 [GeForce 7050 PV / nForce 630a](0x053A)"},
{0x10DE, 0x053B, 0xFFFF, 0xFFFF, "C68 [GeForce 7050 PV / nForce 630a](0x053B)"},
{0x10DE, 0x053B, 0x1043, 0x8308, "M2N68-AM Motherboard(0x1043-0x8308)"},
{0x10DE, 0x053E, 0xFFFF, 0xFFFF, "C68 [GeForce 7025 / nForce 630a](0x053E)"},
{0x10DE, 0x0541, 0xFFFF, 0xFFFF, "MCP67 Memory Controller(0x0541)"},
{0x10DE, 0x0542, 0xFFFF, 0xFFFF, "MCP67 SMBus(0x0542)"},
{0x10DE, 0x0542, 0x1043, 0x8308, "M2N68-AM Motherboard(0x1043-0x8308)"},
{0x10DE, 0x0543, 0xFFFF, 0xFFFF, "MCP67 Co-processor(0x0543)"},
{0x10DE, 0x0547, 0xFFFF, 0xFFFF, "MCP67 Memory Controller(0x0547)"},
{0x10DE, 0x0547, 0x1043, 0x8308, "M2N68-AM Motherboard(0x1043-0x8308)"},
{0x10DE, 0x0547, 0x1849, 0x0547, "ALiveNF7G-HDready(0x1849-0x0547)"},
{0x10DE, 0x0548, 0xFFFF, 0xFFFF, "MCP67 ISA Bridge(0x0548)"},
{0x10DE, 0x0548, 0x1043, 0x8308, "M2N68-AM Motherboard(0x1043-0x8308)"},
{0x10DE, 0x054C, 0xFFFF, 0xFFFF, "MCP67 Ethernet(0x054C)"},
{0x10DE, 0x054C, 0x1043, 0x8308, "M2N68-AM Motherboard(0x1043-0x8308)"},
{0x10DE, 0x054C, 0x1849, 0x054C, "ALiveNF7G-HDready, MCP67 Gigabit Ethernet(0x1849-0x054C)"},
{0x10DE, 0x054D, 0xFFFF, 0xFFFF, "MCP67 Ethernet(0x054D)"},
{0x10DE, 0x054E, 0xFFFF, 0xFFFF, "MCP67 Ethernet(0x054E)"},
{0x10DE, 0x054F, 0xFFFF, 0xFFFF, "MCP67 Ethernet(0x054F)"},
{0x10DE, 0x0550, 0xFFFF, 0xFFFF, "MCP67 AHCI Controller(0x0550)"},
{0x10DE, 0x0550, 0x1043, 0x8308, "M2N68-AM Motherboard(0x1043-0x8308)"},
{0x10DE, 0x0554, 0xFFFF, 0xFFFF, "MCP67 AHCI Controller(0x0554)"},
{0x10DE, 0x0554, 0x1043, 0x8308, "M2N68-AM Motherboard(0x1043-0x8308)"},
{0x10DE, 0x0555, 0xFFFF, 0xFFFF, "MCP67 SATA Controller(0x0555)"},
{0x10DE, 0x0555, 0x1043, 0x8308, "M2N68-AM Motherboard(0x1043-0x8308)"},
{0x10DE, 0x055C, 0xFFFF, 0xFFFF, "MCP67 High Definition Audio(0x055C)"},
{0x10DE, 0x055C, 0x1043, 0x8290, "M2N68-AM Motherboard(0x1043-0x8290)"},
{0x10DE, 0x055D, 0xFFFF, 0xFFFF, "MCP67 High Definition Audio(0x055D)"},
{0x10DE, 0x055E, 0xFFFF, 0xFFFF, "MCP67 OHCI USB 1.1 Controller(0x055E)"},
{0x10DE, 0x055E, 0x1043, 0x8308, "M2N68-AM Motherboard(0x1043-0x8308)"},
{0x10DE, 0x055F, 0xFFFF, 0xFFFF, "MCP67 EHCI USB 2.0 Controller(0x055F)"},
{0x10DE, 0x055F, 0x1043, 0x8308, "M2N68-AM Motherboard(0x1043-0x8308)"},
{0x10DE, 0x0560, 0xFFFF, 0xFFFF, "MCP67 IDE Controller(0x0560)"},
{0x10DE, 0x0560, 0xF043, 0x8308, "M2N68-AM Motherboard(0xF043-0x8308)"},
{0x10DE, 0x0561, 0xFFFF, 0xFFFF, "MCP67 PCI Bridge(0x0561)"},
{0x10DE, 0x0562, 0xFFFF, 0xFFFF, "MCP67 PCI Express Bridge(0x0562)"},
{0x10DE, 0x0562, 0x1849, 0x0562, "ALiveNF7G-HDready(0x1849-0x0562)"},
{0x10DE, 0x0563, 0xFFFF, 0xFFFF, "MCP67 PCI Express Bridge(0x0563)"},
{0x10DE, 0x0568, 0xFFFF, 0xFFFF, "MCP78S [GeForce 8200] Memory Controller(0x0568)"},
{0x10DE, 0x0568, 0x103C, 0x2A9E, "Pavilion p6310f(0x103C-0x2A9E)"},
{0x10DE, 0x0568, 0x1043, 0x82E8, "M3N72-D(0x1043-0x82E8)"},
{0x10DE, 0x0568, 0x1462, 0x7508, "K9N2GM-FIH(0x1462-0x7508)"},
{0x10DE, 0x0568, 0x1849, 0x0568, "K10N78FullHD-hSLI R3.0 Memory Controller(0x1849-0x0568)"},
{0x10DE, 0x0569, 0xFFFF, 0xFFFF, "MCP78S [GeForce 8200] PCI Express Bridge(0x0569)"},
{0x10DE, 0x0569, 0x103C, 0x2A9E, "Pavilion p6310f(0x103C-0x2A9E)"},
{0x10DE, 0x0569, 0x1043, 0x82E8, "M3N72-D(0x1043-0x82E8)"},
{0x10DE, 0x0569, 0x1462, 0x7508, "K9N2GM-FIH(0x1462-0x7508)"},
{0x10DE, 0x0569, 0x1849, 0x0569, "K10N78FullHD-hSLI R3.0 PCI Express Bridge(0x1849-0x0569)"},
{0x10DE, 0x056A, 0xFFFF, 0xFFFF, "MCP73 [nForce 630i] USB 2.0 Controller (EHCI)(0x056A)"},
{0x10DE, 0x056A, 0x1019, 0x297A, "MCP73PVT-SM(0x1019-0x297A)"},
{0x10DE, 0x056A, 0x147B, 0x1C3E, "I-N73V motherboard(0x147B-0x1C3E)"},
{0x10DE, 0x056C, 0xFFFF, 0xFFFF, "MCP73 IDE Controller(0x056C)"},
{0x10DE, 0x056C, 0x1019, 0x297A, "MCP73PVT-SM(0x1019-0x297A)"},
{0x10DE, 0x056C, 0x147B, 0x1C3E, "I-N73V motherboard(0x147B-0x1C3E)"},
{0x10DE, 0x056C, 0x1AFA, 0x7150, "JW-IN7150-HD(0x1AFA-0x7150)"},
{0x10DE, 0x056D, 0xFFFF, 0xFFFF, "MCP73 PCI Express bridge(0x056D)"},
{0x10DE, 0x056D, 0x1019, 0x297A, "MCP73PVT-SM(0x1019-0x297A)"},
{0x10DE, 0x056D, 0x10DE, 0xCB73, "MCP73 PCI Bridge(0x10DE-0xCB73)"},
{0x10DE, 0x056E, 0xFFFF, 0xFFFF, "MCP73 PCI Express bridge(0x056E)"},
{0x10DE, 0x056E, 0x1019, 0x297A, "MCP73PVT-SM(0x1019-0x297A)"},
{0x10DE, 0x056E, 0x10DE, 0x0000, "MCP73 PCIe x16 port(0x10DE-0x0000)"},
{0x10DE, 0x056F, 0xFFFF, 0xFFFF, "MCP73 PCI Express bridge(0x056F)"},
{0x10DE, 0x056F, 0x1019, 0x297A, "MCP73PVT-SM(0x1019-0x297A)"},
{0x10DE, 0x056F, 0x10DE, 0x0000, "MCP73 PCIe x1 port(0x10DE-0x0000)"},
{0x10DE, 0x05B1, 0xFFFF, 0xFFFF, "NF200 PCIe 2.0 switch(0x05B1)"},
{0x10DE, 0x05B8, 0xFFFF, 0xFFFF, "NF200 PCIe 2.0 switch for GTX 295(0x05B8)"},
{0x10DE, 0x05BE, 0xFFFF, 0xFFFF, "NF200 PCIe 2.0 switch for Quadro Plex S4 / Tesla S870 / Tesla S1070 / Tesla S2050(0x05BE)"},
{0x10DE, 0x05E0, 0xFFFF, 0xFFFF, "GT200b [GeForce GTX 295](0x05E0)"},
{0x10DE, 0x05E1, 0xFFFF, 0xFFFF, "GT200 [GeForce GTX 280](0x05E1)"},
{0x10DE, 0x05E2, 0xFFFF, 0xFFFF, "GT200 [GeForce GTX 260](0x05E2)"},
{0x10DE, 0x05E3, 0xFFFF, 0xFFFF, "GT200b [GeForce GTX 285](0x05E3)"},
{0x10DE, 0x05E3, 0x1682, 0x2490, "GX-285N-ZDF(0x1682-0x2490)"},
{0x10DE, 0x05E6, 0xFFFF, 0xFFFF, "GT200b [GeForce GTX 275](0x05E6)"},
{0x10DE, 0x05E7, 0xFFFF, 0xFFFF, "GT200GL [Tesla C1060 / M1060](0x05E7)"},
{0x10DE, 0x05E7, 0x10DE, 0x0595, "Tesla T10 Processor(0x10DE-0x0595)"},
{0x10DE, 0x05E7, 0x10DE, 0x068F, "Tesla T10 Processor(0x10DE-0x068F)"},
{0x10DE, 0x05E7, 0x10DE, 0x0697, "Tesla M1060(0x10DE-0x0697)"},
{0x10DE, 0x05E7, 0x10DE, 0x0714, "Tesla M1060(0x10DE-0x0714)"},
{0x10DE, 0x05E7, 0x10DE, 0x0743, "Tesla M1060(0x10DE-0x0743)"},
{0x10DE, 0x05EA, 0xFFFF, 0xFFFF, "GT200 [GeForce GTX 260](0x05EA)"},
{0x10DE, 0x05EB, 0xFFFF, 0xFFFF, "GT200 [GeForce GTX 295](0x05EB)"},
{0x10DE, 0x05ED, 0xFFFF, 0xFFFF, "GT200GL [Quadro Plex 2200 D2](0x05ED)"},
{0x10DE, 0x05F1, 0xFFFF, 0xFFFF, "GT200 [GeForce GTX 280](0x05F1)"},
{0x10DE, 0x05F2, 0xFFFF, 0xFFFF, "GT200 [GeForce GTX 260](0x05F2)"},
{0x10DE, 0x05F8, 0xFFFF, 0xFFFF, "GT200GL [Quadro Plex 2200 S4](0x05F8)"},
{0x10DE, 0x05F9, 0xFFFF, 0xFFFF, "GT200GL [Quadro CX](0x05F9)"},
{0x10DE, 0x05FD, 0xFFFF, 0xFFFF, "GT200GL [Quadro FX 5800](0x05FD)"},
{0x10DE, 0x05FE, 0xFFFF, 0xFFFF, "GT200GL [Quadro FX 4800](0x05FE)"},
{0x10DE, 0x05FF, 0xFFFF, 0xFFFF, "GT200GL [Quadro FX 3800](0x05FF)"},
{0x10DE, 0x0600, 0xFFFF, 0xFFFF, "G92 [GeForce 8800 GTS 512](0x0600)"},
{0x10DE, 0x0601, 0xFFFF, 0xFFFF, "G92 [GeForce 9800 GT](0x0601)"},
{0x10DE, 0x0602, 0xFFFF, 0xFFFF, "G92 [GeForce 8800 GT](0x0602)"},
{0x10DE, 0x0603, 0xFFFF, 0xFFFF, "G92 [GeForce GT 230 OEM](0x0603)"},
{0x10DE, 0x0604, 0xFFFF, 0xFFFF, "G92 [GeForce 9800 GX2](0x0604)"},
{0x10DE, 0x0605, 0xFFFF, 0xFFFF, "G92 [GeForce 9800 GT](0x0605)"},
{0x10DE, 0x0606, 0xFFFF, 0xFFFF, "G92 [GeForce 8800 GS](0x0606)"},
{0x10DE, 0x0607, 0xFFFF, 0xFFFF, "G92 [GeForce GTS 240](0x0607)"},
{0x10DE, 0x0608, 0xFFFF, 0xFFFF, "G92M [GeForce 9800M GTX](0x0608)"},
{0x10DE, 0x0609, 0xFFFF, 0xFFFF, "G92M [GeForce 8800M GTS](0x0609)"},
{0x10DE, 0x0609, 0x106B, 0x00A7, "GeForce 8800 GS(0x106B-0x00A7)"},
{0x10DE, 0x060A, 0xFFFF, 0xFFFF, "G92M [GeForce GTX 280M](0x060A)"},
{0x10DE, 0x060B, 0xFFFF, 0xFFFF, "G92M [GeForce 9800M GT](0x060B)"},
{0x10DE, 0x060C, 0xFFFF, 0xFFFF, "G92M [GeForce 8800M GTX](0x060C)"},
{0x10DE, 0x060D, 0xFFFF, 0xFFFF, "G92 [GeForce 8800 GS](0x060D)"},
{0x10DE, 0x060F, 0xFFFF, 0xFFFF, "G92M [GeForce GTX 285M](0x060F)"},
{0x10DE, 0x0610, 0xFFFF, 0xFFFF, "G92 [GeForce 9600 GSO](0x0610)"},
{0x10DE, 0x0610, 0x1682, 0x2385, "GeForce 9600 GSO 768mb(0x1682-0x2385)"},
{0x10DE, 0x0611, 0xFFFF, 0xFFFF, "G92 [GeForce 8800 GT](0x0611)"},
{0x10DE, 0x0611, 0x107D, 0x2AB0, "Winfast PX8800 GT PCI-E(0x107D-0x2AB0)"},
{0x10DE, 0x0611, 0x1462, 0x1170, "NX8800GT series model V117 2xDVI+TV(0x1462-0x1170)"},
{0x10DE, 0x0611, 0x19DA, 0x1040, "ZT-88TES2P-FSP(0x19DA-0x1040)"},
{0x10DE, 0x0612, 0xFFFF, 0xFFFF, "G92 [GeForce 9800 GTX / 9800 GTX+](0x0612)"},
{0x10DE, 0x0613, 0xFFFF, 0xFFFF, "G92 [GeForce 9800 GTX+](0x0613)"},
{0x10DE, 0x0614, 0xFFFF, 0xFFFF, "G92 [GeForce 9800 GT](0x0614)"},
{0x10DE, 0x0614, 0x107D, 0x2AB3, "WinFast PX9800 GT (S-Fanpipe)(0x107D-0x2AB3)"},
{0x10DE, 0x0615, 0xFFFF, 0xFFFF, "G92 [GeForce GTS 250](0x0615)"},
{0x10DE, 0x0615, 0x3842, 0x1150, "GeForce GTS 250 P/N 512-P3-1150-TR(0x3842-0x1150)"},
{0x10DE, 0x0615, 0x3842, 0x1151, "GeForce GTS 250 P/N 512-P3-1151-TR(0x3842-0x1151)"},
{0x10DE, 0x0615, 0x3842, 0x1155, "GeForce GTS 250 P/N 01G-P3-1155-TR(0x3842-0x1155)"},
{0x10DE, 0x0615, 0x3842, 0x1156, "GeForce GTS 250 P/N 01G-P3-1156-TR(0x3842-0x1156)"},
{0x10DE, 0x0617, 0xFFFF, 0xFFFF, "G92M [GeForce 9800M GTX](0x0617)"},
{0x10DE, 0x0618, 0xFFFF, 0xFFFF, "G92M [GeForce GTX 260M](0x0618)"},
{0x10DE, 0x0619, 0xFFFF, 0xFFFF, "G92GL [Quadro FX 4700 X2](0x0619)"},
{0x10DE, 0x061A, 0xFFFF, 0xFFFF, "G92GL [Quadro FX 3700](0x061A)"},
{0x10DE, 0x061B, 0xFFFF, 0xFFFF, "G92GL [Quadro VX 200](0x061B)"},
{0x10DE, 0x061C, 0xFFFF, 0xFFFF, "G92GLM [Quadro FX 3600M](0x061C)"},
{0x10DE, 0x061D, 0xFFFF, 0xFFFF, "G92GLM [Quadro FX 2800M](0x061D)"},
{0x10DE, 0x061E, 0xFFFF, 0xFFFF, "G92GLM [Quadro FX 3700M](0x061E)"},
{0x10DE, 0x061F, 0xFFFF, 0xFFFF, "G92GLM [Quadro FX 3800M](0x061F)"},
{0x10DE, 0x0620, 0xFFFF, 0xFFFF, "G94 [GeForce 9800 GT](0x0620)"},
{0x10DE, 0x0621, 0xFFFF, 0xFFFF, "G94 [GeForce GT 230](0x0621)"},
{0x10DE, 0x0622, 0xFFFF, 0xFFFF, "G94 [GeForce 9600 GT](0x0622)"},
{0x10DE, 0x0622, 0x107D, 0x2AC1, "WinFast PX9600GT 1024MB(0x107D-0x2AC1)"},
{0x10DE, 0x0622, 0x1458, 0x3481, "GV-NX96T512HP(0x1458-0x3481)"},
{0x10DE, 0x0623, 0xFFFF, 0xFFFF, "G94 [GeForce 9600 GS](0x0623)"},
{0x10DE, 0x0624, 0xFFFF, 0xFFFF, "G94 [GeForce 9600 GT Green Edition](0x0624)"},
{0x10DE, 0x0625, 0xFFFF, 0xFFFF, "G94 [GeForce 9600 GSO 512](0x0625)"},
{0x10DE, 0x0626, 0xFFFF, 0xFFFF, "G94 [GeForce GT 130](0x0626)"},
{0x10DE, 0x0627, 0xFFFF, 0xFFFF, "G94 [GeForce GT 140](0x0627)"},
{0x10DE, 0x0628, 0xFFFF, 0xFFFF, "G94M [GeForce 9800M GTS](0x0628)"},
{0x10DE, 0x062A, 0xFFFF, 0xFFFF, "G94M [GeForce 9700M GTS](0x062A)"},
{0x10DE, 0x062B, 0xFFFF, 0xFFFF, "G94M [GeForce 9800M GS](0x062B)"},
{0x10DE, 0x062C, 0xFFFF, 0xFFFF, "G94M [GeForce 9800M GTS](0x062C)"},
{0x10DE, 0x062D, 0xFFFF, 0xFFFF, "G94 [GeForce 9600 GT](0x062D)"},
{0x10DE, 0x062E, 0xFFFF, 0xFFFF, "G94 [GeForce 9600 GT](0x062E)"},
{0x10DE, 0x062E, 0x106B, 0x0605, "GeForce GT 130(0x106B-0x0605)"},
{0x10DE, 0x062F, 0xFFFF, 0xFFFF, "G94 [GeForce 9800 S](0x062F)"},
{0x10DE, 0x0630, 0xFFFF, 0xFFFF, "G94 [GeForce 9600 GT](0x0630)"},
{0x10DE, 0x0631, 0xFFFF, 0xFFFF, "G94M [GeForce GTS 160M](0x0631)"},
{0x10DE, 0x0632, 0xFFFF, 0xFFFF, "G94M [GeForce GTS 150M](0x0632)"},
{0x10DE, 0x0633, 0xFFFF, 0xFFFF, "G94 [GeForce GT 220](0x0633)"},
{0x10DE, 0x0635, 0xFFFF, 0xFFFF, "G94 [GeForce 9600 GSO](0x0635)"},
{0x10DE, 0x0637, 0xFFFF, 0xFFFF, "G94 [GeForce 9600 GT](0x0637)"},
{0x10DE, 0x0638, 0xFFFF, 0xFFFF, "G94GL [Quadro FX 1800](0x0638)"},
{0x10DE, 0x063A, 0xFFFF, 0xFFFF, "G94GLM [Quadro FX 2700M](0x063A)"},
{0x10DE, 0x063F, 0xFFFF, 0xFFFF, "G94 [GeForce 9600 GE](0x063F)"},
{0x10DE, 0x0640, 0xFFFF, 0xFFFF, "G96C [GeForce 9500 GT](0x0640)"},
{0x10DE, 0x0641, 0xFFFF, 0xFFFF, "G96C [GeForce 9400 GT](0x0641)"},
{0x10DE, 0x0641, 0x1682, 0x4009, "PV-T94G-ZAFG(0x1682-0x4009)"},
{0x10DE, 0x0642, 0xFFFF, 0xFFFF, "G96 [D9M-10](0x0642)"},
{0x10DE, 0x0643, 0xFFFF, 0xFFFF, "G96 [GeForce 9500 GT](0x0643)"},
{0x10DE, 0x0644, 0xFFFF, 0xFFFF, "G96 [GeForce 9500 GS](0x0644)"},
{0x10DE, 0x0644, 0x174B, 0x9600, "Geforce 9500GS 512M DDR2 V/D/HDMI(0x174B-0x9600)"},
{0x10DE, 0x0645, 0xFFFF, 0xFFFF, "G96C [GeForce 9500 GS](0x0645)"},
{0x10DE, 0x0646, 0xFFFF, 0xFFFF, "G96C [GeForce GT 120](0x0646)"},
{0x10DE, 0x0647, 0xFFFF, 0xFFFF, "G96CM [GeForce 9600M GT](0x0647)"},
{0x10DE, 0x0648, 0xFFFF, 0xFFFF, "G96CM [GeForce 9600M GS](0x0648)"},
{0x10DE, 0x0649, 0xFFFF, 0xFFFF, "G96CM [GeForce 9600M GT](0x0649)"},
{0x10DE, 0x0649, 0x1043, 0x202D, "GeForce GT 220M(0x1043-0x202D)"},
{0x10DE, 0x064A, 0xFFFF, 0xFFFF, "G96M [GeForce 9700M GT](0x064A)"},
{0x10DE, 0x064B, 0xFFFF, 0xFFFF, "G96M [GeForce 9500M G](0x064B)"},
{0x10DE, 0x064C, 0xFFFF, 0xFFFF, "G96CM [GeForce 9650M GT](0x064C)"},
{0x10DE, 0x064E, 0xFFFF, 0xFFFF, "G96C [GeForce 9600 GSO / 9800 GT](0x064E)"},
{0x10DE, 0x0651, 0xFFFF, 0xFFFF, "G96CM [GeForce G 110M](0x0651)"},
{0x10DE, 0x0652, 0xFFFF, 0xFFFF, "G96CM [GeForce GT 130M](0x0652)"},
{0x10DE, 0x0652, 0x152D, 0x0850, "GeForce GT 240M LE(0x152D-0x0850)"},
{0x10DE, 0x0653, 0xFFFF, 0xFFFF, "G96CM [GeForce GT 120M](0x0653)"},
{0x10DE, 0x0654, 0xFFFF, 0xFFFF, "G96CM [GeForce GT 220M](0x0654)"},
{0x10DE, 0x0654, 0x1043, 0x14A2, "GeForce GT 320M(0x1043-0x14A2)"},
{0x10DE, 0x0654, 0x1043, 0x14D2, "GeForce GT 320M(0x1043-0x14D2)"},
{0x10DE, 0x0655, 0xFFFF, 0xFFFF, "G96 [GeForce GT 120 Mac Edition](0x0655)"},
{0x10DE, 0x0656, 0xFFFF, 0xFFFF, "G96 [GeForce GT 120 Mac Edition](0x0656)"},
{0x10DE, 0x0658, 0xFFFF, 0xFFFF, "G96GL [Quadro FX 380](0x0658)"},
{0x10DE, 0x0659, 0xFFFF, 0xFFFF, "G96CGL [Quadro FX 580](0x0659)"},
{0x10DE, 0x065A, 0xFFFF, 0xFFFF, "G96GLM [Quadro FX 1700M](0x065A)"},
{0x10DE, 0x065B, 0xFFFF, 0xFFFF, "G96C [GeForce 9400 GT](0x065B)"},
{0x10DE, 0x065C, 0xFFFF, 0xFFFF, "G96GLM [Quadro FX 770M](0x065C)"},
{0x10DE, 0x065D, 0xFFFF, 0xFFFF, "G96 [GeForce 9500 GA / 9600 GT / GTS 250](0x065D)"},
{0x10DE, 0x065F, 0xFFFF, 0xFFFF, "G96C [GeForce G210](0x065F)"},
{0x10DE, 0x06C0, 0xFFFF, 0xFFFF, "GF100 [GeForce GTX 480](0x06C0)"},
{0x10DE, 0x06C4, 0xFFFF, 0xFFFF, "GF100 [GeForce GTX 465](0x06C4)"},
{0x10DE, 0x06CA, 0xFFFF, 0xFFFF, "GF100M [GeForce GTX 480M](0x06CA)"},
{0x10DE, 0x06CB, 0xFFFF, 0xFFFF, "GF100 [GeForce GTX 480](0x06CB)"},
{0x10DE, 0x06CD, 0xFFFF, 0xFFFF, "GF100 [GeForce GTX 470](0x06CD)"},
{0x10DE, 0x06D0, 0xFFFF, 0xFFFF, "GF100GL(0x06D0)"},
{0x10DE, 0x06D1, 0xFFFF, 0xFFFF, "GF100GL [Tesla C2050 / C2070](0x06D1)"},
{0x10DE, 0x06D1, 0x10DE, 0x0771, "Tesla C2050(0x10DE-0x0771)"},
{0x10DE, 0x06D1, 0x10DE, 0x0772, "Tesla C2070(0x10DE-0x0772)"},
{0x10DE, 0x06D2, 0xFFFF, 0xFFFF, "GF100GL [Tesla M2070](0x06D2)"},
{0x10DE, 0x06D2, 0x10DE, 0x0774, "Tesla M2070(0x10DE-0x0774)"},
{0x10DE, 0x06D2, 0x10DE, 0x0830, "Tesla M2070(0x10DE-0x0830)"},
{0x10DE, 0x06D2, 0x10DE, 0x0842, "Tesla M2070(0x10DE-0x0842)"},
{0x10DE, 0x06D2, 0x10DE, 0x088F, "Tesla X2070(0x10DE-0x088F)"},
{0x10DE, 0x06D2, 0x10DE, 0x0908, "Tesla M2070(0x10DE-0x0908)"},
{0x10DE, 0x06D8, 0xFFFF, 0xFFFF, "GF100GL [Quadro 6000](0x06D8)"},
{0x10DE, 0x06D9, 0xFFFF, 0xFFFF, "GF100GL [Quadro 5000](0x06D9)"},
{0x10DE, 0x06DA, 0xFFFF, 0xFFFF, "GF100GLM [Quadro 5000M](0x06DA)"},
{0x10DE, 0x06DC, 0xFFFF, 0xFFFF, "GF100GL [Quadro 6000](0x06DC)"},
{0x10DE, 0x06DD, 0xFFFF, 0xFFFF, "GF100GL [Quadro 4000](0x06DD)"},
{0x10DE, 0x06DE, 0xFFFF, 0xFFFF, "GF100GL [Tesla T20 Processor](0x06DE)"},
{0x10DE, 0x06DE, 0x10DE, 0x0773, "Tesla S2050(0x10DE-0x0773)"},
{0x10DE, 0x06DE, 0x10DE, 0x082F, "Tesla M2050(0x10DE-0x082F)"},
{0x10DE, 0x06DE, 0x10DE, 0x0840, "Tesla X2070(0x10DE-0x0840)"},
{0x10DE, 0x06DE, 0x10DE, 0x0842, "Tesla M2050(0x10DE-0x0842)"},
{0x10DE, 0x06DE, 0x10DE, 0x0846, "Tesla M2050(0x10DE-0x0846)"},
{0x10DE, 0x06DE, 0x10DE, 0x0866, "Tesla M2050(0x10DE-0x0866)"},
{0x10DE, 0x06DE, 0x10DE, 0x0907, "Tesla M2050(0x10DE-0x0907)"},
{0x10DE, 0x06DE, 0x10DE, 0x091E, "Tesla M2050(0x10DE-0x091E)"},
{0x10DE, 0x06DF, 0xFFFF, 0xFFFF, "GF100GL [Tesla M2070-Q](0x06DF)"},
{0x10DE, 0x06DF, 0x10DE, 0x084D, "Tesla M2070-Q(0x10DE-0x084D)"},
{0x10DE, 0x06DF, 0x10DE, 0x087F, "Tesla M2070-Q(0x10DE-0x087F)"},
{0x10DE, 0x06E0, 0xFFFF, 0xFFFF, "G98 [GeForce 9300 GE](0x06E0)"},
{0x10DE, 0x06E0, 0x107D, 0x5A96, "Geforce 9300GE(0x107D-0x5A96)"},
{0x10DE, 0x06E1, 0xFFFF, 0xFFFF, "G98 [GeForce 9300 GS](0x06E1)"},
{0x10DE, 0x06E2, 0xFFFF, 0xFFFF, "G98 [GeForce 8400](0x06E2)"},
{0x10DE, 0x06E3, 0xFFFF, 0xFFFF, "G98 [GeForce 8300 GS](0x06E3)"},
{0x10DE, 0x06E4, 0xFFFF, 0xFFFF, "G98 [GeForce 8400 GS Rev. 2](0x06E4)"},
{0x10DE, 0x06E4, 0x1458, 0x3475, "GV-NX84S256HE [GeForce 8400 GS](0x1458-0x3475)"},
{0x10DE, 0x06E5, 0xFFFF, 0xFFFF, "G98M [GeForce 9300M GS](0x06E5)"},
{0x10DE, 0x06E6, 0xFFFF, 0xFFFF, "G98 [GeForce G 100](0x06E6)"},
{0x10DE, 0x06E7, 0xFFFF, 0xFFFF, "G98 [GeForce 9300 SE](0x06E7)"},
{0x10DE, 0x06E8, 0xFFFF, 0xFFFF, "G98M [GeForce 9200M GS](0x06E8)"},
{0x10DE, 0x06E8, 0x103C, 0x360B, "GeForce 9200M GE(0x103C-0x360B)"},
{0x10DE, 0x06E9, 0xFFFF, 0xFFFF, "G98M [GeForce 9300M GS](0x06E9)"},
{0x10DE, 0x06E9, 0x1043, 0x19B2, "U6V laptop(0x1043-0x19B2)"},
{0x10DE, 0x06EA, 0xFFFF, 0xFFFF, "G98M [Quadro NVS 150M](0x06EA)"},
{0x10DE, 0x06EB, 0xFFFF, 0xFFFF, "G98M [Quadro NVS 160M](0x06EB)"},
{0x10DE, 0x06EC, 0xFFFF, 0xFFFF, "G98M [GeForce G 105M](0x06EC)"},
{0x10DE, 0x06ED, 0xFFFF, 0xFFFF, "G98 [GeForce 9600 GT / 9800 GT](0x06ED)"},
{0x10DE, 0x06EE, 0xFFFF, 0xFFFF, "G98 [GeForce 9600 GT / 9800 GT / GT 240](0x06EE)"},
{0x10DE, 0x06EF, 0xFFFF, 0xFFFF, "G98M [GeForce G 103M](0x06EF)"},
{0x10DE, 0x06F1, 0xFFFF, 0xFFFF, "G98M [GeForce G 105M](0x06F1)"},
{0x10DE, 0x06F8, 0xFFFF, 0xFFFF, "G98 [Quadro NVS 420](0x06F8)"},
{0x10DE, 0x06F9, 0xFFFF, 0xFFFF, "G98GL [Quadro FX 370 LP](0x06F9)"},
{0x10DE, 0x06FA, 0xFFFF, 0xFFFF, "G98 [Quadro NVS 450](0x06FA)"},
{0x10DE, 0x06FB, 0xFFFF, 0xFFFF, "G98GLM [Quadro FX 370M](0x06FB)"},
{0x10DE, 0x06FD, 0xFFFF, 0xFFFF, "G98 [Quadro NVS 295](0x06FD)"},
{0x10DE, 0x06FF, 0xFFFF, 0xFFFF, "G98 [HICx16 + Graphics](0x06FF)"},
{0x10DE, 0x06FF, 0x10DE, 0x0711, "HICx8 + Graphics(0x10DE-0x0711)"},
{0x10DE, 0x0751, 0xFFFF, 0xFFFF, "MCP78S [GeForce 8200] Memory Controller(0x0751)"},
{0x10DE, 0x0751, 0x103C, 0x2A9E, "Pavilion p6310f(0x103C-0x2A9E)"},
{0x10DE, 0x0751, 0x1043, 0x82E8, "M3N72-D(0x1043-0x82E8)"},
{0x10DE, 0x0751, 0x1462, 0x7508, "K9N2GM-FIH(0x1462-0x7508)"},
{0x10DE, 0x0751, 0x1849, 0x0751, "K10N78FullHD-hSLI R3.0 Memory Controller(0x1849-0x0751)"},
{0x10DE, 0x0752, 0xFFFF, 0xFFFF, "MCP78S [GeForce 8200] SMBus(0x0752)"},
{0x10DE, 0x0752, 0x103C, 0x2A9E, "Pavilion p6310f(0x103C-0x2A9E)"},
{0x10DE, 0x0752, 0x1043, 0x82E8, "M3N72-D(0x1043-0x82E8)"},
{0x10DE, 0x0752, 0x1462, 0x7508, "K9N2GM-FIH(0x1462-0x7508)"},
{0x10DE, 0x0752, 0x1849, 0x0752, "K10N78FullHD-hSLI R3.0 SMBus(0x1849-0x0752)"},
{0x10DE, 0x0753, 0xFFFF, 0xFFFF, "MCP78S [GeForce 8200] Co-Processor(0x0753)"},
{0x10DE, 0x0753, 0x103C, 0x2A9E, "Pavilion p6310f(0x103C-0x2A9E)"},
{0x10DE, 0x0753, 0x1043, 0x82E8, "M3N72-D(0x1043-0x82E8)"},
{0x10DE, 0x0753, 0x1462, 0x7508, "K9N2GM-FIH(0x1462-0x7508)"},
{0x10DE, 0x0753, 0x1849, 0x0753, "K10N78FullHD-hSLI R3.0 Co-Processor(0x1849-0x0753)"},
{0x10DE, 0x0754, 0xFFFF, 0xFFFF, "MCP78S [GeForce 8200] Memory Controller(0x0754)"},
{0x10DE, 0x0754, 0x103C, 0x2A9E, "Pavilion p6310f(0x103C-0x2A9E)"},
{0x10DE, 0x0754, 0x1043, 0x82E8, "M3N72-D(0x1043-0x82E8)"},
{0x10DE, 0x0754, 0x1462, 0x7508, "K9N2GM-FIH(0x1462-0x7508)"},
{0x10DE, 0x0754, 0x1849, 0x0754, "K10N78FullHD-hSLI R3.0 Memory Controller(0x1849-0x0754)"},
{0x10DE, 0x0759, 0xFFFF, 0xFFFF, "MCP78S [GeForce 8200] IDE(0x0759)"},
{0x10DE, 0x0759, 0x1043, 0x82E8, "M3N72-D(0x1043-0x82E8)"},
{0x10DE, 0x0759, 0x1462, 0x7508, "K9N2GM-FIH(0x1462-0x7508)"},
{0x10DE, 0x0759, 0x1849, 0x0759, "K10N78FullHD-hSLI R3.0 IDE(0x1849-0x0759)"},
{0x10DE, 0x075A, 0xFFFF, 0xFFFF, "MCP78S [GeForce 8200] PCI Bridge(0x075A)"},
{0x10DE, 0x075A, 0x103C, 0x2A9E, "Pavilion p6310f(0x103C-0x2A9E)"},
{0x10DE, 0x075A, 0x1043, 0x82E8, "M3N72-D(0x1043-0x82E8)"},
{0x10DE, 0x075A, 0x1849, 0x075A, "K10N78FullHD-hSLI R3.0 PCI Bridge(0x1849-0x075A)"},
{0x10DE, 0x075B, 0xFFFF, 0xFFFF, "MCP78S [GeForce 8200] PCI Express Bridge(0x075B)"},
{0x10DE, 0x075B, 0x103C, 0x2A9E, "Pavilion p6310f(0x103C-0x2A9E)"},
{0x10DE, 0x075B, 0x1043, 0x82E8, "M3N72-D(0x1043-0x82E8)"},
{0x10DE, 0x075B, 0x1462, 0x7508, "K9N2GM-FIH(0x1462-0x7508)"},
{0x10DE, 0x075B, 0x1849, 0x075B, "K10N78FullHD-hSLI R3.0 PCI Express Bridge(0x1849-0x075B)"},
{0x10DE, 0x075C, 0xFFFF, 0xFFFF, "MCP78S [GeForce 8200] LPC Bridge(0x075C)"},
{0x10DE, 0x075C, 0x103C, 0x2A9E, "Pavilion p6310f(0x103C-0x2A9E)"},
{0x10DE, 0x075C, 0x1462, 0x7508, "K9N2GM-FIH(0x1462-0x7508)"},
{0x10DE, 0x075C, 0x1849, 0x075C, "K10N78FullHD-hSLI R3.0 LPC Bridge(0x1849-0x075C)"},
{0x10DE, 0x075D, 0xFFFF, 0xFFFF, "MCP78S [GeForce 8200] LPC Bridge(0x075D)"},
{0x10DE, 0x075D, 0x1043, 0x82E8, "M3N72-D(0x1043-0x82E8)"},
{0x10DE, 0x0760, 0xFFFF, 0xFFFF, "MCP77 Ethernet(0x0760)"},
{0x10DE, 0x0760, 0x103C, 0x2A9E, "Pavilion p6310f(0x103C-0x2A9E)"},
{0x10DE, 0x0760, 0x1043, 0x82E8, "M3N72-D(0x1043-0x82E8)"},
{0x10DE, 0x0760, 0x1462, 0x7508, "K9N2GM-FIH(0x1462-0x7508)"},
{0x10DE, 0x0760, 0x1849, 0x0760, "K10N78FullHD-hSLI R3.0 Ethernet(0x1849-0x0760)"},
{0x10DE, 0x0761, 0xFFFF, 0xFFFF, "MCP77 Ethernet(0x0761)"},
{0x10DE, 0x0762, 0xFFFF, 0xFFFF, "MCP77 Ethernet(0x0762)"},
{0x10DE, 0x0763, 0xFFFF, 0xFFFF, "MCP77 Ethernet(0x0763)"},
{0x10DE, 0x0774, 0xFFFF, 0xFFFF, "MCP72XE/MCP72P/MCP78U/MCP78S High Definition Audio(0x0774)"},
{0x10DE, 0x0774, 0x103C, 0x2A9E, "Pavilion p6310f(0x103C-0x2A9E)"},
{0x10DE, 0x0774, 0x1043, 0x82FE, "M3N72-D(0x1043-0x82FE)"},
{0x10DE, 0x0774, 0x1462, 0x7508, "K9N2GM-FIH(0x1462-0x7508)"},
{0x10DE, 0x0774, 0x1849, 0x3662, "K10N78FullHD-hSLI R3.0 High Definition Audio(0x1849-0x3662)"},
{0x10DE, 0x0778, 0xFFFF, 0xFFFF, "MCP78S [GeForce 8200] PCI Express Bridge(0x0778)"},
{0x10DE, 0x0778, 0x103C, 0x2A9E, "Pavilion p6310f(0x103C-0x2A9E)"},
{0x10DE, 0x0778, 0x1043, 0x82E8, "M3N72-D(0x1043-0x82E8)"},
{0x10DE, 0x0778, 0x1462, 0x7508, "K9N2GM-FIH(0x1462-0x7508)"},
{0x10DE, 0x0778, 0x1849, 0x0778, "K10N78FullHD-hSLI R3.0 PCI Express Bridge(0x1849-0x0778)"},
{0x10DE, 0x077A, 0xFFFF, 0xFFFF, "MCP78S [GeForce 8200] PCI Bridge(0x077A)"},
{0x10DE, 0x077A, 0x103C, 0x2A9E, "Pavilion p6310f(0x103C-0x2A9E)"},
{0x10DE, 0x077A, 0x1043, 0x82E8, "M3N72-D(0x1043-0x82E8)"},
{0x10DE, 0x077A, 0x1462, 0x7508, "K9N2GM-FIH(0x1462-0x7508)"},
{0x10DE, 0x077A, 0x1849, 0x077A, "K10N78FullHD-hSLI R3.0 PCI Bridge(0x1849-0x077A)"},
{0x10DE, 0x077B, 0xFFFF, 0xFFFF, "MCP78S [GeForce 8200] OHCI USB 1.1 Controller(0x077B)"},
{0x10DE, 0x077B, 0x103C, 0x2A9E, "Pavilion p6310f(0x103C-0x2A9E)"},
{0x10DE, 0x077B, 0x1043, 0x82E8, "M3N72-D(0x1043-0x82E8)"},
{0x10DE, 0x077B, 0x1462, 0x7508, "K9N2GM-FIH(0x1462-0x7508)"},
{0x10DE, 0x077B, 0x1849, 0x077B, "K10N78FullHD-hSLI R3.0 OHCI USB 1.1 Controller(0x1849-0x077B)"},
{0x10DE, 0x077C, 0xFFFF, 0xFFFF, "MCP78S [GeForce 8200] EHCI USB 2.0 Controller(0x077C)"},
{0x10DE, 0x077C, 0x103C, 0x2A9E, "Pavilion p6310f(0x103C-0x2A9E)"},
{0x10DE, 0x077C, 0x1043, 0x82E8, "M3N72-D(0x1043-0x82E8)"},
{0x10DE, 0x077C, 0x1462, 0x7508, "K9N2GM-FIH(0x1462-0x7508)"},
{0x10DE, 0x077C, 0x1849, 0x077C, "K10N78FullHD-hSLI R3.0 EHCI USB 2.0 Controller(0x1849-0x077C)"},
{0x10DE, 0x077D, 0xFFFF, 0xFFFF, "MCP78S [GeForce 8200] OHCI USB 1.1 Controller(0x077D)"},
{0x10DE, 0x077D, 0x103C, 0x2A9E, "Pavilion p6310f(0x103C-0x2A9E)"},
{0x10DE, 0x077D, 0x1043, 0x82E8, "M3N72-D(0x1043-0x82E8)"},
{0x10DE, 0x077D, 0x1462, 0x7508, "K9N2GM-FIH(0x1462-0x7508)"},
{0x10DE, 0x077D, 0x1849, 0x077D, "K10N78FullHD-hSLI R3.0 OHCI USB 1.1 Controller(0x1849-0x077D)"},
{0x10DE, 0x077E, 0xFFFF, 0xFFFF, "MCP78S [GeForce 8200] EHCI USB 2.0 Controller(0x077E)"},
{0x10DE, 0x077E, 0x103C, 0x2A9E, "Pavilion p6310f(0x103C-0x2A9E)"},
{0x10DE, 0x077E, 0x1043, 0x82E8, "M3N72-D(0x1043-0x82E8)"},
{0x10DE, 0x077E, 0x1462, 0x7508, "K9N2GM-FIH(0x1462-0x7508)"},
{0x10DE, 0x077E, 0x1849, 0x077E, "K10N78FullHD-hSLI R3.0 EHCI USB 2.0 Controller(0x1849-0x077E)"},
{0x10DE, 0x07C0, 0xFFFF, 0xFFFF, "MCP73 Host Bridge(0x07C0)"},
{0x10DE, 0x07C0, 0x1AFA, 0x7150, "JW-IN7150-HD(0x1AFA-0x7150)"},
{0x10DE, 0x07C1, 0xFFFF, 0xFFFF, "MCP73 Host Bridge(0x07C1)"},
{0x10DE, 0x07C1, 0x1019, 0x297A, "MCP73PVT-SM(0x1019-0x297A)"},
{0x10DE, 0x07C2, 0xFFFF, 0xFFFF, "MCP73 Host Bridge(0x07C2)"},
{0x10DE, 0x07C3, 0xFFFF, 0xFFFF, "MCP73 Host Bridge(0x07C3)"},
{0x10DE, 0x07C3, 0x147B, 0x1C3E, "I-N73V motherboard(0x147B-0x1C3E)"},
{0x10DE, 0x07C5, 0xFFFF, 0xFFFF, "MCP73 Host Bridge(0x07C5)"},
{0x10DE, 0x07C8, 0xFFFF, 0xFFFF, "MCP73 Memory Controller(0x07C8)"},
{0x10DE, 0x07C8, 0x1019, 0x297A, "MCP73PVT-SM(0x1019-0x297A)"},
{0x10DE, 0x07C8, 0x147B, 0x1C3E, "I-N73V motherboard(0x147B-0x1C3E)"},
{0x10DE, 0x07C8, 0x1AFA, 0x7150, "JW-IN7150-HD(0x1AFA-0x7150)"},
{0x10DE, 0x07CB, 0xFFFF, 0xFFFF, "nForce 610i/630i memory controller(0x07CB)"},
{0x10DE, 0x07CB, 0x1019, 0x297A, "MCP73PVT-SM(0x1019-0x297A)"},
{0x10DE, 0x07CB, 0x147B, 0x1C3E, "I-N73V motherboard(0x147B-0x1C3E)"},
{0x10DE, 0x07CB, 0x1AFA, 0x7150, "JW-IN7150-HD(0x1AFA-0x7150)"},
{0x10DE, 0x07CD, 0xFFFF, 0xFFFF, "nForce 610i/630i memory controller(0x07CD)"},
{0x10DE, 0x07CD, 0x1019, 0x297A, "MCP73PVT-SM(0x1019-0x297A)"},
{0x10DE, 0x07CD, 0x147B, 0x1C3E, "I-N73V motherboard(0x147B-0x1C3E)"},
{0x10DE, 0x07CD, 0x1AFA, 0x7150, "JW-IN7150-HD(0x1AFA-0x7150)"},
{0x10DE, 0x07CE, 0xFFFF, 0xFFFF, "nForce 610i/630i memory controller(0x07CE)"},
{0x10DE, 0x07CE, 0x1019, 0x297A, "MCP73PVT-SM(0x1019-0x297A)"},
{0x10DE, 0x07CE, 0x147B, 0x1C3E, "I-N73V motherboard(0x147B-0x1C3E)"},
{0x10DE, 0x07CE, 0x1AFA, 0x7150, "JW-IN7150-HD(0x1AFA-0x7150)"},
{0x10DE, 0x07CF, 0xFFFF, 0xFFFF, "nForce 610i/630i memory controller(0x07CF)"},
{0x10DE, 0x07CF, 0x1019, 0x297A, "MCP73PVT-SM(0x1019-0x297A)"},
{0x10DE, 0x07CF, 0x147B, 0x1C3E, "I-N73V motherboard(0x147B-0x1C3E)"},
{0x10DE, 0x07CF, 0x1AFA, 0x7150, "JW-IN7150-HD(0x1AFA-0x7150)"},
{0x10DE, 0x07D0, 0xFFFF, 0xFFFF, "nForce 610i/630i memory controller(0x07D0)"},
{0x10DE, 0x07D0, 0x1019, 0x297A, "MCP73PVT-SM(0x1019-0x297A)"},
{0x10DE, 0x07D0, 0x147B, 0x1C3E, "I-N73V motherboard(0x147B-0x1C3E)"},
{0x10DE, 0x07D0, 0x1AFA, 0x7150, "JW-IN7150-HD(0x1AFA-0x7150)"},
{0x10DE, 0x07D1, 0xFFFF, 0xFFFF, "nForce 610i/630i memory controller(0x07D1)"},
{0x10DE, 0x07D1, 0x1019, 0x297A, "MCP73PVT-SM(0x1019-0x297A)"},
{0x10DE, 0x07D1, 0x147B, 0x1C3E, "I-N73V motherboard(0x147B-0x1C3E)"},
{0x10DE, 0x07D1, 0x1AFA, 0x7150, "JW-IN7150-HD(0x1AFA-0x7150)"},
{0x10DE, 0x07D2, 0xFFFF, 0xFFFF, "nForce 610i/630i memory controller(0x07D2)"},
{0x10DE, 0x07D2, 0x1019, 0x297A, "MCP73PVT-SM(0x1019-0x297A)"},
{0x10DE, 0x07D2, 0x147B, 0x1C3E, "I-N73V motherboard(0x147B-0x1C3E)"},
{0x10DE, 0x07D2, 0x1AFA, 0x7150, "JW-IN7150-HD(0x1AFA-0x7150)"},
{0x10DE, 0x07D3, 0xFFFF, 0xFFFF, "nForce 610i/630i memory controller(0x07D3)"},
{0x10DE, 0x07D3, 0x1019, 0x297A, "MCP73PVT-SM(0x1019-0x297A)"},
{0x10DE, 0x07D3, 0x147B, 0x1C3E, "I-N73V motherboard(0x147B-0x1C3E)"},
{0x10DE, 0x07D3, 0x1AFA, 0x7150, "JW-IN7150-HD(0x1AFA-0x7150)"},
{0x10DE, 0x07D6, 0xFFFF, 0xFFFF, "nForce 610i/630i memory controller(0x07D6)"},
{0x10DE, 0x07D6, 0x1019, 0x297A, "MCP73PVT-SM(0x1019-0x297A)"},
{0x10DE, 0x07D6, 0x147B, 0x1C3E, "I-N73V motherboard(0x147B-0x1C3E)"},
{0x10DE, 0x07D6, 0x1AFA, 0x7150, "JW-IN7150-HD(0x1AFA-0x7150)"},
{0x10DE, 0x07D7, 0xFFFF, 0xFFFF, "MCP73 LPC Bridge(0x07D7)"},
{0x10DE, 0x07D7, 0x1019, 0x297A, "MCP73PVT-SM(0x1019-0x297A)"},
{0x10DE, 0x07D7, 0x147B, 0x1C3E, "I-N73V motherboard(0x147B-0x1C3E)"},
{0x10DE, 0x07D7, 0x1AFA, 0x7150, "JW-IN7150-HD(0x1AFA-0x7150)"},
{0x10DE, 0x07D8, 0xFFFF, 0xFFFF, "MCP73 SMBus(0x07D8)"},
{0x10DE, 0x07D8, 0x1019, 0x297A, "MCP73PVT-SM(0x1019-0x297A)"},
{0x10DE, 0x07D8, 0x147B, 0x1C3E, "I-N73V motherboard(0x147B-0x1C3E)"},
{0x10DE, 0x07D8, 0x1AFA, 0x7150, "JW-IN7150-HD(0x1AFA-0x7150)"},
{0x10DE, 0x07D9, 0xFFFF, 0xFFFF, "MCP73 Memory Controller(0x07D9)"},
{0x10DE, 0x07D9, 0x1019, 0x297A, "MCP73PVT-SM(0x1019-0x297A)"},
{0x10DE, 0x07D9, 0x147B, 0x1C3E, "I-N73V motherboard(0x147B-0x1C3E)"},
{0x10DE, 0x07D9, 0x1AFA, 0x7150, "JW-IN7150-HD(0x1AFA-0x7150)"},
{0x10DE, 0x07DA, 0xFFFF, 0xFFFF, "MCP73 Co-processor(0x07DA)"},
{0x10DE, 0x07DA, 0x1AFA, 0x7150, "JW-IN7150-HD(0x1AFA-0x7150)"},
{0x10DE, 0x07DC, 0xFFFF, 0xFFFF, "MCP73 Ethernet(0x07DC)"},
{0x10DE, 0x07DC, 0x147B, 0x1C3E, "I-N73V motherboard(0x147B-0x1C3E)"},
{0x10DE, 0x07DD, 0xFFFF, 0xFFFF, "MCP73 Ethernet(0x07DD)"},
{0x10DE, 0x07DE, 0xFFFF, 0xFFFF, "MCP73 Ethernet(0x07DE)"},
{0x10DE, 0x07DF, 0xFFFF, 0xFFFF, "MCP73 Ethernet(0x07DF)"},
{0x10DE, 0x07E0, 0xFFFF, 0xFFFF, "C73 [GeForce 7150 / nForce 630i](0x07E0)"},
{0x10DE, 0x07E0, 0x1AFA, 0x7150, "JW-IN7150-HD(0x1AFA-0x7150)"},
{0x10DE, 0x07E1, 0xFFFF, 0xFFFF, "C73 [GeForce 7100 / nForce 630i](0x07E1)"},
{0x10DE, 0x07E1, 0x1019, 0x297A, "MCP73PVT-SM(0x1019-0x297A)"},
{0x10DE, 0x07E2, 0xFFFF, 0xFFFF, "C73 [GeForce 7050 / nForce 630i](0x07E2)"},
{0x10DE, 0x07E3, 0xFFFF, 0xFFFF, "C73 [GeForce 7050 / nForce 610i](0x07E3)"},
{0x10DE, 0x07E3, 0x147B, 0x1C3E, "I-N73V motherboard(0x147B-0x1C3E)"},
{0x10DE, 0x07E5, 0xFFFF, 0xFFFF, "C73 [GeForce 7100 / nForce 620i](0x07E5)"},
{0x10DE, 0x07F0, 0xFFFF, 0xFFFF, "MCP73 SATA Controller (IDE mode)(0x07F0)"},
{0x10DE, 0x07F0, 0x147B, 0x1C3E, "I-N73V motherboard(0x147B-0x1C3E)"},
{0x10DE, 0x07F4, 0xFFFF, 0xFFFF, "GeForce 7100/nForce 630i SATA(0x07F4)"},
{0x10DE, 0x07F4, 0x1019, 0x297A, "MCP73PVT-SM(0x1019-0x297A)"},
{0x10DE, 0x07F4, 0x147B, 0x1C3E, "I-N73V motherboard(0x147B-0x1C3E)"},
{0x10DE, 0x07F8, 0xFFFF, 0xFFFF, "MCP73 SATA RAID Controller(0x07F8)"},
{0x10DE, 0x07F8, 0x147B, 0x1C3E, "I-N73V motherboard(0x147B-0x1C3E)"},
{0x10DE, 0x07FC, 0xFFFF, 0xFFFF, "MCP73 High Definition Audio(0x07FC)"},
{0x10DE, 0x07FC, 0x1019, 0x297A, "MCP73PVT-SM(0x1019-0x297A)"},
{0x10DE, 0x07FC, 0x10DE, 0x07FC, "MCP73 High Definition Audio(0x10DE-0x07FC)"},
{0x10DE, 0x07FC, 0x147B, 0x1C3E, "I-N73V motherboard(0x147B-0x1C3E)"},
{0x10DE, 0x07FE, 0xFFFF, 0xFFFF, "MCP73 OHCI USB 1.1 Controller(0x07FE)"},
{0x10DE, 0x07FE, 0x1019, 0x297A, "MCP73PVT-SM(0x1019-0x297A)"},
{0x10DE, 0x07FE, 0x147B, 0x1C3E, "I-N73V motherboard(0x147B-0x1C3E)"},
{0x10DE, 0x07FE, 0x1AFA, 0x7150, "JW-IN7150-HD(0x1AFA-0x7150)"},
{0x10DE, 0x0840, 0xFFFF, 0xFFFF, "C77 [GeForce 8200M](0x0840)"},
{0x10DE, 0x0844, 0xFFFF, 0xFFFF, "C77 [GeForce 9100M G](0x0844)"},
{0x10DE, 0x0845, 0xFFFF, 0xFFFF, "C77 [GeForce 8200M G](0x0845)"},
{0x10DE, 0x0846, 0xFFFF, 0xFFFF, "C77 [GeForce 9200](0x0846)"},
{0x10DE, 0x0847, 0xFFFF, 0xFFFF, "C78 [GeForce 9100](0x0847)"},
{0x10DE, 0x0847, 0x103C, 0x2A9E, "Pavilion p6310f(0x103C-0x2A9E)"},
{0x10DE, 0x0848, 0xFFFF, 0xFFFF, "C77 [GeForce 8300](0x0848)"},
{0x10DE, 0x0849, 0xFFFF, 0xFFFF, "C77 [GeForce 8200](0x0849)"},
{0x10DE, 0x0849, 0x1462, 0x7508, "K9N2GM-FIH(0x1462-0x7508)"},
{0x10DE, 0x0849, 0x1849, 0x0849, "K10N78FullHD-hSLI R3.0 GeForce 8200(0x1849-0x0849)"},
{0x10DE, 0x084A, 0xFFFF, 0xFFFF, "C77 [nForce 730a](0x084A)"},
{0x10DE, 0x084B, 0xFFFF, 0xFFFF, "C77 [GeForce 8200](0x084B)"},
{0x10DE, 0x084C, 0xFFFF, 0xFFFF, "C77 [nForce 780a/980a SLI](0x084C)"},
{0x10DE, 0x084D, 0xFFFF, 0xFFFF, "C77 [nForce 750a SLI](0x084D)"},
{0x10DE, 0x084D, 0x1043, 0x82E8, "M3N72-D mGPU(0x1043-0x82E8)"},
{0x10DE, 0x084F, 0xFFFF, 0xFFFF, "C77 [GeForce 8100 / nForce 720a](0x084F)"},
{0x10DE, 0x0860, 0xFFFF, 0xFFFF, "C79 [GeForce 9300](0x0860)"},
{0x10DE, 0x0861, 0xFFFF, 0xFFFF, "C79 [GeForce 9400](0x0861)"},
{0x10DE, 0x0862, 0xFFFF, 0xFFFF, "C79 [GeForce 9400M G](0x0862)"},
{0x10DE, 0x0863, 0xFFFF, 0xFFFF, "C79 [GeForce 9400M](0x0863)"},
{0x10DE, 0x0863, 0x106B, 0x00AA, "MacBook5,1(0x106B-0x00AA)"},
{0x10DE, 0x0864, 0xFFFF, 0xFFFF, "C79 [GeForce 9300](0x0864)"},
{0x10DE, 0x0865, 0xFFFF, 0xFFFF, "C79 [GeForce 9300 / ION](0x0865)"},
{0x10DE, 0x0866, 0xFFFF, 0xFFFF, "C79 [GeForce 9400M G](0x0866)"},
{0x10DE, 0x0866, 0x106B, 0x00B1, "GeForce 9400M(0x106B-0x00B1)"},
{0x10DE, 0x0867, 0xFFFF, 0xFFFF, "C79 [GeForce 9400](0x0867)"},
{0x10DE, 0x0867, 0x106B, 0x00AD, "iMac 9,1(0x106B-0x00AD)"},
{0x10DE, 0x0868, 0xFFFF, 0xFFFF, "C79 [nForce 760i SLI](0x0868)"},
{0x10DE, 0x0869, 0xFFFF, 0xFFFF, "MCP7A [GeForce 9400](0x0869)"},
{0x10DE, 0x086A, 0xFFFF, 0xFFFF, "C79 [GeForce 9400](0x086A)"},
{0x10DE, 0x086C, 0xFFFF, 0xFFFF, "C79 [GeForce 9300 / nForce 730i](0x086C)"},
{0x10DE, 0x086D, 0xFFFF, 0xFFFF, "C79 [GeForce 9200](0x086D)"},
{0x10DE, 0x086E, 0xFFFF, 0xFFFF, "C79 [GeForce 9100M G](0x086E)"},
{0x10DE, 0x086F, 0xFFFF, 0xFFFF, "MCP79 [GeForce 8200M G](0x086F)"},
{0x10DE, 0x086F, 0x1043, 0x16B2, "F5GL Notebook(0x1043-0x16B2)"},
{0x10DE, 0x0870, 0xFFFF, 0xFFFF, "C79 [GeForce 9400M](0x0870)"},
{0x10DE, 0x0871, 0xFFFF, 0xFFFF, "C79 [GeForce 9200](0x0871)"},
{0x10DE, 0x0872, 0xFFFF, 0xFFFF, "C79 [GeForce G102M](0x0872)"},
{0x10DE, 0x0872, 0x1043, 0x19B4, "GeForce G102M(0x1043-0x19B4)"},
{0x10DE, 0x0872, 0x1043, 0x1AA2, "GeForce G102M(0x1043-0x1AA2)"},
{0x10DE, 0x0872, 0x1043, 0x1C02, "GeForce G102M(0x1043-0x1C02)"},
{0x10DE, 0x0872, 0x1043, 0x1C42, "GeForce G205M(0x1043-0x1C42)"},
{0x10DE, 0x0873, 0xFFFF, 0xFFFF, "C79 [GeForce G102M](0x0873)"},
{0x10DE, 0x0873, 0x1043, 0x19B4, "GeForce G102M(0x1043-0x19B4)"},
{0x10DE, 0x0873, 0x1043, 0x1C12, "GeForce G102M(0x1043-0x1C12)"},
{0x10DE, 0x0873, 0x1043, 0x1C52, "GeForce G205M(0x1043-0x1C52)"},
{0x10DE, 0x0874, 0xFFFF, 0xFFFF, "C79 [ION](0x0874)"},
{0x10DE, 0x0876, 0xFFFF, 0xFFFF, "C79 [GeForce 9400M / ION](0x0876)"},
{0x10DE, 0x087A, 0xFFFF, 0xFFFF, "C79 [GeForce 9400](0x087A)"},
{0x10DE, 0x087D, 0xFFFF, 0xFFFF, "C79 [ION](0x087D)"},
{0x10DE, 0x087D, 0x19DA, 0xA123, "IONITX-F-E(0x19DA-0xA123)"},
{0x10DE, 0x087E, 0xFFFF, 0xFFFF, "C79 [ION LE](0x087E)"},
{0x10DE, 0x087F, 0xFFFF, 0xFFFF, "C79 [ION LE](0x087F)"},
{0x10DE, 0x08A0, 0xFFFF, 0xFFFF, "MCP89 [GeForce 320M](0x08A0)"},
{0x10DE, 0x08A2, 0xFFFF, 0xFFFF, "MCP89 [GeForce 320M](0x08A2)"},
{0x10DE, 0x08A3, 0xFFFF, 0xFFFF, "MCP89 [GeForce 320M](0x08A3)"},
{0x10DE, 0x08A4, 0xFFFF, 0xFFFF, "MCP89 [GeForce 320M](0x08A4)"},
{0x10DE, 0x08A5, 0xFFFF, 0xFFFF, "MCP89 [GeForce 320M](0x08A5)"},
{0x10DE, 0x0A20, 0xFFFF, 0xFFFF, "GT216 [GeForce GT 220](0x0A20)"},
{0x10DE, 0x0A20, 0x1043, 0x8311, "ENGT220/DI/1GD3(LP)/V2(0x1043-0x8311)"},
{0x10DE, 0x0A21, 0xFFFF, 0xFFFF, "GT216M [GeForce GT 330M](0x0A21)"},
{0x10DE, 0x0A22, 0xFFFF, 0xFFFF, "GT216 [GeForce 315](0x0A22)"},
{0x10DE, 0x0A23, 0xFFFF, 0xFFFF, "GT216 [GeForce 210](0x0A23)"},
{0x10DE, 0x0A24, 0xFFFF, 0xFFFF, "GT216 [GeForce 405](0x0A24)"},
{0x10DE, 0x0A26, 0xFFFF, 0xFFFF, "GT216 [GeForce 405](0x0A26)"},
{0x10DE, 0x0A27, 0xFFFF, 0xFFFF, "GT216 [GeForce 405](0x0A27)"},
{0x10DE, 0x0A28, 0xFFFF, 0xFFFF, "GT216M [GeForce GT 230M](0x0A28)"},
{0x10DE, 0x0A29, 0xFFFF, 0xFFFF, "GT216M [GeForce GT 330M](0x0A29)"},
{0x10DE, 0x0A2A, 0xFFFF, 0xFFFF, "GT216M [GeForce GT 230M](0x0A2A)"},
{0x10DE, 0x0A2B, 0xFFFF, 0xFFFF, "GT216M [GeForce GT 330M](0x0A2B)"},
{0x10DE, 0x0A2C, 0xFFFF, 0xFFFF, "GT216M [NVS 5100M](0x0A2C)"},
{0x10DE, 0x0A2D, 0xFFFF, 0xFFFF, "GT216M [GeForce GT 320M](0x0A2D)"},
{0x10DE, 0x0A30, 0xFFFF, 0xFFFF, "GT216 [GeForce 505](0x0A30)"},
{0x10DE, 0x0A32, 0xFFFF, 0xFFFF, "GT216 [GeForce GT 415](0x0A32)"},
{0x10DE, 0x0A34, 0xFFFF, 0xFFFF, "GT216M [GeForce GT 240M](0x0A34)"},
{0x10DE, 0x0A35, 0xFFFF, 0xFFFF, "GT216M [GeForce GT 325M](0x0A35)"},
{0x10DE, 0x0A38, 0xFFFF, 0xFFFF, "GT216GL [Quadro 400](0x0A38)"},
{0x10DE, 0x0A3C, 0xFFFF, 0xFFFF, "GT216GLM [Quadro FX 880M](0x0A3C)"},
{0x10DE, 0x0A60, 0xFFFF, 0xFFFF, "GT218 [GeForce G210](0x0A60)"},
{0x10DE, 0x0A62, 0xFFFF, 0xFFFF, "GT218 [GeForce 205](0x0A62)"},
{0x10DE, 0x0A63, 0xFFFF, 0xFFFF, "GT218 [GeForce 310](0x0A63)"},
{0x10DE, 0x0A64, 0xFFFF, 0xFFFF, "GT218 [ION](0x0A64)"},
{0x10DE, 0x0A65, 0xFFFF, 0xFFFF, "GT218 [GeForce 210](0x0A65)"},
{0x10DE, 0x0A65, 0x1043, 0x8334, "EN210 SILENT(0x1043-0x8334)"},
{0x10DE, 0x0A65, 0x1458, 0x36A9, "GV-N210D3-1GI (rev. 6.0/6.1)(0x1458-0x36A9)"},
{0x10DE, 0x0A65, 0x1462, 0x8094, "N210 [Geforce 210] PCIe graphics adapter(0x1462-0x8094)"},
{0x10DE, 0x0A65, 0x19DA, 0x7222, "GeForce 210 1GB [Synergy Edition](0x19DA-0x7222)"},
{0x10DE, 0x0A66, 0xFFFF, 0xFFFF, "GT218 [GeForce 310](0x0A66)"},
{0x10DE, 0x0A67, 0xFFFF, 0xFFFF, "GT218 [GeForce 315](0x0A67)"},
{0x10DE, 0x0A68, 0xFFFF, 0xFFFF, "GT218M [GeForce G 105M](0x0A68)"},
{0x10DE, 0x0A69, 0xFFFF, 0xFFFF, "GT218M [GeForce G 105M](0x0A69)"},
{0x10DE, 0x0A6A, 0xFFFF, 0xFFFF, "GT218M [NVS 2100M](0x0A6A)"},
{0x10DE, 0x0A6C, 0xFFFF, 0xFFFF, "GT218M [NVS 3100M](0x0A6C)"},
{0x10DE, 0x0A6C, 0x1028, 0x040B, "Latitude E6510(0x1028-0x040B)"},
{0x10DE, 0x0A6C, 0x17AA, 0x2142, "ThinkPad T410(0x17AA-0x2142)"},
{0x10DE, 0x0A6E, 0xFFFF, 0xFFFF, "GT218M [GeForce 305M](0x0A6E)"},
{0x10DE, 0x0A6F, 0xFFFF, 0xFFFF, "GT218M [ION](0x0A6F)"},
{0x10DE, 0x0A70, 0xFFFF, 0xFFFF, "GT218M [GeForce 310M](0x0A70)"},
{0x10DE, 0x0A71, 0xFFFF, 0xFFFF, "GT218M [GeForce 305M](0x0A71)"},
{0x10DE, 0x0A72, 0xFFFF, 0xFFFF, "GT218M [GeForce 310M](0x0A72)"},
{0x10DE, 0x0A73, 0xFFFF, 0xFFFF, "GT218M [GeForce 305M](0x0A73)"},
{0x10DE, 0x0A74, 0xFFFF, 0xFFFF, "GT218M [GeForce G210M](0x0A74)"},
{0x10DE, 0x0A74, 0x1B0A, 0x903A, "GeForce G210(0x1B0A-0x903A)"},
{0x10DE, 0x0A75, 0xFFFF, 0xFFFF, "GT218M [GeForce 310M](0x0A75)"},
{0x10DE, 0x0A76, 0xFFFF, 0xFFFF, "GT218M [ION 2](0x0A76)"},
{0x10DE, 0x0A78, 0xFFFF, 0xFFFF, "GT218GL [Quadro FX 380 LP](0x0A78)"},
{0x10DE, 0x0A7A, 0xFFFF, 0xFFFF, "GT218M [GeForce 315M](0x0A7A)"},
{0x10DE, 0x0A7A, 0x104D, 0x907E, "GeForce 315M(0x104D-0x907E)"},
{0x10DE, 0x0A7A, 0x1179, 0xFC50, "GeForce 315M(0x1179-0xFC50)"},
{0x10DE, 0x0A7A, 0x1179, 0xFC61, "GeForce 315M(0x1179-0xFC61)"},
{0x10DE, 0x0A7A, 0x1179, 0xFC71, "GeForce 315M(0x1179-0xFC71)"},
{0x10DE, 0x0A7A, 0x1179, 0xFC90, "GeForce 315M(0x1179-0xFC90)"},
{0x10DE, 0x0A7A, 0x1179, 0xFCC0, "GeForce 315M(0x1179-0xFCC0)"},
{0x10DE, 0x0A7A, 0x1179, 0xFCD0, "GeForce 315M(0x1179-0xFCD0)"},
{0x10DE, 0x0A7A, 0x1179, 0xFCE2, "GeForce 315M(0x1179-0xFCE2)"},
{0x10DE, 0x0A7A, 0x1179, 0xFCF2, "GeForce 315M(0x1179-0xFCF2)"},
{0x10DE, 0x0A7A, 0x1179, 0xFD16, "GeForce 315M(0x1179-0xFD16)"},
{0x10DE, 0x0A7A, 0x1179, 0xFD40, "GeForce 315M(0x1179-0xFD40)"},
{0x10DE, 0x0A7A, 0x1179, 0xFD50, "GeForce 315M(0x1179-0xFD50)"},
{0x10DE, 0x0A7A, 0x1179, 0xFD52, "GeForce 315M(0x1179-0xFD52)"},
{0x10DE, 0x0A7A, 0x1179, 0xFD61, "GeForce 315M(0x1179-0xFD61)"},
{0x10DE, 0x0A7A, 0x1179, 0xFD71, "GeForce 315M(0x1179-0xFD71)"},
{0x10DE, 0x0A7A, 0x1179, 0xFD92, "GeForce 315M(0x1179-0xFD92)"},
{0x10DE, 0x0A7A, 0x1179, 0xFD96, "GeForce 315M(0x1179-0xFD96)"},
{0x10DE, 0x0A7A, 0x1179, 0xFDD0, "GeForce 315M(0x1179-0xFDD0)"},
{0x10DE, 0x0A7A, 0x1179, 0xFDD2, "GeForce 315M(0x1179-0xFDD2)"},
{0x10DE, 0x0A7A, 0x1179, 0xFDFE, "GeForce 315M(0x1179-0xFDFE)"},
{0x10DE, 0x0A7A, 0x144D, 0xC0A2, "GeForce 315M(0x144D-0xC0A2)"},
{0x10DE, 0x0A7A, 0x144D, 0xC0B2, "GeForce 315M(0x144D-0xC0B2)"},
{0x10DE, 0x0A7A, 0x144D, 0xC581, "GeForce 315M(0x144D-0xC581)"},
{0x10DE, 0x0A7A, 0x144D, 0xC587, "GeForce 315M(0x144D-0xC587)"},
{0x10DE, 0x0A7A, 0x144D, 0xC588, "GeForce 315M(0x144D-0xC588)"},
{0x10DE, 0x0A7A, 0x144D, 0xC597, "GeForce 315M(0x144D-0xC597)"},
{0x10DE, 0x0A7A, 0x144D, 0xC606, "GeForce 315M(0x144D-0xC606)"},
{0x10DE, 0x0A7A, 0x1462, 0xAA51, "GeForce 405(0x1462-0xAA51)"},
{0x10DE, 0x0A7A, 0x1462, 0xAA58, "GeForce 405(0x1462-0xAA58)"},
{0x10DE, 0x0A7A, 0x1462, 0xAC71, "GeForce 405(0x1462-0xAC71)"},
{0x10DE, 0x0A7A, 0x1462, 0xAC81, "GeForce 315M(0x1462-0xAC81)"},
{0x10DE, 0x0A7A, 0x1462, 0xAC82, "GeForce 405(0x1462-0xAC82)"},
{0x10DE, 0x0A7A, 0x1462, 0xAE33, "GeForce 405(0x1462-0xAE33)"},
{0x10DE, 0x0A7A, 0x1642, 0x3980, "GeForce 405(0x1642-0x3980)"},
{0x10DE, 0x0A7A, 0x17AA, 0x3950, "GeForce 405M(0x17AA-0x3950)"},
{0x10DE, 0x0A7A, 0x17AA, 0x397D, "GeForce 405M(0x17AA-0x397D)"},
{0x10DE, 0x0A7A, 0x1B0A, 0x2091, "GeForce 315M(0x1B0A-0x2091)"},
{0x10DE, 0x0A7A, 0x1B0A, 0x90B4, "GeForce 405(0x1B0A-0x90B4)"},
{0x10DE, 0x0A7A, 0x1BFD, 0x0003, "GeForce 405(0x1BFD-0x0003)"},
{0x10DE, 0x0A7A, 0x1BFD, 0x8006, "GeForce 405(0x1BFD-0x8006)"},
{0x10DE, 0x0A7A, 0x1BFD, 0x8007, "GeForce 315M(0x1BFD-0x8007)"},
{0x10DE, 0x0A7B, 0xFFFF, 0xFFFF, "GT218 [GeForce 505](0x0A7B)"},
{0x10DE, 0x0A7C, 0xFFFF, 0xFFFF, "GT218GLM [Quadro FX 380M](0x0A7C)"},
{0x10DE, 0x0A80, 0xFFFF, 0xFFFF, "MCP79 Host Bridge(0x0A80)"},
{0x10DE, 0x0A81, 0xFFFF, 0xFFFF, "MCP79 Host Bridge(0x0A81)"},
{0x10DE, 0x0A82, 0xFFFF, 0xFFFF, "MCP79 Host Bridge(0x0A82)"},
{0x10DE, 0x0A83, 0xFFFF, 0xFFFF, "MCP79 Host Bridge(0x0A83)"},
{0x10DE, 0x0A84, 0xFFFF, 0xFFFF, "MCP79 Host Bridge(0x0A84)"},
{0x10DE, 0x0A85, 0xFFFF, 0xFFFF, "MCP79 Host Bridge(0x0A85)"},
{0x10DE, 0x0A86, 0xFFFF, 0xFFFF, "MCP79 Host Bridge(0x0A86)"},
{0x10DE, 0x0A87, 0xFFFF, 0xFFFF, "MCP79 Host Bridge(0x0A87)"},
{0x10DE, 0x0A88, 0xFFFF, 0xFFFF, "MCP79 Memory Controller(0x0A88)"},
{0x10DE, 0x0A89, 0xFFFF, 0xFFFF, "MCP79 Memory Controller(0x0A89)"},
{0x10DE, 0x0A98, 0xFFFF, 0xFFFF, "MCP79 Memory Controller(0x0A98)"},
{0x10DE, 0x0A98, 0x1043, 0x1A87, "F5GL Notebook(0x1043-0x1A87)"},
{0x10DE, 0x0A98, 0x10DE, 0xCB79, "iMac 9,1(0x10DE-0xCB79)"},
{0x10DE, 0x0AA0, 0xFFFF, 0xFFFF, "MCP79 PCI Express Bridge(0x0AA0)"},
{0x10DE, 0x0AA0, 0x1043, 0x1A87, "F5GL Notebook(0x1043-0x1A87)"},
{0x10DE, 0x0AA0, 0x10DE, 0xCB79, "Apple iMac 9,1(0x10DE-0xCB79)"},
{0x10DE, 0x0AA2, 0xFFFF, 0xFFFF, "MCP79 SMBus(0x0AA2)"},
{0x10DE, 0x0AA2, 0x1043, 0x1A87, "F5GL Notebook(0x1043-0x1A87)"},
{0x10DE, 0x0AA2, 0x10DE, 0xCB79, "Apple iMac 9,1(0x10DE-0xCB79)"},
{0x10DE, 0x0AA2, 0x19DA, 0xA123, "IONITX-F-E(0x19DA-0xA123)"},
{0x10DE, 0x0AA3, 0xFFFF, 0xFFFF, "MCP79 Co-processor(0x0AA3)"},
{0x10DE, 0x0AA3, 0x1043, 0x1A87, "F5GL Notebook(0x1043-0x1A87)"},
{0x10DE, 0x0AA3, 0x10DE, 0xCB79, "Apple iMac 9,1(0x10DE-0xCB79)"},
{0x10DE, 0x0AA3, 0x19DA, 0xA123, "IONITX-F-E(0x19DA-0xA123)"},
{0x10DE, 0x0AA4, 0xFFFF, 0xFFFF, "MCP79 Memory Controller(0x0AA4)"},
{0x10DE, 0x0AA4, 0x1043, 0x1A87, "F5GL Notebook(0x1043-0x1A87)"},
{0x10DE, 0x0AA4, 0x19DA, 0xA123, "IONITX-F-E(0x19DA-0xA123)"},
{0x10DE, 0x0AA5, 0xFFFF, 0xFFFF, "MCP79 OHCI USB 1.1 Controller(0x0AA5)"},
{0x10DE, 0x0AA5, 0x1043, 0x1A87, "F5GL Notebook(0x1043-0x1A87)"},
{0x10DE, 0x0AA5, 0x10DE, 0xCB79, "Apple iMac 9,1(0x10DE-0xCB79)"},
{0x10DE, 0x0AA5, 0x19DA, 0xA123, "IONITX-F-E(0x19DA-0xA123)"},
{0x10DE, 0x0AA6, 0xFFFF, 0xFFFF, "MCP79 EHCI USB 2.0 Controller(0x0AA6)"},
{0x10DE, 0x0AA6, 0x1043, 0x1A87, "F5GL Notebook(0x1043-0x1A87)"},
{0x10DE, 0x0AA6, 0x10DE, 0xCB79, "Apple iMac 9,1(0x10DE-0xCB79)"},
{0x10DE, 0x0AA6, 0x19DA, 0xA123, "IONITX-F-E(0x19DA-0xA123)"},
{0x10DE, 0x0AA7, 0xFFFF, 0xFFFF, "MCP79 OHCI USB 1.1 Controller(0x0AA7)"},
{0x10DE, 0x0AA7, 0x10DE, 0xCB79, "Apple iMac 9,1(0x10DE-0xCB79)"},
{0x10DE, 0x0AA7, 0x19DA, 0xA123, "IONITX-F-E(0x19DA-0xA123)"},
{0x10DE, 0x0AA8, 0xFFFF, 0xFFFF, "MCP79 OHCI USB 1.1 Controller(0x0AA8)"},
{0x10DE, 0x0AA9, 0xFFFF, 0xFFFF, "MCP79 EHCI USB 2.0 Controller(0x0AA9)"},
{0x10DE, 0x0AA9, 0x10DE, 0xCB79, "Apple iMac 9,1(0x10DE-0xCB79)"},
{0x10DE, 0x0AA9, 0x19DA, 0xA123, "IONITX-F-E(0x19DA-0xA123)"},
{0x10DE, 0x0AAA, 0xFFFF, 0xFFFF, "MCP79 EHCI USB 2.0 Controller(0x0AAA)"},
{0x10DE, 0x0AAB, 0xFFFF, 0xFFFF, "MCP79 PCI Bridge(0x0AAB)"},
{0x10DE, 0x0AAB, 0x1043, 0x1A87, "F5GL Notebook(0x1043-0x1A87)"},
{0x10DE, 0x0AAB, 0x10DE, 0xCB79, "Apple iMac 9,1(0x10DE-0xCB79)"},
{0x10DE, 0x0AAC, 0xFFFF, 0xFFFF, "MCP79 LPC Bridge(0x0AAC)"},
{0x10DE, 0x0AAD, 0xFFFF, 0xFFFF, "MCP79 LPC Bridge(0x0AAD)"},
{0x10DE, 0x0AAD, 0x19DA, 0xA123, "IONITX-F-E(0x19DA-0xA123)"},
{0x10DE, 0x0AAE, 0xFFFF, 0xFFFF, "MCP79 LPC Bridge(0x0AAE)"},
{0x10DE, 0x0AAE, 0x1043, 0x1A87, "F5GL Notebook(0x1043-0x1A87)"},
{0x10DE, 0x0AAE, 0x10DE, 0xCB79, "Apple iMac 9,1(0x10DE-0xCB79)"},
{0x10DE, 0x0AAF, 0xFFFF, 0xFFFF, "MCP79 LPC Bridge(0x0AAF)"},
{0x10DE, 0x0AB0, 0xFFFF, 0xFFFF, "MCP79 Ethernet(0x0AB0)"},
{0x10DE, 0x0AB0, 0x1043, 0x1215, "F5GL Notebook(0x1043-0x1215)"},
{0x10DE, 0x0AB0, 0x10DE, 0xCB79, "Apple iMac 9,1(0x10DE-0xCB79)"},
{0x10DE, 0x0AB0, 0x19DA, 0xA123, "IONITX-F-E(0x19DA-0xA123)"},
{0x10DE, 0x0AB1, 0xFFFF, 0xFFFF, "MCP79 Ethernet(0x0AB1)"},
{0x10DE, 0x0AB2, 0xFFFF, 0xFFFF, "MCP79 Ethernet(0x0AB2)"},
{0x10DE, 0x0AB3, 0xFFFF, 0xFFFF, "MCP79 Ethernet(0x0AB3)"},
{0x10DE, 0x0AB4, 0xFFFF, 0xFFFF, "MCP79 SATA Controller(0x0AB4)"},
{0x10DE, 0x0AB4, 0x19DA, 0xA123, "IONITX-F-E(0x19DA-0xA123)"},
{0x10DE, 0x0AB5, 0xFFFF, 0xFFFF, "MCP79 SATA Controller(0x0AB5)"},
{0x10DE, 0x0AB6, 0xFFFF, 0xFFFF, "MCP79 SATA Controller(0x0AB6)"},
{0x10DE, 0x0AB7, 0xFFFF, 0xFFFF, "MCP79 SATA Controller(0x0AB7)"},
{0x10DE, 0x0AB8, 0xFFFF, 0xFFFF, "MCP79 AHCI Controller(0x0AB8)"},
{0x10DE, 0x0AB8, 0x1043, 0x1A87, "F5GL Notebook(0x1043-0x1A87)"},
{0x10DE, 0x0AB9, 0xFFFF, 0xFFFF, "MCP79 AHCI Controller(0x0AB9)"},
{0x10DE, 0x0AB9, 0x10DE, 0xCB79, "Apple iMac 9,1(0x10DE-0xCB79)"},
{0x10DE, 0x0ABA, 0xFFFF, 0xFFFF, "MCP79 AHCI Controller(0x0ABA)"},
{0x10DE, 0x0ABB, 0xFFFF, 0xFFFF, "MCP79 AHCI Controller(0x0ABB)"},
{0x10DE, 0x0ABC, 0xFFFF, 0xFFFF, "MCP79 RAID Controller(0x0ABC)"},
{0x10DE, 0x0ABD, 0xFFFF, 0xFFFF, "MCP79 RAID Controller(0x0ABD)"},
{0x10DE, 0x0ABE, 0xFFFF, 0xFFFF, "MCP79 RAID Controller(0x0ABE)"},
{0x10DE, 0x0ABF, 0xFFFF, 0xFFFF, "MCP79 RAID Controller(0x0ABF)"},
{0x10DE, 0x0AC0, 0xFFFF, 0xFFFF, "MCP79 High Definition Audio(0x0AC0)"},
{0x10DE, 0x0AC0, 0x1043, 0x1903, "F5GL Notebook(0x1043-0x1903)"},
{0x10DE, 0x0AC0, 0x10DE, 0xCB79, "Apple iMac 9,1(0x10DE-0xCB79)"},
{0x10DE, 0x0AC1, 0xFFFF, 0xFFFF, "MCP79 High Definition Audio(0x0AC1)"},
{0x10DE, 0x0AC2, 0xFFFF, 0xFFFF, "MCP79 High Definition Audio(0x0AC2)"},
{0x10DE, 0x0AC3, 0xFFFF, 0xFFFF, "MCP79 High Definition Audio(0x0AC3)"},
{0x10DE, 0x0AC4, 0xFFFF, 0xFFFF, "MCP79 PCI Express Bridge(0x0AC4)"},
{0x10DE, 0x0AC4, 0x10DE, 0xCB79, "Apple iMac 9,1(0x10DE-0xCB79)"},
{0x10DE, 0x0AC5, 0xFFFF, 0xFFFF, "MCP79 PCI Express Bridge(0x0AC5)"},
{0x10DE, 0x0AC6, 0xFFFF, 0xFFFF, "MCP79 PCI Express Bridge(0x0AC6)"},
{0x10DE, 0x0AC6, 0x1043, 0x1A87, "F5GL Notebook(0x1043-0x1A87)"},
{0x10DE, 0x0AC6, 0x10DE, 0xCB79, "Apple iMac 9,1(0x10DE-0xCB79)"},
{0x10DE, 0x0AC7, 0xFFFF, 0xFFFF, "MCP79 PCI Express Bridge(0x0AC7)"},
{0x10DE, 0x0AC7, 0x1043, 0x1A87, "F5GL Notebook(0x1043-0x1A87)"},
{0x10DE, 0x0AC7, 0x10DE, 0xCB79, "Apple iMac 9,1(0x10DE-0xCB79)"},
{0x10DE, 0x0AC8, 0xFFFF, 0xFFFF, "MCP79 PCI Express Bridge(0x0AC8)"},
{0x10DE, 0x0AD0, 0xFFFF, 0xFFFF, "MCP78S [GeForce 8200] SATA Controller (non-AHCI mode)(0x0AD0)"},
{0x10DE, 0x0AD0, 0x1462, 0x7508, "K9N2GM-FIH(0x1462-0x7508)"},
{0x10DE, 0x0AD0, 0x1849, 0x0AD0, "K10N78FullHD-hSLI R3.0 IDE(0x1849-0x0AD0)"},
{0x10DE, 0x0AD4, 0xFFFF, 0xFFFF, "MCP78S [GeForce 8200] AHCI Controller(0x0AD4)"},
{0x10DE, 0x0AD4, 0x103C, 0x2A9E, "Pavilion p6310f(0x103C-0x2A9E)"},
{0x10DE, 0x0AD4, 0x1043, 0x82E8, "M3N72-D(0x1043-0x82E8)"},
{0x10DE, 0x0AD4, 0x1849, 0x0AD4, "K10N78FullHD-hSLI R3.0 AHCI Controller(0x1849-0x0AD4)"},
{0x10DE, 0x0AD8, 0xFFFF, 0xFFFF, "MCP78S [GeForce 8200] SATA Controller (RAID mode)(0x0AD8)"},
{0x10DE, 0x0BE2, 0xFFFF, 0xFFFF, "GT216 HDMI Audio Controller(0x0BE2)"},
{0x10DE, 0x0BE2, 0x1043, 0x8311, "ENGT220/DI/1GD3(LP)/V2(0x1043-0x8311)"},
{0x10DE, 0x0BE3, 0xFFFF, 0xFFFF, "High Definition Audio Controller(0x0BE3)"},
{0x10DE, 0x0BE3, 0x1028, 0x040B, "Latitude E6510(0x1028-0x040B)"},
{0x10DE, 0x0BE3, 0x10DE, 0x066D, "G98 [GeForce 8400GS](0x10DE-0x066D)"},
{0x10DE, 0x0BE3, 0x1462, 0x8094, "N210 [Geforce 210] PCIe graphics adapter(0x1462-0x8094)"},
{0x10DE, 0x0BE4, 0xFFFF, 0xFFFF, "High Definition Audio Controller(0x0BE4)"},
{0x10DE, 0x0BE5, 0xFFFF, 0xFFFF, "GF100 High Definition Audio Controller(0x0BE5)"},
{0x10DE, 0x0BE9, 0xFFFF, 0xFFFF, "GF106 High Definition Audio Controller(0x0BE9)"},
{0x10DE, 0x0BE9, 0x1558, 0x8687, "CLEVO/KAPOK W860CU(0x1558-0x8687)"},
{0x10DE, 0x0BE9, 0x3842, 0x1452, "GeForce GTS 450(0x3842-0x1452)"},
{0x10DE, 0x0BEA, 0xFFFF, 0xFFFF, "GF108 High Definition Audio Controller(0x0BEA)"},
{0x10DE, 0x0BEA, 0x3842, 0x1430, "GeForce GT 430(0x3842-0x1430)"},
{0x10DE, 0x0BEB, 0xFFFF, 0xFFFF, "GF104 High Definition Audio Controller(0x0BEB)"},
{0x10DE, 0x0BEB, 0x1462, 0x2322, "N460GTX Cyclone 1GD5/OC(0x1462-0x2322)"},
{0x10DE, 0x0BEE, 0xFFFF, 0xFFFF, "GF116 High Definition Audio Controller(0x0BEE)"},
{0x10DE, 0x0BF0, 0xFFFF, 0xFFFF, "Tegra2 PCIe x4 Bridge(0x0BF0)"},
{0x10DE, 0x0BF1, 0xFFFF, 0xFFFF, "Tegra2 PCIe x2 Bridge(0x0BF1)"},
{0x10DE, 0x0CA0, 0xFFFF, 0xFFFF, "GT215 [GeForce GT 330](0x0CA0)"},
{0x10DE, 0x0CA2, 0xFFFF, 0xFFFF, "GT215 [GeForce GT 320](0x0CA2)"},
{0x10DE, 0x0CA3, 0xFFFF, 0xFFFF, "GT215 [GeForce GT 240](0x0CA3)"},
{0x10DE, 0x0CA4, 0xFFFF, 0xFFFF, "GT215 [GeForce GT 340](0x0CA4)"},
{0x10DE, 0x0CA5, 0xFFFF, 0xFFFF, "GT215 [GeForce GT 220](0x0CA5)"},
{0x10DE, 0x0CA7, 0xFFFF, 0xFFFF, "GT215 [GeForce GT 330](0x0CA7)"},
{0x10DE, 0x0CA8, 0xFFFF, 0xFFFF, "GT215M [GeForce GTS 260M](0x0CA8)"},
{0x10DE, 0x0CA9, 0xFFFF, 0xFFFF, "GT215M [GeForce GTS 250M](0x0CA9)"},
{0x10DE, 0x0CAC, 0xFFFF, 0xFFFF, "GT215 [GeForce GT 220/315](0x0CAC)"},
{0x10DE, 0x0CAF, 0xFFFF, 0xFFFF, "GT215M [GeForce GT 335M](0x0CAF)"},
{0x10DE, 0x0CB0, 0xFFFF, 0xFFFF, "GT215M [GeForce GTS 350M](0x0CB0)"},
{0x10DE, 0x0CB1, 0xFFFF, 0xFFFF, "GT215M [GeForce GTS 360M](0x0CB1)"},
{0x10DE, 0x0CBC, 0xFFFF, 0xFFFF, "GT215GLM [Quadro FX 1800M](0x0CBC)"},
{0x10DE, 0x0D60, 0xFFFF, 0xFFFF, "MCP89 HOST Bridge(0x0D60)"},
{0x10DE, 0x0D68, 0xFFFF, 0xFFFF, "MCP89 Memory Controller(0x0D68)"},
{0x10DE, 0x0D69, 0xFFFF, 0xFFFF, "MCP89 Memory Controller(0x0D69)"},
{0x10DE, 0x0D76, 0xFFFF, 0xFFFF, "MCP89 PCI Express Bridge(0x0D76)"},
{0x10DE, 0x0D79, 0xFFFF, 0xFFFF, "MCP89 SMBus(0x0D79)"},
{0x10DE, 0x0D7A, 0xFFFF, 0xFFFF, "MCP89 Co-Processor(0x0D7A)"},
{0x10DE, 0x0D7B, 0xFFFF, 0xFFFF, "MCP89 Memory Controller(0x0D7B)"},
{0x10DE, 0x0D7D, 0xFFFF, 0xFFFF, "MCP89 Ethernet(0x0D7D)"},
{0x10DE, 0x0D80, 0xFFFF, 0xFFFF, "MCP89 LPC Bridge(0x0D80)"},
{0x10DE, 0x0D85, 0xFFFF, 0xFFFF, "MCP89 SATA Controller(0x0D85)"},
{0x10DE, 0x0D88, 0xFFFF, 0xFFFF, "MCP89 SATA Controller (AHCI mode)(0x0D88)"},
{0x10DE, 0x0D89, 0xFFFF, 0xFFFF, "MCP89 SATA Controller (AHCI mode)(0x0D89)"},
{0x10DE, 0x0D8D, 0xFFFF, 0xFFFF, "MCP89 SATA Controller (RAID mode)(0x0D8D)"},
{0x10DE, 0x0D94, 0xFFFF, 0xFFFF, "MCP89 High Definition Audio(0x0D94)"},
{0x10DE, 0x0D9C, 0xFFFF, 0xFFFF, "MCP89 OHCI USB 1.1 Controller(0x0D9C)"},
{0x10DE, 0x0D9D, 0xFFFF, 0xFFFF, "MCP89 EHCI USB 2.0 Controller(0x0D9D)"},
{0x10DE, 0x0DC0, 0xFFFF, 0xFFFF, "GF106 [GeForce GT 440](0x0DC0)"},
{0x10DE, 0x0DC4, 0xFFFF, 0xFFFF, "GF106 [GeForce GTS 450](0x0DC4)"},
{0x10DE, 0x0DC5, 0xFFFF, 0xFFFF, "GF106 [GeForce GTS 450 OEM](0x0DC5)"},
{0x10DE, 0x0DC6, 0xFFFF, 0xFFFF, "GF106 [GeForce GTS 450 OEM](0x0DC6)"},
{0x10DE, 0x0DCD, 0xFFFF, 0xFFFF, "GF106M [GeForce GT 555M](0x0DCD)"},
{0x10DE, 0x0DCE, 0xFFFF, 0xFFFF, "GF106M [GeForce GT 555M](0x0DCE)"},
{0x10DE, 0x0DD1, 0xFFFF, 0xFFFF, "GF106M [GeForce GTX 460M](0x0DD1)"},
{0x10DE, 0x0DD1, 0x1558, 0x8687, "CLEVO/KAPOK W860CU(0x1558-0x8687)"},
{0x10DE, 0x0DD2, 0xFFFF, 0xFFFF, "GF106M [GeForce GT 445M](0x0DD2)"},
{0x10DE, 0x0DD3, 0xFFFF, 0xFFFF, "GF106M [GeForce GT 435M](0x0DD3)"},
{0x10DE, 0x0DD6, 0xFFFF, 0xFFFF, "GF106M [GeForce GT 550M](0x0DD6)"},
{0x10DE, 0x0DD8, 0xFFFF, 0xFFFF, "GF106GL [Quadro 2000](0x0DD8)"},
{0x10DE, 0x0DD8, 0x10DE, 0x0914, "Quadro 2000D(0x10DE-0x0914)"},
{0x10DE, 0x0DDA, 0xFFFF, 0xFFFF, "GF106GLM [Quadro 2000M](0x0DDA)"},
{0x10DE, 0x0DE0, 0xFFFF, 0xFFFF, "GF108 [GeForce GT 440](0x0DE0)"},
{0x10DE, 0x0DE1, 0xFFFF, 0xFFFF, "GF108 [GeForce GT 430](0x0DE1)"},
{0x10DE, 0x0DE1, 0x3842, 0x1430, "GeForce GT 430(0x3842-0x1430)"},
{0x10DE, 0x0DE2, 0xFFFF, 0xFFFF, "GF108 [GeForce GT 420](0x0DE2)"},
{0x10DE, 0x0DE3, 0xFFFF, 0xFFFF, "GF108M [GeForce GT 635M](0x0DE3)"},
{0x10DE, 0x0DE4, 0xFFFF, 0xFFFF, "GF108 [GeForce GT 520](0x0DE4)"},
{0x10DE, 0x0DE5, 0xFFFF, 0xFFFF, "GF108 [GeForce GT 530](0x0DE5)"},
{0x10DE, 0x0DE7, 0xFFFF, 0xFFFF, "GF108 [GeForce GT 610](0x0DE7)"},
{0x10DE, 0x0DE8, 0xFFFF, 0xFFFF, "GF108M [GeForce GT 620M](0x0DE8)"},
{0x10DE, 0x0DE9, 0xFFFF, 0xFFFF, "GF108M [GeForce GT 620M/630M/635M/640M LE](0x0DE9)"},
{0x10DE, 0x0DE9, 0x1025, 0x0692, "GeForce GT 620M(0x1025-0x0692)"},
{0x10DE, 0x0DE9, 0x1025, 0x0725, "GeForce GT 620M(0x1025-0x0725)"},
{0x10DE, 0x0DE9, 0x1025, 0x0728, "GeForce GT 620M(0x1025-0x0728)"},
{0x10DE, 0x0DE9, 0x1025, 0x072B, "GeForce GT 620M(0x1025-0x072B)"},
{0x10DE, 0x0DE9, 0x1025, 0x072E, "GeForce GT 620M(0x1025-0x072E)"},
{0x10DE, 0x0DE9, 0x1025, 0x0753, "GeForce GT 620M(0x1025-0x0753)"},
{0x10DE, 0x0DE9, 0x1025, 0x0754, "GeForce GT 620M(0x1025-0x0754)"},
{0x10DE, 0x0DE9, 0x17AA, 0x3977, "GeForce GT 640M LE(0x17AA-0x3977)"},
{0x10DE, 0x0DE9, 0x1B0A, 0x20C6, "GeForce GT 630M(0x1B0A-0x20C6)"},
{0x10DE, 0x0DE9, 0x1B0A, 0x2210, "GeForce GT 635M(0x1B0A-0x2210)"},
{0x10DE, 0x0DEA, 0xFFFF, 0xFFFF, "GF108M [GeForce 610M](0x0DEA)"},
{0x10DE, 0x0DEA, 0x17AA, 0x365A, "GeForce 615(0x17AA-0x365A)"},
{0x10DE, 0x0DEA, 0x17AA, 0x365B, "GeForce 615(0x17AA-0x365B)"},
{0x10DE, 0x0DEA, 0x17AA, 0x365E, "GeForce 615(0x17AA-0x365E)"},
{0x10DE, 0x0DEA, 0x17AA, 0x3660, "GeForce 615(0x17AA-0x3660)"},
{0x10DE, 0x0DEA, 0x17AA, 0x366C, "GeForce 615(0x17AA-0x366C)"},
{0x10DE, 0x0DEB, 0xFFFF, 0xFFFF, "GF108M [GeForce GT 555M](0x0DEB)"},
{0x10DE, 0x0DEC, 0xFFFF, 0xFFFF, "GF108M [GeForce GT 525M](0x0DEC)"},
{0x10DE, 0x0DED, 0xFFFF, 0xFFFF, "GF108M [GeForce GT 520M](0x0DED)"},
{0x10DE, 0x0DEE, 0xFFFF, 0xFFFF, "GF108M [GeForce GT 415M](0x0DEE)"},
{0x10DE, 0x0DEF, 0xFFFF, 0xFFFF, "GF108M [NVS 5400M](0x0DEF)"},
{0x10DE, 0x0DF0, 0xFFFF, 0xFFFF, "GF108M [GeForce GT 425M](0x0DF0)"},
{0x10DE, 0x0DF1, 0xFFFF, 0xFFFF, "GF108M [GeForce GT 420M](0x0DF1)"},
{0x10DE, 0x0DF2, 0xFFFF, 0xFFFF, "GF108M [GeForce GT 435M](0x0DF2)"},
{0x10DE, 0x0DF3, 0xFFFF, 0xFFFF, "GF108M [GeForce GT 420M](0x0DF3)"},
{0x10DE, 0x0DF4, 0xFFFF, 0xFFFF, "GF108M [GeForce GT 540M](0x0DF4)"},
{0x10DE, 0x0DF4, 0x152D, 0x0952, "GeForce GT 630M(0x152D-0x0952)"},
{0x10DE, 0x0DF4, 0x152D, 0x0953, "GeForce GT 630M(0x152D-0x0953)"},
{0x10DE, 0x0DF5, 0xFFFF, 0xFFFF, "GF108M [GeForce GT 525M](0x0DF5)"},
{0x10DE, 0x0DF6, 0xFFFF, 0xFFFF, "GF108M [GeForce GT 550M](0x0DF6)"},
{0x10DE, 0x0DF7, 0xFFFF, 0xFFFF, "GF108M [GeForce GT 520M](0x0DF7)"},
{0x10DE, 0x0DF8, 0xFFFF, 0xFFFF, "GF108GL [Quadro 600](0x0DF8)"},
{0x10DE, 0x0DF9, 0xFFFF, 0xFFFF, "GF108GLM [Quadro 500M](0x0DF9)"},
{0x10DE, 0x0DFA, 0xFFFF, 0xFFFF, "GF108GLM [Quadro 1000M](0x0DFA)"},
{0x10DE, 0x0DFC, 0xFFFF, 0xFFFF, "GF108GLM [NVS 5200M](0x0DFC)"},
{0x10DE, 0x0E08, 0xFFFF, 0xFFFF, "GF119 HDMI Audio Controller(0x0E08)"},
{0x10DE, 0x0E08, 0x1043, 0x83A0, "ENGT520 SILENT(0x1043-0x83A0)"},
{0x10DE, 0x0E08, 0x10B0, 0x104A, "Gainward GeForce GT 610(0x10B0-0x104A)"},
{0x10DE, 0x0E09, 0xFFFF, 0xFFFF, "GF110 High Definition Audio Controller(0x0E09)"},
{0x10DE, 0x0E0A, 0xFFFF, 0xFFFF, "GK104 HDMI Audio Controller(0x0E0A)"},
{0x10DE, 0x0E0B, 0xFFFF, 0xFFFF, "GK106 HDMI Audio Controller(0x0E0B)"},
{0x10DE, 0x0E0C, 0xFFFF, 0xFFFF, "GF114 HDMI Audio Controller(0x0E0C)"},
{0x10DE, 0x0E0F, 0xFFFF, 0xFFFF, "GK208 HDMI/DP Audio Controller(0x0E0F)"},
{0x10DE, 0x0E12, 0xFFFF, 0xFFFF, "TegraK1 PCIe x4 Bridge(0x0E12)"},
{0x10DE, 0x0E13, 0xFFFF, 0xFFFF, "TegraK1 PCIe x1 Bridge(0x0E13)"},
{0x10DE, 0x0E1A, 0xFFFF, 0xFFFF, "GK110 High Definition Audio Controller(0x0E1A)"},
{0x10DE, 0x0E1B, 0xFFFF, 0xFFFF, "GK107 HDMI Audio Controller(0x0E1B)"},
{0x10DE, 0x0E1B, 0x103C, 0x197B, "ZBook 15(0x103C-0x197B)"},
{0x10DE, 0x0E1B, 0x1043, 0x8428, "GTX650-DC-1GD5(0x1043-0x8428)"},
{0x10DE, 0x0E1C, 0xFFFF, 0xFFFF, "Tegra3+ PCIe x4 Bridge(0x0E1C)"},
{0x10DE, 0x0E1D, 0xFFFF, 0xFFFF, "Tegra3+ PCIe x2 Bridge(0x0E1D)"},
{0x10DE, 0x0E22, 0xFFFF, 0xFFFF, "GF104 [GeForce GTX 460](0x0E22)"},
{0x10DE, 0x0E22, 0x1462, 0x2322, "N460GTX Cyclone 1GD5/OC(0x1462-0x2322)"},
{0x10DE, 0x0E23, 0xFFFF, 0xFFFF, "GF104 [GeForce GTX 460 SE](0x0E23)"},
{0x10DE, 0x0E24, 0xFFFF, 0xFFFF, "GF104 [GeForce GTX 460 OEM](0x0E24)"},
{0x10DE, 0x0E30, 0xFFFF, 0xFFFF, "GF104M [GeForce GTX 470M](0x0E30)"},
{0x10DE, 0x0E31, 0xFFFF, 0xFFFF, "GF104M [GeForce GTX 485M](0x0E31)"},
{0x10DE, 0x0E3A, 0xFFFF, 0xFFFF, "GF104GLM [Quadro 3000M](0x0E3A)"},
{0x10DE, 0x0E3B, 0xFFFF, 0xFFFF, "GF104GLM [Quadro 4000M](0x0E3B)"},
{0x10DE, 0x0F00, 0xFFFF, 0xFFFF, "GF108 [GeForce GT 630](0x0F00)"},
{0x10DE, 0x0F01, 0xFFFF, 0xFFFF, "GF108 [GeForce GT 620](0x0F01)"},
{0x10DE, 0x0F02, 0xFFFF, 0xFFFF, "GF108 [GeForce GT 730](0x0F02)"},
{0x10DE, 0x0F03, 0xFFFF, 0xFFFF, "GF108 [GeForce GT 610](0x0F03)"},
{0x10DE, 0x0F06, 0xFFFF, 0xFFFF, "GF108 [GeForce GT 730](0x0F06)"},
{0x10DE, 0x0FA0, 0xFFFF, 0xFFFF, "GK11x [GK11x_FPGA](0x0FA0)"},
{0x10DE, 0x0FA5, 0xFFFF, 0xFFFF, "GK11x(0x0FA5)"},
{0x10DE, 0x0FA7, 0xFFFF, 0xFFFF, "GK11x [Tegra on x86 (PEATRANS)](0x0FA7)"},
{0x10DE, 0x0FB0, 0xFFFF, 0xFFFF, "GM200 High Definition Audio(0x0FB0)"},
{0x10DE, 0x0FB8, 0xFFFF, 0xFFFF, "GP108 High Definition Audio Controller(0x0FB8)"},
{0x10DE, 0x0FB9, 0xFFFF, 0xFFFF, "GP107GL High Definition Audio Controller(0x0FB9)"},
{0x10DE, 0x0FBA, 0xFFFF, 0xFFFF, "GM206 High Definition Audio Controller(0x0FBA)"},
{0x10DE, 0x0FBB, 0xFFFF, 0xFFFF, "GM204 High Definition Audio Controller(0x0FBB)"},
{0x10DE, 0x0FBC, 0xFFFF, 0xFFFF, "GM107 High Definition Audio Controller [GeForce 940MX](0x0FBC)"},
{0x10DE, 0x0FC0, 0xFFFF, 0xFFFF, "GK107 [GeForce GT 640 OEM](0x0FC0)"},
{0x10DE, 0x0FC1, 0xFFFF, 0xFFFF, "GK107 [GeForce GT 640](0x0FC1)"},
{0x10DE, 0x0FC2, 0xFFFF, 0xFFFF, "GK107 [GeForce GT 630 OEM](0x0FC2)"},
{0x10DE, 0x0FC4, 0xFFFF, 0xFFFF, "GK107 [D14P1-15](0x0FC4)"},
{0x10DE, 0x0FC5, 0xFFFF, 0xFFFF, "GK107 [GeForce GT 1030](0x0FC5)"},
{0x10DE, 0x0FC6, 0xFFFF, 0xFFFF, "GK107 [GeForce GTX 650](0x0FC6)"},
{0x10DE, 0x0FC6, 0x1043, 0x8428, "GTX650-DC-1GD5(0x1043-0x8428)"},
{0x10DE, 0x0FC8, 0xFFFF, 0xFFFF, "GK107 [GeForce GT 740](0x0FC8)"},
{0x10DE, 0x0FC9, 0xFFFF, 0xFFFF, "GK107 [GeForce GT 730](0x0FC9)"},
{0x10DE, 0x0FCB, 0xFFFF, 0xFFFF, "GK107 [EXK107](0x0FCB)"},
{0x10DE, 0x0FCC, 0xFFFF, 0xFFFF, "GK107 [GeForce GT 720](0x0FCC)"},
{0x10DE, 0x0FCD, 0xFFFF, 0xFFFF, "GK107M [GeForce GT 755M](0x0FCD)"},
{0x10DE, 0x0FCE, 0xFFFF, 0xFFFF, "GK107M [GeForce GT 640M LE](0x0FCE)"},
{0x10DE, 0x0FCF, 0xFFFF, 0xFFFF, "GK107 [GEN3 ESI](0x0FCF)"},
{0x10DE, 0x0FD0, 0xFFFF, 0xFFFF, "GK107 [NB1G](0x0FD0)"},
{0x10DE, 0x0FD1, 0xFFFF, 0xFFFF, "GK107M [GeForce GT 650M](0x0FD1)"},
{0x10DE, 0x0FD1, 0x1043, 0x1597, "GeForce GT 650M(0x1043-0x1597)"},
{0x10DE, 0x0FD1, 0x1043, 0x15A7, "GeForce GT 650M(0x1043-0x15A7)"},
{0x10DE, 0x0FD1, 0x1043, 0x2103, "N56VZ(0x1043-0x2103)"},
{0x10DE, 0x0FD1, 0x1043, 0x2105, "GeForce GT 650M(0x1043-0x2105)"},
{0x10DE, 0x0FD1, 0x1043, 0x2141, "GeForce GT 650M(0x1043-0x2141)"},
{0x10DE, 0x0FD2, 0xFFFF, 0xFFFF, "GK107M [GeForce GT 640M](0x0FD2)"},
{0x10DE, 0x0FD2, 0x1028, 0x054F, "GeForce GT 640M(0x1028-0x054F)"},
{0x10DE, 0x0FD2, 0x1028, 0x055F, "GeForce GT 640M(0x1028-0x055F)"},
{0x10DE, 0x0FD2, 0x1028, 0x0595, "GeForce GT 640M LE(0x1028-0x0595)"},
{0x10DE, 0x0FD2, 0x1028, 0x05B2, "GeForce GT 640M LE(0x1028-0x05B2)"},
{0x10DE, 0x0FD3, 0xFFFF, 0xFFFF, "GK107M [GeForce GT 640M LE](0x0FD3)"},
{0x10DE, 0x0FD4, 0xFFFF, 0xFFFF, "GK107M [GeForce GTX 660M](0x0FD4)"},
{0x10DE, 0x0FD5, 0xFFFF, 0xFFFF, "GK107M [GeForce GT 650M Mac Edition](0x0FD5)"},
{0x10DE, 0x0FD6, 0xFFFF, 0xFFFF, "GK107M [N13P-GS-W](0x0FD6)"},
{0x10DE, 0x0FD7, 0xFFFF, 0xFFFF, "GK107 [GK107-GTX](0x0FD7)"},
{0x10DE, 0x0FD8, 0xFFFF, 0xFFFF, "GK107M [GeForce GT 640M Mac Edition](0x0FD8)"},
{0x10DE, 0x0FD9, 0xFFFF, 0xFFFF, "GK107M [GeForce GT 645M](0x0FD9)"},
{0x10DE, 0x0FDA, 0xFFFF, 0xFFFF, "GK107 [GK107-ES-A1](0x0FDA)"},
{0x10DE, 0x0FDB, 0xFFFF, 0xFFFF, "GK107 [GK107-ESP-A1](0x0FDB)"},
{0x10DE, 0x0FDC, 0xFFFF, 0xFFFF, "GK107 [GK107-INT22-A1](0x0FDC)"},
{0x10DE, 0x0FDD, 0xFFFF, 0xFFFF, "GK107 [GK107-INT11-A1](0x0FDD)"},
{0x10DE, 0x0FDE, 0xFFFF, 0xFFFF, "GK107 [GK107-ES-KA-E1](0x0FDE)"},
{0x10DE, 0x0FDF, 0xFFFF, 0xFFFF, "GK107M [GeForce GT 740M](0x0FDF)"},
{0x10DE, 0x0FE0, 0xFFFF, 0xFFFF, "GK107M [GeForce GTX 660M Mac Edition](0x0FE0)"},
{0x10DE, 0x0FE1, 0xFFFF, 0xFFFF, "GK107M [GeForce GT 730M](0x0FE1)"},
{0x10DE, 0x0FE2, 0xFFFF, 0xFFFF, "GK107M [GeForce GT 745M](0x0FE2)"},
{0x10DE, 0x0FE3, 0xFFFF, 0xFFFF, "GK107M [GeForce GT 745M](0x0FE3)"},
{0x10DE, 0x0FE3, 0x103C, 0x2B16, "GeForce GT 745A(0x103C-0x2B16)"},
{0x10DE, 0x0FE3, 0x17AA, 0x3675, "GeForce GT 745A(0x17AA-0x3675)"},
{0x10DE, 0x0FE4, 0xFFFF, 0xFFFF, "GK107M [GeForce GT 750M](0x0FE4)"},
{0x10DE, 0x0FE5, 0xFFFF, 0xFFFF, "GK107 [GeForce K340 USM](0x0FE5)"},
{0x10DE, 0x0FE6, 0xFFFF, 0xFFFF, "GK107 [GRID K1 NVS USM](0x0FE6)"},
{0x10DE, 0x0FE7, 0xFFFF, 0xFFFF, "GK107GL [GRID K100 vGPU](0x0FE7)"},
{0x10DE, 0x0FE7, 0x10DE, 0x101E, "GRID K100(0x10DE-0x101E)"},
{0x10DE, 0x0FE8, 0xFFFF, 0xFFFF, "GK107M [N14P-GS](0x0FE8)"},
{0x10DE, 0x0FE9, 0xFFFF, 0xFFFF, "GK107M [GeForce GT 750M Mac Edition](0x0FE9)"},
{0x10DE, 0x0FEA, 0xFFFF, 0xFFFF, "GK107M [GeForce GT 755M Mac Edition](0x0FEA)"},
{0x10DE, 0x0FEC, 0xFFFF, 0xFFFF, "GK107M [GeForce 710A](0x0FEC)"},
{0x10DE, 0x0FED, 0xFFFF, 0xFFFF, "GK107M [GeForce 820M](0x0FED)"},
{0x10DE, 0x0FEE, 0xFFFF, 0xFFFF, "GK107M [GeForce 810M](0x0FEE)"},
{0x10DE, 0x0FEF, 0xFFFF, 0xFFFF, "GK107GL [GRID K340](0x0FEF)"},
{0x10DE, 0x0FF0, 0xFFFF, 0xFFFF, "GK107 [NB1Q](0x0FF0)"},
{0x10DE, 0x0FF1, 0xFFFF, 0xFFFF, "GK107 [NVS 1000](0x0FF1)"},
{0x10DE, 0x0FF2, 0xFFFF, 0xFFFF, "GK107GL [GRID K1](0x0FF2)"},
{0x10DE, 0x0FF3, 0xFFFF, 0xFFFF, "GK107GL [Quadro K420](0x0FF3)"},
{0x10DE, 0x0FF5, 0xFFFF, 0xFFFF, "GK107GL [GRID K1 Tesla USM](0x0FF5)"},
{0x10DE, 0x0FF6, 0xFFFF, 0xFFFF, "GK107GLM [Quadro K1100M](0x0FF6)"},
{0x10DE, 0x0FF6, 0x103C, 0x197B, "ZBook 15(0x103C-0x197B)"},
{0x10DE, 0x0FF7, 0xFFFF, 0xFFFF, "GK107GL [GRID K140Q vGPU](0x0FF7)"},
{0x10DE, 0x0FF7, 0x10DE, 0x1037, "GRID K140Q(0x10DE-0x1037)"},
{0x10DE, 0x0FF8, 0xFFFF, 0xFFFF, "GK107GLM [Quadro K500M](0x0FF8)"},
{0x10DE, 0x0FF9, 0xFFFF, 0xFFFF, "GK107GL [Quadro K2000D](0x0FF9)"},
{0x10DE, 0x0FFA, 0xFFFF, 0xFFFF, "GK107GL [Quadro K600](0x0FFA)"},
{0x10DE, 0x0FFB, 0xFFFF, 0xFFFF, "GK107GLM [Quadro K2000M](0x0FFB)"},
{0x10DE, 0x0FFC, 0xFFFF, 0xFFFF, "GK107GLM [Quadro K1000M](0x0FFC)"},
{0x10DE, 0x0FFD, 0xFFFF, 0xFFFF, "GK107 [NVS 510](0x0FFD)"},
{0x10DE, 0x0FFE, 0xFFFF, 0xFFFF, "GK107GL [Quadro K2000](0x0FFE)"},
{0x10DE, 0x0FFF, 0xFFFF, 0xFFFF, "GK107GL [Quadro 410](0x0FFF)"},
{0x10DE, 0x1001, 0xFFFF, 0xFFFF, "GK110B [GeForce GTX TITAN Z](0x1001)"},
{0x10DE, 0x1003, 0xFFFF, 0xFFFF, "GK110 [GeForce GTX Titan LE](0x1003)"},
{0x10DE, 0x1004, 0xFFFF, 0xFFFF, "GK110 [GeForce GTX 780](0x1004)"},
{0x10DE, 0x1004, 0x3842, 0x0784, "GK110B [GeForce GTX 780 SC w/ ACX Cooler](0x3842-0x0784)"},
{0x10DE, 0x1004, 0x3842, 0x1784, "GK110B [GeForce GTX 780 Dual FTW w/ ACX Cooler](0x3842-0x1784)"},
{0x10DE, 0x1004, 0x3842, 0x1788, "GK110B [GeForce GTX 780 Dual Classified w/ ACX Cooler](0x3842-0x1788)"},
{0x10DE, 0x1005, 0xFFFF, 0xFFFF, "GK110 [GeForce GTX TITAN](0x1005)"},
{0x10DE, 0x1005, 0x1043, 0x8451, "GTXTITAN-6GD5(0x1043-0x8451)"},
{0x10DE, 0x1005, 0x10DE, 0x1035, "GeForce GTX Titan(0x10DE-0x1035)"},
{0x10DE, 0x1005, 0x3842, 0x2790, "GeForce GTX Titan(0x3842-0x2790)"},
{0x10DE, 0x1005, 0x3842, 0x2791, "GeForce GTX Titan SC(0x3842-0x2791)"},
{0x10DE, 0x1005, 0x3842, 0x2793, "GeForce GTX Titan SC Signature(0x3842-0x2793)"},
{0x10DE, 0x1005, 0x3842, 0x2794, "GeForce GTX Titan SC Hydro Copper(0x3842-0x2794)"},
{0x10DE, 0x1005, 0x3842, 0x2795, "GeForce GTX Titan SC Hydro Copper Signature(0x3842-0x2795)"},
{0x10DE, 0x1007, 0xFFFF, 0xFFFF, "GK110 [GeForce GTX 780 Rev. 2](0x1007)"},
{0x10DE, 0x1008, 0xFFFF, 0xFFFF, "GK110 [GeForce GTX 780 Ti 6GB](0x1008)"},
{0x10DE, 0x100A, 0xFFFF, 0xFFFF, "GK110B [GeForce GTX 780 Ti](0x100A)"},
{0x10DE, 0x100C, 0xFFFF, 0xFFFF, "GK110B [GeForce GTX TITAN Black](0x100C)"},
{0x10DE, 0x101E, 0xFFFF, 0xFFFF, "GK110GL [Tesla K20X](0x101E)"},
{0x10DE, 0x101F, 0xFFFF, 0xFFFF, "GK110GL [Tesla K20](0x101F)"},
{0x10DE, 0x1020, 0xFFFF, 0xFFFF, "GK110GL [Tesla K20X](0x1020)"},
{0x10DE, 0x1021, 0xFFFF, 0xFFFF, "GK110GL [Tesla K20Xm](0x1021)"},
{0x10DE, 0x1022, 0xFFFF, 0xFFFF, "GK110GL [Tesla K20c](0x1022)"},
{0x10DE, 0x1023, 0xFFFF, 0xFFFF, "GK110BGL [Tesla K40m](0x1023)"},
{0x10DE, 0x1023, 0x10DE, 0x097E, "12GB Computational Accelerator(0x10DE-0x097E)"},
{0x10DE, 0x1024, 0xFFFF, 0xFFFF, "GK180GL [Tesla K40c](0x1024)"},
{0x10DE, 0x1026, 0xFFFF, 0xFFFF, "GK110GL [Tesla K20s](0x1026)"},
{0x10DE, 0x1027, 0xFFFF, 0xFFFF, "GK110BGL [Tesla K40st](0x1027)"},
{0x10DE, 0x1028, 0xFFFF, 0xFFFF, "GK110GL [Tesla K20m](0x1028)"},
{0x10DE, 0x1029, 0xFFFF, 0xFFFF, "GK110BGL [Tesla K40s](0x1029)"},
{0x10DE, 0x102A, 0xFFFF, 0xFFFF, "GK110BGL [Tesla K40t](0x102A)"},
{0x10DE, 0x102D, 0xFFFF, 0xFFFF, "GK210GL [Tesla K80](0x102D)"},
{0x10DE, 0x102E, 0xFFFF, 0xFFFF, "GK110BGL [Tesla K40d](0x102E)"},
{0x10DE, 0x102F, 0xFFFF, 0xFFFF, "GK110BGL [Tesla Stella Solo](0x102F)"},
{0x10DE, 0x103A, 0xFFFF, 0xFFFF, "GK110GL [Quadro K6000](0x103A)"},
{0x10DE, 0x103C, 0xFFFF, 0xFFFF, "GK110GL [Quadro K5200](0x103C)"},
{0x10DE, 0x103F, 0xFFFF, 0xFFFF, "GK110BGL [Tesla Stella SXM](0x103F)"},
{0x10DE, 0x1040, 0xFFFF, 0xFFFF, "GF119 [GeForce GT 520](0x1040)"},
{0x10DE, 0x1040, 0x1043, 0x83A0, "ENGT520 SILENT(0x1043-0x83A0)"},
{0x10DE, 0x1042, 0xFFFF, 0xFFFF, "GF119 [GeForce 510](0x1042)"},
{0x10DE, 0x1045, 0xFFFF, 0xFFFF, "GF119(0x1045)"},
{0x10DE, 0x1048, 0xFFFF, 0xFFFF, "GF119 [GeForce 605](0x1048)"},
{0x10DE, 0x1049, 0xFFFF, 0xFFFF, "GF119 [GeForce GT 620 OEM](0x1049)"},
{0x10DE, 0x104A, 0xFFFF, 0xFFFF, "GF119 [GeForce GT 610](0x104A)"},
{0x10DE, 0x104A, 0x10B0, 0x104A, "Gainward GeForce GT 610(0x10B0-0x104A)"},
{0x10DE, 0x104B, 0xFFFF, 0xFFFF, "GF119 [GeForce GT 625 OEM](0x104B)"},
{0x10DE, 0x104C, 0xFFFF, 0xFFFF, "GF119 [GeForce GT 705](0x104C)"},
{0x10DE, 0x104D, 0xFFFF, 0xFFFF, "GF119 [GeForce GT 710](0x104D)"},
{0x10DE, 0x1050, 0xFFFF, 0xFFFF, "GF119M [GeForce GT 520M](0x1050)"},
{0x10DE, 0x1051, 0xFFFF, 0xFFFF, "GF119M [GeForce GT 520MX](0x1051)"},
{0x10DE, 0x1052, 0xFFFF, 0xFFFF, "GF119M [GeForce GT 520M](0x1052)"},
{0x10DE, 0x1054, 0xFFFF, 0xFFFF, "GF119M [GeForce 410M](0x1054)"},
{0x10DE, 0x1055, 0xFFFF, 0xFFFF, "GF119M [GeForce 410M](0x1055)"},
{0x10DE, 0x1056, 0xFFFF, 0xFFFF, "GF119M [NVS 4200M](0x1056)"},
{0x10DE, 0x1057, 0xFFFF, 0xFFFF, "GF119M [Quadro NVS 4200M](0x1057)"},
{0x10DE, 0x1058, 0xFFFF, 0xFFFF, "GF119M [GeForce 610M](0x1058)"},
{0x10DE, 0x1058, 0x103C, 0x2AED, "GeForce 610(0x103C-0x2AED)"},
{0x10DE, 0x1058, 0x103C, 0x2AF1, "GeForce 610(0x103C-0x2AF1)"},
{0x10DE, 0x1058, 0x1043, 0x10AC, "GeForce GT 610M(0x1043-0x10AC)"},
{0x10DE, 0x1058, 0x1043, 0x10BC, "GeForce GT 610M(0x1043-0x10BC)"},
{0x10DE, 0x1058, 0x1043, 0x1652, "GeForce GT 610M(0x1043-0x1652)"},
{0x10DE, 0x1058, 0x17AA, 0x367A, "GeForce 610M(0x17AA-0x367A)"},
{0x10DE, 0x1058, 0x17AA, 0x3682, "GeForce 800A(0x17AA-0x3682)"},
{0x10DE, 0x1058, 0x17AA, 0x3687, "GeForce 800A(0x17AA-0x3687)"},
{0x10DE, 0x1058, 0x17AA, 0x3692, "GeForce 705A(0x17AA-0x3692)"},
{0x10DE, 0x1058, 0x17AA, 0x3695, "GeForce 800A(0x17AA-0x3695)"},
{0x10DE, 0x1058, 0x17AA, 0xA117, "GeForce 610M(0x17AA-0xA117)"},
{0x10DE, 0x1059, 0xFFFF, 0xFFFF, "GF119M [GeForce 610M](0x1059)"},
{0x10DE, 0x105A, 0xFFFF, 0xFFFF, "GF119M [GeForce 610M](0x105A)"},
{0x10DE, 0x105A, 0x1043, 0x2111, "GeForce GT 610M(0x1043-0x2111)"},
{0x10DE, 0x105A, 0x1043, 0x2112, "GeForce GT 610M(0x1043-0x2112)"},
{0x10DE, 0x105B, 0xFFFF, 0xFFFF, "GF119M [GeForce 705M](0x105B)"},
{0x10DE, 0x105B, 0x103C, 0x2AFB, "GeForce 705A(0x103C-0x2AFB)"},
{0x10DE, 0x105B, 0x17AA, 0x309D, "GeForce 705A(0x17AA-0x309D)"},
{0x10DE, 0x105B, 0x17AA, 0x30B1, "GeForce 800A(0x17AA-0x30B1)"},
{0x10DE, 0x105B, 0x17AA, 0x30F3, "GeForce 705A(0x17AA-0x30F3)"},
{0x10DE, 0x105B, 0x17AA, 0x36A1, "GeForce 800A(0x17AA-0x36A1)"},
{0x10DE, 0x107C, 0xFFFF, 0xFFFF, "GF119 [NVS 315](0x107C)"},
{0x10DE, 0x107D, 0xFFFF, 0xFFFF, "GF119 [NVS 310](0x107D)"},
{0x10DE, 0x1080, 0xFFFF, 0xFFFF, "GF110 [GeForce GTX 580](0x1080)"},
{0x10DE, 0x1081, 0xFFFF, 0xFFFF, "GF110 [GeForce GTX 570](0x1081)"},
{0x10DE, 0x1081, 0x10DE, 0x087E, "Leadtek WinFast GTX 570(0x10DE-0x087E)"},
{0x10DE, 0x1082, 0xFFFF, 0xFFFF, "GF110 [GeForce GTX 560 Ti OEM](0x1082)"},
{0x10DE, 0x1084, 0xFFFF, 0xFFFF, "GF110 [GeForce GTX 560 OEM](0x1084)"},
{0x10DE, 0x1086, 0xFFFF, 0xFFFF, "GF110 [GeForce GTX 570 Rev. 2](0x1086)"},
{0x10DE, 0x1087, 0xFFFF, 0xFFFF, "GF110 [GeForce GTX 560 Ti 448 Cores](0x1087)"},
{0x10DE, 0x1088, 0xFFFF, 0xFFFF, "GF110 [GeForce GTX 590](0x1088)"},
{0x10DE, 0x1089, 0xFFFF, 0xFFFF, "GF110 [GeForce GTX 580 Rev. 2](0x1089)"},
{0x10DE, 0x108B, 0xFFFF, 0xFFFF, "GF110 [GeForce GTX 580](0x108B)"},
{0x10DE, 0x108E, 0xFFFF, 0xFFFF, "GF110GL [Tesla C2090](0x108E)"},
{0x10DE, 0x1091, 0xFFFF, 0xFFFF, "GF110GL [Tesla M2090](0x1091)"},
{0x10DE, 0x1091, 0x10DE, 0x088E, "Tesla X2090(0x10DE-0x088E)"},
{0x10DE, 0x1091, 0x10DE, 0x0891, "Tesla X2090(0x10DE-0x0891)"},
{0x10DE, 0x1091, 0x10DE, 0x0974, "Tesla X2090(0x10DE-0x0974)"},
{0x10DE, 0x1091, 0x10DE, 0x098D, "Tesla X2090(0x10DE-0x098D)"},
{0x10DE, 0x1094, 0xFFFF, 0xFFFF, "GF110GL [Tesla M2075](0x1094)"},
{0x10DE, 0x1094, 0x10DE, 0x0888, "Tesla M2075(0x10DE-0x0888)"},
{0x10DE, 0x1096, 0xFFFF, 0xFFFF, "GF110GL [Tesla C2050 / C2075](0x1096)"},
{0x10DE, 0x1096, 0x10DE, 0x0910, "Tesla C2075(0x10DE-0x0910)"},
{0x10DE, 0x1096, 0x10DE, 0x0911, "Tesla C2050(0x10DE-0x0911)"},
{0x10DE, 0x109A, 0xFFFF, 0xFFFF, "GF100GLM [Quadro 5010M](0x109A)"},
{0x10DE, 0x109B, 0xFFFF, 0xFFFF, "GF100GL [Quadro 7000](0x109B)"},
{0x10DE, 0x109B, 0x10DE, 0x0918, "Quadro 7000(0x10DE-0x0918)"},
{0x10DE, 0x10C0, 0xFFFF, 0xFFFF, "GT218 [GeForce 9300 GS Rev. 2](0x10C0)"},
{0x10DE, 0x10C3, 0xFFFF, 0xFFFF, "GT218 [GeForce 8400 GS Rev. 3](0x10C3)"},
{0x10DE, 0x10C5, 0xFFFF, 0xFFFF, "GT218 [GeForce 405](0x10C5)"},
{0x10DE, 0x10D8, 0xFFFF, 0xFFFF, "GT218 [NVS 300](0x10D8)"},
{0x10DE, 0x10EF, 0xFFFF, 0xFFFF, "GP102 HDMI Audio Controller(0x10EF)"},
{0x10DE, 0x10F0, 0xFFFF, 0xFFFF, "GP104 High Definition Audio Controller(0x10F0)"},
{0x10DE, 0x10F1, 0xFFFF, 0xFFFF, "GP106 High Definition Audio Controller(0x10F1)"},
{0x10DE, 0x10F1, 0x1043, 0x85B6, "DUAL-GTX1060-O6G [GeForce GTX 1060 6GB Dual](0x1043-0x85B6)"},
{0x10DE, 0x10F7, 0xFFFF, 0xFFFF, "TU102 High Definition Audio Controller(0x10F7)"},
{0x10DE, 0x10F8, 0xFFFF, 0xFFFF, "TU104 HD Audio Controller(0x10F8)"},
{0x10DE, 0x10F9, 0xFFFF, 0xFFFF, "TU106 High Definition Audio Controller(0x10F9)"},
{0x10DE, 0x10F9, 0x1043, 0x8673, "TURBO-RTX2070-8G(0x1043-0x8673)"},
{0x10DE, 0x1140, 0xFFFF, 0xFFFF, "GF117M [GeForce 610M/710M/810M/820M / GT 620M/625M/630M/720M](0x1140)"},
{0x10DE, 0x1140, 0x1019, 0x0799, "GeForce 820M(0x1019-0x0799)"},
{0x10DE, 0x1140, 0x1019, 0x999F, "GeForce GT 720M(0x1019-0x999F)"},
{0x10DE, 0x1140, 0x1025, 0x0600, "GeForce GT 620M(0x1025-0x0600)"},
{0x10DE, 0x1140, 0x1025, 0x0606, "GeForce GT 620M(0x1025-0x0606)"},
{0x10DE, 0x1140, 0x1025, 0x064A, "GeForce GT 620M(0x1025-0x064A)"},
{0x10DE, 0x1140, 0x1025, 0x064C, "GeForce GT 620M(0x1025-0x064C)"},
{0x10DE, 0x1140, 0x1025, 0x067A, "GeForce GT 620M(0x1025-0x067A)"},
{0x10DE, 0x1140, 0x1025, 0x0680, "GeForce GT 620M(0x1025-0x0680)"},
{0x10DE, 0x1140, 0x1025, 0x0686, "GeForce 710M(0x1025-0x0686)"},
{0x10DE, 0x1140, 0x1025, 0x0689, "GeForce 710M(0x1025-0x0689)"},
{0x10DE, 0x1140, 0x1025, 0x068B, "GeForce 710M(0x1025-0x068B)"},
{0x10DE, 0x1140, 0x1025, 0x068D, "GeForce 710M(0x1025-0x068D)"},
{0x10DE, 0x1140, 0x1025, 0x068E, "GeForce 710M(0x1025-0x068E)"},
{0x10DE, 0x1140, 0x1025, 0x0691, "GeForce 710M(0x1025-0x0691)"},
{0x10DE, 0x1140, 0x1025, 0x0692, "GeForce GT 620M(0x1025-0x0692)"},
{0x10DE, 0x1140, 0x1025, 0x0694, "GeForce GT 620M(0x1025-0x0694)"},
{0x10DE, 0x1140, 0x1025, 0x0702, "GeForce GT 620M(0x1025-0x0702)"},
{0x10DE, 0x1140, 0x1025, 0x0719, "GeForce GT 620M(0x1025-0x0719)"},
{0x10DE, 0x1140, 0x1025, 0x0725, "GeForce GT 620M(0x1025-0x0725)"},
{0x10DE, 0x1140, 0x1025, 0x0728, "GeForce GT 620M(0x1025-0x0728)"},
{0x10DE, 0x1140, 0x1025, 0x072B, "GeForce GT 620M(0x1025-0x072B)"},
{0x10DE, 0x1140, 0x1025, 0x072E, "GeForce GT 620M(0x1025-0x072E)"},
{0x10DE, 0x1140, 0x1025, 0x0732, "GeForce GT 620M(0x1025-0x0732)"},
{0x10DE, 0x1140, 0x1025, 0x0763, "GeForce GT 720M(0x1025-0x0763)"},
{0x10DE, 0x1140, 0x1025, 0x0773, "GeForce 710M(0x1025-0x0773)"},
{0x10DE, 0x1140, 0x1025, 0x0774, "GeForce 710M(0x1025-0x0774)"},
{0x10DE, 0x1140, 0x1025, 0x0776, "GeForce GT 720M(0x1025-0x0776)"},
{0x10DE, 0x1140, 0x1025, 0x077A, "GeForce 710M(0x1025-0x077A)"},
{0x10DE, 0x1140, 0x1025, 0x077B, "GeForce 710M(0x1025-0x077B)"},
{0x10DE, 0x1140, 0x1025, 0x077C, "GeForce 710M(0x1025-0x077C)"},
{0x10DE, 0x1140, 0x1025, 0x077D, "GeForce 710M(0x1025-0x077D)"},
{0x10DE, 0x1140, 0x1025, 0x077E, "GeForce 710M(0x1025-0x077E)"},
{0x10DE, 0x1140, 0x1025, 0x077F, "GeForce 710M(0x1025-0x077F)"},
{0x10DE, 0x1140, 0x1025, 0x0781, "GeForce GT 720M(0x1025-0x0781)"},
{0x10DE, 0x1140, 0x1025, 0x0798, "GeForce GT 720M(0x1025-0x0798)"},
{0x10DE, 0x1140, 0x1025, 0x0799, "GeForce GT 720M(0x1025-0x0799)"},
{0x10DE, 0x1140, 0x1025, 0x079B, "GeForce GT 720M(0x1025-0x079B)"},
{0x10DE, 0x1140, 0x1025, 0x079C, "GeForce GT 720M(0x1025-0x079C)"},
{0x10DE, 0x1140, 0x1025, 0x0807, "GeForce GT 720M(0x1025-0x0807)"},
{0x10DE, 0x1140, 0x1025, 0x0821, "GeForce GT 720M(0x1025-0x0821)"},
{0x10DE, 0x1140, 0x1025, 0x0823, "GeForce GT 720M(0x1025-0x0823)"},
{0x10DE, 0x1140, 0x1025, 0x0830, "GeForce GT 720M(0x1025-0x0830)"},
{0x10DE, 0x1140, 0x1025, 0x0833, "GeForce GT 720M(0x1025-0x0833)"},
{0x10DE, 0x1140, 0x1025, 0x0837, "GeForce GT 720M(0x1025-0x0837)"},
{0x10DE, 0x1140, 0x1025, 0x083E, "GeForce 820M(0x1025-0x083E)"},
{0x10DE, 0x1140, 0x1025, 0x0841, "GeForce 710M(0x1025-0x0841)"},
{0x10DE, 0x1140, 0x1025, 0x0854, "GeForce 820M(0x1025-0x0854)"},
{0x10DE, 0x1140, 0x1025, 0x0855, "GeForce 820M(0x1025-0x0855)"},
{0x10DE, 0x1140, 0x1025, 0x0856, "GeForce 820M(0x1025-0x0856)"},
{0x10DE, 0x1140, 0x1025, 0x0857, "GeForce 820M(0x1025-0x0857)"},
{0x10DE, 0x1140, 0x1025, 0x0858, "GeForce 820M(0x1025-0x0858)"},
{0x10DE, 0x1140, 0x1025, 0x0863, "GeForce 820M(0x1025-0x0863)"},
{0x10DE, 0x1140, 0x1025, 0x0868, "GeForce 820M(0x1025-0x0868)"},
{0x10DE, 0x1140, 0x1025, 0x0869, "GeForce 810M(0x1025-0x0869)"},
{0x10DE, 0x1140, 0x1025, 0x0873, "GeForce 820M(0x1025-0x0873)"},
{0x10DE, 0x1140, 0x1025, 0x0878, "GeForce 820M(0x1025-0x0878)"},
{0x10DE, 0x1140, 0x1025, 0x087B, "GeForce 820M(0x1025-0x087B)"},
{0x10DE, 0x1140, 0x1025, 0x087C, "GeForce 810M(0x1025-0x087C)"},
{0x10DE, 0x1140, 0x1025, 0x0881, "GeForce 820M(0x1025-0x0881)"},
{0x10DE, 0x1140, 0x1025, 0x088A, "GeForce 820M(0x1025-0x088A)"},
{0x10DE, 0x1140, 0x1025, 0x089B, "GeForce 820M(0x1025-0x089B)"},
{0x10DE, 0x1140, 0x1025, 0x090F, "GeForce 820M(0x1025-0x090F)"},
{0x10DE, 0x1140, 0x1025, 0x0921, "GeForce 820M(0x1025-0x0921)"},
{0x10DE, 0x1140, 0x1025, 0x092E, "GeForce 810M(0x1025-0x092E)"},
{0x10DE, 0x1140, 0x1025, 0x092F, "GeForce 820M(0x1025-0x092F)"},
{0x10DE, 0x1140, 0x1025, 0x0932, "GeForce 820M(0x1025-0x0932)"},
{0x10DE, 0x1140, 0x1025, 0x093A, "GeForce 820M(0x1025-0x093A)"},
{0x10DE, 0x1140, 0x1025, 0x093C, "GeForce 820M(0x1025-0x093C)"},
{0x10DE, 0x1140, 0x1025, 0x093F, "GeForce 820M(0x1025-0x093F)"},
{0x10DE, 0x1140, 0x1025, 0x0941, "GeForce 820M(0x1025-0x0941)"},
{0x10DE, 0x1140, 0x1025, 0x0945, "GeForce 820M(0x1025-0x0945)"},
{0x10DE, 0x1140, 0x1025, 0x0954, "GeForce 820M(0x1025-0x0954)"},
{0x10DE, 0x1140, 0x1025, 0x0965, "GeForce 820M(0x1025-0x0965)"},
{0x10DE, 0x1140, 0x1028, 0x054D, "GeForce GT 630M(0x1028-0x054D)"},
{0x10DE, 0x1140, 0x1028, 0x054E, "GeForce GT 630M(0x1028-0x054E)"},
{0x10DE, 0x1140, 0x1028, 0x0554, "GeForce GT 620M(0x1028-0x0554)"},
{0x10DE, 0x1140, 0x1028, 0x0557, "GeForce GT 620M(0x1028-0x0557)"},
{0x10DE, 0x1140, 0x1028, 0x0562, "GeForce GT 625M(0x1028-0x0562)"},
{0x10DE, 0x1140, 0x1028, 0x0565, "GeForce GT 630M(0x1028-0x0565)"},
{0x10DE, 0x1140, 0x1028, 0x0568, "GeForce GT 630M(0x1028-0x0568)"},
{0x10DE, 0x1140, 0x1028, 0x0590, "GeForce GT 630M(0x1028-0x0590)"},
{0x10DE, 0x1140, 0x1028, 0x0592, "GeForce GT 625M(0x1028-0x0592)"},
{0x10DE, 0x1140, 0x1028, 0x0594, "GeForce GT 625M(0x1028-0x0594)"},
{0x10DE, 0x1140, 0x1028, 0x0595, "GeForce GT 625M(0x1028-0x0595)"},
{0x10DE, 0x1140, 0x1028, 0x05A2, "GeForce GT 625M(0x1028-0x05A2)"},
{0x10DE, 0x1140, 0x1028, 0x05B1, "GeForce GT 625M(0x1028-0x05B1)"},
{0x10DE, 0x1140, 0x1028, 0x05B3, "GeForce GT 625M(0x1028-0x05B3)"},
{0x10DE, 0x1140, 0x1028, 0x05DA, "GeForce GT 630M(0x1028-0x05DA)"},
{0x10DE, 0x1140, 0x1028, 0x05DE, "GeForce GT 720M(0x1028-0x05DE)"},
{0x10DE, 0x1140, 0x1028, 0x05E0, "GeForce GT 720M(0x1028-0x05E0)"},
{0x10DE, 0x1140, 0x1028, 0x05E8, "GeForce GT 630M(0x1028-0x05E8)"},
{0x10DE, 0x1140, 0x1028, 0x05F4, "GeForce GT 720M(0x1028-0x05F4)"},
{0x10DE, 0x1140, 0x1028, 0x060F, "GeForce GT 720M(0x1028-0x060F)"},
{0x10DE, 0x1140, 0x1028, 0x064E, "GeForce 820M(0x1028-0x064E)"},
{0x10DE, 0x1140, 0x1028, 0x0652, "GeForce 820M(0x1028-0x0652)"},
{0x10DE, 0x1140, 0x1028, 0x0653, "GeForce 820M(0x1028-0x0653)"},
{0x10DE, 0x1140, 0x1028, 0x0655, "GeForce 820M(0x1028-0x0655)"},
{0x10DE, 0x1140, 0x1028, 0x065E, "GeForce 820M(0x1028-0x065E)"},
{0x10DE, 0x1140, 0x1028, 0x0662, "GeForce 820M(0x1028-0x0662)"},
{0x10DE, 0x1140, 0x1028, 0x068D, "GeForce 820M(0x1028-0x068D)"},
{0x10DE, 0x1140, 0x1028, 0x06AD, "GeForce 820M(0x1028-0x06AD)"},
{0x10DE, 0x1140, 0x1028, 0x06AE, "GeForce 820M(0x1028-0x06AE)"},
{0x10DE, 0x1140, 0x1028, 0x06AF, "GeForce 820M(0x1028-0x06AF)"},
{0x10DE, 0x1140, 0x1028, 0x06B0, "GeForce 820M(0x1028-0x06B0)"},
{0x10DE, 0x1140, 0x1028, 0x06C0, "GeForce 820M(0x1028-0x06C0)"},
{0x10DE, 0x1140, 0x1028, 0x06C1, "GeForce 820M(0x1028-0x06C1)"},
{0x10DE, 0x1140, 0x103C, 0x18EF, "GeForce GT 630M(0x103C-0x18EF)"},
{0x10DE, 0x1140, 0x103C, 0x18F9, "GeForce GT 630M(0x103C-0x18F9)"},
{0x10DE, 0x1140, 0x103C, 0x18FB, "GeForce GT 630M(0x103C-0x18FB)"},
{0x10DE, 0x1140, 0x103C, 0x18FD, "GeForce GT 630M(0x103C-0x18FD)"},
{0x10DE, 0x1140, 0x103C, 0x18FF, "GeForce GT 630M(0x103C-0x18FF)"},
{0x10DE, 0x1140, 0x103C, 0x218A, "GeForce 820M(0x103C-0x218A)"},
{0x10DE, 0x1140, 0x103C, 0x21BB, "GeForce 820M(0x103C-0x21BB)"},
{0x10DE, 0x1140, 0x103C, 0x21BC, "GeForce 820M(0x103C-0x21BC)"},
{0x10DE, 0x1140, 0x103C, 0x220E, "GeForce 820M(0x103C-0x220E)"},
{0x10DE, 0x1140, 0x103C, 0x2210, "GeForce 820M(0x103C-0x2210)"},
{0x10DE, 0x1140, 0x103C, 0x2212, "GeForce 820M(0x103C-0x2212)"},
{0x10DE, 0x1140, 0x103C, 0x2214, "GeForce 820M(0x103C-0x2214)"},
{0x10DE, 0x1140, 0x103C, 0x2218, "GeForce 820M(0x103C-0x2218)"},
{0x10DE, 0x1140, 0x103C, 0x225B, "GeForce 820M(0x103C-0x225B)"},
{0x10DE, 0x1140, 0x103C, 0x225D, "GeForce 820M(0x103C-0x225D)"},
{0x10DE, 0x1140, 0x103C, 0x226D, "GeForce 820M(0x103C-0x226D)"},
{0x10DE, 0x1140, 0x103C, 0x226F, "GeForce 820M(0x103C-0x226F)"},
{0x10DE, 0x1140, 0x103C, 0x22D2, "GeForce 820M(0x103C-0x22D2)"},
{0x10DE, 0x1140, 0x103C, 0x22D9, "GeForce 820M(0x103C-0x22D9)"},
{0x10DE, 0x1140, 0x103C, 0x2335, "GeForce 820M(0x103C-0x2335)"},
{0x10DE, 0x1140, 0x103C, 0x2337, "GeForce 820M(0x103C-0x2337)"},
{0x10DE, 0x1140, 0x103C, 0x2AEF, "GeForce GT 720A(0x103C-0x2AEF)"},
{0x10DE, 0x1140, 0x103C, 0x2AF9, "GeForce 710A(0x103C-0x2AF9)"},
{0x10DE, 0x1140, 0x1043, 0x10DD, "NVS 5200M(0x1043-0x10DD)"},
{0x10DE, 0x1140, 0x1043, 0x10ED, "NVS 5200M(0x1043-0x10ED)"},
{0x10DE, 0x1140, 0x1043, 0x11FD, "GeForce GT 720M(0x1043-0x11FD)"},
{0x10DE, 0x1140, 0x1043, 0x124D, "GeForce GT 720M(0x1043-0x124D)"},
{0x10DE, 0x1140, 0x1043, 0x126D, "GeForce GT 720M(0x1043-0x126D)"},
{0x10DE, 0x1140, 0x1043, 0x131D, "GeForce GT 720M(0x1043-0x131D)"},
{0x10DE, 0x1140, 0x1043, 0x13FD, "GeForce GT 720M(0x1043-0x13FD)"},
{0x10DE, 0x1140, 0x1043, 0x14C7, "GeForce GT 720M(0x1043-0x14C7)"},
{0x10DE, 0x1140, 0x1043, 0x1507, "GeForce GT 620M(0x1043-0x1507)"},
{0x10DE, 0x1140, 0x1043, 0x15AD, "GeForce 820M(0x1043-0x15AD)"},
{0x10DE, 0x1140, 0x1043, 0x15ED, "GeForce 820M(0x1043-0x15ED)"},
{0x10DE, 0x1140, 0x1043, 0x160D, "GeForce 820M(0x1043-0x160D)"},
{0x10DE, 0x1140, 0x1043, 0x163D, "GeForce 820M(0x1043-0x163D)"},
{0x10DE, 0x1140, 0x1043, 0x166D, "GeForce 820M(0x1043-0x166D)"},
{0x10DE, 0x1140, 0x1043, 0x16CD, "GeForce 820M(0x1043-0x16CD)"},
{0x10DE, 0x1140, 0x1043, 0x16DD, "GeForce 820M(0x1043-0x16DD)"},
{0x10DE, 0x1140, 0x1043, 0x170D, "GeForce 820M(0x1043-0x170D)"},
{0x10DE, 0x1140, 0x1043, 0x176D, "GeForce 820M(0x1043-0x176D)"},
{0x10DE, 0x1140, 0x1043, 0x178D, "GeForce 820M(0x1043-0x178D)"},
{0x10DE, 0x1140, 0x1043, 0x179D, "GeForce 820M(0x1043-0x179D)"},
{0x10DE, 0x1140, 0x1043, 0x17DD, "GeForce 820M(0x1043-0x17DD)"},
{0x10DE, 0x1140, 0x1043, 0x2132, "GeForce GT 620M(0x1043-0x2132)"},
{0x10DE, 0x1140, 0x1043, 0x2136, "NVS 5200M(0x1043-0x2136)"},
{0x10DE, 0x1140, 0x1043, 0x21BA, "GeForce GT 720M(0x1043-0x21BA)"},
{0x10DE, 0x1140, 0x1043, 0x21FA, "GeForce GT 720M(0x1043-0x21FA)"},
{0x10DE, 0x1140, 0x1043, 0x220A, "GeForce GT 720M(0x1043-0x220A)"},
{0x10DE, 0x1140, 0x1043, 0x221A, "GeForce GT 720M(0x1043-0x221A)"},
{0x10DE, 0x1140, 0x1043, 0x223A, "GeForce GT 710M(0x1043-0x223A)"},
{0x10DE, 0x1140, 0x1043, 0x224A, "GeForce GT 710M(0x1043-0x224A)"},
{0x10DE, 0x1140, 0x1043, 0x227A, "GeForce 820M(0x1043-0x227A)"},
{0x10DE, 0x1140, 0x1043, 0x228A, "GeForce 820M(0x1043-0x228A)"},
{0x10DE, 0x1140, 0x1043, 0x232A, "GeForce 820M(0x1043-0x232A)"},
{0x10DE, 0x1140, 0x1043, 0x233A, "GeForce 820M(0x1043-0x233A)"},
{0x10DE, 0x1140, 0x1043, 0x235A, "GeForce 820M(0x1043-0x235A)"},
{0x10DE, 0x1140, 0x1043, 0x236A, "GeForce 820M(0x1043-0x236A)"},
{0x10DE, 0x1140, 0x1043, 0x238A, "GeForce 820M(0x1043-0x238A)"},
{0x10DE, 0x1140, 0x1043, 0x8595, "GeForce GT 720M(0x1043-0x8595)"},
{0x10DE, 0x1140, 0x1043, 0x85EA, "GeForce GT 720M(0x1043-0x85EA)"},
{0x10DE, 0x1140, 0x1043, 0x85EB, "GeForce 820M(0x1043-0x85EB)"},
{0x10DE, 0x1140, 0x1043, 0x85EC, "GeForce 820M(0x1043-0x85EC)"},
{0x10DE, 0x1140, 0x1043, 0x85EE, "GeForce GT 720M(0x1043-0x85EE)"},
{0x10DE, 0x1140, 0x1043, 0x85F3, "GeForce 820M(0x1043-0x85F3)"},
{0x10DE, 0x1140, 0x1043, 0x860E, "GeForce 820M(0x1043-0x860E)"},
{0x10DE, 0x1140, 0x1043, 0x861A, "GeForce 820M(0x1043-0x861A)"},
{0x10DE, 0x1140, 0x1043, 0x861B, "GeForce 820M(0x1043-0x861B)"},
{0x10DE, 0x1140, 0x1043, 0x8628, "GeForce 820M(0x1043-0x8628)"},
{0x10DE, 0x1140, 0x1043, 0x8643, "GeForce 820M(0x1043-0x8643)"},
{0x10DE, 0x1140, 0x1043, 0x864C, "GeForce 820M(0x1043-0x864C)"},
{0x10DE, 0x1140, 0x1043, 0x8652, "GeForce 820M(0x1043-0x8652)"},
{0x10DE, 0x1140, 0x1043, 0x8660, "GeForce 820M(0x1043-0x8660)"},
{0x10DE, 0x1140, 0x1043, 0x8661, "GeForce 820M(0x1043-0x8661)"},
{0x10DE, 0x1140, 0x105B, 0x0DAC, "GeForce GT 720M(0x105B-0x0DAC)"},
{0x10DE, 0x1140, 0x105B, 0x0DAD, "GeForce GT 720M(0x105B-0x0DAD)"},
{0x10DE, 0x1140, 0x105B, 0x0EF3, "GeForce GT 720M(0x105B-0x0EF3)"},
{0x10DE, 0x1140, 0x1072, 0x152D, "GeForce GT 720M(0x1072-0x152D)"},
{0x10DE, 0x1140, 0x10CF, 0x17F5, "GeForce GT 720M(0x10CF-0x17F5)"},
{0x10DE, 0x1140, 0x1179, 0xFA01, "GeForce 710M(0x1179-0xFA01)"},
{0x10DE, 0x1140, 0x1179, 0xFA02, "GeForce 710M(0x1179-0xFA02)"},
{0x10DE, 0x1140, 0x1179, 0xFA03, "GeForce 710M(0x1179-0xFA03)"},
{0x10DE, 0x1140, 0x1179, 0xFA05, "GeForce 710M(0x1179-0xFA05)"},
{0x10DE, 0x1140, 0x1179, 0xFA11, "GeForce 710M(0x1179-0xFA11)"},
{0x10DE, 0x1140, 0x1179, 0xFA13, "GeForce 710M(0x1179-0xFA13)"},
{0x10DE, 0x1140, 0x1179, 0xFA18, "GeForce 710M(0x1179-0xFA18)"},
{0x10DE, 0x1140, 0x1179, 0xFA19, "GeForce 710M(0x1179-0xFA19)"},
{0x10DE, 0x1140, 0x1179, 0xFA21, "GeForce 710M(0x1179-0xFA21)"},
{0x10DE, 0x1140, 0x1179, 0xFA23, "GeForce 710M(0x1179-0xFA23)"},
{0x10DE, 0x1140, 0x1179, 0xFA2A, "GeForce 710M(0x1179-0xFA2A)"},
{0x10DE, 0x1140, 0x1179, 0xFA32, "GeForce 710M(0x1179-0xFA32)"},
{0x10DE, 0x1140, 0x1179, 0xFA33, "GeForce 710M(0x1179-0xFA33)"},
{0x10DE, 0x1140, 0x1179, 0xFA36, "GeForce 710M(0x1179-0xFA36)"},
{0x10DE, 0x1140, 0x1179, 0xFA38, "GeForce 710M(0x1179-0xFA38)"},
{0x10DE, 0x1140, 0x1179, 0xFA42, "GeForce 710M(0x1179-0xFA42)"},
{0x10DE, 0x1140, 0x1179, 0xFA43, "GeForce 710M(0x1179-0xFA43)"},
{0x10DE, 0x1140, 0x1179, 0xFA45, "GeForce 710M(0x1179-0xFA45)"},
{0x10DE, 0x1140, 0x1179, 0xFA47, "GeForce 710M(0x1179-0xFA47)"},
{0x10DE, 0x1140, 0x1179, 0xFA49, "GeForce 710M(0x1179-0xFA49)"},
{0x10DE, 0x1140, 0x1179, 0xFA58, "GeForce 710M(0x1179-0xFA58)"},
{0x10DE, 0x1140, 0x1179, 0xFA59, "GeForce 710M(0x1179-0xFA59)"},
{0x10DE, 0x1140, 0x1179, 0xFA88, "GeForce 710M(0x1179-0xFA88)"},
{0x10DE, 0x1140, 0x1179, 0xFA89, "GeForce 710M(0x1179-0xFA89)"},
{0x10DE, 0x1140, 0x144D, 0xB092, "GeForce GT 620M(0x144D-0xB092)"},
{0x10DE, 0x1140, 0x144D, 0xC0D5, "GeForce GT 630M(0x144D-0xC0D5)"},
{0x10DE, 0x1140, 0x144D, 0xC0D7, "GeForce GT 620M(0x144D-0xC0D7)"},
{0x10DE, 0x1140, 0x144D, 0xC0E2, "NVS 5200M(0x144D-0xC0E2)"},
{0x10DE, 0x1140, 0x144D, 0xC0E3, "NVS 5200M(0x144D-0xC0E3)"},
{0x10DE, 0x1140, 0x144D, 0xC0E4, "NVS 5200M(0x144D-0xC0E4)"},
{0x10DE, 0x1140, 0x144D, 0xC10D, "GeForce 820M(0x144D-0xC10D)"},
{0x10DE, 0x1140, 0x144D, 0xC652, "GeForce GT 620M on NP300E5C series laptop(0x144D-0xC652)"},
{0x10DE, 0x1140, 0x144D, 0xC709, "GeForce 710M(0x144D-0xC709)"},
{0x10DE, 0x1140, 0x144D, 0xC711, "GeForce 710M(0x144D-0xC711)"},
{0x10DE, 0x1140, 0x144D, 0xC736, "GeForce 710M(0x144D-0xC736)"},
{0x10DE, 0x1140, 0x144D, 0xC737, "GeForce 710M(0x144D-0xC737)"},
{0x10DE, 0x1140, 0x144D, 0xC745, "GeForce 820M(0x144D-0xC745)"},
{0x10DE, 0x1140, 0x144D, 0xC750, "GeForce 820M(0x144D-0xC750)"},
{0x10DE, 0x1140, 0x1462, 0x10B8, "GeForce GT 710M(0x1462-0x10B8)"},
{0x10DE, 0x1140, 0x1462, 0x10E9, "GeForce GT 720M(0x1462-0x10E9)"},
{0x10DE, 0x1140, 0x1462, 0x1116, "GeForce 820M(0x1462-0x1116)"},
{0x10DE, 0x1140, 0x1462, 0xAA33, "GeForce 720M(0x1462-0xAA33)"},
{0x10DE, 0x1140, 0x1462, 0xAAA2, "GeForce GT 720M(0x1462-0xAAA2)"},
{0x10DE, 0x1140, 0x1462, 0xAAA3, "GeForce 820M(0x1462-0xAAA3)"},
{0x10DE, 0x1140, 0x1462, 0xACB2, "GeForce GT 720M(0x1462-0xACB2)"},
{0x10DE, 0x1140, 0x1462, 0xACC1, "GeForce GT 720M(0x1462-0xACC1)"},
{0x10DE, 0x1140, 0x1462, 0xAE61, "GeForce 720M(0x1462-0xAE61)"},
{0x10DE, 0x1140, 0x1462, 0xAE65, "GeForce GT 720M(0x1462-0xAE65)"},
{0x10DE, 0x1140, 0x1462, 0xAE6A, "GeForce 820M(0x1462-0xAE6A)"},
{0x10DE, 0x1140, 0x1462, 0xAE71, "GeForce GT 720M(0x1462-0xAE71)"},
{0x10DE, 0x1140, 0x14C0, 0x0083, "GeForce 820M(0x14C0-0x0083)"},
{0x10DE, 0x1140, 0x152D, 0x0926, "GeForce 620M(0x152D-0x0926)"},
{0x10DE, 0x1140, 0x152D, 0x0982, "GeForce GT 630M(0x152D-0x0982)"},
{0x10DE, 0x1140, 0x152D, 0x0983, "GeForce GT 630M(0x152D-0x0983)"},
{0x10DE, 0x1140, 0x152D, 0x1005, "GeForce GT 820M(0x152D-0x1005)"},
{0x10DE, 0x1140, 0x152D, 0x1012, "GeForce 710M(0x152D-0x1012)"},
{0x10DE, 0x1140, 0x152D, 0x1019, "GeForce 820M(0x152D-0x1019)"},
{0x10DE, 0x1140, 0x152D, 0x1030, "GeForce GT 630M(0x152D-0x1030)"},
{0x10DE, 0x1140, 0x152D, 0x1055, "GeForce 710M(0x152D-0x1055)"},
{0x10DE, 0x1140, 0x152D, 0x1067, "GeForce GT 720M(0x152D-0x1067)"},
{0x10DE, 0x1140, 0x152D, 0x1072, "GeForce GT 720M(0x152D-0x1072)"},
{0x10DE, 0x1140, 0x152D, 0x1086, "GeForce 820M(0x152D-0x1086)"},
{0x10DE, 0x1140, 0x152D, 0x1092, "GeForce 820M(0x152D-0x1092)"},
{0x10DE, 0x1140, 0x17AA, 0x2200, "NVS 5200M(0x17AA-0x2200)"},
{0x10DE, 0x1140, 0x17AA, 0x2213, "GeForce GT 720M(0x17AA-0x2213)"},
{0x10DE, 0x1140, 0x17AA, 0x2220, "GeForce GT 720M(0x17AA-0x2220)"},
{0x10DE, 0x1140, 0x17AA, 0x309C, "GeForce GT 720A(0x17AA-0x309C)"},
{0x10DE, 0x1140, 0x17AA, 0x30B4, "GeForce 820A(0x17AA-0x30B4)"},
{0x10DE, 0x1140, 0x17AA, 0x30B7, "GeForce 720A(0x17AA-0x30B7)"},
{0x10DE, 0x1140, 0x17AA, 0x30E4, "GeForce 820A(0x17AA-0x30E4)"},
{0x10DE, 0x1140, 0x17AA, 0x361B, "GeForce 820A(0x17AA-0x361B)"},
{0x10DE, 0x1140, 0x17AA, 0x361C, "GeForce 820A(0x17AA-0x361C)"},
{0x10DE, 0x1140, 0x17AA, 0x361D, "GeForce 820A(0x17AA-0x361D)"},
{0x10DE, 0x1140, 0x17AA, 0x3656, "GeForce GT 620M(0x17AA-0x3656)"},
{0x10DE, 0x1140, 0x17AA, 0x365A, "GeForce 705M(0x17AA-0x365A)"},
{0x10DE, 0x1140, 0x17AA, 0x365E, "GeForce 800M(0x17AA-0x365E)"},
{0x10DE, 0x1140, 0x17AA, 0x3661, "GeForce 820A(0x17AA-0x3661)"},
{0x10DE, 0x1140, 0x17AA, 0x366C, "GeForce 800M(0x17AA-0x366C)"},
{0x10DE, 0x1140, 0x17AA, 0x3685, "GeForce 800M(0x17AA-0x3685)"},
{0x10DE, 0x1140, 0x17AA, 0x3686, "GeForce 800M(0x17AA-0x3686)"},
{0x10DE, 0x1140, 0x17AA, 0x3687, "GeForce 705A(0x17AA-0x3687)"},
{0x10DE, 0x1140, 0x17AA, 0x3696, "GeForce 820A(0x17AA-0x3696)"},
{0x10DE, 0x1140, 0x17AA, 0x369B, "GeForce 820A(0x17AA-0x369B)"},
{0x10DE, 0x1140, 0x17AA, 0x369C, "GeForce 820A(0x17AA-0x369C)"},
{0x10DE, 0x1140, 0x17AA, 0x369D, "GeForce 820A(0x17AA-0x369D)"},
{0x10DE, 0x1140, 0x17AA, 0x369E, "GeForce 820A(0x17AA-0x369E)"},
{0x10DE, 0x1140, 0x17AA, 0x36A9, "GeForce 820A(0x17AA-0x36A9)"},
{0x10DE, 0x1140, 0x17AA, 0x36AF, "GeForce 820A(0x17AA-0x36AF)"},
{0x10DE, 0x1140, 0x17AA, 0x36B0, "GeForce 820A(0x17AA-0x36B0)"},
{0x10DE, 0x1140, 0x17AA, 0x36B6, "GeForce 820A(0x17AA-0x36B6)"},
{0x10DE, 0x1140, 0x17AA, 0x3800, "GeForce GT 720M(0x17AA-0x3800)"},
{0x10DE, 0x1140, 0x17AA, 0x3801, "GeForce GT 720M(0x17AA-0x3801)"},
{0x10DE, 0x1140, 0x17AA, 0x3802, "GeForce GT 720M(0x17AA-0x3802)"},
{0x10DE, 0x1140, 0x17AA, 0x3803, "GeForce GT 720M(0x17AA-0x3803)"},
{0x10DE, 0x1140, 0x17AA, 0x3804, "GeForce GT 720M(0x17AA-0x3804)"},
{0x10DE, 0x1140, 0x17AA, 0x3806, "GeForce GT 720M(0x17AA-0x3806)"},
{0x10DE, 0x1140, 0x17AA, 0x3808, "GeForce GT 720M(0x17AA-0x3808)"},
{0x10DE, 0x1140, 0x17AA, 0x380D, "GeForce 820M(0x17AA-0x380D)"},
{0x10DE, 0x1140, 0x17AA, 0x380E, "GeForce 820M(0x17AA-0x380E)"},
{0x10DE, 0x1140, 0x17AA, 0x380F, "GeForce 820M(0x17AA-0x380F)"},
{0x10DE, 0x1140, 0x17AA, 0x3811, "GeForce 820M(0x17AA-0x3811)"},
{0x10DE, 0x1140, 0x17AA, 0x3812, "GeForce 820M(0x17AA-0x3812)"},
{0x10DE, 0x1140, 0x17AA, 0x3813, "GeForce 820M(0x17AA-0x3813)"},
{0x10DE, 0x1140, 0x17AA, 0x3816, "GeForce 820M(0x17AA-0x3816)"},
{0x10DE, 0x1140, 0x17AA, 0x3818, "GeForce 820M(0x17AA-0x3818)"},
{0x10DE, 0x1140, 0x17AA, 0x381A, "GeForce 820M(0x17AA-0x381A)"},
{0x10DE, 0x1140, 0x17AA, 0x381C, "GeForce 820M(0x17AA-0x381C)"},
{0x10DE, 0x1140, 0x17AA, 0x3901, "GeForce 610M / GT 620M(0x17AA-0x3901)"},
{0x10DE, 0x1140, 0x17AA, 0x3902, "GeForce 710M(0x17AA-0x3902)"},
{0x10DE, 0x1140, 0x17AA, 0x3903, "GeForce 610M/710M(0x17AA-0x3903)"},
{0x10DE, 0x1140, 0x17AA, 0x3904, "GeForce GT 620M/625M(0x17AA-0x3904)"},
{0x10DE, 0x1140, 0x17AA, 0x3905, "GeForce GT 720M(0x17AA-0x3905)"},
{0x10DE, 0x1140, 0x17AA, 0x3907, "GeForce 820M(0x17AA-0x3907)"},
{0x10DE, 0x1140, 0x17AA, 0x3910, "GeForce 720M(0x17AA-0x3910)"},
{0x10DE, 0x1140, 0x17AA, 0x3912, "GeForce 720M(0x17AA-0x3912)"},
{0x10DE, 0x1140, 0x17AA, 0x3913, "GeForce 820M(0x17AA-0x3913)"},
{0x10DE, 0x1140, 0x17AA, 0x3915, "GeForce 820M(0x17AA-0x3915)"},
{0x10DE, 0x1140, 0x17AA, 0x3977, "GeForce GT 720M(0x17AA-0x3977)"},
{0x10DE, 0x1140, 0x17AA, 0x3983, "GeForce 610M(0x17AA-0x3983)"},
{0x10DE, 0x1140, 0x17AA, 0x5001, "GeForce 610M(0x17AA-0x5001)"},
{0x10DE, 0x1140, 0x17AA, 0x5003, "GeForce GT 720M(0x17AA-0x5003)"},
{0x10DE, 0x1140, 0x17AA, 0x5005, "GeForce 705M(0x17AA-0x5005)"},
{0x10DE, 0x1140, 0x17AA, 0x500D, "GeForce GT 620M(0x17AA-0x500D)"},
{0x10DE, 0x1140, 0x17AA, 0x5014, "GeForce 710M(0x17AA-0x5014)"},
{0x10DE, 0x1140, 0x17AA, 0x5017, "GeForce 710M(0x17AA-0x5017)"},
{0x10DE, 0x1140, 0x17AA, 0x5019, "GeForce 710M(0x17AA-0x5019)"},
{0x10DE, 0x1140, 0x17AA, 0x501A, "GeForce 710M(0x17AA-0x501A)"},
{0x10DE, 0x1140, 0x17AA, 0x501F, "GeForce GT 720M(0x17AA-0x501F)"},
{0x10DE, 0x1140, 0x17AA, 0x5025, "GeForce 710M(0x17AA-0x5025)"},
{0x10DE, 0x1140, 0x17AA, 0x5027, "GeForce 710M(0x17AA-0x5027)"},
{0x10DE, 0x1140, 0x17AA, 0x502A, "GeForce 710M(0x17AA-0x502A)"},
{0x10DE, 0x1140, 0x17AA, 0x502B, "GeForce GT 720M(0x17AA-0x502B)"},
{0x10DE, 0x1140, 0x17AA, 0x502D, "GeForce 710M(0x17AA-0x502D)"},
{0x10DE, 0x1140, 0x17AA, 0x502E, "GeForce GT 720M(0x17AA-0x502E)"},
{0x10DE, 0x1140, 0x17AA, 0x502F, "GeForce GT 720M(0x17AA-0x502F)"},
{0x10DE, 0x1140, 0x17AA, 0x5030, "GeForce 705M(0x17AA-0x5030)"},
{0x10DE, 0x1140, 0x17AA, 0x5031, "GeForce 705M(0x17AA-0x5031)"},
{0x10DE, 0x1140, 0x17AA, 0x5032, "GeForce 820M(0x17AA-0x5032)"},
{0x10DE, 0x1140, 0x17AA, 0x5033, "GeForce 820M(0x17AA-0x5033)"},
{0x10DE, 0x1140, 0x17AA, 0x503E, "GeForce 710M(0x17AA-0x503E)"},
{0x10DE, 0x1140, 0x17AA, 0x503F, "GeForce 820M(0x17AA-0x503F)"},
{0x10DE, 0x1140, 0x17AA, 0x5040, "GeForce 820M(0x17AA-0x5040)"},
{0x10DE, 0x1140, 0x1854, 0x0177, "GeForce 710M(0x1854-0x0177)"},
{0x10DE, 0x1140, 0x1854, 0x0180, "GeForce 710M(0x1854-0x0180)"},
{0x10DE, 0x1140, 0x1854, 0x0190, "GeForce GT 720M(0x1854-0x0190)"},
{0x10DE, 0x1140, 0x1854, 0x0192, "GeForce GT 720M(0x1854-0x0192)"},
{0x10DE, 0x1140, 0x1854, 0x0224, "GeForce 820M(0x1854-0x0224)"},
{0x10DE, 0x1140, 0x1B0A, 0x01C0, "GeForce 820M(0x1B0A-0x01C0)"},
{0x10DE, 0x1140, 0x1B0A, 0x20DD, "GeForce GT 620M(0x1B0A-0x20DD)"},
{0x10DE, 0x1140, 0x1B0A, 0x20DF, "GeForce GT 620M(0x1B0A-0x20DF)"},
{0x10DE, 0x1140, 0x1B0A, 0x210E, "GeForce 820M(0x1B0A-0x210E)"},
{0x10DE, 0x1140, 0x1B0A, 0x2202, "GeForce GT 720M(0x1B0A-0x2202)"},
{0x10DE, 0x1140, 0x1B0A, 0x90D7, "GeForce 820M(0x1B0A-0x90D7)"},
{0x10DE, 0x1140, 0x1B0A, 0x90DD, "GeForce 820M(0x1B0A-0x90DD)"},
{0x10DE, 0x1140, 0x1B50, 0x5530, "GeForce 820M(0x1B50-0x5530)"},
{0x10DE, 0x1140, 0x1B6C, 0x5531, "GeForce GT 720M(0x1B6C-0x5531)"},
{0x10DE, 0x1140, 0x1BAB, 0x0106, "GeForce 820M(0x1BAB-0x0106)"},
{0x10DE, 0x1140, 0x1D05, 0x1013, "GeForce 810M(0x1D05-0x1013)"},
{0x10DE, 0x1180, 0xFFFF, 0xFFFF, "GK104 [GeForce GTX 680](0x1180)"},
{0x10DE, 0x1180, 0x1043, 0x83F1, "GTX680-DC2-2GD5(0x1043-0x83F1)"},
{0x10DE, 0x1180, 0x3842, 0x3682, "GeForce GTX 680 Mac Edition(0x3842-0x3682)"},
{0x10DE, 0x1182, 0xFFFF, 0xFFFF, "GK104 [GeForce GTX 760 Ti](0x1182)"},
{0x10DE, 0x1183, 0xFFFF, 0xFFFF, "GK104 [GeForce GTX 660 Ti](0x1183)"},
{0x10DE, 0x1184, 0xFFFF, 0xFFFF, "GK104 [GeForce GTX 770](0x1184)"},
{0x10DE, 0x1185, 0xFFFF, 0xFFFF, "GK104 [GeForce GTX 660 OEM](0x1185)"},
{0x10DE, 0x1185, 0x10DE, 0x106F, "GK104 [GeForce GTX 760 OEM](0x10DE-0x106F)"},
{0x10DE, 0x1186, 0xFFFF, 0xFFFF, "GK104 [GeForce GTX 660 Ti](0x1186)"},
{0x10DE, 0x1187, 0xFFFF, 0xFFFF, "GK104 [GeForce GTX 760](0x1187)"},
{0x10DE, 0x1188, 0xFFFF, 0xFFFF, "GK104 [GeForce GTX 690](0x1188)"},
{0x10DE, 0x1189, 0xFFFF, 0xFFFF, "GK104 [GeForce GTX 670](0x1189)"},
{0x10DE, 0x1189, 0x10DE, 0x1074, "GK104 [GeForce GTX 760 Ti OEM](0x10DE-0x1074)"},
{0x10DE, 0x118A, 0xFFFF, 0xFFFF, "GK104GL [GRID K520](0x118A)"},
{0x10DE, 0x118B, 0xFFFF, 0xFFFF, "GK104GL [GRID K2 GeForce USM](0x118B)"},
{0x10DE, 0x118C, 0xFFFF, 0xFFFF, "GK104 [GRID K2 NVS USM](0x118C)"},
{0x10DE, 0x118D, 0xFFFF, 0xFFFF, "GK104GL [GRID K200 vGPU](0x118D)"},
{0x10DE, 0x118D, 0x10DE, 0x101D, "GRID K200(0x10DE-0x101D)"},
{0x10DE, 0x118E, 0xFFFF, 0xFFFF, "GK104 [GeForce GTX 760 OEM](0x118E)"},
{0x10DE, 0x118F, 0xFFFF, 0xFFFF, "GK104GL [Tesla K10](0x118F)"},
{0x10DE, 0x1191, 0xFFFF, 0xFFFF, "GK104 [GeForce GTX 760 Rev. 2](0x1191)"},
{0x10DE, 0x1193, 0xFFFF, 0xFFFF, "GK104 [GeForce GTX 760 Ti OEM](0x1193)"},
{0x10DE, 0x1194, 0xFFFF, 0xFFFF, "GK104GL [Tesla K8](0x1194)"},
{0x10DE, 0x1195, 0xFFFF, 0xFFFF, "GK104 [GeForce GTX 660 Rev. 2](0x1195)"},
{0x10DE, 0x1198, 0xFFFF, 0xFFFF, "GK104M [GeForce GTX 880M](0x1198)"},
{0x10DE, 0x1199, 0xFFFF, 0xFFFF, "GK104M [GeForce GTX 870M](0x1199)"},
{0x10DE, 0x119A, 0xFFFF, 0xFFFF, "GK104M [GeForce GTX 860M](0x119A)"},
{0x10DE, 0x119D, 0xFFFF, 0xFFFF, "GK104M [GeForce GTX 775M Mac Edition](0x119D)"},
{0x10DE, 0x119E, 0xFFFF, 0xFFFF, "GK104M [GeForce GTX 780M Mac Edition](0x119E)"},
{0x10DE, 0x119F, 0xFFFF, 0xFFFF, "GK104M [GeForce GTX 780M](0x119F)"},
{0x10DE, 0x11A0, 0xFFFF, 0xFFFF, "GK104M [GeForce GTX 680M](0x11A0)"},
{0x10DE, 0x11A1, 0xFFFF, 0xFFFF, "GK104M [GeForce GTX 670MX](0x11A1)"},
{0x10DE, 0x11A2, 0xFFFF, 0xFFFF, "GK104M [GeForce GTX 675MX Mac Edition](0x11A2)"},
{0x10DE, 0x11A3, 0xFFFF, 0xFFFF, "GK104M [GeForce GTX 680MX](0x11A3)"},
{0x10DE, 0x11A3, 0x106B, 0x010D, "iMac 13,2(0x106B-0x010D)"},
{0x10DE, 0x11A4, 0xFFFF, 0xFFFF, "GK104 [GK104-ESA](0x11A4)"},
{0x10DE, 0x11A5, 0xFFFF, 0xFFFF, "GK104 [GK104-ESA](0x11A5)"},
{0x10DE, 0x11A7, 0xFFFF, 0xFFFF, "GK104M [GeForce GTX 675MX](0x11A7)"},
{0x10DE, 0x11A8, 0xFFFF, 0xFFFF, "GK104GLM [Quadro K5100M](0x11A8)"},
{0x10DE, 0x11A9, 0xFFFF, 0xFFFF, "GK104M [GeForce GTX 870M](0x11A9)"},
{0x10DE, 0x11AA, 0xFFFF, 0xFFFF, "GK104 [GK104-INT](0x11AA)"},
{0x10DE, 0x11AC, 0xFFFF, 0xFFFF, "GK104 [GK104-CS](0x11AC)"},
{0x10DE, 0x11AF, 0xFFFF, 0xFFFF, "GK104GLM [GRID IceCube](0x11AF)"},
{0x10DE, 0x11B0, 0xFFFF, 0xFFFF, "GK104GL [GRID K240Q / K260Q vGPU](0x11B0)"},
{0x10DE, 0x11B0, 0x10DE, 0x101A, "GRID K240Q(0x10DE-0x101A)"},
{0x10DE, 0x11B0, 0x10DE, 0x101B, "GRID K260Q(0x10DE-0x101B)"},
{0x10DE, 0x11B1, 0xFFFF, 0xFFFF, "GK104GL [GRID K2 Tesla USM](0x11B1)"},
{0x10DE, 0x11B4, 0xFFFF, 0xFFFF, "GK104GL [Quadro K4200](0x11B4)"},
{0x10DE, 0x11B6, 0xFFFF, 0xFFFF, "GK104GLM [Quadro K3100M](0x11B6)"},
{0x10DE, 0x11B7, 0xFFFF, 0xFFFF, "GK104GLM [Quadro K4100M](0x11B7)"},
{0x10DE, 0x11B8, 0xFFFF, 0xFFFF, "GK104GLM [Quadro K5100M](0x11B8)"},
{0x10DE, 0x11B9, 0xFFFF, 0xFFFF, "GK104GLM(0x11B9)"},
{0x10DE, 0x11BA, 0xFFFF, 0xFFFF, "GK104GL [Quadro K5000](0x11BA)"},
{0x10DE, 0x11BB, 0xFFFF, 0xFFFF, "GK104GL [Quadro 4100](0x11BB)"},
{0x10DE, 0x11BC, 0xFFFF, 0xFFFF, "GK104GLM [Quadro K5000M](0x11BC)"},
{0x10DE, 0x11BD, 0xFFFF, 0xFFFF, "GK104GLM [Quadro K4000M](0x11BD)"},
{0x10DE, 0x11BE, 0xFFFF, 0xFFFF, "GK104GLM [Quadro K3000M](0x11BE)"},
{0x10DE, 0x11BF, 0xFFFF, 0xFFFF, "GK104GL [GRID K2](0x11BF)"},
{0x10DE, 0x11C0, 0xFFFF, 0xFFFF, "GK106 [GeForce GTX 660](0x11C0)"},
{0x10DE, 0x11C1, 0xFFFF, 0xFFFF, "GK106 [D14P2-30](0x11C1)"},
{0x10DE, 0x11C2, 0xFFFF, 0xFFFF, "GK106 [GeForce GTX 650 Ti Boost](0x11C2)"},
{0x10DE, 0x11C2, 0x1043, 0x845B, "GeForce GTX 650 Ti Boost DirectCU II OC(0x1043-0x845B)"},
{0x10DE, 0x11C2, 0x1462, 0x2874, "GeForce GTX 650 Ti Boost TwinFrozr II OC(0x1462-0x2874)"},
{0x10DE, 0x11C2, 0x1569, 0x11C2, "GeForce GTX 650 Ti Boost OC(0x1569-0x11C2)"},
{0x10DE, 0x11C2, 0x19DA, 0x1281, "GeForce GTX 650 Ti Boost OC(0x19DA-0x1281)"},
{0x10DE, 0x11C2, 0x3842, 0x3657, "GeForce GTX 650 Ti Boost(0x3842-0x3657)"},
{0x10DE, 0x11C2, 0x3842, 0x3658, "GeForce GTX 650 Ti Boost Superclocked(0x3842-0x3658)"},
{0x10DE, 0x11C3, 0xFFFF, 0xFFFF, "GK106 [GeForce GTX 650 Ti OEM](0x11C3)"},
{0x10DE, 0x11C3, 0x10DE, 0x1030, "GeForce GTX 650 Ti OEM(0x10DE-0x1030)"},
{0x10DE, 0x11C4, 0xFFFF, 0xFFFF, "GK106 [GeForce GTX 645 OEM](0x11C4)"},
{0x10DE, 0x11C5, 0xFFFF, 0xFFFF, "GK106 [GeForce GT 740](0x11C5)"},
{0x10DE, 0x11C6, 0xFFFF, 0xFFFF, "GK106 [GeForce GTX 650 Ti](0x11C6)"},
{0x10DE, 0x11C7, 0xFFFF, 0xFFFF, "GK106 [GeForce GTX 750 Ti](0x11C7)"},
{0x10DE, 0x11C8, 0xFFFF, 0xFFFF, "GK106 [GeForce GTX 650 OEM](0x11C8)"},
{0x10DE, 0x11CB, 0xFFFF, 0xFFFF, "GK106 [GeForce GT 740](0x11CB)"},
{0x10DE, 0x11D0, 0xFFFF, 0xFFFF, "GK106 [GK106-INT353](0x11D0)"},
{0x10DE, 0x11D1, 0xFFFF, 0xFFFF, "GK106 [GK106-INT343](0x11D1)"},
{0x10DE, 0x11D2, 0xFFFF, 0xFFFF, "GK106 [GK106-INT232](0x11D2)"},
{0x10DE, 0x11D3, 0xFFFF, 0xFFFF, "GK106 [GK106-ES](0x11D3)"},
{0x10DE, 0x11E0, 0xFFFF, 0xFFFF, "GK106M [GeForce GTX 770M](0x11E0)"},
{0x10DE, 0x11E1, 0xFFFF, 0xFFFF, "GK106M [GeForce GTX 765M](0x11E1)"},
{0x10DE, 0x11E2, 0xFFFF, 0xFFFF, "GK106M [GeForce GTX 765M](0x11E2)"},
{0x10DE, 0x11E3, 0xFFFF, 0xFFFF, "GK106M [GeForce GTX 760M](0x11E3)"},
{0x10DE, 0x11E3, 0x17AA, 0x3683, "GeForce GTX 760A(0x17AA-0x3683)"},
{0x10DE, 0x11E7, 0xFFFF, 0xFFFF, "GK106M(0x11E7)"},
{0x10DE, 0x11FA, 0xFFFF, 0xFFFF, "GK106GL [Quadro K4000](0x11FA)"},
{0x10DE, 0x11FC, 0xFFFF, 0xFFFF, "GK106GLM [Quadro K2100M](0x11FC)"},
{0x10DE, 0x11FF, 0xFFFF, 0xFFFF, "GK106 [NB1Q](0x11FF)"},
{0x10DE, 0x1200, 0xFFFF, 0xFFFF, "GF114 [GeForce GTX 560 Ti](0x1200)"},
{0x10DE, 0x1201, 0xFFFF, 0xFFFF, "GF114 [GeForce GTX 560](0x1201)"},
{0x10DE, 0x1202, 0xFFFF, 0xFFFF, "GF114 [GeForce GTX 560 Ti OEM](0x1202)"},
{0x10DE, 0x1203, 0xFFFF, 0xFFFF, "GF114 [GeForce GTX 460 SE v2](0x1203)"},
{0x10DE, 0x1205, 0xFFFF, 0xFFFF, "GF114 [GeForce GTX 460 v2](0x1205)"},
{0x10DE, 0x1206, 0xFFFF, 0xFFFF, "GF114 [GeForce GTX 555](0x1206)"},
{0x10DE, 0x1207, 0xFFFF, 0xFFFF, "GF114 [GeForce GT 645 OEM](0x1207)"},
{0x10DE, 0x1208, 0xFFFF, 0xFFFF, "GF114 [GeForce GTX 560 SE](0x1208)"},
{0x10DE, 0x1210, 0xFFFF, 0xFFFF, "GF114M [GeForce GTX 570M](0x1210)"},
{0x10DE, 0x1211, 0xFFFF, 0xFFFF, "GF114M [GeForce GTX 580M](0x1211)"},
{0x10DE, 0x1212, 0xFFFF, 0xFFFF, "GF114M [GeForce GTX 675M](0x1212)"},
{0x10DE, 0x1213, 0xFFFF, 0xFFFF, "GF114M [GeForce GTX 670M](0x1213)"},
{0x10DE, 0x1241, 0xFFFF, 0xFFFF, "GF116 [GeForce GT 545 OEM](0x1241)"},
{0x10DE, 0x1243, 0xFFFF, 0xFFFF, "GF116 [GeForce GT 545](0x1243)"},
{0x10DE, 0x1244, 0xFFFF, 0xFFFF, "GF116 [GeForce GTX 550 Ti](0x1244)"},
{0x10DE, 0x1245, 0xFFFF, 0xFFFF, "GF116 [GeForce GTS 450 Rev. 2](0x1245)"},
{0x10DE, 0x1246, 0xFFFF, 0xFFFF, "GF116M [GeForce GT 550M](0x1246)"},
{0x10DE, 0x1247, 0xFFFF, 0xFFFF, "GF116M [GeForce GT 555M/635M](0x1247)"},
{0x10DE, 0x1247, 0x1043, 0x1752, "GeForce GT 555M(0x1043-0x1752)"},
{0x10DE, 0x1247, 0x1043, 0x2050, "GeForce GT 555M(0x1043-0x2050)"},
{0x10DE, 0x1247, 0x1043, 0x2051, "GeForce GT 555M(0x1043-0x2051)"},
{0x10DE, 0x1247, 0x1043, 0x212A, "GeForce GT 635M(0x1043-0x212A)"},
{0x10DE, 0x1247, 0x1043, 0x212B, "GeForce GT 635M(0x1043-0x212B)"},
{0x10DE, 0x1247, 0x1043, 0x212C, "GeForce GT 635M(0x1043-0x212C)"},
{0x10DE, 0x1247, 0x152D, 0x0930, "GeForce GT 635M(0x152D-0x0930)"},
{0x10DE, 0x1248, 0xFFFF, 0xFFFF, "GF116M [GeForce GT 555M/635M](0x1248)"},
{0x10DE, 0x1248, 0x152D, 0x0930, "GeForce GT 635M(0x152D-0x0930)"},
{0x10DE, 0x1248, 0x17C0, 0x10E7, "GeForce GT 555M(0x17C0-0x10E7)"},
{0x10DE, 0x1248, 0x17C0, 0x10E8, "GeForce GT 555M(0x17C0-0x10E8)"},
{0x10DE, 0x1248, 0x17C0, 0x10EA, "GeForce GT 555M(0x17C0-0x10EA)"},
{0x10DE, 0x1248, 0x1854, 0x0890, "GeForce GT 555M(0x1854-0x0890)"},
{0x10DE, 0x1248, 0x1854, 0x0891, "GeForce GT 555M(0x1854-0x0891)"},
{0x10DE, 0x1248, 0x1854, 0x1795, "GeForce GT 555M(0x1854-0x1795)"},
{0x10DE, 0x1248, 0x1854, 0x1796, "GeForce GT 555M(0x1854-0x1796)"},
{0x10DE, 0x1248, 0x1854, 0x3005, "GeForce GT 555M(0x1854-0x3005)"},
{0x10DE, 0x1249, 0xFFFF, 0xFFFF, "GF116 [GeForce GTS 450 Rev. 3](0x1249)"},
{0x10DE, 0x124B, 0xFFFF, 0xFFFF, "GF116 [GeForce GT 640 OEM](0x124B)"},
{0x10DE, 0x124D, 0xFFFF, 0xFFFF, "GF116M [GeForce GT 555M/635M](0x124D)"},
{0x10DE, 0x124D, 0x1028, 0x0491, "GeForce GT 555M(0x1028-0x0491)"},
{0x10DE, 0x124D, 0x1028, 0x0570, "GeForce GT 555M(0x1028-0x0570)"},
{0x10DE, 0x124D, 0x1028, 0x0571, "GeForce GT 555M(0x1028-0x0571)"},
{0x10DE, 0x124D, 0x1462, 0x108D, "GeForce GT 555M(0x1462-0x108D)"},
{0x10DE, 0x124D, 0x1462, 0x10CC, "GeForce GT 635M(0x1462-0x10CC)"},
{0x10DE, 0x1251, 0xFFFF, 0xFFFF, "GF116M [GeForce GT 560M](0x1251)"},
{0x10DE, 0x1280, 0xFFFF, 0xFFFF, "GK208 [GeForce GT 635](0x1280)"},
{0x10DE, 0x1281, 0xFFFF, 0xFFFF, "GK208 [GeForce GT 710](0x1281)"},
{0x10DE, 0x1282, 0xFFFF, 0xFFFF, "GK208 [GeForce GT 640 Rev. 2](0x1282)"},
{0x10DE, 0x1283, 0xFFFF, 0xFFFF, "GK208 [D15M2-10](0x1283)"},
{0x10DE, 0x1284, 0xFFFF, 0xFFFF, "GK208 [GeForce GT 630 Rev. 2](0x1284)"},
{0x10DE, 0x1285, 0xFFFF, 0xFFFF, "GK208 [GK208-100](0x1285)"},
{0x10DE, 0x1286, 0xFFFF, 0xFFFF, "GK208 [GeForce GT 720](0x1286)"},
{0x10DE, 0x1287, 0xFFFF, 0xFFFF, "GK208B [GeForce GT 730](0x1287)"},
{0x10DE, 0x1288, 0xFFFF, 0xFFFF, "GK208B [GeForce GT 720](0x1288)"},
{0x10DE, 0x1289, 0xFFFF, 0xFFFF, "GK208 [GeForce GT 710](0x1289)"},
{0x10DE, 0x128A, 0xFFFF, 0xFFFF, "GK208B(0x128A)"},
{0x10DE, 0x128B, 0xFFFF, 0xFFFF, "GK208B [GeForce GT 710](0x128B)"},
{0x10DE, 0x128B, 0x1043, 0x85F7, "GT710-SL-1GD5(0x1043-0x85F7)"},
{0x10DE, 0x128B, 0x1043, 0x8770, "GT710-4H-SL-2GD5(0x1043-0x8770)"},
{0x10DE, 0x128C, 0xFFFF, 0xFFFF, "GK208B(0x128C)"},
{0x10DE, 0x1290, 0xFFFF, 0xFFFF, "GK208M [GeForce GT 730M](0x1290)"},
{0x10DE, 0x1290, 0x103C, 0x2AFA, "GeForce GT 730A(0x103C-0x2AFA)"},
{0x10DE, 0x1290, 0x103C, 0x2B04, "GeForce GT 730A(0x103C-0x2B04)"},
{0x10DE, 0x1290, 0x1043, 0x13AD, "GeForce GT 730M(0x1043-0x13AD)"},
{0x10DE, 0x1290, 0x1043, 0x13CD, "GeForce GT 730M(0x1043-0x13CD)"},
{0x10DE, 0x1291, 0xFFFF, 0xFFFF, "GK208M [GeForce GT 735M](0x1291)"},
{0x10DE, 0x1292, 0xFFFF, 0xFFFF, "GK208M [GeForce GT 740M](0x1292)"},
{0x10DE, 0x1292, 0x17AA, 0x3675, "GeForce GT 740A(0x17AA-0x3675)"},
{0x10DE, 0x1292, 0x17AA, 0x367C, "GeForce GT 740A(0x17AA-0x367C)"},
{0x10DE, 0x1292, 0x17AA, 0x3684, "GeForce GT 740A(0x17AA-0x3684)"},
{0x10DE, 0x1293, 0xFFFF, 0xFFFF, "GK208M [GeForce GT 730M](0x1293)"},
{0x10DE, 0x1294, 0xFFFF, 0xFFFF, "GK208M [GeForce GT 740M](0x1294)"},
{0x10DE, 0x1295, 0xFFFF, 0xFFFF, "GK208M [GeForce 710M](0x1295)"},
{0x10DE, 0x1295, 0x103C, 0x2B0D, "GeForce 710A(0x103C-0x2B0D)"},
{0x10DE, 0x1295, 0x103C, 0x2B0F, "GeForce 710A(0x103C-0x2B0F)"},
{0x10DE, 0x1295, 0x103C, 0x2B11, "GeForce 710A(0x103C-0x2B11)"},
{0x10DE, 0x1295, 0x103C, 0x2B20, "GeForce 810A(0x103C-0x2B20)"},
{0x10DE, 0x1295, 0x103C, 0x2B21, "GeForce 810A(0x103C-0x2B21)"},
{0x10DE, 0x1295, 0x103C, 0x2B22, "GeForce 810A(0x103C-0x2B22)"},
{0x10DE, 0x1295, 0x17AA, 0x367A, "GeForce 805A(0x17AA-0x367A)"},
{0x10DE, 0x1295, 0x17AA, 0x367C, "GeForce 710A(0x17AA-0x367C)"},
{0x10DE, 0x1296, 0xFFFF, 0xFFFF, "GK208M [GeForce 825M](0x1296)"},
{0x10DE, 0x1298, 0xFFFF, 0xFFFF, "GK208M [GeForce GT 720M](0x1298)"},
{0x10DE, 0x1299, 0xFFFF, 0xFFFF, "GK208BM [GeForce 920M](0x1299)"},
{0x10DE, 0x1299, 0x17AA, 0x30BB, "GeForce 920A(0x17AA-0x30BB)"},
{0x10DE, 0x1299, 0x17AA, 0x30DF, "GeForce 920A(0x17AA-0x30DF)"},
{0x10DE, 0x1299, 0x17AA, 0x36A7, "GeForce 920A(0x17AA-0x36A7)"},
{0x10DE, 0x1299, 0x17AA, 0x36AF, "GeForce 920M(0x17AA-0x36AF)"},
{0x10DE, 0x129A, 0xFFFF, 0xFFFF, "GK208BM [GeForce 910M](0x129A)"},
{0x10DE, 0x12A0, 0xFFFF, 0xFFFF, "GK208(0x12A0)"},
{0x10DE, 0x12AD, 0xFFFF, 0xFFFF, "GK208 [GK208-ES](0x12AD)"},
{0x10DE, 0x12AE, 0xFFFF, 0xFFFF, "GK208 [GK208-CS1-C](0x12AE)"},
{0x10DE, 0x12AF, 0xFFFF, 0xFFFF, "GK208 [GK208-INT](0x12AF)"},
{0x10DE, 0x12B0, 0xFFFF, 0xFFFF, "GK208 [GK208-CS-Q](0x12B0)"},
{0x10DE, 0x12B1, 0xFFFF, 0xFFFF, "GK208 [GK208 INT](0x12B1)"},
{0x10DE, 0x12B9, 0xFFFF, 0xFFFF, "GK208GLM [Quadro K610M](0x12B9)"},
{0x10DE, 0x12BA, 0xFFFF, 0xFFFF, "GK208GLM [Quadro K510M](0x12BA)"},
{0x10DE, 0x130B, 0xFFFF, 0xFFFF, "GK110 [Q12U-1](0x130B)"},
{0x10DE, 0x1340, 0xFFFF, 0xFFFF, "GM108M [GeForce 830M](0x1340)"},
{0x10DE, 0x1340, 0x103C, 0x2B2B, "GeForce 830A(0x103C-0x2B2B)"},
{0x10DE, 0x1341, 0xFFFF, 0xFFFF, "GM108M [GeForce 840M](0x1341)"},
{0x10DE, 0x1341, 0x17AA, 0x3697, "GeForce 840A(0x17AA-0x3697)"},
{0x10DE, 0x1341, 0x17AA, 0x3699, "GeForce 840A(0x17AA-0x3699)"},
{0x10DE, 0x1341, 0x17AA, 0x369C, "GeForce 840A(0x17AA-0x369C)"},
{0x10DE, 0x1344, 0xFFFF, 0xFFFF, "GM108M [GeForce 845M](0x1344)"},
{0x10DE, 0x1346, 0xFFFF, 0xFFFF, "GM108M [GeForce 930M](0x1346)"},
{0x10DE, 0x1347, 0xFFFF, 0xFFFF, "GM108M [GeForce 940M](0x1347)"},
{0x10DE, 0x1348, 0xFFFF, 0xFFFF, "GM108M [GeForce 945M / 945A](0x1348)"},
{0x10DE, 0x1349, 0xFFFF, 0xFFFF, "GM108M [GeForce 930M](0x1349)"},
{0x10DE, 0x134B, 0xFFFF, 0xFFFF, "GM108M [GeForce 940MX](0x134B)"},
{0x10DE, 0x134D, 0xFFFF, 0xFFFF, "GM108M [GeForce 940MX](0x134D)"},
{0x10DE, 0x134D, 0x17AA, 0x2248, "ThinkPad T570(0x17AA-0x2248)"},
{0x10DE, 0x134E, 0xFFFF, 0xFFFF, "GM108M [GeForce 930MX](0x134E)"},
{0x10DE, 0x134F, 0xFFFF, 0xFFFF, "GM108M [GeForce 920MX](0x134F)"},
{0x10DE, 0x137A, 0xFFFF, 0xFFFF, "GM108GLM [Quadro K620M / Quadro M500M](0x137A)"},
{0x10DE, 0x137A, 0x17AA, 0x505A, "Quadro M500M(0x17AA-0x505A)"},
{0x10DE, 0x137B, 0xFFFF, 0xFFFF, "GM108GLM [Quadro M520 Mobile](0x137B)"},
{0x10DE, 0x137D, 0xFFFF, 0xFFFF, "GM108M [GeForce 940A](0x137D)"},
{0x10DE, 0x1380, 0xFFFF, 0xFFFF, "GM107 [GeForce GTX 750 Ti](0x1380)"},
{0x10DE, 0x1381, 0xFFFF, 0xFFFF, "GM107 [GeForce GTX 750](0x1381)"},
{0x10DE, 0x1382, 0xFFFF, 0xFFFF, "GM107 [GeForce GTX 745](0x1382)"},
{0x10DE, 0x1389, 0xFFFF, 0xFFFF, "GM107GL [GRID M30](0x1389)"},
{0x10DE, 0x1390, 0xFFFF, 0xFFFF, "GM107M [GeForce 845M](0x1390)"},
{0x10DE, 0x1391, 0xFFFF, 0xFFFF, "GM107M [GeForce GTX 850M](0x1391)"},
{0x10DE, 0x1391, 0x17AA, 0x3697, "GeForce GTX 850A(0x17AA-0x3697)"},
{0x10DE, 0x1391, 0x17AA, 0xA125, "GeForce GTX 850A(0x17AA-0xA125)"},
{0x10DE, 0x1392, 0xFFFF, 0xFFFF, "GM107M [GeForce GTX 860M](0x1392)"},
{0x10DE, 0x1393, 0xFFFF, 0xFFFF, "GM107M [GeForce 840M](0x1393)"},
{0x10DE, 0x1398, 0xFFFF, 0xFFFF, "GM107M [GeForce 845M](0x1398)"},
{0x10DE, 0x1399, 0xFFFF, 0xFFFF, "GM107M [GeForce 945M](0x1399)"},
{0x10DE, 0x139A, 0xFFFF, 0xFFFF, "GM107M [GeForce GTX 950M](0x139A)"},
{0x10DE, 0x139A, 0x17AA, 0x362C, "GeForce GTX 950A(0x17AA-0x362C)"},
{0x10DE, 0x139A, 0x17AA, 0x362F, "GeForce GTX 950A(0x17AA-0x362F)"},
{0x10DE, 0x139A, 0x17AA, 0x363F, "GeForce GTX 950A(0x17AA-0x363F)"},
{0x10DE, 0x139A, 0x17AA, 0x3640, "GeForce GTX 950A(0x17AA-0x3640)"},
{0x10DE, 0x139A, 0x17AA, 0x3647, "GeForce GTX 950A(0x17AA-0x3647)"},
{0x10DE, 0x139A, 0x17AA, 0x36B9, "GeForce GTX 950A(0x17AA-0x36B9)"},
{0x10DE, 0x139B, 0xFFFF, 0xFFFF, "GM107M [GeForce GTX 960M](0x139B)"},
{0x10DE, 0x139B, 0x1028, 0x06E4, "XPS 15 9550(0x1028-0x06E4)"},
{0x10DE, 0x139B, 0x103C, 0x2B4C, "GeForce GTX 960A(0x103C-0x2B4C)"},
{0x10DE, 0x139C, 0xFFFF, 0xFFFF, "GM107M [GeForce 940M](0x139C)"},
{0x10DE, 0x139D, 0xFFFF, 0xFFFF, "GM107M [GeForce GTX 750 Ti](0x139D)"},
{0x10DE, 0x13AD, 0xFFFF, 0xFFFF, "GM204 [GM107 INT52](0x13AD)"},
{0x10DE, 0x13AE, 0xFFFF, 0xFFFF, "GM204 [GM107 CS1](0x13AE)"},
{0x10DE, 0x13B0, 0xFFFF, 0xFFFF, "GM107GLM [Quadro M2000M](0x13B0)"},
{0x10DE, 0x13B1, 0xFFFF, 0xFFFF, "GM107GLM [Quadro M1000M](0x13B1)"},
{0x10DE, 0x13B2, 0xFFFF, 0xFFFF, "GM107GLM [Quadro M600M](0x13B2)"},
{0x10DE, 0x13B3, 0xFFFF, 0xFFFF, "GM107GLM [Quadro K2200M](0x13B3)"},
{0x10DE, 0x13B4, 0xFFFF, 0xFFFF, "GM107GLM [Quadro M620 Mobile](0x13B4)"},
{0x10DE, 0x13B6, 0xFFFF, 0xFFFF, "GM107GLM [Quadro M1200 Mobile](0x13B6)"},
{0x10DE, 0x13B9, 0xFFFF, 0xFFFF, "GM107GL [NVS 810](0x13B9)"},
{0x10DE, 0x13BA, 0xFFFF, 0xFFFF, "GM107GL [Quadro K2200](0x13BA)"},
{0x10DE, 0x13BB, 0xFFFF, 0xFFFF, "GM107GL [Quadro K620](0x13BB)"},
{0x10DE, 0x13BC, 0xFFFF, 0xFFFF, "GM107GL [Quadro K1200](0x13BC)"},
{0x10DE, 0x13BD, 0xFFFF, 0xFFFF, "GM107GL [Tesla M10](0x13BD)"},
{0x10DE, 0x13BD, 0x10DE, 0x110A, "GRID M40(0x10DE-0x110A)"},
{0x10DE, 0x13BD, 0x10DE, 0x1160, "Tesla M10(0x10DE-0x1160)"},
{0x10DE, 0x13BD, 0x10DE, 0x11D2, "GRID M10-8Q(0x10DE-0x11D2)"},
{0x10DE, 0x13BE, 0xFFFF, 0xFFFF, "GM204 [GM107 CS1](0x13BE)"},
{0x10DE, 0x13BF, 0xFFFF, 0xFFFF, "GM204 [GM107 INT52](0x13BF)"},
{0x10DE, 0x13C0, 0xFFFF, 0xFFFF, "GM204 [GeForce GTX 980](0x13C0)"},
{0x10DE, 0x13C0, 0x1043, 0x8504, "GTX980-4GD5(0x1043-0x8504)"},
{0x10DE, 0x13C1, 0xFFFF, 0xFFFF, "GM204(0x13C1)"},
{0x10DE, 0x13C2, 0xFFFF, 0xFFFF, "GM204 [GeForce GTX 970](0x13C2)"},
{0x10DE, 0x13C3, 0xFFFF, 0xFFFF, "GM204(0x13C3)"},
{0x10DE, 0x13C4, 0xFFFF, 0xFFFF, "GM204 [D17U-20](0x13C4)"},
{0x10DE, 0x13D7, 0xFFFF, 0xFFFF, "GM204M [GeForce GTX 980M](0x13D7)"},
{0x10DE, 0x13D8, 0xFFFF, 0xFFFF, "GM204M [GeForce GTX 960 OEM / 970M](0x13D8)"},
{0x10DE, 0x13D9, 0xFFFF, 0xFFFF, "GM204M [GeForce GTX 965M](0x13D9)"},
{0x10DE, 0x13DA, 0xFFFF, 0xFFFF, "GM204M [GeForce GTX 980 Mobile](0x13DA)"},
{0x10DE, 0x13E4, 0xFFFF, 0xFFFF, "GM204 [Graphics Device ES-A](0x13E4)"},
{0x10DE, 0x13E7, 0xFFFF, 0xFFFF, "GM204GL [GeForce GTX 980 Engineering Sample](0x13E7)"},
{0x10DE, 0x13F0, 0xFFFF, 0xFFFF, "GM204GL [Quadro M5000](0x13F0)"},
{0x10DE, 0x13F1, 0xFFFF, 0xFFFF, "GM204GL [Quadro M4000](0x13F1)"},
{0x10DE, 0x13F2, 0xFFFF, 0xFFFF, "GM204GL [Tesla M60](0x13F2)"},
{0x10DE, 0x13F2, 0x10DE, 0x114D, "GRID M60-1Q(0x10DE-0x114D)"},
{0x10DE, 0x13F2, 0x10DE, 0x114E, "GRID M60-2Q(0x10DE-0x114E)"},
{0x10DE, 0x13F2, 0x10DE, 0x1150, "GRID M60-8Q(0x10DE-0x1150)"},
{0x10DE, 0x13F2, 0x10DE, 0x11B0, "GRID M60-4A(0x10DE-0x11B0)"},
{0x10DE, 0x13F3, 0xFFFF, 0xFFFF, "GM204GL [Tesla M6](0x13F3)"},
{0x10DE, 0x13F3, 0x10DE, 0x1184, "GRID M6-8Q(0x10DE-0x1184)"},
{0x10DE, 0x13F8, 0xFFFF, 0xFFFF, "GM204GLM [Quadro M5000M / M5000 SE](0x13F8)"},
{0x10DE, 0x13F9, 0xFFFF, 0xFFFF, "GM204GLM [Quadro M4000M](0x13F9)"},
{0x10DE, 0x13FA, 0xFFFF, 0xFFFF, "GM204GLM [Quadro M3000M](0x13FA)"},
{0x10DE, 0x13FA, 0x10DE, 0x11C9, "Quadro M3000 SE(0x10DE-0x11C9)"},
{0x10DE, 0x13FB, 0xFFFF, 0xFFFF, "GM204GLM [Quadro M5500](0x13FB)"},
{0x10DE, 0x1401, 0xFFFF, 0xFFFF, "GM206 [GeForce GTX 960](0x1401)"},
{0x10DE, 0x1402, 0xFFFF, 0xFFFF, "GM206 [GeForce GTX 950](0x1402)"},
{0x10DE, 0x1404, 0xFFFF, 0xFFFF, "GM206 [GeForce GTX 960 FAKE](0x1404)"},
{0x10DE, 0x1406, 0xFFFF, 0xFFFF, "GM206 [GeForce GTX 960 OEM](0x1406)"},
{0x10DE, 0x1407, 0xFFFF, 0xFFFF, "GM206 [GeForce GTX 750 v2](0x1407)"},
{0x10DE, 0x1427, 0xFFFF, 0xFFFF, "GM206M [GeForce GTX 965M](0x1427)"},
{0x10DE, 0x1427, 0x103C, 0x825B, "OMEN-17-w001nv(0x103C-0x825B)"},
{0x10DE, 0x1430, 0xFFFF, 0xFFFF, "GM206GL [Quadro M2000](0x1430)"},
{0x10DE, 0x1431, 0xFFFF, 0xFFFF, "GM206GL [Tesla M4](0x1431)"},
{0x10DE, 0x1436, 0xFFFF, 0xFFFF, "GM206GLM [Quadro M2200 Mobile](0x1436)"},
{0x10DE, 0x15C2, 0xFFFF, 0xFFFF, "GP100 [CMP 100-100](0x15C2)"},
{0x10DE, 0x15F0, 0xFFFF, 0xFFFF, "GP100GL [Quadro GP100](0x15F0)"},
{0x10DE, 0x15F1, 0xFFFF, 0xFFFF, "GP100GL(0x15F1)"},
{0x10DE, 0x15F7, 0xFFFF, 0xFFFF, "GP100GL [Tesla P100 PCIe 12GB](0x15F7)"},
{0x10DE, 0x15F8, 0xFFFF, 0xFFFF, "GP100GL [Tesla P100 PCIe 16GB](0x15F8)"},
{0x10DE, 0x15F9, 0xFFFF, 0xFFFF, "GP100GL [Tesla P100 SXM2 16GB](0x15F9)"},
{0x10DE, 0x15FA, 0xFFFF, 0xFFFF, "GP100GL [DGX Station / PH402 SKU 200](0x15FA)"},
{0x10DE, 0x15FB, 0xFFFF, 0xFFFF, "GP100GL [GP100 SKU 200](0x15FB)"},
{0x10DE, 0x15FC, 0xFFFF, 0xFFFF, "GP100GL [Tesla P100-DGXS-16GB](0x15FC)"},
{0x10DE, 0x15FF, 0xFFFF, 0xFFFF, "GP100GL [GP100 SKU 15ff](0x15FF)"},
{0x10DE, 0x1617, 0xFFFF, 0xFFFF, "GM204M [GeForce GTX 980M](0x1617)"},
{0x10DE, 0x1618, 0xFFFF, 0xFFFF, "GM204M [GeForce GTX 970M](0x1618)"},
{0x10DE, 0x1619, 0xFFFF, 0xFFFF, "GM204M [GeForce GTX 965M](0x1619)"},
{0x10DE, 0x161A, 0xFFFF, 0xFFFF, "GM204M [GeForce GTX 980 Mobile](0x161A)"},
{0x10DE, 0x1667, 0xFFFF, 0xFFFF, "GM204M [GeForce GTX 965M](0x1667)"},
{0x10DE, 0x1725, 0xFFFF, 0xFFFF, "GP100(0x1725)"},
{0x10DE, 0x172E, 0xFFFF, 0xFFFF, "GP100(0x172E)"},
{0x10DE, 0x172F, 0xFFFF, 0xFFFF, "GP100(0x172F)"},
{0x10DE, 0x174D, 0xFFFF, 0xFFFF, "GM108M [GeForce MX130](0x174D)"},
{0x10DE, 0x174E, 0xFFFF, 0xFFFF, "GM108M [GeForce MX110](0x174E)"},
{0x10DE, 0x1789, 0xFFFF, 0xFFFF, "GM107GL [GRID M3-3020](0x1789)"},
{0x10DE, 0x179C, 0xFFFF, 0xFFFF, "GM107 [GeForce 940MX](0x179C)"},
{0x10DE, 0x179C, 0x1025, 0x1094, "Acer Aspire E5-575G(0x1025-0x1094)"},
{0x10DE, 0x17C2, 0xFFFF, 0xFFFF, "GM200 [GeForce GTX TITAN X](0x17C2)"},
{0x10DE, 0x17C8, 0xFFFF, 0xFFFF, "GM200 [GeForce GTX 980 Ti](0x17C8)"},
{0x10DE, 0x17F0, 0xFFFF, 0xFFFF, "GM200GL [Quadro M6000](0x17F0)"},
{0x10DE, 0x17F0, 0x10DE, 0x1141, "VCA 6000(0x10DE-0x1141)"},
{0x10DE, 0x17F1, 0xFFFF, 0xFFFF, "GM200GL [Quadro M6000 24GB](0x17F1)"},
{0x10DE, 0x17FD, 0xFFFF, 0xFFFF, "GM200GL [Tesla M40](0x17FD)"},
{0x10DE, 0x1AD0, 0xFFFF, 0xFFFF, "Tegra PCIe x8 Endpoint(0x1AD0)"},
{0x10DE, 0x1AD1, 0xFFFF, 0xFFFF, "Tegra PCIe x4/x8 Endpoint/Root Complex(0x1AD1)"},
{0x10DE, 0x1AD2, 0xFFFF, 0xFFFF, "Tegra PCIe x1 Root Complex(0x1AD2)"},
{0x10DE, 0x1AD3, 0xFFFF, 0xFFFF, "Xavier SATA Controller(0x1AD3)"},
{0x10DE, 0x1AD6, 0xFFFF, 0xFFFF, "TU102 USB 3.1 Host Controller(0x1AD6)"},
{0x10DE, 0x1AD7, 0xFFFF, 0xFFFF, "TU102 USB Type-C UCSI Controller(0x1AD7)"},
{0x10DE, 0x1AD8, 0xFFFF, 0xFFFF, "TU104 USB 3.1 Host Controller(0x1AD8)"},
{0x10DE, 0x1AD9, 0xFFFF, 0xFFFF, "TU104 USB Type-C UCSI Controller(0x1AD9)"},
{0x10DE, 0x1ADA, 0xFFFF, 0xFFFF, "TU106 USB 3.1 Host Controller(0x1ADA)"},
{0x10DE, 0x1ADA, 0x1043, 0x8673, "TURBO-RTX2070-8G(0x1043-0x8673)"},
{0x10DE, 0x1ADB, 0xFFFF, 0xFFFF, "TU106 USB Type-C UCSI Controller(0x1ADB)"},
{0x10DE, 0x1ADB, 0x1043, 0x8673, "TURBO-RTX2070-8G(0x1043-0x8673)"},
{0x10DE, 0x1AEB, 0xFFFF, 0xFFFF, "TU116 High Definition Audio Controller(0x1AEB)"},
{0x10DE, 0x1AEC, 0xFFFF, 0xFFFF, "TU116 USB 3.1 Host Controller(0x1AEC)"},
{0x10DE, 0x1AED, 0xFFFF, 0xFFFF, "TU116 USB Type-C UCSI Controller(0x1AED)"},
{0x10DE, 0x1AEF, 0xFFFF, 0xFFFF, "GA102 High Definition Audio Controller(0x1AEF)"},
{0x10DE, 0x1AF1, 0xFFFF, 0xFFFF, "GA100 [A100 NVSwitch](0x1AF1)"},
{0x10DE, 0x1B00, 0xFFFF, 0xFFFF, "GP102 [TITAN X](0x1B00)"},
{0x10DE, 0x1B01, 0xFFFF, 0xFFFF, "GP102 [GeForce GTX 1080 Ti 10GB](0x1B01)"},
{0x10DE, 0x1B02, 0xFFFF, 0xFFFF, "GP102 [TITAN Xp](0x1B02)"},
{0x10DE, 0x1B04, 0xFFFF, 0xFFFF, "GP102(0x1B04)"},
{0x10DE, 0x1B06, 0xFFFF, 0xFFFF, "GP102 [GeForce GTX 1080 Ti](0x1B06)"},
{0x10DE, 0x1B07, 0xFFFF, 0xFFFF, "GP102 [P102-100](0x1B07)"},
{0x10DE, 0x1B30, 0xFFFF, 0xFFFF, "GP102GL [Quadro P6000](0x1B30)"},
{0x10DE, 0x1B38, 0xFFFF, 0xFFFF, "GP102GL [Tesla P40](0x1B38)"},
{0x10DE, 0x1B39, 0xFFFF, 0xFFFF, "GP102GL [Tesla P10](0x1B39)"},
{0x10DE, 0x1B70, 0xFFFF, 0xFFFF, "GP102GL(0x1B70)"},
{0x10DE, 0x1B78, 0xFFFF, 0xFFFF, "GP102GL(0x1B78)"},
{0x10DE, 0x1B80, 0xFFFF, 0xFFFF, "GP104 [GeForce GTX 1080](0x1B80)"},
{0x10DE, 0x1B81, 0xFFFF, 0xFFFF, "GP104 [GeForce GTX 1070](0x1B81)"},
{0x10DE, 0x1B82, 0xFFFF, 0xFFFF, "GP104 [GeForce GTX 1070 Ti](0x1B82)"},
{0x10DE, 0x1B83, 0xFFFF, 0xFFFF, "GP104 [GeForce GTX 1060 6GB](0x1B83)"},
{0x10DE, 0x1B84, 0xFFFF, 0xFFFF, "GP104 [GeForce GTX 1060 3GB](0x1B84)"},
{0x10DE, 0x1B87, 0xFFFF, 0xFFFF, "GP104 [P104-100](0x1B87)"},
{0x10DE, 0x1BA0, 0xFFFF, 0xFFFF, "GP104M [GeForce GTX 1080 Mobile](0x1BA0)"},
{0x10DE, 0x1BA1, 0xFFFF, 0xFFFF, "GP104M [GeForce GTX 1070 Mobile](0x1BA1)"},
{0x10DE, 0x1BA1, 0x1458, 0x1651, "GeForce GTX 1070 Max-Q(0x1458-0x1651)"},
{0x10DE, 0x1BA1, 0x1462, 0x11E8, "GeForce GTX 1070 Max-Q(0x1462-0x11E8)"},
{0x10DE, 0x1BA1, 0x1462, 0x11E9, "GeForce GTX 1070 Max-Q(0x1462-0x11E9)"},
{0x10DE, 0x1BA1, 0x1558, 0x9501, "GeForce GTX 1070 Max-Q(0x1558-0x9501)"},
{0x10DE, 0x1BA2, 0xFFFF, 0xFFFF, "GP104M [GeForce GTX 1070 Mobile](0x1BA2)"},
{0x10DE, 0x1BA9, 0xFFFF, 0xFFFF, "GP104M(0x1BA9)"},
{0x10DE, 0x1BAA, 0xFFFF, 0xFFFF, "GP104M(0x1BAA)"},
{0x10DE, 0x1BAD, 0xFFFF, 0xFFFF, "GP104 [GeForce GTX 1070 Engineering Sample](0x1BAD)"},
{0x10DE, 0x1BB0, 0xFFFF, 0xFFFF, "GP104GL [Quadro P5000](0x1BB0)"},
{0x10DE, 0x1BB1, 0xFFFF, 0xFFFF, "GP104GL [Quadro P4000](0x1BB1)"},
{0x10DE, 0x1BB3, 0xFFFF, 0xFFFF, "GP104GL [Tesla P4](0x1BB3)"},
{0x10DE, 0x1BB4, 0xFFFF, 0xFFFF, "GP104GL [Tesla P6](0x1BB4)"},
{0x10DE, 0x1BB5, 0xFFFF, 0xFFFF, "GP104GLM [Quadro P5200 Mobile](0x1BB5)"},
{0x10DE, 0x1BB5, 0x103C, 0x842F, "P5200 [Zbook 17 G5 mobile workstation](0x103C-0x842F)"},
{0x10DE, 0x1BB6, 0xFFFF, 0xFFFF, "GP104GLM [Quadro P5000 Mobile](0x1BB6)"},
{0x10DE, 0x1BB7, 0xFFFF, 0xFFFF, "GP104GLM [Quadro P4000 Mobile](0x1BB7)"},
{0x10DE, 0x1BB7, 0x1462, 0x11E9, "Quadro P4000 Max-Q(0x1462-0x11E9)"},
{0x10DE, 0x1BB8, 0xFFFF, 0xFFFF, "GP104GLM [Quadro P3000 Mobile](0x1BB8)"},
{0x10DE, 0x1BB9, 0xFFFF, 0xFFFF, "GP104GLM [Quadro P4200 Mobile](0x1BB9)"},
{0x10DE, 0x1BB9, 0x103C, 0x842F, "P4200 [Zbook 17 G5 mobile workstation](0x103C-0x842F)"},
{0x10DE, 0x1BBB, 0xFFFF, 0xFFFF, "GP104GLM [Quadro P3200 Mobile](0x1BBB)"},
{0x10DE, 0x1BBB, 0x103C, 0x842F, "P3200 [Zbook 17 G5 moble workstation](0x103C-0x842F)"},
{0x10DE, 0x1BC7, 0xFFFF, 0xFFFF, "GP104 [P104-101](0x1BC7)"},
{0x10DE, 0x1BE0, 0xFFFF, 0xFFFF, "GP104BM [GeForce GTX 1080 Mobile](0x1BE0)"},
{0x10DE, 0x1BE0, 0x1028, 0x07C0, "GeForce GTX 1080 Max-Q(0x1028-0x07C0)"},
{0x10DE, 0x1BE0, 0x1458, 0x355B, "GeForce GTX 1080 Max-Q(0x1458-0x355B)"},
{0x10DE, 0x1BE1, 0xFFFF, 0xFFFF, "GP104BM [GeForce GTX 1070 Mobile](0x1BE1)"},
{0x10DE, 0x1C00, 0xFFFF, 0xFFFF, "GP106(0x1C00)"},
{0x10DE, 0x1C01, 0xFFFF, 0xFFFF, "GP106(0x1C01)"},
{0x10DE, 0x1C02, 0xFFFF, 0xFFFF, "GP106 [GeForce GTX 1060 3GB](0x1C02)"},
{0x10DE, 0x1C03, 0xFFFF, 0xFFFF, "GP106 [GeForce GTX 1060 6GB](0x1C03)"},
{0x10DE, 0x1C03, 0x1043, 0x85B6, "DUAL-GTX1060-O6G [GeForce GTX 1060 6GB Dual](0x1043-0x85B6)"},
{0x10DE, 0x1C04, 0xFFFF, 0xFFFF, "GP106 [GeForce GTX 1060 5GB](0x1C04)"},
{0x10DE, 0x1C06, 0xFFFF, 0xFFFF, "GP106 [GeForce GTX 1060 6GB Rev. 2](0x1C06)"},
{0x10DE, 0x1C07, 0xFFFF, 0xFFFF, "GP106 [P106-100](0x1C07)"},
{0x10DE, 0x1C09, 0xFFFF, 0xFFFF, "GP106 [P106-090](0x1C09)"},
{0x10DE, 0x1C20, 0xFFFF, 0xFFFF, "GP106M [GeForce GTX 1060 Mobile](0x1C20)"},
{0x10DE, 0x1C20, 0x17AA, 0x39B9, "GeForce GTX 1060 Max-Q 3GB(0x17AA-0x39B9)"},
{0x10DE, 0x1C21, 0xFFFF, 0xFFFF, "GP106M [GeForce GTX 1050 Ti Mobile](0x1C21)"},
{0x10DE, 0x1C22, 0xFFFF, 0xFFFF, "GP106M [GeForce GTX 1050 Mobile](0x1C22)"},
{0x10DE, 0x1C23, 0xFFFF, 0xFFFF, "GP106M [GeForce GTX 1060 Mobile Rev. 2](0x1C23)"},
{0x10DE, 0x1C23, 0x1414, 0x0020, "GTX 1060 Mobile(0x1414-0x0020)"},
{0x10DE, 0x1C2D, 0xFFFF, 0xFFFF, "GP106M(0x1C2D)"},
{0x10DE, 0x1C30, 0xFFFF, 0xFFFF, "GP106GL [Quadro P2000](0x1C30)"},
{0x10DE, 0x1C31, 0xFFFF, 0xFFFF, "GP106GL [Quadro P2200](0x1C31)"},
{0x10DE, 0x1C35, 0xFFFF, 0xFFFF, "GP106M [Quadro P2000 Mobile / DRIVE PX 2 AutoChauffeur](0x1C35)"},
{0x10DE, 0x1C36, 0xFFFF, 0xFFFF, "GP106 [P106M](0x1C36)"},
{0x10DE, 0x1C60, 0xFFFF, 0xFFFF, "GP106BM [GeForce GTX 1060 Mobile 6GB](0x1C60)"},
{0x10DE, 0x1C60, 0x103C, 0x8390, "GeForce GTX 1060 Max-Q 6GB(0x103C-0x8390)"},
{0x10DE, 0x1C61, 0xFFFF, 0xFFFF, "GP106BM [GeForce GTX 1050 Ti Mobile](0x1C61)"},
{0x10DE, 0x1C62, 0xFFFF, 0xFFFF, "GP106BM [GeForce GTX 1050 Mobile](0x1C62)"},
{0x10DE, 0x1C70, 0xFFFF, 0xFFFF, "GP106GL(0x1C70)"},
{0x10DE, 0x1C81, 0xFFFF, 0xFFFF, "GP107 [GeForce GTX 1050](0x1C81)"},
{0x10DE, 0x1C82, 0xFFFF, 0xFFFF, "GP107 [GeForce GTX 1050 Ti](0x1C82)"},
{0x10DE, 0x1C82, 0x1043, 0x8613, "PH-GTX1050TI-4G(0x1043-0x8613)"},
{0x10DE, 0x1C82, 0x1458, 0x3763, "GV-N105TOC-4GD(0x1458-0x3763)"},
{0x10DE, 0x1C83, 0xFFFF, 0xFFFF, "GP107 [GeForce GTX 1050 3GB](0x1C83)"},
{0x10DE, 0x1C8C, 0xFFFF, 0xFFFF, "GP107M [GeForce GTX 1050 Ti Mobile](0x1C8C)"},
{0x10DE, 0x1C8D, 0xFFFF, 0xFFFF, "GP107M [GeForce GTX 1050 Mobile](0x1C8D)"},
{0x10DE, 0x1C8E, 0xFFFF, 0xFFFF, "GP107M(0x1C8E)"},
{0x10DE, 0x1C8F, 0xFFFF, 0xFFFF, "GP107M [GeForce GTX 1050 Ti Max-Q](0x1C8F)"},
{0x10DE, 0x1C90, 0xFFFF, 0xFFFF, "GP107M [GeForce MX150](0x1C90)"},
{0x10DE, 0x1C91, 0xFFFF, 0xFFFF, "GP107M [GeForce GTX 1050 3 GB Max-Q](0x1C91)"},
{0x10DE, 0x1C92, 0xFFFF, 0xFFFF, "GP107M [GeForce GTX 1050 Mobile](0x1C92)"},
{0x10DE, 0x1C94, 0xFFFF, 0xFFFF, "GP107M [GeForce MX350](0x1C94)"},
{0x10DE, 0x1C96, 0xFFFF, 0xFFFF, "GP107M [GeForce MX350](0x1C96)"},
{0x10DE, 0x1CA7, 0xFFFF, 0xFFFF, "GP107GL(0x1CA7)"},
{0x10DE, 0x1CA8, 0xFFFF, 0xFFFF, "GP107GL(0x1CA8)"},
{0x10DE, 0x1CAA, 0xFFFF, 0xFFFF, "GP107GL(0x1CAA)"},
{0x10DE, 0x1CB1, 0xFFFF, 0xFFFF, "GP107GL [Quadro P1000](0x1CB1)"},
{0x10DE, 0x1CB2, 0xFFFF, 0xFFFF, "GP107GL [Quadro P600](0x1CB2)"},
{0x10DE, 0x1CB3, 0xFFFF, 0xFFFF, "GP107GL [Quadro P400](0x1CB3)"},
{0x10DE, 0x1CB6, 0xFFFF, 0xFFFF, "GP107GL [Quadro P620](0x1CB6)"},
{0x10DE, 0x1CBA, 0xFFFF, 0xFFFF, "GP107GLM [Quadro P2000 Mobile](0x1CBA)"},
{0x10DE, 0x1CBA, 0x103C, 0x842C, "P2000 [Zbook 15 G5 mobile workstation](0x103C-0x842C)"},
{0x10DE, 0x1CBA, 0x103C, 0x842F, "P2000 [Zbook 17 G5 mobile workstation](0x103C-0x842F)"},
{0x10DE, 0x1CBB, 0xFFFF, 0xFFFF, "GP107GLM [Quadro P1000 Mobile](0x1CBB)"},
{0x10DE, 0x1CBB, 0x103C, 0x8429, "P1000 [Zbook Studio G5 mobile workstation](0x103C-0x8429)"},
{0x10DE, 0x1CBB, 0x103C, 0x842C, "P1000 [Zbook 15 G5 mobile workstation](0x103C-0x842C)"},
{0x10DE, 0x1CBB, 0x103C, 0x842F, "P1000 [Zbook 17 G5 mobile workstation](0x103C-0x842F)"},
{0x10DE, 0x1CBB, 0x103C, 0x8451, "P1000 [Zbook Studio x360 G5 mobile workstation](0x103C-0x8451)"},
{0x10DE, 0x1CBC, 0xFFFF, 0xFFFF, "GP107GLM [Quadro P600 Mobile](0x1CBC)"},
{0x10DE, 0x1CBD, 0xFFFF, 0xFFFF, "GP107GLM [Quadro P620](0x1CBD)"},
{0x10DE, 0x1CCC, 0xFFFF, 0xFFFF, "GP107BM [GeForce GTX 1050 Ti Mobile](0x1CCC)"},
{0x10DE, 0x1CCD, 0xFFFF, 0xFFFF, "GP107BM [GeForce GTX 1050 Mobile](0x1CCD)"},
{0x10DE, 0x1CFA, 0xFFFF, 0xFFFF, "GP107GL [Quadro P2000](0x1CFA)"},
{0x10DE, 0x1CFB, 0xFFFF, 0xFFFF, "GP107GL [Quadro P1000](0x1CFB)"},
{0x10DE, 0x1D01, 0xFFFF, 0xFFFF, "GP108 [GeForce GT 1030](0x1D01)"},
{0x10DE, 0x1D02, 0xFFFF, 0xFFFF, "GP108 [GeForce GT 1010](0x1D02)"},
{0x10DE, 0x1D10, 0xFFFF, 0xFFFF, "GP108M [GeForce MX150](0x1D10)"},
{0x10DE, 0x1D10, 0x17AA, 0x225E, "ThinkPad T480(0x17AA-0x225E)"},
{0x10DE, 0x1D11, 0xFFFF, 0xFFFF, "GP108M [GeForce MX230](0x1D11)"},
{0x10DE, 0x1D12, 0xFFFF, 0xFFFF, "GP108M [GeForce MX150](0x1D12)"},
{0x10DE, 0x1D12, 0x1D72, 0x1701, "Mi Notebook Pro [GeForce MX150](0x1D72-0x1701)"},
{0x10DE, 0x1D13, 0xFFFF, 0xFFFF, "GP108M [GeForce MX250](0x1D13)"},
{0x10DE, 0x1D16, 0xFFFF, 0xFFFF, "GP108M [GeForce MX330](0x1D16)"},
{0x10DE, 0x1D33, 0xFFFF, 0xFFFF, "GP108GLM [Quadro P500 Mobile](0x1D33)"},
{0x10DE, 0x1D34, 0xFFFF, 0xFFFF, "GP108GLM [Quadro P520](0x1D34)"},
{0x10DE, 0x1D52, 0xFFFF, 0xFFFF, "GP108BM [GeForce MX250](0x1D52)"},
{0x10DE, 0x1D56, 0xFFFF, 0xFFFF, "GP108BM [GeForce MX330](0x1D56)"},
{0x10DE, 0x1D81, 0xFFFF, 0xFFFF, "GV100 [TITAN V](0x1D81)"},
{0x10DE, 0x1D83, 0xFFFF, 0xFFFF, "GV100 [CMP 100-200](0x1D83)"},
{0x10DE, 0x1D84, 0xFFFF, 0xFFFF, "GV100 [CMP 100-210](0x1D84)"},
{0x10DE, 0x1DB0, 0xFFFF, 0xFFFF, "GV100GL [Tesla GV100 SXM2-16GB SKU 890](0x1DB0)"},
{0x10DE, 0x1DB1, 0xFFFF, 0xFFFF, "GV100GL [Tesla V100 SXM2 16GB](0x1DB1)"},
{0x10DE, 0x1DB2, 0xFFFF, 0xFFFF, "GV100GL [Tesla V100 DGXS 16GB](0x1DB2)"},
{0x10DE, 0x1DB3, 0xFFFF, 0xFFFF, "GV100GL [Tesla V100 FHHL 16GB](0x1DB3)"},
{0x10DE, 0x1DB4, 0xFFFF, 0xFFFF, "GV100GL [Tesla V100 PCIe 16GB](0x1DB4)"},
{0x10DE, 0x1DB5, 0xFFFF, 0xFFFF, "GV100GL [Tesla V100 SXM2 32GB](0x1DB5)"},
{0x10DE, 0x1DB6, 0xFFFF, 0xFFFF, "GV100GL [Tesla V100 PCIe 32GB](0x1DB6)"},
{0x10DE, 0x1DB7, 0xFFFF, 0xFFFF, "GV100GL [Tesla V100 DGXS 32GB](0x1DB7)"},
{0x10DE, 0x1DB8, 0xFFFF, 0xFFFF, "GV100GL [Tesla V100 SXM3 32GB](0x1DB8)"},
{0x10DE, 0x1DB8, 0x10DE, 0x131D, "Tesla V100-SXM3-32GB-H(0x10DE-0x131D)"},
{0x10DE, 0x1DBA, 0xFFFF, 0xFFFF, "GV100GL [Quadro GV100](0x1DBA)"},
{0x10DE, 0x1DBA, 0x10DE, 0x12EB, "TITAN V CEO Edition(0x10DE-0x12EB)"},
{0x10DE, 0x1DBD, 0xFFFF, 0xFFFF, "GV100GL [Tesla GV100 DGX1-V](0x1DBD)"},
{0x10DE, 0x1DBE, 0xFFFF, 0xFFFF, "GV100 Engineering Sample(0x1DBE)"},
{0x10DE, 0x1DC1, 0xFFFF, 0xFFFF, "GV100 [CMP 100-200](0x1DC1)"},
{0x10DE, 0x1DF0, 0xFFFF, 0xFFFF, "GV100GL [Tesla PG500-216](0x1DF0)"},
{0x10DE, 0x1DF2, 0xFFFF, 0xFFFF, "GV100GL [Tesla PG503-216](0x1DF2)"},
{0x10DE, 0x1DF4, 0xFFFF, 0xFFFF, "GV100 [CMP 100-210](0x1DF4)"},
{0x10DE, 0x1DF5, 0xFFFF, 0xFFFF, "GV100GL [Tesla V100 SXM2 16GB](0x1DF5)"},
{0x10DE, 0x1DF6, 0xFFFF, 0xFFFF, "GV100GL [Tesla V100S PCIe 32GB](0x1DF6)"},
{0x10DE, 0x1E02, 0xFFFF, 0xFFFF, "TU102 [TITAN RTX](0x1E02)"},
{0x10DE, 0x1E03, 0xFFFF, 0xFFFF, "TU102 [GeForce RTX 2080 Ti 12GB](0x1E03)"},
{0x10DE, 0x1E04, 0xFFFF, 0xFFFF, "TU102 [GeForce RTX 2080 Ti](0x1E04)"},
{0x10DE, 0x1E07, 0xFFFF, 0xFFFF, "TU102 [GeForce RTX 2080 Ti Rev. A](0x1E07)"},
{0x10DE, 0x1E07, 0x1462, 0x3715, "RTX 2080 Ti GAMING X TRIO(0x1462-0x3715)"},
{0x10DE, 0x1E09, 0xFFFF, 0xFFFF, "TU102 [CMP 50HX](0x1E09)"},
{0x10DE, 0x1E2D, 0xFFFF, 0xFFFF, "TU102 [GeForce RTX 2080 Ti Engineering Sample](0x1E2D)"},
{0x10DE, 0x1E2E, 0xFFFF, 0xFFFF, "TU102 [GeForce RTX 2080 Ti 12GB Engineering Sample](0x1E2E)"},
{0x10DE, 0x1E30, 0xFFFF, 0xFFFF, "TU102GL [Quadro RTX 6000/8000](0x1E30)"},
{0x10DE, 0x1E30, 0x10DE, 0x129E, "Quadro RTX 8000(0x10DE-0x129E)"},
{0x10DE, 0x1E30, 0x10DE, 0x12BA, "Quadro RTX 6000(0x10DE-0x12BA)"},
{0x10DE, 0x1E35, 0xFFFF, 0xFFFF, "TU102GL [Tesla T10](0x1E35)"},
{0x10DE, 0x1E36, 0xFFFF, 0xFFFF, "TU102GL [Quadro RTX 6000](0x1E36)"},
{0x10DE, 0x1E37, 0xFFFF, 0xFFFF, "TU102GL [Tesla T10 16GB / GRID RTX T10-2/T10-4/T10-8](0x1E37)"},
{0x10DE, 0x1E37, 0x10DE, 0x1304, "Tesla T10 16GB(0x10DE-0x1304)"},
{0x10DE, 0x1E37, 0x10DE, 0x1347, "GRID RTX T10-8(0x10DE-0x1347)"},
{0x10DE, 0x1E37, 0x10DE, 0x1348, "GRID RTX T10-4(0x10DE-0x1348)"},
{0x10DE, 0x1E37, 0x10DE, 0x1349, "GRID RTX T10-2(0x10DE-0x1349)"},
{0x10DE, 0x1E37, 0x10DE, 0x1370, "Tesla T10 16GB(0x10DE-0x1370)"},
{0x10DE, 0x1E37, 0x10DE, 0x13A5, "GRID RTX T10-8(0x10DE-0x13A5)"},
{0x10DE, 0x1E38, 0xFFFF, 0xFFFF, "TU102GL [Tesla T40 24GB](0x1E38)"},
{0x10DE, 0x1E3C, 0xFFFF, 0xFFFF, "TU102GL(0x1E3C)"},
{0x10DE, 0x1E3D, 0xFFFF, 0xFFFF, "TU102GL(0x1E3D)"},
{0x10DE, 0x1E3E, 0xFFFF, 0xFFFF, "TU102GL(0x1E3E)"},
{0x10DE, 0x1E78, 0xFFFF, 0xFFFF, "TU102GL [Quadro RTX 6000/8000](0x1E78)"},
{0x10DE, 0x1E78, 0x10DE, 0x13D8, "Quadro RTX 8000(0x10DE-0x13D8)"},
{0x10DE, 0x1E78, 0x10DE, 0x13D9, "Quadro RTX 6000(0x10DE-0x13D9)"},
{0x10DE, 0x1E81, 0xFFFF, 0xFFFF, "TU104 [GeForce RTX 2080 SUPER](0x1E81)"},
{0x10DE, 0x1E82, 0xFFFF, 0xFFFF, "TU104 [GeForce RTX 2080](0x1E82)"},
{0x10DE, 0x1E84, 0xFFFF, 0xFFFF, "TU104 [GeForce RTX 2070 SUPER](0x1E84)"},
{0x10DE, 0x1E87, 0xFFFF, 0xFFFF, "TU104 [GeForce RTX 2080 Rev. A](0x1E87)"},
{0x10DE, 0x1E89, 0xFFFF, 0xFFFF, "TU104 [GeForce RTX 2060](0x1E89)"},
{0x10DE, 0x1E90, 0xFFFF, 0xFFFF, "TU104M [GeForce RTX 2080 Mobile](0x1E90)"},
{0x10DE, 0x1E91, 0xFFFF, 0xFFFF, "TU104M [GeForce RTX 2070 SUPER Mobile / Max-Q](0x1E91)"},
{0x10DE, 0x1E93, 0xFFFF, 0xFFFF, "TU104M [GeForce RTX 2080 SUPER Mobile / Max-Q](0x1E93)"},
{0x10DE, 0x1EAB, 0xFFFF, 0xFFFF, "TU104M(0x1EAB)"},
{0x10DE, 0x1EAE, 0xFFFF, 0xFFFF, "TU104M [GeForce GTX 2080 Engineering Sample](0x1EAE)"},
{0x10DE, 0x1EB0, 0xFFFF, 0xFFFF, "TU104GL [Quadro RTX 5000](0x1EB0)"},
{0x10DE, 0x1EB1, 0xFFFF, 0xFFFF, "TU104GL [Quadro RTX 4000](0x1EB1)"},
{0x10DE, 0x1EB4, 0xFFFF, 0xFFFF, "TU104GL [T4G](0x1EB4)"},
{0x10DE, 0x1EB5, 0xFFFF, 0xFFFF, "TU104GLM [Quadro RTX 5000 Mobile / Max-Q](0x1EB5)"},
{0x10DE, 0x1EB6, 0xFFFF, 0xFFFF, "TU104GLM [Quadro RTX 4000 Mobile / Max-Q](0x1EB6)"},
{0x10DE, 0x1EB8, 0xFFFF, 0xFFFF, "TU104GL [Tesla T4](0x1EB8)"},
{0x10DE, 0x1EB9, 0xFFFF, 0xFFFF, "TU104GL(0x1EB9)"},
{0x10DE, 0x1EBA, 0xFFFF, 0xFFFF, "TU104GL [PG189 SKU600](0x1EBA)"},
{0x10DE, 0x1EBE, 0xFFFF, 0xFFFF, "TU104GL(0x1EBE)"},
{0x10DE, 0x1EC2, 0xFFFF, 0xFFFF, "TU104 [GeForce RTX 2070 SUPER](0x1EC2)"},
{0x10DE, 0x1EC7, 0xFFFF, 0xFFFF, "TU104 [GeForce RTX 2070 SUPER](0x1EC7)"},
{0x10DE, 0x1ED0, 0xFFFF, 0xFFFF, "TU104BM [GeForce RTX 2080 Mobile](0x1ED0)"},
{0x10DE, 0x1ED1, 0xFFFF, 0xFFFF, "TU104BM [GeForce RTX 2070 SUPER Mobile / Max-Q](0x1ED1)"},
{0x10DE, 0x1ED3, 0xFFFF, 0xFFFF, "TU104BM [GeForce RTX 2080 SUPER Mobile / Max-Q](0x1ED3)"},
{0x10DE, 0x1EF5, 0xFFFF, 0xFFFF, "TU104GLM [Quadro RTX 5000 Mobile Refresh](0x1EF5)"},
{0x10DE, 0x1F02, 0xFFFF, 0xFFFF, "TU106 [GeForce RTX 2070](0x1F02)"},
{0x10DE, 0x1F02, 0x1043, 0x8673, "TURBO RTX 2070(0x1043-0x8673)"},
{0x10DE, 0x1F03, 0xFFFF, 0xFFFF, "TU106 [GeForce RTX 2060 12GB](0x1F03)"},
{0x10DE, 0x1F04, 0xFFFF, 0xFFFF, "TU106(0x1F04)"},
{0x10DE, 0x1F06, 0xFFFF, 0xFFFF, "TU106 [GeForce RTX 2060 SUPER](0x1F06)"},
{0x10DE, 0x1F07, 0xFFFF, 0xFFFF, "TU106 [GeForce RTX 2070 Rev. A](0x1F07)"},
{0x10DE, 0x1F08, 0xFFFF, 0xFFFF, "TU106 [GeForce RTX 2060 Rev. A](0x1F08)"},
{0x10DE, 0x1F09, 0xFFFF, 0xFFFF, "TU106 [GeForce GTX 1660 SUPER](0x1F09)"},
{0x10DE, 0x1F0A, 0xFFFF, 0xFFFF, "TU106 [GeForce GTX 1650](0x1F0A)"},
{0x10DE, 0x1F0B, 0xFFFF, 0xFFFF, "TU106 [CMP 40HX](0x1F0B)"},
{0x10DE, 0x1F10, 0xFFFF, 0xFFFF, "TU106M [GeForce RTX 2070 Mobile](0x1F10)"},
{0x10DE, 0x1F11, 0xFFFF, 0xFFFF, "TU106M [GeForce RTX 2060 Mobile](0x1F11)"},
{0x10DE, 0x1F12, 0xFFFF, 0xFFFF, "TU106M [GeForce RTX 2060 Max-Q](0x1F12)"},
{0x10DE, 0x1F14, 0xFFFF, 0xFFFF, "TU106M [GeForce RTX 2070 Mobile / Max-Q Refresh](0x1F14)"},
{0x10DE, 0x1F15, 0xFFFF, 0xFFFF, "TU106M [GeForce RTX 2060 Mobile](0x1F15)"},
{0x10DE, 0x1F2E, 0xFFFF, 0xFFFF, "TU106M(0x1F2E)"},
{0x10DE, 0x1F36, 0xFFFF, 0xFFFF, "TU106GLM [Quadro RTX 3000 Mobile / Max-Q](0x1F36)"},
{0x10DE, 0x1F42, 0xFFFF, 0xFFFF, "TU106 [GeForce RTX 2060 SUPER](0x1F42)"},
{0x10DE, 0x1F47, 0xFFFF, 0xFFFF, "TU106 [GeForce RTX 2060 SUPER](0x1F47)"},
{0x10DE, 0x1F50, 0xFFFF, 0xFFFF, "TU106BM [GeForce RTX 2070 Mobile / Max-Q](0x1F50)"},
{0x10DE, 0x1F51, 0xFFFF, 0xFFFF, "TU106BM [GeForce RTX 2060 Mobile](0x1F51)"},
{0x10DE, 0x1F54, 0xFFFF, 0xFFFF, "TU106BM [GeForce RTX 2070 Mobile](0x1F54)"},
{0x10DE, 0x1F55, 0xFFFF, 0xFFFF, "TU106BM [GeForce RTX 2060 Mobile](0x1F55)"},
{0x10DE, 0x1F76, 0xFFFF, 0xFFFF, "TU106GLM [Quadro RTX 3000 Mobile Refresh](0x1F76)"},
{0x10DE, 0x1F81, 0xFFFF, 0xFFFF, "TU117(0x1F81)"},
{0x10DE, 0x1F82, 0xFFFF, 0xFFFF, "TU117 [GeForce GTX 1650](0x1F82)"},
{0x10DE, 0x1F83, 0xFFFF, 0xFFFF, "TU117 [GeForce GTX 1630](0x1F83)"},
{0x10DE, 0x1F91, 0xFFFF, 0xFFFF, "TU117M [GeForce GTX 1650 Mobile / Max-Q](0x1F91)"},
{0x10DE, 0x1F92, 0xFFFF, 0xFFFF, "TU117M [GeForce GTX 1650 Mobile](0x1F92)"},
{0x10DE, 0x1F94, 0xFFFF, 0xFFFF, "TU117M [GeForce GTX 1650 Mobile](0x1F94)"},
{0x10DE, 0x1F95, 0xFFFF, 0xFFFF, "TU117M [GeForce GTX 1650 Ti Mobile](0x1F95)"},
{0x10DE, 0x1F96, 0xFFFF, 0xFFFF, "TU117M [GeForce GTX 1650 Mobile / Max-Q](0x1F96)"},
{0x10DE, 0x1F97, 0xFFFF, 0xFFFF, "TU117M [GeForce MX450](0x1F97)"},
{0x10DE, 0x1F98, 0xFFFF, 0xFFFF, "TU117M [GeForce MX450](0x1F98)"},
{0x10DE, 0x1F99, 0xFFFF, 0xFFFF, "TU117M [GeForce GTX 1650 Mobile / Max-Q](0x1F99)"},
{0x10DE, 0x1F9C, 0xFFFF, 0xFFFF, "TU117M [GeForce MX450](0x1F9C)"},
{0x10DE, 0x1F9D, 0xFFFF, 0xFFFF, "TU117M [GeForce GTX 1650 Mobile / Max-Q](0x1F9D)"},
{0x10DE, 0x1F9F, 0xFFFF, 0xFFFF, "TU117M [GeForce MX550](0x1F9F)"},
{0x10DE, 0x1FA0, 0xFFFF, 0xFFFF, "TU117M [GeForce MX550](0x1FA0)"},
{0x10DE, 0x1FA1, 0xFFFF, 0xFFFF, "TU117M(0x1FA1)"},
{0x10DE, 0x1FAE, 0xFFFF, 0xFFFF, "TU117GL(0x1FAE)"},
{0x10DE, 0x1FB0, 0xFFFF, 0xFFFF, "TU117GLM [Quadro T1000 Mobile](0x1FB0)"},
{0x10DE, 0x1FB1, 0xFFFF, 0xFFFF, "TU117GL [T600](0x1FB1)"},
{0x10DE, 0x1FB2, 0xFFFF, 0xFFFF, "TU117GLM [Quadro T400 Mobile](0x1FB2)"},
{0x10DE, 0x1FB6, 0xFFFF, 0xFFFF, "TU117GLM [T600 Laptop GPU](0x1FB6)"},
{0x10DE, 0x1FB6, 0x1028, 0x0B10, "Precision 3571(0x1028-0x0B10)"},
{0x10DE, 0x1FB7, 0xFFFF, 0xFFFF, "TU117GLM [T550 Laptop GPU](0x1FB7)"},
{0x10DE, 0x1FB8, 0xFFFF, 0xFFFF, "TU117GLM [Quadro T2000 Mobile / Max-Q](0x1FB8)"},
{0x10DE, 0x1FB9, 0xFFFF, 0xFFFF, "TU117GLM [Quadro T1000 Mobile](0x1FB9)"},
{0x10DE, 0x1FBA, 0xFFFF, 0xFFFF, "TU117GLM [T600 Mobile](0x1FBA)"},
{0x10DE, 0x1FBB, 0xFFFF, 0xFFFF, "TU117GLM [Quadro T500 Mobile](0x1FBB)"},
{0x10DE, 0x1FBC, 0xFFFF, 0xFFFF, "TU117GLM [T1200 Laptop GPU](0x1FBC)"},
{0x10DE, 0x1FBF, 0xFFFF, 0xFFFF, "TU117GL(0x1FBF)"},
{0x10DE, 0x1FD9, 0xFFFF, 0xFFFF, "TU117BM [GeForce GTX 1650 Mobile Refresh](0x1FD9)"},
{0x10DE, 0x1FDD, 0xFFFF, 0xFFFF, "TU117BM [GeForce GTX 1650 Mobile Refresh](0x1FDD)"},
{0x10DE, 0x1FF0, 0xFFFF, 0xFFFF, "TU117GL [T1000 8GB](0x1FF0)"},
{0x10DE, 0x1FF2, 0xFFFF, 0xFFFF, "TU117GL [T400 4GB / T400E](0x1FF2)"},
{0x10DE, 0x1FF9, 0xFFFF, 0xFFFF, "TU117GLM [Quadro T1000 Mobile](0x1FF9)"},
{0x10DE, 0x2080, 0xFFFF, 0xFFFF, "GA100(0x2080)"},
{0x10DE, 0x2081, 0xFFFF, 0xFFFF, "GA100(0x2081)"},
{0x10DE, 0x2082, 0xFFFF, 0xFFFF, "GA100 [CMP 170HX](0x2082)"},
{0x10DE, 0x20B0, 0xFFFF, 0xFFFF, "GA100 [A100 SXM4 40GB](0x20B0)"},
{0x10DE, 0x20B1, 0xFFFF, 0xFFFF, "GA100 [A100 PCIe 40GB](0x20B1)"},
{0x10DE, 0x20B2, 0xFFFF, 0xFFFF, "GA100 [A100 SXM4 80GB](0x20B2)"},
{0x10DE, 0x20B3, 0xFFFF, 0xFFFF, "GA100 [A100-SXM-64GB](0x20B3)"},
{0x10DE, 0x20B4, 0xFFFF, 0xFFFF, "GA100(0x20B4)"},
{0x10DE, 0x20B5, 0xFFFF, 0xFFFF, "GA100 [A100 PCIe 80GB](0x20B5)"},
{0x10DE, 0x20B6, 0xFFFF, 0xFFFF, "GA100GL [PG506-232](0x20B6)"},
{0x10DE, 0x20B7, 0xFFFF, 0xFFFF, "GA100GL [A30 PCIe](0x20B7)"},
{0x10DE, 0x20B8, 0xFFFF, 0xFFFF, "GA100 [A100X](0x20B8)"},
{0x10DE, 0x20B9, 0xFFFF, 0xFFFF, "GA100 [A30X](0x20B9)"},
{0x10DE, 0x20BB, 0xFFFF, 0xFFFF, "GA100 [DRIVE A100 PROD](0x20BB)"},
{0x10DE, 0x20BD, 0xFFFF, 0xFFFF, "GA100 [A800 SXM4 40GB](0x20BD)"},
{0x10DE, 0x20BE, 0xFFFF, 0xFFFF, "GA100 [GRID A100A](0x20BE)"},
{0x10DE, 0x20BF, 0xFFFF, 0xFFFF, "GA100 [GRID A100B](0x20BF)"},
{0x10DE, 0x20C0, 0xFFFF, 0xFFFF, "GA100 [Initial DevID](0x20C0)"},
{0x10DE, 0x20C2, 0xFFFF, 0xFFFF, "GA100 [CMP 170HX](0x20C2)"},
{0x10DE, 0x20F0, 0xFFFF, 0xFFFF, "GA100 [A100-PG506-207](0x20F0)"},
{0x10DE, 0x20F1, 0xFFFF, 0xFFFF, "GA100 [A100 PCIe 40GB](0x20F1)"},
{0x10DE, 0x20F2, 0xFFFF, 0xFFFF, "GA100 [A100-PG506-217](0x20F2)"},
{0x10DE, 0x20F3, 0xFFFF, 0xFFFF, "GA100 [A800-SXM4-80GB](0x20F3)"},
{0x10DE, 0x20F5, 0xFFFF, 0xFFFF, "GA100 [A800 80GB PCIe](0x20F5)"},
{0x10DE, 0x20F6, 0xFFFF, 0xFFFF, "GA100 [A800 40GB PCIe](0x20F6)"},
{0x10DE, 0x20FD, 0xFFFF, 0xFFFF, "GA100 [AX800 Converged Accelerator](0x20FD)"},
{0x10DE, 0x20FE, 0xFFFF, 0xFFFF, "GA100 [INT SKU](0x20FE)"},
{0x10DE, 0x20FF, 0xFFFF, 0xFFFF, "GA100(0x20FF)"},
{0x10DE, 0x2182, 0xFFFF, 0xFFFF, "TU116 [GeForce GTX 1660 Ti](0x2182)"},
{0x10DE, 0x2183, 0xFFFF, 0xFFFF, "TU116(0x2183)"},
{0x10DE, 0x2184, 0xFFFF, 0xFFFF, "TU116 [GeForce GTX 1660](0x2184)"},
{0x10DE, 0x2187, 0xFFFF, 0xFFFF, "TU116 [GeForce GTX 1650 SUPER](0x2187)"},
{0x10DE, 0x2188, 0xFFFF, 0xFFFF, "TU116 [GeForce GTX 1650](0x2188)"},
{0x10DE, 0x2189, 0xFFFF, 0xFFFF, "TU116 [CMP 30HX](0x2189)"},
{0x10DE, 0x2191, 0xFFFF, 0xFFFF, "TU116M [GeForce GTX 1660 Ti Mobile](0x2191)"},
{0x10DE, 0x2192, 0xFFFF, 0xFFFF, "TU116M [GeForce GTX 1650 Ti Mobile](0x2192)"},
{0x10DE, 0x21AE, 0xFFFF, 0xFFFF, "TU116GL(0x21AE)"},
{0x10DE, 0x21BF, 0xFFFF, 0xFFFF, "TU116GL(0x21BF)"},
{0x10DE, 0x21C2, 0xFFFF, 0xFFFF, "TU116(0x21C2)"},
{0x10DE, 0x21C3, 0xFFFF, 0xFFFF, "TU116(0x21C3)"},
{0x10DE, 0x21C4, 0xFFFF, 0xFFFF, "TU116 [GeForce GTX 1660 SUPER](0x21C4)"},
{0x10DE, 0x21D1, 0xFFFF, 0xFFFF, "TU116BM [GeForce GTX 1660 Ti Mobile](0x21D1)"},
{0x10DE, 0x2200, 0xFFFF, 0xFFFF, "GA102(0x2200)"},
{0x10DE, 0x2203, 0xFFFF, 0xFFFF, "GA102 [GeForce RTX 3090 Ti](0x2203)"},
{0x10DE, 0x2204, 0xFFFF, 0xFFFF, "GA102 [GeForce RTX 3090](0x2204)"},
{0x10DE, 0x2204, 0x147D, 0x10DE, "NVIDIA Geforce RTX 3090 Founders Edition(0x147D-0x10DE)"},
{0x10DE, 0x2205, 0xFFFF, 0xFFFF, "GA102 [GeForce RTX 3080 Ti 20GB](0x2205)"},
{0x10DE, 0x2206, 0xFFFF, 0xFFFF, "GA102 [GeForce RTX 3080](0x2206)"},
{0x10DE, 0x2206, 0x10DE, 0x1467, "GA102 [GeForce RTX 3080](0x10DE-0x1467)"},
{0x10DE, 0x2206, 0x10DE, 0x146D, "GA102 [GeForce RTX 3080 20GB](0x10DE-0x146D)"},
{0x10DE, 0x2206, 0x1462, 0x3892, "RTX 3080 10GB GAMING X TRIO(0x1462-0x3892)"},
{0x10DE, 0x2207, 0xFFFF, 0xFFFF, "GA102 [GeForce RTX 3070 Ti](0x2207)"},
{0x10DE, 0x2208, 0xFFFF, 0xFFFF, "GA102 [GeForce RTX 3080 Ti](0x2208)"},
{0x10DE, 0x220A, 0xFFFF, 0xFFFF, "GA102 [GeForce RTX 3080 12GB](0x220A)"},
{0x10DE, 0x220D, 0xFFFF, 0xFFFF, "GA102 [CMP 90HX](0x220D)"},
{0x10DE, 0x2216, 0xFFFF, 0xFFFF, "GA102 [GeForce RTX 3080 Lite Hash Rate](0x2216)"},
{0x10DE, 0x222B, 0xFFFF, 0xFFFF, "GA102 [GeForce RTX 3090 Engineering Sample](0x222B)"},
{0x10DE, 0x222F, 0xFFFF, 0xFFFF, "GA102 [GeForce RTX 3080 11GB / 12GB Engineering Sample](0x222F)"},
{0x10DE, 0x2230, 0xFFFF, 0xFFFF, "GA102GL [RTX A6000](0x2230)"},
{0x10DE, 0x2231, 0xFFFF, 0xFFFF, "GA102GL [RTX A5000](0x2231)"},
{0x10DE, 0x2232, 0xFFFF, 0xFFFF, "GA102GL [RTX A4500](0x2232)"},
{0x10DE, 0x2233, 0xFFFF, 0xFFFF, "GA102GL [RTX A5500](0x2233)"},
{0x10DE, 0x2235, 0xFFFF, 0xFFFF, "GA102GL [A40](0x2235)"},
{0x10DE, 0x2236, 0xFFFF, 0xFFFF, "GA102GL [A10](0x2236)"},
{0x10DE, 0x2237, 0xFFFF, 0xFFFF, "GA102GL [A10G](0x2237)"},
{0x10DE, 0x2238, 0xFFFF, 0xFFFF, "GA102GL [A10M](0x2238)"},
{0x10DE, 0x223F, 0xFFFF, 0xFFFF, "GA102GL(0x223F)"},
{0x10DE, 0x228B, 0xFFFF, 0xFFFF, "GA104 High Definition Audio Controller(0x228B)"},
{0x10DE, 0x228E, 0xFFFF, 0xFFFF, "GA106 High Definition Audio Controller(0x228E)"},
{0x10DE, 0x2296, 0xFFFF, 0xFFFF, "Tegra PCIe Endpoint Virtual Network(0x2296)"},
{0x10DE, 0x22A3, 0xFFFF, 0xFFFF, "GH100 [H100 NVSwitch](0x22A3)"},
{0x10DE, 0x22BA, 0xFFFF, 0xFFFF, "AD102 High Definition Audio Controller(0x22BA)"},
{0x10DE, 0x22BC, 0xFFFF, 0xFFFF, "AD104 High Definition Audio Controller(0x22BC)"},
{0x10DE, 0x22BD, 0xFFFF, 0xFFFF, "AD106M High Definition Audio Controller(0x22BD)"},
{0x10DE, 0x2302, 0xFFFF, 0xFFFF, "GH100(0x2302)"},
{0x10DE, 0x2313, 0xFFFF, 0xFFFF, "GH100 [H100 CNX](0x2313)"},
{0x10DE, 0x2321, 0xFFFF, 0xFFFF, "GH100 [H100L 94GB](0x2321)"},
{0x10DE, 0x2322, 0xFFFF, 0xFFFF, "GH100 [H800 PCIe](0x2322)"},
{0x10DE, 0x2324, 0xFFFF, 0xFFFF, "GH100 [H800](0x2324)"},
{0x10DE, 0x2329, 0xFFFF, 0xFFFF, "GH100 [H20](0x2329)"},
{0x10DE, 0x2330, 0xFFFF, 0xFFFF, "GH100 [H100 SXM5 80GB](0x2330)"},
{0x10DE, 0x2331, 0xFFFF, 0xFFFF, "GH100 [H100 PCIe](0x2331)"},
{0x10DE, 0x2335, 0xFFFF, 0xFFFF, "GH100 [H200 SXM 141GB](0x2335)"},
{0x10DE, 0x2336, 0xFFFF, 0xFFFF, "GH100 [H100](0x2336)"},
{0x10DE, 0x2337, 0xFFFF, 0xFFFF, "GH100 [H100 SXM5 64GB](0x2337)"},
{0x10DE, 0x2338, 0xFFFF, 0xFFFF, "GH100 [H100 SXM5 96GB](0x2338)"},
{0x10DE, 0x2339, 0xFFFF, 0xFFFF, "GH100 [H100 SXM5 94GB](0x2339)"},
{0x10DE, 0x233A, 0xFFFF, 0xFFFF, "GH100 [H800L 94GB](0x233A)"},
{0x10DE, 0x233D, 0xFFFF, 0xFFFF, "GH100 [H100 96GB](0x233D)"},
{0x10DE, 0x2342, 0xFFFF, 0xFFFF, "GH100 [GH200 120GB / 480GB](0x2342)"},
{0x10DE, 0x2343, 0xFFFF, 0xFFFF, "GH100(0x2343)"},
{0x10DE, 0x2345, 0xFFFF, 0xFFFF, "GH100 [GH100-88K-A1](0x2345)"},
{0x10DE, 0x237F, 0xFFFF, 0xFFFF, "GH100 [Skinny Joe](0x237F)"},
{0x10DE, 0x23B0, 0xFFFF, 0xFFFF, "GH100(0x23B0)"},
{0x10DE, 0x23F0, 0xFFFF, 0xFFFF, "GH100(0x23F0)"},
{0x10DE, 0x2414, 0xFFFF, 0xFFFF, "GA103 [GeForce RTX 3060 Ti](0x2414)"},
{0x10DE, 0x2420, 0xFFFF, 0xFFFF, "GA103M [GeForce RTX 3080 Ti Mobile](0x2420)"},
{0x10DE, 0x2438, 0xFFFF, 0xFFFF, "GA103GLM [RTX A5500 Laptop GPU](0x2438)"},
{0x10DE, 0x2460, 0xFFFF, 0xFFFF, "GA103M [GeForce RTX 3080 Ti Laptop GPU](0x2460)"},
{0x10DE, 0x2480, 0xFFFF, 0xFFFF, "GA104 [Reserved Dev ID A](0x2480)"},
{0x10DE, 0x2482, 0xFFFF, 0xFFFF, "GA104 [GeForce RTX 3070 Ti](0x2482)"},
{0x10DE, 0x2483, 0xFFFF, 0xFFFF, "GA104(0x2483)"},
{0x10DE, 0x2484, 0xFFFF, 0xFFFF, "GA104 [GeForce RTX 3070](0x2484)"},
{0x10DE, 0x2484, 0x10DE, 0x146B, "GA104 [GeForce RTX 3070](0x10DE-0x146B)"},
{0x10DE, 0x2484, 0x10DE, 0x14AE, "GA104 [GeForce RTX 3070 16GB](0x10DE-0x14AE)"},
{0x10DE, 0x2486, 0xFFFF, 0xFFFF, "GA104 [GeForce RTX 3060 Ti](0x2486)"},
{0x10DE, 0x2486, 0x19DA, 0x6630, "ZT-A30610H-10M [RTX 3060 Ti Twin Edge OC](0x19DA-0x6630)"},
{0x10DE, 0x2487, 0xFFFF, 0xFFFF, "GA104 [GeForce RTX 3060](0x2487)"},
{0x10DE, 0x2488, 0xFFFF, 0xFFFF, "GA104 [GeForce RTX 3070 Lite Hash Rate](0x2488)"},
{0x10DE, 0x2489, 0xFFFF, 0xFFFF, "GA104 [GeForce RTX 3060 Ti Lite Hash Rate](0x2489)"},
{0x10DE, 0x248A, 0xFFFF, 0xFFFF, "GA104 [CMP 70HX](0x248A)"},
{0x10DE, 0x248C, 0xFFFF, 0xFFFF, "GA104 [GeForce RTX 3070 Ti](0x248C)"},
{0x10DE, 0x248D, 0xFFFF, 0xFFFF, "GA104 [GeForce RTX 3070](0x248D)"},
{0x10DE, 0x248E, 0xFFFF, 0xFFFF, "GA104 [GeForce RTX 3060 Ti](0x248E)"},
{0x10DE, 0x249C, 0xFFFF, 0xFFFF, "GA104M [GeForce RTX 3080 Mobile / Max-Q 8GB/16GB](0x249C)"},
{0x10DE, 0x249D, 0xFFFF, 0xFFFF, "GA104M [GeForce RTX 3070 Mobile / Max-Q](0x249D)"},
{0x10DE, 0x249F, 0xFFFF, 0xFFFF, "GA104M(0x249F)"},
{0x10DE, 0x24A0, 0xFFFF, 0xFFFF, "GA104 [Geforce RTX 3070 Ti Laptop GPU](0x24A0)"},
{0x10DE, 0x24A4, 0xFFFF, 0xFFFF, "GA104M(0x24A4)"},
{0x10DE, 0x24AC, 0xFFFF, 0xFFFF, "GA104 [GeForce RTX 30x0 Engineering Sample](0x24AC)"},
{0x10DE, 0x24AD, 0xFFFF, 0xFFFF, "GA104 [GeForce RTX 3060 Engineering Sample](0x24AD)"},
{0x10DE, 0x24AF, 0xFFFF, 0xFFFF, "GA104 [GeForce RTX 3070 Engineering Sample](0x24AF)"},
{0x10DE, 0x24B0, 0xFFFF, 0xFFFF, "GA104GL [RTX A4000](0x24B0)"},
{0x10DE, 0x24B1, 0xFFFF, 0xFFFF, "GA104GL [RTX A4000H](0x24B1)"},
{0x10DE, 0x24B6, 0xFFFF, 0xFFFF, "GA104GLM [RTX A5000 Mobile](0x24B6)"},
{0x10DE, 0x24B7, 0xFFFF, 0xFFFF, "GA104GLM [RTX A4000 Mobile](0x24B7)"},
{0x10DE, 0x24B8, 0xFFFF, 0xFFFF, "GA104GLM [RTX A3000 Mobile](0x24B8)"},
{0x10DE, 0x24B9, 0xFFFF, 0xFFFF, "GA104GLM [RTX A3000 12GB Laptop GPU](0x24B9)"},
{0x10DE, 0x24BA, 0xFFFF, 0xFFFF, "GA104GLM [RTX A4500 Laptop GPU](0x24BA)"},
{0x10DE, 0x24BB, 0xFFFF, 0xFFFF, "GA104GLM [RTX A3000 Laptop GPU](0x24BB)"},
{0x10DE, 0x24BF, 0xFFFF, 0xFFFF, "GA104 [GeForce RTX 3070 Engineering Sample](0x24BF)"},
{0x10DE, 0x24C0, 0xFFFF, 0xFFFF, "GA104 [Initial Dev ID B](0x24C0)"},
{0x10DE, 0x24C7, 0xFFFF, 0xFFFF, "GA104 [GeForce RTX 3060 8GB](0x24C7)"},
{0x10DE, 0x24C8, 0xFFFF, 0xFFFF, "GA104 [GeForce RTX 3070 GDDR6X](0x24C8)"},
{0x10DE, 0x24C9, 0xFFFF, 0xFFFF, "GA104 [GeForce RTX 3060 Ti GDDR6X](0x24C9)"},
{0x10DE, 0x24DC, 0xFFFF, 0xFFFF, "GA104M [GeForce RTX 3080 Mobile / Max-Q 8GB/16GB](0x24DC)"},
{0x10DE, 0x24DD, 0xFFFF, 0xFFFF, "GA104M [GeForce RTX 3070 Mobile / Max-Q](0x24DD)"},
{0x10DE, 0x24DF, 0xFFFF, 0xFFFF, "GA104M(0x24DF)"},
{0x10DE, 0x24E0, 0xFFFF, 0xFFFF, "GA104M [Geforce RTX 3070 Ti Laptop GPU](0x24E0)"},
{0x10DE, 0x24FA, 0xFFFF, 0xFFFF, "GA104 [RTX A4500 Embedded GPU ](0x24FA)"},
{0x10DE, 0x2501, 0xFFFF, 0xFFFF, "GA106 [GeForce RTX 3060](0x2501)"},
{0x10DE, 0x2503, 0xFFFF, 0xFFFF, "GA106 [GeForce RTX 3060](0x2503)"},
{0x10DE, 0x2504, 0xFFFF, 0xFFFF, "GA106 [GeForce RTX 3060 Lite Hash Rate](0x2504)"},
{0x10DE, 0x2505, 0xFFFF, 0xFFFF, "GA106(0x2505)"},
{0x10DE, 0x2507, 0xFFFF, 0xFFFF, "GA106 [Geforce RTX 3050](0x2507)"},
{0x10DE, 0x2508, 0xFFFF, 0xFFFF, "GA106 [GeForce RTX 3050 OEM](0x2508)"},
{0x10DE, 0x2509, 0xFFFF, 0xFFFF, "GA106 [GeForce RTX 3060 12GB Rev. 2](0x2509)"},
{0x10DE, 0x2520, 0xFFFF, 0xFFFF, "GA106M [GeForce RTX 3060 Mobile / Max-Q](0x2520)"},
{0x10DE, 0x2521, 0xFFFF, 0xFFFF, "GA106M [GeForce RTX 3060 Laptop GPU](0x2521)"},
{0x10DE, 0x2523, 0xFFFF, 0xFFFF, "GA106M [GeForce RTX 3050 Ti Mobile / Max-Q](0x2523)"},
{0x10DE, 0x252F, 0xFFFF, 0xFFFF, "GA106 [GeForce RTX 3060 Engineering Sample](0x252F)"},
{0x10DE, 0x2531, 0xFFFF, 0xFFFF, "GA106 [RTX A2000](0x2531)"},
{0x10DE, 0x2544, 0xFFFF, 0xFFFF, "GA106 [GeForce RTX 3060](0x2544)"},
{0x10DE, 0x2560, 0xFFFF, 0xFFFF, "GA106M [GeForce RTX 3060 Mobile / Max-Q](0x2560)"},
{0x10DE, 0x2561, 0xFFFF, 0xFFFF, "GA106M [GeForce RTX 3060 Laptop GPU](0x2561)"},
{0x10DE, 0x2563, 0xFFFF, 0xFFFF, "GA106M [GeForce RTX 3050 Ti Mobile / Max-Q](0x2563)"},
{0x10DE, 0x2571, 0xFFFF, 0xFFFF, "GA106 [RTX A2000 12GB](0x2571)"},
{0x10DE, 0x2582, 0xFFFF, 0xFFFF, "GA107 [GeForce RTX 3050 8GB](0x2582)"},
{0x10DE, 0x2583, 0xFFFF, 0xFFFF, "GA107 [GeForce RTX 3050 4GB](0x2583)"},
{0x10DE, 0x2584, 0xFFFF, 0xFFFF, "GA107 [GeForce RTX 3050 6GB](0x2584)"},
{0x10DE, 0x25A0, 0xFFFF, 0xFFFF, "GA107M [GeForce RTX 3050 Ti Mobile](0x25A0)"},
{0x10DE, 0x25A2, 0xFFFF, 0xFFFF, "GA107M [GeForce RTX 3050 Mobile](0x25A2)"},
{0x10DE, 0x25A3, 0xFFFF, 0xFFFF, "GA107(0x25A3)"},
{0x10DE, 0x25A4, 0xFFFF, 0xFFFF, "GA107(0x25A4)"},
{0x10DE, 0x25A5, 0xFFFF, 0xFFFF, "GA107M [GeForce RTX 3050 Mobile](0x25A5)"},
{0x10DE, 0x25A6, 0xFFFF, 0xFFFF, "GA107M [GeForce MX570](0x25A6)"},
{0x10DE, 0x25A7, 0xFFFF, 0xFFFF, "GA107M [GeForce MX570](0x25A7)"},
{0x10DE, 0x25A9, 0xFFFF, 0xFFFF, "GA107M [GeForce RTX 2050](0x25A9)"},
{0x10DE, 0x25AA, 0xFFFF, 0xFFFF, "GA107M [GeForce MX570 A](0x25AA)"},
{0x10DE, 0x25AB, 0xFFFF, 0xFFFF, "GA107M [GeForce RTX 3050 4GB Laptop GPU](0x25AB)"},
{0x10DE, 0x25AC, 0xFFFF, 0xFFFF, "GN20-P0-R-K2 [GeForce RTX 3050 6GB Laptop GPU](0x25AC)"},
{0x10DE, 0x25AD, 0xFFFF, 0xFFFF, "GA107 [GeForce RTX 2050](0x25AD)"},
{0x10DE, 0x25AF, 0xFFFF, 0xFFFF, "GA107 [GeForce RTX 3050 Engineering Sample](0x25AF)"},
{0x10DE, 0x25B0, 0xFFFF, 0xFFFF, "GA107GL [RTX A1000](0x25B0)"},
{0x10DE, 0x25B2, 0xFFFF, 0xFFFF, "GA107GL [RTX A400](0x25B2)"},
{0x10DE, 0x25B5, 0xFFFF, 0xFFFF, "GA107GLM [RTX A4 Mobile](0x25B5)"},
{0x10DE, 0x25B6, 0xFFFF, 0xFFFF, "GA107GL [A2 / A16](0x25B6)"},
{0x10DE, 0x25B8, 0xFFFF, 0xFFFF, "GA107GLM [RTX A2000 Mobile](0x25B8)"},
{0x10DE, 0x25B9, 0xFFFF, 0xFFFF, "GA107GLM [RTX A1000 Laptop GPU](0x25B9)"},
{0x10DE, 0x25BA, 0xFFFF, 0xFFFF, "GA107GLM [RTX A2000 8GB Laptop GPU](0x25BA)"},
{0x10DE, 0x25BB, 0xFFFF, 0xFFFF, "GA107GLM [RTX A500 Laptop GPU](0x25BB)"},
{0x10DE, 0x25BC, 0xFFFF, 0xFFFF, "GA107GLM [RTX A1000 6GB Laptop GPU](0x25BC)"},
{0x10DE, 0x25BD, 0xFFFF, 0xFFFF, "GA107GLM [RTX A500 Laptop GPU](0x25BD)"},
{0x10DE, 0x25E0, 0xFFFF, 0xFFFF, "GA107BM [GeForce RTX 3050 Ti Mobile](0x25E0)"},
{0x10DE, 0x25E2, 0xFFFF, 0xFFFF, "GA107BM [GeForce RTX 3050 Mobile](0x25E2)"},
{0x10DE, 0x25E5, 0xFFFF, 0xFFFF, "GA107BM [GeForce RTX 3050 Mobile](0x25E5)"},
{0x10DE, 0x25EC, 0xFFFF, 0xFFFF, "GN20-P0-R-K2 [GeForce RTX 3050 6GB Laptop GPU](0x25EC)"},
{0x10DE, 0x25ED, 0xFFFF, 0xFFFF, "GA107 [GeForce RTX 2050](0x25ED)"},
{0x10DE, 0x25F9, 0xFFFF, 0xFFFF, "GA107 [RTX A1000 Embedded GPU ](0x25F9)"},
{0x10DE, 0x25FA, 0xFFFF, 0xFFFF, "GA107 [RTX A2000 Embedded GPU](0x25FA)"},
{0x10DE, 0x25FB, 0xFFFF, 0xFFFF, "GA107 [RTX A500 Embedded GPU](0x25FB)"},
{0x10DE, 0x2681, 0xFFFF, 0xFFFF, "AD102 [RTX TITAN Ada](0x2681)"},
{0x10DE, 0x2684, 0xFFFF, 0xFFFF, "AD102 [GeForce RTX 4090](0x2684)"},
{0x10DE, 0x2685, 0xFFFF, 0xFFFF, "AD102 [GeForce RTX 4090 D](0x2685)"},
{0x10DE, 0x2689, 0xFFFF, 0xFFFF, "AD102 [GeForce RTX 4070 Ti SUPER](0x2689)"},
{0x10DE, 0x26B1, 0xFFFF, 0xFFFF, "AD102GL [RTX 6000 Ada Generation](0x26B1)"},
{0x10DE, 0x26B2, 0xFFFF, 0xFFFF, "AD102GL [RTX 5000 Ada Generation](0x26B2)"},
{0x10DE, 0x26B3, 0xFFFF, 0xFFFF, "AD102GL [RTX 5880 Ada Generation](0x26B3)"},
{0x10DE, 0x26B5, 0xFFFF, 0xFFFF, "AD102GL [L40](0x26B5)"},
{0x10DE, 0x26B7, 0xFFFF, 0xFFFF, "AD102GL [L20](0x26B7)"},
{0x10DE, 0x26B8, 0xFFFF, 0xFFFF, "AD102GL [L40G](0x26B8)"},
{0x10DE, 0x26B9, 0xFFFF, 0xFFFF, "AD102GL [L40S](0x26B9)"},
{0x10DE, 0x26BA, 0xFFFF, 0xFFFF, "AD102GL [L20](0x26BA)"},
{0x10DE, 0x26F5, 0xFFFF, 0xFFFF, "AD102GL [L40 CNX](0x26F5)"},
{0x10DE, 0x2702, 0xFFFF, 0xFFFF, "AD103 [GeForce RTX 4080 SUPER](0x2702)"},
{0x10DE, 0x2703, 0xFFFF, 0xFFFF, "AD103 [GeForce RTX 4080 SUPER](0x2703)"},
{0x10DE, 0x2704, 0xFFFF, 0xFFFF, "AD103 [GeForce RTX 4080](0x2704)"},
{0x10DE, 0x2705, 0xFFFF, 0xFFFF, "AD103 [GeForce RTX 4070 Ti SUPER](0x2705)"},
{0x10DE, 0x2709, 0xFFFF, 0xFFFF, "AD103 [GeForce RTX 4070](0x2709)"},
{0x10DE, 0x2717, 0xFFFF, 0xFFFF, "GN21-X11 [GeForce RTX 4090 Laptop GPU](0x2717)"},
{0x10DE, 0x2730, 0xFFFF, 0xFFFF, "AD103GLM [RTX 5000 Ada Generation Laptop GPU](0x2730)"},
{0x10DE, 0x2757, 0xFFFF, 0xFFFF, "GN21-X11(0x2757)"},
{0x10DE, 0x2770, 0xFFFF, 0xFFFF, "AD103GLM [RTX 5000 Ada Generation Embedded GPU](0x2770)"},
{0x10DE, 0x2782, 0xFFFF, 0xFFFF, "AD104 [GeForce RTX 4070 Ti](0x2782)"},
{0x10DE, 0x2783, 0xFFFF, 0xFFFF, "AD104 [GeForce RTX 4070 SUPER](0x2783)"},
{0x10DE, 0x2785, 0xFFFF, 0xFFFF, "AD104 [AC AD104 20GB](0x2785)"},
{0x10DE, 0x2786, 0xFFFF, 0xFFFF, "AD104 [GeForce RTX 4070](0x2786)"},
{0x10DE, 0x2788, 0xFFFF, 0xFFFF, "AD104 [GeForce RTX 4060 Ti](0x2788)"},
{0x10DE, 0x27A0, 0xFFFF, 0xFFFF, "AD104M [GeForce RTX 4080 Max-Q / Mobile](0x27A0)"},
{0x10DE, 0x27B0, 0xFFFF, 0xFFFF, "AD104GL [RTX 4000 SFF Ada Generation](0x27B0)"},
{0x10DE, 0x27B1, 0xFFFF, 0xFFFF, "AD104GL [RTX 4500 Ada Generation](0x27B1)"},
{0x10DE, 0x27B2, 0xFFFF, 0xFFFF, "AD104GL [RTX 4000 Ada Generation](0x27B2)"},
{0x10DE, 0x27B6, 0xFFFF, 0xFFFF, "AD104GL [L2](0x27B6)"},
{0x10DE, 0x27B7, 0xFFFF, 0xFFFF, "AD104GL [L16](0x27B7)"},
{0x10DE, 0x27B8, 0xFFFF, 0xFFFF, "AD104GL [L4](0x27B8)"},
{0x10DE, 0x27BA, 0xFFFF, 0xFFFF, "AD104GLM [RTX 4000 Ada Generation Laptop GPU](0x27BA)"},
{0x10DE, 0x27BB, 0xFFFF, 0xFFFF, "AD104GLM [RTX 3500 Ada Generation Laptop GPU](0x27BB)"},
{0x10DE, 0x27E0, 0xFFFF, 0xFFFF, "AD104M [GeForce RTX 4080 Max-Q / Mobile](0x27E0)"},
{0x10DE, 0x27FA, 0xFFFF, 0xFFFF, "AD104GLM [RTX 4000 Ada Generation Embedded GPU](0x27FA)"},
{0x10DE, 0x27FB, 0xFFFF, 0xFFFF, "AD104GLM [RTX 3500 Ada Generation Embedded GPU](0x27FB)"},
{0x10DE, 0x2803, 0xFFFF, 0xFFFF, "AD106 [GeForce RTX 4060 Ti](0x2803)"},
{0x10DE, 0x2805, 0xFFFF, 0xFFFF, "AD106 [GeForce RTX 4060 Ti 16GB](0x2805)"},
{0x10DE, 0x2808, 0xFFFF, 0xFFFF, "AD106 [GeForce RTX 4060](0x2808)"},
{0x10DE, 0x2820, 0xFFFF, 0xFFFF, "AD106M [GeForce RTX 4070 Max-Q / Mobile](0x2820)"},
{0x10DE, 0x2838, 0xFFFF, 0xFFFF, "AD106GLM [RTX 3000 Ada Generation Laptop GPU](0x2838)"},
{0x10DE, 0x2860, 0xFFFF, 0xFFFF, "AD106M [GeForce RTX 4070 Max-Q / Mobile](0x2860)"},
{0x10DE, 0x2878, 0xFFFF, 0xFFFF, "AD106GLM [RTX 3000 Ada Generation Embedded GPU](0x2878)"},
{0x10DE, 0x2882, 0xFFFF, 0xFFFF, "AD107 [GeForce RTX 4060](0x2882)"},
{0x10DE, 0x28A0, 0xFFFF, 0xFFFF, "AD107M [GeForce RTX 4060 Max-Q / Mobile](0x28A0)"},
{0x10DE, 0x28A1, 0xFFFF, 0xFFFF, "AD107M [GeForce RTX 4050 Max-Q / Mobile](0x28A1)"},
{0x10DE, 0x28B0, 0xFFFF, 0xFFFF, "AD107GL [RTX 2000 / 2000E Ada Generation](0x28B0)"},
{0x10DE, 0x28B8, 0xFFFF, 0xFFFF, "AD107GLM [RTX 2000 Ada Generation Laptop GPU](0x28B8)"},
{0x10DE, 0x28B9, 0xFFFF, 0xFFFF, "AD107GLM [RTX 1000 Ada Generation Laptop GPU](0x28B9)"},
{0x10DE, 0x28BA, 0xFFFF, 0xFFFF, "AD107GLM [RTX 500 Ada Generation Laptop GPU](0x28BA)"},
{0x10DE, 0x28BB, 0xFFFF, 0xFFFF, "AD107GLM [RTX 500 Ada Generation Laptop GPU](0x28BB)"},
{0x10DE, 0x28E0, 0xFFFF, 0xFFFF, "AD107M [GeForce RTX 4060 Max-Q / Mobile](0x28E0)"},
{0x10DE, 0x28E1, 0xFFFF, 0xFFFF, "AD107M [GeForce RTX 4050 Max-Q / Mobile](0x28E1)"},
{0x10DE, 0x28F8, 0xFFFF, 0xFFFF, "AD107GLM [RTX 2000 Ada Generation Embedded GPU](0x28F8)"},
}; /* pci_vid_10DE[] */

static pci_id_t const pci_vid_10DF[] = {
{0x10DF, 0xFFFF, 0xFFFF, 0xFFFF, "Emulex Corporation(0x10DF)"},
{0x10DF, 0x0720, 0xFFFF, 0xFFFF, "OneConnect NIC (Skyhawk)(0x0720)"},
{0x10DF, 0x0720, 0x103C, 0x1934, "FlexFabric 20Gb 2-port 650M Adapter(0x103C-0x1934)"},
{0x10DF, 0x0720, 0x103C, 0x1935, "FlexFabric 20Gb 2-port 650FLB Adapter(0x103C-0x1935)"},
{0x10DF, 0x0720, 0x103C, 0x21D4, "StoreFabric CN1200E 10Gb Converged Network Adapter(0x103C-0x21D4)"},
{0x10DF, 0x0720, 0x103C, 0x220A, "FlexFabric 10Gb 2-port 556FLR-SFP+ Adapter(0x103C-0x220A)"},
{0x10DF, 0x0720, 0x103C, 0x803F, "Ethernet 10Gb 2-port 557SFP+ Adapter(0x103C-0x803F)"},
{0x10DF, 0x0720, 0x103C, 0x8144, "FlexFabric 10GB 2-port 556FLR-T Adapter(0x103C-0x8144)"},
{0x10DF, 0x0720, 0x17AA, 0x1056, "ThinkServer OCm14102-UX-L AnyFabric(0x17AA-0x1056)"},
{0x10DF, 0x0720, 0x17AA, 0x1057, "ThinkServer OCm14104-UX-L AnyFabric(0x17AA-0x1057)"},
{0x10DF, 0x0720, 0x17AA, 0x1059, "ThinkServer OCm14104-UT-L AnyFabric(0x17AA-0x1059)"},
{0x10DF, 0x0720, 0x17AA, 0x4014, "ThinkServer OCm14102-NX-L AnyFabric(0x17AA-0x4014)"},
{0x10DF, 0x0722, 0xFFFF, 0xFFFF, "OneConnect iSCSI Initiator (Skyhawk)(0x0722)"},
{0x10DF, 0x0723, 0xFFFF, 0xFFFF, "OneConnect iSCSI Initiator + Target (Skyhawk)(0x0723)"},
{0x10DF, 0x0724, 0xFFFF, 0xFFFF, "OneConnect FCoE Initiator (Skyhawk)(0x0724)"},
{0x10DF, 0x0728, 0xFFFF, 0xFFFF, "OneConnect NIC (Skyhawk-VF)(0x0728)"},
{0x10DF, 0x072A, 0xFFFF, 0xFFFF, "OneConnect iSCSI Initiator (Skyhawk-VF)(0x072A)"},
{0x10DF, 0x072B, 0xFFFF, 0xFFFF, "OneConnect iSCSI Initiator + Target (Skyhawk-VF)(0x072B)"},
{0x10DF, 0x072C, 0xFFFF, 0xFFFF, "OneConnect FCoE Initiator (Skyhawk-VF)(0x072C)"},
{0x10DF, 0x1AE5, 0xFFFF, 0xFFFF, "LP6000 Fibre Channel Host Adapter(0x1AE5)"},
{0x10DF, 0xE100, 0xFFFF, 0xFFFF, "Proteus-X: LightPulse IOV Fibre Channel Host Adapter(0xE100)"},
{0x10DF, 0xE131, 0xFFFF, 0xFFFF, "LightPulse 8Gb/s PCIe Shared I/O Fibre Channel Adapter(0xE131)"},
{0x10DF, 0xE180, 0xFFFF, 0xFFFF, "Proteus-X: LightPulse IOV Fibre Channel Host Adapter(0xE180)"},
{0x10DF, 0xE200, 0xFFFF, 0xFFFF, "LPe15000/LPe16000 Series 8Gb/16Gb Fibre Channel Adapter(0xE200)"},
{0x10DF, 0xE200, 0x1014, 0x03F1, "PCIe2 2-Port 16Gb Fibre Channel Adapter for POWER (FC EL5B; CCIN 577F)(0x1014-0x03F1)"},
{0x10DF, 0xE200, 0x1014, 0x04E3, "PCIe3 4-Port 10GbE SR Adapter for POWER (FC EN15/EN16; CCIN 2CE3)(0x1014-0x04E3)"},
{0x10DF, 0xE200, 0x1014, 0x04E4, "PCIe3 4-Port 10GbE SFP+ Adapter for POWER (FC EN18; CCIN 2CE4)(0x1014-0x04E4)"},
{0x10DF, 0xE200, 0x10DF, 0xE280, "LPe16002B-M6 2-Port 16Gb Fibre Channel Adapter(0x10DF-0xE280)"},
{0x10DF, 0xE200, 0x10DF, 0xE281, "LPe16000B-M6 1-Port 16Gb Fibre Channel Adapter(0x10DF-0xE281)"},
{0x10DF, 0xE200, 0x10DF, 0xE282, "Flex System FC5054 4-port 16Gb FC Adapter(0x10DF-0xE282)"},
{0x10DF, 0xE208, 0xFFFF, 0xFFFF, "LightPulse 16Gb Fibre Channel Host Adapter (Lancer-VF)(0xE208)"},
{0x10DF, 0xE220, 0xFFFF, 0xFFFF, "OneConnect NIC (Lancer)(0xE220)"},
{0x10DF, 0xE220, 0x17AA, 0x1054, "ThinkServer LPm16002B-M6-L AnyFabric(0x17AA-0x1054)"},
{0x10DF, 0xE220, 0x17AA, 0x1055, "ThinkServer LPm16004B-M8-L AnyFabric(0x17AA-0x1055)"},
{0x10DF, 0xE240, 0xFFFF, 0xFFFF, "OneConnect iSCSI Initiator (Lancer)(0xE240)"},
{0x10DF, 0xE260, 0xFFFF, 0xFFFF, "OneConnect FCoE Initiator (Lancer)(0xE260)"},
{0x10DF, 0xE268, 0xFFFF, 0xFFFF, "OneConnect 10Gb FCoE Converged Network Adapter (Lancer-VF)(0xE268)"},
{0x10DF, 0xE300, 0xFFFF, 0xFFFF, "LPe31000/LPe32000 Series 16Gb/32Gb Fibre Channel Adapter(0xE300)"},
{0x10DF, 0xE300, 0x1014, 0x0614, "PCIe3 4-Port 16Gb Fibre Channel Adapter for POWER (FC EN1C/EN1D; CCIN 578E)(0x1014-0x0614)"},
{0x10DF, 0xE300, 0x1014, 0x0615, "PCIe3 2-Port 32Gb Fibre Channel Adapter for POWER (FC EN1A/EN1B; CCIN 578F)(0x1014-0x0615)"},
{0x10DF, 0xE300, 0x1014, 0x06A0, "PCIe3 2-Port 16Gb Fibre Channel Adapter for POWER (FC EN1L/EN1M; CCIN 2CFC)(0x1014-0x06A0)"},
{0x10DF, 0xE300, 0x10DF, 0xE300, "LPe32002-M2 2-Port 32Gb Fibre Channel Adapter(0x10DF-0xE300)"},
{0x10DF, 0xE300, 0x10DF, 0xE301, "LPe32000-M2 1-Port 32Gb Fibre Channel Adapter(0x10DF-0xE301)"},
{0x10DF, 0xE300, 0x10DF, 0xE310, "LPe31002-M6 2-Port 16Gb Fibre Channel Adapter(0x10DF-0xE310)"},
{0x10DF, 0xE300, 0x10DF, 0xE311, "LPe31000-M6 1-Port 16Gb Fibre Channel Adapter(0x10DF-0xE311)"},
{0x10DF, 0xE300, 0x10DF, 0xE312, "LPe31004-M6 4-Port 16Gb Fibre Channel Adapter(0x10DF-0xE312)"},
{0x10DF, 0xE300, 0x10DF, 0xE320, "LPe32002-M2-D 2-Port 32Gb Fibre Channel Adapter(0x10DF-0xE320)"},
{0x10DF, 0xE300, 0x10DF, 0xE321, "LPe32000-M2-D 1-Port 32Gb Fibre Channel Adapter(0x10DF-0xE321)"},
{0x10DF, 0xE300, 0x10DF, 0xE322, "LPe31002-M6-D 2-Port 16Gb Fibre Channel Adapter(0x10DF-0xE322)"},
{0x10DF, 0xE300, 0x10DF, 0xE323, "LPe31000-M6-D 1-Port 16Gb Fibre Channel Adapter(0x10DF-0xE323)"},
{0x10DF, 0xE300, 0x10DF, 0xE324, "LPm32002-D 2-Port 32Gb Fibre Channel Mezz Card(0x10DF-0xE324)"},
{0x10DF, 0xE300, 0x10DF, 0xE325, "LPm31002-D 2-Port 16Gb Fibre Channel Mezz Card(0x10DF-0xE325)"},
{0x10DF, 0xE300, 0x10DF, 0xE330, "LPe32002-M2-L 2-Port 32Gb PCIe Fibre Channel Adapter(0x10DF-0xE330)"},
{0x10DF, 0xE300, 0x10DF, 0xE331, "LPe32000-M2-L 1-Port 32Gb PCIe Fibre Channel Adapter(0x10DF-0xE331)"},
{0x10DF, 0xE300, 0x10DF, 0xE332, "LPe31002-M6-L 2-Port 16Gb PCIe Fibre Channel Adapter(0x10DF-0xE332)"},
{0x10DF, 0xE300, 0x10DF, 0xE333, "LPe31000-M6-L 1-Port 16Gb PCIe Fibre Channel Adapter(0x10DF-0xE333)"},
{0x10DF, 0xE300, 0x1590, 0x0201, "StoreFabric SN1600E 1-Port 32Gb Fibre Channel Adapter(0x1590-0x0201)"},
{0x10DF, 0xE300, 0x1590, 0x0202, "StoreFabric SN1600E 2-Port 32Gb Fibre Channel Adapter(0x1590-0x0202)"},
{0x10DF, 0xE300, 0x1590, 0x0213, "StoreFabric SN1200E 1-Port 16Gb Fibre Channel Adapter(0x1590-0x0213)"},
{0x10DF, 0xE300, 0x1590, 0x0214, "StoreFabric SN1200E 2-Port 16Gb Fibre Channel Adapter(0x1590-0x0214)"},
{0x10DF, 0xE300, 0x1590, 0x022E, "Synergy 5330C 2-Port 32Gb Fibre Channel Mezz Card(0x1590-0x022E)"},
{0x10DF, 0xE300, 0x193D, 0x1060, "NIC-FC730i-Mb-2P(0x193D-0x1060)"},
{0x10DF, 0xF011, 0xFFFF, 0xFFFF, "Saturn: LightPulse Fibre Channel Host Adapter(0xF011)"},
{0x10DF, 0xF015, 0xFFFF, 0xFFFF, "Saturn: LightPulse Fibre Channel Host Adapter(0xF015)"},
{0x10DF, 0xF085, 0xFFFF, 0xFFFF, "LP850 Fibre Channel Host Adapter(0xF085)"},
{0x10DF, 0xF095, 0xFFFF, 0xFFFF, "LP952 Fibre Channel Host Adapter(0xF095)"},
{0x10DF, 0xF098, 0xFFFF, 0xFFFF, "LP982 Fibre Channel Host Adapter(0xF098)"},
{0x10DF, 0xF0A1, 0xFFFF, 0xFFFF, "Thor LightPulse Fibre Channel Host Adapter(0xF0A1)"},
{0x10DF, 0xF0A5, 0xFFFF, 0xFFFF, "Thor LightPulse Fibre Channel Host Adapter(0xF0A5)"},
{0x10DF, 0xF0B5, 0xFFFF, 0xFFFF, "Viper LightPulse Fibre Channel Host Adapter(0xF0B5)"},
{0x10DF, 0xF0D1, 0xFFFF, 0xFFFF, "Helios LightPulse Fibre Channel Host Adapter(0xF0D1)"},
{0x10DF, 0xF0D5, 0xFFFF, 0xFFFF, "Helios LightPulse Fibre Channel Host Adapter(0xF0D5)"},
{0x10DF, 0xF0E1, 0xFFFF, 0xFFFF, "Zephyr LightPulse Fibre Channel Host Adapter(0xF0E1)"},
{0x10DF, 0xF0E5, 0xFFFF, 0xFFFF, "Zephyr LightPulse Fibre Channel Host Adapter(0xF0E5)"},
{0x10DF, 0xF0F5, 0xFFFF, 0xFFFF, "Neptune LightPulse Fibre Channel Host Adapter(0xF0F5)"},
{0x10DF, 0xF100, 0xFFFF, 0xFFFF, "LPe12000 Series 8Gb Fibre Channel Adapter(0xF100)"},
{0x10DF, 0xF100, 0x1014, 0x038A, "8Gb PCI Express Dual Port FC Adapter for POWER(0x1014-0x038A)"},
{0x10DF, 0xF100, 0x103C, 0x3282, "8Gb Dual-port PCI-e FC HBA(0x103C-0x3282)"},
{0x10DF, 0xF100, 0x10DF, 0xF140, "LPe12000-M8-L 1-Port 8Gb PCIe Fibre Channel Adapter(0x10DF-0xF140)"},
{0x10DF, 0xF100, 0x10DF, 0xF141, "LPe12002-M8-L 2-Port 8Gb PCIe Fibre Channel Adapter(0x10DF-0xF141)"},
{0x10DF, 0xF111, 0xFFFF, 0xFFFF, "Saturn-X LightPulse Fibre Channel Host Adapter(0xF111)"},
{0x10DF, 0xF112, 0xFFFF, 0xFFFF, "Saturn-X LightPulse Fibre Channel Host Adapter(0xF112)"},
{0x10DF, 0xF180, 0xFFFF, 0xFFFF, "LPSe12002 EmulexSecure Fibre Channel Adapter(0xF180)"},
{0x10DF, 0xF400, 0xFFFF, 0xFFFF, "LPe35000/LPe36000 Series 32Gb/64Gb Fibre Channel Adapter(0xF400)"},
{0x10DF, 0xF400, 0x10DF, 0xF401, "LPe35000-M2 1-Port 32Gb Fibre Channel Adapter(0x10DF-0xF401)"},
{0x10DF, 0xF400, 0x10DF, 0xF402, "LPe35002-M2 2-Port 32Gb Fibre Channel Adapter(0x10DF-0xF402)"},
{0x10DF, 0xF400, 0x10DF, 0xF403, "LPe36000-M64 1-Port 64Gb Fibre Channel Adapter(0x10DF-0xF403)"},
{0x10DF, 0xF400, 0x10DF, 0xF404, "LPe36002-M64 2-Port 64Gb Fibre Channel Adapter(0x10DF-0xF404)"},
{0x10DF, 0xF400, 0x10DF, 0xF405, "LPe35004-M2 4-Port 32Gb Fibre Channel Adapter(0x10DF-0xF405)"},
{0x10DF, 0xF400, 0x10DF, 0xF406, "LPe35004-X6 4-Port Fibre Channel Adapter(0x10DF-0xF406)"},
{0x10DF, 0xF400, 0x10DF, 0xF410, "LPe35002-M2-D 2-Port 32Gb Fibre Channel Adapter(0x10DF-0xF410)"},
{0x10DF, 0xF400, 0x10DF, 0xF411, "LPe35000-M2-D 1-Port 32Gb Fibre Channel Adapter(0x10DF-0xF411)"},
{0x10DF, 0xF400, 0x10DF, 0xF418, "LPe35000-M2-L 1-Port 32Gb PCIe Fibre Channel Adapter(0x10DF-0xF418)"},
{0x10DF, 0xF400, 0x10DF, 0xF419, "LPe35002-M2-L 2-Port 32Gb PCIe Fibre Channel Adapter(0x10DF-0xF419)"},
{0x10DF, 0xF400, 0x10DF, 0xF421, "LPe36002-M2-L 2-Port 64Gb PCIe Fibre Channel Adapter(0x10DF-0xF421)"},
{0x10DF, 0xF400, 0x10DF, 0xF422, "LPe36002-M64-D 2-Port 64Gb Fibre Channel Adapter(0x10DF-0xF422)"},
{0x10DF, 0xF400, 0x1590, 0x02D5, "StoreFabric SN1610E 1-Port 32Gb Fibre Channel Adapter(0x1590-0x02D5)"},
{0x10DF, 0xF400, 0x1590, 0x02D6, "StoreFabric SN1610E 2-Port 32Gb Fibre Channel Adapter(0x1590-0x02D6)"},
{0x10DF, 0xF500, 0xFFFF, 0xFFFF, "LPe37000/LPe38000 Series 32Gb/64Gb Fibre Channel Adapter(0xF500)"},
{0x10DF, 0xF500, 0x1014, 0x06C1, "PCIe4 4-Port 32Gb Fibre Channel Adapter for POWER (FC EN1L/EN1M; CCIN 2CFC)(0x1014-0x06C1)"},
{0x10DF, 0xF500, 0x1014, 0x06C2, "PCIe4 2-Port 64Gb Fibre Channel Adapter for POWER (FC EN1N/EN1P; CCIN 2CFD)(0x1014-0x06C2)"},
{0x10DF, 0xF700, 0xFFFF, 0xFFFF, "LP7000 Fibre Channel Host Adapter(0xF700)"},
{0x10DF, 0xF701, 0xFFFF, 0xFFFF, "LP7000 Fibre Channel Host Adapter Alternate ID (JX1:2-3, JX2:1-2)(0xF701)"},
{0x10DF, 0xF800, 0xFFFF, 0xFFFF, "LP8000 Fibre Channel Host Adapter(0xF800)"},
{0x10DF, 0xF801, 0xFFFF, 0xFFFF, "LP8000 Fibre Channel Host Adapter Alternate ID (JX1:2-3, JX2:1-2)(0xF801)"},
{0x10DF, 0xF900, 0xFFFF, 0xFFFF, "LP9000 Fibre Channel Host Adapter(0xF900)"},
{0x10DF, 0xF901, 0xFFFF, 0xFFFF, "LP9000 Fibre Channel Host Adapter Alternate ID (JX1:2-3, JX2:1-2)(0xF901)"},
{0x10DF, 0xF980, 0xFFFF, 0xFFFF, "LP9802 Fibre Channel Host Adapter(0xF980)"},
{0x10DF, 0xF981, 0xFFFF, 0xFFFF, "LP9802 Fibre Channel Host Adapter Alternate ID(0xF981)"},
{0x10DF, 0xF982, 0xFFFF, 0xFFFF, "LP9802 Fibre Channel Host Adapter Alternate ID(0xF982)"},
{0x10DF, 0xFA00, 0xFFFF, 0xFFFF, "Thor-X LightPulse Fibre Channel Host Adapter(0xFA00)"},
{0x10DF, 0xFB00, 0xFFFF, 0xFFFF, "Viper LightPulse Fibre Channel Host Adapter(0xFB00)"},
{0x10DF, 0xFC00, 0xFFFF, 0xFFFF, "Thor-X LightPulse Fibre Channel Host Adapter(0xFC00)"},
{0x10DF, 0xFC00, 0x10DF, 0xFC00, "LP10000 LightPulse Fibre Channel Host Adapter(0x10DF-0xFC00)"},
{0x10DF, 0xFC10, 0xFFFF, 0xFFFF, "Helios-X LightPulse Fibre Channel Host Adapter(0xFC10)"},
{0x10DF, 0xFC20, 0xFFFF, 0xFFFF, "Zephyr-X LightPulse Fibre Channel Host Adapter(0xFC20)"},
{0x10DF, 0xFC40, 0xFFFF, 0xFFFF, "Saturn-X: LightPulse Fibre Channel Host Adapter(0xFC40)"},
{0x10DF, 0xFC50, 0xFFFF, 0xFFFF, "Proteus-X: LightPulse IOV Fibre Channel Host Adapter(0xFC50)"},
{0x10DF, 0xFD00, 0xFFFF, 0xFFFF, "Helios-X LightPulse Fibre Channel Host Adapter(0xFD00)"},
{0x10DF, 0xFD00, 0x10DF, 0xFD02, "LightPulse LP11002 Dual-port 4Gigabit PCI Fibre Channel Adapter(0x10DF-0xFD02)"},
{0x10DF, 0xFD11, 0xFFFF, 0xFFFF, "Helios-X LightPulse Fibre Channel Host Adapter(0xFD11)"},
{0x10DF, 0xFD12, 0xFFFF, 0xFFFF, "Helios-X LightPulse Fibre Channel Host Adapter(0xFD12)"},
{0x10DF, 0xFE00, 0xFFFF, 0xFFFF, "Zephyr-X LightPulse Fibre Channel Host Adapter(0xFE00)"},
{0x10DF, 0xFE05, 0xFFFF, 0xFFFF, "Zephyr-X: LightPulse FCoE Adapter(0xFE05)"},
{0x10DF, 0xFE11, 0xFFFF, 0xFFFF, "Zephyr-X LightPulse Fibre Channel Host Adapter(0xFE11)"},
{0x10DF, 0xFE12, 0xFFFF, 0xFFFF, "Zephyr-X LightPulse FCoE Adapter(0xFE12)"},
{0x10DF, 0xFF00, 0xFFFF, 0xFFFF, "Neptune LightPulse Fibre Channel Host Adapter(0xFF00)"},
}; /* pci_vid_10DF[] */

static pci_id_t const pci_vid_10E0[] = {
{0x10E0, 0xFFFF, 0xFFFF, 0xFFFF, "Integrated Micro Solutions Inc.(0x10E0)"},
{0x10E0, 0x5026, 0xFFFF, 0xFFFF, "IMS5026/27/28(0x5026)"},
{0x10E0, 0x5027, 0xFFFF, 0xFFFF, "IMS5027(0x5027)"},
{0x10E0, 0x5028, 0xFFFF, 0xFFFF, "IMS5028(0x5028)"},
{0x10E0, 0x8849, 0xFFFF, 0xFFFF, "IMS8849(0x8849)"},
{0x10E0, 0x8853, 0xFFFF, 0xFFFF, "IMS8853(0x8853)"},
{0x10E0, 0x9128, 0xFFFF, 0xFFFF, "IMS9128 [Twin turbo 128](0x9128)"},
}; /* pci_vid_10E0[] */

static pci_id_t const pci_vid_10E1[] = {
{0x10E1, 0xFFFF, 0xFFFF, 0xFFFF, "Tekram Technology Co.,Ltd.(0x10E1)"},
{0x10E1, 0x0391, 0xFFFF, 0xFFFF, "TRM-S1040(0x0391)"},
{0x10E1, 0x0391, 0x10E1, 0x0391, "DC-315U SCSI-3 Host Adapter(0x10E1-0x0391)"},
{0x10E1, 0x690C, 0xFFFF, 0xFFFF, "DC-690c(0x690C)"},
{0x10E1, 0xDC29, 0xFFFF, 0xFFFF, "DC-290(0xDC29)"},
}; /* pci_vid_10E1[] */

static pci_id_t const pci_vid_10E2[] = {
{0x10E2, 0xFFFF, 0xFFFF, 0xFFFF, "Aptix Corporation(0x10E2)"},
}; /* pci_vid_10E2[] */

static pci_id_t const pci_vid_10E3[] = {
{0x10E3, 0xFFFF, 0xFFFF, 0xFFFF, "Tundra Semiconductor Corp.(0x10E3)"},
{0x10E3, 0x0000, 0xFFFF, 0xFFFF, "CA91C042 [Universe](0x0000)"},
{0x10E3, 0x0108, 0xFFFF, 0xFFFF, "Tsi108 Host Bridge for Single PowerPC(0x0108)"},
{0x10E3, 0x0148, 0xFFFF, 0xFFFF, "Tsi148 [Tempe](0x0148)"},
{0x10E3, 0x0148, 0x1775, 0x1100, "VR11 Single Board Computer(0x1775-0x1100)"},
{0x10E3, 0x0860, 0xFFFF, 0xFFFF, "CA91C860 [QSpan](0x0860)"},
{0x10E3, 0x0862, 0xFFFF, 0xFFFF, "CA91C862A [QSpan-II](0x0862)"},
{0x10E3, 0x8111, 0xFFFF, 0xFFFF, "Tsi381 PCIe to PCI Bridge(0x8111)"},
{0x10E3, 0x8260, 0xFFFF, 0xFFFF, "CA91L8200B [Dual PCI PowerSpan II](0x8260)"},
{0x10E3, 0x8261, 0xFFFF, 0xFFFF, "CA91L8260B [Single PCI PowerSpan II](0x8261)"},
{0x10E3, 0xA108, 0xFFFF, 0xFFFF, "Tsi109 Host Bridge for Dual PowerPC(0xA108)"},
}; /* pci_vid_10E3[] */

static pci_id_t const pci_vid_10E4[] = {
{0x10E4, 0xFFFF, 0xFFFF, 0xFFFF, "Tandem Computers(0x10E4)"},
{0x10E4, 0x8029, 0xFFFF, 0xFFFF, "Realtek 8029 Network Card(0x8029)"},
}; /* pci_vid_10E4[] */

static pci_id_t const pci_vid_10E5[] = {
{0x10E5, 0xFFFF, 0xFFFF, 0xFFFF, "Micro Industries Corporation(0x10E5)"},
}; /* pci_vid_10E5[] */

static pci_id_t const pci_vid_10E6[] = {
{0x10E6, 0xFFFF, 0xFFFF, 0xFFFF, "Gainbery Computer Products Inc.(0x10E6)"},
}; /* pci_vid_10E6[] */

static pci_id_t const pci_vid_10E7[] = {
{0x10E7, 0xFFFF, 0xFFFF, 0xFFFF, "Vadem(0x10E7)"},
}; /* pci_vid_10E7[] */

static pci_id_t const pci_vid_10E8[] = {
{0x10E8, 0xFFFF, 0xFFFF, 0xFFFF, "Applied Micro Circuits Corp.(0x10E8)"},
{0x10E8, 0x1072, 0xFFFF, 0xFFFF, "INES GPIB-PCI (AMCC5920 based)(0x1072)"},
{0x10E8, 0x2011, 0xFFFF, 0xFFFF, "Q-Motion Video Capture/Edit board(0x2011)"},
{0x10E8, 0x4750, 0xFFFF, 0xFFFF, "S5930 [Matchmaker](0x4750)"},
{0x10E8, 0x5920, 0xFFFF, 0xFFFF, "S5920(0x5920)"},
{0x10E8, 0x801D, 0xFFFF, 0xFFFF, "Roper Scientific PCI TAXI interface(0x801D)"},
{0x10E8, 0x8043, 0xFFFF, 0xFFFF, "LANai4.x [Myrinet LANai interface chip](0x8043)"},
{0x10E8, 0x8062, 0xFFFF, 0xFFFF, "S5933_PARASTATION(0x8062)"},
{0x10E8, 0x807D, 0xFFFF, 0xFFFF, "S5933 [Matchmaker](0x807D)"},
{0x10E8, 0x8081, 0xFFFF, 0xFFFF, "GPIB interface card [IOtech Inc. PCI488](0x8081)"},
{0x10E8, 0x8088, 0xFFFF, 0xFFFF, "Kongsberg Spacetec Format Synchronizer(0x8088)"},
{0x10E8, 0x8089, 0xFFFF, 0xFFFF, "Kongsberg Spacetec Serial Output Board(0x8089)"},
{0x10E8, 0x809C, 0xFFFF, 0xFFFF, "S5933_HEPC3(0x809C)"},
{0x10E8, 0x80B9, 0xFFFF, 0xFFFF, "Harmonix Hi-Card P8 (4x active ISDN BRI)(0x80B9)"},
{0x10E8, 0x80D7, 0xFFFF, 0xFFFF, "PCI-9112(0x80D7)"},
{0x10E8, 0x80D8, 0xFFFF, 0xFFFF, "PCI-7200(0x80D8)"},
{0x10E8, 0x80D9, 0xFFFF, 0xFFFF, "PCI-9118(0x80D9)"},
{0x10E8, 0x80DA, 0xFFFF, 0xFFFF, "PCI-9812(0x80DA)"},
{0x10E8, 0x80FC, 0xFFFF, 0xFFFF, "APCI1500 Signal processing controller (16 dig. inputs + 16 dig. outputs)(0x80FC)"},
{0x10E8, 0x811A, 0xFFFF, 0xFFFF, "PCI-IEEE1355-DS-DE Interface(0x811A)"},
{0x10E8, 0x814C, 0xFFFF, 0xFFFF, "Fastcom ESCC-PCI (Commtech, Inc.)(0x814C)"},
{0x10E8, 0x8170, 0xFFFF, 0xFFFF, "S5933 [Matchmaker] (Chipset Development Tool)(0x8170)"},
{0x10E8, 0x81E6, 0xFFFF, 0xFFFF, "Multimedia video controller(0x81E6)"},
{0x10E8, 0x828D, 0xFFFF, 0xFFFF, "APCI3001 Signal processing controller (up to 16 analog inputs)(0x828D)"},
{0x10E8, 0x8291, 0xFFFF, 0xFFFF, "Fastcom 232/8-PCI (Commtech, Inc.)(0x8291)"},
{0x10E8, 0x82C4, 0xFFFF, 0xFFFF, "Fastcom 422/4-PCI (Commtech, Inc.)(0x82C4)"},
{0x10E8, 0x82C5, 0xFFFF, 0xFFFF, "Fastcom 422/2-PCI (Commtech, Inc.)(0x82C5)"},
{0x10E8, 0x82C6, 0xFFFF, 0xFFFF, "Fastcom IG422/1-PCI (Commtech, Inc.)(0x82C6)"},
{0x10E8, 0x82C7, 0xFFFF, 0xFFFF, "Fastcom IG232/2-PCI (Commtech, Inc.)(0x82C7)"},
{0x10E8, 0x82CA, 0xFFFF, 0xFFFF, "Fastcom 232/4-PCI (Commtech, Inc.)(0x82CA)"},
{0x10E8, 0x82DB, 0xFFFF, 0xFFFF, "AJA HDNTV HD SDI Framestore(0x82DB)"},
{0x10E8, 0x82E2, 0xFFFF, 0xFFFF, "Fastcom DIO24H-PCI (Commtech, Inc.)(0x82E2)"},
{0x10E8, 0x8406, 0xFFFF, 0xFFFF, "PCIcanx/PCIcan CAN interface [Kvaser AB](0x8406)"},
{0x10E8, 0x8407, 0xFFFF, 0xFFFF, "PCIcan II CAN interface (A1021, PCB-07, PCB-08) [Kvaser AB](0x8407)"},
{0x10E8, 0x8851, 0xFFFF, 0xFFFF, "S5933 on Innes Corp FM Radio Capture card(0x8851)"},
{0x10E8, 0xE004, 0xFFFF, 0xFFFF, "X-Gene PCIe bridge(0xE004)"},
}; /* pci_vid_10E8[] */

static pci_id_t const pci_vid_10E9[] = {
{0x10E9, 0xFFFF, 0xFFFF, 0xFFFF, "Alps Electric Co., Ltd.(0x10E9)"},
}; /* pci_vid_10E9[] */

static pci_id_t const pci_vid_10EA[] = {
{0x10EA, 0xFFFF, 0xFFFF, 0xFFFF, "Integraphics(0x10EA)"},
{0x10EA, 0x1680, 0xFFFF, 0xFFFF, "IGA-1680(0x1680)"},
{0x10EA, 0x1682, 0xFFFF, 0xFFFF, "IGA-1682(0x1682)"},
{0x10EA, 0x1683, 0xFFFF, 0xFFFF, "IGA-1683(0x1683)"},
{0x10EA, 0x2000, 0xFFFF, 0xFFFF, "CyberPro 2000(0x2000)"},
{0x10EA, 0x2010, 0xFFFF, 0xFFFF, "CyberPro 2000A(0x2010)"},
{0x10EA, 0x5000, 0xFFFF, 0xFFFF, "CyberPro 5000(0x5000)"},
{0x10EA, 0x5050, 0xFFFF, 0xFFFF, "CyberPro 5050(0x5050)"},
{0x10EA, 0x5202, 0xFFFF, 0xFFFF, "CyberPro 5202(0x5202)"},
{0x10EA, 0x5252, 0xFFFF, 0xFFFF, "CyberPro5252(0x5252)"},
}; /* pci_vid_10EA[] */

static pci_id_t const pci_vid_10EB[] = {
{0x10EB, 0xFFFF, 0xFFFF, 0xFFFF, "Artists Graphics(0x10EB)"},
{0x10EB, 0x0101, 0xFFFF, 0xFFFF, "3GA(0x0101)"},
{0x10EB, 0x8111, 0xFFFF, 0xFFFF, "Twist3 Frame Grabber(0x8111)"},
}; /* pci_vid_10EB[] */

static pci_id_t const pci_vid_10EC[] = {
{0x10EC, 0xFFFF, 0xFFFF, 0xFFFF, "Realtek Semiconductor Co., Ltd.(0x10EC)"},
{0x10EC, 0x0139, 0xFFFF, 0xFFFF, "RTL-8139/8139C/8139C+ Ethernet Controller(0x0139)"},
{0x10EC, 0x2600, 0xFFFF, 0xFFFF, "Killer E2600 GbE Controller(0x2600)"},
{0x10EC, 0x3000, 0xFFFF, 0xFFFF, "Killer E3000 2.5GbE Controller(0x3000)"},
{0x10EC, 0x4321, 0xFFFF, 0xFFFF, "RTL8852BE 802.11ax PCIe Wireless Network Adapter(0x4321)"},
{0x10EC, 0x5208, 0xFFFF, 0xFFFF, "RTS5208 PCI Express Card Reader(0x5208)"},
{0x10EC, 0x5209, 0xFFFF, 0xFFFF, "RTS5209 PCI Express Card Reader(0x5209)"},
{0x10EC, 0x5227, 0xFFFF, 0xFFFF, "RTS5227 PCI Express Card Reader(0x5227)"},
{0x10EC, 0x5227, 0x17AA, 0x220E, "ThinkPad T440p(0x17AA-0x220E)"},
{0x10EC, 0x5227, 0x17AA, 0x2214, "ThinkPad X240(0x17AA-0x2214)"},
{0x10EC, 0x5229, 0xFFFF, 0xFFFF, "RTS5229 PCI Express Card Reader(0x5229)"},
{0x10EC, 0x5229, 0x1025, 0x0813, "Aspire R7-571(0x1025-0x0813)"},
{0x10EC, 0x5229, 0x103C, 0x194E, "ProBook 455 G1 Notebook(0x103C-0x194E)"},
{0x10EC, 0x5229, 0x103C, 0x1985, "Pavilion 17-e163sg Notebook PC(0x103C-0x1985)"},
{0x10EC, 0x5229, 0x17AA, 0x3832, "Yoga 520(0x17AA-0x3832)"},
{0x10EC, 0x522A, 0xFFFF, 0xFFFF, "RTS522A PCI Express Card Reader(0x522A)"},
{0x10EC, 0x522A, 0x103C, 0x8079, "EliteBook 840 G3(0x103C-0x8079)"},
{0x10EC, 0x522A, 0x103C, 0x825B, "OMEN-17-w001nv(0x103C-0x825B)"},
{0x10EC, 0x522A, 0x17AA, 0x5124, "ThinkPad E595(0x17AA-0x5124)"},
{0x10EC, 0x5249, 0xFFFF, 0xFFFF, "RTS5249 PCI Express Card Reader(0x5249)"},
{0x10EC, 0x5249, 0x103C, 0x1909, "ZBook 15(0x103C-0x1909)"},
{0x10EC, 0x524A, 0xFFFF, 0xFFFF, "RTS524A PCI Express Card Reader(0x524A)"},
{0x10EC, 0x5250, 0xFFFF, 0xFFFF, "RTS5250 PCI Express Card Reader(0x5250)"},
{0x10EC, 0x525A, 0xFFFF, 0xFFFF, "RTS525A PCI Express Card Reader(0x525A)"},
{0x10EC, 0x525A, 0x1028, 0x06D6, "Latitude 7275 tablet(0x1028-0x06D6)"},
{0x10EC, 0x525A, 0x1028, 0x06DC, "Latitude E7470(0x1028-0x06DC)"},
{0x10EC, 0x525A, 0x1028, 0x06E4, "XPS 15 9550(0x1028-0x06E4)"},
{0x10EC, 0x525A, 0x1028, 0x06E6, "Latitude 11 5175 2-in-1(0x1028-0x06E6)"},
{0x10EC, 0x525A, 0x1028, 0x09BE, "Latitude 7410(0x1028-0x09BE)"},
{0x10EC, 0x525A, 0x1028, 0x0B10, "Precision 3571(0x1028-0x0B10)"},
{0x10EC, 0x525A, 0x1028, 0x0C06, "Precision 3580(0x1028-0x0C06)"},
{0x10EC, 0x525A, 0x17AA, 0x224F, "ThinkPad X1 Carbon 5th Gen(0x17AA-0x224F)"},
{0x10EC, 0x5260, 0xFFFF, 0xFFFF, "RTS5260 PCI Express Card Reader(0x5260)"},
{0x10EC, 0x5261, 0xFFFF, 0xFFFF, "RTS5261 PCI Express Card Reader(0x5261)"},
{0x10EC, 0x5286, 0xFFFF, 0xFFFF, "RTS5286 PCI Express Card Reader(0x5286)"},
{0x10EC, 0x5287, 0xFFFF, 0xFFFF, "RTL8411B PCI Express Card Reader(0x5287)"},
{0x10EC, 0x5287, 0x1025, 0x1094, "Acer Aspire E5-575G(0x1025-0x1094)"},
{0x10EC, 0x5288, 0xFFFF, 0xFFFF, "RTS5288 PCI Express Card Reader(0x5288)"},
{0x10EC, 0x5289, 0xFFFF, 0xFFFF, "RTL8411 PCI Express Card Reader(0x5289)"},
{0x10EC, 0x5289, 0x1043, 0x1457, "K55A Laptop(0x1043-0x1457)"},
{0x10EC, 0x5760, 0xFFFF, 0xFFFF, "RTS5763DL x2 NVMe SSD Controller(0x5760)"},
{0x10EC, 0x5762, 0xFFFF, 0xFFFF, "RTS5762 NVMe SSD Controller(0x5762)"},
{0x10EC, 0x5763, 0xFFFF, 0xFFFF, "RTS5763DL NVMe SSD Controller (DRAM-less)(0x5763)"},
{0x10EC, 0x5765, 0xFFFF, 0xFFFF, "RTS5765DL NVMe SSD Controller (DRAM-less)(0x5765)"},
{0x10EC, 0x5770, 0xFFFF, 0xFFFF, "RTS5770DL NVMe SSD Controller (DRAM-less)(0x5770)"},
{0x10EC, 0x5772, 0xFFFF, 0xFFFF, "RTS5772DL NVMe SSD Controller (DRAM-less)(0x5772)"},
{0x10EC, 0x8029, 0xFFFF, 0xFFFF, "RTL-8029(AS)(0x8029)"},
{0x10EC, 0x8029, 0x10B8, 0x2011, "EZ-Card (SMC1208)(0x10B8-0x2011)"},
{0x10EC, 0x8029, 0x10EC, 0x8029, "RTL-8029(AS)(0x10EC-0x8029)"},
{0x10EC, 0x8029, 0x1113, 0x1208, "EN1208(0x1113-0x1208)"},
{0x10EC, 0x8029, 0x1186, 0x0300, "DE-528(0x1186-0x0300)"},
{0x10EC, 0x8029, 0x1259, 0x2400, "AT-2400(0x1259-0x2400)"},
{0x10EC, 0x8029, 0x1AF4, 0x1100, "QEMU Virtual Machine(0x1AF4-0x1100)"},
{0x10EC, 0x8125, 0xFFFF, 0xFFFF, "RTL8125 2.5GbE Controller(0x8125)"},
{0x10EC, 0x8125, 0x4C52, 0x2022, "LRES2022PT Single-port 2.5Gb Ethernet Network Adapter(0x4C52-0x2022)"},
{0x10EC, 0x8129, 0xFFFF, 0xFFFF, "RTL-8129(0x8129)"},
{0x10EC, 0x8129, 0x10EC, 0x8129, "RT8129 Fast Ethernet Adapter(0x10EC-0x8129)"},
{0x10EC, 0x8129, 0x11EC, 0x8129, "RTL8111/8168 PCIe Gigabit Ethernet (misconfigured)(0x11EC-0x8129)"},
{0x10EC, 0x8136, 0xFFFF, 0xFFFF, "RTL810xE PCI Express Fast Ethernet controller(0x8136)"},
{0x10EC, 0x8136, 0x103C, 0x1985, "RTL8106E on Pavilion 17-e163sg Notebook PC(0x103C-0x1985)"},
{0x10EC, 0x8136, 0x103C, 0x2A8C, "Compaq 500B Microtower(0x103C-0x2A8C)"},
{0x10EC, 0x8136, 0x103C, 0x2AB1, "Pavilion p6774(0x103C-0x2AB1)"},
{0x10EC, 0x8136, 0x103C, 0x30CC, "Pavilion dv6700(0x103C-0x30CC)"},
{0x10EC, 0x8136, 0x1179, 0xFF64, "RTL8102E PCI-E Fast Ethernet NIC(0x1179-0xFF64)"},
{0x10EC, 0x8136, 0x17C0, 0x1053, "RTL8101e Medion WIM 2210 Notebook PC [MD96850](0x17C0-0x1053)"},
{0x10EC, 0x8137, 0xFFFF, 0xFFFF, "RTL8104E PCIe Fast Ethernet Controller(0x8137)"},
{0x10EC, 0x8138, 0xFFFF, 0xFFFF, "RT8139 (B/C) Cardbus Fast Ethernet Adapter(0x8138)"},
{0x10EC, 0x8138, 0x10EC, 0x8138, "RT8139 (B/C) Fast Ethernet Adapter(0x10EC-0x8138)"},
{0x10EC, 0x8139, 0xFFFF, 0xFFFF, "RTL-8100/8101L/8139 PCI Fast Ethernet Adapter(0x8139)"},
{0x10EC, 0x8139, 0x0357, 0x000A, "TTP-Monitoring Card V2.0(0x0357-0x000A)"},
{0x10EC, 0x8139, 0x1025, 0x005A, "TravelMate 290(0x1025-0x005A)"},
{0x10EC, 0x8139, 0x1025, 0x8920, "ALN-325(0x1025-0x8920)"},
{0x10EC, 0x8139, 0x1025, 0x8921, "ALN-325(0x1025-0x8921)"},
{0x10EC, 0x8139, 0x103C, 0x006A, "NX9500(0x103C-0x006A)"},
{0x10EC, 0x8139, 0x103C, 0x2A20, "Pavilion t3030.de Desktop PC(0x103C-0x2A20)"},
{0x10EC, 0x8139, 0x103C, 0x30D9, "Presario C700(0x103C-0x30D9)"},
{0x10EC, 0x8139, 0x1043, 0x1045, "L8400B, L3C/S, X58LE notebook(0x1043-0x1045)"},
{0x10EC, 0x8139, 0x1043, 0x8109, "P5P800-MX Mainboard(0x1043-0x8109)"},
{0x10EC, 0x8139, 0x1071, 0x8160, "MIM2000(0x1071-0x8160)"},
{0x10EC, 0x8139, 0x10BD, 0x0320, "EP-320X-R(0x10BD-0x0320)"},
{0x10EC, 0x8139, 0x10EC, 0x8139, "RTL-8100/8101L/8139 PCI Fast Ethernet Adapter(0x10EC-0x8139)"},
{0x10EC, 0x8139, 0x10F7, 0x8338, "Panasonic CF-Y5 laptop(0x10F7-0x8338)"},
{0x10EC, 0x8139, 0x1113, 0xEC01, "LevelOne FNC-0107TX/FNC-0109TX(0x1113-0xEC01)"},
{0x10EC, 0x8139, 0x1186, 0x1104, "DFE-520TX Fast Ethernet PCI Adapter (rev. D1)(0x1186-0x1104)"},
{0x10EC, 0x8139, 0x1186, 0x1300, "DFE-538TX(0x1186-0x1300)"},
{0x10EC, 0x8139, 0x1186, 0x1320, "SN5200(0x1186-0x1320)"},
{0x10EC, 0x8139, 0x1186, 0x8139, "DRN-32TX(0x1186-0x8139)"},
{0x10EC, 0x8139, 0x11F6, 0x8139, "FN22-3(A) LinxPRO Ethernet Adapter(0x11F6-0x8139)"},
{0x10EC, 0x8139, 0x1259, 0x2500, "AT-2500TX(0x1259-0x2500)"},
{0x10EC, 0x8139, 0x1259, 0x2503, "AT-2500TX/ACPI(0x1259-0x2503)"},
{0x10EC, 0x8139, 0x1385, 0xF31D, "FA311 v2(0x1385-0xF31D)"},
{0x10EC, 0x8139, 0x1395, 0x2100, "AMB2100(0x1395-0x2100)"},
{0x10EC, 0x8139, 0x1429, 0xD010, "ND010/ND012(0x1429-0xD010)"},
{0x10EC, 0x8139, 0x1432, 0x9130, "EN-9130TX(0x1432-0x9130)"},
{0x10EC, 0x8139, 0x1436, 0x8139, "RT8139(0x1436-0x8139)"},
{0x10EC, 0x8139, 0x144D, 0xC00C, "P30/P35 notebook(0x144D-0xC00C)"},
{0x10EC, 0x8139, 0x1458, 0xE000, "GA-7VM400M/7VT600 Motherboard(0x1458-0xE000)"},
{0x10EC, 0x8139, 0x1462, 0x0131, "MS-1013 Notebook(0x1462-0x0131)"},
{0x10EC, 0x8139, 0x1462, 0x217C, "Aspire L250(0x1462-0x217C)"},
{0x10EC, 0x8139, 0x1462, 0x788C, "865PE Neo2-V Mainboard(0x1462-0x788C)"},
{0x10EC, 0x8139, 0x146C, 0x1439, "FE-1439TX(0x146C-0x1439)"},
{0x10EC, 0x8139, 0x1489, 0x6001, "GF100TXRII(0x1489-0x6001)"},
{0x10EC, 0x8139, 0x1489, 0x6002, "GF100TXRA(0x1489-0x6002)"},
{0x10EC, 0x8139, 0x149C, 0x139A, "LFE-8139ATX(0x149C-0x139A)"},
{0x10EC, 0x8139, 0x149C, 0x8139, "LFE-8139TX(0x149C-0x8139)"},
{0x10EC, 0x8139, 0x14CB, 0x0200, "LNR-100 Family 10/100 Base-TX Ethernet(0x14CB-0x0200)"},
{0x10EC, 0x8139, 0x1565, 0x2300, "P4TSV Onboard LAN (RTL8100B)(0x1565-0x2300)"},
{0x10EC, 0x8139, 0x1631, 0x7003, "Onboard RTL8111 on GA-8SIML Rev1.0 Mainboard(0x1631-0x7003)"},
{0x10EC, 0x8139, 0x1695, 0x9001, "Onboard RTL8101L 10/100 MBit(0x1695-0x9001)"},
{0x10EC, 0x8139, 0x16EC, 0x00FF, "USR997900A(0x16EC-0x00FF)"},
{0x10EC, 0x8139, 0x1799, 0x5000, "F5D5000 PCI Card/Desktop Network PCI Card(0x1799-0x5000)"},
{0x10EC, 0x8139, 0x1799, 0x5010, "F5D5010 CardBus Notebook Network Card(0x1799-0x5010)"},
{0x10EC, 0x8139, 0x187E, 0x3303, "FN312(0x187E-0x3303)"},
{0x10EC, 0x8139, 0x1904, 0x8139, "RTL8139D Fast Ethernet Adapter(0x1904-0x8139)"},
{0x10EC, 0x8139, 0x1AF4, 0x1100, "QEMU Virtual Machine(0x1AF4-0x1100)"},
{0x10EC, 0x8139, 0x2646, 0x0001, "KNE120TX(0x2646-0x0001)"},
{0x10EC, 0x8139, 0x8E2E, 0x7000, "KF-230TX(0x8E2E-0x7000)"},
{0x10EC, 0x8139, 0x8E2E, 0x7100, "KF-230TX/2(0x8E2E-0x7100)"},
{0x10EC, 0x8139, 0xA0A0, 0x0007, "ALN-325C(0xA0A0-0x0007)"},
{0x10EC, 0x8161, 0xFFFF, 0xFFFF, "RTL8111/8168/8411 PCI Express Gigabit Ethernet Controller(0x8161)"},
{0x10EC, 0x8161, 0x10EC, 0x8168, "TP-Link TG-3468 v4.0 Gigabit PCI Express Network Adapter(0x10EC-0x8168)"},
{0x10EC, 0x8167, 0xFFFF, 0xFFFF, "RTL-8110SC/8169SC Gigabit Ethernet(0x8167)"},
{0x10EC, 0x8167, 0x105B, 0x0E10, "RTL-8110SC-GR on a N15235/A74MX mainboard(0x105B-0x0E10)"},
{0x10EC, 0x8167, 0x1458, 0xE000, "GA-MA69G-S3H Motherboard(0x1458-0xE000)"},
{0x10EC, 0x8167, 0x1462, 0x235C, "P965 Neo MS-7235 mainboard(0x1462-0x235C)"},
{0x10EC, 0x8167, 0x1462, 0x236C, "945P Neo3-F motherboard(0x1462-0x236C)"},
{0x10EC, 0x8168, 0xFFFF, 0xFFFF, "RTL8111/8168/8211/8411 PCI Express Gigabit Ethernet Controller(0x8168)"},
{0x10EC, 0x8168, 0x1019, 0x8168, "RTL8111/8168 PCI Express Gigabit Ethernet controller(0x1019-0x8168)"},
{0x10EC, 0x8168, 0x1025, 0x1094, "Acer Aspire E5-575G(0x1025-0x1094)"},
{0x10EC, 0x8168, 0x1028, 0x0283, "Vostro 220(0x1028-0x0283)"},
{0x10EC, 0x8168, 0x1028, 0x04B2, "Vostro 3350(0x1028-0x04B2)"},
{0x10EC, 0x8168, 0x1028, 0x04DA, "Vostro 3750(0x1028-0x04DA)"},
{0x10EC, 0x8168, 0x1028, 0x05D7, "Alienware X51 R2(0x1028-0x05D7)"},
{0x10EC, 0x8168, 0x1028, 0x06F2, "Latitude 3470(0x1028-0x06F2)"},
{0x10EC, 0x8168, 0x1028, 0x06F3, "Latitude 3570(0x1028-0x06F3)"},
{0x10EC, 0x8168, 0x1028, 0x0869, "Vostro 3470(0x1028-0x0869)"},
{0x10EC, 0x8168, 0x103C, 0x1611, "Pavilion DM1Z-3000(0x103C-0x1611)"},
{0x10EC, 0x8168, 0x103C, 0x1950, "ProBook 450/455(0x103C-0x1950)"},
{0x10EC, 0x8168, 0x103C, 0x2A6F, "Asus IPIBL-LB Motherboard(0x103C-0x2A6F)"},
{0x10EC, 0x8168, 0x103C, 0x825B, "OMEN-17-w001nv(0x103C-0x825B)"},
{0x10EC, 0x8168, 0x103C, 0x8615, "Pavilion Laptop 15-cw1xxx(0x103C-0x8615)"},
{0x10EC, 0x8168, 0x103C, 0x86D4, "Pavilion Laptop 15-ec0xxx(0x103C-0x86D4)"},
{0x10EC, 0x8168, 0x103C, 0x8882, "HP ProDesk 405 G8 Desktop Mini PC(0x103C-0x8882)"},
{0x10EC, 0x8168, 0x103C, 0x8B17, "ProBook 445 G9/455 G9 [RTL8111HSH-CG GbE Controller](0x103C-0x8B17)"},
{0x10EC, 0x8168, 0x1043, 0x11F5, "Notebook motherboard (one of many models)(0x1043-0x11F5)"},
{0x10EC, 0x8168, 0x1043, 0x16D5, "U6V/U31J laptop(0x1043-0x16D5)"},
{0x10EC, 0x8168, 0x1043, 0x81AA, "P5B(0x1043-0x81AA)"},
{0x10EC, 0x8168, 0x1043, 0x82C6, "M3A78 Series Motherboard(0x1043-0x82C6)"},
{0x10EC, 0x8168, 0x1043, 0x83A3, "M4A785/P7P55 Motherboard(0x1043-0x83A3)"},
{0x10EC, 0x8168, 0x1043, 0x8432, "P8P67 and other motherboards(0x1043-0x8432)"},
{0x10EC, 0x8168, 0x1043, 0x8505, "P8 series motherboard(0x1043-0x8505)"},
{0x10EC, 0x8168, 0x1043, 0x8554, "H81M-C Motherboard(0x1043-0x8554)"},
{0x10EC, 0x8168, 0x1043, 0x859E, "AM1I-A Motherboard(0x1043-0x859E)"},
{0x10EC, 0x8168, 0x1043, 0x8677, "Onboard RTL8111H Ethernet(0x1043-0x8677)"},
{0x10EC, 0x8168, 0x105B, 0x0D7C, "D270S/D250S Motherboard(0x105B-0x0D7C)"},
{0x10EC, 0x8168, 0x10EC, 0x8168, "RTL8111/8168 PCI Express Gigabit Ethernet controller(0x10EC-0x8168)"},
{0x10EC, 0x8168, 0x144D, 0xC652, "RTL8168 on a NP300E5C series laptop(0x144D-0xC652)"},
{0x10EC, 0x8168, 0x1458, 0xE000, "Onboard Ethernet(0x1458-0xE000)"},
{0x10EC, 0x8168, 0x1462, 0x238C, "Onboard RTL8111b on MSI P965 Platinum Mainboard(0x1462-0x238C)"},
{0x10EC, 0x8168, 0x1462, 0x345C, "RTL8111B on MS-7345 Motherboard(0x1462-0x345C)"},
{0x10EC, 0x8168, 0x1462, 0x368C, "K9AG Neo2(0x1462-0x368C)"},
{0x10EC, 0x8168, 0x1462, 0x4180, "Wind PC MS-7418(0x1462-0x4180)"},
{0x10EC, 0x8168, 0x1462, 0x7522, "X58 Pro-E(0x1462-0x7522)"},
{0x10EC, 0x8168, 0x1462, 0x7C37, "X570-A PRO motherboard(0x1462-0x7C37)"},
{0x10EC, 0x8168, 0x1734, 0x11C0, "RTL8211DN on Esprimo P510 D3171 motherboard(0x1734-0x11C0)"},
{0x10EC, 0x8168, 0x1775, 0x11CC, "CC11/CL11(0x1775-0x11CC)"},
{0x10EC, 0x8168, 0x17AA, 0x3098, "ThinkCentre E73(0x17AA-0x3098)"},
{0x10EC, 0x8168, 0x17AA, 0x3814, "Z50-75(0x17AA-0x3814)"},
{0x10EC, 0x8168, 0x17AA, 0x3823, "Lenovo V130-15IGM Laptop - Type 81HL(0x17AA-0x3823)"},
{0x10EC, 0x8168, 0x17AA, 0x5068, "Thinkpad E480/E580(0x17AA-0x5068)"},
{0x10EC, 0x8168, 0x17AA, 0x5124, "ThinkPad E595(0x17AA-0x5124)"},
{0x10EC, 0x8168, 0x1849, 0x8168, "Motherboard (one of many)(0x1849-0x8168)"},
{0x10EC, 0x8168, 0x7470, 0x3468, "TG-3468 Gigabit PCI Express Network Adapter(0x7470-0x3468)"},
{0x10EC, 0x8168, 0x8086, 0x2055, "NUC Kit DN2820FYKH(0x8086-0x2055)"},
{0x10EC, 0x8168, 0x8086, 0xD615, "Desktop Board D510MO/D525MW(0x8086-0xD615)"},
{0x10EC, 0x8168, 0xEA50, 0xCE19, "mCOM10-L1900(0xEA50-0xCE19)"},
{0x10EC, 0x8169, 0xFFFF, 0xFFFF, "RTL8169 PCI Gigabit Ethernet Controller(0x8169)"},
{0x10EC, 0x8169, 0x1025, 0x0079, "Aspire 5024WLMi(0x1025-0x0079)"},
{0x10EC, 0x8169, 0x10BD, 0x3202, "EP-320G-TX1 32-bit PCI Gigabit Ethernet Adapter(0x10BD-0x3202)"},
{0x10EC, 0x8169, 0x10EC, 0x8169, "RTL8169/8110 Family PCI Gigabit Ethernet NIC(0x10EC-0x8169)"},
{0x10EC, 0x8169, 0x1259, 0xC107, "CG-LAPCIGT(0x1259-0xC107)"},
{0x10EC, 0x8169, 0x1371, 0x434E, "ProG-2000L(0x1371-0x434E)"},
{0x10EC, 0x8169, 0x1385, 0x311A, "GA311(0x1385-0x311A)"},
{0x10EC, 0x8169, 0x1385, 0x5200, "GA511 Gigabit PC Card(0x1385-0x5200)"},
{0x10EC, 0x8169, 0x1458, 0xE000, "GA-8I915ME-G Mainboard(0x1458-0xE000)"},
{0x10EC, 0x8169, 0x1462, 0x030C, "K8N Neo-FSR v2.0 mainboard(0x1462-0x030C)"},
{0x10EC, 0x8169, 0x1462, 0x065C, "Hetis 865GV-E (MS-7065)(0x1462-0x065C)"},
{0x10EC, 0x8169, 0x1462, 0x702C, "K8T NEO 2 motherboard(0x1462-0x702C)"},
{0x10EC, 0x8169, 0x1462, 0x7094, "K8T Neo2-F V2.0(0x1462-0x7094)"},
{0x10EC, 0x8169, 0x16EC, 0x011F, "USR997903(0x16EC-0x011F)"},
{0x10EC, 0x8169, 0x1734, 0x1091, "D2030-A1(0x1734-0x1091)"},
{0x10EC, 0x8169, 0xA0A0, 0x0449, "AK86-L motherboard(0xA0A0-0x0449)"},
{0x10EC, 0x816A, 0xFFFF, 0xFFFF, "RTL8111xP UART #1(0x816A)"},
{0x10EC, 0x816A, 0xEA50, 0xCE19, "mCOM10-L1900(0xEA50-0xCE19)"},
{0x10EC, 0x816B, 0xFFFF, 0xFFFF, "RTL8111xP UART #2(0x816B)"},
{0x10EC, 0x816B, 0xEA50, 0xCE19, "mCOM10-L1900(0xEA50-0xCE19)"},
{0x10EC, 0x816C, 0xFFFF, 0xFFFF, "RTL8111xP IPMI interface(0x816C)"},
{0x10EC, 0x816C, 0xEA50, 0xCE19, "mCOM10-L1900(0xEA50-0xCE19)"},
{0x10EC, 0x816D, 0xFFFF, 0xFFFF, "RTL811x EHCI host controller(0x816D)"},
{0x10EC, 0x816D, 0xEA50, 0xCE19, "mCOM10-L1900(0xEA50-0xCE19)"},
{0x10EC, 0x816E, 0xFFFF, 0xFFFF, "Realtek RealManage BMC(0x816E)"},
{0x10EC, 0x8171, 0xFFFF, 0xFFFF, "RTL8191SEvA Wireless LAN Controller(0x8171)"},
{0x10EC, 0x8172, 0xFFFF, 0xFFFF, "RTL8191SEvB Wireless LAN Controller(0x8172)"},
{0x10EC, 0x8173, 0xFFFF, 0xFFFF, "RTL8192SE Wireless LAN Controller(0x8173)"},
{0x10EC, 0x8174, 0xFFFF, 0xFFFF, "RTL8192SE Wireless LAN Controller(0x8174)"},
{0x10EC, 0x8176, 0xFFFF, 0xFFFF, "RTL8188CE 802.11b/g/n WiFi Adapter(0x8176)"},
{0x10EC, 0x8176, 0x1043, 0x84B5, "PCE-N10(0x1043-0x84B5)"},
{0x10EC, 0x8176, 0x1A3B, 0x1139, "AW-NE139H Half-size Mini PCIe Card(0x1A3B-0x1139)"},
{0x10EC, 0x8177, 0xFFFF, 0xFFFF, "RTL8191CE PCIe Wireless Network Adapter(0x8177)"},
{0x10EC, 0x8178, 0xFFFF, 0xFFFF, "RTL8192CE PCIe Wireless Network Adapter(0x8178)"},
{0x10EC, 0x8179, 0xFFFF, 0xFFFF, "RTL8188EE Wireless Network Adapter(0x8179)"},
{0x10EC, 0x8179, 0x103C, 0x197D, "RTL8188EE mini-PCIe card(0x103C-0x197D)"},
{0x10EC, 0x8180, 0xFFFF, 0xFFFF, "RTL8180L 802.11b MAC(0x8180)"},
{0x10EC, 0x8180, 0x1385, 0x4700, "MA521 802.11b Wireless PC Card(0x1385-0x4700)"},
{0x10EC, 0x8180, 0x1737, 0x0019, "WPC11v4 802.11b Wireless-B Notebook Adapter(0x1737-0x0019)"},
{0x10EC, 0x8185, 0xFFFF, 0xFFFF, "RTL-8185 IEEE 802.11a/b/g Wireless LAN Controller(0x8185)"},
{0x10EC, 0x818B, 0xFFFF, 0xFFFF, "RTL8192EE PCIe Wireless Network Adapter(0x818B)"},
{0x10EC, 0x8190, 0xFFFF, 0xFFFF, "RTL8190 802.11n PCI Wireless Network Adapter(0x8190)"},
{0x10EC, 0x8191, 0xFFFF, 0xFFFF, "RTL8192CE PCIe Wireless Network Adapter(0x8191)"},
{0x10EC, 0x8192, 0xFFFF, 0xFFFF, "RTL8192E/RTL8192SE Wireless LAN Controller(0x8192)"},
{0x10EC, 0x8193, 0xFFFF, 0xFFFF, "RTL8192DE Wireless LAN Controller(0x8193)"},
{0x10EC, 0x8196, 0xFFFF, 0xFFFF, "RTL8196 Integrated PCI-e Bridge(0x8196)"},
{0x10EC, 0x8197, 0xFFFF, 0xFFFF, "SmartLAN56 56K Modem(0x8197)"},
{0x10EC, 0x8199, 0xFFFF, 0xFFFF, "RTL8187SE Wireless LAN Controller(0x8199)"},
{0x10EC, 0x8199, 0x1462, 0x6894, "MN54G2 / MS-6894 Wireless Mini PCIe Card(0x1462-0x6894)"},
{0x10EC, 0x8723, 0xFFFF, 0xFFFF, "RTL8723AE PCIe Wireless Network Adapter(0x8723)"},
{0x10EC, 0x8812, 0xFFFF, 0xFFFF, "RTL8812AE 802.11ac PCIe Wireless Network Adapter(0x8812)"},
{0x10EC, 0x8813, 0xFFFF, 0xFFFF, "RTL8813AE 802.11ac PCIe Wireless Network Adapter(0x8813)"},
{0x10EC, 0x8821, 0xFFFF, 0xFFFF, "RTL8821AE 802.11ac PCIe Wireless Network Adapter(0x8821)"},
{0x10EC, 0x8852, 0xFFFF, 0xFFFF, "RTL8852AE 802.11ax PCIe Wireless Network Adapter(0x8852)"},
{0x10EC, 0xA85A, 0xFFFF, 0xFFFF, "RTL8852AE WiFi 6 802.11ax PCIe Adapter(0xA85A)"},
{0x10EC, 0xB723, 0xFFFF, 0xFFFF, "RTL8723BE PCIe Wireless Network Adapter(0xB723)"},
{0x10EC, 0xB723, 0x10EC, 0x8739, "Dell Wireless 1801(0x10EC-0x8739)"},
{0x10EC, 0xB723, 0x17AA, 0xB736, "Z50-75(0x17AA-0xB736)"},
{0x10EC, 0xB821, 0xFFFF, 0xFFFF, "RTL8821CE PCIe 802.11ac Wireless Network Controller(0xB821)"},
{0x10EC, 0xB822, 0xFFFF, 0xFFFF, "RTL8822BE 802.11a/b/g/n/ac WiFi adapter(0xB822)"},
{0x10EC, 0xB822, 0x103C, 0x831B, "Realtek RTL8822BE 802.11ac 2x2 Wi-Fi + Bluetooth 4.2 Combo Adapter (MU-MIMO supported)(0x103C-0x831B)"},
{0x10EC, 0xB822, 0x17AA, 0x5124, "ThinkPad E595(0x17AA-0x5124)"},
{0x10EC, 0xB822, 0x17AA, 0xB023, "ThinkPad E595(0x17AA-0xB023)"},
{0x10EC, 0xB852, 0xFFFF, 0xFFFF, "RTL8852BE PCIe 802.11ax Wireless Network Controller(0xB852)"},
{0x10EC, 0xB85B, 0xFFFF, 0xFFFF, "RTL8852BE PCIe 802.11ax Wireless Network Controller [1T1R](0xB85B)"},
{0x10EC, 0xC821, 0xFFFF, 0xFFFF, "RTL8821CE 802.11ac PCIe Wireless Network Adapter(0xC821)"},
{0x10EC, 0xC822, 0xFFFF, 0xFFFF, "RTL8822CE 802.11ac PCIe Wireless Network Adapter(0xC822)"},
{0x10EC, 0xC82F, 0xFFFF, 0xFFFF, "RTL8822CE 802.11ac PCIe Wireless Network Adapter(0xC82F)"},
{0x10EC, 0xC852, 0xFFFF, 0xFFFF, "RTL8852CE PCIe 802.11ax Wireless Network Controller(0xC852)"},
{0x10EC, 0xD723, 0xFFFF, 0xFFFF, "RTL8723DE 802.11b/g/n PCIe Adapter(0xD723)"},
}; /* pci_vid_10EC[] */

static pci_id_t const pci_vid_10ED[] = {
{0x10ED, 0xFFFF, 0xFFFF, 0xFFFF, "Ascii Corporation(0x10ED)"},
{0x10ED, 0x7310, 0xFFFF, 0xFFFF, "V7310(0x7310)"},
}; /* pci_vid_10ED[] */

static pci_id_t const pci_vid_10EE[] = {
{0x10EE, 0xFFFF, 0xFFFF, 0xFFFF, "Xilinx Corporation(0x10EE)"},
{0x10EE, 0x0001, 0xFFFF, 0xFFFF, "EUROCOM for PCI (ECOMP)(0x0001)"},
{0x10EE, 0x0002, 0xFFFF, 0xFFFF, "Octal E1/T1 for PCI ETP Card(0x0002)"},
{0x10EE, 0x0007, 0xFFFF, 0xFFFF, "Default PCIe endpoint ID(0x0007)"},
{0x10EE, 0x0205, 0xFFFF, 0xFFFF, "Wildcard TE205P(0x0205)"},
{0x10EE, 0x0210, 0xFFFF, 0xFFFF, "Wildcard TE210P(0x0210)"},
{0x10EE, 0x0300, 0xFFFF, 0xFFFF, "Spartan 3 Designs (Xilinx IP)(0x0300)"},
{0x10EE, 0x0314, 0xFFFF, 0xFFFF, "Wildcard TE405P/TE410P (1st Gen)(0x0314)"},
{0x10EE, 0x0405, 0xFFFF, 0xFFFF, "Wildcard TE405P (2nd Gen)(0x0405)"},
{0x10EE, 0x0410, 0xFFFF, 0xFFFF, "Wildcard TE410P (2nd Gen)(0x0410)"},
{0x10EE, 0x0600, 0xFFFF, 0xFFFF, "Xilinx 6 Designs (Xilinx IP)(0x0600)"},
{0x10EE, 0x3FC0, 0xFFFF, 0xFFFF, "RME Digi96(0x3FC0)"},
{0x10EE, 0x3FC1, 0xFFFF, 0xFFFF, "RME Digi96/8(0x3FC1)"},
{0x10EE, 0x3FC2, 0xFFFF, 0xFFFF, "RME Digi96/8 Pro(0x3FC2)"},
{0x10EE, 0x3FC3, 0xFFFF, 0xFFFF, "RME Digi96/8 Pad(0x3FC3)"},
{0x10EE, 0x3FC4, 0xFFFF, 0xFFFF, "RME Digi9652 (Hammerfall)(0x3FC4)"},
{0x10EE, 0x3FC5, 0xFFFF, 0xFFFF, "RME Hammerfall DSP(0x3FC5)"},
{0x10EE, 0x3FC6, 0xFFFF, 0xFFFF, "RME Hammerfall DSP MADI(0x3FC6)"},
{0x10EE, 0x5000, 0xFFFF, 0xFFFF, "Alveo U200 XDMA Platform(0x5000)"},
{0x10EE, 0x5004, 0xFFFF, 0xFFFF, "Alveo U250 XDMA Platform(0x5004)"},
{0x10EE, 0x5005, 0xFFFF, 0xFFFF, "Alveo U250(0x5005)"},
{0x10EE, 0x500C, 0xFFFF, 0xFFFF, "Alveo U280 XDMA Platform(0x500C)"},
{0x10EE, 0x5020, 0xFFFF, 0xFFFF, "Alveo U50 XMDA Platform(0x5020)"},
{0x10EE, 0x505C, 0xFFFF, 0xFFFF, "Alveo U55C(0x505C)"},
{0x10EE, 0x5074, 0xFFFF, 0xFFFF, "Alveo X3522, Quad Port, 10/25GbE Adaptable Accelerator Card(0x5074)"},
{0x10EE, 0x5084, 0xFFFF, 0xFFFF, "Alveo X3522, Quad Port, 10/25GbE Low Latency Network Adapter(0x5084)"},
{0x10EE, 0x6987, 0xFFFF, 0xFFFF, "SmartSSD(0x6987)"},
{0x10EE, 0x6988, 0xFFFF, 0xFFFF, "SmartSSD(0x6988)"},
{0x10EE, 0x7011, 0xFFFF, 0xFFFF, "7-Series FPGA Hard PCIe block (AXI/debug)(0x7011)"},
{0x10EE, 0x7038, 0xFFFF, 0xFFFF, "FPGA Card XC7VX690T(0x7038)"},
{0x10EE, 0x7038, 0x17AA, 0x402F, "FPGA XC7VX690T-3FFG1157E(0x17AA-0x402F)"},
{0x10EE, 0x8019, 0xFFFF, 0xFFFF, "Memory controller(0x8019)"},
{0x10EE, 0x8019, 0x1EEC, 0x0201, "VSEC10232X Dual-port 100Gb/s Etherent PCIe(0x1EEC-0x0201)"},
{0x10EE, 0x8380, 0xFFFF, 0xFFFF, "Ellips ProfiXpress Profibus Master(0x8380)"},
{0x10EE, 0x8381, 0xFFFF, 0xFFFF, "Ellips Santos Frame Grabber(0x8381)"},
{0x10EE, 0x9134, 0xFFFF, 0xFFFF, "SmartSSD(0x9134)"},
{0x10EE, 0x9234, 0xFFFF, 0xFFFF, "SmartSSD(0x9234)"},
{0x10EE, 0x9434, 0xFFFF, 0xFFFF, "SmartSSD(0x9434)"},
{0x10EE, 0xD000, 0xFFFF, 0xFFFF, "Alveo U200 Golden Image(0xD000)"},
{0x10EE, 0xD004, 0xFFFF, 0xFFFF, "Alveo U250 Golden Image(0xD004)"},
{0x10EE, 0xD00C, 0xFFFF, 0xFFFF, "Alveo U280 Golden Image(0xD00C)"},
{0x10EE, 0xD020, 0xFFFF, 0xFFFF, "Alveo U50 Golden Image(0xD020)"},
{0x10EE, 0xD154, 0xFFFF, 0xFFFF, "Copley Controls CAN card (PCI-CAN-02)(0xD154)"},
{0x10EE, 0xEBF0, 0xFFFF, 0xFFFF, "SED Systems Modulator/Demodulator(0xEBF0)"},
{0x10EE, 0xEBF1, 0xFFFF, 0xFFFF, "SED Systems Audio Interface Card(0xEBF1)"},
{0x10EE, 0xEBF2, 0xFFFF, 0xFFFF, "SED Systems Common PCI Interface(0xEBF2)"},
{0x10EE, 0xEBF3, 0xFFFF, 0xFFFF, "SED Systems PCIe-AXI Bridge(0xEBF3)"},
}; /* pci_vid_10EE[] */

static pci_id_t const pci_vid_10EF[] = {
{0x10EF, 0xFFFF, 0xFFFF, 0xFFFF, "Racore Computer Products, Inc.(0x10EF)"},
{0x10EF, 0x8154, 0xFFFF, 0xFFFF, "M815x Token Ring Adapter(0x8154)"},
}; /* pci_vid_10EF[] */

static pci_id_t const pci_vid_10F0[] = {
{0x10F0, 0xFFFF, 0xFFFF, 0xFFFF, "Peritek Corporation(0x10F0)"},
}; /* pci_vid_10F0[] */

static pci_id_t const pci_vid_10F1[] = {
{0x10F1, 0xFFFF, 0xFFFF, 0xFFFF, "Tyan Computer(0x10F1)"},
{0x10F1, 0x2865, 0xFFFF, 0xFFFF, "Tyan Thunder K8E S2865(0x2865)"},
{0x10F1, 0x5300, 0xFFFF, 0xFFFF, "Tyan S5380 Mainboard(0x5300)"},
}; /* pci_vid_10F1[] */

static pci_id_t const pci_vid_10F2[] = {
{0x10F2, 0xFFFF, 0xFFFF, 0xFFFF, "Achme Computer, Inc.(0x10F2)"},
}; /* pci_vid_10F2[] */

static pci_id_t const pci_vid_10F3[] = {
{0x10F3, 0xFFFF, 0xFFFF, 0xFFFF, "Alaris, Inc.(0x10F3)"},
}; /* pci_vid_10F3[] */

static pci_id_t const pci_vid_10F4[] = {
{0x10F4, 0xFFFF, 0xFFFF, 0xFFFF, "S-MOS Systems, Inc.(0x10F4)"},
}; /* pci_vid_10F4[] */

static pci_id_t const pci_vid_10F5[] = {
{0x10F5, 0xFFFF, 0xFFFF, 0xFFFF, "NKK Corporation(0x10F5)"},
{0x10F5, 0xA001, 0xFFFF, 0xFFFF, "NDR4000 [NR4600 Bridge](0xA001)"},
}; /* pci_vid_10F5[] */

static pci_id_t const pci_vid_10F6[] = {
{0x10F6, 0xFFFF, 0xFFFF, 0xFFFF, "Creative Electronic Systems SA(0x10F6)"},
}; /* pci_vid_10F6[] */

static pci_id_t const pci_vid_10F7[] = {
{0x10F7, 0xFFFF, 0xFFFF, 0xFFFF, "Matsushita Electric Industrial Co., Ltd.(0x10F7)"},
}; /* pci_vid_10F7[] */

static pci_id_t const pci_vid_10F8[] = {
{0x10F8, 0xFFFF, 0xFFFF, 0xFFFF, "Altos India Ltd(0x10F8)"},
}; /* pci_vid_10F8[] */

static pci_id_t const pci_vid_10F9[] = {
{0x10F9, 0xFFFF, 0xFFFF, 0xFFFF, "PC Direct(0x10F9)"},
}; /* pci_vid_10F9[] */

static pci_id_t const pci_vid_10FA[] = {
{0x10FA, 0xFFFF, 0xFFFF, 0xFFFF, "Truevision(0x10FA)"},
{0x10FA, 0x000C, 0xFFFF, 0xFFFF, "TARGA 1000(0x000C)"},
}; /* pci_vid_10FA[] */

static pci_id_t const pci_vid_10FB[] = {
{0x10FB, 0xFFFF, 0xFFFF, 0xFFFF, "Thesys Gesellschaft fuer Mikroelektronik mbH(0x10FB)"},
{0x10FB, 0x186F, 0xFFFF, 0xFFFF, "TH 6255(0x186F)"},
}; /* pci_vid_10FB[] */

static pci_id_t const pci_vid_10FC[] = {
{0x10FC, 0xFFFF, 0xFFFF, 0xFFFF, "I-O Data Device, Inc.(0x10FC)"},
{0x10FC, 0x0003, 0xFFFF, 0xFFFF, "Cardbus IDE Controller(0x0003)"},
{0x10FC, 0x0005, 0xFFFF, 0xFFFF, "Cardbus SCSI CBSC II(0x0005)"},
}; /* pci_vid_10FC[] */

static pci_id_t const pci_vid_10FD[] = {
{0x10FD, 0xFFFF, 0xFFFF, 0xFFFF, "Soyo Computer, Inc(0x10FD)"},
}; /* pci_vid_10FD[] */

static pci_id_t const pci_vid_10FE[] = {
{0x10FE, 0xFFFF, 0xFFFF, 0xFFFF, "Fast Multimedia AG(0x10FE)"},
}; /* pci_vid_10FE[] */

static pci_id_t const pci_vid_10FF[] = {
{0x10FF, 0xFFFF, 0xFFFF, 0xFFFF, "NCube(0x10FF)"},
}; /* pci_vid_10FF[] */

static pci_id_t const pci_vid_1100[] = {
{0x1100, 0xFFFF, 0xFFFF, 0xFFFF, "Jazz Multimedia(0x1100)"},
}; /* pci_vid_1100[] */

static pci_id_t const pci_vid_1101[] = {
{0x1101, 0xFFFF, 0xFFFF, 0xFFFF, "Initio Corporation(0x1101)"},
{0x1101, 0x0002, 0xFFFF, 0xFFFF, "INI-920 Ultra SCSI Adapter(0x0002)"},
{0x1101, 0x1060, 0xFFFF, 0xFFFF, "INI-A100U2W(0x1060)"},
{0x1101, 0x1622, 0xFFFF, 0xFFFF, "INI-1623 PCI SATA-II Controller(0x1622)"},
{0x1101, 0x9100, 0xFFFF, 0xFFFF, "INI-9100/9100W(0x9100)"},
{0x1101, 0x9400, 0xFFFF, 0xFFFF, "INI-940 Fast Wide SCSI Adapter(0x9400)"},
{0x1101, 0x9401, 0xFFFF, 0xFFFF, "INI-935 Fast Wide SCSI Adapter(0x9401)"},
{0x1101, 0x9500, 0xFFFF, 0xFFFF, "INI-950 SCSI Adapter(0x9500)"},
{0x1101, 0x9502, 0xFFFF, 0xFFFF, "INI-950P Ultra Wide SCSI Adapter(0x9502)"},
}; /* pci_vid_1101[] */

static pci_id_t const pci_vid_1102[] = {
{0x1102, 0xFFFF, 0xFFFF, 0xFFFF, "Creative Labs(0x1102)"},
{0x1102, 0x0002, 0xFFFF, 0xFFFF, "EMU10k1 [Sound Blaster Live! Series](0x0002)"},
{0x1102, 0x0002, 0x100A, 0x1102, "SB Live! 5.1 Digital OEM SB0220 EMU10K1-JFF(0x100A-0x1102)"},
{0x1102, 0x0002, 0x1102, 0x0020, "CT4670/4850 SBLive! Value(0x1102-0x0020)"},
{0x1102, 0x0002, 0x1102, 0x0021, "CT4620 SBLive!(0x1102-0x0021)"},
{0x1102, 0x0002, 0x1102, 0x002F, "M002/M003 Integrated SBLive!(0x1102-0x002F)"},
{0x1102, 0x0002, 0x1102, 0x100A, "SB0220/0229 SBLive! 5.1 Digital OEM(0x1102-0x100A)"},
{0x1102, 0x0002, 0x1102, 0x4001, "E-mu APS(0x1102-0x4001)"},
{0x1102, 0x0002, 0x1102, 0x8022, "CT4780 SBLive! Value(0x1102-0x8022)"},
{0x1102, 0x0002, 0x1102, 0x8023, "CT4790 SoundBlaster PCI512(0x1102-0x8023)"},
{0x1102, 0x0002, 0x1102, 0x8024, "CT4760 SBLive!(0x1102-0x8024)"},
{0x1102, 0x0002, 0x1102, 0x8025, "CT1140/SB0040 Integrated SBLive!(0x1102-0x8025)"},
{0x1102, 0x0002, 0x1102, 0x8026, "CT4830 SBLive! Value(0x1102-0x8026)"},
{0x1102, 0x0002, 0x1102, 0x8027, "CT4832 SBLive! Value(0x1102-0x8027)"},
{0x1102, 0x0002, 0x1102, 0x8028, "CT4870 SBLive! Value(0x1102-0x8028)"},
{0x1102, 0x0002, 0x1102, 0x8029, "CT4872 SBLive! Value(0x1102-0x8029)"},
{0x1102, 0x0002, 0x1102, 0x802A, "CT4890 SoundBlaster PCI256(0x1102-0x802A)"},
{0x1102, 0x0002, 0x1102, 0x802B, "CT4891 SoundBlaster PCI256(0x1102-0x802B)"},
{0x1102, 0x0002, 0x1102, 0x8031, "CT4831 SBLive! Value(0x1102-0x8031)"},
{0x1102, 0x0002, 0x1102, 0x8032, "CT4871 SBLive! Value(0x1102-0x8032)"},
{0x1102, 0x0002, 0x1102, 0x8033, "CT4893 SoundBlaster PCI256(0x1102-0x8033)"},
{0x1102, 0x0002, 0x1102, 0x8035, "CT0060 SBLive!(0x1102-0x8035)"},
{0x1102, 0x0002, 0x1102, 0x8040, "CT4760 SBLive!(0x1102-0x8040)"},
{0x1102, 0x0002, 0x1102, 0x8050, "CT4750 SoundBlaster PCI512(0x1102-0x8050)"},
{0x1102, 0x0002, 0x1102, 0x8051, "CT4850 SBLive! Value(0x1102-0x8051)"},
{0x1102, 0x0002, 0x1102, 0x8061, "SB060 SBLive! Player 5.1(0x1102-0x8061)"},
{0x1102, 0x0002, 0x1102, 0x8062, "SB0100 SBLive! 5.1(0x1102-0x8062)"},
{0x1102, 0x0002, 0x1102, 0x8063, "DXW Integrated SBLive! 5.1(0x1102-0x8063)"},
{0x1102, 0x0002, 0x1102, 0x8064, "SB0100/SB0102 SBLive! 5.1(0x1102-0x8064)"},
{0x1102, 0x0002, 0x1102, 0x8065, "SB0220/0222 SBLive! 5.1 Digital(0x1102-0x8065)"},
{0x1102, 0x0002, 0x1102, 0x8066, "SB0228 SBLive! 5.1 Digital(0x1102-0x8066)"},
{0x1102, 0x0002, 0x1102, 0x8067, "SB0220 SBLive! 5.1(0x1102-0x8067)"},
{0x1102, 0x0002, 0x1102, 0x8068, "CT0061 SBLive!(0x1102-0x8068)"},
{0x1102, 0x0002, 0x1102, 0x8069, "SB0101 SBLive! 5.1 Value(0x1102-0x8069)"},
{0x1102, 0x0002, 0x1102, 0x806A, "SB0103 SBLive! 5.1(0x1102-0x806A)"},
{0x1102, 0x0002, 0x1102, 0x806B, "SB0105 SBLive! 5.1(0x1102-0x806B)"},
{0x1102, 0x0002, 0x1102, 0x806C, "SB0221 SBLive! 5.1(0x1102-0x806C)"},
{0x1102, 0x0002, 0x1102, 0x8071, "SB0150 SoundBlaster PCI512(0x1102-0x8071)"},
{0x1102, 0x0003, 0xFFFF, 0xFFFF, "SB AWE64(D)(0x0003)"},
{0x1102, 0x0003, 0x1102, 0x0010, "CT4600 AWE64D(0x1102-0x0010)"},
{0x1102, 0x0003, 0x1102, 0x0030, "CT4650 AWE64D(0x1102-0x0030)"},
{0x1102, 0x0003, 0x1102, 0x0031, "CT4655 AWE64D(0x1102-0x0031)"},
{0x1102, 0x0004, 0xFFFF, 0xFFFF, "EMU10k2/CA0100/CA0102/CA10200 [Sound Blaster Audigy Series](0x0004)"},
{0x1102, 0x0004, 0x1102, 0x0040, "SB0090 Audigy Player(0x1102-0x0040)"},
{0x1102, 0x0004, 0x1102, 0x0041, "CT4820 SBLive!2(0x1102-0x0041)"},
{0x1102, 0x0004, 0x1102, 0x0042, "CT0070 Audigy(0x1102-0x0042)"},
{0x1102, 0x0004, 0x1102, 0x0043, "CT0072 Audigy(0x1102-0x0043)"},
{0x1102, 0x0004, 0x1102, 0x0051, "SB0090 Audigy Player/Platinum (EX)(0x1102-0x0051)"},
{0x1102, 0x0004, 0x1102, 0x0052, "SB0162 Audigy ES(0x1102-0x0052)"},
{0x1102, 0x0004, 0x1102, 0x0053, "CT0090/SB0092 Audigy Player/OEM(0x1102-0x0053)"},
{0x1102, 0x0004, 0x1102, 0x0054, "SB0161 Audigy ES(0x1102-0x0054)"},
{0x1102, 0x0004, 0x1102, 0x0055, "SB0192 Audigy(0x1102-0x0055)"},
{0x1102, 0x0004, 0x1102, 0x0056, "SB0191 Audigy(0x1102-0x0056)"},
{0x1102, 0x0004, 0x1102, 0x0057, "SB0091 Audigy(0x1102-0x0057)"},
{0x1102, 0x0004, 0x1102, 0x0058, "SB0095 Audigy Player/OEM(0x1102-0x0058)"},
{0x1102, 0x0004, 0x1102, 0x0059, "SB0230 Audigy(0x1102-0x0059)"},
{0x1102, 0x0004, 0x1102, 0x005A, "SB0231 Audigy(0x1102-0x005A)"},
{0x1102, 0x0004, 0x1102, 0x005B, "SB0232 Audigy(0x1102-0x005B)"},
{0x1102, 0x0004, 0x1102, 0x005C, "SB0238 Audigy(0x1102-0x005C)"},
{0x1102, 0x0004, 0x1102, 0x1002, "SB0240 Audigy 2 Platinum 6.1(0x1102-0x1002)"},
{0x1102, 0x0004, 0x1102, 0x1003, "SB0350 Audigy 2 / SB0243 Audigy 2 OEM(0x1102-0x1003)"},
{0x1102, 0x0004, 0x1102, 0x1004, "SB0242 Audigy 2(0x1102-0x1004)"},
{0x1102, 0x0004, 0x1102, 0x1005, "SB0280 Audigy 2 Platinum Ex(0x1102-0x1005)"},
{0x1102, 0x0004, 0x1102, 0x1006, "SB0245 Audigy 2 OEM(0x1102-0x1006)"},
{0x1102, 0x0004, 0x1102, 0x1007, "SB0240/SB0244 Audigy 2 Platinum(0x1102-0x1007)"},
{0x1102, 0x0004, 0x1102, 0x1008, "SB0320 Audigy 2(0x1102-0x1008)"},
{0x1102, 0x0004, 0x1102, 0x1009, "SB0249 Audigy 2 OEM(0x1102-0x1009)"},
{0x1102, 0x0004, 0x1102, 0x100A, "SB0246 Audigy 2(0x1102-0x100A)"},
{0x1102, 0x0004, 0x1102, 0x2001, "SB0360 Audigy 2 ZS Platinum Pro(0x1102-0x2001)"},
{0x1102, 0x0004, 0x1102, 0x2002, "SB0350 Audigy 2 ZS(0x1102-0x2002)"},
{0x1102, 0x0004, 0x1102, 0x2003, "SB0352 Audigy 2 ZS(0x1102-0x2003)"},
{0x1102, 0x0004, 0x1102, 0x2004, "SB0355 Audigy 2 ZS(0x1102-0x2004)"},
{0x1102, 0x0004, 0x1102, 0x2005, "SB0359 Audigy 2 ZS(0x1102-0x2005)"},
{0x1102, 0x0004, 0x1102, 0x2006, "SB035x Audigy 2 OEM(0x1102-0x2006)"},
{0x1102, 0x0004, 0x1102, 0x2007, "SB0380 Audigy 4 Pro(0x1102-0x2007)"},
{0x1102, 0x0004, 0x1102, 0x4001, "E-MU 1010 [MAEM8810](0x1102-0x4001)"},
{0x1102, 0x0004, 0x1102, 0x4002, "E-MU 0404(0x1102-0x4002)"},
{0x1102, 0x0004, 0x1102, 0x4003, "E-MU 1010(0x1102-0x4003)"},
{0x1102, 0x0005, 0xFFFF, 0xFFFF, "EMU20k1 [Sound Blaster X-Fi Series](0x0005)"},
{0x1102, 0x0005, 0x1102, 0x0021, "X-Fi Platinum(0x1102-0x0021)"},
{0x1102, 0x0005, 0x1102, 0x002C, "X-Fi XtremeGamer FATAL1TY PRO(0x1102-0x002C)"},
{0x1102, 0x0005, 0x1102, 0x1003, "X-Fi XtremeMusic(0x1102-0x1003)"},
{0x1102, 0x0006, 0xFFFF, 0xFFFF, "EMU10k1X / CA0103 [SB Live! OEM / SB 5.1 / Ectiva 5.1](0x0006)"},
{0x1102, 0x0006, 0x1102, 0x1001, "SB0680 Sound Blaster 5.1(0x1102-0x1001)"},
{0x1102, 0x0006, 0x1102, 0x1003, "SB0203 SB Live! 5.1 (Dell)(0x1102-0x1003)"},
{0x1102, 0x0006, 0x1102, 0x1004, "TP0033 Ectiva Audio 5.1(0x1102-0x1004)"},
{0x1102, 0x0007, 0xFFFF, 0xFFFF, "CA0106/CA0111 [SB Live!/Audigy/X-Fi Series](0x0007)"},
{0x1102, 0x0007, 0x1102, 0x0007, "SBLive! 24bit(0x1102-0x0007)"},
{0x1102, 0x0007, 0x1102, 0x1001, "SB0310 Audigy LS(0x1102-0x1001)"},
{0x1102, 0x0007, 0x1102, 0x1002, "SB0312 Audigy LS(0x1102-0x1002)"},
{0x1102, 0x0007, 0x1102, 0x1006, "SB0410 SBLive! 24-bit(0x1102-0x1006)"},
{0x1102, 0x0007, 0x1102, 0x100A, "SB0570 [SB Audigy SE](0x1102-0x100A)"},
{0x1102, 0x0007, 0x1102, 0x1012, "SB0790 X-Fi XA(0x1102-0x1012)"},
{0x1102, 0x0007, 0x1102, 0x1013, "Soundblaster X-Fi Xtreme Audio(0x1102-0x1013)"},
{0x1102, 0x0007, 0x1462, 0x1009, "K8N Diamond(0x1462-0x1009)"},
{0x1102, 0x0008, 0xFFFF, 0xFFFF, "CA0108/CA10300 [Sound Blaster Audigy Series](0x0008)"},
{0x1102, 0x0008, 0x1102, 0x0008, "EMU0404 Digital Audio System(0x1102-0x0008)"},
{0x1102, 0x0008, 0x1102, 0x1001, "SB0400 Audigy 2 Value(0x1102-0x1001)"},
{0x1102, 0x0008, 0x1102, 0x1021, "SB0610 Audigy 4 Value(0x1102-0x1021)"},
{0x1102, 0x0008, 0x1102, 0x1022, "SBxxx Audigy 2/4 Value(0x1102-0x1022)"},
{0x1102, 0x0008, 0x1102, 0x1023, "SB0612 Audigy 2 LS(0x1102-0x1023)"},
{0x1102, 0x0008, 0x1102, 0x1024, "SB1550 Audigy 5/Rx(0x1102-0x1024)"},
{0x1102, 0x0008, 0x1102, 0x1101, "SBxxxx Audigy 2 SA(0x1102-0x1101)"},
{0x1102, 0x0008, 0x1102, 0x2001, "SB0530 Audigy 2 ZS Notebook(0x1102-0x2001)"},
{0x1102, 0x0008, 0x1102, 0x2021, "SBxxxx Audigy 4 Notebook(0x1102-0x2021)"},
{0x1102, 0x0008, 0x1102, 0x4002, "E-MU 0404(0x1102-0x4002)"},
{0x1102, 0x0008, 0x1102, 0x4003, "E-MU 1010(0x1102-0x4003)"},
{0x1102, 0x0008, 0x1102, 0x4004, "EMU1010 Digital Audio System [MAEM8960](0x1102-0x4004)"},
{0x1102, 0x0008, 0x1102, 0x4005, "E-MU 0404 [MAEM8984](0x1102-0x4005)"},
{0x1102, 0x0008, 0x1102, 0x4007, "E-MU 1010 [MAEM8982](0x1102-0x4007)"},
{0x1102, 0x0008, 0x1102, 0x4201, "E-MU 0202 [MAEM8950](0x1102-0x4201)"},
{0x1102, 0x0009, 0xFFFF, 0xFFFF, "CA0110 [Sound Blaster X-Fi Xtreme Audio](0x0009)"},
{0x1102, 0x0009, 0x1102, 0x0010, "MB0820 Integrated(0x1102-0x0010)"},
{0x1102, 0x0009, 0x1102, 0x0018, "SB1040 PCI Express(0x1102-0x0018)"},
{0x1102, 0x000B, 0xFFFF, 0xFFFF, "EMU20k2 [Sound Blaster X-Fi Titanium Series](0x000B)"},
{0x1102, 0x000B, 0x1102, 0x0041, "SB0880 [SoundBlaster X-Fi Titanium PCI-e](0x1102-0x0041)"},
{0x1102, 0x000B, 0x1102, 0x0062, "SB1270 [SoundBlaster X-Fi Titanium HD](0x1102-0x0062)"},
{0x1102, 0x0012, 0xFFFF, 0xFFFF, "CA0132 Sound Core3D [Sound Blaster Recon3D / Z-Series / Sound BlasterX AE-5 Plus](0x0012)"},
{0x1102, 0x0012, 0x1102, 0x0010, "SB1570 SB Audigy Fx(0x1102-0x0010)"},
{0x1102, 0x0012, 0x1102, 0x0191, "CA0132 Sound Core3D - CA0113 [ Sound BlasterX AE-5 Plus](0x1102-0x0191)"},
{0x1102, 0x4001, 0xFFFF, 0xFFFF, "SB Audigy FireWire Port(0x4001)"},
{0x1102, 0x4001, 0x1102, 0x0010, "SB Audigy FireWire Port(0x1102-0x0010)"},
{0x1102, 0x7002, 0xFFFF, 0xFFFF, "SB Live! Game Port(0x7002)"},
{0x1102, 0x7002, 0x1102, 0x0020, "Gameport Joystick(0x1102-0x0020)"},
{0x1102, 0x7003, 0xFFFF, 0xFFFF, "SB Audigy Game Port(0x7003)"},
{0x1102, 0x7003, 0x1102, 0x0040, "SB Audigy Game Port(0x1102-0x0040)"},
{0x1102, 0x7003, 0x1102, 0x0060, "SB Audigy2 MIDI/Game Port(0x1102-0x0060)"},
{0x1102, 0x7004, 0xFFFF, 0xFFFF, "[SB Live! Value] Input device controller(0x7004)"},
{0x1102, 0x7005, 0xFFFF, 0xFFFF, "SB Audigy LS Game Port(0x7005)"},
{0x1102, 0x7005, 0x1102, 0x1001, "SB0310 Audigy LS MIDI/Game port(0x1102-0x1001)"},
{0x1102, 0x7005, 0x1102, 0x1002, "SB0312 Audigy LS MIDI/Game port(0x1102-0x1002)"},
{0x1102, 0x7006, 0xFFFF, 0xFFFF, "[SB X-Fi Xtreme Audio] CA0110-IBG PCIe to PCI Bridge(0x7006)"},
{0x1102, 0x8938, 0xFFFF, 0xFFFF, "Ectiva EV1938(0x8938)"},
{0x1102, 0x8938, 0x1033, 0x80E5, "SlimTower-Jim (NEC)(0x1033-0x80E5)"},
{0x1102, 0x8938, 0x1071, 0x7150, "Mitac 7150(0x1071-0x7150)"},
{0x1102, 0x8938, 0x110A, 0x5938, "Siemens Scenic Mobile 510PIII(0x110A-0x5938)"},
{0x1102, 0x8938, 0x13BD, 0x100C, "Ceres-C (Sharp, Intel BX)(0x13BD-0x100C)"},
{0x1102, 0x8938, 0x13BD, 0x100D, "Sharp, Intel Banister(0x13BD-0x100D)"},
{0x1102, 0x8938, 0x13BD, 0x100E, "TwinHead P09S/P09S3 (Sharp)(0x13BD-0x100E)"},
{0x1102, 0x8938, 0x13BD, 0xF6F1, "Marlin (Sharp)(0x13BD-0xF6F1)"},
{0x1102, 0x8938, 0x14FF, 0x0E70, "P88TE (TWINHEAD INTERNATIONAL Corp)(0x14FF-0x0E70)"},
{0x1102, 0x8938, 0x14FF, 0xC401, "Notebook 9100/9200/2000 (TWINHEAD INTERNATIONAL Corp)(0x14FF-0xC401)"},
{0x1102, 0x8938, 0x156D, 0xB400, "G400 - Geo (AlphaTop (Taiwan))(0x156D-0xB400)"},
{0x1102, 0x8938, 0x156D, 0xB550, "G560  (AlphaTop (Taiwan))(0x156D-0xB550)"},
{0x1102, 0x8938, 0x156D, 0xB560, "G560  (AlphaTop (Taiwan))(0x156D-0xB560)"},
{0x1102, 0x8938, 0x156D, 0xB700, "G700/U700  (AlphaTop (Taiwan))(0x156D-0xB700)"},
{0x1102, 0x8938, 0x156D, 0xB795, "G795  (AlphaTop (Taiwan))(0x156D-0xB795)"},
{0x1102, 0x8938, 0x156D, 0xB797, "G797  (AlphaTop (Taiwan))(0x156D-0xB797)"},
}; /* pci_vid_1102[] */

static pci_id_t const pci_vid_1103[] = {
{0x1103, 0xFFFF, 0xFFFF, 0xFFFF, "HighPoint Technologies, Inc.(0x1103)"},
{0x1103, 0x0003, 0xFFFF, 0xFFFF, "HPT343/345/346/363(0x0003)"},
{0x1103, 0x0004, 0xFFFF, 0xFFFF, "HPT366/368/370/370A/372/372N(0x0004)"},
{0x1103, 0x0004, 0x1103, 0x0001, "HPT370A(0x1103-0x0001)"},
{0x1103, 0x0004, 0x1103, 0x0004, "HPT366 UDMA66 (r1) / HPT368 UDMA66 (r2) / HPT370 UDMA100 (r3) / HPT370 UDMA100 RAID (r4)(0x1103-0x0004)"},
{0x1103, 0x0004, 0x1103, 0x0005, "HPT370 UDMA100(0x1103-0x0005)"},
{0x1103, 0x0004, 0x1103, 0x0006, "HPT302/302N(0x1103-0x0006)"},
{0x1103, 0x0005, 0xFFFF, 0xFFFF, "HPT372A/372N(0x0005)"},
{0x1103, 0x0006, 0xFFFF, 0xFFFF, "HPT302/302N(0x0006)"},
{0x1103, 0x0007, 0xFFFF, 0xFFFF, "HPT371/371N(0x0007)"},
{0x1103, 0x0008, 0xFFFF, 0xFFFF, "HPT374(0x0008)"},
{0x1103, 0x0009, 0xFFFF, 0xFFFF, "HPT372N(0x0009)"},
{0x1103, 0x0620, 0xFFFF, 0xFFFF, "RocketRAID 620 2 Port SATA-III Controller(0x0620)"},
{0x1103, 0x0622, 0xFFFF, 0xFFFF, "RocketRAID 622 2 Port SATA-III Controller(0x0622)"},
{0x1103, 0x0640, 0xFFFF, 0xFFFF, "RocketRAID 640 4 Port SATA-III Controller(0x0640)"},
{0x1103, 0x0641, 0xFFFF, 0xFFFF, "RocketRAID 640L 4 Port SATA-III Controller(0x0641)"},
{0x1103, 0x0642, 0xFFFF, 0xFFFF, "RocketRAID 642L SATA-III Controller (2 eSATA ports + 2 internal SATA ports)(0x0642)"},
{0x1103, 0x0644, 0xFFFF, 0xFFFF, "RocketRAID 644 4 Port SATA-III Controller (eSATA)(0x0644)"},
{0x1103, 0x0645, 0xFFFF, 0xFFFF, "RocketRAID 644L 4 Port SATA-III Controller (eSATA)(0x0645)"},
{0x1103, 0x0646, 0xFFFF, 0xFFFF, "RocketRAID 644LS SATA-III Controller (4 eSATA devices connected by 1 SAS cable)(0x0646)"},
{0x1103, 0x0750, 0xFFFF, 0xFFFF, "Rocket 750 PCIe Gen2 SATA III Controller(0x0750)"},
{0x1103, 0x0840, 0xFFFF, 0xFFFF, "RocketRAID 840 PCIe Gen3 SATA III Controller(0x0840)"},
{0x1103, 0x1720, 0xFFFF, 0xFFFF, "RocketRAID 1720 (2x SATA II RAID Controller)(0x1720)"},
{0x1103, 0x1740, 0xFFFF, 0xFFFF, "RocketRAID 1740(0x1740)"},
{0x1103, 0x1742, 0xFFFF, 0xFFFF, "RocketRAID 1742(0x1742)"},
{0x1103, 0x2210, 0xFFFF, 0xFFFF, "RocketRAID 2210 SATA-II Controller(0x2210)"},
{0x1103, 0x2210, 0x11AB, 0x11AB, "88SX6042(0x11AB-0x11AB)"},
{0x1103, 0x2300, 0xFFFF, 0xFFFF, "RocketRAID 230x 4 Port SATA-II Controller(0x2300)"},
{0x1103, 0x2310, 0xFFFF, 0xFFFF, "RocketRAID 2310 4 Port SATA-II Controller(0x2310)"},
{0x1103, 0x2320, 0xFFFF, 0xFFFF, "RocketRAID 2320 SATA-II Controller(0x2320)"},
{0x1103, 0x2322, 0xFFFF, 0xFFFF, "RocketRAID 2322 SATA-II Controller(0x2322)"},
{0x1103, 0x2340, 0xFFFF, 0xFFFF, "RocketRAID 2340 16 Port SATA-II Controller(0x2340)"},
{0x1103, 0x2640, 0xFFFF, 0xFFFF, "RocketRAID 2640 SAS/SATA Controller(0x2640)"},
{0x1103, 0x2720, 0xFFFF, 0xFFFF, "RocketRAID 2720 PCIe Gen2 6Gb/s SAS/SATA Controller(0x2720)"},
{0x1103, 0x2722, 0xFFFF, 0xFFFF, "RocketRAID 2722(0x2722)"},
{0x1103, 0x2740, 0xFFFF, 0xFFFF, "RocketRAID 2740(0x2740)"},
{0x1103, 0x2744, 0xFFFF, 0xFFFF, "RocketRaid 2744(0x2744)"},
{0x1103, 0x2782, 0xFFFF, 0xFFFF, "RocketRAID 2782(0x2782)"},
{0x1103, 0x2840, 0xFFFF, 0xFFFF, "RocketRAID 2840 PCIe Gen3 6Gb/s SAS/SATA Controller(0x2840)"},
{0x1103, 0x3120, 0xFFFF, 0xFFFF, "RocketRAID 3120(0x3120)"},
{0x1103, 0x3220, 0xFFFF, 0xFFFF, "RocketRAID 3220(0x3220)"},
{0x1103, 0x3320, 0xFFFF, 0xFFFF, "RocketRAID 3320(0x3320)"},
{0x1103, 0x3520, 0xFFFF, 0xFFFF, "RocketRAID 3520 PCIe Gen1 8-Port SATA II Controller(0x3520)"},
{0x1103, 0x3530, 0xFFFF, 0xFFFF, "RocketRAID 3530 PCIe Gen1 12-Port SATA II Controller(0x3530)"},
{0x1103, 0x3740, 0xFFFF, 0xFFFF, "RocketRAID 3740 PCIe Gen3 12Gb/s SAS/SATA Controller(0x3740)"},
{0x1103, 0x4310, 0xFFFF, 0xFFFF, "RocketRaid 4310(0x4310)"},
{0x1103, 0x4320, 0xFFFF, 0xFFFF, "RocketRAID 4320 SAS Controller(0x4320)"},
{0x1103, 0x7103, 0xFFFF, 0xFFFF, "SSD7103 PCIe Gen3 x16 4-Port M.2 NVMe RAID Controller(0x7103)"},
{0x1103, 0x7105, 0xFFFF, 0xFFFF, "SSD7105 PCIe Gen3 x16 4-Port M.2 NVMe RAID Controller(0x7105)"},
{0x1103, 0x7110, 0xFFFF, 0xFFFF, "SSD7110 PCIe Gen3 x16 NVMe RAID Controller(0x7110)"},
{0x1103, 0x7505, 0xFFFF, 0xFFFF, "SSD7505 PCIe Gen4 x16 4-Port M.2 NVMe RAID Controller(0x7505)"},
{0x1103, 0x7540, 0xFFFF, 0xFFFF, "SSD7540 PCIe Gen4 x16 8-Port M.2 NVMe RAID Controller(0x7540)"},
{0x1103, 0x7580, 0xFFFF, 0xFFFF, "SSD7580 PCIe Gen4 x16 8-Port M.2 NVMe RAID Controller(0x7580)"},
}; /* pci_vid_1103[] */

static pci_id_t const pci_vid_1104[] = {
{0x1104, 0xFFFF, 0xFFFF, 0xFFFF, "RasterOps Corp.(0x1104)"},
}; /* pci_vid_1104[] */

static pci_id_t const pci_vid_1105[] = {
{0x1105, 0xFFFF, 0xFFFF, 0xFFFF, "Sigma Designs, Inc.(0x1105)"},
{0x1105, 0x1105, 0xFFFF, 0xFFFF, "REALmagic Xcard MPEG 1/2/3/4 DVD Decoder(0x1105)"},
{0x1105, 0x8300, 0xFFFF, 0xFFFF, "REALmagic Hollywood Plus DVD Decoder(0x8300)"},
{0x1105, 0x8400, 0xFFFF, 0xFFFF, "EM840x REALmagic DVD/MPEG-2 Audio/Video Decoder(0x8400)"},
{0x1105, 0x8401, 0xFFFF, 0xFFFF, "EM8401 REALmagic DVD/MPEG-2 A/V Decoder(0x8401)"},
{0x1105, 0x8470, 0xFFFF, 0xFFFF, "EM8470 REALmagic DVD/MPEG-4 A/V Decoder(0x8470)"},
{0x1105, 0x8471, 0xFFFF, 0xFFFF, "EM8471 REALmagic DVD/MPEG-4 A/V Decoder(0x8471)"},
{0x1105, 0x8475, 0xFFFF, 0xFFFF, "EM8475 REALmagic DVD/MPEG-4 A/V Decoder(0x8475)"},
{0x1105, 0x8475, 0x1105, 0x0001, "REALmagic X-Card(0x1105-0x0001)"},
{0x1105, 0x8476, 0xFFFF, 0xFFFF, "EM8476 REALmagic DVD/MPEG-4 A/V Decoder(0x8476)"},
{0x1105, 0x8476, 0x127D, 0x0000, "CineView II(0x127D-0x0000)"},
{0x1105, 0x8485, 0xFFFF, 0xFFFF, "EM8485 REALmagic DVD/MPEG-4 A/V Decoder(0x8485)"},
{0x1105, 0x8486, 0xFFFF, 0xFFFF, "EM8486 REALmagic DVD/MPEG-4 A/V Decoder(0x8486)"},
{0x1105, 0xC621, 0xFFFF, 0xFFFF, "EM8621L Digital Media Processor(0xC621)"},
{0x1105, 0xC622, 0xFFFF, 0xFFFF, "EM8622L MPEG-4.10 (H.264) and SMPTE 421M (VC-1) A/V Decoder(0xC622)"},
}; /* pci_vid_1105[] */

static pci_id_t const pci_vid_1106[] = {
{0x1106, 0xFFFF, 0xFFFF, 0xFFFF, "VIA Technologies, Inc.(0x1106)"},
{0x1106, 0x0102, 0xFFFF, 0xFFFF, "Embedded VIA Ethernet Controller(0x0102)"},
{0x1106, 0x0130, 0xFFFF, 0xFFFF, "VT6305 1394.A Controller(0x0130)"},
{0x1106, 0x0198, 0xFFFF, 0xFFFF, "P4X600 Host Bridge(0x0198)"},
{0x1106, 0x0204, 0xFFFF, 0xFFFF, "K8M800 Host Bridge(0x0204)"},
{0x1106, 0x0208, 0xFFFF, 0xFFFF, "PT890 Host Bridge(0x0208)"},
{0x1106, 0x0238, 0xFFFF, 0xFFFF, "K8T890 Host Bridge(0x0238)"},
{0x1106, 0x0258, 0xFFFF, 0xFFFF, "PT880 Host Bridge(0x0258)"},
{0x1106, 0x0259, 0xFFFF, 0xFFFF, "CN333/CN400/PM880 Host Bridge(0x0259)"},
{0x1106, 0x0269, 0xFFFF, 0xFFFF, "KT880 Host Bridge(0x0269)"},
{0x1106, 0x0282, 0xFFFF, 0xFFFF, "K8T800Pro Host Bridge(0x0282)"},
{0x1106, 0x0282, 0x1043, 0x80A3, "A8V Deluxe(0x1043-0x80A3)"},
{0x1106, 0x0290, 0xFFFF, 0xFFFF, "K8M890 Host Bridge(0x0290)"},
{0x1106, 0x0293, 0xFFFF, 0xFFFF, "PM896 Host Bridge(0x0293)"},
{0x1106, 0x0296, 0xFFFF, 0xFFFF, "P4M800 Host Bridge(0x0296)"},
{0x1106, 0x0305, 0xFFFF, 0xFFFF, "VT8363/8365 [KT133/KM133](0x0305)"},
{0x1106, 0x0305, 0x1019, 0x0987, "K7VZA Mainboard(0x1019-0x0987)"},
{0x1106, 0x0305, 0x1043, 0x8033, "A7V Mainboard(0x1043-0x8033)"},
{0x1106, 0x0305, 0x1043, 0x803E, "A7V-E Mainboard(0x1043-0x803E)"},
{0x1106, 0x0305, 0x1043, 0x8042, "A7V133/A7V133-C Mainboard(0x1043-0x8042)"},
{0x1106, 0x0305, 0x147B, 0xA401, "KT7/KT7-RAID/KT7A/KT7A-RAID Mainboard(0x147B-0xA401)"},
{0x1106, 0x0308, 0xFFFF, 0xFFFF, "PT880 Ultra/PT894 Host Bridge(0x0308)"},
{0x1106, 0x0308, 0x1043, 0x8199, "P4V800D-X Mainboard(0x1043-0x8199)"},
{0x1106, 0x0308, 0x1849, 0x0308, "Motherboard(0x1849-0x0308)"},
{0x1106, 0x0314, 0xFFFF, 0xFFFF, "CN700/VN800/P4M800CE/Pro Host Bridge(0x0314)"},
{0x1106, 0x0324, 0xFFFF, 0xFFFF, "CX700/VX700 Host Bridge(0x0324)"},
{0x1106, 0x0327, 0xFFFF, 0xFFFF, "P4M890 Host Bridge(0x0327)"},
{0x1106, 0x0336, 0xFFFF, 0xFFFF, "K8M890CE Host Bridge(0x0336)"},
{0x1106, 0x0340, 0xFFFF, 0xFFFF, "PT900 Host Bridge(0x0340)"},
{0x1106, 0x0351, 0xFFFF, 0xFFFF, "K8T890CF Host Bridge(0x0351)"},
{0x1106, 0x0353, 0xFFFF, 0xFFFF, "VX800/820-Series Chipset Host-Bridge Controller(0x0353)"},
{0x1106, 0x0364, 0xFFFF, 0xFFFF, "CN896/VN896/P4M900 Host Bridge(0x0364)"},
{0x1106, 0x0364, 0x1043, 0x81CE, "P5VD2-VM mothervoard(0x1043-0x81CE)"},
{0x1106, 0x0391, 0xFFFF, 0xFFFF, "VT8371 [KX133](0x0391)"},
{0x1106, 0x0409, 0xFFFF, 0xFFFF, "VX855/VX875 Host Bridge: Host Control(0x0409)"},
{0x1106, 0x0410, 0xFFFF, 0xFFFF, "VX900 Series Host Bridge: Host Control(0x0410)"},
{0x1106, 0x0415, 0xFFFF, 0xFFFF, "VT6415 PATA IDE Host Controller(0x0415)"},
{0x1106, 0x0415, 0x1043, 0x838F, "Motherboard(0x1043-0x838F)"},
{0x1106, 0x0501, 0xFFFF, 0xFFFF, "VT8501 [Apollo MVP4](0x0501)"},
{0x1106, 0x0505, 0xFFFF, 0xFFFF, "VT82C505(0x0505)"},
{0x1106, 0x0561, 0xFFFF, 0xFFFF, "VT82C576MV(0x0561)"},
{0x1106, 0x0571, 0xFFFF, 0xFFFF, "VT82C586A/B/VT82C686/A/B/VT823x/A/C PIPC Bus Master IDE(0x0571)"},
{0x1106, 0x0571, 0x1019, 0x0985, "P6VXA Motherboard(0x1019-0x0985)"},
{0x1106, 0x0571, 0x1019, 0x0A81, "L7VTA v1.0 Motherboard (KT400-8235)(0x1019-0x0A81)"},
{0x1106, 0x0571, 0x1043, 0x8052, "VT8233A Bus Master ATA100/66/33 IDE(0x1043-0x8052)"},
{0x1106, 0x0571, 0x1043, 0x808C, "A7V8X / A7V333 motherboard(0x1043-0x808C)"},
{0x1106, 0x0571, 0x1043, 0x80A1, "A7V8X-X motherboard rev. 1.01(0x1043-0x80A1)"},
{0x1106, 0x0571, 0x1043, 0x80ED, "A7V600/K8V-X/A8V Deluxe motherboard(0x1043-0x80ED)"},
{0x1106, 0x0571, 0x1106, 0x0571, "VT82C586/B/VT82C686/A/B/VT8233/A/C/VT8235 PIPC Bus Master IDE(0x1106-0x0571)"},
{0x1106, 0x0571, 0x1179, 0x0001, "Magnia Z310(0x1179-0x0001)"},
{0x1106, 0x0571, 0x1297, 0xF641, "FX41 motherboard(0x1297-0xF641)"},
{0x1106, 0x0571, 0x1458, 0x5002, "GA-7VAX Mainboard(0x1458-0x5002)"},
{0x1106, 0x0571, 0x1462, 0x5901, "KT6 Delta-FIS2R (MS-6590)(0x1462-0x5901)"},
{0x1106, 0x0571, 0x1462, 0x7020, "K8T NEO 2 motherboard(0x1462-0x7020)"},
{0x1106, 0x0571, 0x1462, 0x7094, "K8T Neo2-F V2.0(0x1462-0x7094)"},
{0x1106, 0x0571, 0x1462, 0x7120, "KT4AV motherboard(0x1462-0x7120)"},
{0x1106, 0x0571, 0x1462, 0x7181, "K8MM3-V mainboard(0x1462-0x7181)"},
{0x1106, 0x0571, 0x147B, 0x1407, "KV8-MAX3 motherboard(0x147B-0x1407)"},
{0x1106, 0x0571, 0x1849, 0x0571, "K7VT series Motherboards(0x1849-0x0571)"},
{0x1106, 0x0576, 0xFFFF, 0xFFFF, "VT82C576 3V [Apollo Master](0x0576)"},
{0x1106, 0x0581, 0xFFFF, 0xFFFF, "CX700/VX700/VX800/820-Series Serial ATA RAID-Controller(0x0581)"},
{0x1106, 0x0581, 0x1106, 0x0581, "Wrong IDE ID(0x1106-0x0581)"},
{0x1106, 0x0585, 0xFFFF, 0xFFFF, "VT82C585VP [Apollo VP1/VPX](0x0585)"},
{0x1106, 0x0586, 0xFFFF, 0xFFFF, "VT82C586/A/B PCI-to-ISA [Apollo VP](0x0586)"},
{0x1106, 0x0586, 0x1106, 0x0000, "MVP3 ISA Bridge(0x1106-0x0000)"},
{0x1106, 0x0591, 0xFFFF, 0xFFFF, "VT8237A SATA 2-Port Controller(0x0591)"},
{0x1106, 0x0595, 0xFFFF, 0xFFFF, "VT82C595 [Apollo VP2](0x0595)"},
{0x1106, 0x0596, 0xFFFF, 0xFFFF, "VT82C596 ISA [Mobile South](0x0596)"},
{0x1106, 0x0596, 0x1106, 0x0000, "VT82C596/A/B PCI to ISA Bridge(0x1106-0x0000)"},
{0x1106, 0x0596, 0x1458, 0x0596, "VT82C596/A/B PCI to ISA Bridge(0x1458-0x0596)"},
{0x1106, 0x0597, 0xFFFF, 0xFFFF, "VT82C597 [Apollo VP3](0x0597)"},
{0x1106, 0x0598, 0xFFFF, 0xFFFF, "VT82C598 [Apollo MVP3](0x0598)"},
{0x1106, 0x0601, 0xFFFF, 0xFFFF, "VT8601 [Apollo ProMedia](0x0601)"},
{0x1106, 0x0605, 0xFFFF, 0xFFFF, "VT8605 [ProSavage PM133](0x0605)"},
{0x1106, 0x0605, 0x103C, 0x1254, "D9840-60001 [Brio BA410 Motherboard](0x103C-0x1254)"},
{0x1106, 0x0605, 0x1043, 0x802C, "CUV4X mainboard(0x1043-0x802C)"},
{0x1106, 0x0680, 0xFFFF, 0xFFFF, "VT82C680 [Apollo P6](0x0680)"},
{0x1106, 0x0686, 0xFFFF, 0xFFFF, "VT82C686 [Apollo Super South](0x0686)"},
{0x1106, 0x0686, 0x1019, 0x0985, "P6VXA Motherboard(0x1019-0x0985)"},
{0x1106, 0x0686, 0x103C, 0x1256, "D9840-60001 [Brio BA410 Motherboard](0x103C-0x1256)"},
{0x1106, 0x0686, 0x1043, 0x802C, "CUV4X mainboard(0x1043-0x802C)"},
{0x1106, 0x0686, 0x1043, 0x8033, "A7V Mainboard(0x1043-0x8033)"},
{0x1106, 0x0686, 0x1043, 0x803E, "A7V-E Mainboard(0x1043-0x803E)"},
{0x1106, 0x0686, 0x1043, 0x8040, "A7M266 Mainboard(0x1043-0x8040)"},
{0x1106, 0x0686, 0x1043, 0x8042, "A7V133/A7V133-C Mainboard(0x1043-0x8042)"},
{0x1106, 0x0686, 0x1106, 0x0000, "VT82C686/A PCI to ISA Bridge(0x1106-0x0000)"},
{0x1106, 0x0686, 0x1106, 0x0686, "VT82C686/A PCI to ISA Bridge(0x1106-0x0686)"},
{0x1106, 0x0686, 0x1179, 0x0001, "Magnia Z310(0x1179-0x0001)"},
{0x1106, 0x0686, 0x147B, 0xA702, "KG7-Lite Mainboard(0x147B-0xA702)"},
{0x1106, 0x0691, 0xFFFF, 0xFFFF, "VT82C693A/694x [Apollo PRO133x](0x0691)"},
{0x1106, 0x0691, 0x1019, 0x0985, "P6VXA Motherboard(0x1019-0x0985)"},
{0x1106, 0x0691, 0x1179, 0x0001, "Magnia Z310(0x1179-0x0001)"},
{0x1106, 0x0691, 0x1458, 0x0691, "VT82C691 Apollo Pro System Controller(0x1458-0x0691)"},
{0x1106, 0x0693, 0xFFFF, 0xFFFF, "VT82C693 [Apollo Pro Plus](0x0693)"},
{0x1106, 0x0698, 0xFFFF, 0xFFFF, "VT82C693A [Apollo Pro133 AGP](0x0698)"},
{0x1106, 0x0709, 0xFFFF, 0xFFFF, "VX11 Standard Host Bridge(0x0709)"},
{0x1106, 0x070A, 0xFFFF, 0xFFFF, "VX11 PCI Express Root Port(0x070A)"},
{0x1106, 0x070B, 0xFFFF, 0xFFFF, "VX11 PCI Express Root Port(0x070B)"},
{0x1106, 0x070C, 0xFFFF, 0xFFFF, "VX11 PCI Express Root Port(0x070C)"},
{0x1106, 0x070D, 0xFFFF, 0xFFFF, "VX11 PCI Express Root Port(0x070D)"},
{0x1106, 0x070E, 0xFFFF, 0xFFFF, "VX11 PCI Express Root Port(0x070E)"},
{0x1106, 0x0926, 0xFFFF, 0xFFFF, "VT82C926 [Amazon](0x0926)"},
{0x1106, 0x1000, 0xFFFF, 0xFFFF, "VT82C570MV(0x1000)"},
{0x1106, 0x1106, 0xFFFF, 0xFFFF, "VT82C570MV(0x1106)"},
{0x1106, 0x1122, 0xFFFF, 0xFFFF, "VX800/VX820 Chrome 9 HC3 Integrated Graphics(0x1122)"},
{0x1106, 0x1204, 0xFFFF, 0xFFFF, "K8M800 Host Bridge(0x1204)"},
{0x1106, 0x1208, 0xFFFF, 0xFFFF, "PT890 Host Bridge(0x1208)"},
{0x1106, 0x1238, 0xFFFF, 0xFFFF, "K8T890 Host Bridge(0x1238)"},
{0x1106, 0x1258, 0xFFFF, 0xFFFF, "PT880 Host Bridge(0x1258)"},
{0x1106, 0x1259, 0xFFFF, 0xFFFF, "CN333/CN400/PM880 Host Bridge(0x1259)"},
{0x1106, 0x1269, 0xFFFF, 0xFFFF, "KT880 Host Bridge(0x1269)"},
{0x1106, 0x1282, 0xFFFF, 0xFFFF, "K8T800Pro Host Bridge(0x1282)"},
{0x1106, 0x1290, 0xFFFF, 0xFFFF, "K8M890 Host Bridge(0x1290)"},
{0x1106, 0x1293, 0xFFFF, 0xFFFF, "PM896 Host Bridge(0x1293)"},
{0x1106, 0x1296, 0xFFFF, 0xFFFF, "P4M800 Host Bridge(0x1296)"},
{0x1106, 0x1308, 0xFFFF, 0xFFFF, "PT894 Host Bridge(0x1308)"},
{0x1106, 0x1314, 0xFFFF, 0xFFFF, "CN700/VN800/P4M800CE/Pro Host Bridge(0x1314)"},
{0x1106, 0x1324, 0xFFFF, 0xFFFF, "CX700/VX700-Series Error Reporting(0x1324)"},
{0x1106, 0x1327, 0xFFFF, 0xFFFF, "P4M890 Host Bridge(0x1327)"},
{0x1106, 0x1336, 0xFFFF, 0xFFFF, "K8M890CE Host Bridge(0x1336)"},
{0x1106, 0x1340, 0xFFFF, 0xFFFF, "PT900 Host Bridge(0x1340)"},
{0x1106, 0x1351, 0xFFFF, 0xFFFF, "VT3351 Host Bridge(0x1351)"},
{0x1106, 0x1353, 0xFFFF, 0xFFFF, "VX800/VX820 Error Reporting(0x1353)"},
{0x1106, 0x1364, 0xFFFF, 0xFFFF, "CN896/VN896/P4M900 Host Bridge(0x1364)"},
{0x1106, 0x1409, 0xFFFF, 0xFFFF, "VX855/VX875 Error Reporting(0x1409)"},
{0x1106, 0x1410, 0xFFFF, 0xFFFF, "VX900 Series Error Reporting(0x1410)"},
{0x1106, 0x1571, 0xFFFF, 0xFFFF, "VT82C576M/VT82C586(0x1571)"},
{0x1106, 0x1595, 0xFFFF, 0xFFFF, "VT82C595/97 [Apollo VP2/97](0x1595)"},
{0x1106, 0x1732, 0xFFFF, 0xFFFF, "VT1732 [Envy24 II] PCI Multi-Channel Audio Controller(0x1732)"},
{0x1106, 0x2106, 0xFFFF, 0xFFFF, "VIA Rhine Family Fast Ethernet Adapter (VT6105)(0x2106)"},
{0x1106, 0x2204, 0xFFFF, 0xFFFF, "K8M800 Host Bridge(0x2204)"},
{0x1106, 0x2208, 0xFFFF, 0xFFFF, "PT890 Host Bridge(0x2208)"},
{0x1106, 0x2238, 0xFFFF, 0xFFFF, "K8T890 Host Bridge(0x2238)"},
{0x1106, 0x2258, 0xFFFF, 0xFFFF, "PT880 Host Bridge(0x2258)"},
{0x1106, 0x2259, 0xFFFF, 0xFFFF, "CN333/CN400/PM880 CPU Host Bridge(0x2259)"},
{0x1106, 0x2269, 0xFFFF, 0xFFFF, "KT880 Host Bridge(0x2269)"},
{0x1106, 0x2282, 0xFFFF, 0xFFFF, "K8T800Pro Host Bridge(0x2282)"},
{0x1106, 0x2290, 0xFFFF, 0xFFFF, "K8M890 Host Bridge(0x2290)"},
{0x1106, 0x2293, 0xFFFF, 0xFFFF, "PM896 Host Bridge(0x2293)"},
{0x1106, 0x2296, 0xFFFF, 0xFFFF, "P4M800 Host Bridge(0x2296)"},
{0x1106, 0x2308, 0xFFFF, 0xFFFF, "PT894 Host Bridge(0x2308)"},
{0x1106, 0x2314, 0xFFFF, 0xFFFF, "CN700/VN800/P4M800CE/Pro Host Bridge(0x2314)"},
{0x1106, 0x2324, 0xFFFF, 0xFFFF, "CX700/VX700-Series Host Interface Control(0x2324)"},
{0x1106, 0x2327, 0xFFFF, 0xFFFF, "P4M890 Host Bridge(0x2327)"},
{0x1106, 0x2336, 0xFFFF, 0xFFFF, "K8M890CE Host Bridge(0x2336)"},
{0x1106, 0x2340, 0xFFFF, 0xFFFF, "PT900 Host Bridge(0x2340)"},
{0x1106, 0x2351, 0xFFFF, 0xFFFF, "VT3351 Host Bridge(0x2351)"},
{0x1106, 0x2353, 0xFFFF, 0xFFFF, "VX800/VX820 Host Bus Control(0x2353)"},
{0x1106, 0x2364, 0xFFFF, 0xFFFF, "CN896/VN896/P4M900 Host Bridge(0x2364)"},
{0x1106, 0x2409, 0xFFFF, 0xFFFF, "VX855/VX875 Host Bus Control(0x2409)"},
{0x1106, 0x2410, 0xFFFF, 0xFFFF, "VX900 Series CPU Bus Controller(0x2410)"},
{0x1106, 0x287A, 0xFFFF, 0xFFFF, "VT8251 PCI to PCI Bridge(0x287A)"},
{0x1106, 0x287B, 0xFFFF, 0xFFFF, "VT8251 Host Bridge(0x287B)"},
{0x1106, 0x287C, 0xFFFF, 0xFFFF, "VT8251 PCIE Root Port(0x287C)"},
{0x1106, 0x287D, 0xFFFF, 0xFFFF, "VT8251 PCIE Root Port(0x287D)"},
{0x1106, 0x287E, 0xFFFF, 0xFFFF, "VT8237/8251 Ultra VLINK Controller(0x287E)"},
{0x1106, 0x3022, 0xFFFF, 0xFFFF, "CLE266(0x3022)"},
{0x1106, 0x3038, 0xFFFF, 0xFFFF, "VT82xx/62xx/VX700/8x0/900 UHCI USB 1.1 Controller(0x3038)"},
{0x1106, 0x3038, 0x0925, 0x1234, "onboard UHCI USB 1.1 Controller(0x0925-0x1234)"},
{0x1106, 0x3038, 0x1019, 0x0985, "P6VXA Motherboard(0x1019-0x0985)"},
{0x1106, 0x3038, 0x1019, 0x0A81, "L7VTA v1.0 Motherboard (KT400-8235)(0x1019-0x0A81)"},
{0x1106, 0x3038, 0x1043, 0x8080, "A7V333 motherboard(0x1043-0x8080)"},
{0x1106, 0x3038, 0x1043, 0x808C, "VT62xx USB1.1 4 port controller(0x1043-0x808C)"},
{0x1106, 0x3038, 0x1043, 0x80A1, "A7V8X-X motherboard(0x1043-0x80A1)"},
{0x1106, 0x3038, 0x1043, 0x80ED, "A7V600/K8V-X/A8V Deluxe motherboard(0x1043-0x80ED)"},
{0x1106, 0x3038, 0x1106, 0x3038, "USB 1.1 UHCI controller(0x1106-0x3038)"},
{0x1106, 0x3038, 0x1179, 0x0001, "Magnia Z310(0x1179-0x0001)"},
{0x1106, 0x3038, 0x1234, 0x0925, "MVP3 USB Controller(0x1234-0x0925)"},
{0x1106, 0x3038, 0x1458, 0x5004, "GA-7VAX Mainboard(0x1458-0x5004)"},
{0x1106, 0x3038, 0x1462, 0x5901, "KT6 Delta-FIS2R (MS-6590)(0x1462-0x5901)"},
{0x1106, 0x3038, 0x1462, 0x7020, "K8T NEO 2 motherboard(0x1462-0x7020)"},
{0x1106, 0x3038, 0x1462, 0x7094, "K8T Neo2-F V2.0(0x1462-0x7094)"},
{0x1106, 0x3038, 0x1462, 0x7120, "KT4AV motherboard(0x1462-0x7120)"},
{0x1106, 0x3038, 0x1462, 0x7181, "K8MM3-V mainboard(0x1462-0x7181)"},
{0x1106, 0x3038, 0x147B, 0x1407, "KV8-MAX3 motherboard(0x147B-0x1407)"},
{0x1106, 0x3038, 0x182D, 0x201D, "CN-029 USB2.0 4 port PCI Card(0x182D-0x201D)"},
{0x1106, 0x3038, 0x1849, 0x3038, "K7VT series Motherboards(0x1849-0x3038)"},
{0x1106, 0x3038, 0x19DA, 0xA179, "ZBOX nano VD01(0x19DA-0xA179)"},
{0x1106, 0x3038, 0x1AF4, 0x1100, "QEMU Virtual Machine(0x1AF4-0x1100)"},
{0x1106, 0x3040, 0xFFFF, 0xFFFF, "VT82C586B ACPI(0x3040)"},
{0x1106, 0x3043, 0xFFFF, 0xFFFF, "VT86C100A [Rhine](0x3043)"},
{0x1106, 0x3043, 0x10BD, 0x0000, "VT86C100A Fast Ethernet Adapter(0x10BD-0x0000)"},
{0x1106, 0x3043, 0x1106, 0x0100, "VT86C100A Fast Ethernet Adapter(0x1106-0x0100)"},
{0x1106, 0x3043, 0x1186, 0x1400, "DFE-530TX PCI Fast Ethernet Adapter (rev. A)(0x1186-0x1400)"},
{0x1106, 0x3044, 0xFFFF, 0xFFFF, "VT6306/7/8 [Fire II(M)] IEEE 1394 OHCI Controller(0x3044)"},
{0x1106, 0x3044, 0x0010, 0x0001, "IEEE 1394 4port DCST 1394-3+1B(0x0010-0x0001)"},
{0x1106, 0x3044, 0x1025, 0x005A, "TravelMate 290(0x1025-0x005A)"},
{0x1106, 0x3044, 0x103C, 0x2A20, "Pavilion t3030.de Desktop PC(0x103C-0x2A20)"},
{0x1106, 0x3044, 0x103C, 0x2A3B, "Media Center PC m7590n(0x103C-0x2A3B)"},
{0x1106, 0x3044, 0x1043, 0x808A, "A8V/A8N/P4P800/P5SD2 series motherboard(0x1043-0x808A)"},
{0x1106, 0x3044, 0x1043, 0x81FE, "Motherboard(0x1043-0x81FE)"},
{0x1106, 0x3044, 0x1458, 0x1000, "GA-7VT600-1394 Motherboard(0x1458-0x1000)"},
{0x1106, 0x3044, 0x1462, 0x207D, "K8NGM2 series motherboard(0x1462-0x207D)"},
{0x1106, 0x3044, 0x1462, 0x217D, "Aspire L250(0x1462-0x217D)"},
{0x1106, 0x3044, 0x1462, 0x590D, "KT6 Delta-FIS2R (MS-6590)(0x1462-0x590D)"},
{0x1106, 0x3044, 0x1462, 0x702D, "K8T NEO 2 motherboard(0x1462-0x702D)"},
{0x1106, 0x3044, 0x1462, 0x971D, "MS-6917(0x1462-0x971D)"},
{0x1106, 0x3044, 0x153B, 0x1146, "Cameo DV Firewire controller(0x153B-0x1146)"},
{0x1106, 0x3050, 0xFFFF, 0xFFFF, "VT82C596 Power Management(0x3050)"},
{0x1106, 0x3051, 0xFFFF, 0xFFFF, "VT82C596 Power Management(0x3051)"},
{0x1106, 0x3053, 0xFFFF, 0xFFFF, "VT6105M [Rhine-III](0x3053)"},
{0x1106, 0x3053, 0x1186, 0x1404, "DFE-530TX PCI Fast Ethernet Adapter (rev. D)(0x1186-0x1404)"},
{0x1106, 0x3057, 0xFFFF, 0xFFFF, "VT82C686 [Apollo Super ACPI](0x3057)"},
{0x1106, 0x3057, 0x1019, 0x0985, "P6VXA Motherboard(0x1019-0x0985)"},
{0x1106, 0x3057, 0x1019, 0x0987, "K7VZA Motherboard(0x1019-0x0987)"},
{0x1106, 0x3057, 0x1043, 0x8033, "A7V Mainboard(0x1043-0x8033)"},
{0x1106, 0x3057, 0x1043, 0x803E, "A7V-E Mainboard(0x1043-0x803E)"},
{0x1106, 0x3057, 0x1043, 0x8040, "A7M266 Mainboard(0x1043-0x8040)"},
{0x1106, 0x3057, 0x1043, 0x8042, "A7V133/A7V133-C Mainboard(0x1043-0x8042)"},
{0x1106, 0x3057, 0x1179, 0x0001, "Magnia Z310(0x1179-0x0001)"},
{0x1106, 0x3058, 0xFFFF, 0xFFFF, "VT82C686 AC97 Audio Controller(0x3058)"},
{0x1106, 0x3058, 0x0E11, 0x0097, "SoundMax Digital Integrated Audio(0x0E11-0x0097)"},
{0x1106, 0x3058, 0x0E11, 0xB194, "Soundmax integrated digital audio(0x0E11-0xB194)"},
{0x1106, 0x3058, 0x1019, 0x0985, "P6VXA Motherboard(0x1019-0x0985)"},
{0x1106, 0x3058, 0x1019, 0x0987, "K7VZA Motherboard(0x1019-0x0987)"},
{0x1106, 0x3058, 0x103C, 0x1251, "D9840-60001 [Brio BA410 Motherboard](0x103C-0x1251)"},
{0x1106, 0x3058, 0x1043, 0x1106, "A7V133/A7V133-C Mainboard(0x1043-0x1106)"},
{0x1106, 0x3058, 0x1106, 0x4511, "Onboard Audio on EP7KXA(0x1106-0x4511)"},
{0x1106, 0x3058, 0x1106, 0xAA03, "VT1612A AC'97 Audio Controller(0x1106-0xAA03)"},
{0x1106, 0x3058, 0x11D4, 0x5348, "AD1881A audio(0x11D4-0x5348)"},
{0x1106, 0x3058, 0x1458, 0x7600, "Onboard Audio(0x1458-0x7600)"},
{0x1106, 0x3058, 0x1462, 0x3091, "MS-6309 Onboard Audio(0x1462-0x3091)"},
{0x1106, 0x3058, 0x1462, 0x3092, "MS-6309 v2.x Mainboard (VIA VT1611A codec)(0x1462-0x3092)"},
{0x1106, 0x3058, 0x1462, 0x3300, "MS-6330 Onboard Audio(0x1462-0x3300)"},
{0x1106, 0x3058, 0x1462, 0x3400, "MS-6340 (VT8363) motherboard(0x1462-0x3400)"},
{0x1106, 0x3058, 0x15DD, 0x7609, "Onboard Audio(0x15DD-0x7609)"},
{0x1106, 0x3059, 0xFFFF, 0xFFFF, "VT8233/A/8235/8237 AC97 Audio Controller(0x3059)"},
{0x1106, 0x3059, 0x1019, 0x0A81, "L7VTA v1.0 Motherboard (KT400-8235)(0x1019-0x0A81)"},
{0x1106, 0x3059, 0x1019, 0x1841, "M811 (VT8367/VT8235/VT6103) [KT333] motherboard(0x1019-0x1841)"},
{0x1106, 0x3059, 0x1019, 0x1877, "K8M800-M2 (V2.0) onboard audio(0x1019-0x1877)"},
{0x1106, 0x3059, 0x1043, 0x8095, "A7V8X Motherboard (Realtek ALC650 codec)(0x1043-0x8095)"},
{0x1106, 0x3059, 0x1043, 0x80A1, "A7V8X-X Motherboard(0x1043-0x80A1)"},
{0x1106, 0x3059, 0x1043, 0x80B0, "A7V600/K8V-X/K8V Deluxe motherboard (ADI AD1980 codec [SoundMAX])(0x1043-0x80B0)"},
{0x1106, 0x3059, 0x1043, 0x80F3, "SK8V motherboard(0x1043-0x80F3)"},
{0x1106, 0x3059, 0x1043, 0x810D, "P5VD1-X (AD1888 codec [SoundMax])(0x1043-0x810D)"},
{0x1106, 0x3059, 0x1043, 0x812A, "A8V Deluxe motherboard (Realtek ALC850 codec)(0x1043-0x812A)"},
{0x1106, 0x3059, 0x10EC, 0x8168, "High Definition Audio(0x10EC-0x8168)"},
{0x1106, 0x3059, 0x1106, 0x3059, "L7VMM2 Motherboard(0x1106-0x3059)"},
{0x1106, 0x3059, 0x1106, 0x4161, "K7VT2 motherboard(0x1106-0x4161)"},
{0x1106, 0x3059, 0x1106, 0x4170, "PCPartner P4M800-8237R Motherboard(0x1106-0x4170)"},
{0x1106, 0x3059, 0x1106, 0x4552, "Soyo KT-600 Dragon Plus (Realtek ALC 650)(0x1106-0x4552)"},
{0x1106, 0x3059, 0x1297, 0xC160, "FX41 motherboard (Realtek ALC650 codec)(0x1297-0xC160)"},
{0x1106, 0x3059, 0x1413, 0x147B, "KV8 Pro motherboard onboard audio(0x1413-0x147B)"},
{0x1106, 0x3059, 0x1458, 0xA002, "GA-7VAX Onboard Audio (Realtek ALC650)(0x1458-0xA002)"},
{0x1106, 0x3059, 0x1462, 0x0080, "K8T NEO 2 motherboard(0x1462-0x0080)"},
{0x1106, 0x3059, 0x1462, 0x3800, "KT266 onboard audio(0x1462-0x3800)"},
{0x1106, 0x3059, 0x1462, 0x5901, "KT6 Delta-FIS2R (MS-6590)(0x1462-0x5901)"},
{0x1106, 0x3059, 0x1462, 0x7181, "K8MM3-V mainboard(0x1462-0x7181)"},
{0x1106, 0x3059, 0x147B, 0x1407, "KV8-MAX3 motherboard(0x147B-0x1407)"},
{0x1106, 0x3059, 0x1695, 0x300C, "Realtek ALC655 audio on EP-8KRA series mainboard(0x1695-0x300C)"},
{0x1106, 0x3059, 0x16F3, 0x4170, "J7F2 motherboard(0x16F3-0x4170)"},
{0x1106, 0x3059, 0x1734, 0x1078, "Amilo L7300T notebook(0x1734-0x1078)"},
{0x1106, 0x3059, 0x1849, 0x0850, "ASRock 775Dual-880 Pro onboard audio (Realtek ALC850)(0x1849-0x0850)"},
{0x1106, 0x3059, 0x1849, 0x9739, "P4VT8 Mainboard (C-Media CMI9739A codec)(0x1849-0x9739)"},
{0x1106, 0x3059, 0x1849, 0x9761, "K7VT series Motherboards(0x1849-0x9761)"},
{0x1106, 0x3059, 0x4005, 0x4710, "MSI K7T266 Pro2-RU (MSI-6380 v2) onboard audio (Realtek/ALC 200/200P)(0x4005-0x4710)"},
{0x1106, 0x3059, 0xA0A0, 0x01B6, "AK77-8XN onboard audio(0xA0A0-0x01B6)"},
{0x1106, 0x3059, 0xA0A0, 0x0342, "AK86-L motherboard(0xA0A0-0x0342)"},
{0x1106, 0x3065, 0xFFFF, 0xFFFF, "VT6102/VT6103 [Rhine-II](0x3065)"},
{0x1106, 0x3065, 0x1043, 0x80A1, "A7V8X-X Motherboard(0x1043-0x80A1)"},
{0x1106, 0x3065, 0x1043, 0x80ED, "A7V600-X Motherboard(0x1043-0x80ED)"},
{0x1106, 0x3065, 0x1106, 0x0102, "VT6102/6103 [Rhine II] Ethernet Controller(0x1106-0x0102)"},
{0x1106, 0x3065, 0x1186, 0x1400, "DFE-530TX PCI Fast Ethernet Adapter (rev. A)(0x1186-0x1400)"},
{0x1106, 0x3065, 0x1186, 0x1401, "DFE-530TX PCI Fast Ethernet Adapter (rev. B)(0x1186-0x1401)"},
{0x1106, 0x3065, 0x1186, 0x1402, "DFE-530TX PCI Fast Ethernet Adapter (rev. B)(0x1186-0x1402)"},
{0x1106, 0x3065, 0x13B9, 0x1421, "LD-10/100AL PCI Fast Ethernet Adapter (rev.B)(0x13B9-0x1421)"},
{0x1106, 0x3065, 0x1462, 0x7061, "MS-7061(0x1462-0x7061)"},
{0x1106, 0x3065, 0x1462, 0x7181, "K8MM3-V mainboard(0x1462-0x7181)"},
{0x1106, 0x3065, 0x147B, 0x1C09, "NV7 Motherboard(0x147B-0x1C09)"},
{0x1106, 0x3065, 0x1695, 0x3005, "VT6103(0x1695-0x3005)"},
{0x1106, 0x3065, 0x1849, 0x3065, "K7VT series Motherboards(0x1849-0x3065)"},
{0x1106, 0x3068, 0xFFFF, 0xFFFF, "AC'97 Modem Controller(0x3068)"},
{0x1106, 0x3068, 0x1462, 0x309E, "MS-6309 Saturn Motherboard(0x1462-0x309E)"},
{0x1106, 0x3074, 0xFFFF, 0xFFFF, "VT8233 PCI to ISA Bridge(0x3074)"},
{0x1106, 0x3074, 0x1043, 0x8052, "VT8233A(0x1043-0x8052)"},
{0x1106, 0x3091, 0xFFFF, 0xFFFF, "VT8633 [Apollo Pro266](0x3091)"},
{0x1106, 0x3099, 0xFFFF, 0xFFFF, "VT8366/A/7 [Apollo KT266/A/333](0x3099)"},
{0x1106, 0x3099, 0x1019, 0x1841, "M811 (VT8367/VT8235/VT6103) [KT333] motherboard(0x1019-0x1841)"},
{0x1106, 0x3099, 0x1043, 0x8064, "A7V266-E Mainboard(0x1043-0x8064)"},
{0x1106, 0x3099, 0x1043, 0x807F, "A7V333 Mainboard(0x1043-0x807F)"},
{0x1106, 0x3099, 0x1849, 0x3099, "K7VT2 motherboard(0x1849-0x3099)"},
{0x1106, 0x3101, 0xFFFF, 0xFFFF, "VT8653 Host Bridge(0x3101)"},
{0x1106, 0x3102, 0xFFFF, 0xFFFF, "VT8662 Host Bridge(0x3102)"},
{0x1106, 0x3103, 0xFFFF, 0xFFFF, "VT8615 Host Bridge(0x3103)"},
{0x1106, 0x3104, 0xFFFF, 0xFFFF, "USB 2.0 EHCI-Compliant Host-Controller(0x3104)"},
{0x1106, 0x3104, 0x0925, 0x1234, "onboard EHCI USB 2.0 Controller(0x0925-0x1234)"},
{0x1106, 0x3104, 0x1019, 0x0A81, "L7VTA v1.0 Motherboard (KT400-8235)(0x1019-0x0A81)"},
{0x1106, 0x3104, 0x1043, 0x808C, "A7V8X motherboard(0x1043-0x808C)"},
{0x1106, 0x3104, 0x1043, 0x80A1, "A7V8X-X motherboard rev 1.01(0x1043-0x80A1)"},
{0x1106, 0x3104, 0x1043, 0x80ED, "A7V600/K8V-X/A8V Deluxe motherboard(0x1043-0x80ED)"},
{0x1106, 0x3104, 0x1106, 0x3104, "USB 2.0 EHCI controller(0x1106-0x3104)"},
{0x1106, 0x3104, 0x1297, 0xF641, "FX41 motherboard(0x1297-0xF641)"},
{0x1106, 0x3104, 0x1458, 0x5004, "GA-7VAX Mainboard(0x1458-0x5004)"},
{0x1106, 0x3104, 0x1462, 0x5901, "KT6 Delta-FIS2R (MS-6590)(0x1462-0x5901)"},
{0x1106, 0x3104, 0x1462, 0x7020, "K8T NEO 2 motherboard(0x1462-0x7020)"},
{0x1106, 0x3104, 0x1462, 0x7094, "K8T Neo2-F V2.0(0x1462-0x7094)"},
{0x1106, 0x3104, 0x1462, 0x7120, "KT4AV motherboard(0x1462-0x7120)"},
{0x1106, 0x3104, 0x1462, 0x7181, "K8MM3-V mainboard(0x1462-0x7181)"},
{0x1106, 0x3104, 0x147B, 0x1407, "KV8-MAX3 motherboard(0x147B-0x1407)"},
{0x1106, 0x3104, 0x182D, 0x201D, "CN-029 USB 2.0 4 port PCI Card(0x182D-0x201D)"},
{0x1106, 0x3104, 0x1849, 0x3104, "K7VT series Motherboards(0x1849-0x3104)"},
{0x1106, 0x3104, 0x19DA, 0xA179, "ZBOX nano VD01(0x19DA-0xA179)"},
{0x1106, 0x3106, 0xFFFF, 0xFFFF, "VT6105/VT6106S [Rhine-III](0x3106)"},
{0x1106, 0x3106, 0x1106, 0x0105, "VT6106S [Rhine-III](0x1106-0x0105)"},
{0x1106, 0x3106, 0x1186, 0x1403, "DFE-530TX PCI Fast Ethernet Adapter (rev. C)(0x1186-0x1403)"},
{0x1106, 0x3106, 0x1186, 0x1405, "DFE-520TX Fast Ethernet PCI Adapter(0x1186-0x1405)"},
{0x1106, 0x3106, 0x1186, 0x1406, "DFE-530TX+ rev F2(0x1186-0x1406)"},
{0x1106, 0x3106, 0x1186, 0x1407, "DFE-538TX(0x1186-0x1407)"},
{0x1106, 0x3108, 0xFFFF, 0xFFFF, "K8M800/K8N800/K8N800A [S3 UniChrome Pro](0x3108)"},
{0x1106, 0x3109, 0xFFFF, 0xFFFF, "VT8233C PCI to ISA Bridge(0x3109)"},
{0x1106, 0x3112, 0xFFFF, 0xFFFF, "VT8361 [KLE133] Host Bridge(0x3112)"},
{0x1106, 0x3113, 0xFFFF, 0xFFFF, "VPX/VPX2 PCI to PCI Bridge Controller(0x3113)"},
{0x1106, 0x3116, 0xFFFF, 0xFFFF, "VT8375 [KM266/KL266] Host Bridge(0x3116)"},
{0x1106, 0x3116, 0x1297, 0xF641, "FX41 motherboard(0x1297-0xF641)"},
{0x1106, 0x3118, 0xFFFF, 0xFFFF, "CN400/PM800/PM880/PN800/PN880 [S3 UniChrome Pro](0x3118)"},
{0x1106, 0x3119, 0xFFFF, 0xFFFF, "VT6120/VT6121/VT6122 Gigabit Ethernet Adapter(0x3119)"},
{0x1106, 0x3122, 0xFFFF, 0xFFFF, "VT8623 [Apollo CLE266] integrated CastleRock graphics(0x3122)"},
{0x1106, 0x3123, 0xFFFF, 0xFFFF, "VT8623 [Apollo CLE266](0x3123)"},
{0x1106, 0x3128, 0xFFFF, 0xFFFF, "VT8753 [P4X266 AGP](0x3128)"},
{0x1106, 0x3133, 0xFFFF, 0xFFFF, "VT3133 Host Bridge(0x3133)"},
{0x1106, 0x3142, 0xFFFF, 0xFFFF, "VT6651 WiFi Adapter, 802.11b(0x3142)"},
{0x1106, 0x3147, 0xFFFF, 0xFFFF, "VT8233A ISA Bridge(0x3147)"},
{0x1106, 0x3147, 0x1043, 0x808C, "A7V333 motherboard(0x1043-0x808C)"},
{0x1106, 0x3148, 0xFFFF, 0xFFFF, "P4M266 Host Bridge(0x3148)"},
{0x1106, 0x3149, 0xFFFF, 0xFFFF, "VIA VT6420 SATA RAID Controller(0x3149)"},
{0x1106, 0x3149, 0x1043, 0x80ED, "A7V600/K8V Deluxe/K8V-X/A8V Deluxe motherboard(0x1043-0x80ED)"},
{0x1106, 0x3149, 0x1458, 0xB003, "GA-7VM400AM(F) Motherboard(0x1458-0xB003)"},
{0x1106, 0x3149, 0x1462, 0x5901, "KT6 Delta-FIS2R (MS-6590)(0x1462-0x5901)"},
{0x1106, 0x3149, 0x1462, 0x7020, "K8T Neo 2 Motherboard(0x1462-0x7020)"},
{0x1106, 0x3149, 0x1462, 0x7094, "K8T Neo2-F V2.0(0x1462-0x7094)"},
{0x1106, 0x3149, 0x1462, 0x7181, "K8MM3-V mainboard(0x1462-0x7181)"},
{0x1106, 0x3149, 0x147B, 0x1407, "KV8-MAX3 motherboard(0x147B-0x1407)"},
{0x1106, 0x3149, 0x147B, 0x1408, "KV7(0x147B-0x1408)"},
{0x1106, 0x3149, 0x1849, 0x3149, "K7VT6 motherboard(0x1849-0x3149)"},
{0x1106, 0x3149, 0xA0A0, 0x04AD, "AK86-L motherboard(0xA0A0-0x04AD)"},
{0x1106, 0x3156, 0xFFFF, 0xFFFF, "P/KN266 Host Bridge(0x3156)"},
{0x1106, 0x3157, 0xFFFF, 0xFFFF, "CX700/VX700 [S3 UniChrome Pro](0x3157)"},
{0x1106, 0x3164, 0xFFFF, 0xFFFF, "VT6410 ATA133 RAID controller(0x3164)"},
{0x1106, 0x3164, 0x1043, 0x80F4, "P4P800 Mainboard Deluxe ATX(0x1043-0x80F4)"},
{0x1106, 0x3164, 0x1462, 0x7028, "915P/G Neo2(0x1462-0x7028)"},
{0x1106, 0x3168, 0xFFFF, 0xFFFF, "P4X333/P4X400/PT800 AGP Bridge(0x3168)"},
{0x1106, 0x3168, 0x1849, 0x3168, "P4VT8 Mainboard(0x1849-0x3168)"},
{0x1106, 0x3177, 0xFFFF, 0xFFFF, "VT8235 ISA Bridge(0x3177)"},
{0x1106, 0x3177, 0x1019, 0x0A81, "L7VTA v1.0 Motherboard (KT400-8235)(0x1019-0x0A81)"},
{0x1106, 0x3177, 0x1019, 0x1841, "M811 (VT8367/VT8235/VT6103) [KT333] motherboard(0x1019-0x1841)"},
{0x1106, 0x3177, 0x1043, 0x808C, "A7V8X motherboard(0x1043-0x808C)"},
{0x1106, 0x3177, 0x1043, 0x80A1, "A7V8X-X motherboard(0x1043-0x80A1)"},
{0x1106, 0x3177, 0x1106, 0x0000, "KT4AV motherboard(0x1106-0x0000)"},
{0x1106, 0x3177, 0x1297, 0xF641, "FX41 motherboard(0x1297-0xF641)"},
{0x1106, 0x3177, 0x1458, 0x5001, "GA-7VAX Mainboard(0x1458-0x5001)"},
{0x1106, 0x3177, 0x1849, 0x3177, "K7VT series Motherboards(0x1849-0x3177)"},
{0x1106, 0x3178, 0xFFFF, 0xFFFF, "ProSavageDDR P4N333 Host Bridge(0x3178)"},
{0x1106, 0x3188, 0xFFFF, 0xFFFF, "VT8385 [K8T800 AGP] Host Bridge(0x3188)"},
{0x1106, 0x3188, 0x1043, 0x80A3, "K8V Deluxe/K8V-X motherboard(0x1043-0x80A3)"},
{0x1106, 0x3188, 0x147B, 0x1407, "KV8-MAX3 motherboard(0x147B-0x1407)"},
{0x1106, 0x3189, 0xFFFF, 0xFFFF, "VT8377 [KT400/KT600 AGP] Host Bridge(0x3189)"},
{0x1106, 0x3189, 0x1043, 0x807F, "A7V8X motherboard(0x1043-0x807F)"},
{0x1106, 0x3189, 0x1106, 0x0000, "KT4AV motherboard (KT400A)(0x1106-0x0000)"},
{0x1106, 0x3189, 0x1458, 0x5000, "GA-7VAX Mainboard(0x1458-0x5000)"},
{0x1106, 0x3189, 0x1849, 0x3189, "K7VT series Motherboards(0x1849-0x3189)"},
{0x1106, 0x31B0, 0xFFFF, 0xFFFF, "VX11 Standard Host Bridge(0x31B0)"},
{0x1106, 0x31B1, 0xFFFF, 0xFFFF, "VX11 Standard Host Bridge(0x31B1)"},
{0x1106, 0x31B2, 0xFFFF, 0xFFFF, "VX11 DRAM Controller(0x31B2)"},
{0x1106, 0x31B3, 0xFFFF, 0xFFFF, "VX11 Power Management Controller(0x31B3)"},
{0x1106, 0x31B4, 0xFFFF, 0xFFFF, "VX11 I/O APIC(0x31B4)"},
{0x1106, 0x31B5, 0xFFFF, 0xFFFF, "VX11 Scratch Device(0x31B5)"},
{0x1106, 0x31B7, 0xFFFF, 0xFFFF, "VX11 Standard Host Bridge(0x31B7)"},
{0x1106, 0x31B8, 0xFFFF, 0xFFFF, "VX11 PCI to PCI Bridge(0x31B8)"},
{0x1106, 0x3204, 0xFFFF, 0xFFFF, "K8M800 Host Bridge(0x3204)"},
{0x1106, 0x3205, 0xFFFF, 0xFFFF, "VT8378 [KM400/A] Chipset Host Bridge(0x3205)"},
{0x1106, 0x3205, 0x1458, 0x5000, "GA-7VM400M Motherboard(0x1458-0x5000)"},
{0x1106, 0x3208, 0xFFFF, 0xFFFF, "PT890 Host Bridge(0x3208)"},
{0x1106, 0x3213, 0xFFFF, 0xFFFF, "VPX/VPX2 PCI to PCI Bridge Controller(0x3213)"},
{0x1106, 0x3218, 0xFFFF, 0xFFFF, "K8T800M Host Bridge(0x3218)"},
{0x1106, 0x3227, 0xFFFF, 0xFFFF, "VT8237 ISA bridge [KT600/K8T800/K8T890/CN700 South](0x3227)"},
{0x1106, 0x3227, 0x1043, 0x80ED, "A7V600/K8V-X/A8V Deluxe motherboard(0x1043-0x80ED)"},
{0x1106, 0x3227, 0x1106, 0x3227, "VT8237 ISA bridge(0x1106-0x3227)"},
{0x1106, 0x3227, 0x1458, 0x5001, "GA-7VT600 Motherboard(0x1458-0x5001)"},
{0x1106, 0x3227, 0x147B, 0x1407, "KV8-MAX3 motherboard(0x147B-0x1407)"},
{0x1106, 0x3227, 0x1849, 0x3227, "K7VT4 motherboard(0x1849-0x3227)"},
{0x1106, 0x3230, 0xFFFF, 0xFFFF, "K8M890CE/K8N890CE [Chrome 9](0x3230)"},
{0x1106, 0x3238, 0xFFFF, 0xFFFF, "K8T890 Host Bridge(0x3238)"},
{0x1106, 0x3249, 0xFFFF, 0xFFFF, "VT6421 IDE/SATA Controller(0x3249)"},
{0x1106, 0x3249, 0x1106, 0x3249, "VT6421 IDE/SATA Controller(0x1106-0x3249)"},
{0x1106, 0x324A, 0xFFFF, 0xFFFF, "CX700/VX700 PCI to PCI Bridge(0x324A)"},
{0x1106, 0x324B, 0xFFFF, 0xFFFF, "CX700/VX700 Host Bridge(0x324B)"},
{0x1106, 0x324E, 0xFFFF, 0xFFFF, "CX700/VX700 Internal Module Bus(0x324E)"},
{0x1106, 0x3253, 0xFFFF, 0xFFFF, "VT6655 WiFi Adapter, 802.11a/b/g(0x3253)"},
{0x1106, 0x3258, 0xFFFF, 0xFFFF, "PT880 Host Bridge(0x3258)"},
{0x1106, 0x3259, 0xFFFF, 0xFFFF, "CN333/CN400/PM880 Host Bridge(0x3259)"},
{0x1106, 0x3260, 0xFFFF, 0xFFFF, "VIA Chrome9 HC IGP(0x3260)"},
{0x1106, 0x3269, 0xFFFF, 0xFFFF, "KT880 Host Bridge(0x3269)"},
{0x1106, 0x3282, 0xFFFF, 0xFFFF, "K8T800Pro Host Bridge(0x3282)"},
{0x1106, 0x3287, 0xFFFF, 0xFFFF, "VT8251 PCI to ISA Bridge(0x3287)"},
{0x1106, 0x3288, 0xFFFF, 0xFFFF, "VX900/VT8xxx High Definition Audio Controller(0x3288)"},
{0x1106, 0x3288, 0x19DA, 0xA179, "ZBOX VD01(0x19DA-0xA179)"},
{0x1106, 0x3290, 0xFFFF, 0xFFFF, "K8M890 Host Bridge(0x3290)"},
{0x1106, 0x3296, 0xFFFF, 0xFFFF, "P4M800 Host Bridge(0x3296)"},
{0x1106, 0x3324, 0xFFFF, 0xFFFF, "CX700/VX700-Series DRAM Bus Control(0x3324)"},
{0x1106, 0x3327, 0xFFFF, 0xFFFF, "P4M890 Host Bridge(0x3327)"},
{0x1106, 0x3336, 0xFFFF, 0xFFFF, "K8M890CE Host Bridge(0x3336)"},
{0x1106, 0x3337, 0xFFFF, 0xFFFF, "VT8237A PCI to ISA Bridge(0x3337)"},
{0x1106, 0x3340, 0xFFFF, 0xFFFF, "PT900 Host Bridge(0x3340)"},
{0x1106, 0x3343, 0xFFFF, 0xFFFF, "P4M890 [S3 UniChrome Pro](0x3343)"},
{0x1106, 0x3344, 0xFFFF, 0xFFFF, "CN700/P4M800 Pro/P4M800 CE/VN800 Graphics [S3 UniChrome Pro](0x3344)"},
{0x1106, 0x3349, 0xFFFF, 0xFFFF, "VT8251 AHCI/SATA 4-Port Controller(0x3349)"},
{0x1106, 0x3351, 0xFFFF, 0xFFFF, "VT3351 Host Bridge(0x3351)"},
{0x1106, 0x3353, 0xFFFF, 0xFFFF, "VX800/820 PCI to PCI Bridge(0x3353)"},
{0x1106, 0x3364, 0xFFFF, 0xFFFF, "CN896/VN896/P4M900 Host Bridge(0x3364)"},
{0x1106, 0x3365, 0xFFFF, 0xFFFF, "VT630x IEEE 1394 Host Controller [Fire II/M](0x3365)"},
{0x1106, 0x3371, 0xFFFF, 0xFFFF, "CN896/VN896/P4M900 [Chrome 9 HC](0x3371)"},
{0x1106, 0x3372, 0xFFFF, 0xFFFF, "VT8237S PCI to ISA Bridge(0x3372)"},
{0x1106, 0x337A, 0xFFFF, 0xFFFF, "VT8237A PCI to PCI Bridge(0x337A)"},
{0x1106, 0x337B, 0xFFFF, 0xFFFF, "VT8237A Host Bridge(0x337B)"},
{0x1106, 0x3403, 0xFFFF, 0xFFFF, "VT6315 Series Firewire Controller(0x3403)"},
{0x1106, 0x3403, 0x1043, 0x8374, "M5A88-V EVO(0x1043-0x8374)"},
{0x1106, 0x3403, 0x1043, 0x8384, "P8P67 Deluxe Motherboard(0x1043-0x8384)"},
{0x1106, 0x3409, 0xFFFF, 0xFFFF, "VX855/VX875 DRAM Bus Control(0x3409)"},
{0x1106, 0x3410, 0xFFFF, 0xFFFF, "VX900 Series DRAM Bus Control(0x3410)"},
{0x1106, 0x3410, 0x19DA, 0xA179, "ZBOX nano VD01(0x19DA-0xA179)"},
{0x1106, 0x3432, 0xFFFF, 0xFFFF, "VL800/801 xHCI USB 3.0 Controller(0x3432)"},
{0x1106, 0x3456, 0xFFFF, 0xFFFF, "VX11 Standard Host Bridge(0x3456)"},
{0x1106, 0x345B, 0xFFFF, 0xFFFF, "VX11 Miscellaneous Bus(0x345B)"},
{0x1106, 0x3483, 0xFFFF, 0xFFFF, "VL805/806 xHCI USB 3.0 Controller(0x3483)"},
{0x1106, 0x3A01, 0xFFFF, 0xFFFF, "VX11 Graphics [Chrome 645/640](0x3A01)"},
{0x1106, 0x4149, 0xFFFF, 0xFFFF, "VIA VT6420 (ATA133) Controller(0x4149)"},
{0x1106, 0x4204, 0xFFFF, 0xFFFF, "K8M800 Host Bridge(0x4204)"},
{0x1106, 0x4208, 0xFFFF, 0xFFFF, "PT890 Host Bridge(0x4208)"},
{0x1106, 0x4238, 0xFFFF, 0xFFFF, "K8T890 Host Bridge(0x4238)"},
{0x1106, 0x4258, 0xFFFF, 0xFFFF, "PT880 Host Bridge(0x4258)"},
{0x1106, 0x4259, 0xFFFF, 0xFFFF, "CN333/CN400/PM880 Host Bridge(0x4259)"},
{0x1106, 0x4269, 0xFFFF, 0xFFFF, "KT880 Host Bridge(0x4269)"},
{0x1106, 0x4282, 0xFFFF, 0xFFFF, "K8T800Pro Host Bridge(0x4282)"},
{0x1106, 0x4290, 0xFFFF, 0xFFFF, "K8M890 Host Bridge(0x4290)"},
{0x1106, 0x4293, 0xFFFF, 0xFFFF, "PM896 Host Bridge(0x4293)"},
{0x1106, 0x4296, 0xFFFF, 0xFFFF, "P4M800 Host Bridge(0x4296)"},
{0x1106, 0x4308, 0xFFFF, 0xFFFF, "PT894 Host Bridge(0x4308)"},
{0x1106, 0x4314, 0xFFFF, 0xFFFF, "CN700/VN800/P4M800CE/Pro Host Bridge(0x4314)"},
{0x1106, 0x4324, 0xFFFF, 0xFFFF, "CX700/VX700-Series Power Management and Testing Control(0x4324)"},
{0x1106, 0x4327, 0xFFFF, 0xFFFF, "P4M890 Host Bridge(0x4327)"},
{0x1106, 0x4336, 0xFFFF, 0xFFFF, "K8M890CE Host Bridge(0x4336)"},
{0x1106, 0x4340, 0xFFFF, 0xFFFF, "PT900 Host Bridge(0x4340)"},
{0x1106, 0x4351, 0xFFFF, 0xFFFF, "VT3351 Host Bridge(0x4351)"},
{0x1106, 0x4353, 0xFFFF, 0xFFFF, "VX800/VX820 Power Management Control(0x4353)"},
{0x1106, 0x4364, 0xFFFF, 0xFFFF, "CN896/VN896/P4M900 Host Bridge(0x4364)"},
{0x1106, 0x4409, 0xFFFF, 0xFFFF, "VX855/VX875 Power Management Control(0x4409)"},
{0x1106, 0x4410, 0xFFFF, 0xFFFF, "VX900 Series Power Management and Chip Testing Control(0x4410)"},
{0x1106, 0x4410, 0x19DA, 0xA179, "ZBOX nano VD01(0x19DA-0xA179)"},
{0x1106, 0x5030, 0xFFFF, 0xFFFF, "VT82C596 ACPI [Apollo PRO](0x5030)"},
{0x1106, 0x5122, 0xFFFF, 0xFFFF, "VX855/VX875 Chrome 9 HCM Integrated Graphics(0x5122)"},
{0x1106, 0x5208, 0xFFFF, 0xFFFF, "PT890 I/O APIC Interrupt Controller(0x5208)"},
{0x1106, 0x5238, 0xFFFF, 0xFFFF, "K8T890 I/O APIC Interrupt Controller(0x5238)"},
{0x1106, 0x5287, 0xFFFF, 0xFFFF, "VT8251 Serial ATA Controller(0x5287)"},
{0x1106, 0x5290, 0xFFFF, 0xFFFF, "K8M890 I/O APIC Interrupt Controller(0x5290)"},
{0x1106, 0x5308, 0xFFFF, 0xFFFF, "PT894 I/O APIC Interrupt Controller(0x5308)"},
{0x1106, 0x5324, 0xFFFF, 0xFFFF, "CX700M2/VX700/VX800/820-Series Serial ATA & EIDE-Controller(0x5324)"},
{0x1106, 0x5327, 0xFFFF, 0xFFFF, "P4M890 I/O APIC Interrupt Controller(0x5327)"},
{0x1106, 0x5336, 0xFFFF, 0xFFFF, "K8M890CE I/O APIC Interrupt Controller(0x5336)"},
{0x1106, 0x5340, 0xFFFF, 0xFFFF, "PT900 I/O APIC Interrupt Controller(0x5340)"},
{0x1106, 0x5351, 0xFFFF, 0xFFFF, "VT3351 I/O APIC Interrupt Controller(0x5351)"},
{0x1106, 0x5353, 0xFFFF, 0xFFFF, "VX800/VX820 APIC and Central Traffic Control(0x5353)"},
{0x1106, 0x5364, 0xFFFF, 0xFFFF, "CN896/VN896/P4M900 I/O APIC Interrupt Controller(0x5364)"},
{0x1106, 0x5372, 0xFFFF, 0xFFFF, "VT8237/8251 Serial ATA Controller(0x5372)"},
{0x1106, 0x5409, 0xFFFF, 0xFFFF, "VX855/VX875 APIC and Central Traffic Control(0x5409)"},
{0x1106, 0x5410, 0xFFFF, 0xFFFF, "VX900 Series APIC and Central Traffic Control(0x5410)"},
{0x1106, 0x6100, 0xFFFF, 0xFFFF, "VT85C100A [Rhine II](0x6100)"},
{0x1106, 0x6122, 0xFFFF, 0xFFFF, "VN1000 Graphics [Chrome 520 IGP](0x6122)"},
{0x1106, 0x6287, 0xFFFF, 0xFFFF, "SATA RAID Controller(0x6287)"},
{0x1106, 0x6290, 0xFFFF, 0xFFFF, "K8M890CE Host Bridge(0x6290)"},
{0x1106, 0x6327, 0xFFFF, 0xFFFF, "P4M890 Security Device(0x6327)"},
{0x1106, 0x6353, 0xFFFF, 0xFFFF, "VX800/VX820 Scratch Registers(0x6353)"},
{0x1106, 0x6364, 0xFFFF, 0xFFFF, "CN896/VN896/P4M900 Security Device(0x6364)"},
{0x1106, 0x6409, 0xFFFF, 0xFFFF, "VX855/VX875 Scratch Registers(0x6409)"},
{0x1106, 0x6410, 0xFFFF, 0xFFFF, "VX900 Series Scratch Registers(0x6410)"},
{0x1106, 0x6410, 0x19DA, 0xA179, "ZBOX nano VD01(0x19DA-0xA179)"},
{0x1106, 0x7122, 0xFFFF, 0xFFFF, "VX900 Graphics [Chrome9 HD](0x7122)"},
{0x1106, 0x7204, 0xFFFF, 0xFFFF, "K8M800 Host Bridge(0x7204)"},
{0x1106, 0x7205, 0xFFFF, 0xFFFF, "KM400/KN400/P4M800 [S3 UniChrome](0x7205)"},
{0x1106, 0x7205, 0x1458, 0xD000, "Gigabyte GA-7VM400(A)M(F) Motherboard(0x1458-0xD000)"},
{0x1106, 0x7205, 0x1462, 0x7061, "MS-7061(0x1462-0x7061)"},
{0x1106, 0x7208, 0xFFFF, 0xFFFF, "PT890 Host Bridge(0x7208)"},
{0x1106, 0x7238, 0xFFFF, 0xFFFF, "K8T890 Host Bridge(0x7238)"},
{0x1106, 0x7258, 0xFFFF, 0xFFFF, "PT880 Host Bridge(0x7258)"},
{0x1106, 0x7259, 0xFFFF, 0xFFFF, "CN333/CN400/PM880 Host Bridge(0x7259)"},
{0x1106, 0x7269, 0xFFFF, 0xFFFF, "KT880 Host Bridge(0x7269)"},
{0x1106, 0x7282, 0xFFFF, 0xFFFF, "K8T800Pro Host Bridge(0x7282)"},
{0x1106, 0x7290, 0xFFFF, 0xFFFF, "K8M890 Host Bridge(0x7290)"},
{0x1106, 0x7293, 0xFFFF, 0xFFFF, "PM896 Host Bridge(0x7293)"},
{0x1106, 0x7296, 0xFFFF, 0xFFFF, "P4M800 Host Bridge(0x7296)"},
{0x1106, 0x7308, 0xFFFF, 0xFFFF, "PT894 Host Bridge(0x7308)"},
{0x1106, 0x7314, 0xFFFF, 0xFFFF, "CN700/VN800/P4M800CE/Pro Host Bridge(0x7314)"},
{0x1106, 0x7324, 0xFFFF, 0xFFFF, "CX700/VX700-Series North-South Module Interface Control(0x7324)"},
{0x1106, 0x7327, 0xFFFF, 0xFFFF, "P4M890 Host Bridge(0x7327)"},
{0x1106, 0x7336, 0xFFFF, 0xFFFF, "K8M890CE Host Bridge(0x7336)"},
{0x1106, 0x7340, 0xFFFF, 0xFFFF, "PT900 Host Bridge(0x7340)"},
{0x1106, 0x7351, 0xFFFF, 0xFFFF, "VT3351 Host Bridge(0x7351)"},
{0x1106, 0x7353, 0xFFFF, 0xFFFF, "VX800/VX820 North-South Module Interface Control(0x7353)"},
{0x1106, 0x7364, 0xFFFF, 0xFFFF, "CN896/VN896/P4M900 Host Bridge(0x7364)"},
{0x1106, 0x7409, 0xFFFF, 0xFFFF, "VX855/VX875 North-South Module Interface Control(0x7409)"},
{0x1106, 0x7410, 0xFFFF, 0xFFFF, "VX900 Series North-South Module Interface Control(0x7410)"},
{0x1106, 0x7410, 0x19DA, 0xA179, "ZBOX nano VD01(0x19DA-0xA179)"},
{0x1106, 0x8231, 0xFFFF, 0xFFFF, "VT8231 [PCI-to-ISA Bridge](0x8231)"},
{0x1106, 0x8235, 0xFFFF, 0xFFFF, "VT8235 ACPI(0x8235)"},
{0x1106, 0x8305, 0xFFFF, 0xFFFF, "VT8363/8365 [KT133/KM133 AGP](0x8305)"},
{0x1106, 0x8324, 0xFFFF, 0xFFFF, "CX700/VX700-Series Bus Control and Power Management(0x8324)"},
{0x1106, 0x8353, 0xFFFF, 0xFFFF, "VX800/VX820 Bus Control and Power Management(0x8353)"},
{0x1106, 0x8391, 0xFFFF, 0xFFFF, "VT8371 [KX133 AGP](0x8391)"},
{0x1106, 0x8400, 0xFFFF, 0xFFFF, "MVP4(0x8400)"},
{0x1106, 0x8409, 0xFFFF, 0xFFFF, "VX855/VX875 Bus Control and Power Management(0x8409)"},
{0x1106, 0x8410, 0xFFFF, 0xFFFF, "VX900 Series Bus Control and Power Management(0x8410)"},
{0x1106, 0x8410, 0x19DA, 0xA179, "ZBOX VD01(0x19DA-0xA179)"},
{0x1106, 0x8500, 0xFFFF, 0xFFFF, "KLE133/PLE133/PLE133T(0x8500)"},
{0x1106, 0x8501, 0xFFFF, 0xFFFF, "VT8501 [Apollo MVP4 AGP](0x8501)"},
{0x1106, 0x8596, 0xFFFF, 0xFFFF, "VT82C596 [Apollo PRO AGP](0x8596)"},
{0x1106, 0x8597, 0xFFFF, 0xFFFF, "VT82C597 [Apollo VP3 AGP](0x8597)"},
{0x1106, 0x8598, 0xFFFF, 0xFFFF, "VT82C598/694x [Apollo MVP3/Pro133x AGP](0x8598)"},
{0x1106, 0x8598, 0x1019, 0x0985, "P6VXA Motherboard(0x1019-0x0985)"},
{0x1106, 0x8601, 0xFFFF, 0xFFFF, "VT8601 [Apollo ProMedia AGP](0x8601)"},
{0x1106, 0x8605, 0xFFFF, 0xFFFF, "VT8605 [PM133 AGP](0x8605)"},
{0x1106, 0x8691, 0xFFFF, 0xFFFF, "VT82C691 [Apollo Pro](0x8691)"},
{0x1106, 0x8693, 0xFFFF, 0xFFFF, "VT82C693 [Apollo Pro Plus] PCI Bridge(0x8693)"},
{0x1106, 0x8A25, 0xFFFF, 0xFFFF, "PL133/PL133T [S3 ProSavage](0x8A25)"},
{0x1106, 0x8A26, 0xFFFF, 0xFFFF, "KL133/KL133A/KM133/KM133A [S3 ProSavage](0x8A26)"},
{0x1106, 0x8D01, 0xFFFF, 0xFFFF, "PN133/PN133T [S3 Twister](0x8D01)"},
{0x1106, 0x8D04, 0xFFFF, 0xFFFF, "KM266/P4M266/P4M266A/P4N266 [S3 ProSavageDDR](0x8D04)"},
{0x1106, 0x9001, 0xFFFF, 0xFFFF, "VX900 Series Serial-ATA Controller(0x9001)"},
{0x1106, 0x9082, 0xFFFF, 0xFFFF, "Standard AHCI 1.0 SATA Controller(0x9082)"},
{0x1106, 0x9140, 0xFFFF, 0xFFFF, "HDMI Audio Device(0x9140)"},
{0x1106, 0x9201, 0xFFFF, 0xFFFF, "USB3.0 Controller(0x9201)"},
{0x1106, 0x9380, 0xFFFF, 0xFFFF, "Ncore Coprocessor for Centaur CNS(0x9380)"},
{0x1106, 0x9530, 0xFFFF, 0xFFFF, "VX800/820/900 Series Secure Digital Memory Card Controller(0x9530)"},
{0x1106, 0x95D0, 0xFFFF, 0xFFFF, "VX800/820/900 Series SDIO Host Controller(0x95D0)"},
{0x1106, 0xA208, 0xFFFF, 0xFFFF, "PT890 PCI to PCI Bridge Controller(0xA208)"},
{0x1106, 0xA238, 0xFFFF, 0xFFFF, "K8T890 PCI to PCI Bridge Controller(0xA238)"},
{0x1106, 0xA327, 0xFFFF, 0xFFFF, "P4M890 PCI to PCI Bridge Controller(0xA327)"},
{0x1106, 0xA353, 0xFFFF, 0xFFFF, "VX8xx/900 Series South-North Module Interface Control(0xA353)"},
{0x1106, 0xA364, 0xFFFF, 0xFFFF, "CN896/VN896/P4M900 PCI to PCI Bridge Controller(0xA364)"},
{0x1106, 0xA409, 0xFFFF, 0xFFFF, "VX855/VX875/VX900 Series USB Device Controller(0xA409)"},
{0x1106, 0xA410, 0xFFFF, 0xFFFF, "VX900 Series PCI Express Root Port 0(0xA410)"},
{0x1106, 0xB091, 0xFFFF, 0xFFFF, "VT8633 [Apollo Pro266 AGP](0xB091)"},
{0x1106, 0xB099, 0xFFFF, 0xFFFF, "VT8366/A/7 [Apollo KT266/A/333 AGP](0xB099)"},
{0x1106, 0xB101, 0xFFFF, 0xFFFF, "VT8653 AGP Bridge(0xB101)"},
{0x1106, 0xB102, 0xFFFF, 0xFFFF, "VT8362 AGP Bridge(0xB102)"},
{0x1106, 0xB103, 0xFFFF, 0xFFFF, "VT8615 AGP Bridge(0xB103)"},
{0x1106, 0xB112, 0xFFFF, 0xFFFF, "VT8361 [KLE133] AGP Bridge(0xB112)"},
{0x1106, 0xB113, 0xFFFF, 0xFFFF, "VPX/VPX2 I/O APIC Interrupt Controller(0xB113)"},
{0x1106, 0xB115, 0xFFFF, 0xFFFF, "VT8363/8365 [KT133/KM133] PCI Bridge(0xB115)"},
{0x1106, 0xB168, 0xFFFF, 0xFFFF, "VT8235 PCI Bridge(0xB168)"},
{0x1106, 0xB188, 0xFFFF, 0xFFFF, "VT8237/8251 PCI bridge [K8M890/K8T800/K8T890 South](0xB188)"},
{0x1106, 0xB188, 0x147B, 0x1407, "KV8-MAX3 motherboard(0x147B-0x1407)"},
{0x1106, 0xB198, 0xFFFF, 0xFFFF, "VT8237/CX700/VX700-Series PCI to PCI Bridge(0xB198)"},
{0x1106, 0xB213, 0xFFFF, 0xFFFF, "VPX/VPX2 I/O APIC Interrupt Controller(0xB213)"},
{0x1106, 0xB353, 0xFFFF, 0xFFFF, "VX855/VX875/VX900 PCI to PCI Bridge(0xB353)"},
{0x1106, 0xB410, 0xFFFF, 0xFFFF, "VX900 Series PCI Express Root Port 1(0xB410)"},
{0x1106, 0xB999, 0xFFFF, 0xFFFF, "[K8T890 North / VT8237 South] PCI Bridge(0xB999)"},
{0x1106, 0xC208, 0xFFFF, 0xFFFF, "PT890 PCI to PCI Bridge Controller(0xC208)"},
{0x1106, 0xC238, 0xFFFF, 0xFFFF, "K8T890 PCI to PCI Bridge Controller(0xC238)"},
{0x1106, 0xC327, 0xFFFF, 0xFFFF, "P4M890 PCI to PCI Bridge Controller(0xC327)"},
{0x1106, 0xC340, 0xFFFF, 0xFFFF, "PT900 PCI to PCI Bridge Controller(0xC340)"},
{0x1106, 0xC353, 0xFFFF, 0xFFFF, "VX800/820-Series PCI-Express Root (PCI-to-PCI Virtual Bridge)(0xC353)"},
{0x1106, 0xC364, 0xFFFF, 0xFFFF, "CN896/VN896/P4M900 PCI to PCI Bridge Controller(0xC364)"},
{0x1106, 0xC409, 0xFFFF, 0xFFFF, "VX855/VX875 EIDE Controller(0xC409)"},
{0x1106, 0xC410, 0xFFFF, 0xFFFF, "VX900 Series PCI Express Root Port 2(0xC410)"},
{0x1106, 0xD104, 0xFFFF, 0xFFFF, "VT8237R USB UDCI Controller(0xD104)"},
{0x1106, 0xD208, 0xFFFF, 0xFFFF, "PT890 PCI to PCI Bridge Controller(0xD208)"},
{0x1106, 0xD213, 0xFFFF, 0xFFFF, "VPX/VPX2 PCI to PCI Bridge Controller(0xD213)"},
{0x1106, 0xD238, 0xFFFF, 0xFFFF, "K8T890 PCI to PCI Bridge Controller(0xD238)"},
{0x1106, 0xD340, 0xFFFF, 0xFFFF, "PT900 PCI to PCI Bridge Controller(0xD340)"},
{0x1106, 0xD410, 0xFFFF, 0xFFFF, "VX900 Series PCI Express Root Port 3(0xD410)"},
{0x1106, 0xE208, 0xFFFF, 0xFFFF, "PT890 PCI to PCI Bridge Controller(0xE208)"},
{0x1106, 0xE238, 0xFFFF, 0xFFFF, "K8T890 PCI to PCI Bridge Controller(0xE238)"},
{0x1106, 0xE340, 0xFFFF, 0xFFFF, "PT900 PCI to PCI Bridge Controller(0xE340)"},
{0x1106, 0xE353, 0xFFFF, 0xFFFF, "VX800/820-Series PCI-Express Root Port 0(0xE353)"},
{0x1106, 0xE410, 0xFFFF, 0xFFFF, "VX900 Series PCI Express Physical Layer Electrical Sub-block(0xE410)"},
{0x1106, 0xF208, 0xFFFF, 0xFFFF, "PT890 PCI to PCI Bridge Controller(0xF208)"},
{0x1106, 0xF238, 0xFFFF, 0xFFFF, "K8T890 PCI to PCI Bridge Controller(0xF238)"},
{0x1106, 0xF340, 0xFFFF, 0xFFFF, "PT900 PCI to PCI Bridge Controller(0xF340)"},
{0x1106, 0xF353, 0xFFFF, 0xFFFF, "VX800/820-Series PCI-Express Root Port 1(0xF353)"},
{0x1106, 0xF410, 0xFFFF, 0xFFFF, "VX900 Series PCI UART Port 0-3(0xF410)"},
}; /* pci_vid_1106[] */

static pci_id_t const pci_vid_1107[] = {
{0x1107, 0xFFFF, 0xFFFF, 0xFFFF, "Stratus Computers(0x1107)"},
{0x1107, 0x0576, 0xFFFF, 0xFFFF, "VIA VT82C570MV [Apollo] (Wrong vendor ID!)(0x0576)"},
}; /* pci_vid_1107[] */

static pci_id_t const pci_vid_1108[] = {
{0x1108, 0xFFFF, 0xFFFF, 0xFFFF, "Proteon, Inc.(0x1108)"},
{0x1108, 0x0100, 0xFFFF, 0xFFFF, "p1690plus_AA(0x0100)"},
{0x1108, 0x0101, 0xFFFF, 0xFFFF, "p1690plus_AB(0x0101)"},
{0x1108, 0x0105, 0xFFFF, 0xFFFF, "P1690Plus(0x0105)"},
{0x1108, 0x0108, 0xFFFF, 0xFFFF, "P1690Plus(0x0108)"},
{0x1108, 0x0138, 0xFFFF, 0xFFFF, "P1690Plus(0x0138)"},
{0x1108, 0x0139, 0xFFFF, 0xFFFF, "P1690Plus(0x0139)"},
{0x1108, 0x013C, 0xFFFF, 0xFFFF, "P1690Plus(0x013C)"},
{0x1108, 0x013D, 0xFFFF, 0xFFFF, "P1690Plus(0x013D)"},
}; /* pci_vid_1108[] */

static pci_id_t const pci_vid_1109[] = {
{0x1109, 0xFFFF, 0xFFFF, 0xFFFF, "Cogent Data Technologies, Inc.(0x1109)"},
{0x1109, 0x1400, 0xFFFF, 0xFFFF, "EM110TX [EX110TX](0x1400)"},
}; /* pci_vid_1109[] */

static pci_id_t const pci_vid_110A[] = {
{0x110A, 0xFFFF, 0xFFFF, 0xFFFF, "Siemens AG(0x110A)"},
{0x110A, 0x0002, 0xFFFF, 0xFFFF, "Pirahna 2-port(0x0002)"},
{0x110A, 0x0005, 0xFFFF, 0xFFFF, "Tulip controller, power management, switch extender(0x0005)"},
{0x110A, 0x0006, 0xFFFF, 0xFFFF, "FSC PINC (I/O-APIC)(0x0006)"},
{0x110A, 0x0015, 0xFFFF, 0xFFFF, "FSC Multiprocessor Interrupt Controller(0x0015)"},
{0x110A, 0x001D, 0xFFFF, 0xFFFF, "FSC Copernicus Management Controller(0x001D)"},
{0x110A, 0x007B, 0xFFFF, 0xFFFF, "FSC Remote Service Controller, mailbox device(0x007B)"},
{0x110A, 0x007C, 0xFFFF, 0xFFFF, "FSC Remote Service Controller, shared memory device(0x007C)"},
{0x110A, 0x007D, 0xFFFF, 0xFFFF, "FSC Remote Service Controller, SMIC device(0x007D)"},
{0x110A, 0x2101, 0xFFFF, 0xFFFF, "HST SAPHIR V Primary PCI (ISDN/PMx)(0x2101)"},
{0x110A, 0x2102, 0xFFFF, 0xFFFF, "DSCC4 PEB/PEF 20534 DMA Supported Serial Communication Controller with 4 Channels(0x2102)"},
{0x110A, 0x2104, 0xFFFF, 0xFFFF, "Eicon Diva 2.02 compatible passive ISDN card(0x2104)"},
{0x110A, 0x3101, 0xFFFF, 0xFFFF, "HiPath 4000 PCI card(0x3101)"},
{0x110A, 0x3141, 0xFFFF, 0xFFFF, "SIMATIC NET CP 5611 / 5621(0x3141)"},
{0x110A, 0x3142, 0xFFFF, 0xFFFF, "SIMATIC NET CP 5613 / 5614(0x3142)"},
{0x110A, 0x3143, 0xFFFF, 0xFFFF, "SIMATIC NET CP 1613(0x3143)"},
{0x110A, 0x4021, 0xFFFF, 0xFFFF, "SIMATIC NET CP 5512 (Profibus and MPI Cardbus Adapter)(0x4021)"},
{0x110A, 0x4029, 0xFFFF, 0xFFFF, "SIMATIC NET CP 5613 A2(0x4029)"},
{0x110A, 0x4029, 0x110A, 0x4029, "SIMATIC NET CP 5613 A2(0x110A-0x4029)"},
{0x110A, 0x4029, 0x110A, 0xC029, "SIMATIC NET CP 5614 A2(0x110A-0xC029)"},
{0x110A, 0x4035, 0xFFFF, 0xFFFF, "SIMATIC NET CP 1613 A2(0x4035)"},
{0x110A, 0x4036, 0xFFFF, 0xFFFF, "SIMATIC NET CP 1616(0x4036)"},
{0x110A, 0x4038, 0xFFFF, 0xFFFF, "SIMATIC NET CP 1604(0x4038)"},
{0x110A, 0x4069, 0xFFFF, 0xFFFF, "SIMATIC NET CP 5623(0x4069)"},
{0x110A, 0x4069, 0x110A, 0x4069, "SIMATIC NET CP 5623(0x110A-0x4069)"},
{0x110A, 0x4069, 0x110A, 0xC069, "SIMATIC NET CP 5624(0x110A-0xC069)"},
{0x110A, 0x407C, 0xFFFF, 0xFFFF, "SIMATIC NET CP 5612(0x407C)"},
{0x110A, 0x407D, 0xFFFF, 0xFFFF, "SIMATIC NET CP 5613 A3(0x407D)"},
{0x110A, 0x407E, 0xFFFF, 0xFFFF, "SIMATIC NET CP 5622(0x407E)"},
{0x110A, 0x4083, 0xFFFF, 0xFFFF, "SIMATIC NET CP 5614 A3(0x4083)"},
{0x110A, 0x4084, 0xFFFF, 0xFFFF, "SIMATIC NET CP 1626(0x4084)"},
{0x110A, 0x4942, 0xFFFF, 0xFFFF, "FPGA I-Bus Tracer for MBD(0x4942)"},
{0x110A, 0x6120, 0xFFFF, 0xFFFF, "SZB6120(0x6120)"},
}; /* pci_vid_110A[] */

static pci_id_t const pci_vid_110B[] = {
{0x110B, 0xFFFF, 0xFFFF, 0xFFFF, "Chromatic Research Inc.(0x110B)"},
{0x110B, 0x0001, 0xFFFF, 0xFFFF, "Mpact Media Processor(0x0001)"},
{0x110B, 0x0004, 0xFFFF, 0xFFFF, "Mpact 2(0x0004)"},
}; /* pci_vid_110B[] */

static pci_id_t const pci_vid_110C[] = {
{0x110C, 0xFFFF, 0xFFFF, 0xFFFF, "Mini-Max Technology, Inc.(0x110C)"},
}; /* pci_vid_110C[] */

static pci_id_t const pci_vid_110D[] = {
{0x110D, 0xFFFF, 0xFFFF, 0xFFFF, "Znyx Advanced Systems(0x110D)"},
}; /* pci_vid_110D[] */

static pci_id_t const pci_vid_110E[] = {
{0x110E, 0xFFFF, 0xFFFF, 0xFFFF, "CPU Technology(0x110E)"},
}; /* pci_vid_110E[] */

static pci_id_t const pci_vid_110F[] = {
{0x110F, 0xFFFF, 0xFFFF, 0xFFFF, "Ross Technology(0x110F)"},
}; /* pci_vid_110F[] */

static pci_id_t const pci_vid_1110[] = {
{0x1110, 0xFFFF, 0xFFFF, 0xFFFF, "Powerhouse Systems(0x1110)"},
{0x1110, 0x6037, 0xFFFF, 0xFFFF, "Firepower Powerized SMP I/O ASIC(0x6037)"},
{0x1110, 0x6073, 0xFFFF, 0xFFFF, "Firepower Powerized SMP I/O ASIC(0x6073)"},
}; /* pci_vid_1110[] */

static pci_id_t const pci_vid_1111[] = {
{0x1111, 0xFFFF, 0xFFFF, 0xFFFF, "Santa Cruz Operation(0x1111)"},
}; /* pci_vid_1111[] */

static pci_id_t const pci_vid_1112[] = {
{0x1112, 0xFFFF, 0xFFFF, 0xFFFF, "Osicom Technologies Inc(0x1112)"},
{0x1112, 0x2200, 0xFFFF, 0xFFFF, "FDDI Adapter(0x2200)"},
{0x1112, 0x2300, 0xFFFF, 0xFFFF, "Fast Ethernet Adapter(0x2300)"},
{0x1112, 0x2340, 0xFFFF, 0xFFFF, "4 Port Fast Ethernet Adapter(0x2340)"},
{0x1112, 0x2400, 0xFFFF, 0xFFFF, "ATM Adapter(0x2400)"},
}; /* pci_vid_1112[] */

static pci_id_t const pci_vid_1113[] = {
{0x1113, 0xFFFF, 0xFFFF, 0xFFFF, "Accton Technology Corporation(0x1113)"},
{0x1113, 0x1211, 0xFFFF, 0xFFFF, "SMC2-1211TX(0x1211)"},
{0x1113, 0x1211, 0x103C, 0x1207, "EN-1207D Fast Ethernet Adapter(0x103C-0x1207)"},
{0x1113, 0x1211, 0x1113, 0x1211, "EN-1207D Fast Ethernet Adapter(0x1113-0x1211)"},
{0x1113, 0x1216, 0xFFFF, 0xFFFF, "EN-1216 Ethernet Adapter(0x1216)"},
{0x1113, 0x1216, 0x1113, 0x1216, "EN1207F series PCI Fast Ethernet Adapter(0x1113-0x1216)"},
{0x1113, 0x1216, 0x1113, 0x2220, "EN2220A Cardbus Fast Ethernet Adapter(0x1113-0x2220)"},
{0x1113, 0x1216, 0x1113, 0x2242, "EN2242 10/100 Ethernet Mini-PCI Card(0x1113-0x2242)"},
{0x1113, 0x1216, 0x111A, 0x1020, "SpeedStream 1020 PCI 10/100 Ethernet Adaptor [EN-1207F-TX ?-](0x111A-0x1020)"},
{0x1113, 0x1217, 0xFFFF, 0xFFFF, "EN-1217 Ethernet Adapter(0x1217)"},
{0x1113, 0x5105, 0xFFFF, 0xFFFF, "10Mbps Network card(0x5105)"},
{0x1113, 0x9211, 0xFFFF, 0xFFFF, "EN-1207D Fast Ethernet Adapter(0x9211)"},
{0x1113, 0x9211, 0x1113, 0x9211, "EN-1207D Fast Ethernet Adapter(0x1113-0x9211)"},
{0x1113, 0x9511, 0xFFFF, 0xFFFF, "21x4x DEC-Tulip compatible Fast Ethernet(0x9511)"},
{0x1113, 0xD301, 0xFFFF, 0xFFFF, "CPWNA100 (Philips wireless PCMCIA)(0xD301)"},
{0x1113, 0xEC02, 0xFFFF, 0xFFFF, "SMC 1244TX v3(0xEC02)"},
{0x1113, 0xEE23, 0xFFFF, 0xFFFF, "SMCWPCIT-G 108Mbps Wireless PCI adapter(0xEE23)"},
}; /* pci_vid_1113[] */

static pci_id_t const pci_vid_1114[] = {
{0x1114, 0xFFFF, 0xFFFF, 0xFFFF, "Atmel Corporation(0x1114)"},
{0x1114, 0x0506, 0xFFFF, 0xFFFF, "at76c506 802.11b Wireless Network Adaptor(0x0506)"},
}; /* pci_vid_1114[] */

static pci_id_t const pci_vid_1115[] = {
{0x1115, 0xFFFF, 0xFFFF, 0xFFFF, "3D Labs(0x1115)"},
}; /* pci_vid_1115[] */

static pci_id_t const pci_vid_1116[] = {
{0x1116, 0xFFFF, 0xFFFF, 0xFFFF, "Data Translation(0x1116)"},
{0x1116, 0x0022, 0xFFFF, 0xFFFF, "DT3001(0x0022)"},
{0x1116, 0x0023, 0xFFFF, 0xFFFF, "DT3002(0x0023)"},
{0x1116, 0x0024, 0xFFFF, 0xFFFF, "DT3003(0x0024)"},
{0x1116, 0x0025, 0xFFFF, 0xFFFF, "DT3004(0x0025)"},
{0x1116, 0x0026, 0xFFFF, 0xFFFF, "DT3005(0x0026)"},
{0x1116, 0x0027, 0xFFFF, 0xFFFF, "DT3001-PGL(0x0027)"},
{0x1116, 0x0028, 0xFFFF, 0xFFFF, "DT3003-PGL(0x0028)"},
{0x1116, 0x0051, 0xFFFF, 0xFFFF, "DT322(0x0051)"},
{0x1116, 0x0060, 0xFFFF, 0xFFFF, "DT340(0x0060)"},
{0x1116, 0x0069, 0xFFFF, 0xFFFF, "DT332(0x0069)"},
{0x1116, 0x80C2, 0xFFFF, 0xFFFF, "DT3162(0x80C2)"},
}; /* pci_vid_1116[] */

static pci_id_t const pci_vid_1117[] = {
{0x1117, 0xFFFF, 0xFFFF, 0xFFFF, "Datacube, Inc(0x1117)"},
{0x1117, 0x9500, 0xFFFF, 0xFFFF, "Max-1C SVGA card(0x9500)"},
{0x1117, 0x9501, 0xFFFF, 0xFFFF, "Max-1C image processing(0x9501)"},
}; /* pci_vid_1117[] */

static pci_id_t const pci_vid_1118[] = {
{0x1118, 0xFFFF, 0xFFFF, 0xFFFF, "Berg Electronics(0x1118)"},
}; /* pci_vid_1118[] */

static pci_id_t const pci_vid_1119[] = {
{0x1119, 0xFFFF, 0xFFFF, 0xFFFF, "ICP Vortex Computersysteme GmbH(0x1119)"},
{0x1119, 0x0000, 0xFFFF, 0xFFFF, "GDT 6000/6020/6050(0x0000)"},
{0x1119, 0x0001, 0xFFFF, 0xFFFF, "GDT 6000B/6010(0x0001)"},
{0x1119, 0x0002, 0xFFFF, 0xFFFF, "GDT 6110/6510(0x0002)"},
{0x1119, 0x0003, 0xFFFF, 0xFFFF, "GDT 6120/6520(0x0003)"},
{0x1119, 0x0004, 0xFFFF, 0xFFFF, "GDT 6530(0x0004)"},
{0x1119, 0x0005, 0xFFFF, 0xFFFF, "GDT 6550(0x0005)"},
{0x1119, 0x0006, 0xFFFF, 0xFFFF, "GDT 6117/6517(0x0006)"},
{0x1119, 0x0007, 0xFFFF, 0xFFFF, "GDT 6127/6527(0x0007)"},
{0x1119, 0x0008, 0xFFFF, 0xFFFF, "GDT 6537(0x0008)"},
{0x1119, 0x0009, 0xFFFF, 0xFFFF, "GDT 6557/6557-ECC(0x0009)"},
{0x1119, 0x000A, 0xFFFF, 0xFFFF, "GDT 6115/6515(0x000A)"},
{0x1119, 0x000B, 0xFFFF, 0xFFFF, "GDT 6125/6525(0x000B)"},
{0x1119, 0x000C, 0xFFFF, 0xFFFF, "GDT 6535(0x000C)"},
{0x1119, 0x000D, 0xFFFF, 0xFFFF, "GDT 6555/6555-ECC(0x000D)"},
{0x1119, 0x0100, 0xFFFF, 0xFFFF, "GDT 6117RP/6517RP(0x0100)"},
{0x1119, 0x0101, 0xFFFF, 0xFFFF, "GDT 6127RP/6527RP(0x0101)"},
{0x1119, 0x0102, 0xFFFF, 0xFFFF, "GDT 6537RP(0x0102)"},
{0x1119, 0x0103, 0xFFFF, 0xFFFF, "GDT 6557RP(0x0103)"},
{0x1119, 0x0104, 0xFFFF, 0xFFFF, "GDT 6111RP/6511RP(0x0104)"},
{0x1119, 0x0105, 0xFFFF, 0xFFFF, "GDT 6121RP/6521RP(0x0105)"},
{0x1119, 0x0110, 0xFFFF, 0xFFFF, "GDT 6117RD/6517RD(0x0110)"},
{0x1119, 0x0111, 0xFFFF, 0xFFFF, "GDT 6127RD/6527RD(0x0111)"},
{0x1119, 0x0112, 0xFFFF, 0xFFFF, "GDT 6537RD(0x0112)"},
{0x1119, 0x0113, 0xFFFF, 0xFFFF, "GDT 6557RD(0x0113)"},
{0x1119, 0x0114, 0xFFFF, 0xFFFF, "GDT 6111RD/6511RD(0x0114)"},
{0x1119, 0x0115, 0xFFFF, 0xFFFF, "GDT 6121RD/6521RD(0x0115)"},
{0x1119, 0x0118, 0xFFFF, 0xFFFF, "GDT 6118RD/6518RD/6618RD(0x0118)"},
{0x1119, 0x0119, 0xFFFF, 0xFFFF, "GDT 6128RD/6528RD/6628RD(0x0119)"},
{0x1119, 0x011A, 0xFFFF, 0xFFFF, "GDT 6538RD/6638RD(0x011A)"},
{0x1119, 0x011B, 0xFFFF, 0xFFFF, "GDT 6558RD/6658RD(0x011B)"},
{0x1119, 0x0120, 0xFFFF, 0xFFFF, "GDT 6117RP2/6517RP2(0x0120)"},
{0x1119, 0x0121, 0xFFFF, 0xFFFF, "GDT 6127RP2/6527RP2(0x0121)"},
{0x1119, 0x0122, 0xFFFF, 0xFFFF, "GDT 6537RP2(0x0122)"},
{0x1119, 0x0123, 0xFFFF, 0xFFFF, "GDT 6557RP2(0x0123)"},
{0x1119, 0x0124, 0xFFFF, 0xFFFF, "GDT 6111RP2/6511RP2(0x0124)"},
{0x1119, 0x0125, 0xFFFF, 0xFFFF, "GDT 6121RP2/6521RP2(0x0125)"},
{0x1119, 0x0136, 0xFFFF, 0xFFFF, "GDT 6113RS/6513RS(0x0136)"},
{0x1119, 0x0137, 0xFFFF, 0xFFFF, "GDT 6123RS/6523RS(0x0137)"},
{0x1119, 0x0138, 0xFFFF, 0xFFFF, "GDT 6118RS/6518RS/6618RS(0x0138)"},
{0x1119, 0x0139, 0xFFFF, 0xFFFF, "GDT 6128RS/6528RS/6628RS(0x0139)"},
{0x1119, 0x013A, 0xFFFF, 0xFFFF, "GDT 6538RS/6638RS(0x013A)"},
{0x1119, 0x013B, 0xFFFF, 0xFFFF, "GDT 6558RS/6658RS(0x013B)"},
{0x1119, 0x013C, 0xFFFF, 0xFFFF, "GDT 6533RS/6633RS(0x013C)"},
{0x1119, 0x013D, 0xFFFF, 0xFFFF, "GDT 6543RS/6643RS(0x013D)"},
{0x1119, 0x013E, 0xFFFF, 0xFFFF, "GDT 6553RS/6653RS(0x013E)"},
{0x1119, 0x013F, 0xFFFF, 0xFFFF, "GDT 6563RS/6663RS(0x013F)"},
{0x1119, 0x0166, 0xFFFF, 0xFFFF, "GDT 7113RN/7513RN/7613RN(0x0166)"},
{0x1119, 0x0167, 0xFFFF, 0xFFFF, "GDT 7123RN/7523RN/7623RN(0x0167)"},
{0x1119, 0x0168, 0xFFFF, 0xFFFF, "GDT 7118RN/7518RN/7518RN(0x0168)"},
{0x1119, 0x0169, 0xFFFF, 0xFFFF, "GDT 7128RN/7528RN/7628RN(0x0169)"},
{0x1119, 0x016A, 0xFFFF, 0xFFFF, "GDT 7538RN/7638RN(0x016A)"},
{0x1119, 0x016B, 0xFFFF, 0xFFFF, "GDT 7558RN/7658RN(0x016B)"},
{0x1119, 0x016C, 0xFFFF, 0xFFFF, "GDT 7533RN/7633RN(0x016C)"},
{0x1119, 0x016D, 0xFFFF, 0xFFFF, "GDT 7543RN/7643RN(0x016D)"},
{0x1119, 0x016E, 0xFFFF, 0xFFFF, "GDT 7553RN/7653RN(0x016E)"},
{0x1119, 0x016F, 0xFFFF, 0xFFFF, "GDT 7563RN/7663RN(0x016F)"},
{0x1119, 0x01D6, 0xFFFF, 0xFFFF, "GDT 4x13RZ(0x01D6)"},
{0x1119, 0x01D7, 0xFFFF, 0xFFFF, "GDT 4x23RZ(0x01D7)"},
{0x1119, 0x01F6, 0xFFFF, 0xFFFF, "GDT 8x13RZ(0x01F6)"},
{0x1119, 0x01F7, 0xFFFF, 0xFFFF, "GDT 8x23RZ(0x01F7)"},
{0x1119, 0x01FC, 0xFFFF, 0xFFFF, "GDT 8x33RZ(0x01FC)"},
{0x1119, 0x01FD, 0xFFFF, 0xFFFF, "GDT 8x43RZ(0x01FD)"},
{0x1119, 0x01FE, 0xFFFF, 0xFFFF, "GDT 8x53RZ(0x01FE)"},
{0x1119, 0x01FF, 0xFFFF, 0xFFFF, "GDT 8x63RZ(0x01FF)"},
{0x1119, 0x0210, 0xFFFF, 0xFFFF, "GDT 6519RD/6619RD(0x0210)"},
{0x1119, 0x0211, 0xFFFF, 0xFFFF, "GDT 6529RD/6629RD(0x0211)"},
{0x1119, 0x0260, 0xFFFF, 0xFFFF, "GDT 7519RN/7619RN(0x0260)"},
{0x1119, 0x0261, 0xFFFF, 0xFFFF, "GDT 7529RN/7629RN(0x0261)"},
{0x1119, 0x02FF, 0xFFFF, 0xFFFF, "GDT MAXRP(0x02FF)"},
{0x1119, 0x0300, 0xFFFF, 0xFFFF, "GDT NEWRX(0x0300)"},
{0x1119, 0x0301, 0xFFFF, 0xFFFF, "GDT NEWRX2(0x0301)"},
}; /* pci_vid_1119[] */

static pci_id_t const pci_vid_111A[] = {
{0x111A, 0xFFFF, 0xFFFF, 0xFFFF, "Efficient Networks, Inc(0x111A)"},
{0x111A, 0x0000, 0xFFFF, 0xFFFF, "155P-MF1 (FPGA)(0x0000)"},
{0x111A, 0x0002, 0xFFFF, 0xFFFF, "155P-MF1 (ASIC)(0x0002)"},
{0x111A, 0x0003, 0xFFFF, 0xFFFF, "ENI-25P ATM(0x0003)"},
{0x111A, 0x0003, 0x111A, 0x0000, "ENI-25p Miniport ATM Adapter(0x111A-0x0000)"},
{0x111A, 0x0005, 0xFFFF, 0xFFFF, "SpeedStream (LANAI)(0x0005)"},
{0x111A, 0x0005, 0x111A, 0x0001, "ENI-3010 ATM(0x111A-0x0001)"},
{0x111A, 0x0005, 0x111A, 0x0009, "ENI-3060 ADSL (VPI=0)(0x111A-0x0009)"},
{0x111A, 0x0005, 0x111A, 0x0101, "ENI-3010 ATM(0x111A-0x0101)"},
{0x111A, 0x0005, 0x111A, 0x0109, "ENI-3060CO ADSL (VPI=0)(0x111A-0x0109)"},
{0x111A, 0x0005, 0x111A, 0x0809, "ENI-3060 ADSL (VPI=0 or 8)(0x111A-0x0809)"},
{0x111A, 0x0005, 0x111A, 0x0909, "ENI-3060CO ADSL (VPI=0 or 8)(0x111A-0x0909)"},
{0x111A, 0x0005, 0x111A, 0x0A09, "ENI-3060 ADSL (VPI=<0..15>)(0x111A-0x0A09)"},
{0x111A, 0x0007, 0xFFFF, 0xFFFF, "SpeedStream ADSL(0x0007)"},
{0x111A, 0x0007, 0x111A, 0x1001, "ENI-3061 ADSL [ASIC](0x111A-0x1001)"},
{0x111A, 0x1020, 0xFFFF, 0xFFFF, "SpeedStream PCI 10/100 Network Card(0x1020)"},
{0x111A, 0x1203, 0xFFFF, 0xFFFF, "SpeedStream 1023 Wireless PCI Adapter(0x1203)"},
}; /* pci_vid_111A[] */

static pci_id_t const pci_vid_111B[] = {
{0x111B, 0xFFFF, 0xFFFF, 0xFFFF, "Teledyne Electronic Systems(0x111B)"},
}; /* pci_vid_111B[] */

static pci_id_t const pci_vid_111C[] = {
{0x111C, 0xFFFF, 0xFFFF, 0xFFFF, "Tricord Systems Inc.(0x111C)"},
{0x111C, 0x0001, 0xFFFF, 0xFFFF, "Powerbis Bridge(0x0001)"},
}; /* pci_vid_111C[] */

static pci_id_t const pci_vid_111D[] = {
{0x111D, 0xFFFF, 0xFFFF, 0xFFFF, "Microsemi / PMC / IDT(0x111D)"},
{0x111D, 0x0001, 0xFFFF, 0xFFFF, "IDT77201/77211 155Mbps ATM SAR Controller [NICStAR](0x0001)"},
{0x111D, 0x0003, 0xFFFF, 0xFFFF, "IDT77222/77252 155Mbps ATM MICRO ABR SAR Controller(0x0003)"},
{0x111D, 0x0004, 0xFFFF, 0xFFFF, "IDT77V252 155Mbps ATM MICRO ABR SAR Controller(0x0004)"},
{0x111D, 0x0005, 0xFFFF, 0xFFFF, "IDT77V222 155Mbps ATM MICRO ABR SAR Controller(0x0005)"},
{0x111D, 0x8018, 0xFFFF, 0xFFFF, "PES12N3A 12-lane 3-Port PCI Express Switch(0x8018)"},
{0x111D, 0x801C, 0xFFFF, 0xFFFF, "PES24N3A PCI Express Switch(0x801C)"},
{0x111D, 0x8028, 0xFFFF, 0xFFFF, "PES4T4 PCI Express Switch(0x8028)"},
{0x111D, 0x802B, 0xFFFF, 0xFFFF, "PES8T5A PCI Express Switch(0x802B)"},
{0x111D, 0x802C, 0xFFFF, 0xFFFF, "PES16T4 PCI Express Switch(0x802C)"},
{0x111D, 0x802D, 0xFFFF, 0xFFFF, "PES16T7 PCI Express Switch(0x802D)"},
{0x111D, 0x802E, 0xFFFF, 0xFFFF, "PES24T6 PCI Express Switch(0x802E)"},
{0x111D, 0x802F, 0xFFFF, 0xFFFF, "PES32T8 PCI Express Switch(0x802F)"},
{0x111D, 0x8032, 0xFFFF, 0xFFFF, "PES48T12 PCI Express Switch(0x8032)"},
{0x111D, 0x8034, 0xFFFF, 0xFFFF, "PES16/22/34H16 PCI Express Switch(0x8034)"},
{0x111D, 0x8035, 0xFFFF, 0xFFFF, "PES32H8 PCI Express Switch(0x8035)"},
{0x111D, 0x8036, 0xFFFF, 0xFFFF, "PES48H12 PCI Express Switch(0x8036)"},
{0x111D, 0x8037, 0xFFFF, 0xFFFF, "PES64H16 PCI Express Switch(0x8037)"},
{0x111D, 0x8039, 0xFFFF, 0xFFFF, "PES3T3 PCI Express Switch(0x8039)"},
{0x111D, 0x803A, 0xFFFF, 0xFFFF, "PES4T4 PCI Express Switch(0x803A)"},
{0x111D, 0x803C, 0xFFFF, 0xFFFF, "PES5T5 PCI Express Switch(0x803C)"},
{0x111D, 0x803D, 0xFFFF, 0xFFFF, "PES6T5 PCI Express Switch(0x803D)"},
{0x111D, 0x8048, 0xFFFF, 0xFFFF, "PES8NT2 PCI Express Switch(0x8048)"},
{0x111D, 0x8049, 0xFFFF, 0xFFFF, "PES8NT2 PCI Express Switch(0x8049)"},
{0x111D, 0x804A, 0xFFFF, 0xFFFF, "PES8NT2 PCI Express Internal NTB(0x804A)"},
{0x111D, 0x804B, 0xFFFF, 0xFFFF, "PES8NT2 PCI Express External NTB(0x804B)"},
{0x111D, 0x804C, 0xFFFF, 0xFFFF, "PES16NT2 PCI Express Switch(0x804C)"},
{0x111D, 0x804D, 0xFFFF, 0xFFFF, "PES16NT2 PCI Express Switch(0x804D)"},
{0x111D, 0x804E, 0xFFFF, 0xFFFF, "PES16NT2 PCI Express Internal NTB(0x804E)"},
{0x111D, 0x804F, 0xFFFF, 0xFFFF, "PES16NT2 PCI Express External NTB(0x804F)"},
{0x111D, 0x8058, 0xFFFF, 0xFFFF, "PES12NT3 PCI Express Switch(0x8058)"},
{0x111D, 0x8059, 0xFFFF, 0xFFFF, "PES12NT3 PCI Express Switch(0x8059)"},
{0x111D, 0x805A, 0xFFFF, 0xFFFF, "PES12NT3 PCI Express Internal NTB(0x805A)"},
{0x111D, 0x805B, 0xFFFF, 0xFFFF, "PES12NT3 PCI Express External NTB(0x805B)"},
{0x111D, 0x805C, 0xFFFF, 0xFFFF, "PES24NT3 PCI Express Switch(0x805C)"},
{0x111D, 0x805D, 0xFFFF, 0xFFFF, "PES24NT3 PCI Express Switch(0x805D)"},
{0x111D, 0x805E, 0xFFFF, 0xFFFF, "PES24NT3 PCI Express Internal NTB(0x805E)"},
{0x111D, 0x805F, 0xFFFF, 0xFFFF, "PES24NT3 PCI Express External NTB(0x805F)"},
{0x111D, 0x8060, 0xFFFF, 0xFFFF, "PES16T4G2 PCI Express Gen2 Switch(0x8060)"},
{0x111D, 0x8061, 0xFFFF, 0xFFFF, "PES12T3G2 PCI Express Gen2 Switch(0x8061)"},
{0x111D, 0x8068, 0xFFFF, 0xFFFF, "PES6T6G2 PCI Express Gen2 Switch(0x8068)"},
{0x111D, 0x806A, 0xFFFF, 0xFFFF, "PES24T3G2 PCI Express Gen2 Switch(0x806A)"},
{0x111D, 0x806A, 0x14C1, 0x000C, "10G-PCIE2-8B2(0x14C1-0x000C)"},
{0x111D, 0x806C, 0xFFFF, 0xFFFF, "PES16T4A/4T4G2 PCI Express Gen2 Switch(0x806C)"},
{0x111D, 0x806E, 0xFFFF, 0xFFFF, "PES24T6G2 PCI Express Gen2 Switch(0x806E)"},
{0x111D, 0x806F, 0xFFFF, 0xFFFF, "HIO524G2 PCI Express Gen2 Switch(0x806F)"},
{0x111D, 0x8077, 0xFFFF, 0xFFFF, "89HPES64H16G2 64-Lane 16-Port PCIe Gen2 System Interconnect Switch(0x8077)"},
{0x111D, 0x8088, 0xFFFF, 0xFFFF, "PES32NT8BG2 PCI Express Switch(0x8088)"},
{0x111D, 0x8088, 0x1093, 0x752F, "PXIe-8383mc Device(0x1093-0x752F)"},
{0x111D, 0x8088, 0x1093, 0x7543, "PXIe-8383mc System Host(0x1093-0x7543)"},
{0x111D, 0x8088, 0x1093, 0x755C, "PXIe-8364(0x1093-0x755C)"},
{0x111D, 0x8088, 0x1093, 0x755D, "PXIe-8374(0x1093-0x755D)"},
{0x111D, 0x8088, 0x1093, 0x75FF, "PXIe-8383mc DMA(0x1093-0x75FF)"},
{0x111D, 0x8088, 0x1093, 0x7600, "PXIe-8383mc DMA(0x1093-0x7600)"},
{0x111D, 0x8088, 0x1093, 0x7602, "PXIe-8384(0x1093-0x7602)"},
{0x111D, 0x808A, 0xFFFF, 0xFFFF, "89HPES32NT24BG2 PCI Express Switch(0x808A)"},
{0x111D, 0x808C, 0xFFFF, 0xFFFF, "89HPES32NT24AG2 PCI Express Switch(0x808C)"},
{0x111D, 0x808E, 0xFFFF, 0xFFFF, "PES24NT24G2 PCI Express Switch(0x808E)"},
{0x111D, 0x808F, 0xFFFF, 0xFFFF, "89HPES32NT8AG2 32-Lane 8-Port PCIe Gen2 System Interconnect Switch with Non-Transparent Bridging(0x808F)"},
{0x111D, 0x8090, 0xFFFF, 0xFFFF, "89HPES16NT16G2 16-Lane 16-Port PCIe Gen2 System Interconnect Switch(0x8090)"},
{0x111D, 0x8092, 0xFFFF, 0xFFFF, "89HPES12NT12G2 12-Lane 12-Port PCIe Gen2 System Interconnect Switch(0x8092)"},
{0x111D, 0x80CF, 0xFFFF, 0xFFFF, "F32P08xG3 [PCIe boot mode](0x80CF)"},
{0x111D, 0x80D2, 0xFFFF, 0xFFFF, "F32P08xG3 NVMe controller(0x80D2)"},
}; /* pci_vid_111D[] */

static pci_id_t const pci_vid_111E[] = {
{0x111E, 0xFFFF, 0xFFFF, 0xFFFF, "Eldec(0x111E)"},
}; /* pci_vid_111E[] */

static pci_id_t const pci_vid_111F[] = {
{0x111F, 0xFFFF, 0xFFFF, 0xFFFF, "Precision Digital Images(0x111F)"},
{0x111F, 0x4A47, 0xFFFF, 0xFFFF, "Precision MX Video engine interface(0x4A47)"},
{0x111F, 0x5243, 0xFFFF, 0xFFFF, "Frame capture bus interface(0x5243)"},
}; /* pci_vid_111F[] */

static pci_id_t const pci_vid_1120[] = {
{0x1120, 0xFFFF, 0xFFFF, 0xFFFF, "Dell EMC(0x1120)"},
{0x1120, 0x2306, 0xFFFF, 0xFFFF, "Unity Fibre Channel Controller(0x2306)"},
{0x1120, 0x2501, 0xFFFF, 0xFFFF, "Unity Ethernet Controller(0x2501)"},
{0x1120, 0x2505, 0xFFFF, 0xFFFF, "Unity Fibre Channel Controller(0x2505)"},
}; /* pci_vid_1120[] */

static pci_id_t const pci_vid_1121[] = {
{0x1121, 0xFFFF, 0xFFFF, 0xFFFF, "Zilog(0x1121)"},
}; /* pci_vid_1121[] */

static pci_id_t const pci_vid_1122[] = {
{0x1122, 0xFFFF, 0xFFFF, 0xFFFF, "Multi-tech Systems, Inc.(0x1122)"},
}; /* pci_vid_1122[] */

static pci_id_t const pci_vid_1123[] = {
{0x1123, 0xFFFF, 0xFFFF, 0xFFFF, "Excellent Design, Inc.(0x1123)"},
}; /* pci_vid_1123[] */

static pci_id_t const pci_vid_1124[] = {
{0x1124, 0xFFFF, 0xFFFF, 0xFFFF, "Leutron Vision AG(0x1124)"},
{0x1124, 0x2581, 0xFFFF, 0xFFFF, "Picport Monochrome(0x2581)"},
}; /* pci_vid_1124[] */

static pci_id_t const pci_vid_1125[] = {
{0x1125, 0xFFFF, 0xFFFF, 0xFFFF, "Eurocore(0x1125)"},
}; /* pci_vid_1125[] */

static pci_id_t const pci_vid_1126[] = {
{0x1126, 0xFFFF, 0xFFFF, 0xFFFF, "Vigra(0x1126)"},
}; /* pci_vid_1126[] */

static pci_id_t const pci_vid_1127[] = {
{0x1127, 0xFFFF, 0xFFFF, 0xFFFF, "FORE Systems Inc(0x1127)"},
{0x1127, 0x0200, 0xFFFF, 0xFFFF, "ForeRunner PCA-200 ATM(0x0200)"},
{0x1127, 0x0210, 0xFFFF, 0xFFFF, "PCA-200PC(0x0210)"},
{0x1127, 0x0250, 0xFFFF, 0xFFFF, "ATM(0x0250)"},
{0x1127, 0x0300, 0xFFFF, 0xFFFF, "ForeRunner PCA-200EPC ATM(0x0300)"},
{0x1127, 0x0310, 0xFFFF, 0xFFFF, "ATM(0x0310)"},
{0x1127, 0x0400, 0xFFFF, 0xFFFF, "ForeRunnerHE ATM Adapter(0x0400)"},
{0x1127, 0x0400, 0x1127, 0x0400, "ForeRunnerHE ATM(0x1127-0x0400)"},
}; /* pci_vid_1127[] */

static pci_id_t const pci_vid_1129[] = {
{0x1129, 0xFFFF, 0xFFFF, 0xFFFF, "Firmworks(0x1129)"},
}; /* pci_vid_1129[] */

static pci_id_t const pci_vid_112A[] = {
{0x112A, 0xFFFF, 0xFFFF, 0xFFFF, "Hermes Electronics Company, Ltd.(0x112A)"},
}; /* pci_vid_112A[] */

static pci_id_t const pci_vid_112B[] = {
{0x112B, 0xFFFF, 0xFFFF, 0xFFFF, "Heidelberger Druckmaschinen AG(0x112B)"},
{0x112B, 0x0001, 0xFFFF, 0xFFFF, "SCU5(0x0001)"},
}; /* pci_vid_112B[] */

static pci_id_t const pci_vid_112C[] = {
{0x112C, 0xFFFF, 0xFFFF, 0xFFFF, "Zenith Data Systems(0x112C)"},
}; /* pci_vid_112C[] */

static pci_id_t const pci_vid_112D[] = {
{0x112D, 0xFFFF, 0xFFFF, 0xFFFF, "Ravicad(0x112D)"},
}; /* pci_vid_112D[] */

static pci_id_t const pci_vid_112E[] = {
{0x112E, 0xFFFF, 0xFFFF, 0xFFFF, "Infomedia Microelectronics Inc.(0x112E)"},
}; /* pci_vid_112E[] */

static pci_id_t const pci_vid_112F[] = {
{0x112F, 0xFFFF, 0xFFFF, 0xFFFF, "Dalsa Inc.(0x112F)"},
{0x112F, 0x0000, 0xFFFF, 0xFFFF, "MVC IC-PCI(0x0000)"},
{0x112F, 0x0001, 0xFFFF, 0xFFFF, "MVC IM-PCI Video frame grabber/processor(0x0001)"},
{0x112F, 0x0004, 0xFFFF, 0xFFFF, "PCDig Digital Image Capture(0x0004)"},
{0x112F, 0x0008, 0xFFFF, 0xFFFF, "PC-CamLink PCI framegrabber(0x0008)"},
}; /* pci_vid_112F[] */

static pci_id_t const pci_vid_1130[] = {
{0x1130, 0xFFFF, 0xFFFF, 0xFFFF, "Computervision(0x1130)"},
}; /* pci_vid_1130[] */

static pci_id_t const pci_vid_1131[] = {
{0x1131, 0xFFFF, 0xFFFF, 0xFFFF, "Philips Semiconductors(0x1131)"},
{0x1131, 0x1561, 0xFFFF, 0xFFFF, "USB 1.1 Host Controller(0x1561)"},
{0x1131, 0x1561, 0x1775, 0xC200, "C2K onboard USB 1.1 host controller(0x1775-0xC200)"},
{0x1131, 0x1562, 0xFFFF, 0xFFFF, "USB 2.0 Host Controller(0x1562)"},
{0x1131, 0x1562, 0x1775, 0xC200, "C2K onboard USB 2.0 host controller(0x1775-0xC200)"},
{0x1131, 0x3400, 0xFFFF, 0xFFFF, "SmartPCI56(UCB1500) 56K Modem(0x3400)"},
{0x1131, 0x5400, 0xFFFF, 0xFFFF, "TriMedia TM1000/1100(0x5400)"},
{0x1131, 0x5400, 0x12CA, 0x0000, "BlueICE(0x12CA-0x0000)"},
{0x1131, 0x5402, 0xFFFF, 0xFFFF, "TriMedia TM1300(0x5402)"},
{0x1131, 0x5402, 0x1244, 0x0F00, "Fritz!Card DSL(0x1244-0x0F00)"},
{0x1131, 0x5402, 0x15EB, 0x1300, "DT1300(0x15EB-0x1300)"},
{0x1131, 0x5402, 0x15EB, 0x1302, "DT1302(0x15EB-0x1302)"},
{0x1131, 0x5402, 0x15EB, 0x1304, "DT1304(0x15EB-0x1304)"},
{0x1131, 0x5402, 0x15EB, 0x1305, "DT1305(0x15EB-0x1305)"},
{0x1131, 0x5402, 0x15EB, 0x1306, "PMCDT1306(0x15EB-0x1306)"},
{0x1131, 0x5402, 0x15EB, 0x1308, "DT1308(0x15EB-0x1308)"},
{0x1131, 0x5402, 0x15EB, 0x1331, "DT1301 with SAA7121(0x15EB-0x1331)"},
{0x1131, 0x5402, 0x15EB, 0x1337, "DT1301 with SAA7127(0x15EB-0x1337)"},
{0x1131, 0x5402, 0x15EB, 0x2D3D, "X3D(0x15EB-0x2D3D)"},
{0x1131, 0x5402, 0x15EB, 0x7022, "PTM1300(0x15EB-0x7022)"},
{0x1131, 0x5405, 0xFFFF, 0xFFFF, "TriMedia TM1500(0x5405)"},
{0x1131, 0x5405, 0x1136, 0x0005, "LCP-1500(0x1136-0x0005)"},
{0x1131, 0x5406, 0xFFFF, 0xFFFF, "TriMedia TM1700(0x5406)"},
{0x1131, 0x540B, 0xFFFF, 0xFFFF, "PNX1005 Media Processor(0x540B)"},
{0x1131, 0x540B, 0x1131, 0x0020, "PNXLite PCI Demo Board(0x1131-0x0020)"},
{0x1131, 0x7130, 0xFFFF, 0xFFFF, "SAA7130 Video Broadcast Decoder(0x7130)"},
{0x1131, 0x7130, 0x0000, 0x4016, "Behold TV 401(0x0000-0x4016)"},
{0x1131, 0x7130, 0x0000, 0x4051, "Behold TV 405 FM(0x0000-0x4051)"},
{0x1131, 0x7130, 0x0000, 0x5051, "Behold TV 505 RDS(0x0000-0x5051)"},
{0x1131, 0x7130, 0x0000, 0x505B, "Behold TV 505 RDS(0x0000-0x505B)"},
{0x1131, 0x7130, 0x102B, 0x48D0, "Matrox CronosPlus(0x102B-0x48D0)"},
{0x1131, 0x7130, 0x1048, 0x226B, "ELSA EX-VISION 300TV(0x1048-0x226B)"},
{0x1131, 0x7130, 0x107D, 0x6655, "WinFast DTV1000S(0x107D-0x6655)"},
{0x1131, 0x7130, 0x1131, 0x0000, "SAA7130-based TV tuner card(0x1131-0x0000)"},
{0x1131, 0x7130, 0x1131, 0x2001, "10MOONS PCI TV CAPTURE CARD(0x1131-0x2001)"},
{0x1131, 0x7130, 0x1131, 0x2005, "Techcom (India) TV Tuner Card (SSD-TV-670)(0x1131-0x2005)"},
{0x1131, 0x7130, 0x1458, 0x9006, "GT-PS700 DVB-S tuner(0x1458-0x9006)"},
{0x1131, 0x7130, 0x1461, 0x050C, "Nagase Sangyo TransGear 3000TV(0x1461-0x050C)"},
{0x1131, 0x7130, 0x1461, 0x10FF, "AVerMedia DVD EZMaker(0x1461-0x10FF)"},
{0x1131, 0x7130, 0x1461, 0x2108, "AverMedia AverTV/305(0x1461-0x2108)"},
{0x1131, 0x7130, 0x1461, 0x2115, "AverMedia AverTV Studio 305(0x1461-0x2115)"},
{0x1131, 0x7130, 0x153B, 0x1152, "Terratec Cinergy 200 TV(0x153B-0x1152)"},
{0x1131, 0x7130, 0x185B, 0xC100, "Compro VideoMate TV PVR/FM(0x185B-0xC100)"},
{0x1131, 0x7130, 0x185B, 0xC901, "Videomate DVB-T200(0x185B-0xC901)"},
{0x1131, 0x7130, 0x5168, 0x0138, "LifeView FlyVIDEO2000(0x5168-0x0138)"},
{0x1131, 0x7130, 0x5ACE, 0x5010, "Behold TV 501(0x5ACE-0x5010)"},
{0x1131, 0x7130, 0x5ACE, 0x5050, "Behold TV 505 FM(0x5ACE-0x5050)"},
{0x1131, 0x7133, 0xFFFF, 0xFFFF, "SAA7131/SAA7133/SAA7135 Video Broadcast Decoder(0x7133)"},
{0x1131, 0x7133, 0x0000, 0x4091, "Beholder BeholdTV 409 FM(0x0000-0x4091)"},
{0x1131, 0x7133, 0x0000, 0x5071, "Behold TV 507 RDS(0x0000-0x5071)"},
{0x1131, 0x7133, 0x0000, 0x507B, "Behold TV 507 RDS(0x0000-0x507B)"},
{0x1131, 0x7133, 0x0000, 0x5201, "Behold TV Columbus(0x0000-0x5201)"},
{0x1131, 0x7133, 0x0070, 0x6701, "WinTV HVR-1110(0x0070-0x6701)"},
{0x1131, 0x7133, 0x1019, 0x4CB5, "Elitegroup ECS TVP3XP FM1236 Tuner Card (NTSC,FM)(0x1019-0x4CB5)"},
{0x1131, 0x7133, 0x1043, 0x0210, "FlyTV mini Asus Digimatrix(0x1043-0x0210)"},
{0x1131, 0x7133, 0x1043, 0x4843, "TV-FM 7133(0x1043-0x4843)"},
{0x1131, 0x7133, 0x1043, 0x4845, "TV-FM 7135(0x1043-0x4845)"},
{0x1131, 0x7133, 0x1043, 0x4862, "P7131 Dual(0x1043-0x4862)"},
{0x1131, 0x7133, 0x1043, 0x4876, "My Cinema-P7131 Hybrid(0x1043-0x4876)"},
{0x1131, 0x7133, 0x1131, 0x0000, "SAA713x-based TV tuner card(0x1131-0x0000)"},
{0x1131, 0x7133, 0x1131, 0x2001, "Proteus Pro [philips reference design](0x1131-0x2001)"},
{0x1131, 0x7133, 0x1131, 0x2018, "Tiger reference design(0x1131-0x2018)"},
{0x1131, 0x7133, 0x1131, 0x4EE9, "MonsterTV Mobile(0x1131-0x4EE9)"},
{0x1131, 0x7133, 0x1131, 0x7133, "Pinnacle PCTV 301i(0x1131-0x7133)"},
{0x1131, 0x7133, 0x11BD, 0x002B, "PCTV Stereo(0x11BD-0x002B)"},
{0x1131, 0x7133, 0x11BD, 0x002E, "PCTV 110i (saa7133)(0x11BD-0x002E)"},
{0x1131, 0x7133, 0x12AB, 0x0800, "PURPLE TV(0x12AB-0x0800)"},
{0x1131, 0x7133, 0x13C2, 0x2804, "Technotrend Budget T-3000 Hybrid(0x13C2-0x2804)"},
{0x1131, 0x7133, 0x1421, 0x0335, "Instant TV DVB-T Cardbus(0x1421-0x0335)"},
{0x1131, 0x7133, 0x1421, 0x1370, "Instant TV (saa7135)(0x1421-0x1370)"},
{0x1131, 0x7133, 0x1435, 0x7330, "VFG7330(0x1435-0x7330)"},
{0x1131, 0x7133, 0x1435, 0x7350, "VFG7350(0x1435-0x7350)"},
{0x1131, 0x7133, 0x1458, 0x9001, "GC-PTV-TAF Hybrid TV card(0x1458-0x9001)"},
{0x1131, 0x7133, 0x1458, 0x9002, "GT-PTV-TAF-RH DVB-T/Analog TV/FM tuner(0x1458-0x9002)"},
{0x1131, 0x7133, 0x1458, 0x9003, "GT-PTV-AF-RH Analog TV/FM tuner(0x1458-0x9003)"},
{0x1131, 0x7133, 0x1458, 0x9004, "GT-P8000 DVB-T/Analog TV/FM tuner(0x1458-0x9004)"},
{0x1131, 0x7133, 0x1458, 0x9005, "GT-P6000 Analog TV/FM tuner(0x1458-0x9005)"},
{0x1131, 0x7133, 0x1458, 0x9008, "GT-P5100 Analog TV tuner(0x1458-0x9008)"},
{0x1131, 0x7133, 0x1461, 0x1044, "AVerTVHD MCE A180(0x1461-0x1044)"},
{0x1131, 0x7133, 0x1461, 0x4836, "M10D Hybrid DVBT(0x1461-0x4836)"},
{0x1131, 0x7133, 0x1461, 0x861E, "M105 PAL/SECAM/NTSC/FM Tuner(0x1461-0x861E)"},
{0x1131, 0x7133, 0x1461, 0xA14B, "AVerTV Studio 509(0x1461-0xA14B)"},
{0x1131, 0x7133, 0x1461, 0xA836, "M115 DVB-T, PAL/SECAM/NTSC Tuner(0x1461-0xA836)"},
{0x1131, 0x7133, 0x1461, 0xF01D, "DVB-T Super 007(0x1461-0xF01D)"},
{0x1131, 0x7133, 0x1461, 0xF31F, "Avermedia AVerTV GO 007 FM(0x1461-0xF31F)"},
{0x1131, 0x7133, 0x1461, 0xF936, "Hybrid+FM PCI (rev A16D)(0x1461-0xF936)"},
{0x1131, 0x7133, 0x1462, 0x6231, "TV@nywhere Plus(0x1462-0x6231)"},
{0x1131, 0x7133, 0x1489, 0x0214, "LifeView FlyTV Platinum FM(0x1489-0x0214)"},
{0x1131, 0x7133, 0x14C0, 0x1212, "LifeView FlyTV Platinum Mini2(0x14C0-0x1212)"},
{0x1131, 0x7133, 0x153B, 0x1160, "Cinergy 250 PCI TV(0x153B-0x1160)"},
{0x1131, 0x7133, 0x153B, 0x1162, "Terratec Cinergy 400 mobile(0x153B-0x1162)"},
{0x1131, 0x7133, 0x17DE, 0x7256, "PlusTV All In One PI610 card(0x17DE-0x7256)"},
{0x1131, 0x7133, 0x17DE, 0x7350, "ATSC 110 Digital / Analog HDTV Tuner(0x17DE-0x7350)"},
{0x1131, 0x7133, 0x17DE, 0x7352, "ATSC 115 Digital / Analog HDTV Tuner(0x17DE-0x7352)"},
{0x1131, 0x7133, 0x185B, 0xC100, "VideoMate TV(0x185B-0xC100)"},
{0x1131, 0x7133, 0x185B, 0xC900, "VideoMate T750(0x185B-0xC900)"},
{0x1131, 0x7133, 0x5168, 0x0306, "LifeView FlyDVB-T DUO(0x5168-0x0306)"},
{0x1131, 0x7133, 0x5168, 0x0319, "LifeView FlyDVB Trio(0x5168-0x0319)"},
{0x1131, 0x7133, 0x5168, 0x0502, "LifeView FlyDVB-T Duo CardBus(0x5168-0x0502)"},
{0x1131, 0x7133, 0x5168, 0x0520, "LifeView FlyDVB Trio CardBus(0x5168-0x0520)"},
{0x1131, 0x7133, 0x5168, 0x1502, "LifeView FlyTV CardBus(0x5168-0x1502)"},
{0x1131, 0x7133, 0x5168, 0x2502, "LifeView FlyDVB-T CardBus(0x5168-0x2502)"},
{0x1131, 0x7133, 0x5168, 0x2520, "LifeView FlyDVB-S Duo CardBus(0x5168-0x2520)"},
{0x1131, 0x7133, 0x5168, 0x3502, "LifeView FlyDVB-T Hybrid CardBus(0x5168-0x3502)"},
{0x1131, 0x7133, 0x5168, 0x3520, "LifeView FlyDVB Trio N CardBus(0x5168-0x3520)"},
{0x1131, 0x7133, 0x5ACE, 0x5030, "Behold TV 503 FM(0x5ACE-0x5030)"},
{0x1131, 0x7133, 0x5ACE, 0x5090, "Behold TV 509 FM(0x5ACE-0x5090)"},
{0x1131, 0x7133, 0x5ACE, 0x6090, "Behold TV 609 FM(0x5ACE-0x6090)"},
{0x1131, 0x7133, 0x5ACE, 0x6091, "Behold TV 609 FM(0x5ACE-0x6091)"},
{0x1131, 0x7133, 0x5ACE, 0x6092, "Behold TV 609 RDS(0x5ACE-0x6092)"},
{0x1131, 0x7133, 0x5ACE, 0x6093, "Behold TV 609 RDS(0x5ACE-0x6093)"},
{0x1131, 0x7133, 0x5ACE, 0x6190, "Behold TV M6(0x5ACE-0x6190)"},
{0x1131, 0x7133, 0x5ACE, 0x6191, "Behold TV M63(0x5ACE-0x6191)"},
{0x1131, 0x7133, 0x5ACE, 0x6193, "Behold TV M6 Extra(0x5ACE-0x6193)"},
{0x1131, 0x7133, 0x5ACE, 0x6290, "Behold TV H6(0x5ACE-0x6290)"},
{0x1131, 0x7133, 0x5ACE, 0x7090, "Behold TV A7(0x5ACE-0x7090)"},
{0x1131, 0x7133, 0x5ACE, 0x7150, "Behold TV H75(0x5ACE-0x7150)"},
{0x1131, 0x7133, 0x5ACE, 0x7151, "Behold TV H75(0x5ACE-0x7151)"},
{0x1131, 0x7133, 0x5ACE, 0x7190, "Behold TV H7(0x5ACE-0x7190)"},
{0x1131, 0x7133, 0x5ACE, 0x7191, "Behold TV H7(0x5ACE-0x7191)"},
{0x1131, 0x7133, 0x5ACE, 0x7290, "Behold TV T7(0x5ACE-0x7290)"},
{0x1131, 0x7133, 0x5ACE, 0x7591, "Behold TV X7(0x5ACE-0x7591)"},
{0x1131, 0x7133, 0x5ACE, 0x7595, "Behold TV X7(0x5ACE-0x7595)"},
{0x1131, 0x7134, 0xFFFF, 0xFFFF, "SAA7134/SAA7135HL Video Broadcast Decoder(0x7134)"},
{0x1131, 0x7134, 0x0000, 0x4036, "Behold TV 403(0x0000-0x4036)"},
{0x1131, 0x7134, 0x0000, 0x4037, "Behold TV 403 FM(0x0000-0x4037)"},
{0x1131, 0x7134, 0x0000, 0x4071, "Behold TV 407 FM(0x0000-0x4071)"},
{0x1131, 0x7134, 0x1019, 0x4CB4, "Elitegroup ECS TVP3XP FM1216 Tuner Card(PAL-BG,FM)(0x1019-0x4CB4)"},
{0x1131, 0x7134, 0x1043, 0x0210, "Digimatrix TV(0x1043-0x0210)"},
{0x1131, 0x7134, 0x1043, 0x4840, "TV-FM 7134(0x1043-0x4840)"},
{0x1131, 0x7134, 0x1043, 0x4842, "TV-FM 7134(0x1043-0x4842)"},
{0x1131, 0x7134, 0x1131, 0x0000, "SAA713x-based TV tuner card(0x1131-0x0000)"},
{0x1131, 0x7134, 0x1131, 0x2004, "EUROPA V3 reference design(0x1131-0x2004)"},
{0x1131, 0x7134, 0x1131, 0x4E85, "SKNet Monster TV(0x1131-0x4E85)"},
{0x1131, 0x7134, 0x1131, 0x6752, "EMPRESS(0x1131-0x6752)"},
{0x1131, 0x7134, 0x11BD, 0x002B, "PCTV Stereo(0x11BD-0x002B)"},
{0x1131, 0x7134, 0x11BD, 0x002D, "PCTV 300i DVB-T + PAL(0x11BD-0x002D)"},
{0x1131, 0x7134, 0x1461, 0x2C00, "AverTV Hybrid+FM PCI(0x1461-0x2C00)"},
{0x1131, 0x7134, 0x1461, 0x9715, "AVerTV Studio 307(0x1461-0x9715)"},
{0x1131, 0x7134, 0x1461, 0xA70A, "Avermedia AVerTV 307(0x1461-0xA70A)"},
{0x1131, 0x7134, 0x1461, 0xA70B, "AverMedia M156 / Medion 2819(0x1461-0xA70B)"},
{0x1131, 0x7134, 0x1461, 0xD6EE, "Cardbus TV/Radio (E500)(0x1461-0xD6EE)"},
{0x1131, 0x7134, 0x1471, 0xB7E9, "AVerTV Cardbus plus(0x1471-0xB7E9)"},
{0x1131, 0x7134, 0x153B, 0x1142, "Terratec Cinergy 400 TV(0x153B-0x1142)"},
{0x1131, 0x7134, 0x153B, 0x1143, "Terratec Cinergy 600 TV(0x153B-0x1143)"},
{0x1131, 0x7134, 0x153B, 0x1158, "Terratec Cinergy 600 TV MK3(0x153B-0x1158)"},
{0x1131, 0x7134, 0x1540, 0x9524, "ProVideo PV952(0x1540-0x9524)"},
{0x1131, 0x7134, 0x16BE, 0x0003, "Medion 7134(0x16BE-0x0003)"},
{0x1131, 0x7134, 0x185B, 0xC200, "Compro VideoMate Gold+ Pal(0x185B-0xC200)"},
{0x1131, 0x7134, 0x185B, 0xC900, "Videomate DVB-T300(0x185B-0xC900)"},
{0x1131, 0x7134, 0x1894, 0xA006, "KNC One TV-Station DVR(0x1894-0xA006)"},
{0x1131, 0x7134, 0x1894, 0xFE01, "KNC One TV-Station RDS / Typhoon TV Tuner RDS(0x1894-0xFE01)"},
{0x1131, 0x7134, 0x5168, 0x0138, "FLY TV PRIME 34FM(0x5168-0x0138)"},
{0x1131, 0x7134, 0x5168, 0x0300, "FlyDVB-S(0x5168-0x0300)"},
{0x1131, 0x7134, 0x5ACE, 0x5070, "Behold TV 507 FM(0x5ACE-0x5070)"},
{0x1131, 0x7134, 0x5ACE, 0x6070, "Behold TV 607 FM(0x5ACE-0x6070)"},
{0x1131, 0x7134, 0x5ACE, 0x6071, "Behold TV 607 FM(0x5ACE-0x6071)"},
{0x1131, 0x7134, 0x5ACE, 0x6072, "Behold TV 607 RDS(0x5ACE-0x6072)"},
{0x1131, 0x7134, 0x5ACE, 0x6073, "Behold TV 607 RDS(0x5ACE-0x6073)"},
{0x1131, 0x7145, 0xFFFF, 0xFFFF, "SAA7145(0x7145)"},
{0x1131, 0x7146, 0xFFFF, 0xFFFF, "SAA7146(0x7146)"},
{0x1131, 0x7146, 0x110A, 0x0000, "Fujitsu/Siemens DVB-C card rev1.5(0x110A-0x0000)"},
{0x1131, 0x7146, 0x110A, 0xFFFF, "Fujitsu/Siemens DVB-C card rev1.5(0x110A-0xFFFF)"},
{0x1131, 0x7146, 0x1124, 0x2581, "Leutron Vision PicPort(0x1124-0x2581)"},
{0x1131, 0x7146, 0x1131, 0x4F56, "KNC1 DVB-S Budget(0x1131-0x4F56)"},
{0x1131, 0x7146, 0x1131, 0x4F60, "Fujitsu-Siemens Activy DVB-S Budget Rev AL(0x1131-0x4F60)"},
{0x1131, 0x7146, 0x1131, 0x4F61, "Activy DVB-S Budget Rev GR(0x1131-0x4F61)"},
{0x1131, 0x7146, 0x1131, 0x5F61, "Activy DVB-T Budget(0x1131-0x5F61)"},
{0x1131, 0x7146, 0x114B, 0x2003, "DVRaptor Video Edit/Capture Card(0x114B-0x2003)"},
{0x1131, 0x7146, 0x1159, 0x0040, "MuTech M-Vision 500 (MV-500 rev. E)(0x1159-0x0040)"},
{0x1131, 0x7146, 0x1159, 0x0050, "MuTech M-Vision 500 (MV-500 rev. F)(0x1159-0x0050)"},
{0x1131, 0x7146, 0x11BD, 0x0006, "DV500 Overlay(0x11BD-0x0006)"},
{0x1131, 0x7146, 0x11BD, 0x000A, "DV500 Overlay(0x11BD-0x000A)"},
{0x1131, 0x7146, 0x11BD, 0x000F, "DV500 Overlay(0x11BD-0x000F)"},
{0x1131, 0x7146, 0x13C2, 0x0000, "Siemens/Technotrend/Hauppauge DVB card rev1.3 or rev1.5(0x13C2-0x0000)"},
{0x1131, 0x7146, 0x13C2, 0x0001, "Technotrend/Hauppauge DVB card rev1.3 or rev1.6(0x13C2-0x0001)"},
{0x1131, 0x7146, 0x13C2, 0x0002, "Technotrend/Hauppauge DVB card rev2.1(0x13C2-0x0002)"},
{0x1131, 0x7146, 0x13C2, 0x0003, "Technotrend/Hauppauge DVB card rev2.1(0x13C2-0x0003)"},
{0x1131, 0x7146, 0x13C2, 0x0004, "Technotrend/Hauppauge DVB card rev2.1(0x13C2-0x0004)"},
{0x1131, 0x7146, 0x13C2, 0x0006, "Technotrend/Hauppauge DVB card rev1.3 or rev1.6(0x13C2-0x0006)"},
{0x1131, 0x7146, 0x13C2, 0x0008, "Technotrend/Hauppauge DVB-T(0x13C2-0x0008)"},
{0x1131, 0x7146, 0x13C2, 0x000A, "Octal/Technotrend DVB-C for iTV(0x13C2-0x000A)"},
{0x1131, 0x7146, 0x13C2, 0x000E, "Technotrend/Hauppauge DVB card rev2.3(0x13C2-0x000E)"},
{0x1131, 0x7146, 0x13C2, 0x1003, "Technotrend-Budget/Hauppauge WinTV-NOVA-S DVB card(0x13C2-0x1003)"},
{0x1131, 0x7146, 0x13C2, 0x1004, "Technotrend-Budget/Hauppauge WinTV-NOVA-C DVB card(0x13C2-0x1004)"},
{0x1131, 0x7146, 0x13C2, 0x1005, "Technotrend-Budget/Hauppauge WinTV-NOVA-T DVB card(0x13C2-0x1005)"},
{0x1131, 0x7146, 0x13C2, 0x100C, "Technotrend-Budget/Hauppauge WinTV-NOVA-CI DVB card(0x13C2-0x100C)"},
{0x1131, 0x7146, 0x13C2, 0x100F, "Technotrend-Budget/Hauppauge WinTV-NOVA-CI DVB card(0x13C2-0x100F)"},
{0x1131, 0x7146, 0x13C2, 0x1010, "DVB C-1500(0x13C2-0x1010)"},
{0x1131, 0x7146, 0x13C2, 0x1011, "Technotrend-Budget/Hauppauge WinTV-NOVA-T DVB card(0x13C2-0x1011)"},
{0x1131, 0x7146, 0x13C2, 0x1012, "DVB T-1500(0x13C2-0x1012)"},
{0x1131, 0x7146, 0x13C2, 0x1013, "SATELCO Multimedia DVB(0x13C2-0x1013)"},
{0x1131, 0x7146, 0x13C2, 0x1016, "WinTV-NOVA-SE DVB card(0x13C2-0x1016)"},
{0x1131, 0x7146, 0x13C2, 0x1018, "DVB S-1401(0x13C2-0x1018)"},
{0x1131, 0x7146, 0x13C2, 0x1019, "S2-3200(0x13C2-0x1019)"},
{0x1131, 0x7146, 0x13C2, 0x1102, "Technotrend/Hauppauge DVB card rev2.1(0x13C2-0x1102)"},
{0x1131, 0x7146, 0x153B, 0x1155, "Cinergy 1200 DVB-S(0x153B-0x1155)"},
{0x1131, 0x7146, 0x153B, 0x1156, "Cinergy 1200 DVB-C(0x153B-0x1156)"},
{0x1131, 0x7146, 0x153B, 0x1157, "Cinergy 1200 DVB-T(0x153B-0x1157)"},
{0x1131, 0x7146, 0x153B, 0x1176, "Cinergy 1200 DVB-C (MK3)(0x153B-0x1176)"},
{0x1131, 0x7146, 0x1894, 0x0020, "KNC One DVB-C V1.0(0x1894-0x0020)"},
{0x1131, 0x7146, 0x1894, 0x0023, "TV-Station DVB-C plus(0x1894-0x0023)"},
{0x1131, 0x7146, 0x1894, 0x0054, "TV-Station DVB-S(0x1894-0x0054)"},
{0x1131, 0x7160, 0xFFFF, 0xFFFF, "SAA7160(0x7160)"},
{0x1131, 0x7160, 0x1458, 0x9009, "E8000 DVB-T/Analog TV/FM tuner(0x1458-0x9009)"},
{0x1131, 0x7160, 0x1461, 0x1455, "AVerTV Hybrid Speedy PCI-E (H788)(0x1461-0x1455)"},
{0x1131, 0x7162, 0xFFFF, 0xFFFF, "SAA7162(0x7162)"},
{0x1131, 0x7162, 0x11BD, 0x0101, "Pinnacle PCTV 7010iX TV Card(0x11BD-0x0101)"},
{0x1131, 0x7164, 0xFFFF, 0xFFFF, "SAA7164(0x7164)"},
{0x1131, 0x7164, 0x0070, 0x8800, "WinTV HVR-2250(0x0070-0x8800)"},
{0x1131, 0x7164, 0x0070, 0x8810, "WinTV HVR-2250(0x0070-0x8810)"},
{0x1131, 0x7164, 0x0070, 0x8851, "WinTV HVR-2250(0x0070-0x8851)"},
{0x1131, 0x7164, 0x0070, 0x8853, "WinTV HVR-2250(0x0070-0x8853)"},
{0x1131, 0x7164, 0x0070, 0x8880, "WinTV HVR-2250(0x0070-0x8880)"},
{0x1131, 0x7164, 0x0070, 0x8891, "WinTV HVR-2250(0x0070-0x8891)"},
{0x1131, 0x7164, 0x0070, 0x88A0, "WinTV HVR-2250(0x0070-0x88A0)"},
{0x1131, 0x7164, 0x0070, 0x88A1, "WinTV HVR-2250(0x0070-0x88A1)"},
{0x1131, 0x7164, 0x0070, 0x8900, "WinTV HVR-2200(0x0070-0x8900)"},
{0x1131, 0x7164, 0x0070, 0x8901, "WinTV HVR-2200(0x0070-0x8901)"},
{0x1131, 0x7164, 0x0070, 0x8940, "WinTV HVR-2200 (submodel 89619)(0x0070-0x8940)"},
{0x1131, 0x7164, 0x0070, 0x8951, "WinTV HVR-2200(0x0070-0x8951)"},
{0x1131, 0x7164, 0x0070, 0x8953, "WinTV HVR-2200(0x0070-0x8953)"},
{0x1131, 0x7164, 0x0070, 0x8980, "WinTV HVR-2200(0x0070-0x8980)"},
{0x1131, 0x7164, 0x0070, 0x8991, "WinTV HVR-2200(0x0070-0x8991)"},
{0x1131, 0x7164, 0x0070, 0x8993, "WinTV HVR-2200(0x0070-0x8993)"},
{0x1131, 0x7164, 0x0070, 0x89A0, "WinTV HVR-2200(0x0070-0x89A0)"},
{0x1131, 0x7164, 0x0070, 0x89A1, "WinTV HVR-2200(0x0070-0x89A1)"},
{0x1131, 0x7164, 0x0070, 0xF120, "WinTV HVR-2205(0x0070-0xF120)"},
{0x1131, 0x7164, 0x0070, 0xF123, "WinTV HVR-2215(0x0070-0xF123)"},
{0x1131, 0x7231, 0xFFFF, 0xFFFF, "SAA7231(0x7231)"},
{0x1131, 0x7231, 0x5ACE, 0x8000, "Behold TV H8(0x5ACE-0x8000)"},
{0x1131, 0x7231, 0x5ACE, 0x8001, "Behold TV H8(0x5ACE-0x8001)"},
{0x1131, 0x7231, 0x5ACE, 0x8050, "Behold TV H85(0x5ACE-0x8050)"},
{0x1131, 0x7231, 0x5ACE, 0x8051, "Behold TV H85(0x5ACE-0x8051)"},
{0x1131, 0x7231, 0x5ACE, 0x8100, "Behold TV A8(0x5ACE-0x8100)"},
{0x1131, 0x7231, 0x5ACE, 0x8101, "Behold TV A8(0x5ACE-0x8101)"},
{0x1131, 0x7231, 0x5ACE, 0x8150, "Behold TV A85(0x5ACE-0x8150)"},
{0x1131, 0x7231, 0x5ACE, 0x8151, "Behold TV A85(0x5ACE-0x8151)"},
{0x1131, 0x7231, 0x5ACE, 0x8201, "Behold TV T8(0x5ACE-0x8201)"},
{0x1131, 0x9730, 0xFFFF, 0xFFFF, "SAA9730 Integrated Multimedia and Peripheral Controller(0x9730)"},
{0x1131, 0x9730, 0x1131, 0x0000, "Integrated Multimedia and Peripheral Controller(0x1131-0x0000)"},
}; /* pci_vid_1131[] */

static pci_id_t const pci_vid_1132[] = {
{0x1132, 0xFFFF, 0xFFFF, 0xFFFF, "Mitel Corp.(0x1132)"},
}; /* pci_vid_1132[] */

static pci_id_t const pci_vid_1133[] = {
{0x1133, 0xFFFF, 0xFFFF, 0xFFFF, "Dialogic Corporation(0x1133)"},
{0x1133, 0x7701, 0xFFFF, 0xFFFF, "Eiconcard C90(0x7701)"},
{0x1133, 0x7711, 0xFFFF, 0xFFFF, "Eiconcard C91(0x7711)"},
{0x1133, 0x7901, 0xFFFF, 0xFFFF, "EiconCard S90(0x7901)"},
{0x1133, 0x7902, 0xFFFF, 0xFFFF, "EiconCard S90(0x7902)"},
{0x1133, 0x7911, 0xFFFF, 0xFFFF, "EiconCard S91(0x7911)"},
{0x1133, 0x7912, 0xFFFF, 0xFFFF, "EiconCard S91(0x7912)"},
{0x1133, 0x7921, 0xFFFF, 0xFFFF, "Eiconcard S92(0x7921)"},
{0x1133, 0x7941, 0xFFFF, 0xFFFF, "EiconCard S94(0x7941)"},
{0x1133, 0x7942, 0xFFFF, 0xFFFF, "EiconCard S94(0x7942)"},
{0x1133, 0x7943, 0xFFFF, 0xFFFF, "EiconCard S94(0x7943)"},
{0x1133, 0x7944, 0xFFFF, 0xFFFF, "EiconCard S94(0x7944)"},
{0x1133, 0x7945, 0xFFFF, 0xFFFF, "Eiconcard S94(0x7945)"},
{0x1133, 0x7948, 0xFFFF, 0xFFFF, "Eiconcard S94 64bit/66MHz(0x7948)"},
{0x1133, 0x9711, 0xFFFF, 0xFFFF, "Eiconcard S91 V2(0x9711)"},
{0x1133, 0x9911, 0xFFFF, 0xFFFF, "Eiconcard S91 V2(0x9911)"},
{0x1133, 0x9941, 0xFFFF, 0xFFFF, "Eiconcard S94 V2(0x9941)"},
{0x1133, 0x9A41, 0xFFFF, 0xFFFF, "Eiconcard S94 PCIe(0x9A41)"},
{0x1133, 0xB921, 0xFFFF, 0xFFFF, "EiconCard P92(0xB921)"},
{0x1133, 0xB922, 0xFFFF, 0xFFFF, "EiconCard P92(0xB922)"},
{0x1133, 0xB923, 0xFFFF, 0xFFFF, "EiconCard P92(0xB923)"},
{0x1133, 0xE001, 0xFFFF, 0xFFFF, "Diva Pro 2.0 S/T(0xE001)"},
{0x1133, 0xE002, 0xFFFF, 0xFFFF, "Diva 2.0 S/T PCI(0xE002)"},
{0x1133, 0xE003, 0xFFFF, 0xFFFF, "Diva Pro 2.0 U(0xE003)"},
{0x1133, 0xE004, 0xFFFF, 0xFFFF, "Diva 2.0 U PCI(0xE004)"},
{0x1133, 0xE005, 0xFFFF, 0xFFFF, "Diva 2.01 S/T PCI(0xE005)"},
{0x1133, 0xE006, 0xFFFF, 0xFFFF, "Diva CT S/T PCI(0xE006)"},
{0x1133, 0xE007, 0xFFFF, 0xFFFF, "Diva CT U PCI(0xE007)"},
{0x1133, 0xE008, 0xFFFF, 0xFFFF, "Diva CT Lite S/T PCI(0xE008)"},
{0x1133, 0xE009, 0xFFFF, 0xFFFF, "Diva CT Lite U PCI(0xE009)"},
{0x1133, 0xE00A, 0xFFFF, 0xFFFF, "Diva ISDN+V.90 PCI(0xE00A)"},
{0x1133, 0xE00B, 0xFFFF, 0xFFFF, "Diva ISDN PCI 2.02(0xE00B)"},
{0x1133, 0xE00C, 0xFFFF, 0xFFFF, "Diva 2.02 PCI U(0xE00C)"},
{0x1133, 0xE00D, 0xFFFF, 0xFFFF, "Diva Pro 3.0 PCI(0xE00D)"},
{0x1133, 0xE00E, 0xFFFF, 0xFFFF, "Diva ISDN+CT S/T PCI Rev 2(0xE00E)"},
{0x1133, 0xE010, 0xFFFF, 0xFFFF, "Diva Server BRI-2M PCI(0xE010)"},
{0x1133, 0xE010, 0x110A, 0x0021, "Fujitsu Siemens ISDN S0(0x110A-0x0021)"},
{0x1133, 0xE011, 0xFFFF, 0xFFFF, "Diva Server BRI S/T Rev 2(0xE011)"},
{0x1133, 0xE012, 0xFFFF, 0xFFFF, "Diva Server 4BRI-8M PCI(0xE012)"},
{0x1133, 0xE013, 0xFFFF, 0xFFFF, "4BRI(0xE013)"},
{0x1133, 0xE013, 0x1133, 0x1300, "Diva V-4BRI-8 PCI v2(0x1133-0x1300)"},
{0x1133, 0xE013, 0x1133, 0xE013, "Diva 4BRI-8 PCI v2(0x1133-0xE013)"},
{0x1133, 0xE014, 0xFFFF, 0xFFFF, "Diva Server PRI-30M PCI(0xE014)"},
{0x1133, 0xE015, 0xFFFF, 0xFFFF, "Diva PRI PCI v2(0xE015)"},
{0x1133, 0xE016, 0xFFFF, 0xFFFF, "Diva Server Voice 4BRI PCI(0xE016)"},
{0x1133, 0xE017, 0xFFFF, 0xFFFF, "Diva Server Voice 4BRI Rev 2(0xE017)"},
{0x1133, 0xE017, 0x1133, 0xE017, "Diva Server Voice 4BRI-8M 2.0 PCI(0x1133-0xE017)"},
{0x1133, 0xE018, 0xFFFF, 0xFFFF, "BRI(0xE018)"},
{0x1133, 0xE018, 0x1133, 0x1800, "Diva V-BRI-2 PCI v2(0x1133-0x1800)"},
{0x1133, 0xE018, 0x1133, 0xE018, "Diva BRI-2 PCI v2(0x1133-0xE018)"},
{0x1133, 0xE019, 0xFFFF, 0xFFFF, "Diva Server Voice PRI Rev 2(0xE019)"},
{0x1133, 0xE019, 0x1133, 0xE019, "Diva Server Voice PRI 2.0 PCI(0x1133-0xE019)"},
{0x1133, 0xE01A, 0xFFFF, 0xFFFF, "Diva BRI-2FX PCI v2(0xE01A)"},
{0x1133, 0xE01B, 0xFFFF, 0xFFFF, "Diva Server Voice BRI-2M 2.0 PCI(0xE01B)"},
{0x1133, 0xE01B, 0x1133, 0xE01B, "Diva Server Voice BRI-2M 2.0 PCI(0x1133-0xE01B)"},
{0x1133, 0xE01C, 0xFFFF, 0xFFFF, "PRI(0xE01C)"},
{0x1133, 0xE01C, 0x1133, 0x1C01, "Diva PRI/E1/T1-8 PCI v3(0x1133-0x1C01)"},
{0x1133, 0xE01C, 0x1133, 0x1C02, "Diva PRI/T1-24 PCI(e) v3(0x1133-0x1C02)"},
{0x1133, 0xE01C, 0x1133, 0x1C03, "Diva PRI/E1-30 PCI(e) v3(0x1133-0x1C03)"},
{0x1133, 0xE01C, 0x1133, 0x1C04, "Diva PRI/E1/T1-CTI PCI(e) v3(0x1133-0x1C04)"},
{0x1133, 0xE01C, 0x1133, 0x1C05, "Diva V-PRI/T1-24 PCI(e) v3(0x1133-0x1C05)"},
{0x1133, 0xE01C, 0x1133, 0x1C06, "Diva V-PRI/E1-30 PCI(e) v3(0x1133-0x1C06)"},
{0x1133, 0xE01C, 0x1133, 0x1C07, "Diva Server PRI/E1/T1-8 Cornet NQ(0x1133-0x1C07)"},
{0x1133, 0xE01C, 0x1133, 0x1C08, "Diva Server PRI/T1-24 Cornet NQ(0x1133-0x1C08)"},
{0x1133, 0xE01C, 0x1133, 0x1C09, "Diva Server PRI/E1-30 Cornet NQ(0x1133-0x1C09)"},
{0x1133, 0xE01C, 0x1133, 0x1C0A, "Diva Server PRI/E1/T1 Cornet NQ(0x1133-0x1C0A)"},
{0x1133, 0xE01C, 0x1133, 0x1C0B, "Diva Server V-PRI/T1-24 Cornet NQ(0x1133-0x1C0B)"},
{0x1133, 0xE01C, 0x1133, 0x1C0C, "Diva Server V-PRI/E1-30 Cornet NQ(0x1133-0x1C0C)"},
{0x1133, 0xE01E, 0xFFFF, 0xFFFF, "2PRI(0xE01E)"},
{0x1133, 0xE01E, 0x1133, 0x1E01, "Diva 2PRI/E1/T1-60 PCI v1(0x1133-0x1E01)"},
{0x1133, 0xE01E, 0x1133, 0xE01E, "Diva V-2PRI/E1/T1-60 PCI v1(0x1133-0xE01E)"},
{0x1133, 0xE020, 0xFFFF, 0xFFFF, "4PRI(0xE020)"},
{0x1133, 0xE020, 0x1133, 0x2001, "Diva 4PRI/E1/T1-120 PCI v1(0x1133-0x2001)"},
{0x1133, 0xE020, 0x1133, 0xE020, "Diva V-4PRI/E1/T1-120 PCI v1(0x1133-0xE020)"},
{0x1133, 0xE022, 0xFFFF, 0xFFFF, "Analog-2(0xE022)"},
{0x1133, 0xE022, 0x1133, 0x2200, "Diva V-Analog-2 PCI v1(0x1133-0x2200)"},
{0x1133, 0xE022, 0x1133, 0xE022, "Diva Analog-2 PCI v1(0x1133-0xE022)"},
{0x1133, 0xE024, 0xFFFF, 0xFFFF, "Analog-4(0xE024)"},
{0x1133, 0xE024, 0x1133, 0x2400, "Diva V-Analog-4 PCI v1(0x1133-0x2400)"},
{0x1133, 0xE024, 0x1133, 0xE024, "Diva Analog-4 PCI v1(0x1133-0xE024)"},
{0x1133, 0xE028, 0xFFFF, 0xFFFF, "Analog-8(0xE028)"},
{0x1133, 0xE028, 0x1133, 0x2800, "Diva V-Analog-8 PCI v1(0x1133-0x2800)"},
{0x1133, 0xE028, 0x1133, 0xE028, "Diva Analog-8 PCI v1(0x1133-0xE028)"},
{0x1133, 0xE02A, 0xFFFF, 0xFFFF, "Diva IPM-300 PCI v1(0xE02A)"},
{0x1133, 0xE02C, 0xFFFF, 0xFFFF, "Diva IPM-600 PCI v1(0xE02C)"},
{0x1133, 0xE02E, 0xFFFF, 0xFFFF, "4BRI(0xE02E)"},
{0x1133, 0xE02E, 0x1133, 0x2E01, "Diva V-4BRI-8 PCIe v2(0x1133-0x2E01)"},
{0x1133, 0xE02E, 0x1133, 0xE02E, "Diva 4BRI-8 PCIe v2(0x1133-0xE02E)"},
{0x1133, 0xE032, 0xFFFF, 0xFFFF, "BRI(0xE032)"},
{0x1133, 0xE032, 0x1133, 0x3201, "Diva V-BRI-2 PCIe v2(0x1133-0x3201)"},
{0x1133, 0xE032, 0x1133, 0xE032, "Diva BRI-2 PCIe v2(0x1133-0xE032)"},
{0x1133, 0xE034, 0xFFFF, 0xFFFF, "Diva BRI-CTI PCI v2(0xE034)"},
}; /* pci_vid_1133[] */

static pci_id_t const pci_vid_1134[] = {
{0x1134, 0xFFFF, 0xFFFF, 0xFFFF, "Mercury Computer Systems(0x1134)"},
{0x1134, 0x0001, 0xFFFF, 0xFFFF, "Raceway Bridge(0x0001)"},
{0x1134, 0x0002, 0xFFFF, 0xFFFF, "Dual PCI to RapidIO Bridge(0x0002)"},
{0x1134, 0x000B, 0xFFFF, 0xFFFF, "POET Serial RapidIO Bridge(0x000B)"},
{0x1134, 0x000D, 0xFFFF, 0xFFFF, "POET PSDMS Device(0x000D)"},
}; /* pci_vid_1134[] */

static pci_id_t const pci_vid_1135[] = {
{0x1135, 0xFFFF, 0xFFFF, 0xFFFF, "FUJIFILM Business Innovation Corp.(0x1135)"},
{0x1135, 0x0001, 0xFFFF, 0xFFFF, "Printer controller(0x0001)"},
}; /* pci_vid_1135[] */

static pci_id_t const pci_vid_1136[] = {
{0x1136, 0xFFFF, 0xFFFF, 0xFFFF, "Momentum Data Systems(0x1136)"},
{0x1136, 0x0002, 0xFFFF, 0xFFFF, "PCI-JTAG(0x0002)"},
}; /* pci_vid_1136[] */

static pci_id_t const pci_vid_1137[] = {
{0x1137, 0xFFFF, 0xFFFF, 0xFFFF, "Cisco Systems Inc(0x1137)"},
{0x1137, 0x0023, 0xFFFF, 0xFFFF, "VIC 81 PCIe Upstream Port(0x0023)"},
{0x1137, 0x0040, 0xFFFF, 0xFFFF, "VIC PCIe Upstream Port(0x0040)"},
{0x1137, 0x0040, 0x1137, 0x004F, "VIC 1280 Dual 40Gb Mezzanine(0x1137-0x004F)"},
{0x1137, 0x0040, 0x1137, 0x0084, "VIC 1240 Dual 40Gb MLOM(0x1137-0x0084)"},
{0x1137, 0x0040, 0x1137, 0x0085, "VIC 1225 Dual 10Gb SFP+ PCIe(0x1137-0x0085)"},
{0x1137, 0x0040, 0x1137, 0x00CD, "VIC 1285 Dual 40Gb QSFP+ PCIe(0x1137-0x00CD)"},
{0x1137, 0x0040, 0x1137, 0x00CE, "VIC 1225T Dual 10GBaseT PCIe(0x1137-0x00CE)"},
{0x1137, 0x0040, 0x1137, 0x012A, "VIC M4308 Dual 40Gb(0x1137-0x012A)"},
{0x1137, 0x0040, 0x1137, 0x012C, "VIC 1340 Dual 40Gb MLOM(0x1137-0x012C)"},
{0x1137, 0x0040, 0x1137, 0x012E, "VIC 1227 Dual 10Gb SFP+ PCIe(0x1137-0x012E)"},
{0x1137, 0x0040, 0x1137, 0x0137, "VIC 1380 Dual 40Gb Mezzanine(0x1137-0x0137)"},
{0x1137, 0x0040, 0x1137, 0x014D, "VIC 1385 Dual 40Gb PCIe(0x1137-0x014D)"},
{0x1137, 0x0041, 0xFFFF, 0xFFFF, "VIC PCIe Downstream Port(0x0041)"},
{0x1137, 0x0042, 0xFFFF, 0xFFFF, "VIC Management Controller(0x0042)"},
{0x1137, 0x0042, 0x1137, 0x0047, "VIC P81E PCIe Management Controller(0x1137-0x0047)"},
{0x1137, 0x0042, 0x1137, 0x0085, "VIC 1225 PCIe Management Controller(0x1137-0x0085)"},
{0x1137, 0x0042, 0x1137, 0x00CD, "VIC 1285 PCIe Management Controller(0x1137-0x00CD)"},
{0x1137, 0x0042, 0x1137, 0x00CE, "VIC 1225T PCIe Management Controller(0x1137-0x00CE)"},
{0x1137, 0x0042, 0x1137, 0x012E, "VIC 1227 PCIe Management Controller(0x1137-0x012E)"},
{0x1137, 0x0042, 0x1137, 0x014D, "VIC 1385 PCIe Management Controller(0x1137-0x014D)"},
{0x1137, 0x0042, 0x1137, 0x0217, "VIC 1455 PCIe Management Controller(0x1137-0x0217)"},
{0x1137, 0x0042, 0x1137, 0x0218, "VIC 1457 PCIe Management Controller(0x1137-0x0218)"},
{0x1137, 0x0043, 0xFFFF, 0xFFFF, "VIC Ethernet NIC(0x0043)"},
{0x1137, 0x0043, 0x1137, 0x0047, "VIC P81E PCIe Ethernet NIC(0x1137-0x0047)"},
{0x1137, 0x0043, 0x1137, 0x0048, "VIC M81KR Mezzanine Ethernet NIC(0x1137-0x0048)"},
{0x1137, 0x0043, 0x1137, 0x004F, "VIC 1280 Mezzanine Ethernet NIC(0x1137-0x004F)"},
{0x1137, 0x0043, 0x1137, 0x0084, "VIC 1240 MLOM Ethernet NIC(0x1137-0x0084)"},
{0x1137, 0x0043, 0x1137, 0x0085, "VIC 1225 PCIe Ethernet NIC(0x1137-0x0085)"},
{0x1137, 0x0043, 0x1137, 0x00CD, "VIC 1285 PCIe Ethernet NIC(0x1137-0x00CD)"},
{0x1137, 0x0043, 0x1137, 0x00CE, "VIC 1225T PCIe Ethernet NIC(0x1137-0x00CE)"},
{0x1137, 0x0043, 0x1137, 0x012A, "VIC M4308 Ethernet NIC(0x1137-0x012A)"},
{0x1137, 0x0043, 0x1137, 0x012C, "VIC 1340 MLOM Ethernet NIC(0x1137-0x012C)"},
{0x1137, 0x0043, 0x1137, 0x012E, "VIC 1227 PCIe Ethernet NIC(0x1137-0x012E)"},
{0x1137, 0x0043, 0x1137, 0x0137, "VIC 1380 Mezzanine Ethernet NIC(0x1137-0x0137)"},
{0x1137, 0x0043, 0x1137, 0x014D, "VIC 1385 PCIe Ethernet NIC(0x1137-0x014D)"},
{0x1137, 0x0043, 0x1137, 0x015D, "VIC 1387 MLOM Ethernet NIC(0x1137-0x015D)"},
{0x1137, 0x0043, 0x1137, 0x0215, "VIC 1440 Mezzanine Ethernet NIC(0x1137-0x0215)"},
{0x1137, 0x0043, 0x1137, 0x0216, "VIC 1480 MLOM Ethernet NIC(0x1137-0x0216)"},
{0x1137, 0x0043, 0x1137, 0x0217, "VIC 1455 PCIe Ethernet NIC(0x1137-0x0217)"},
{0x1137, 0x0043, 0x1137, 0x0218, "VIC 1457 MLOM Ethernet NIC(0x1137-0x0218)"},
{0x1137, 0x0043, 0x1137, 0x0219, "VIC 1485 PCIe Ethernet NIC(0x1137-0x0219)"},
{0x1137, 0x0043, 0x1137, 0x021A, "VIC 1487 MLOM Ethernet NIC(0x1137-0x021A)"},
{0x1137, 0x0043, 0x1137, 0x024A, "VIC 1495 PCIe Ethernet NIC(0x1137-0x024A)"},
{0x1137, 0x0043, 0x1137, 0x024B, "VIC 1497 MLOM Ethernet NIC(0x1137-0x024B)"},
{0x1137, 0x0044, 0xFFFF, 0xFFFF, "VIC Ethernet NIC Dynamic(0x0044)"},
{0x1137, 0x0044, 0x1137, 0x0047, "VIC P81E PCIe Ethernet NIC Dynamic(0x1137-0x0047)"},
{0x1137, 0x0044, 0x1137, 0x0048, "VIC M81KR Mezzanine Ethernet NIC Dynamic(0x1137-0x0048)"},
{0x1137, 0x0044, 0x1137, 0x004F, "VIC 1280 Mezzanine Ethernet NIC Dynamic(0x1137-0x004F)"},
{0x1137, 0x0044, 0x1137, 0x0084, "VIC 1240 MLOM Ethernet NIC Dynamic(0x1137-0x0084)"},
{0x1137, 0x0044, 0x1137, 0x0085, "VIC 1225 PCIe Ethernet NIC Dynamic(0x1137-0x0085)"},
{0x1137, 0x0044, 0x1137, 0x00CD, "VIC 1285 PCIe Ethernet NIC Dynamic(0x1137-0x00CD)"},
{0x1137, 0x0044, 0x1137, 0x00CE, "VIC 1225T PCIe Ethernet NIC Dynamic(0x1137-0x00CE)"},
{0x1137, 0x0044, 0x1137, 0x012A, "VIC M4308 Ethernet NIC Dynamic(0x1137-0x012A)"},
{0x1137, 0x0044, 0x1137, 0x012C, "VIC 1340 MLOM Ethernet NIC Dynamic(0x1137-0x012C)"},
{0x1137, 0x0044, 0x1137, 0x012E, "VIC 1227 PCIe Ethernet NIC Dynamic(0x1137-0x012E)"},
{0x1137, 0x0044, 0x1137, 0x0137, "VIC 1380 Mezzanine Ethernet NIC Dynamic(0x1137-0x0137)"},
{0x1137, 0x0044, 0x1137, 0x014D, "VIC 1385 PCIe Ethernet NIC Dynamic(0x1137-0x014D)"},
{0x1137, 0x0045, 0xFFFF, 0xFFFF, "VIC FCoE HBA(0x0045)"},
{0x1137, 0x0045, 0x1137, 0x0047, "VIC P81E PCIe FCoE HBA(0x1137-0x0047)"},
{0x1137, 0x0045, 0x1137, 0x0048, "VIC M81KR Mezzanine FCoE HBA(0x1137-0x0048)"},
{0x1137, 0x0045, 0x1137, 0x004F, "VIC 1280 Mezzanine FCoE HBA(0x1137-0x004F)"},
{0x1137, 0x0045, 0x1137, 0x0084, "VIC 1240 MLOM FCoE HBA(0x1137-0x0084)"},
{0x1137, 0x0045, 0x1137, 0x0085, "VIC 1225 PCIe FCoE HBA(0x1137-0x0085)"},
{0x1137, 0x0045, 0x1137, 0x00CD, "VIC 1285 PCIe FCoE HBA(0x1137-0x00CD)"},
{0x1137, 0x0045, 0x1137, 0x00CE, "VIC 1225T PCIe FCoE HBA(0x1137-0x00CE)"},
{0x1137, 0x0045, 0x1137, 0x012A, "VIC M4308 FCoE HBA(0x1137-0x012A)"},
{0x1137, 0x0045, 0x1137, 0x012C, "VIC 1340 MLOM FCoE HBA(0x1137-0x012C)"},
{0x1137, 0x0045, 0x1137, 0x012E, "VIC 1227 PCIe FCoE HBA(0x1137-0x012E)"},
{0x1137, 0x0045, 0x1137, 0x0137, "VIC 1380 Mezzanine FCoE HBA(0x1137-0x0137)"},
{0x1137, 0x0045, 0x1137, 0x014D, "VIC 1385 PCIe FCoE HBA(0x1137-0x014D)"},
{0x1137, 0x0046, 0xFFFF, 0xFFFF, "VIC SCSI Controller(0x0046)"},
{0x1137, 0x0046, 0x1137, 0x012A, "VIC M4308 SCSI Controller(0x1137-0x012A)"},
{0x1137, 0x004E, 0xFFFF, 0xFFFF, "VIC 82 PCIe Upstream Port(0x004E)"},
{0x1137, 0x0071, 0xFFFF, 0xFFFF, "VIC SR-IOV VF(0x0071)"},
{0x1137, 0x007A, 0xFFFF, 0xFFFF, "VIC 1300 PCIe Upstream Port(0x007A)"},
{0x1137, 0x007A, 0x1137, 0x012A, "VIC M4308 Dual 40Gb(0x1137-0x012A)"},
{0x1137, 0x007A, 0x1137, 0x012C, "VIC 1340 Dual 40Gb MLOM(0x1137-0x012C)"},
{0x1137, 0x007A, 0x1137, 0x0137, "VIC 1380 Dual 40Gb Mezzanine(0x1137-0x0137)"},
{0x1137, 0x007A, 0x1137, 0x014D, "VIC 1385 Dual 40Gb PCIe(0x1137-0x014D)"},
{0x1137, 0x00CF, 0xFFFF, 0xFFFF, "VIC Userspace NIC(0x00CF)"},
{0x1137, 0x00CF, 0x1137, 0x004F, "VIC 1280 Mezzanine Userspace NIC(0x1137-0x004F)"},
{0x1137, 0x00CF, 0x1137, 0x0084, "VIC 1240 MLOM Userspace NIC(0x1137-0x0084)"},
{0x1137, 0x00CF, 0x1137, 0x0085, "VIC 1225 PCIe Userspace NIC(0x1137-0x0085)"},
{0x1137, 0x00CF, 0x1137, 0x00CD, "VIC 1285 PCIe Userspace NIC(0x1137-0x00CD)"},
{0x1137, 0x00CF, 0x1137, 0x00CE, "VIC 1225T PCIe Userspace NIC(0x1137-0x00CE)"},
{0x1137, 0x00CF, 0x1137, 0x012A, "VIC M4308 Userspace NIC(0x1137-0x012A)"},
{0x1137, 0x00CF, 0x1137, 0x012C, "VIC 1340 MLOM Userspace NIC(0x1137-0x012C)"},
{0x1137, 0x00CF, 0x1137, 0x012E, "VIC 1227 PCIe Userspace NIC(0x1137-0x012E)"},
{0x1137, 0x00CF, 0x1137, 0x0137, "VIC 1380 Mezzanine Userspace NIC(0x1137-0x0137)"},
{0x1137, 0x023E, 0xFFFF, 0xFFFF, "1GigE I350 LOM(0x023E)"},
}; /* pci_vid_1137[] */

static pci_id_t const pci_vid_1138[] = {
{0x1138, 0xFFFF, 0xFFFF, 0xFFFF, "Ziatech Corporation(0x1138)"},
{0x1138, 0x8905, 0xFFFF, 0xFFFF, "8905 [STD 32 Bridge](0x8905)"},
}; /* pci_vid_1138[] */

static pci_id_t const pci_vid_1139[] = {
{0x1139, 0xFFFF, 0xFFFF, 0xFFFF, "Dynamic Pictures, Inc(0x1139)"},
{0x1139, 0x0001, 0xFFFF, 0xFFFF, "VGA Compatible 3D Graphics(0x0001)"},
}; /* pci_vid_1139[] */

static pci_id_t const pci_vid_113A[] = {
{0x113A, 0xFFFF, 0xFFFF, 0xFFFF, "FWB Inc(0x113A)"},
}; /* pci_vid_113A[] */

static pci_id_t const pci_vid_113B[] = {
{0x113B, 0xFFFF, 0xFFFF, 0xFFFF, "Network Computing Devices(0x113B)"},
}; /* pci_vid_113B[] */

static pci_id_t const pci_vid_113C[] = {
{0x113C, 0xFFFF, 0xFFFF, 0xFFFF, "Cyclone Microsystems, Inc.(0x113C)"},
{0x113C, 0x0000, 0xFFFF, 0xFFFF, "PCI-9060 i960 Bridge(0x0000)"},
{0x113C, 0x0001, 0xFFFF, 0xFFFF, "PCI-SDK [PCI i960 Evaluation Platform](0x0001)"},
{0x113C, 0x0911, 0xFFFF, 0xFFFF, "PCI-911 [i960Jx-based Intelligent I/O Controller](0x0911)"},
{0x113C, 0x0912, 0xFFFF, 0xFFFF, "PCI-912 [i960CF-based Intelligent I/O Controller](0x0912)"},
{0x113C, 0x0913, 0xFFFF, 0xFFFF, "PCI-913(0x0913)"},
{0x113C, 0x0914, 0xFFFF, 0xFFFF, "PCI-914 [I/O Controller w/ secondary PCI bus](0x0914)"},
}; /* pci_vid_113C[] */

static pci_id_t const pci_vid_113D[] = {
{0x113D, 0xFFFF, 0xFFFF, 0xFFFF, "Leading Edge Products Inc(0x113D)"},
}; /* pci_vid_113D[] */

static pci_id_t const pci_vid_113E[] = {
{0x113E, 0xFFFF, 0xFFFF, 0xFFFF, "Sanyo Electric Co - Computer Engineering Dept(0x113E)"},
}; /* pci_vid_113E[] */

static pci_id_t const pci_vid_113F[] = {
{0x113F, 0xFFFF, 0xFFFF, 0xFFFF, "Equinox Systems, Inc.(0x113F)"},
{0x113F, 0x0808, 0xFFFF, 0xFFFF, "SST-64P Adapter(0x0808)"},
{0x113F, 0x1010, 0xFFFF, 0xFFFF, "SST-128P Adapter(0x1010)"},
{0x113F, 0x80C0, 0xFFFF, 0xFFFF, "SST-16P DB Adapter(0x80C0)"},
{0x113F, 0x80C4, 0xFFFF, 0xFFFF, "SST-16P RJ Adapter(0x80C4)"},
{0x113F, 0x80C8, 0xFFFF, 0xFFFF, "SST-16P Adapter(0x80C8)"},
{0x113F, 0x8888, 0xFFFF, 0xFFFF, "SST-4P Adapter(0x8888)"},
{0x113F, 0x9090, 0xFFFF, 0xFFFF, "SST-8P Adapter(0x9090)"},
}; /* pci_vid_113F[] */

static pci_id_t const pci_vid_1140[] = {
{0x1140, 0xFFFF, 0xFFFF, 0xFFFF, "Intervoice Inc(0x1140)"},
}; /* pci_vid_1140[] */

static pci_id_t const pci_vid_1141[] = {
{0x1141, 0xFFFF, 0xFFFF, 0xFFFF, "Crest Microsystem Inc(0x1141)"},
}; /* pci_vid_1141[] */

static pci_id_t const pci_vid_1142[] = {
{0x1142, 0xFFFF, 0xFFFF, 0xFFFF, "Alliance Semiconductor Corporation(0x1142)"},
{0x1142, 0x3210, 0xFFFF, 0xFFFF, "AP6410(0x3210)"},
{0x1142, 0x6422, 0xFFFF, 0xFFFF, "ProVideo 6422(0x6422)"},
{0x1142, 0x6424, 0xFFFF, 0xFFFF, "ProVideo 6424(0x6424)"},
{0x1142, 0x6425, 0xFFFF, 0xFFFF, "ProMotion AT25(0x6425)"},
{0x1142, 0x643D, 0xFFFF, 0xFFFF, "ProMotion AT3D(0x643D)"},
}; /* pci_vid_1142[] */

static pci_id_t const pci_vid_1143[] = {
{0x1143, 0xFFFF, 0xFFFF, 0xFFFF, "NetPower, Inc(0x1143)"},
}; /* pci_vid_1143[] */

static pci_id_t const pci_vid_1144[] = {
{0x1144, 0xFFFF, 0xFFFF, 0xFFFF, "Cincinnati Milacron(0x1144)"},
{0x1144, 0x0001, 0xFFFF, 0xFFFF, "Noservo controller(0x0001)"},
}; /* pci_vid_1144[] */

static pci_id_t const pci_vid_1145[] = {
{0x1145, 0xFFFF, 0xFFFF, 0xFFFF, "Workbit Corporation(0x1145)"},
{0x1145, 0x8007, 0xFFFF, 0xFFFF, "NinjaSCSI-32 Workbit(0x8007)"},
{0x1145, 0xF007, 0xFFFF, 0xFFFF, "NinjaSCSI-32 KME(0xF007)"},
{0x1145, 0xF010, 0xFFFF, 0xFFFF, "NinjaSCSI-32 Workbit(0xF010)"},
{0x1145, 0xF012, 0xFFFF, 0xFFFF, "NinjaSCSI-32 Logitec(0xF012)"},
{0x1145, 0xF013, 0xFFFF, 0xFFFF, "NinjaSCSI-32 Logitec(0xF013)"},
{0x1145, 0xF015, 0xFFFF, 0xFFFF, "NinjaSCSI-32 Melco(0xF015)"},
{0x1145, 0xF020, 0xFFFF, 0xFFFF, "NinjaSCSI-32 Sony PCGA-DVD51(0xF020)"},
{0x1145, 0xF021, 0xFFFF, 0xFFFF, "NinjaPATA-32 Delkin Cardbus UDMA(0xF021)"},
{0x1145, 0xF024, 0xFFFF, 0xFFFF, "NinjaPATA-32 Delkin Cardbus UDMA(0xF024)"},
{0x1145, 0xF103, 0xFFFF, 0xFFFF, "NinjaPATA-32 Delkin Cardbus UDMA(0xF103)"},
}; /* pci_vid_1145[] */

static pci_id_t const pci_vid_1146[] = {
{0x1146, 0xFFFF, 0xFFFF, 0xFFFF, "Force Computers(0x1146)"},
}; /* pci_vid_1146[] */

static pci_id_t const pci_vid_1147[] = {
{0x1147, 0xFFFF, 0xFFFF, 0xFFFF, "Interface Corp(0x1147)"},
}; /* pci_vid_1147[] */

static pci_id_t const pci_vid_1148[] = {
{0x1148, 0xFFFF, 0xFFFF, 0xFFFF, "SysKonnect(0x1148)"},
{0x1148, 0x4000, 0xFFFF, 0xFFFF, "FDDI Adapter(0x4000)"},
{0x1148, 0x4000, 0x0E11, 0xB03B, "Netelligent 100 FDDI DAS Fibre SC(0x0E11-0xB03B)"},
{0x1148, 0x4000, 0x0E11, 0xB03C, "Netelligent 100 FDDI SAS Fibre SC(0x0E11-0xB03C)"},
{0x1148, 0x4000, 0x0E11, 0xB03D, "Netelligent 100 FDDI DAS UTP(0x0E11-0xB03D)"},
{0x1148, 0x4000, 0x0E11, 0xB03E, "Netelligent 100 FDDI SAS UTP(0x0E11-0xB03E)"},
{0x1148, 0x4000, 0x0E11, 0xB03F, "Netelligent 100 FDDI SAS Fibre MIC(0x0E11-0xB03F)"},
{0x1148, 0x4000, 0x1148, 0x5521, "FDDI SK-5521 (SK-NET FDDI-UP)(0x1148-0x5521)"},
{0x1148, 0x4000, 0x1148, 0x5522, "FDDI SK-5522 (SK-NET FDDI-UP DAS)(0x1148-0x5522)"},
{0x1148, 0x4000, 0x1148, 0x5541, "FDDI SK-5541 (SK-NET FDDI-FP)(0x1148-0x5541)"},
{0x1148, 0x4000, 0x1148, 0x5543, "FDDI SK-5543 (SK-NET FDDI-LP)(0x1148-0x5543)"},
{0x1148, 0x4000, 0x1148, 0x5544, "FDDI SK-5544 (SK-NET FDDI-LP DAS)(0x1148-0x5544)"},
{0x1148, 0x4000, 0x1148, 0x5821, "FDDI SK-5821 (SK-NET FDDI-UP64)(0x1148-0x5821)"},
{0x1148, 0x4000, 0x1148, 0x5822, "FDDI SK-5822 (SK-NET FDDI-UP64 DAS)(0x1148-0x5822)"},
{0x1148, 0x4000, 0x1148, 0x5841, "FDDI SK-5841 (SK-NET FDDI-FP64)(0x1148-0x5841)"},
{0x1148, 0x4000, 0x1148, 0x5843, "FDDI SK-5843 (SK-NET FDDI-LP64)(0x1148-0x5843)"},
{0x1148, 0x4000, 0x1148, 0x5844, "FDDI SK-5844 (SK-NET FDDI-LP64 DAS)(0x1148-0x5844)"},
{0x1148, 0x4200, 0xFFFF, 0xFFFF, "Token Ring adapter(0x4200)"},
{0x1148, 0x4300, 0xFFFF, 0xFFFF, "SK-9872 Gigabit Ethernet Server Adapter (SK-NET GE-ZX dual link)(0x4300)"},
{0x1148, 0x4300, 0x1148, 0x9821, "SK-9821 Gigabit Ethernet Server Adapter (SK-NET GE-T)(0x1148-0x9821)"},
{0x1148, 0x4300, 0x1148, 0x9822, "SK-9822 Gigabit Ethernet Server Adapter (SK-NET GE-T dual link)(0x1148-0x9822)"},
{0x1148, 0x4300, 0x1148, 0x9841, "SK-9841 Gigabit Ethernet Server Adapter (SK-NET GE-LX)(0x1148-0x9841)"},
{0x1148, 0x4300, 0x1148, 0x9842, "SK-9842 Gigabit Ethernet Server Adapter (SK-NET GE-LX dual link)(0x1148-0x9842)"},
{0x1148, 0x4300, 0x1148, 0x9843, "SK-9843 Gigabit Ethernet Server Adapter (SK-NET GE-SX)(0x1148-0x9843)"},
{0x1148, 0x4300, 0x1148, 0x9844, "SK-9844 Gigabit Ethernet Server Adapter (SK-NET GE-SX dual link)(0x1148-0x9844)"},
{0x1148, 0x4300, 0x1148, 0x9861, "SK-9861 Gigabit Ethernet Server Adapter (SK-NET GE-SX Volition)(0x1148-0x9861)"},
{0x1148, 0x4300, 0x1148, 0x9862, "SK-9862 Gigabit Ethernet Server Adapter (SK-NET GE-SX Volition dual link)(0x1148-0x9862)"},
{0x1148, 0x4300, 0x1148, 0x9871, "SK-9871 Gigabit Ethernet Server Adapter (SK-NET GE-ZX)(0x1148-0x9871)"},
{0x1148, 0x4300, 0x1148, 0x9872, "SK-9872 Gigabit Ethernet Server Adapter (SK-NET GE-ZX dual link)(0x1148-0x9872)"},
{0x1148, 0x4300, 0x1259, 0x2970, "AT-2970SX Gigabit Ethernet Adapter(0x1259-0x2970)"},
{0x1148, 0x4300, 0x1259, 0x2971, "AT-2970LX Gigabit Ethernet Adapter(0x1259-0x2971)"},
{0x1148, 0x4300, 0x1259, 0x2972, "AT-2970TX Gigabit Ethernet Adapter(0x1259-0x2972)"},
{0x1148, 0x4300, 0x1259, 0x2973, "AT-2971SX Gigabit Ethernet Adapter(0x1259-0x2973)"},
{0x1148, 0x4300, 0x1259, 0x2974, "AT-2971T Gigabit Ethernet Adapter(0x1259-0x2974)"},
{0x1148, 0x4300, 0x1259, 0x2975, "AT-2970SX/2SC Gigabit Ethernet Adapter(0x1259-0x2975)"},
{0x1148, 0x4300, 0x1259, 0x2976, "AT-2970LX/2SC Gigabit Ethernet Adapter(0x1259-0x2976)"},
{0x1148, 0x4300, 0x1259, 0x2977, "AT-2970TX/2TX Gigabit Ethernet Adapter(0x1259-0x2977)"},
{0x1148, 0x4320, 0xFFFF, 0xFFFF, "SK-98xx V2.0 Gigabit Ethernet Adapter [Marvell 88E8001](0x4320)"},
{0x1148, 0x4320, 0x1148, 0x0121, "Marvell RDK-8001 Adapter(0x1148-0x0121)"},
{0x1148, 0x4320, 0x1148, 0x0221, "Marvell RDK-8002 Adapter(0x1148-0x0221)"},
{0x1148, 0x4320, 0x1148, 0x0321, "Marvell RDK-8003 Adapter(0x1148-0x0321)"},
{0x1148, 0x4320, 0x1148, 0x0421, "Marvell RDK-8004 Adapter(0x1148-0x0421)"},
{0x1148, 0x4320, 0x1148, 0x0621, "Marvell RDK-8006 Adapter(0x1148-0x0621)"},
{0x1148, 0x4320, 0x1148, 0x0721, "Marvell RDK-8007 Adapter(0x1148-0x0721)"},
{0x1148, 0x4320, 0x1148, 0x0821, "Marvell RDK-8008 Adapter(0x1148-0x0821)"},
{0x1148, 0x4320, 0x1148, 0x0921, "Marvell RDK-8009 Adapter(0x1148-0x0921)"},
{0x1148, 0x4320, 0x1148, 0x1121, "Marvell RDK-8011 Adapter(0x1148-0x1121)"},
{0x1148, 0x4320, 0x1148, 0x1221, "Marvell RDK-8012 Adapter(0x1148-0x1221)"},
{0x1148, 0x4320, 0x1148, 0x3221, "SK-9521 V2.0 10/100/1000Base-T Adapter(0x1148-0x3221)"},
{0x1148, 0x4320, 0x1148, 0x5021, "SK-9821 V2.0 Gigabit Ethernet 10/100/1000Base-T Adapter(0x1148-0x5021)"},
{0x1148, 0x4320, 0x1148, 0x5041, "SK-9841 V2.0 Gigabit Ethernet 1000Base-LX Adapter(0x1148-0x5041)"},
{0x1148, 0x4320, 0x1148, 0x5043, "SK-9843 V2.0 Gigabit Ethernet 1000Base-SX Adapter(0x1148-0x5043)"},
{0x1148, 0x4320, 0x1148, 0x5051, "SK-9851 V2.0 Gigabit Ethernet 1000Base-SX Adapter(0x1148-0x5051)"},
{0x1148, 0x4320, 0x1148, 0x5061, "SK-9861 V2.0 Gigabit Ethernet 1000Base-SX Adapter(0x1148-0x5061)"},
{0x1148, 0x4320, 0x1148, 0x5071, "SK-9871 V2.0 Gigabit Ethernet 1000Base-ZX Adapter(0x1148-0x5071)"},
{0x1148, 0x4320, 0x1148, 0x9521, "SK-9521 10/100/1000Base-T Adapter(0x1148-0x9521)"},
{0x1148, 0x4320, 0x1259, 0x2916, "AT-2916T(0x1259-0x2916)"},
{0x1148, 0x4400, 0xFFFF, 0xFFFF, "SK-9Dxx Gigabit Ethernet Adapter(0x4400)"},
{0x1148, 0x4500, 0xFFFF, 0xFFFF, "SK-9Mxx Gigabit Ethernet Adapter(0x4500)"},
{0x1148, 0x9000, 0xFFFF, 0xFFFF, "SK-9Sxx Gigabit Ethernet Server Adapter PCI-X [Marvell 88E8022](0x9000)"},
{0x1148, 0x9000, 0x1148, 0x2100, "SK-9S21 10/100/1000Base-T Server Adapter, PCI-X, Copper RJ-45(0x1148-0x2100)"},
{0x1148, 0x9000, 0x1148, 0x2200, "SK-9S22 10/100/1000Base-T Dual Port Server Adapter, PCI-X, 2 Copper RJ-45(0x1148-0x2200)"},
{0x1148, 0x9000, 0x1148, 0x2210, "SK-9P22 10/100/1000 Base-T Dual Port PMC card(0x1148-0x2210)"},
{0x1148, 0x9000, 0x1148, 0x2220, "TPMC-GBE-CO(0x1148-0x2220)"},
{0x1148, 0x9000, 0x1148, 0x8100, "SK-9S81 1000Base-SX Server Adapter,PCI-X, Fiber SX/LC(0x1148-0x8100)"},
{0x1148, 0x9000, 0x1148, 0x8200, "SK-9S82 1000Base-SX Dual Port Server Adapter, PCI-X, 2 Fiber SX/LC(0x1148-0x8200)"},
{0x1148, 0x9000, 0x1148, 0x8210, "SK-9P82 1000 Base-SX Dual Port PMC card(0x1148-0x8210)"},
{0x1148, 0x9000, 0x1148, 0x8220, "TPMC-GBE-FI(0x1148-0x8220)"},
{0x1148, 0x9000, 0x1148, 0x9100, "SK-9S91 1000Base-LX Server Adapter,PCI-X, Fiber LX/LC(0x1148-0x9100)"},
{0x1148, 0x9000, 0x1148, 0x9200, "SK-9S92 1000Base-LX Dual Port Server Adapter, PCI-X, 2 Fiber LX/LC(0x1148-0x9200)"},
{0x1148, 0x9000, 0x1259, 0x2973, "AT-2971SX v2 Gigabit Adapter(0x1259-0x2973)"},
{0x1148, 0x9000, 0x1259, 0x2974, "AT-2971T v2 Gigabit Adapter(0x1259-0x2974)"},
{0x1148, 0x9000, 0x1259, 0x2978, "AT-2971LX Gigabit Adapter(0x1259-0x2978)"},
{0x1148, 0x9843, 0xFFFF, 0xFFFF, "[Fujitsu] Gigabit Ethernet(0x9843)"},
{0x1148, 0x9E00, 0xFFFF, 0xFFFF, "SK-9E21D 10/100/1000Base-T Adapter, Copper RJ-45(0x9E00)"},
{0x1148, 0x9E00, 0x1148, 0x2100, "SK-9E21 Server Adapter(0x1148-0x2100)"},
{0x1148, 0x9E00, 0x1148, 0x21D0, "SK-9E21D 10/100/1000Base-T Adapter(0x1148-0x21D0)"},
{0x1148, 0x9E00, 0x1148, 0x2200, "SK-9E22 Server Adapter(0x1148-0x2200)"},
{0x1148, 0x9E00, 0x1148, 0x8100, "SK-9E81 Server Adapter(0x1148-0x8100)"},
{0x1148, 0x9E00, 0x1148, 0x8200, "SK-9E82 Server Adapter(0x1148-0x8200)"},
{0x1148, 0x9E00, 0x1148, 0x9100, "SK-9E91 Server Adapter(0x1148-0x9100)"},
{0x1148, 0x9E00, 0x1148, 0x9200, "SK-9E92 Server Adapter(0x1148-0x9200)"},
{0x1148, 0x9E01, 0xFFFF, 0xFFFF, "SK-9E21M 10/100/1000Base-T Adapter(0x9E01)"},
}; /* pci_vid_1148[] */

static pci_id_t const pci_vid_1149[] = {
{0x1149, 0xFFFF, 0xFFFF, 0xFFFF, "Win System Corporation(0x1149)"},
}; /* pci_vid_1149[] */

static pci_id_t const pci_vid_114A[] = {
{0x114A, 0xFFFF, 0xFFFF, 0xFFFF, "VMIC(0x114A)"},
{0x114A, 0x5565, 0xFFFF, 0xFFFF, "GE-IP PCI5565,PMC5565 Reflective Memory Node(0x5565)"},
{0x114A, 0x5579, 0xFFFF, 0xFFFF, "VMIPCI-5579 (Reflective Memory Card)(0x5579)"},
{0x114A, 0x5587, 0xFFFF, 0xFFFF, "VMIPCI-5587 (Reflective Memory Card)(0x5587)"},
{0x114A, 0x6504, 0xFFFF, 0xFFFF, "VMIC PCI 7755 FPGA(0x6504)"},
{0x114A, 0x7587, 0xFFFF, 0xFFFF, "VMIVME-7587(0x7587)"},
}; /* pci_vid_114A[] */

static pci_id_t const pci_vid_114B[] = {
{0x114B, 0xFFFF, 0xFFFF, 0xFFFF, "Canopus Co., Ltd(0x114B)"},
}; /* pci_vid_114B[] */

static pci_id_t const pci_vid_114C[] = {
{0x114C, 0xFFFF, 0xFFFF, 0xFFFF, "Annabooks(0x114C)"},
}; /* pci_vid_114C[] */

static pci_id_t const pci_vid_114D[] = {
{0x114D, 0xFFFF, 0xFFFF, 0xFFFF, "IC Corporation(0x114D)"},
}; /* pci_vid_114D[] */

static pci_id_t const pci_vid_114E[] = {
{0x114E, 0xFFFF, 0xFFFF, 0xFFFF, "Nikon Systems Inc(0x114E)"},
}; /* pci_vid_114E[] */

static pci_id_t const pci_vid_114F[] = {
{0x114F, 0xFFFF, 0xFFFF, 0xFFFF, "Digi International(0x114F)"},
{0x114F, 0x0002, 0xFFFF, 0xFFFF, "AccelePort EPC(0x0002)"},
{0x114F, 0x0003, 0xFFFF, 0xFFFF, "RightSwitch SE-6(0x0003)"},
{0x114F, 0x0004, 0xFFFF, 0xFFFF, "AccelePort Xem(0x0004)"},
{0x114F, 0x0005, 0xFFFF, 0xFFFF, "AccelePort Xr(0x0005)"},
{0x114F, 0x0006, 0xFFFF, 0xFFFF, "AccelePort Xr,C/X(0x0006)"},
{0x114F, 0x0009, 0xFFFF, 0xFFFF, "AccelePort Xr/J(0x0009)"},
{0x114F, 0x000A, 0xFFFF, 0xFFFF, "AccelePort EPC/J(0x000A)"},
{0x114F, 0x000C, 0xFFFF, 0xFFFF, "DataFirePRIme T1 (1-port)(0x000C)"},
{0x114F, 0x000D, 0xFFFF, 0xFFFF, "SyncPort 2-Port (x.25/FR)(0x000D)"},
{0x114F, 0x0011, 0xFFFF, 0xFFFF, "AccelePort 8r EIA-232 (IBM)(0x0011)"},
{0x114F, 0x0012, 0xFFFF, 0xFFFF, "AccelePort 8r EIA-422(0x0012)"},
{0x114F, 0x0013, 0xFFFF, 0xFFFF, "AccelePort Xr(0x0013)"},
{0x114F, 0x0014, 0xFFFF, 0xFFFF, "AccelePort 8r EIA-422(0x0014)"},
{0x114F, 0x0015, 0xFFFF, 0xFFFF, "AccelePort Xem(0x0015)"},
{0x114F, 0x0016, 0xFFFF, 0xFFFF, "AccelePort EPC/X(0x0016)"},
{0x114F, 0x0017, 0xFFFF, 0xFFFF, "AccelePort C/X(0x0017)"},
{0x114F, 0x001A, 0xFFFF, 0xFFFF, "DataFirePRIme E1 (1-port)(0x001A)"},
{0x114F, 0x001B, 0xFFFF, 0xFFFF, "AccelePort C/X (IBM)(0x001B)"},
{0x114F, 0x001C, 0xFFFF, 0xFFFF, "AccelePort Xr (SAIP)(0x001C)"},
{0x114F, 0x001D, 0xFFFF, 0xFFFF, "DataFire RAS T1/E1/PRI(0x001D)"},
{0x114F, 0x001D, 0x114F, 0x0050, "DataFire RAS E1 Adapter(0x114F-0x0050)"},
{0x114F, 0x001D, 0x114F, 0x0051, "DataFire RAS Dual E1 Adapter(0x114F-0x0051)"},
{0x114F, 0x001D, 0x114F, 0x0052, "DataFire RAS T1 Adapter(0x114F-0x0052)"},
{0x114F, 0x001D, 0x114F, 0x0053, "DataFire RAS Dual T1 Adapter(0x114F-0x0053)"},
{0x114F, 0x0023, 0xFFFF, 0xFFFF, "AccelePort RAS(0x0023)"},
{0x114F, 0x0024, 0xFFFF, 0xFFFF, "DataFire RAS B4 ST/U(0x0024)"},
{0x114F, 0x0024, 0x114F, 0x0030, "DataFire RAS BRI U Adapter(0x114F-0x0030)"},
{0x114F, 0x0024, 0x114F, 0x0031, "DataFire RAS BRI S/T Adapter(0x114F-0x0031)"},
{0x114F, 0x0026, 0xFFFF, 0xFFFF, "AccelePort 4r 920(0x0026)"},
{0x114F, 0x0027, 0xFFFF, 0xFFFF, "AccelePort Xr 920(0x0027)"},
{0x114F, 0x0028, 0xFFFF, 0xFFFF, "ClassicBoard 4(0x0028)"},
{0x114F, 0x0029, 0xFFFF, 0xFFFF, "ClassicBoard 8(0x0029)"},
{0x114F, 0x0034, 0xFFFF, 0xFFFF, "AccelePort 2r 920(0x0034)"},
{0x114F, 0x0035, 0xFFFF, 0xFFFF, "DataFire DSP T1/E1/PRI cPCI(0x0035)"},
{0x114F, 0x0040, 0xFFFF, 0xFFFF, "AccelePort Xp(0x0040)"},
{0x114F, 0x0040, 0x114F, 0x0042, "AccelePort 2p PCI(0x114F-0x0042)"},
{0x114F, 0x0040, 0x114F, 0x0043, "AccelePort 4p PCI(0x114F-0x0043)"},
{0x114F, 0x0040, 0x114F, 0x0044, "AccelePort 8p PCI(0x114F-0x0044)"},
{0x114F, 0x0040, 0x114F, 0x0045, "AccelePort 16p PCI(0x114F-0x0045)"},
{0x114F, 0x0040, 0x114F, 0x004E, "AccelePort 32p PCI(0x114F-0x004E)"},
{0x114F, 0x0042, 0xFFFF, 0xFFFF, "AccelePort 2p(0x0042)"},
{0x114F, 0x0043, 0xFFFF, 0xFFFF, "AccelePort 4p(0x0043)"},
{0x114F, 0x0044, 0xFFFF, 0xFFFF, "AccelePort 8p(0x0044)"},
{0x114F, 0x0045, 0xFFFF, 0xFFFF, "AccelePort 16p(0x0045)"},
{0x114F, 0x004E, 0xFFFF, 0xFFFF, "AccelePort 32p(0x004E)"},
{0x114F, 0x0070, 0xFFFF, 0xFFFF, "Datafire Micro V IOM2 (Europe)(0x0070)"},
{0x114F, 0x0071, 0xFFFF, 0xFFFF, "Datafire Micro V (Europe)(0x0071)"},
{0x114F, 0x0072, 0xFFFF, 0xFFFF, "Datafire Micro V IOM2 (North America)(0x0072)"},
{0x114F, 0x0073, 0xFFFF, 0xFFFF, "Datafire Micro V (North America)(0x0073)"},
{0x114F, 0x00B0, 0xFFFF, 0xFFFF, "Digi Neo 4(0x00B0)"},
{0x114F, 0x00B1, 0xFFFF, 0xFFFF, "Digi Neo 8(0x00B1)"},
{0x114F, 0x00C8, 0xFFFF, 0xFFFF, "Digi Neo 2 DB9(0x00C8)"},
{0x114F, 0x00C9, 0xFFFF, 0xFFFF, "Digi Neo 2 DB9 PRI(0x00C9)"},
{0x114F, 0x00CA, 0xFFFF, 0xFFFF, "Digi Neo 2 RJ45(0x00CA)"},
{0x114F, 0x00CB, 0xFFFF, 0xFFFF, "Digi Neo 2 RJ45 PRI(0x00CB)"},
{0x114F, 0x00CC, 0xFFFF, 0xFFFF, "Digi Neo 1 422(0x00CC)"},
{0x114F, 0x00CD, 0xFFFF, 0xFFFF, "Digi Neo 1 422 485(0x00CD)"},
{0x114F, 0x00CE, 0xFFFF, 0xFFFF, "Digi Neo 2 422 485(0x00CE)"},
{0x114F, 0x00D0, 0xFFFF, 0xFFFF, "ClassicBoard 4 422(0x00D0)"},
{0x114F, 0x00D1, 0xFFFF, 0xFFFF, "ClassicBoard 8 422(0x00D1)"},
{0x114F, 0x00F1, 0xFFFF, 0xFFFF, "Digi Neo PCI-E 4 port(0x00F1)"},
{0x114F, 0x00F4, 0xFFFF, 0xFFFF, "Digi Neo 4 (IBM version)(0x00F4)"},
{0x114F, 0x6001, 0xFFFF, 0xFFFF, "Avanstar(0x6001)"},
}; /* pci_vid_114F[] */

static pci_id_t const pci_vid_1150[] = {
{0x1150, 0xFFFF, 0xFFFF, 0xFFFF, "Thinking Machines Corp(0x1150)"},
}; /* pci_vid_1150[] */

static pci_id_t const pci_vid_1151[] = {
{0x1151, 0xFFFF, 0xFFFF, 0xFFFF, "JAE Electronics Inc.(0x1151)"},
}; /* pci_vid_1151[] */

static pci_id_t const pci_vid_1152[] = {
{0x1152, 0xFFFF, 0xFFFF, 0xFFFF, "Megatek(0x1152)"},
}; /* pci_vid_1152[] */

static pci_id_t const pci_vid_1153[] = {
{0x1153, 0xFFFF, 0xFFFF, 0xFFFF, "Land Win Electronic Corp(0x1153)"},
}; /* pci_vid_1153[] */

static pci_id_t const pci_vid_1154[] = {
{0x1154, 0xFFFF, 0xFFFF, 0xFFFF, "Melco Inc(0x1154)"},
}; /* pci_vid_1154[] */

static pci_id_t const pci_vid_1155[] = {
{0x1155, 0xFFFF, 0xFFFF, 0xFFFF, "Pine Technology Ltd(0x1155)"},
}; /* pci_vid_1155[] */

static pci_id_t const pci_vid_1156[] = {
{0x1156, 0xFFFF, 0xFFFF, 0xFFFF, "Periscope Engineering(0x1156)"},
}; /* pci_vid_1156[] */

static pci_id_t const pci_vid_1157[] = {
{0x1157, 0xFFFF, 0xFFFF, 0xFFFF, "Avsys Corporation(0x1157)"},
}; /* pci_vid_1157[] */

static pci_id_t const pci_vid_1158[] = {
{0x1158, 0xFFFF, 0xFFFF, 0xFFFF, "Voarx R & D Inc(0x1158)"},
{0x1158, 0x3011, 0xFFFF, 0xFFFF, "Tokenet/vg 1001/10m anylan(0x3011)"},
{0x1158, 0x9050, 0xFFFF, 0xFFFF, "Lanfleet/Truevalue(0x9050)"},
{0x1158, 0x9051, 0xFFFF, 0xFFFF, "Lanfleet/Truevalue(0x9051)"},
}; /* pci_vid_1158[] */

static pci_id_t const pci_vid_1159[] = {
{0x1159, 0xFFFF, 0xFFFF, 0xFFFF, "MuTech Corporation(0x1159)"},
{0x1159, 0x0001, 0xFFFF, 0xFFFF, "MV-1000(0x0001)"},
{0x1159, 0x0002, 0xFFFF, 0xFFFF, "MV-1500(0x0002)"},
}; /* pci_vid_1159[] */

static pci_id_t const pci_vid_115A[] = {
{0x115A, 0xFFFF, 0xFFFF, 0xFFFF, "Harlequin Ltd(0x115A)"},
}; /* pci_vid_115A[] */

static pci_id_t const pci_vid_115B[] = {
{0x115B, 0xFFFF, 0xFFFF, 0xFFFF, "Parallax Graphics(0x115B)"},
}; /* pci_vid_115B[] */

static pci_id_t const pci_vid_115C[] = {
{0x115C, 0xFFFF, 0xFFFF, 0xFFFF, "Photron Ltd.(0x115C)"},
}; /* pci_vid_115C[] */

static pci_id_t const pci_vid_115D[] = {
{0x115D, 0xFFFF, 0xFFFF, 0xFFFF, "Xircom(0x115D)"},
{0x115D, 0x0003, 0xFFFF, 0xFFFF, "Cardbus Ethernet 10/100(0x0003)"},
{0x115D, 0x0003, 0x1014, 0x0181, "10/100 EtherJet Cardbus Adapter(0x1014-0x0181)"},
{0x115D, 0x0003, 0x1014, 0x1181, "10/100 EtherJet Cardbus Adapter(0x1014-0x1181)"},
{0x115D, 0x0003, 0x1014, 0x8181, "10/100 EtherJet Cardbus Adapter(0x1014-0x8181)"},
{0x115D, 0x0003, 0x1014, 0x9181, "10/100 EtherJet Cardbus Adapter(0x1014-0x9181)"},
{0x115D, 0x0003, 0x115D, 0x0181, "Cardbus Ethernet 10/100(0x115D-0x0181)"},
{0x115D, 0x0003, 0x115D, 0x0182, "RealPort2 CardBus Ethernet 10/100 (R2BE-100)(0x115D-0x0182)"},
{0x115D, 0x0003, 0x115D, 0x1181, "Cardbus Ethernet 10/100(0x115D-0x1181)"},
{0x115D, 0x0003, 0x1179, 0x0181, "Cardbus Ethernet 10/100(0x1179-0x0181)"},
{0x115D, 0x0003, 0x8086, 0x8181, "EtherExpress PRO/100 Mobile CardBus 32 Adapter(0x8086-0x8181)"},
{0x115D, 0x0003, 0x8086, 0x9181, "EtherExpress PRO/100 Mobile CardBus 32 Adapter(0x8086-0x9181)"},
{0x115D, 0x0005, 0xFFFF, 0xFFFF, "Cardbus Ethernet 10/100(0x0005)"},
{0x115D, 0x0005, 0x1014, 0x0182, "10/100 EtherJet Cardbus Adapter(0x1014-0x0182)"},
{0x115D, 0x0005, 0x1014, 0x1182, "10/100 EtherJet Cardbus Adapter(0x1014-0x1182)"},
{0x115D, 0x0005, 0x115D, 0x0182, "Cardbus Ethernet 10/100(0x115D-0x0182)"},
{0x115D, 0x0005, 0x115D, 0x1182, "Cardbus Ethernet 10/100(0x115D-0x1182)"},
{0x115D, 0x0007, 0xFFFF, 0xFFFF, "Cardbus Ethernet 10/100(0x0007)"},
{0x115D, 0x0007, 0x1014, 0x0182, "10/100 EtherJet Cardbus Adapter(0x1014-0x0182)"},
{0x115D, 0x0007, 0x1014, 0x1182, "10/100 EtherJet Cardbus Adapter(0x1014-0x1182)"},
{0x115D, 0x0007, 0x115D, 0x0182, "Cardbus Ethernet 10/100(0x115D-0x0182)"},
{0x115D, 0x0007, 0x115D, 0x1182, "Cardbus Ethernet 10/100(0x115D-0x1182)"},
{0x115D, 0x000B, 0xFFFF, 0xFFFF, "Cardbus Ethernet 10/100(0x000B)"},
{0x115D, 0x000B, 0x1014, 0x0183, "10/100 EtherJet Cardbus Adapter(0x1014-0x0183)"},
{0x115D, 0x000B, 0x115D, 0x0183, "Cardbus Ethernet 10/100(0x115D-0x0183)"},
{0x115D, 0x000C, 0xFFFF, 0xFFFF, "Mini-PCI V.90 56k Modem(0x000C)"},
{0x115D, 0x000F, 0xFFFF, 0xFFFF, "Cardbus Ethernet 10/100(0x000F)"},
{0x115D, 0x000F, 0x1014, 0x0183, "10/100 EtherJet Cardbus Adapter(0x1014-0x0183)"},
{0x115D, 0x000F, 0x115D, 0x0183, "Cardbus Ethernet 10/100(0x115D-0x0183)"},
{0x115D, 0x00D4, 0xFFFF, 0xFFFF, "Mini-PCI K56Flex Modem(0x00D4)"},
{0x115D, 0x0101, 0xFFFF, 0xFFFF, "Cardbus 56k modem(0x0101)"},
{0x115D, 0x0101, 0x115D, 0x1081, "Cardbus 56k Modem(0x115D-0x1081)"},
{0x115D, 0x0103, 0xFFFF, 0xFFFF, "Cardbus Ethernet + 56k Modem(0x0103)"},
{0x115D, 0x0103, 0x1014, 0x9181, "Cardbus 56k Modem(0x1014-0x9181)"},
{0x115D, 0x0103, 0x1115, 0x1181, "Cardbus Ethernet 100 + 56k Modem(0x1115-0x1181)"},
{0x115D, 0x0103, 0x115D, 0x1181, "CBEM56G-100 Ethernet + 56k Modem(0x115D-0x1181)"},
{0x115D, 0x0103, 0x8086, 0x9181, "PRO/100 LAN + Modem56 CardBus(0x8086-0x9181)"},
}; /* pci_vid_115D[] */

static pci_id_t const pci_vid_115E[] = {
{0x115E, 0xFFFF, 0xFFFF, 0xFFFF, "Peer Protocols Inc(0x115E)"},
}; /* pci_vid_115E[] */

static pci_id_t const pci_vid_115F[] = {
{0x115F, 0xFFFF, 0xFFFF, 0xFFFF, "Maxtor Corporation(0x115F)"},
}; /* pci_vid_115F[] */

static pci_id_t const pci_vid_1160[] = {
{0x1160, 0xFFFF, 0xFFFF, 0xFFFF, "Megasoft Inc(0x1160)"},
}; /* pci_vid_1160[] */

static pci_id_t const pci_vid_1161[] = {
{0x1161, 0xFFFF, 0xFFFF, 0xFFFF, "PFU Limited(0x1161)"},
}; /* pci_vid_1161[] */

static pci_id_t const pci_vid_1162[] = {
{0x1162, 0xFFFF, 0xFFFF, 0xFFFF, "OA Laboratory Co Ltd(0x1162)"},
}; /* pci_vid_1162[] */

static pci_id_t const pci_vid_1163[] = {
{0x1163, 0xFFFF, 0xFFFF, 0xFFFF, "Rendition(0x1163)"},
{0x1163, 0x0001, 0xFFFF, 0xFFFF, "Verite 1000(0x0001)"},
{0x1163, 0x2000, 0xFFFF, 0xFFFF, "Verite V2000/V2100/V2200(0x2000)"},
{0x1163, 0x2000, 0x1092, 0x2000, "Stealth II S220(0x1092-0x2000)"},
}; /* pci_vid_1163[] */

static pci_id_t const pci_vid_1164[] = {
{0x1164, 0xFFFF, 0xFFFF, 0xFFFF, "Advanced Peripherals Technologies(0x1164)"},
}; /* pci_vid_1164[] */

static pci_id_t const pci_vid_1165[] = {
{0x1165, 0xFFFF, 0xFFFF, 0xFFFF, "Imagraph Corporation(0x1165)"},
{0x1165, 0x0001, 0xFFFF, 0xFFFF, "Motion TPEG Recorder/Player with audio(0x0001)"},
}; /* pci_vid_1165[] */

static pci_id_t const pci_vid_1166[] = {
{0x1166, 0xFFFF, 0xFFFF, 0xFFFF, "Broadcom(0x1166)"},
{0x1166, 0x0000, 0xFFFF, 0xFFFF, "CMIC-LE(0x0000)"},
{0x1166, 0x0005, 0xFFFF, 0xFFFF, "CNB20-LE Host Bridge(0x0005)"},
{0x1166, 0x0006, 0xFFFF, 0xFFFF, "CNB20HE Host Bridge(0x0006)"},
{0x1166, 0x0007, 0xFFFF, 0xFFFF, "CNB20-LE Host Bridge(0x0007)"},
{0x1166, 0x0008, 0xFFFF, 0xFFFF, "CNB20HE Host Bridge(0x0008)"},
{0x1166, 0x0009, 0xFFFF, 0xFFFF, "CNB20LE Host Bridge(0x0009)"},
{0x1166, 0x0010, 0xFFFF, 0xFFFF, "CIOB30(0x0010)"},
{0x1166, 0x0011, 0xFFFF, 0xFFFF, "CMIC-HE(0x0011)"},
{0x1166, 0x0012, 0xFFFF, 0xFFFF, "CMIC-WS Host Bridge (GC-LE chipset)(0x0012)"},
{0x1166, 0x0013, 0xFFFF, 0xFFFF, "CNB20-HE Host Bridge(0x0013)"},
{0x1166, 0x0014, 0xFFFF, 0xFFFF, "CMIC-LE Host Bridge (GC-LE chipset)(0x0014)"},
{0x1166, 0x0015, 0xFFFF, 0xFFFF, "CMIC-GC Host Bridge(0x0015)"},
{0x1166, 0x0016, 0xFFFF, 0xFFFF, "CMIC-GC Host Bridge(0x0016)"},
{0x1166, 0x0017, 0xFFFF, 0xFFFF, "GCNB-LE Host Bridge(0x0017)"},
{0x1166, 0x0031, 0xFFFF, 0xFFFF, "HT1100 HPX0 HT Host Bridge(0x0031)"},
{0x1166, 0x0036, 0xFFFF, 0xFFFF, "BCM5785 [HT1000] PCI/PCI-X Bridge(0x0036)"},
{0x1166, 0x0101, 0xFFFF, 0xFFFF, "CIOB-X2 PCI-X I/O Bridge(0x0101)"},
{0x1166, 0x0103, 0xFFFF, 0xFFFF, "EPB PCI-Express to PCI-X Bridge(0x0103)"},
{0x1166, 0x0104, 0xFFFF, 0xFFFF, "BCM5785 [HT1000] PCI/PCI-X Bridge(0x0104)"},
{0x1166, 0x0110, 0xFFFF, 0xFFFF, "CIOB-E I/O Bridge with Gigabit Ethernet(0x0110)"},
{0x1166, 0x0130, 0xFFFF, 0xFFFF, "BCM5780 [HT2000] PCI-X bridge(0x0130)"},
{0x1166, 0x0132, 0xFFFF, 0xFFFF, "BCM5780 [HT2000] PCI-Express Bridge(0x0132)"},
{0x1166, 0x0132, 0x1166, 0x0132, "HT2000 PCI-Express bridge(0x1166-0x0132)"},
{0x1166, 0x0140, 0xFFFF, 0xFFFF, "HT2100 PCI-Express Bridge(0x0140)"},
{0x1166, 0x0141, 0xFFFF, 0xFFFF, "HT2100 PCI-Express Bridge(0x0141)"},
{0x1166, 0x0142, 0xFFFF, 0xFFFF, "HT2100 PCI-Express Bridge(0x0142)"},
{0x1166, 0x0144, 0xFFFF, 0xFFFF, "HT2100 PCI-Express Bridge(0x0144)"},
{0x1166, 0x0200, 0xFFFF, 0xFFFF, "OSB4 South Bridge(0x0200)"},
{0x1166, 0x0201, 0xFFFF, 0xFFFF, "CSB5 South Bridge(0x0201)"},
{0x1166, 0x0201, 0x4C53, 0x1080, "CT8 mainboard(0x4C53-0x1080)"},
{0x1166, 0x0203, 0xFFFF, 0xFFFF, "CSB6 South Bridge(0x0203)"},
{0x1166, 0x0203, 0x1734, 0x1012, "PRIMERGY RX/TX series(0x1734-0x1012)"},
{0x1166, 0x0205, 0xFFFF, 0xFFFF, "BCM5785 [HT1000] Legacy South Bridge(0x0205)"},
{0x1166, 0x0211, 0xFFFF, 0xFFFF, "OSB4 IDE Controller(0x0211)"},
{0x1166, 0x0212, 0xFFFF, 0xFFFF, "CSB5 IDE Controller(0x0212)"},
{0x1166, 0x0212, 0x1028, 0x014A, "PowerEdge 1750(0x1028-0x014A)"},
{0x1166, 0x0212, 0x1028, 0x810B, "PowerEdge 1650/2550(0x1028-0x810B)"},
{0x1166, 0x0212, 0x4C53, 0x1080, "CT8 mainboard(0x4C53-0x1080)"},
{0x1166, 0x0213, 0xFFFF, 0xFFFF, "CSB6 RAID/IDE Controller(0x0213)"},
{0x1166, 0x0213, 0x1028, 0x4134, "PowerEdge 600SC(0x1028-0x4134)"},
{0x1166, 0x0213, 0x1028, 0xC134, "Poweredge SC600(0x1028-0xC134)"},
{0x1166, 0x0213, 0x1734, 0x1012, "PRIMERGY RX/TX series onboard IDE(0x1734-0x1012)"},
{0x1166, 0x0214, 0xFFFF, 0xFFFF, "BCM5785 [HT1000] IDE(0x0214)"},
{0x1166, 0x0214, 0x1028, 0x0205, "PowerEdge 2970 HT1000 IDE(0x1028-0x0205)"},
{0x1166, 0x0217, 0xFFFF, 0xFFFF, "CSB6 IDE Controller(0x0217)"},
{0x1166, 0x0217, 0x1028, 0x4134, "Poweredge SC600(0x1028-0x4134)"},
{0x1166, 0x021B, 0xFFFF, 0xFFFF, "HT1100 HD Audio(0x021B)"},
{0x1166, 0x0220, 0xFFFF, 0xFFFF, "OSB4/CSB5 OHCI USB Controller(0x0220)"},
{0x1166, 0x0220, 0x4C53, 0x1080, "CT8 mainboard(0x4C53-0x1080)"},
{0x1166, 0x0221, 0xFFFF, 0xFFFF, "CSB6 OHCI USB Controller(0x0221)"},
{0x1166, 0x0221, 0x1734, 0x1012, "PRIMERGY RX/TX series onboard OHCI(0x1734-0x1012)"},
{0x1166, 0x0223, 0xFFFF, 0xFFFF, "BCM5785 [HT1000] USB(0x0223)"},
{0x1166, 0x0223, 0x1028, 0x0205, "PowerEdge 2970 HT1000 USB Controller(0x1028-0x0205)"},
{0x1166, 0x0223, 0x1028, 0x020B, "PowerEdge T605 HT1000 USB Controller(0x1028-0x020B)"},
{0x1166, 0x0225, 0xFFFF, 0xFFFF, "CSB5 LPC bridge(0x0225)"},
{0x1166, 0x0227, 0xFFFF, 0xFFFF, "GCLE-2 Host Bridge(0x0227)"},
{0x1166, 0x0227, 0x1734, 0x1012, "PRIMERGY RX/TX series(0x1734-0x1012)"},
{0x1166, 0x0230, 0xFFFF, 0xFFFF, "CSB5 LPC bridge(0x0230)"},
{0x1166, 0x0230, 0x4C53, 0x1080, "CT8 mainboard(0x4C53-0x1080)"},
{0x1166, 0x0234, 0xFFFF, 0xFFFF, "BCM5785 [HT1000] LPC(0x0234)"},
{0x1166, 0x0234, 0x1028, 0x0205, "PowerEdge 2970 HT1000 LPC(0x1028-0x0205)"},
{0x1166, 0x0234, 0x1028, 0x020B, "PowerEdge T605 HT1000 LPC(0x1028-0x020B)"},
{0x1166, 0x0235, 0xFFFF, 0xFFFF, "BCM5785 [HT1000] XIOAPIC0-2(0x0235)"},
{0x1166, 0x0238, 0xFFFF, 0xFFFF, "BCM5785 [HT1000] WDTimer(0x0238)"},
{0x1166, 0x0240, 0xFFFF, 0xFFFF, "K2 SATA(0x0240)"},
{0x1166, 0x0241, 0xFFFF, 0xFFFF, "RAIDCore RC4000(0x0241)"},
{0x1166, 0x0242, 0xFFFF, 0xFFFF, "RAIDCore BC4000(0x0242)"},
{0x1166, 0x024A, 0xFFFF, 0xFFFF, "BCM5785 [HT1000] SATA (Native SATA Mode)(0x024A)"},
{0x1166, 0x024A, 0x1028, 0x020B, "PowerEdge T605 onboard SATA Controller(0x1028-0x020B)"},
{0x1166, 0x024B, 0xFFFF, 0xFFFF, "BCM5785 [HT1000] SATA (PATA/IDE Mode)(0x024B)"},
{0x1166, 0x024B, 0x1028, 0x0205, "PowerEdge 2970 HT1000 SATA controller(0x1028-0x0205)"},
{0x1166, 0x0406, 0xFFFF, 0xFFFF, "HT1100 PCI-X Bridge(0x0406)"},
{0x1166, 0x0408, 0xFFFF, 0xFFFF, "HT1100 Legacy Device(0x0408)"},
{0x1166, 0x040A, 0xFFFF, 0xFFFF, "HT1100 ISA-LPC Bridge(0x040A)"},
{0x1166, 0x040A, 0x1028, 0x0223, "PowerEdge R905 HT1100 ISA-LPC Bridge(0x1028-0x0223)"},
{0x1166, 0x0410, 0xFFFF, 0xFFFF, "HT1100 SATA Controller (Native SATA Mode)(0x0410)"},
{0x1166, 0x0411, 0xFFFF, 0xFFFF, "HT1100 SATA Controller (PATA / IDE Mode)(0x0411)"},
{0x1166, 0x0412, 0xFFFF, 0xFFFF, "HT1100 USB OHCI Controller(0x0412)"},
{0x1166, 0x0414, 0xFFFF, 0xFFFF, "HT1100 USB EHCI Controller(0x0414)"},
{0x1166, 0x0416, 0xFFFF, 0xFFFF, "HT1100 USB EHCI Controller (with Debug Port)(0x0416)"},
{0x1166, 0x0420, 0xFFFF, 0xFFFF, "HT1100 PCI-Express Bridge(0x0420)"},
{0x1166, 0x0421, 0xFFFF, 0xFFFF, "HT1100 SAS/SATA Controller(0x0421)"},
{0x1166, 0x0422, 0xFFFF, 0xFFFF, "HT1100 PCI-Express Bridge(0x0422)"},
}; /* pci_vid_1166[] */

static pci_id_t const pci_vid_1167[] = {
{0x1167, 0xFFFF, 0xFFFF, 0xFFFF, "Mutoh Industries Inc(0x1167)"},
}; /* pci_vid_1167[] */

static pci_id_t const pci_vid_1168[] = {
{0x1168, 0xFFFF, 0xFFFF, 0xFFFF, "Thine Electronics Inc(0x1168)"},
}; /* pci_vid_1168[] */

static pci_id_t const pci_vid_1169[] = {
{0x1169, 0xFFFF, 0xFFFF, 0xFFFF, "Centre for Development of Advanced Computing(0x1169)"},
}; /* pci_vid_1169[] */

static pci_id_t const pci_vid_116A[] = {
{0x116A, 0xFFFF, 0xFFFF, 0xFFFF, "Luminex Software, Inc.(0x116A)"},
{0x116A, 0x6100, 0xFFFF, 0xFFFF, "Bus/Tag Channel(0x6100)"},
{0x116A, 0x6800, 0xFFFF, 0xFFFF, "Escon Channel(0x6800)"},
{0x116A, 0x7100, 0xFFFF, 0xFFFF, "Bus/Tag Channel(0x7100)"},
{0x116A, 0x7800, 0xFFFF, 0xFFFF, "Escon Channel(0x7800)"},
}; /* pci_vid_116A[] */

static pci_id_t const pci_vid_116B[] = {
{0x116B, 0xFFFF, 0xFFFF, 0xFFFF, "Connectware Inc(0x116B)"},
}; /* pci_vid_116B[] */

static pci_id_t const pci_vid_116C[] = {
{0x116C, 0xFFFF, 0xFFFF, 0xFFFF, "Intelligent Resources Integrated Systems(0x116C)"},
}; /* pci_vid_116C[] */

static pci_id_t const pci_vid_116D[] = {
{0x116D, 0xFFFF, 0xFFFF, 0xFFFF, "Martin-Marietta(0x116D)"},
}; /* pci_vid_116D[] */

static pci_id_t const pci_vid_116E[] = {
{0x116E, 0xFFFF, 0xFFFF, 0xFFFF, "Electronics for Imaging(0x116E)"},
}; /* pci_vid_116E[] */

static pci_id_t const pci_vid_116F[] = {
{0x116F, 0xFFFF, 0xFFFF, 0xFFFF, "Workstation Technology(0x116F)"},
}; /* pci_vid_116F[] */

static pci_id_t const pci_vid_1170[] = {
{0x1170, 0xFFFF, 0xFFFF, 0xFFFF, "Inventec Corporation(0x1170)"},
}; /* pci_vid_1170[] */

static pci_id_t const pci_vid_1171[] = {
{0x1171, 0xFFFF, 0xFFFF, 0xFFFF, "Loughborough Sound Images Plc(0x1171)"},
}; /* pci_vid_1171[] */

static pci_id_t const pci_vid_1172[] = {
{0x1172, 0xFFFF, 0xFFFF, 0xFFFF, "Altera Corporation(0x1172)"},
{0x1172, 0x00A7, 0xFFFF, 0xFFFF, "Stratix V(0x00A7)"},
{0x1172, 0x0530, 0xFFFF, 0xFFFF, "Stratix IV(0x0530)"},
{0x1172, 0x646C, 0xFFFF, 0xFFFF, "KT-500/KT-521 board(0x646C)"},
}; /* pci_vid_1172[] */

static pci_id_t const pci_vid_1173[] = {
{0x1173, 0xFFFF, 0xFFFF, 0xFFFF, "Adobe Systems, Inc(0x1173)"},
}; /* pci_vid_1173[] */

static pci_id_t const pci_vid_1174[] = {
{0x1174, 0xFFFF, 0xFFFF, 0xFFFF, "Bridgeport Machines(0x1174)"},
}; /* pci_vid_1174[] */

static pci_id_t const pci_vid_1175[] = {
{0x1175, 0xFFFF, 0xFFFF, 0xFFFF, "Mitron Computer Inc.(0x1175)"},
}; /* pci_vid_1175[] */

static pci_id_t const pci_vid_1176[] = {
{0x1176, 0xFFFF, 0xFFFF, 0xFFFF, "SBE Incorporated(0x1176)"},
}; /* pci_vid_1176[] */

static pci_id_t const pci_vid_1177[] = {
{0x1177, 0xFFFF, 0xFFFF, 0xFFFF, "Silicon Engineering(0x1177)"},
}; /* pci_vid_1177[] */

static pci_id_t const pci_vid_1178[] = {
{0x1178, 0xFFFF, 0xFFFF, 0xFFFF, "Alfa, Inc.(0x1178)"},
{0x1178, 0xAFA1, 0xFFFF, 0xFFFF, "Fast Ethernet Adapter(0xAFA1)"},
}; /* pci_vid_1178[] */

static pci_id_t const pci_vid_1179[] = {
{0x1179, 0xFFFF, 0xFFFF, 0xFFFF, "Toshiba Corporation(0x1179)"},
{0x1179, 0x0102, 0xFFFF, 0xFFFF, "Extended IDE Controller(0x0102)"},
{0x1179, 0x0103, 0xFFFF, 0xFFFF, "EX-IDE Type-B(0x0103)"},
{0x1179, 0x010E, 0xFFFF, 0xFFFF, "PXP04 NVMe SSD(0x010E)"},
{0x1179, 0x010F, 0xFFFF, 0xFFFF, "XG3 NVMe SSD Controller(0x010F)"},
{0x1179, 0x0110, 0xFFFF, 0xFFFF, "Cx5 NVMe SSD Controller(0x0110)"},
{0x1179, 0x0110, 0x1028, 0x1FFB, "Express Flash NVMe 960G (RI) U.2 (CD5)(0x1028-0x1FFB)"},
{0x1179, 0x0110, 0x1028, 0x1FFC, "Express Flash NVMe 1.92T (RI) U.2 (CD5)(0x1028-0x1FFC)"},
{0x1179, 0x0110, 0x1028, 0x1FFD, "Express Flash NVMe 3.84T (RI) U.2 (CD5)(0x1028-0x1FFD)"},
{0x1179, 0x0110, 0x1028, 0x1FFE, "Express Flash NVMe 7.68T (RI) U.2 (CD5)(0x1028-0x1FFE)"},
{0x1179, 0x0110, 0x1179, 0x0001, "KIOXIA CM5-R series SSD(0x1179-0x0001)"},
{0x1179, 0x0110, 0x1179, 0x0021, "KIOXIA CD5 series SSD(0x1179-0x0021)"},
{0x1179, 0x0110, 0x1D49, 0x4039, "Thinksystem U.2 CM5 NVMe SSD(0x1D49-0x4039)"},
{0x1179, 0x0110, 0x1D49, 0x403A, "Thinksystem AIC CM5 NVMe SSD(0x1D49-0x403A)"},
{0x1179, 0x0113, 0xFFFF, 0xFFFF, "BG3 x2 NVMe SSD Controller (DRAM-less)(0x0113)"},
{0x1179, 0x0113, 0x1179, 0x0001, "Toshiba KBG30ZMS128G 128GB NVMe SSD(0x1179-0x0001)"},
{0x1179, 0x0115, 0xFFFF, 0xFFFF, "XG4 NVMe SSD Controller(0x0115)"},
{0x1179, 0x0116, 0xFFFF, 0xFFFF, "XG5 NVMe SSD Controller(0x0116)"},
{0x1179, 0x0116, 0x1179, 0x0001, "XG5 NVMe SSD Controller(0x1179-0x0001)"},
{0x1179, 0x011A, 0xFFFF, 0xFFFF, "XG6 NVMe SSD Controller(0x011A)"},
{0x1179, 0x0404, 0xFFFF, 0xFFFF, "DVD Decoder card(0x0404)"},
{0x1179, 0x0406, 0xFFFF, 0xFFFF, "Tecra Video Capture device(0x0406)"},
{0x1179, 0x0407, 0xFFFF, 0xFFFF, "DVD Decoder card (Version 2)(0x0407)"},
{0x1179, 0x0601, 0xFFFF, 0xFFFF, "CPU to PCI bridge(0x0601)"},
{0x1179, 0x0601, 0x1179, 0x0001, "Satellite Pro(0x1179-0x0001)"},
{0x1179, 0x0602, 0xFFFF, 0xFFFF, "PCI to ISA bridge(0x0602)"},
{0x1179, 0x0603, 0xFFFF, 0xFFFF, "ToPIC95 PCI to CardBus Bridge for Notebooks(0x0603)"},
{0x1179, 0x0604, 0xFFFF, 0xFFFF, "PCI-Docking Host bridge(0x0604)"},
{0x1179, 0x060A, 0xFFFF, 0xFFFF, "ToPIC95(0x060A)"},
{0x1179, 0x060A, 0x1179, 0x0001, "Satellite Pro(0x1179-0x0001)"},
{0x1179, 0x060F, 0xFFFF, 0xFFFF, "ToPIC97(0x060F)"},
{0x1179, 0x060F, 0x1179, 0x0001, "Satellite 4010(0x1179-0x0001)"},
{0x1179, 0x0617, 0xFFFF, 0xFFFF, "ToPIC100 PCI to Cardbus Bridge with ZV Support(0x0617)"},
{0x1179, 0x0618, 0xFFFF, 0xFFFF, "CPU to PCI and PCI to ISA bridge(0x0618)"},
{0x1179, 0x0701, 0xFFFF, 0xFFFF, "FIR Port Type-O(0x0701)"},
{0x1179, 0x0803, 0xFFFF, 0xFFFF, "TC6371AF SD Host Controller(0x0803)"},
{0x1179, 0x0804, 0xFFFF, 0xFFFF, "TC6371AF SmartMedia Controller(0x0804)"},
{0x1179, 0x0805, 0xFFFF, 0xFFFF, "SD TypA Controller(0x0805)"},
{0x1179, 0x0D01, 0xFFFF, 0xFFFF, "FIR Port Type-DO(0x0D01)"},
{0x1179, 0x0D01, 0x1179, 0x0001, "FIR Port Type-DO(0x1179-0x0001)"},
{0x1179, 0x9602, 0xFFFF, 0xFFFF, "RS780/RS880 PCI to PCI bridge (int gfx)(0x9602)"},
}; /* pci_vid_1179[] */

static pci_id_t const pci_vid_117A[] = {
{0x117A, 0xFFFF, 0xFFFF, 0xFFFF, "A-Trend Technology(0x117A)"},
}; /* pci_vid_117A[] */

static pci_id_t const pci_vid_117B[] = {
{0x117B, 0xFFFF, 0xFFFF, 0xFFFF, "L G Electronics, Inc.(0x117B)"},
}; /* pci_vid_117B[] */

static pci_id_t const pci_vid_117C[] = {
{0x117C, 0xFFFF, 0xFFFF, 0xFFFF, "ATTO Technology, Inc.(0x117C)"},
{0x117C, 0x002C, 0xFFFF, 0xFFFF, "ExpressSAS R380(0x002C)"},
{0x117C, 0x002D, 0xFFFF, 0xFFFF, "ExpressSAS R348(0x002D)"},
{0x117C, 0x0030, 0xFFFF, 0xFFFF, "Ultra320 SCSI Host Adapter(0x0030)"},
{0x117C, 0x0030, 0x117C, 0x8013, "ExpressPCI UL4D(0x117C-0x8013)"},
{0x117C, 0x0030, 0x117C, 0x8014, "ExpressPCI UL4S(0x117C-0x8014)"},
{0x117C, 0x0030, 0x117C, 0x8027, "ExpressPCI UL5D(0x117C-0x8027)"},
{0x117C, 0x0030, 0x117C, 0x802F, "ExpressPCI UL5D Low Profile(0x117C-0x802F)"},
{0x117C, 0x0033, 0xFFFF, 0xFFFF, "SAS Adapter(0x0033)"},
{0x117C, 0x0041, 0xFFFF, 0xFFFF, "ExpressSAS R30F(0x0041)"},
{0x117C, 0x0042, 0xFFFF, 0xFFFF, "ExpressSAS 6Gb/s SAS/SATA HBA(0x0042)"},
{0x117C, 0x0042, 0x117C, 0x0042, "ExpressSAS H680(0x117C-0x0042)"},
{0x117C, 0x0042, 0x117C, 0x0043, "ExpressSAS H608(0x117C-0x0043)"},
{0x117C, 0x0042, 0x117C, 0x0044, "ExpressSAS H60F(0x117C-0x0044)"},
{0x117C, 0x0042, 0x117C, 0x0045, "ExpressSAS H6F0(0x117C-0x0045)"},
{0x117C, 0x0042, 0x117C, 0x0046, "ExpressSAS H644(0x117C-0x0046)"},
{0x117C, 0x0042, 0x117C, 0x004F, "ExpressSAS M608(0x117C-0x004F)"},
{0x117C, 0x0042, 0x117C, 0x0057, "ExpressSAS M680(0x117C-0x0057)"},
{0x117C, 0x0042, 0x117C, 0x0058, "ExpressSAS M644(0x117C-0x0058)"},
{0x117C, 0x0042, 0x117C, 0x0059, "ExpressSAS W608(0x117C-0x0059)"},
{0x117C, 0x0042, 0x117C, 0x005A, "ExpressSAS W680(0x117C-0x005A)"},
{0x117C, 0x0042, 0x117C, 0x005B, "ExpressSAS W644(0x117C-0x005B)"},
{0x117C, 0x0049, 0xFFFF, 0xFFFF, "ExpressSAS 6Gb SAS/SATA RAID Adapter(0x0049)"},
{0x117C, 0x0049, 0x117C, 0x0049, "ExpressSAS R680(0x117C-0x0049)"},
{0x117C, 0x0049, 0x117C, 0x004A, "ExpressSAS R608(0x117C-0x004A)"},
{0x117C, 0x0049, 0x117C, 0x004B, "ExpressSAS R60F(0x117C-0x004B)"},
{0x117C, 0x0049, 0x117C, 0x004C, "ExpressSAS R6F0(0x117C-0x004C)"},
{0x117C, 0x0049, 0x117C, 0x004D, "ExpressSAS R644(0x117C-0x004D)"},
{0x117C, 0x0049, 0x117C, 0x004E, "ExpressSAS R648(0x117C-0x004E)"},
{0x117C, 0x0064, 0xFFFF, 0xFFFF, "Celerity FC 16Gb/s Gen 5 Fibre Channel HBA(0x0064)"},
{0x117C, 0x0064, 0x117C, 0x0063, "Celerity FC-161E(0x117C-0x0063)"},
{0x117C, 0x0064, 0x117C, 0x0064, "Celerity FC-162E(0x117C-0x0064)"},
{0x117C, 0x0064, 0x117C, 0x0065, "Celerity FC-164E(0x117C-0x0065)"},
{0x117C, 0x0094, 0xFFFF, 0xFFFF, "Celerity FC 16/32Gb/s Gen 6 Fibre Channel HBA(0x0094)"},
{0x117C, 0x0094, 0x117C, 0x0094, "Celerity FC-162P(0x117C-0x0094)"},
{0x117C, 0x0094, 0x117C, 0x00A0, "Celerity FC-161P(0x117C-0x00A0)"},
{0x117C, 0x0094, 0x117C, 0x00A1, "Celerity FC-164P(0x117C-0x00A1)"},
{0x117C, 0x0094, 0x117C, 0x00A2, "Celerity FC-321E(0x117C-0x00A2)"},
{0x117C, 0x0094, 0x117C, 0x00A3, "Celerity FC-322E(0x117C-0x00A3)"},
{0x117C, 0x0094, 0x117C, 0x00AC, "Celerity FC-324E(0x117C-0x00AC)"},
{0x117C, 0x00BB, 0xFFFF, 0xFFFF, "Celerity FC 32/64Gb/s Gen 7 Fibre Channel HBA(0x00BB)"},
{0x117C, 0x00BB, 0x117C, 0x00BC, "Celerity FC-321P(0x117C-0x00BC)"},
{0x117C, 0x00BB, 0x117C, 0x00BD, "Celerity FC-322P(0x117C-0x00BD)"},
{0x117C, 0x00BB, 0x117C, 0x00BE, "Celerity FC-324P(0x117C-0x00BE)"},
{0x117C, 0x00BB, 0x117C, 0x00C9, "Celerity FC-641E(0x117C-0x00C9)"},
{0x117C, 0x00BB, 0x117C, 0x00CA, "Celerity FC-642E(0x117C-0x00CA)"},
{0x117C, 0x00C5, 0xFFFF, 0xFFFF, "ExpressNVM PCIe Gen4 Switch(0x00C5)"},
{0x117C, 0x00C5, 0x117C, 0x00C6, "ExpressNVM S48F PCIe Gen4(0x117C-0x00C6)"},
{0x117C, 0x00C5, 0x117C, 0x00C7, "ExpressNVM S468 PCIe Gen4(0x117C-0x00C7)"},
{0x117C, 0x00E6, 0xFFFF, 0xFFFF, "ExpressSAS GT 12Gb/s SAS/SATA HBA(0x00E6)"},
{0x117C, 0x00E6, 0x117C, 0x00C0, "ExpressSAS H1280 GT(0x117C-0x00C0)"},
{0x117C, 0x00E6, 0x117C, 0x00C1, "ExpressSAS H1208 GT(0x117C-0x00C1)"},
{0x117C, 0x00E6, 0x117C, 0x00C2, "ExpressSAS H1244 GT(0x117C-0x00C2)"},
{0x117C, 0x00E6, 0x117C, 0x00C3, "ExpressSAS H12F0 GT(0x117C-0x00C3)"},
{0x117C, 0x00E6, 0x117C, 0x00C4, "ExpressSAS H120F GT(0x117C-0x00C4)"},
{0x117C, 0x8013, 0xFFFF, 0xFFFF, "ExpressPCI UL4D(0x8013)"},
{0x117C, 0x8014, 0xFFFF, 0xFFFF, "ExpressPCI UL4S(0x8014)"},
{0x117C, 0x8027, 0xFFFF, 0xFFFF, "ExpressPCI UL5D(0x8027)"},
{0x117C, 0x8070, 0xFFFF, 0xFFFF, "ExpressSAS 12Gb/s SAS/SATA HBA(0x8070)"},
{0x117C, 0x8070, 0x117C, 0x0070, "ExpressSAS H1280(0x117C-0x0070)"},
{0x117C, 0x8070, 0x117C, 0x0071, "ExpressSAS H1208(0x117C-0x0071)"},
{0x117C, 0x8070, 0x117C, 0x0080, "ExpressSAS H1244(0x117C-0x0080)"},
{0x117C, 0x8072, 0xFFFF, 0xFFFF, "ExpressSAS 12Gb/s SAS/SATA HBA(0x8072)"},
{0x117C, 0x8072, 0x117C, 0x0072, "ExpressSAS H12F0(0x117C-0x0072)"},
{0x117C, 0x8072, 0x117C, 0x0073, "ExpressSAS H120F(0x117C-0x0073)"},
{0x117C, 0x8072, 0x117C, 0x0082, "ExpressSAS H1288(0x117C-0x0082)"},
}; /* pci_vid_117C[] */

static pci_id_t const pci_vid_117D[] = {
{0x117D, 0xFFFF, 0xFFFF, 0xFFFF, "Becton & Dickinson(0x117D)"},
}; /* pci_vid_117D[] */

static pci_id_t const pci_vid_117E[] = {
{0x117E, 0xFFFF, 0xFFFF, 0xFFFF, "T/R Systems(0x117E)"},
}; /* pci_vid_117E[] */

static pci_id_t const pci_vid_117F[] = {
{0x117F, 0xFFFF, 0xFFFF, 0xFFFF, "Integrated Circuit Systems(0x117F)"},
}; /* pci_vid_117F[] */

static pci_id_t const pci_vid_1180[] = {
{0x1180, 0xFFFF, 0xFFFF, 0xFFFF, "Ricoh Co Ltd(0x1180)"},
{0x1180, 0x0465, 0xFFFF, 0xFFFF, "RL5c465(0x0465)"},
{0x1180, 0x0466, 0xFFFF, 0xFFFF, "RL5c466(0x0466)"},
{0x1180, 0x0475, 0xFFFF, 0xFFFF, "RL5c475(0x0475)"},
{0x1180, 0x0475, 0x144D, 0xC006, "vpr Matrix 170B4 CardBus bridge(0x144D-0xC006)"},
{0x1180, 0x0476, 0xFFFF, 0xFFFF, "RL5c476 II(0x0476)"},
{0x1180, 0x0476, 0x1014, 0x0185, "ThinkPad A/T/X Series(0x1014-0x0185)"},
{0x1180, 0x0476, 0x1014, 0x0555, "ThinkPad X41(0x1014-0x0555)"},
{0x1180, 0x0476, 0x1014, 0x056C, "ThinkPad Z60t(0x1014-0x056C)"},
{0x1180, 0x0476, 0x1028, 0x014F, "Latitude X300 laptop(0x1028-0x014F)"},
{0x1180, 0x0476, 0x1028, 0x0188, "Inspiron 6000 laptop(0x1028-0x0188)"},
{0x1180, 0x0476, 0x103C, 0x30C0, "Compaq 6710b(0x103C-0x30C0)"},
{0x1180, 0x0476, 0x103C, 0x30C1, "Compaq 6910p(0x103C-0x30C1)"},
{0x1180, 0x0476, 0x1043, 0x1017, "X58LE(0x1043-0x1017)"},
{0x1180, 0x0476, 0x1043, 0x1237, "A6J-Q008(0x1043-0x1237)"},
{0x1180, 0x0476, 0x1043, 0x1967, "V6800V(0x1043-0x1967)"},
{0x1180, 0x0476, 0x1043, 0x1987, "A4K and Z81K notebooks, possibly others ( mid-2005 machines )(0x1043-0x1987)"},
{0x1180, 0x0476, 0x104D, 0x80DF, "Vaio PCG-FX403(0x104D-0x80DF)"},
{0x1180, 0x0476, 0x104D, 0x80E7, "VAIO PCG-GR214EP/GR214MP/GR215MP/GR314MP/GR315MP(0x104D-0x80E7)"},
{0x1180, 0x0476, 0x104D, 0x814E, "VAIO GRZ390Z(0x104D-0x814E)"},
{0x1180, 0x0476, 0x10F7, 0x8338, "Panasonic CF-Y5 laptop(0x10F7-0x8338)"},
{0x1180, 0x0476, 0x144D, 0xC005, "X10 Laptop(0x144D-0xC005)"},
{0x1180, 0x0476, 0x144D, 0xC00C, "P30/P35 notebook(0x144D-0xC00C)"},
{0x1180, 0x0476, 0x14EF, 0x0220, "PCD-RP-220S(0x14EF-0x0220)"},
{0x1180, 0x0476, 0x17AA, 0x201C, "ThinkPad X60/X60s(0x17AA-0x201C)"},
{0x1180, 0x0476, 0x17AA, 0x20C4, "ThinkPad T61/R61(0x17AA-0x20C4)"},
{0x1180, 0x0476, 0x17AA, 0x20C6, "ThinkPad R61/T400(0x17AA-0x20C6)"},
{0x1180, 0x0477, 0xFFFF, 0xFFFF, "RL5c477(0x0477)"},
{0x1180, 0x0478, 0xFFFF, 0xFFFF, "RL5c478(0x0478)"},
{0x1180, 0x0478, 0x1014, 0x0184, "ThinkPad A30p(0x1014-0x0184)"},
{0x1180, 0x0511, 0xFFFF, 0xFFFF, "R5C511(0x0511)"},
{0x1180, 0x0522, 0xFFFF, 0xFFFF, "R5C522 IEEE 1394 Controller(0x0522)"},
{0x1180, 0x0522, 0x1014, 0x01CF, "ThinkPad A30p(0x1014-0x01CF)"},
{0x1180, 0x0522, 0x1043, 0x1967, "V6800V(0x1043-0x1967)"},
{0x1180, 0x0551, 0xFFFF, 0xFFFF, "R5C551 IEEE 1394 Controller(0x0551)"},
{0x1180, 0x0551, 0x144D, 0xC006, "vpr Matrix 170B4(0x144D-0xC006)"},
{0x1180, 0x0552, 0xFFFF, 0xFFFF, "R5C552 IEEE 1394 Controller(0x0552)"},
{0x1180, 0x0552, 0x1014, 0x0511, "ThinkPad A/T/X Series(0x1014-0x0511)"},
{0x1180, 0x0552, 0x1028, 0x014F, "Latitude X300 laptop(0x1028-0x014F)"},
{0x1180, 0x0552, 0x1028, 0x0188, "Inspiron 6000 laptop(0x1028-0x0188)"},
{0x1180, 0x0552, 0x1043, 0x1237, "A6J-Q008(0x1043-0x1237)"},
{0x1180, 0x0552, 0x1043, 0x1757, "M2400N laptop(0x1043-0x1757)"},
{0x1180, 0x0552, 0x144D, 0xC005, "X10 Laptop(0x144D-0xC005)"},
{0x1180, 0x0552, 0x144D, 0xC00C, "P30/P35 notebook(0x144D-0xC00C)"},
{0x1180, 0x0552, 0x17AA, 0x201E, "ThinkPad X60/X60s(0x17AA-0x201E)"},
{0x1180, 0x0554, 0xFFFF, 0xFFFF, "R5C554(0x0554)"},
{0x1180, 0x0575, 0xFFFF, 0xFFFF, "R5C575 SD Bus Host Adapter(0x0575)"},
{0x1180, 0x0576, 0xFFFF, 0xFFFF, "R5C576 SD Bus Host Adapter(0x0576)"},
{0x1180, 0x0592, 0xFFFF, 0xFFFF, "R5C592 Memory Stick Bus Host Adapter(0x0592)"},
{0x1180, 0x0592, 0x1025, 0x0121, "Aspire 5920G(0x1025-0x0121)"},
{0x1180, 0x0592, 0x1028, 0x01D7, "XPS M1210(0x1028-0x01D7)"},
{0x1180, 0x0592, 0x1028, 0x01F3, "Inspiron 1420(0x1028-0x01F3)"},
{0x1180, 0x0592, 0x1028, 0x022F, "Inspiron 1525(0x1028-0x022F)"},
{0x1180, 0x0592, 0x103C, 0x1521, "HP EliteBook 8540w(0x103C-0x1521)"},
{0x1180, 0x0592, 0x103C, 0x30B5, "Presario V3242AU(0x103C-0x30B5)"},
{0x1180, 0x0592, 0x103C, 0x30B7, "Presario V6133CL(0x103C-0x30B7)"},
{0x1180, 0x0592, 0x103C, 0x30CC, "Pavilion dv6700(0x103C-0x30CC)"},
{0x1180, 0x0592, 0x103C, 0x30CF, "Pavilion dv95xx/96xx/97xx/98xx series(0x103C-0x30CF)"},
{0x1180, 0x0592, 0x1043, 0x1017, "X58LE(0x1043-0x1017)"},
{0x1180, 0x0592, 0x1043, 0x1237, "A6J-Q008(0x1043-0x1237)"},
{0x1180, 0x0592, 0x1043, 0x1967, "V6800V(0x1043-0x1967)"},
{0x1180, 0x0592, 0x104D, 0x9035, "VAIO VGN-FW11ZRU(0x104D-0x9035)"},
{0x1180, 0x0592, 0x144D, 0xC018, "X20 IV(0x144D-0xC018)"},
{0x1180, 0x0592, 0x17AA, 0x20CA, "ThinkPad T61/T400(0x17AA-0x20CA)"},
{0x1180, 0x0811, 0xFFFF, 0xFFFF, "R5C811(0x0811)"},
{0x1180, 0x0822, 0xFFFF, 0xFFFF, "R5C822 SD/SDIO/MMC/MS/MSPro Host Adapter(0x0822)"},
{0x1180, 0x0822, 0x1014, 0x0556, "ThinkPad X40 / X41 / X60s / Z60t(0x1014-0x0556)"},
{0x1180, 0x0822, 0x1014, 0x0598, "ThinkPad Z60m(0x1014-0x0598)"},
{0x1180, 0x0822, 0x1025, 0x0121, "Aspire 5920G(0x1025-0x0121)"},
{0x1180, 0x0822, 0x1028, 0x0188, "Inspiron 6000 laptop(0x1028-0x0188)"},
{0x1180, 0x0822, 0x1028, 0x01A2, "Inspiron 9200(0x1028-0x01A2)"},
{0x1180, 0x0822, 0x1028, 0x01D7, "XPS M1210(0x1028-0x01D7)"},
{0x1180, 0x0822, 0x1028, 0x01F3, "Inspiron 1420(0x1028-0x01F3)"},
{0x1180, 0x0822, 0x1028, 0x022F, "Inspiron 1525(0x1028-0x022F)"},
{0x1180, 0x0822, 0x103C, 0x03B5, "Presario V3242AU(0x103C-0x03B5)"},
{0x1180, 0x0822, 0x103C, 0x30B7, "Presario V6133CL(0x103C-0x30B7)"},
{0x1180, 0x0822, 0x103C, 0x30C1, "Compaq 6910p(0x103C-0x30C1)"},
{0x1180, 0x0822, 0x103C, 0x30CC, "Pavilion dv6700(0x103C-0x30CC)"},
{0x1180, 0x0822, 0x103C, 0x30CF, "Pavilion dv9668eg Laptop(0x103C-0x30CF)"},
{0x1180, 0x0822, 0x1043, 0x1017, "X58LE(0x1043-0x1017)"},
{0x1180, 0x0822, 0x1043, 0x1237, "A6J-Q008(0x1043-0x1237)"},
{0x1180, 0x0822, 0x1043, 0x1967, "V6800V(0x1043-0x1967)"},
{0x1180, 0x0822, 0x10F7, 0x8338, "Panasonic CF-Y5 laptop(0x10F7-0x8338)"},
{0x1180, 0x0822, 0x144D, 0xC018, "X20 IV(0x144D-0xC018)"},
{0x1180, 0x0822, 0x17AA, 0x201D, "ThinkPad X60/X60s(0x17AA-0x201D)"},
{0x1180, 0x0822, 0x17AA, 0x20C7, "ThinkPad T61(0x17AA-0x20C7)"},
{0x1180, 0x0822, 0x17AA, 0x20C8, "ThinkPad T400/W500(0x17AA-0x20C8)"},
{0x1180, 0x0832, 0xFFFF, 0xFFFF, "R5C832 IEEE 1394 Controller(0x0832)"},
{0x1180, 0x0832, 0x1025, 0x0121, "Aspire 5920G(0x1025-0x0121)"},
{0x1180, 0x0832, 0x1028, 0x01D7, "XPS M1210(0x1028-0x01D7)"},
{0x1180, 0x0832, 0x1028, 0x01F3, "Inspiron 1420(0x1028-0x01F3)"},
{0x1180, 0x0832, 0x1028, 0x022F, "Inspiron 1525(0x1028-0x022F)"},
{0x1180, 0x0832, 0x1028, 0x024D, "Latitude E4300(0x1028-0x024D)"},
{0x1180, 0x0832, 0x103C, 0x30B5, "Presario V3242AU(0x103C-0x30B5)"},
{0x1180, 0x0832, 0x103C, 0x30B7, "Presario V6133CL(0x103C-0x30B7)"},
{0x1180, 0x0832, 0x103C, 0x30C1, "Compaq 6910p(0x103C-0x30C1)"},
{0x1180, 0x0832, 0x103C, 0x30CC, "Pavilion dv6700(0x103C-0x30CC)"},
{0x1180, 0x0832, 0x103C, 0x30CF, "Pavilion dv9668eg Laptop(0x103C-0x30CF)"},
{0x1180, 0x0832, 0x17AA, 0x20C5, "ThinkPad R61(0x17AA-0x20C5)"},
{0x1180, 0x0832, 0x17AA, 0x20C7, "ThinkPad R61(0x17AA-0x20C7)"},
{0x1180, 0x0841, 0xFFFF, 0xFFFF, "R5C841 CardBus/SD/SDIO/MMC/MS/MSPro/xD/IEEE1394(0x0841)"},
{0x1180, 0x0843, 0xFFFF, 0xFFFF, "R5C843 MMC Host Controller(0x0843)"},
{0x1180, 0x0843, 0x1025, 0x0121, "Aspire 5920G(0x1025-0x0121)"},
{0x1180, 0x0843, 0x1028, 0x01D7, "XPS M1210(0x1028-0x01D7)"},
{0x1180, 0x0843, 0x1028, 0x01F3, "Inspiron 1420(0x1028-0x01F3)"},
{0x1180, 0x0843, 0x1028, 0x01F5, "Inspiron 1501(0x1028-0x01F5)"},
{0x1180, 0x0843, 0x1028, 0x024F, "Latitude e6500(0x1028-0x024F)"},
{0x1180, 0x0843, 0x103C, 0x03B5, "Presario V3242AU(0x103C-0x03B5)"},
{0x1180, 0x0843, 0x103C, 0x1521, "HP EliteBook 8540w(0x103C-0x1521)"},
{0x1180, 0x0843, 0x103C, 0x30B7, "Presario V6133CL(0x103C-0x30B7)"},
{0x1180, 0x0843, 0x103C, 0x30CF, "Pavilion dv9500/9600/9700 series(0x103C-0x30CF)"},
{0x1180, 0x0843, 0x1043, 0x1017, "X58LE(0x1043-0x1017)"},
{0x1180, 0x0843, 0x1183, 0x0843, "Alienware Aurora m9700(0x1183-0x0843)"},
{0x1180, 0x0852, 0xFFFF, 0xFFFF, "xD-Picture Card Controller(0x0852)"},
{0x1180, 0x0852, 0x1025, 0x0121, "Aspire 5920G(0x1025-0x0121)"},
{0x1180, 0x0852, 0x1028, 0x01F3, "Inspiron 1420(0x1028-0x01F3)"},
{0x1180, 0x0852, 0x1028, 0x022F, "Inspiron 1525(0x1028-0x022F)"},
{0x1180, 0x0852, 0x103C, 0x30B5, "Presario V3242AU(0x103C-0x30B5)"},
{0x1180, 0x0852, 0x103C, 0x30B7, "Presario V6133CL(0x103C-0x30B7)"},
{0x1180, 0x0852, 0x103C, 0x30CC, "Pavilion dv6700(0x103C-0x30CC)"},
{0x1180, 0x0852, 0x103C, 0x30CF, "Pavilion dv9668eg Laptop(0x103C-0x30CF)"},
{0x1180, 0x0852, 0x1043, 0x1967, "V6800V(0x1043-0x1967)"},
{0x1180, 0x0852, 0x1180, 0x0852, "Pavilion 2410us(0x1180-0x0852)"},
{0x1180, 0x0852, 0x1324, 0x10CF, "P7120(0x1324-0x10CF)"},
{0x1180, 0x0852, 0x17AA, 0x20CB, "ThinkPad T400(0x17AA-0x20CB)"},
{0x1180, 0xE230, 0xFFFF, 0xFFFF, "R5U2xx (R5U230 / R5U231 / R5U241) [Memory Stick Host Controller](0xE230)"},
{0x1180, 0xE476, 0xFFFF, 0xFFFF, "CardBus bridge(0xE476)"},
{0x1180, 0xE476, 0x1028, 0x040A, "Latitude E6410(0x1028-0x040A)"},
{0x1180, 0xE476, 0x1028, 0x040B, "Latitude E6510(0x1028-0x040B)"},
{0x1180, 0xE822, 0xFFFF, 0xFFFF, "MMC/SD Host Controller(0xE822)"},
{0x1180, 0xE822, 0x1028, 0x040A, "Latitude E6410(0x1028-0x040A)"},
{0x1180, 0xE822, 0x1028, 0x040B, "Latitude E6510(0x1028-0x040B)"},
{0x1180, 0xE822, 0x17AA, 0x21CF, "ThinkPad T520(0x17AA-0x21CF)"},
{0x1180, 0xE823, 0xFFFF, 0xFFFF, "PCIe SDXC/MMC Host Controller(0xE823)"},
{0x1180, 0xE823, 0x17AA, 0x21CF, "ThinkPad T520(0x17AA-0x21CF)"},
{0x1180, 0xE832, 0xFFFF, 0xFFFF, "R5C832 PCIe IEEE 1394 Controller(0xE832)"},
{0x1180, 0xE832, 0x1028, 0x040A, "Latitude E6410(0x1028-0x040A)"},
{0x1180, 0xE832, 0x1028, 0x040B, "Latitude E6510(0x1028-0x040B)"},
{0x1180, 0xE832, 0x17AA, 0x21CF, "ThinkPad T520(0x17AA-0x21CF)"},
{0x1180, 0xE852, 0xFFFF, 0xFFFF, "PCIe xD-Picture Card Controller(0xE852)"},
}; /* pci_vid_1180[] */

static pci_id_t const pci_vid_1181[] = {
{0x1181, 0xFFFF, 0xFFFF, 0xFFFF, "Telmatics International(0x1181)"},
}; /* pci_vid_1181[] */

static pci_id_t const pci_vid_1183[] = {
{0x1183, 0xFFFF, 0xFFFF, 0xFFFF, "Fujikura Ltd(0x1183)"},
}; /* pci_vid_1183[] */

static pci_id_t const pci_vid_1184[] = {
{0x1184, 0xFFFF, 0xFFFF, 0xFFFF, "Forks Inc(0x1184)"},
}; /* pci_vid_1184[] */

static pci_id_t const pci_vid_1185[] = {
{0x1185, 0xFFFF, 0xFFFF, 0xFFFF, "Dataworld International Ltd(0x1185)"},
}; /* pci_vid_1185[] */

static pci_id_t const pci_vid_1186[] = {
{0x1186, 0xFFFF, 0xFFFF, 0xFFFF, "D-Link System Inc(0x1186)"},
{0x1186, 0x1002, 0xFFFF, 0xFFFF, "DL10050 Sundance Ethernet(0x1002)"},
{0x1186, 0x1002, 0x1186, 0x1002, "DFE-550TX/FX(0x1186-0x1002)"},
{0x1186, 0x1002, 0x1186, 0x1012, "DFE-580TX(0x1186-0x1012)"},
{0x1186, 0x1025, 0xFFFF, 0xFFFF, "AirPlus Xtreme G DWL-G650 Adapter(0x1025)"},
{0x1186, 0x1026, 0xFFFF, 0xFFFF, "AirXpert DWL-AG650 Wireless Cardbus Adapter(0x1026)"},
{0x1186, 0x1043, 0xFFFF, 0xFFFF, "AirXpert DWL-AG650 Wireless Cardbus Adapter(0x1043)"},
{0x1186, 0x1300, 0xFFFF, 0xFFFF, "RTL8139 Ethernet(0x1300)"},
{0x1186, 0x1300, 0x1186, 0x1300, "DFE-538TX 10/100 Ethernet Adapter(0x1186-0x1300)"},
{0x1186, 0x1300, 0x1186, 0x1301, "DFE-530TX+ 10/100 Ethernet Adapter(0x1186-0x1301)"},
{0x1186, 0x1300, 0x1186, 0x1303, "DFE-528TX 10/100 Fast Ethernet PCI Adapter(0x1186-0x1303)"},
{0x1186, 0x1340, 0xFFFF, 0xFFFF, "DFE-690TXD CardBus PC Card(0x1340)"},
{0x1186, 0x1540, 0xFFFF, 0xFFFF, "DFE-680TX(0x1540)"},
{0x1186, 0x1541, 0xFFFF, 0xFFFF, "DFE-680TXD CardBus PC Card(0x1541)"},
{0x1186, 0x1561, 0xFFFF, 0xFFFF, "DRP-32TXD Cardbus PC Card(0x1561)"},
{0x1186, 0x3300, 0xFFFF, 0xFFFF, "DWL-510 / DWL-610 802.11b [Realtek RTL8180L](0x3300)"},
{0x1186, 0x3300, 0x1186, 0x3300, "DWL-610 Wireless Cardbus Adapter(0x1186-0x3300)"},
{0x1186, 0x3300, 0x1186, 0x3301, "DWL-510 Wireless PCI Adapter(0x1186-0x3301)"},
{0x1186, 0x3A10, 0xFFFF, 0xFFFF, "AirXpert DWL-AG650 Wireless Cardbus Adapter(rev.B)(0x3A10)"},
{0x1186, 0x3A11, 0xFFFF, 0xFFFF, "AirXpert DWL-AG520 Wireless PCI Adapter(rev.B)(0x3A11)"},
{0x1186, 0x4000, 0xFFFF, 0xFFFF, "DL2000-based Gigabit Ethernet(0x4000)"},
{0x1186, 0x4001, 0xFFFF, 0xFFFF, "DGE-550SX PCI-X Gigabit Ethernet Adapter(0x4001)"},
{0x1186, 0x4200, 0xFFFF, 0xFFFF, "DFE-520TX Fast Ethernet PCI Adapter(0x4200)"},
{0x1186, 0x4200, 0x1186, 0x1103, "DFE-520TX Fast Ethernet PCI Adapter (rev. C1)(0x1186-0x1103)"},
{0x1186, 0x4300, 0xFFFF, 0xFFFF, "DGE-528T Gigabit Ethernet Adapter(0x4300)"},
{0x1186, 0x4300, 0x1186, 0x4300, "DGE-528T PCI Gigabit Ethernet Adapter(0x1186-0x4300)"},
{0x1186, 0x4300, 0x1186, 0x4B10, "DGE-560T PCI Express (x1) Gigabit Ethernet Adapter(0x1186-0x4B10)"},
{0x1186, 0x4302, 0xFFFF, 0xFFFF, "DGE-530T Gigabit Ethernet Adapter (rev.C1) [Realtek RTL8169](0x4302)"},
{0x1186, 0x4B00, 0xFFFF, 0xFFFF, "DGE-560T PCI Express Gigabit Ethernet Adapter(0x4B00)"},
{0x1186, 0x4B01, 0xFFFF, 0xFFFF, "DGE-530T Gigabit Ethernet Adapter (rev 11)(0x4B01)"},
{0x1186, 0x4B02, 0xFFFF, 0xFFFF, "DGE-560SX PCI Express Gigabit Ethernet Adapter(0x4B02)"},
{0x1186, 0x4B03, 0xFFFF, 0xFFFF, "DGE-550T Gigabit Ethernet Adapter V.B1(0x4B03)"},
{0x1186, 0x4C00, 0xFFFF, 0xFFFF, "Gigabit Ethernet Adapter(0x4C00)"},
{0x1186, 0x4C00, 0x1186, 0x4C00, "DGE-530T Gigabit Ethernet Adapter(0x1186-0x4C00)"},
{0x1186, 0x8400, 0xFFFF, 0xFFFF, "D-Link DWL-650+ CardBus PC Card(0x8400)"},
}; /* pci_vid_1186[] */

static pci_id_t const pci_vid_1187[] = {
{0x1187, 0xFFFF, 0xFFFF, 0xFFFF, "Advanced Technology Laboratories, Inc.(0x1187)"},
}; /* pci_vid_1187[] */

static pci_id_t const pci_vid_1188[] = {
{0x1188, 0xFFFF, 0xFFFF, 0xFFFF, "Shima Seiki Manufacturing Ltd.(0x1188)"},
}; /* pci_vid_1188[] */

static pci_id_t const pci_vid_1189[] = {
{0x1189, 0xFFFF, 0xFFFF, 0xFFFF, "Matsushita Electronics Co Ltd(0x1189)"},
}; /* pci_vid_1189[] */

static pci_id_t const pci_vid_118A[] = {
{0x118A, 0xFFFF, 0xFFFF, 0xFFFF, "Hilevel Technology(0x118A)"},
}; /* pci_vid_118A[] */

static pci_id_t const pci_vid_118B[] = {
{0x118B, 0xFFFF, 0xFFFF, 0xFFFF, "Hypertec Pty Limited(0x118B)"},
}; /* pci_vid_118B[] */

static pci_id_t const pci_vid_118C[] = {
{0x118C, 0xFFFF, 0xFFFF, 0xFFFF, "Corollary, Inc(0x118C)"},
{0x118C, 0x0014, 0xFFFF, 0xFFFF, "PCIB [C-bus II to PCI bus host bridge chip](0x0014)"},
{0x118C, 0x1117, 0xFFFF, 0xFFFF, "Intel 8-way XEON Profusion Chipset [Cache Coherency Filter](0x1117)"},
}; /* pci_vid_118C[] */

static pci_id_t const pci_vid_118D[] = {
{0x118D, 0xFFFF, 0xFFFF, 0xFFFF, "BitFlow Inc(0x118D)"},
{0x118D, 0x0001, 0xFFFF, 0xFFFF, "Raptor-PCI framegrabber(0x0001)"},
{0x118D, 0x0012, 0xFFFF, 0xFFFF, "Model 12 Road Runner Frame Grabber(0x0012)"},
{0x118D, 0x0014, 0xFFFF, 0xFFFF, "Model 14 Road Runner Frame Grabber(0x0014)"},
{0x118D, 0x0024, 0xFFFF, 0xFFFF, "Model 24 Road Runner Frame Grabber(0x0024)"},
{0x118D, 0x0044, 0xFFFF, 0xFFFF, "Model 44 Road Runner Frame Grabber(0x0044)"},
{0x118D, 0x0112, 0xFFFF, 0xFFFF, "Model 12 Road Runner Frame Grabber(0x0112)"},
{0x118D, 0x0114, 0xFFFF, 0xFFFF, "Model 14 Road Runner Frame Grabber(0x0114)"},
{0x118D, 0x0124, 0xFFFF, 0xFFFF, "Model 24 Road Runner Frame Grabber(0x0124)"},
{0x118D, 0x0144, 0xFFFF, 0xFFFF, "Model 44 Road Runner Frame Grabber(0x0144)"},
{0x118D, 0x0212, 0xFFFF, 0xFFFF, "Model 12 Road Runner Frame Grabber(0x0212)"},
{0x118D, 0x0214, 0xFFFF, 0xFFFF, "Model 14 Road Runner Frame Grabber(0x0214)"},
{0x118D, 0x0224, 0xFFFF, 0xFFFF, "Model 24 Road Runner Frame Grabber(0x0224)"},
{0x118D, 0x0244, 0xFFFF, 0xFFFF, "Model 44 Road Runner Frame Grabber(0x0244)"},
{0x118D, 0x0312, 0xFFFF, 0xFFFF, "Model 12 Road Runner Frame Grabber(0x0312)"},
{0x118D, 0x0314, 0xFFFF, 0xFFFF, "Model 14 Road Runner Frame Grabber(0x0314)"},
{0x118D, 0x0324, 0xFFFF, 0xFFFF, "Model 24 Road Runner Frame Grabber(0x0324)"},
{0x118D, 0x0344, 0xFFFF, 0xFFFF, "Model 44 Road Runner Frame Grabber(0x0344)"},
{0x118D, 0xB04E, 0xFFFF, 0xFFFF, "Claxon CXP4 CoaXPress frame grabber(0xB04E)"},
}; /* pci_vid_118D[] */

static pci_id_t const pci_vid_118E[] = {
{0x118E, 0xFFFF, 0xFFFF, 0xFFFF, "Hermstedt GmbH(0x118E)"},
}; /* pci_vid_118E[] */

static pci_id_t const pci_vid_118F[] = {
{0x118F, 0xFFFF, 0xFFFF, 0xFFFF, "Green Logic(0x118F)"},
}; /* pci_vid_118F[] */

static pci_id_t const pci_vid_1190[] = {
{0x1190, 0xFFFF, 0xFFFF, 0xFFFF, "Tripace(0x1190)"},
{0x1190, 0xC731, 0xFFFF, 0xFFFF, "TP-910/920/940 PCI Ultra(Wide) SCSI Adapter(0xC731)"},
}; /* pci_vid_1190[] */

static pci_id_t const pci_vid_1191[] = {
{0x1191, 0xFFFF, 0xFFFF, 0xFFFF, "Artop Electronic Corp(0x1191)"},
{0x1191, 0x0003, 0xFFFF, 0xFFFF, "SCSI Cache Host Adapter(0x0003)"},
{0x1191, 0x0004, 0xFFFF, 0xFFFF, "ATP8400(0x0004)"},
{0x1191, 0x0005, 0xFFFF, 0xFFFF, "ATP850UF(0x0005)"},
{0x1191, 0x0006, 0xFFFF, 0xFFFF, "ATP860 NO-BIOS(0x0006)"},
{0x1191, 0x0007, 0xFFFF, 0xFFFF, "ATP860(0x0007)"},
{0x1191, 0x0008, 0xFFFF, 0xFFFF, "ATP865 NO-ROM(0x0008)"},
{0x1191, 0x0009, 0xFFFF, 0xFFFF, "ATP865(0x0009)"},
{0x1191, 0x000A, 0xFFFF, 0xFFFF, "ATP867-A(0x000A)"},
{0x1191, 0x000B, 0xFFFF, 0xFFFF, "ATP867-B(0x000B)"},
{0x1191, 0x000D, 0xFFFF, 0xFFFF, "ATP8620(0x000D)"},
{0x1191, 0x000E, 0xFFFF, 0xFFFF, "ATP8620(0x000E)"},
{0x1191, 0x0011, 0xFFFF, 0xFFFF, "ATP865-B(0x0011)"},
{0x1191, 0x0011, 0x1191, 0x0011, "ACARD AEC-6280(0x1191-0x0011)"},
{0x1191, 0x8002, 0xFFFF, 0xFFFF, "AEC6710 SCSI-2 Host Adapter(0x8002)"},
{0x1191, 0x8010, 0xFFFF, 0xFFFF, "AEC6712UW SCSI(0x8010)"},
{0x1191, 0x8020, 0xFFFF, 0xFFFF, "AEC6712U SCSI(0x8020)"},
{0x1191, 0x8030, 0xFFFF, 0xFFFF, "AEC6712S SCSI(0x8030)"},
{0x1191, 0x8040, 0xFFFF, 0xFFFF, "AEC6712D SCSI(0x8040)"},
{0x1191, 0x8050, 0xFFFF, 0xFFFF, "AEC6712SUW SCSI(0x8050)"},
{0x1191, 0x8060, 0xFFFF, 0xFFFF, "AEC6712 SCSI(0x8060)"},
{0x1191, 0x8080, 0xFFFF, 0xFFFF, "AEC67160 SCSI(0x8080)"},
{0x1191, 0x8081, 0xFFFF, 0xFFFF, "AEC67160S SCSI(0x8081)"},
{0x1191, 0x808A, 0xFFFF, 0xFFFF, "AEC67162 2-ch. LVD SCSI(0x808A)"},
}; /* pci_vid_1191[] */

static pci_id_t const pci_vid_1192[] = {
{0x1192, 0xFFFF, 0xFFFF, 0xFFFF, "Densan Company Ltd(0x1192)"},
}; /* pci_vid_1192[] */

static pci_id_t const pci_vid_1193[] = {
{0x1193, 0xFFFF, 0xFFFF, 0xFFFF, "Zeitnet Inc.(0x1193)"},
{0x1193, 0x0001, 0xFFFF, 0xFFFF, "1221(0x0001)"},
{0x1193, 0x0002, 0xFFFF, 0xFFFF, "1225(0x0002)"},
}; /* pci_vid_1193[] */

static pci_id_t const pci_vid_1194[] = {
{0x1194, 0xFFFF, 0xFFFF, 0xFFFF, "Toucan Technology(0x1194)"},
}; /* pci_vid_1194[] */

static pci_id_t const pci_vid_1195[] = {
{0x1195, 0xFFFF, 0xFFFF, 0xFFFF, "Ratoc System Inc(0x1195)"},
}; /* pci_vid_1195[] */

static pci_id_t const pci_vid_1196[] = {
{0x1196, 0xFFFF, 0xFFFF, 0xFFFF, "Hytec Electronics Ltd(0x1196)"},
}; /* pci_vid_1196[] */

static pci_id_t const pci_vid_1197[] = {
{0x1197, 0xFFFF, 0xFFFF, 0xFFFF, "Gage Applied Sciences, Inc.(0x1197)"},
{0x1197, 0x010C, 0xFFFF, 0xFFFF, "CompuScope 82G 8bit 2GS/s Analog Input Card(0x010C)"},
}; /* pci_vid_1197[] */

static pci_id_t const pci_vid_1198[] = {
{0x1198, 0xFFFF, 0xFFFF, 0xFFFF, "Lambda Systems Inc(0x1198)"},
}; /* pci_vid_1198[] */

static pci_id_t const pci_vid_1199[] = {
{0x1199, 0xFFFF, 0xFFFF, 0xFFFF, "Attachmate Corporation(0x1199)"},
{0x1199, 0x0101, 0xFFFF, 0xFFFF, "Advanced ISCA/PCI Adapter(0x0101)"},
}; /* pci_vid_1199[] */

static pci_id_t const pci_vid_119A[] = {
{0x119A, 0xFFFF, 0xFFFF, 0xFFFF, "Mind Share, Inc.(0x119A)"},
}; /* pci_vid_119A[] */

static pci_id_t const pci_vid_119B[] = {
{0x119B, 0xFFFF, 0xFFFF, 0xFFFF, "Omega Micro Inc.(0x119B)"},
{0x119B, 0x1221, 0xFFFF, 0xFFFF, "82C092G(0x1221)"},
}; /* pci_vid_119B[] */

static pci_id_t const pci_vid_119C[] = {
{0x119C, 0xFFFF, 0xFFFF, 0xFFFF, "Information Technology Inst.(0x119C)"},
}; /* pci_vid_119C[] */

static pci_id_t const pci_vid_119D[] = {
{0x119D, 0xFFFF, 0xFFFF, 0xFFFF, "Bug, Inc. Sapporo Japan(0x119D)"},
}; /* pci_vid_119D[] */

static pci_id_t const pci_vid_119E[] = {
{0x119E, 0xFFFF, 0xFFFF, 0xFFFF, "Fujitsu Microelectronics Ltd.(0x119E)"},
{0x119E, 0x0001, 0xFFFF, 0xFFFF, "FireStream 155(0x0001)"},
{0x119E, 0x0003, 0xFFFF, 0xFFFF, "FireStream 50(0x0003)"},
}; /* pci_vid_119E[] */

static pci_id_t const pci_vid_119F[] = {
{0x119F, 0xFFFF, 0xFFFF, 0xFFFF, "Bull HN Information Systems(0x119F)"},
{0x119F, 0x1081, 0xFFFF, 0xFFFF, "BXI Host Channel Adapter(0x1081)"},
{0x119F, 0x1101, 0xFFFF, 0xFFFF, "BXI Host Channel Adapter v1.2(0x1101)"},
{0x119F, 0x1121, 0xFFFF, 0xFFFF, "BXI Host Channel Adapter v1.3(0x1121)"},
}; /* pci_vid_119F[] */

static pci_id_t const pci_vid_11A0[] = {
{0x11A0, 0xFFFF, 0xFFFF, 0xFFFF, "Convex Computer Corporation(0x11A0)"},
}; /* pci_vid_11A0[] */

static pci_id_t const pci_vid_11A1[] = {
{0x11A1, 0xFFFF, 0xFFFF, 0xFFFF, "Hamamatsu Photonics K.K.(0x11A1)"},
}; /* pci_vid_11A1[] */

static pci_id_t const pci_vid_11A2[] = {
{0x11A2, 0xFFFF, 0xFFFF, 0xFFFF, "Sierra Research and Technology(0x11A2)"},
}; /* pci_vid_11A2[] */

static pci_id_t const pci_vid_11A3[] = {
{0x11A3, 0xFFFF, 0xFFFF, 0xFFFF, "Deuretzbacher GmbH & Co. Eng. KG(0x11A3)"},
}; /* pci_vid_11A3[] */

static pci_id_t const pci_vid_11A4[] = {
{0x11A4, 0xFFFF, 0xFFFF, 0xFFFF, "Barco Graphics NV(0x11A4)"},
}; /* pci_vid_11A4[] */

static pci_id_t const pci_vid_11A5[] = {
{0x11A5, 0xFFFF, 0xFFFF, 0xFFFF, "Microunity Systems Eng. Inc(0x11A5)"},
}; /* pci_vid_11A5[] */

static pci_id_t const pci_vid_11A6[] = {
{0x11A6, 0xFFFF, 0xFFFF, 0xFFFF, "Pure Data Ltd.(0x11A6)"},
}; /* pci_vid_11A6[] */

static pci_id_t const pci_vid_11A7[] = {
{0x11A7, 0xFFFF, 0xFFFF, 0xFFFF, "Power Computing Corp.(0x11A7)"},
}; /* pci_vid_11A7[] */

static pci_id_t const pci_vid_11A8[] = {
{0x11A8, 0xFFFF, 0xFFFF, 0xFFFF, "Systech Corp.(0x11A8)"},
}; /* pci_vid_11A8[] */

static pci_id_t const pci_vid_11A9[] = {
{0x11A9, 0xFFFF, 0xFFFF, 0xFFFF, "InnoSys Inc.(0x11A9)"},
{0x11A9, 0x4240, 0xFFFF, 0xFFFF, "AMCC S933Q Intelligent Serial Card(0x4240)"},
}; /* pci_vid_11A9[] */

static pci_id_t const pci_vid_11AA[] = {
{0x11AA, 0xFFFF, 0xFFFF, 0xFFFF, "Actel(0x11AA)"},
}; /* pci_vid_11AA[] */

static pci_id_t const pci_vid_11AB[] = {
{0x11AB, 0xFFFF, 0xFFFF, 0xFFFF, "Marvell Technology Group Ltd.(0x11AB)"},
{0x11AB, 0x0100, 0xFFFF, 0xFFFF, "88F3700 [Armada 3700 Family] ARM SoC(0x0100)"},
{0x11AB, 0x0110, 0xFFFF, 0xFFFF, "88F60x0/88F70x0/88F80x0/CN913x ARM SoC(0x0110)"},
{0x11AB, 0x0146, 0xFFFF, 0xFFFF, "GT-64010/64010A System Controller(0x0146)"},
{0x11AB, 0x0F53, 0xFFFF, 0xFFFF, "88E6318 Link Street network controller(0x0F53)"},
{0x11AB, 0x11AB, 0xFFFF, 0xFFFF, "MV88SE614x SATA II PCI-E controller(0x11AB)"},
{0x11AB, 0x138F, 0xFFFF, 0xFFFF, "W8300 802.11 Adapter (rev 07)(0x138F)"},
{0x11AB, 0x1FA6, 0xFFFF, 0xFFFF, "Marvell W8300 802.11 Adapter(0x1FA6)"},
{0x11AB, 0x1FA6, 0x1186, 0x3B08, "AirPlus G DWL-G630 Wireless Cardbus Adapter (rev.A1)(0x1186-0x3B08)"},
{0x11AB, 0x1FA7, 0xFFFF, 0xFFFF, "88W8310 and 88W8000G [Libertas] 802.11g client chipset(0x1FA7)"},
{0x11AB, 0x1FAA, 0xFFFF, 0xFFFF, "88w8335 [Libertas] 802.11b/g Wireless(0x1FAA)"},
{0x11AB, 0x1FAA, 0x1385, 0x4E00, "WG511v2 54 Mbps Wireless PC Card(0x1385-0x4E00)"},
{0x11AB, 0x1FAA, 0x1385, 0x6B00, "WG311v3 802.11g Wireless PCI Adapter(0x1385-0x6B00)"},
{0x11AB, 0x1FAA, 0x1737, 0x0040, "WPC54G v5 802.11g Wireless-G Notebook Adapter(0x1737-0x0040)"},
{0x11AB, 0x2211, 0xFFFF, 0xFFFF, "88SB2211 PCI Express to PCI Bridge(0x2211)"},
{0x11AB, 0x2A01, 0xFFFF, 0xFFFF, "88W8335 [Libertas] 802.11b/g Wireless(0x2A01)"},
{0x11AB, 0x2A02, 0xFFFF, 0xFFFF, "88W8361 [TopDog] 802.11n Wireless(0x2A02)"},
{0x11AB, 0x2A02, 0x07D1, 0x3B02, "DIR-615 rev. A1 Mini PCI Wireless Module(0x07D1-0x3B02)"},
{0x11AB, 0x2A02, 0x1385, 0x7C00, "WN511T RangeMax Next 300 Mbps Wireless PC Card(0x1385-0x7C00)"},
{0x11AB, 0x2A02, 0x1385, 0x7C01, "WN511T RangeMax Next 300 Mbps Wireless Notebook Adapter(0x1385-0x7C01)"},
{0x11AB, 0x2A02, 0x1385, 0x7E00, "WN311T RangeMax Next 300 Mbps Wireless PCI Adapter(0x1385-0x7E00)"},
{0x11AB, 0x2A02, 0x1799, 0x801B, "F5D8011 v2 802.11n N1 Wireless Notebook Card(0x1799-0x801B)"},
{0x11AB, 0x2A08, 0xFFFF, 0xFFFF, "88W8362e [TopDog] 802.11a/b/g/n Wireless(0x2A08)"},
{0x11AB, 0x2A0A, 0xFFFF, 0xFFFF, "88W8363 [TopDog] 802.11n Wireless(0x2A0A)"},
{0x11AB, 0x2A0C, 0xFFFF, 0xFFFF, "88W8363 [TopDog] 802.11n Wireless(0x2A0C)"},
{0x11AB, 0x2A24, 0xFFFF, 0xFFFF, "88W8363 [TopDog] 802.11n Wireless(0x2A24)"},
{0x11AB, 0x2A2B, 0xFFFF, 0xFFFF, "88W8687 [TopDog] 802.11b/g Wireless(0x2A2B)"},
{0x11AB, 0x2A30, 0xFFFF, 0xFFFF, "88W8687 [TopDog] 802.11b/g Wireless(0x2A30)"},
{0x11AB, 0x2A40, 0xFFFF, 0xFFFF, "88W8366 [TopDog] 802.11n Wireless(0x2A40)"},
{0x11AB, 0x2A41, 0xFFFF, 0xFFFF, "88W8366 [TopDog] 802.11n Wireless(0x2A41)"},
{0x11AB, 0x2A42, 0xFFFF, 0xFFFF, "88W8366 [TopDog] 802.11n Wireless(0x2A42)"},
{0x11AB, 0x2A43, 0xFFFF, 0xFFFF, "88W8366 [TopDog] 802.11n Wireless(0x2A43)"},
{0x11AB, 0x2A55, 0xFFFF, 0xFFFF, "88W8864 [Avastar] 802.11ac Wireless(0x2A55)"},
{0x11AB, 0x2B36, 0xFFFF, 0xFFFF, "88W8764 [Avastar] 802.11n Wireless(0x2B36)"},
{0x11AB, 0x2B38, 0xFFFF, 0xFFFF, "88W8897 [AVASTAR] 802.11ac Wireless(0x2B38)"},
{0x11AB, 0x2B40, 0xFFFF, 0xFFFF, "88W8964 [Avastar] 802.11ac Wireless(0x2B40)"},
{0x11AB, 0x4101, 0xFFFF, 0xFFFF, "OLPC Cafe Controller Secure Digital Controller(0x4101)"},
{0x11AB, 0x4146, 0xFFFF, 0xFFFF, "GT-64111 System Controller(0x4146)"},
{0x11AB, 0x4320, 0xFFFF, 0xFFFF, "88E8001 Gigabit Ethernet Controller(0x4320)"},
{0x11AB, 0x4320, 0x1019, 0x0F38, "Marvell 88E8001 Gigabit Ethernet Controller (ECS)(0x1019-0x0F38)"},
{0x11AB, 0x4320, 0x1019, 0x8001, "Marvell 88E8001 Gigabit Ethernet Controller (ECS)(0x1019-0x8001)"},
{0x11AB, 0x4320, 0x1043, 0x173C, "Marvell 88E8001 Gigabit Ethernet Controller (Asus)(0x1043-0x173C)"},
{0x11AB, 0x4320, 0x1043, 0x811A, "Marvell 88E8001 Gigabit Ethernet Controller (Asus)(0x1043-0x811A)"},
{0x11AB, 0x4320, 0x105B, 0x0C19, "Marvell 88E8001 Gigabit Ethernet Controller (Foxconn)(0x105B-0x0C19)"},
{0x11AB, 0x4320, 0x10B8, 0xB452, "EZ Card 1000 (SMC9452TXV.2)(0x10B8-0xB452)"},
{0x11AB, 0x4320, 0x11AB, 0x0121, "Marvell RDK-8001(0x11AB-0x0121)"},
{0x11AB, 0x4320, 0x11AB, 0x0321, "Marvell RDK-8003(0x11AB-0x0321)"},
{0x11AB, 0x4320, 0x11AB, 0x1021, "Marvell RDK-8010(0x11AB-0x1021)"},
{0x11AB, 0x4320, 0x11AB, 0x4320, "Marvell Yukon Gigabit Ethernet 10/100/1000Baset-T Constroller (Asus)(0x11AB-0x4320)"},
{0x11AB, 0x4320, 0x11AB, 0x5021, "Marvell Yukon Gigabit Ethernet 10/100/1000Base-T Controller (64 bit)(0x11AB-0x5021)"},
{0x11AB, 0x4320, 0x11AB, 0x9521, "Marvell Yukon Gigabit Ethernet 10/100/1000Base-T Controller (32 bit)(0x11AB-0x9521)"},
{0x11AB, 0x4320, 0x1458, 0xE000, "Marvell 88E8001 Gigabit Ethernet Controller (Gigabyte)(0x1458-0xE000)"},
{0x11AB, 0x4320, 0x147B, 0x1406, "Marvell 88E8001 Gigabit Ethernet Controller (Abit)(0x147B-0x1406)"},
{0x11AB, 0x4320, 0x15D4, 0x0047, "Marvell 88E8001 Gigabit Ethernet Controller (Iwill)(0x15D4-0x0047)"},
{0x11AB, 0x4320, 0x1695, 0x9025, "Marvell 88E8001 Gigabit Ethernet Controller (Epox)(0x1695-0x9025)"},
{0x11AB, 0x4320, 0x17F2, 0x1C03, "Marvell 88E8001 Gigabit Ethernet Controller (Albatron)(0x17F2-0x1C03)"},
{0x11AB, 0x4320, 0x270F, 0x2803, "Marvell 88E8001 Gigabit Ethernet Controller (Chaintech)(0x270F-0x2803)"},
{0x11AB, 0x4340, 0xFFFF, 0xFFFF, "88E8021 PCI-X IPMI Gigabit Ethernet Controller(0x4340)"},
{0x11AB, 0x4341, 0xFFFF, 0xFFFF, "88E8022 PCI-X IPMI Gigabit Ethernet Controller(0x4341)"},
{0x11AB, 0x4342, 0xFFFF, 0xFFFF, "88E8061 PCI-E IPMI Gigabit Ethernet Controller(0x4342)"},
{0x11AB, 0x4343, 0xFFFF, 0xFFFF, "88E8062 PCI-E IPMI Gigabit Ethernet Controller(0x4343)"},
{0x11AB, 0x4344, 0xFFFF, 0xFFFF, "88E8021 PCI-X IPMI Gigabit Ethernet Controller(0x4344)"},
{0x11AB, 0x4345, 0xFFFF, 0xFFFF, "88E8022 PCI-X IPMI Gigabit Ethernet Controller(0x4345)"},
{0x11AB, 0x4346, 0xFFFF, 0xFFFF, "88E8061 PCI-E IPMI Gigabit Ethernet Controller(0x4346)"},
{0x11AB, 0x4347, 0xFFFF, 0xFFFF, "88E8062 PCI-E IPMI Gigabit Ethernet Controller(0x4347)"},
{0x11AB, 0x4347, 0x4C53, 0x10D0, "Telum ASLP10 PrAMC Gigabit Ethernet(0x4C53-0x10D0)"},
{0x11AB, 0x4350, 0xFFFF, 0xFFFF, "88E8035 PCI-E Fast Ethernet Controller(0x4350)"},
{0x11AB, 0x4350, 0x1179, 0x0001, "Marvell 88E8035 Fast Ethernet Controller (Toshiba)(0x1179-0x0001)"},
{0x11AB, 0x4350, 0x11AB, 0x3521, "Marvell RDK-8035(0x11AB-0x3521)"},
{0x11AB, 0x4350, 0x1854, 0x000D, "Marvell 88E8035 Fast Ethernet Controller (LGE)(0x1854-0x000D)"},
{0x11AB, 0x4350, 0x1854, 0x000E, "Marvell 88E8035 Fast Ethernet Controller (LGE)(0x1854-0x000E)"},
{0x11AB, 0x4350, 0x1854, 0x000F, "Marvell 88E8035 Fast Ethernet Controller (LGE)(0x1854-0x000F)"},
{0x11AB, 0x4350, 0x1854, 0x0011, "Marvell 88E8035 Fast Ethernet Controller (LGE)(0x1854-0x0011)"},
{0x11AB, 0x4350, 0x1854, 0x0012, "Marvell 88E8035 Fast Ethernet Controller (LGE)(0x1854-0x0012)"},
{0x11AB, 0x4350, 0x1854, 0x0016, "Marvell 88E8035 Fast Ethernet Controller (LGE)(0x1854-0x0016)"},
{0x11AB, 0x4350, 0x1854, 0x0017, "Marvell 88E8035 Fast Ethernet Controller (LGE)(0x1854-0x0017)"},
{0x11AB, 0x4350, 0x1854, 0x0018, "Marvell 88E8035 Fast Ethernet Controller (LGE)(0x1854-0x0018)"},
{0x11AB, 0x4350, 0x1854, 0x0019, "Marvell 88E8035 Fast Ethernet Controller (LGE)(0x1854-0x0019)"},
{0x11AB, 0x4350, 0x1854, 0x001C, "Marvell 88E8035 Fast Ethernet Controller (LGE)(0x1854-0x001C)"},
{0x11AB, 0x4350, 0x1854, 0x001E, "Marvell 88E8035 Fast Ethernet Controller (LGE)(0x1854-0x001E)"},
{0x11AB, 0x4350, 0x1854, 0x0020, "Marvell 88E8035 Fast Ethernet Controller (LGE)(0x1854-0x0020)"},
{0x11AB, 0x4351, 0xFFFF, 0xFFFF, "88E8036 PCI-E Fast Ethernet Controller(0x4351)"},
{0x11AB, 0x4351, 0x107B, 0x4009, "Marvell 88E8036 Fast Ethernet Controller (Wistron)(0x107B-0x4009)"},
{0x11AB, 0x4351, 0x10F7, 0x8338, "Marvell 88E8036 Fast Ethernet Controller (Panasonic)(0x10F7-0x8338)"},
{0x11AB, 0x4351, 0x1179, 0x0001, "Marvell 88E8036 Fast Ethernet Controller (Toshiba)(0x1179-0x0001)"},
{0x11AB, 0x4351, 0x1179, 0xFF00, "Marvell 88E8036 Fast Ethernet Controller (Compal)(0x1179-0xFF00)"},
{0x11AB, 0x4351, 0x1179, 0xFF10, "Marvell 88E8036 Fast Ethernet Controller (Inventec)(0x1179-0xFF10)"},
{0x11AB, 0x4351, 0x11AB, 0x3621, "Marvell RDK-8036(0x11AB-0x3621)"},
{0x11AB, 0x4351, 0x13D1, 0xAC12, "Abocom EFE3K - 10/100 Ethernet Expresscard(0x13D1-0xAC12)"},
{0x11AB, 0x4351, 0x161F, 0x203D, "Marvell 88E8036 Fast Ethernet Controller (Arima)(0x161F-0x203D)"},
{0x11AB, 0x4351, 0x1854, 0x000D, "Marvell 88E8036 Fast Ethernet Controller (LGE)(0x1854-0x000D)"},
{0x11AB, 0x4351, 0x1854, 0x000E, "Marvell 88E8036 Fast Ethernet Controller (LGE)(0x1854-0x000E)"},
{0x11AB, 0x4351, 0x1854, 0x000F, "Marvell 88E8036 Fast Ethernet Controller (LGE)(0x1854-0x000F)"},
{0x11AB, 0x4351, 0x1854, 0x0011, "Marvell 88E8036 Fast Ethernet Controller (LGE)(0x1854-0x0011)"},
{0x11AB, 0x4351, 0x1854, 0x0012, "Marvell 88E8036 Fast Ethernet Controller (LGE)(0x1854-0x0012)"},
{0x11AB, 0x4351, 0x1854, 0x0016, "Marvell 88E8036 Fast Ethernet Controller (LGE)(0x1854-0x0016)"},
{0x11AB, 0x4351, 0x1854, 0x0017, "Marvell 88E8036 Fast Ethernet Controller (LGE)(0x1854-0x0017)"},
{0x11AB, 0x4351, 0x1854, 0x0018, "Marvell 88E8036 Fast Ethernet Controller (LGE)(0x1854-0x0018)"},
{0x11AB, 0x4351, 0x1854, 0x0019, "Marvell 88E8036 Fast Ethernet Controller (LGE)(0x1854-0x0019)"},
{0x11AB, 0x4351, 0x1854, 0x001C, "Marvell 88E8036 Fast Ethernet Controller (LGE)(0x1854-0x001C)"},
{0x11AB, 0x4351, 0x1854, 0x001E, "Marvell 88E8036 Fast Ethernet Controller (LGE)(0x1854-0x001E)"},
{0x11AB, 0x4351, 0x1854, 0x0020, "Marvell 88E8036 Fast Ethernet Controller (LGE)(0x1854-0x0020)"},
{0x11AB, 0x4352, 0xFFFF, 0xFFFF, "88E8038 PCI-E Fast Ethernet Controller(0x4352)"},
{0x11AB, 0x4353, 0xFFFF, 0xFFFF, "88E8039 PCI-E Fast Ethernet Controller(0x4353)"},
{0x11AB, 0x4353, 0x104D, 0x902D, "VAIO VGN-NR120E(0x104D-0x902D)"},
{0x11AB, 0x4354, 0xFFFF, 0xFFFF, "88E8040 PCI-E Fast Ethernet Controller(0x4354)"},
{0x11AB, 0x4354, 0x1028, 0x022F, "Inspiron 1525(0x1028-0x022F)"},
{0x11AB, 0x4354, 0x144D, 0xC06A, "R730 Laptop(0x144D-0xC06A)"},
{0x11AB, 0x4354, 0x144D, 0xC072, "Notebook N150P(0x144D-0xC072)"},
{0x11AB, 0x4355, 0xFFFF, 0xFFFF, "88E8040T PCI-E Fast Ethernet Controller(0x4355)"},
{0x11AB, 0x4355, 0x1179, 0xFF50, "Satellite P305D-S8995E(0x1179-0xFF50)"},
{0x11AB, 0x4356, 0xFFFF, 0xFFFF, "88EC033 PCI-E Fast Ethernet Controller(0x4356)"},
{0x11AB, 0x4357, 0xFFFF, 0xFFFF, "88E8042 PCI-E Fast Ethernet Controller(0x4357)"},
{0x11AB, 0x435A, 0xFFFF, 0xFFFF, "88E8048 PCI-E Fast Ethernet Controller(0x435A)"},
{0x11AB, 0x4360, 0xFFFF, 0xFFFF, "88E8052 PCI-E ASF Gigabit Ethernet Controller(0x4360)"},
{0x11AB, 0x4360, 0x1043, 0x8134, "Marvell 88E8052 Gigabit Ethernet Controller (Asus)(0x1043-0x8134)"},
{0x11AB, 0x4360, 0x107B, 0x4009, "Marvell 88E8052 Gigabit Ethernet Controller (Wistron)(0x107B-0x4009)"},
{0x11AB, 0x4360, 0x11AB, 0x5221, "Marvell RDK-8052(0x11AB-0x5221)"},
{0x11AB, 0x4360, 0x1458, 0xE000, "Marvell 88E8052 Gigabit Ethernet Controller (Gigabyte)(0x1458-0xE000)"},
{0x11AB, 0x4360, 0x1462, 0x052C, "Marvell 88E8052 Gigabit Ethernet Controller (MSI)(0x1462-0x052C)"},
{0x11AB, 0x4360, 0x1849, 0x8052, "Marvell 88E8052 Gigabit Ethernet Controller (ASRock)(0x1849-0x8052)"},
{0x11AB, 0x4360, 0xA0A0, 0x0509, "Marvell 88E8052 Gigabit Ethernet Controller (Aopen)(0xA0A0-0x0509)"},
{0x11AB, 0x4361, 0xFFFF, 0xFFFF, "88E8050 PCI-E ASF Gigabit Ethernet Controller(0x4361)"},
{0x11AB, 0x4361, 0x107B, 0x3015, "Marvell 88E8050 Gigabit Ethernet Controller (Gateway)(0x107B-0x3015)"},
{0x11AB, 0x4361, 0x11AB, 0x5021, "Marvell 88E8050 Gigabit Ethernet Controller (Intel)(0x11AB-0x5021)"},
{0x11AB, 0x4361, 0x8086, 0x3063, "D925XCVLK mainboard(0x8086-0x3063)"},
{0x11AB, 0x4361, 0x8086, 0x3439, "Marvell 88E8050 Gigabit Ethernet Controller (Intel)(0x8086-0x3439)"},
{0x11AB, 0x4362, 0xFFFF, 0xFFFF, "88E8053 PCI-E Gigabit Ethernet Controller(0x4362)"},
{0x11AB, 0x4362, 0x103C, 0x2A0D, "Marvell 88E8053 Gigabit Ethernet Controller (Asus)(0x103C-0x2A0D)"},
{0x11AB, 0x4362, 0x1043, 0x8142, "Marvell 88E8053 Gigabit Ethernet controller PCIe (Asus)(0x1043-0x8142)"},
{0x11AB, 0x4362, 0x109F, 0x3197, "Marvell 88E8053 Gigabit Ethernet Controller (Trigem)(0x109F-0x3197)"},
{0x11AB, 0x4362, 0x10F7, 0x8338, "Marvell 88E8053 Gigabit Ethernet Controller (Panasonic)(0x10F7-0x8338)"},
{0x11AB, 0x4362, 0x10FD, 0xA430, "Marvell 88E8053 Gigabit Ethernet Controller (SOYO)(0x10FD-0xA430)"},
{0x11AB, 0x4362, 0x1179, 0x0001, "Marvell 88E8053 Gigabit Ethernet Controller (Toshiba)(0x1179-0x0001)"},
{0x11AB, 0x4362, 0x1179, 0xFF00, "Marvell 88E8053 Gigabit Ethernet Controller (Compal)(0x1179-0xFF00)"},
{0x11AB, 0x4362, 0x1179, 0xFF10, "Marvell 88E8053 Gigabit Ethernet Controller (Inventec)(0x1179-0xFF10)"},
{0x11AB, 0x4362, 0x11AB, 0x5321, "Marvell RDK-8053(0x11AB-0x5321)"},
{0x11AB, 0x4362, 0x1297, 0xC240, "Marvell 88E8053 Gigabit Ethernet Controller (Shuttle)(0x1297-0xC240)"},
{0x11AB, 0x4362, 0x1297, 0xC241, "Marvell 88E8053 Gigabit Ethernet Controller (Shuttle)(0x1297-0xC241)"},
{0x11AB, 0x4362, 0x1297, 0xC242, "Marvell 88E8053 Gigabit Ethernet Controller (Shuttle)(0x1297-0xC242)"},
{0x11AB, 0x4362, 0x1297, 0xC243, "Marvell 88E8053 Gigabit Ethernet Controller (Shuttle)(0x1297-0xC243)"},
{0x11AB, 0x4362, 0x1297, 0xC244, "Marvell 88E8053 Gigabit Ethernet Controller (Shuttle)(0x1297-0xC244)"},
{0x11AB, 0x4362, 0x13D1, 0xAC11, "EGE5K - Giga Ethernet Expresscard(0x13D1-0xAC11)"},
{0x11AB, 0x4362, 0x1458, 0xE000, "Marvell 88E8053 Gigabit Ethernet Controller (Gigabyte)(0x1458-0xE000)"},
{0x11AB, 0x4362, 0x1462, 0x058C, "Marvell 88E8053 Gigabit Ethernet Controller (MSI)(0x1462-0x058C)"},
{0x11AB, 0x4362, 0x14C0, 0x0012, "Marvell 88E8053 Gigabit Ethernet Controller (Compal)(0x14C0-0x0012)"},
{0x11AB, 0x4362, 0x1558, 0x04A0, "Marvell 88E8053 Gigabit Ethernet Controller (Clevo)(0x1558-0x04A0)"},
{0x11AB, 0x4362, 0x15BD, 0x1003, "Marvell 88E8053 Gigabit Ethernet Controller (DFI)(0x15BD-0x1003)"},
{0x11AB, 0x4362, 0x161F, 0x203C, "Marvell 88E8053 Gigabit Ethernet Controller (Arima)(0x161F-0x203C)"},
{0x11AB, 0x4362, 0x161F, 0x203D, "Marvell 88E8053 Gigabit Ethernet Controller (Arima)(0x161F-0x203D)"},
{0x11AB, 0x4362, 0x1695, 0x9029, "Marvell 88E8053 Gigabit Ethernet Controller (Epox)(0x1695-0x9029)"},
{0x11AB, 0x4362, 0x17F2, 0x2C08, "Marvell 88E8053 Gigabit Ethernet Controller (Albatron)(0x17F2-0x2C08)"},
{0x11AB, 0x4362, 0x17FF, 0x0585, "Marvell 88E8053 Gigabit Ethernet Controller (Quanta)(0x17FF-0x0585)"},
{0x11AB, 0x4362, 0x1849, 0x8053, "Marvell 88E8053 Gigabit Ethernet Controller (ASRock)(0x1849-0x8053)"},
{0x11AB, 0x4362, 0x1854, 0x000B, "Marvell 88E8053 Gigabit Ethernet Controller (LGE)(0x1854-0x000B)"},
{0x11AB, 0x4362, 0x1854, 0x000C, "Marvell 88E8053 Gigabit Ethernet Controller (LGE)(0x1854-0x000C)"},
{0x11AB, 0x4362, 0x1854, 0x0010, "Marvell 88E8053 Gigabit Ethernet Controller (LGE)(0x1854-0x0010)"},
{0x11AB, 0x4362, 0x1854, 0x0013, "Marvell 88E8053 Gigabit Ethernet Controller (LGE)(0x1854-0x0013)"},
{0x11AB, 0x4362, 0x1854, 0x0014, "Marvell 88E8053 Gigabit Ethernet Controller (LGE)(0x1854-0x0014)"},
{0x11AB, 0x4362, 0x1854, 0x0015, "Marvell 88E8053 Gigabit Ethernet Controller (LGE)(0x1854-0x0015)"},
{0x11AB, 0x4362, 0x1854, 0x001A, "Marvell 88E8053 Gigabit Ethernet Controller (LGE)(0x1854-0x001A)"},
{0x11AB, 0x4362, 0x1854, 0x001B, "Marvell 88E8053 Gigabit Ethernet Controller (LGE)(0x1854-0x001B)"},
{0x11AB, 0x4362, 0x1854, 0x001D, "Marvell 88E8053 Gigabit Ethernet Controller (LGE)(0x1854-0x001D)"},
{0x11AB, 0x4362, 0x1854, 0x001F, "Marvell 88E8053 Gigabit Ethernet Controller (LGE)(0x1854-0x001F)"},
{0x11AB, 0x4362, 0x1854, 0x0021, "Marvell 88E8053 Gigabit Ethernet Controller (LGE)(0x1854-0x0021)"},
{0x11AB, 0x4362, 0x1854, 0x0022, "Marvell 88E8053 Gigabit Ethernet Controller (LGE)(0x1854-0x0022)"},
{0x11AB, 0x4362, 0x270F, 0x2801, "Marvell 88E8053 Gigabit Ethernet Controller (Chaintech)(0x270F-0x2801)"},
{0x11AB, 0x4362, 0xA0A0, 0x0506, "Marvell 88E8053 Gigabit Ethernet Controller (Aopen)(0xA0A0-0x0506)"},
{0x11AB, 0x4363, 0xFFFF, 0xFFFF, "88E8055 PCI-E Gigabit Ethernet Controller(0x4363)"},
{0x11AB, 0x4364, 0xFFFF, 0xFFFF, "88E8056 PCI-E Gigabit Ethernet Controller(0x4364)"},
{0x11AB, 0x4364, 0x1043, 0x81F8, "Motherboard(0x1043-0x81F8)"},
{0x11AB, 0x4364, 0x11BA, 0x00BA, "8056 Gigabit Ethernet Controller(0x11BA-0x00BA)"},
{0x11AB, 0x4365, 0xFFFF, 0xFFFF, "88E8070 based Ethernet Controller(0x4365)"},
{0x11AB, 0x4366, 0xFFFF, 0xFFFF, "88EC036 PCI-E Gigabit Ethernet Controller(0x4366)"},
{0x11AB, 0x4367, 0xFFFF, 0xFFFF, "88EC032 Ethernet Controller(0x4367)"},
{0x11AB, 0x4368, 0xFFFF, 0xFFFF, "88EC034 Ethernet Controller(0x4368)"},
{0x11AB, 0x4369, 0xFFFF, 0xFFFF, "88EC042 Ethernet Controller(0x4369)"},
{0x11AB, 0x436A, 0xFFFF, 0xFFFF, "88E8058 PCI-E Gigabit Ethernet Controller(0x436A)"},
{0x11AB, 0x436A, 0x11AB, 0x00BA, "Imac 8,1 Wired Ethernet Adapter(0x11AB-0x00BA)"},
{0x11AB, 0x436B, 0xFFFF, 0xFFFF, "88E8071 PCI-E Gigabit Ethernet Controller(0x436B)"},
{0x11AB, 0x436C, 0xFFFF, 0xFFFF, "88E8072 PCI-E Gigabit Ethernet Controller(0x436C)"},
{0x11AB, 0x436D, 0xFFFF, 0xFFFF, "88E8055 PCI-E Gigabit Ethernet Controller(0x436D)"},
{0x11AB, 0x4370, 0xFFFF, 0xFFFF, "88E8075 PCI-E Gigabit Ethernet Controller(0x4370)"},
{0x11AB, 0x4380, 0xFFFF, 0xFFFF, "88E8057 PCI-E Gigabit Ethernet Controller(0x4380)"},
{0x11AB, 0x4381, 0xFFFF, 0xFFFF, "Yukon Optima 88E8059 [PCIe Gigabit Ethernet Controller with AVB](0x4381)"},
{0x11AB, 0x4381, 0x1259, 0x2803, "AT-2814FX(0x1259-0x2803)"},
{0x11AB, 0x4381, 0x1259, 0x2804, "AT-2874xx(0x1259-0x2804)"},
{0x11AB, 0x4611, 0xFFFF, 0xFFFF, "GT-64115 System Controller(0x4611)"},
{0x11AB, 0x4620, 0xFFFF, 0xFFFF, "GT-64120/64120A/64121A System Controller(0x4620)"},
{0x11AB, 0x4801, 0xFFFF, 0xFFFF, "GT-48001(0x4801)"},
{0x11AB, 0x5005, 0xFFFF, 0xFFFF, "Belkin F5D5005 Gigabit Desktop Network PCI Card(0x5005)"},
{0x11AB, 0x5040, 0xFFFF, 0xFFFF, "MV88SX5040 4-port SATA I PCI-X Controller(0x5040)"},
{0x11AB, 0x5041, 0xFFFF, 0xFFFF, "MV88SX5041 4-port SATA I PCI-X Controller(0x5041)"},
{0x11AB, 0x5080, 0xFFFF, 0xFFFF, "MV88SX5080 8-port SATA I PCI-X Controller(0x5080)"},
{0x11AB, 0x5081, 0xFFFF, 0xFFFF, "MV88SX5081 8-port SATA I PCI-X Controller(0x5081)"},
{0x11AB, 0x5181, 0xFFFF, 0xFFFF, "88f5181 [Orion-1] ARM SoC(0x5181)"},
{0x11AB, 0x5182, 0xFFFF, 0xFFFF, "88f5182 [Orion-NAS] ARM SoC(0x5182)"},
{0x11AB, 0x5281, 0xFFFF, 0xFFFF, "88f5281 [Orion-2] ARM SoC(0x5281)"},
{0x11AB, 0x6041, 0xFFFF, 0xFFFF, "MV88SX6041 4-port SATA II PCI-X Controller(0x6041)"},
{0x11AB, 0x6042, 0xFFFF, 0xFFFF, "88SX6042 PCI-X 4-Port SATA-II(0x6042)"},
{0x11AB, 0x6081, 0xFFFF, 0xFFFF, "MV88SX6081 8-port SATA II PCI-X Controller(0x6081)"},
{0x11AB, 0x6101, 0xFFFF, 0xFFFF, "88SE6101/6102 single-port PATA133 interface(0x6101)"},
{0x11AB, 0x6101, 0x1043, 0x82E0, "P5K PRO Motherboard(0x1043-0x82E0)"},
{0x11AB, 0x6121, 0xFFFF, 0xFFFF, "88SE6111/6121 SATA II / PATA Controller(0x6121)"},
{0x11AB, 0x6121, 0x11AB, 0x6121, "88SE6111/6121 1/2 port SATA II + 1 port PATA Controller(0x11AB-0x6121)"},
{0x11AB, 0x6141, 0xFFFF, 0xFFFF, "88SE614x SATA II PCI-E controller(0x6141)"},
{0x11AB, 0x6145, 0xFFFF, 0xFFFF, "88SE6145 SATA II PCI-E controller(0x6145)"},
{0x11AB, 0x6180, 0xFFFF, 0xFFFF, "88F6180 [Kirkwood] ARM SoC(0x6180)"},
{0x11AB, 0x6192, 0xFFFF, 0xFFFF, "88F6190/6192 [Kirkwood] ARM SoC(0x6192)"},
{0x11AB, 0x6281, 0xFFFF, 0xFFFF, "88F6281 [Kirkwood] ARM SoC(0x6281)"},
{0x11AB, 0x6381, 0xFFFF, 0xFFFF, "MV78xx0 [Discovery Innovation] ARM SoC(0x6381)"},
{0x11AB, 0x6440, 0xFFFF, 0xFFFF, "88SE63x0 x1, 88SE6440 x4 PCIe SAS/SATA 3Gb/s RAID controller(0x6440)"},
{0x11AB, 0x6450, 0xFFFF, 0xFFFF, "64560 System Controller(0x6450)"},
{0x11AB, 0x6460, 0xFFFF, 0xFFFF, "MV64360/64361/64362 System Controller(0x6460)"},
{0x11AB, 0x6480, 0xFFFF, 0xFFFF, "MV64460/64461/64462 System Controller(0x6480)"},
{0x11AB, 0x6480, 0x1775, 0xC200, "C2K CompactPCI single board computer(0x1775-0xC200)"},
{0x11AB, 0x6485, 0xFFFF, 0xFFFF, "MV64460/64461/64462 System Controller, Revision B(0x6485)"},
{0x11AB, 0x6560, 0xFFFF, 0xFFFF, "88F6560 [Avanta] ARM SoC(0x6560)"},
{0x11AB, 0x6710, 0xFFFF, 0xFFFF, "88F6710 [Armada 370] ARM SoC(0x6710)"},
{0x11AB, 0x6820, 0xFFFF, 0xFFFF, "88F6820 [Armada 385] ARM SoC(0x6820)"},
{0x11AB, 0x6828, 0xFFFF, 0xFFFF, "88F6828 [Armada 388] ARM SoC(0x6828)"},
{0x11AB, 0x6920, 0xFFFF, 0xFFFF, "88F6920 [Armada 390] ARM SoC(0x6920)"},
{0x11AB, 0x7042, 0xFFFF, 0xFFFF, "88SX7042 PCIe 4-port SATA-II controller(0x7042)"},
{0x11AB, 0x7042, 0x16B8, 0x434B, "Tempo SATA E4P(0x16B8-0x434B)"},
{0x11AB, 0x7810, 0xFFFF, 0xFFFF, "MV78100 [Discovery Innovation] ARM SoC(0x7810)"},
{0x11AB, 0x7820, 0xFFFF, 0xFFFF, "MV78200 [Discovery Innovation] ARM SoC(0x7820)"},
{0x11AB, 0x7823, 0xFFFF, 0xFFFF, "MV78230 [Armada XP] ARM SoC(0x7823)"},
{0x11AB, 0x7846, 0xFFFF, 0xFFFF, "MV78460 [Armada XP] ARM SoC(0x7846)"},
{0x11AB, 0xD40F, 0xFFFF, 0xFFFF, "Bobcat3 Ethernet Switch(0xD40F)"},
{0x11AB, 0xF003, 0xFFFF, 0xFFFF, "GT-64010 Primary Image Piranha Image Generator(0xF003)"},
}; /* pci_vid_11AB[] */

static pci_id_t const pci_vid_11AC[] = {
{0x11AC, 0xFFFF, 0xFFFF, 0xFFFF, "Canon Information Systems Research Aust.(0x11AC)"},
}; /* pci_vid_11AC[] */

static pci_id_t const pci_vid_11AD[] = {
{0x11AD, 0xFFFF, 0xFFFF, 0xFFFF, "Lite-On Communications Inc(0x11AD)"},
{0x11AD, 0x0002, 0xFFFF, 0xFFFF, "LNE100TX(0x0002)"},
{0x11AD, 0x0002, 0x11AD, 0x0002, "LNE100TX(0x11AD-0x0002)"},
{0x11AD, 0x0002, 0x11AD, 0x0003, "LNE100TX(0x11AD-0x0003)"},
{0x11AD, 0x0002, 0x11AD, 0xF003, "LNE100TX(0x11AD-0xF003)"},
{0x11AD, 0x0002, 0x11AD, 0xFFFF, "LNE100TX(0x11AD-0xFFFF)"},
{0x11AD, 0x0002, 0x1385, 0xF004, "FA310/TX LAN 10/100 PCI Ethernet Adapter(0x1385-0xF004)"},
{0x11AD, 0x0002, 0x2646, 0xF002, "KNE110TX EtheRx Fast Ethernet(0x2646-0xF002)"},
{0x11AD, 0xC115, 0xFFFF, 0xFFFF, "LNE100TX [Linksys EtherFast 10/100](0xC115)"},
{0x11AD, 0xC115, 0x11AD, 0xC001, "LNE100TX [ver 2.0](0x11AD-0xC001)"},
{0x11AD, 0xC115, 0x2646, 0x000B, "KNE111TX(0x2646-0x000B)"},
}; /* pci_vid_11AD[] */

static pci_id_t const pci_vid_11AE[] = {
{0x11AE, 0xFFFF, 0xFFFF, 0xFFFF, "Aztech System Ltd(0x11AE)"},
}; /* pci_vid_11AE[] */

static pci_id_t const pci_vid_11AF[] = {
{0x11AF, 0xFFFF, 0xFFFF, 0xFFFF, "Avid Technology Inc.(0x11AF)"},
{0x11AF, 0x0001, 0xFFFF, 0xFFFF, "Cinema(0x0001)"},
{0x11AF, 0xEE21, 0xFFFF, 0xFFFF, "Digidesign DSP Farm(0xEE21)"},
{0x11AF, 0xEE40, 0xFFFF, 0xFFFF, "Digidesign Audiomedia III(0xEE40)"},
{0x11AF, 0xEE60, 0xFFFF, 0xFFFF, "Digidesign SampleCell II / II Plus(0xEE60)"},
}; /* pci_vid_11AF[] */

static pci_id_t const pci_vid_11B0[] = {
{0x11B0, 0xFFFF, 0xFFFF, 0xFFFF, "V3 Semiconductor Inc.(0x11B0)"},
{0x11B0, 0x0002, 0xFFFF, 0xFFFF, "V300PSC(0x0002)"},
{0x11B0, 0x0292, 0xFFFF, 0xFFFF, "V292PBC [Am29030/40 Bridge](0x0292)"},
{0x11B0, 0x0960, 0xFFFF, 0xFFFF, "V96xPBC(0x0960)"},
{0x11B0, 0x880A, 0xFFFF, 0xFFFF, "Deltacast Delta-HD-22(0x880A)"},
{0x11B0, 0xC960, 0xFFFF, 0xFFFF, "V96DPC(0xC960)"},
}; /* pci_vid_11B0[] */

static pci_id_t const pci_vid_11B1[] = {
{0x11B1, 0xFFFF, 0xFFFF, 0xFFFF, "Apricot Computers(0x11B1)"},
}; /* pci_vid_11B1[] */

static pci_id_t const pci_vid_11B2[] = {
{0x11B2, 0xFFFF, 0xFFFF, 0xFFFF, "Eastman Kodak(0x11B2)"},
}; /* pci_vid_11B2[] */

static pci_id_t const pci_vid_11B3[] = {
{0x11B3, 0xFFFF, 0xFFFF, 0xFFFF, "Barr Systems Inc.(0x11B3)"},
}; /* pci_vid_11B3[] */

static pci_id_t const pci_vid_11B4[] = {
{0x11B4, 0xFFFF, 0xFFFF, 0xFFFF, "Leitch Technology International(0x11B4)"},
}; /* pci_vid_11B4[] */

static pci_id_t const pci_vid_11B5[] = {
{0x11B5, 0xFFFF, 0xFFFF, 0xFFFF, "Radstone Technology Plc(0x11B5)"},
}; /* pci_vid_11B5[] */

static pci_id_t const pci_vid_11B6[] = {
{0x11B6, 0xFFFF, 0xFFFF, 0xFFFF, "United Video Corp(0x11B6)"},
}; /* pci_vid_11B6[] */

static pci_id_t const pci_vid_11B7[] = {
{0x11B7, 0xFFFF, 0xFFFF, 0xFFFF, "Motorola(0x11B7)"},
}; /* pci_vid_11B7[] */

static pci_id_t const pci_vid_11B8[] = {
{0x11B8, 0xFFFF, 0xFFFF, 0xFFFF, "XPoint Technologies, Inc(0x11B8)"},
{0x11B8, 0x0001, 0xFFFF, 0xFFFF, "Quad PeerMaster(0x0001)"},
}; /* pci_vid_11B8[] */

static pci_id_t const pci_vid_11B9[] = {
{0x11B9, 0xFFFF, 0xFFFF, 0xFFFF, "Pathlight Technology Inc.(0x11B9)"},
{0x11B9, 0xC0ED, 0xFFFF, 0xFFFF, "SSA Controller(0xC0ED)"},
}; /* pci_vid_11B9[] */

static pci_id_t const pci_vid_11BA[] = {
{0x11BA, 0xFFFF, 0xFFFF, 0xFFFF, "Videotron Corp(0x11BA)"},
}; /* pci_vid_11BA[] */

static pci_id_t const pci_vid_11BB[] = {
{0x11BB, 0xFFFF, 0xFFFF, 0xFFFF, "Pyramid Technology(0x11BB)"},
}; /* pci_vid_11BB[] */

static pci_id_t const pci_vid_11BC[] = {
{0x11BC, 0xFFFF, 0xFFFF, 0xFFFF, "Network Peripherals Inc(0x11BC)"},
{0x11BC, 0x0001, 0xFFFF, 0xFFFF, "NP-PCI(0x0001)"},
}; /* pci_vid_11BC[] */

static pci_id_t const pci_vid_11BD[] = {
{0x11BD, 0xFFFF, 0xFFFF, 0xFFFF, "Pinnacle Systems Inc.(0x11BD)"},
{0x11BD, 0x002E, 0xFFFF, 0xFFFF, "PCTV 40i(0x002E)"},
{0x11BD, 0x0040, 0xFFFF, 0xFFFF, "Royal TS Function 1(0x0040)"},
{0x11BD, 0x0040, 0x11BD, 0x0044, "PCTV 2000i Dual DVB-T Pro PCI Tuner 1(0x11BD-0x0044)"},
{0x11BD, 0x0040, 0x11BD, 0x0045, "PCTV Dual Sat Pro PCI 4000i Tuner 1(0x11BD-0x0045)"},
{0x11BD, 0x0041, 0xFFFF, 0xFFFF, "RoyalTS Function 2(0x0041)"},
{0x11BD, 0x0041, 0x11BD, 0x0044, "PCTV 2000i Dual DVB-T Pro PCI Tuner 2(0x11BD-0x0044)"},
{0x11BD, 0x0041, 0x11BD, 0x0045, "PCTV Dual Sat Pro PCI 4000i Tuner 2(0x11BD-0x0045)"},
{0x11BD, 0x0042, 0xFFFF, 0xFFFF, "Royal TS Function 3(0x0042)"},
{0x11BD, 0x0042, 0x11BD, 0x0044, "PCTV 2000i Dual DVB-T Pro PCI Common(0x11BD-0x0044)"},
{0x11BD, 0x0042, 0x11BD, 0x0045, "PCTV Dual Sat Pro PCI 4000i Common(0x11BD-0x0045)"},
{0x11BD, 0x0051, 0xFFFF, 0xFFFF, "PCTV HD 800i(0x0051)"},
{0x11BD, 0xBEDE, 0xFFFF, 0xFFFF, "AV/DV Studio Capture Card(0xBEDE)"},
}; /* pci_vid_11BD[] */

static pci_id_t const pci_vid_11BE[] = {
{0x11BE, 0xFFFF, 0xFFFF, 0xFFFF, "International Microcircuits Inc(0x11BE)"},
}; /* pci_vid_11BE[] */

static pci_id_t const pci_vid_11BF[] = {
{0x11BF, 0xFFFF, 0xFFFF, 0xFFFF, "Astrodesign, Inc.(0x11BF)"},
}; /* pci_vid_11BF[] */

static pci_id_t const pci_vid_11C0[] = {
{0x11C0, 0xFFFF, 0xFFFF, 0xFFFF, "Hewlett Packard(0x11C0)"},
}; /* pci_vid_11C0[] */

static pci_id_t const pci_vid_11C1[] = {
{0x11C1, 0xFFFF, 0xFFFF, 0xFFFF, "LSI Corporation(0x11C1)"},
{0x11C1, 0x0440, 0xFFFF, 0xFFFF, "56k WinModem(0x0440)"},
{0x11C1, 0x0440, 0x1033, 0x8015, "LT WinModem 56k Data+Fax+Voice+Dsvd(0x1033-0x8015)"},
{0x11C1, 0x0440, 0x1033, 0x8047, "LT WinModem 56k Data+Fax+Voice+Dsvd(0x1033-0x8047)"},
{0x11C1, 0x0440, 0x1033, 0x804F, "LT WinModem 56k Data+Fax+Voice+Dsvd(0x1033-0x804F)"},
{0x11C1, 0x0440, 0x10CF, 0x102C, "LB LT Modem V.90 56k(0x10CF-0x102C)"},
{0x11C1, 0x0440, 0x10CF, 0x104A, "BIBLO LT Modem 56k(0x10CF-0x104A)"},
{0x11C1, 0x0440, 0x10CF, 0x105F, "LB2 LT Modem V.90 56k(0x10CF-0x105F)"},
{0x11C1, 0x0440, 0x1179, 0x0001, "Internal V.90 Modem(0x1179-0x0001)"},
{0x11C1, 0x0440, 0x11C1, 0x0440, "LT WinModem 56k Data+Fax+Voice+Dsvd(0x11C1-0x0440)"},
{0x11C1, 0x0440, 0x122D, 0x4101, "MDP7800-U Modem(0x122D-0x4101)"},
{0x11C1, 0x0440, 0x122D, 0x4102, "MDP7800SP-U Modem(0x122D-0x4102)"},
{0x11C1, 0x0440, 0x13E0, 0x0040, "LT WinModem 56k Data+Fax+Voice+Dsvd(0x13E0-0x0040)"},
{0x11C1, 0x0440, 0x13E0, 0x0440, "LT WinModem 56k Data+Fax+Voice+Dsvd(0x13E0-0x0440)"},
{0x11C1, 0x0440, 0x13E0, 0x0441, "LT WinModem 56k Data+Fax+Voice+Dsvd(0x13E0-0x0441)"},
{0x11C1, 0x0440, 0x13E0, 0x0450, "LT WinModem 56k Data+Fax+Voice+Dsvd(0x13E0-0x0450)"},
{0x11C1, 0x0440, 0x13E0, 0xF100, "LT WinModem 56k Data+Fax+Voice+Dsvd(0x13E0-0xF100)"},
{0x11C1, 0x0440, 0x13E0, 0xF101, "LT WinModem 56k Data+Fax+Voice+Dsvd(0x13E0-0xF101)"},
{0x11C1, 0x0440, 0x144D, 0x2101, "LT56PV Modem(0x144D-0x2101)"},
{0x11C1, 0x0440, 0x149F, 0x0440, "LT WinModem 56k Data+Fax+Voice+Dsvd(0x149F-0x0440)"},
{0x11C1, 0x0441, 0xFFFF, 0xFFFF, "56k WinModem(0x0441)"},
{0x11C1, 0x0441, 0x1033, 0x804D, "LT WinModem 56k Data+Fax(0x1033-0x804D)"},
{0x11C1, 0x0441, 0x1033, 0x8065, "LT WinModem 56k Data+Fax(0x1033-0x8065)"},
{0x11C1, 0x0441, 0x1092, 0x0440, "Supra 56i(0x1092-0x0440)"},
{0x11C1, 0x0441, 0x1179, 0x0001, "Internal V.90 Modem(0x1179-0x0001)"},
{0x11C1, 0x0441, 0x11C1, 0x0440, "LT WinModem 56k Data+Fax(0x11C1-0x0440)"},
{0x11C1, 0x0441, 0x11C1, 0x0441, "LT WinModem 56k Data+Fax(0x11C1-0x0441)"},
{0x11C1, 0x0441, 0x122D, 0x4100, "MDP7800-U Modem(0x122D-0x4100)"},
{0x11C1, 0x0441, 0x13E0, 0x0040, "LT WinModem 56k Data+Fax(0x13E0-0x0040)"},
{0x11C1, 0x0441, 0x13E0, 0x0100, "LT WinModem 56k Data+Fax(0x13E0-0x0100)"},
{0x11C1, 0x0441, 0x13E0, 0x0410, "LT WinModem 56k Data+Fax(0x13E0-0x0410)"},
{0x11C1, 0x0441, 0x13E0, 0x0420, "TelePath Internet 56k WinModem(0x13E0-0x0420)"},
{0x11C1, 0x0441, 0x13E0, 0x0440, "LT WinModem 56k Data+Fax(0x13E0-0x0440)"},
{0x11C1, 0x0441, 0x13E0, 0x0443, "LT WinModem 56k Data+Fax(0x13E0-0x0443)"},
{0x11C1, 0x0441, 0x13E0, 0xF102, "LT WinModem 56k Data+Fax(0x13E0-0xF102)"},
{0x11C1, 0x0441, 0x1416, 0x9804, "CommWave 56k Modem(0x1416-0x9804)"},
{0x11C1, 0x0441, 0x141D, 0x0440, "LT WinModem 56k Data+Fax(0x141D-0x0440)"},
{0x11C1, 0x0441, 0x144F, 0x0441, "Lucent 56k V.90 DF Modem(0x144F-0x0441)"},
{0x11C1, 0x0441, 0x144F, 0x0449, "Lucent 56k V.90 DF Modem(0x144F-0x0449)"},
{0x11C1, 0x0441, 0x144F, 0x110D, "Lucent Win Modem(0x144F-0x110D)"},
{0x11C1, 0x0441, 0x1468, 0x0441, "Presario 56k V.90 DF Modem(0x1468-0x0441)"},
{0x11C1, 0x0441, 0x1668, 0x0440, "Lucent Win Modem(0x1668-0x0440)"},
{0x11C1, 0x0442, 0xFFFF, 0xFFFF, "56k WinModem(0x0442)"},
{0x11C1, 0x0442, 0x11C1, 0x0440, "LT WinModem 56k Data+Fax+Voice+VoiceView+Dsvd(0x11C1-0x0440)"},
{0x11C1, 0x0442, 0x11C1, 0x0442, "LT WinModem 56k Data+Fax+Voice+VoiceView+Dsvd(0x11C1-0x0442)"},
{0x11C1, 0x0442, 0x13E0, 0x0412, "LT WinModem 56k Data+Fax+Voice+VoiceView+Dsvd(0x13E0-0x0412)"},
{0x11C1, 0x0442, 0x13E0, 0x0442, "LT WinModem 56k Data+Fax+Voice+VoiceView+Dsvd(0x13E0-0x0442)"},
{0x11C1, 0x0442, 0x13FC, 0x2471, "LT WinModem 56k Data+Fax+Voice+VoiceView+Dsvd(0x13FC-0x2471)"},
{0x11C1, 0x0442, 0x144D, 0x2104, "LT56PT Modem(0x144D-0x2104)"},
{0x11C1, 0x0442, 0x144F, 0x1104, "LT WinModem 56k Data+Fax+Voice+VoiceView+Dsvd(0x144F-0x1104)"},
{0x11C1, 0x0442, 0x149F, 0x0440, "LT WinModem 56k Data+Fax+Voice+VoiceView+Dsvd(0x149F-0x0440)"},
{0x11C1, 0x0442, 0x1668, 0x0440, "LT WinModem 56k Data+Fax+Voice+VoiceView+Dsvd(0x1668-0x0440)"},
{0x11C1, 0x0443, 0xFFFF, 0xFFFF, "LT WinModem(0x0443)"},
{0x11C1, 0x0444, 0xFFFF, 0xFFFF, "LT WinModem(0x0444)"},
{0x11C1, 0x0445, 0xFFFF, 0xFFFF, "LT WinModem(0x0445)"},
{0x11C1, 0x0445, 0x8086, 0x2203, "PRO/100+ MiniPCI (probably an Ambit U98.003.C.00 combo card)(0x8086-0x2203)"},
{0x11C1, 0x0445, 0x8086, 0x2204, "PRO/100+ MiniPCI on Armada E500(0x8086-0x2204)"},
{0x11C1, 0x0446, 0xFFFF, 0xFFFF, "LT WinModem(0x0446)"},
{0x11C1, 0x0447, 0xFFFF, 0xFFFF, "LT WinModem(0x0447)"},
{0x11C1, 0x0448, 0xFFFF, 0xFFFF, "WinModem 56k(0x0448)"},
{0x11C1, 0x0448, 0x1014, 0x0131, "Lucent Win Modem(0x1014-0x0131)"},
{0x11C1, 0x0448, 0x1033, 0x8066, "LT WinModem 56k Data+Fax+Voice+Dsvd(0x1033-0x8066)"},
{0x11C1, 0x0448, 0x13E0, 0x0030, "56k Voice Modem(0x13E0-0x0030)"},
{0x11C1, 0x0448, 0x13E0, 0x0040, "LT WinModem 56k Data+Fax+Voice+Dsvd(0x13E0-0x0040)"},
{0x11C1, 0x0448, 0x1668, 0x2400, "LT WinModem 56k (MiniPCI Ethernet+Modem)(0x1668-0x2400)"},
{0x11C1, 0x0449, 0xFFFF, 0xFFFF, "L56xM+S [Mars-2] WinModem 56k(0x0449)"},
{0x11C1, 0x0449, 0x0E11, 0xB14D, "56k V.90 Modem(0x0E11-0xB14D)"},
{0x11C1, 0x0449, 0x1014, 0x018C, "ThinkPad 600X(0x1014-0x018C)"},
{0x11C1, 0x0449, 0x13E0, 0x0020, "LT WinModem 56k Data+Fax(0x13E0-0x0020)"},
{0x11C1, 0x0449, 0x13E0, 0x0041, "TelePath Internet 56k WinModem(0x13E0-0x0041)"},
{0x11C1, 0x0449, 0x1436, 0x0440, "Lucent Win Modem(0x1436-0x0440)"},
{0x11C1, 0x0449, 0x144F, 0x0449, "Lucent 56k V.90 DFi Modem(0x144F-0x0449)"},
{0x11C1, 0x0449, 0x1468, 0x0410, "IBM ThinkPad T23(0x1468-0x0410)"},
{0x11C1, 0x0449, 0x1468, 0x0440, "Lucent Win Modem(0x1468-0x0440)"},
{0x11C1, 0x0449, 0x1468, 0x0449, "Presario 56k V.90 DFi Modem(0x1468-0x0449)"},
{0x11C1, 0x044A, 0xFFFF, 0xFFFF, "F-1156IV WinModem (V90, 56KFlex)(0x044A)"},
{0x11C1, 0x044A, 0x10CF, 0x1072, "LB Global LT Modem(0x10CF-0x1072)"},
{0x11C1, 0x044A, 0x13E0, 0x0012, "LT WinModem 56k Data+Fax+Voice+VoiceView+Dsvd(0x13E0-0x0012)"},
{0x11C1, 0x044A, 0x13E0, 0x0042, "LT WinModem 56k Data+Fax+Voice+VoiceView+Dsvd(0x13E0-0x0042)"},
{0x11C1, 0x044A, 0x144F, 0x1005, "LT WinModem 56k Data+Fax+Voice+VoiceView+Dsvd(0x144F-0x1005)"},
{0x11C1, 0x044B, 0xFFFF, 0xFFFF, "LT WinModem(0x044B)"},
{0x11C1, 0x044C, 0xFFFF, 0xFFFF, "LT WinModem(0x044C)"},
{0x11C1, 0x044D, 0xFFFF, 0xFFFF, "LT WinModem(0x044D)"},
{0x11C1, 0x044E, 0xFFFF, 0xFFFF, "LT WinModem(0x044E)"},
{0x11C1, 0x044F, 0xFFFF, 0xFFFF, "V90 WildWire Modem(0x044F)"},
{0x11C1, 0x0450, 0xFFFF, 0xFFFF, "LT WinModem(0x0450)"},
{0x11C1, 0x0450, 0x1033, 0x80A8, "Versa Note Vxi(0x1033-0x80A8)"},
{0x11C1, 0x0450, 0x144F, 0x4005, "Magnia SG20(0x144F-0x4005)"},
{0x11C1, 0x0450, 0x1468, 0x0450, "Evo N600c(0x1468-0x0450)"},
{0x11C1, 0x0451, 0xFFFF, 0xFFFF, "LT WinModem(0x0451)"},
{0x11C1, 0x0452, 0xFFFF, 0xFFFF, "LT WinModem(0x0452)"},
{0x11C1, 0x0453, 0xFFFF, 0xFFFF, "LT WinModem(0x0453)"},
{0x11C1, 0x0454, 0xFFFF, 0xFFFF, "LT WinModem(0x0454)"},
{0x11C1, 0x0455, 0xFFFF, 0xFFFF, "LT WinModem(0x0455)"},
{0x11C1, 0x0456, 0xFFFF, 0xFFFF, "LT WinModem(0x0456)"},
{0x11C1, 0x0457, 0xFFFF, 0xFFFF, "LT WinModem(0x0457)"},
{0x11C1, 0x0458, 0xFFFF, 0xFFFF, "LT WinModem(0x0458)"},
{0x11C1, 0x0459, 0xFFFF, 0xFFFF, "LT WinModem(0x0459)"},
{0x11C1, 0x045A, 0xFFFF, 0xFFFF, "LT WinModem(0x045A)"},
{0x11C1, 0x045C, 0xFFFF, 0xFFFF, "LT WinModem(0x045C)"},
{0x11C1, 0x0461, 0xFFFF, 0xFFFF, "V90 WildWire Modem(0x0461)"},
{0x11C1, 0x0462, 0xFFFF, 0xFFFF, "V90 WildWire Modem(0x0462)"},
{0x11C1, 0x0480, 0xFFFF, 0xFFFF, "Venus Modem (V90, 56KFlex)(0x0480)"},
{0x11C1, 0x048C, 0xFFFF, 0xFFFF, "V.92 56K WinModem(0x048C)"},
{0x11C1, 0x048F, 0xFFFF, 0xFFFF, "V.92 56k WinModem(0x048F)"},
{0x11C1, 0x0620, 0xFFFF, 0xFFFF, "Lucent V.92 Data/Fax Modem(0x0620)"},
{0x11C1, 0x2600, 0xFFFF, 0xFFFF, "StarPro26XX family (SP2601, SP2603, SP2612) DSP(0x2600)"},
{0x11C1, 0x5400, 0xFFFF, 0xFFFF, "OR3TP12 FPSC(0x5400)"},
{0x11C1, 0x5656, 0xFFFF, 0xFFFF, "Venus Modem(0x5656)"},
{0x11C1, 0x5801, 0xFFFF, 0xFFFF, "USB(0x5801)"},
{0x11C1, 0x5802, 0xFFFF, 0xFFFF, "USS-312 USB Controller(0x5802)"},
{0x11C1, 0x5803, 0xFFFF, 0xFFFF, "USS-344S USB Controller(0x5803)"},
{0x11C1, 0x5811, 0xFFFF, 0xFFFF, "FW322/323 [TrueFire] 1394a Controller(0x5811)"},
{0x11C1, 0x5811, 0x103C, 0x2A34, "Pavilion a1677c(0x103C-0x2A34)"},
{0x11C1, 0x5811, 0x103C, 0x2A6F, "Asus IPIBL-LB Motherboard(0x103C-0x2A6F)"},
{0x11C1, 0x5811, 0x103C, 0x2A9E, "Pavilion p6310f(0x103C-0x2A9E)"},
{0x11C1, 0x5811, 0x1043, 0x8294, "LSI FW322/323 IEEE 1394a FireWire Controller(0x1043-0x8294)"},
{0x11C1, 0x5811, 0x11BD, 0x000E, "LSI FW323(0x11BD-0x000E)"},
{0x11C1, 0x5811, 0x8086, 0x524C, "D865PERL mainboard(0x8086-0x524C)"},
{0x11C1, 0x5811, 0x9005, 0x0033, "Adaptec AFW-2100 (HP) 2102900-R(0x9005-0x0033)"},
{0x11C1, 0x5811, 0xDEAD, 0x0800, "FireWire Host Bus Adapter(0xDEAD-0x0800)"},
{0x11C1, 0x5901, 0xFFFF, 0xFFFF, "FW643 [TrueFire] PCIe 1394b Controller(0x5901)"},
{0x11C1, 0x5901, 0x11C1, 0x5900, "FW643 [TrueFire] PCIe 1394b Controller(0x11C1-0x5900)"},
{0x11C1, 0x5901, 0x1443, 0x0643, "FireBoard800-e V.2(0x1443-0x0643)"},
{0x11C1, 0x5901, 0x1546, 0x0643, "FWB-PCIE1X2x(0x1546-0x0643)"},
{0x11C1, 0x5903, 0xFFFF, 0xFFFF, "FW533 [TrueFire] PCIe 1394a Controller(0x5903)"},
{0x11C1, 0x8110, 0xFFFF, 0xFFFF, "T8110 H.100/H.110 TDM switch(0x8110)"},
{0x11C1, 0x8110, 0x12D9, 0x000C, "E1/T1 PMXc cPCI carrier card(0x12D9-0x000C)"},
{0x11C1, 0xAB10, 0xFFFF, 0xFFFF, "WL60010 Wireless LAN MAC(0xAB10)"},
{0x11C1, 0xAB11, 0xFFFF, 0xFFFF, "WL60040 Multimode Wireles LAN MAC(0xAB11)"},
{0x11C1, 0xAB11, 0x11C1, 0xAB12, "WaveLAN 11abg Cardbus card (Model 1102)(0x11C1-0xAB12)"},
{0x11C1, 0xAB11, 0x11C1, 0xAB13, "WaveLAN 11abg MiniPCI card (Model 0512)(0x11C1-0xAB13)"},
{0x11C1, 0xAB11, 0x11C1, 0xAB15, "WaveLAN 11abg Cardbus card (Model 1106)(0x11C1-0xAB15)"},
{0x11C1, 0xAB11, 0x11C1, 0xAB16, "WaveLAN 11abg MiniPCI card (Model 0516)(0x11C1-0xAB16)"},
{0x11C1, 0xAB20, 0xFFFF, 0xFFFF, "ORiNOCO PCI Adapter(0xAB20)"},
{0x11C1, 0xAB21, 0xFFFF, 0xFFFF, "Agere Wireless PCI Adapter(0xAB21)"},
{0x11C1, 0xAB30, 0xFFFF, 0xFFFF, "Hermes2 Mini-PCI WaveLAN a/b/g(0xAB30)"},
{0x11C1, 0xAB30, 0x14CD, 0x2012, "Hermes2 Mini-PCI WaveLAN a/b/g(0x14CD-0x2012)"},
{0x11C1, 0xED00, 0xFFFF, 0xFFFF, "ET-131x PCI-E Ethernet Controller(0xED00)"},
{0x11C1, 0xED01, 0xFFFF, 0xFFFF, "ET-131x PCI-E Ethernet Controller(0xED01)"},
}; /* pci_vid_11C1[] */

static pci_id_t const pci_vid_11C2[] = {
{0x11C2, 0xFFFF, 0xFFFF, 0xFFFF, "Sand Microelectronics(0x11C2)"},
}; /* pci_vid_11C2[] */

static pci_id_t const pci_vid_11C3[] = {
{0x11C3, 0xFFFF, 0xFFFF, 0xFFFF, "NEC Corporation(0x11C3)"},
}; /* pci_vid_11C3[] */

static pci_id_t const pci_vid_11C4[] = {
{0x11C4, 0xFFFF, 0xFFFF, 0xFFFF, "Document Technologies, Inc(0x11C4)"},
}; /* pci_vid_11C4[] */

static pci_id_t const pci_vid_11C5[] = {
{0x11C5, 0xFFFF, 0xFFFF, 0xFFFF, "Shiva Corporation(0x11C5)"},
}; /* pci_vid_11C5[] */

static pci_id_t const pci_vid_11C6[] = {
{0x11C6, 0xFFFF, 0xFFFF, 0xFFFF, "Dainippon Screen Mfg. Co. Ltd(0x11C6)"},
}; /* pci_vid_11C6[] */

static pci_id_t const pci_vid_11C7[] = {
{0x11C7, 0xFFFF, 0xFFFF, 0xFFFF, "D.C.M. Data Systems(0x11C7)"},
}; /* pci_vid_11C7[] */

static pci_id_t const pci_vid_11C8[] = {
{0x11C8, 0xFFFF, 0xFFFF, 0xFFFF, "Dolphin Interconnect Solutions AS(0x11C8)"},
{0x11C8, 0x0658, 0xFFFF, 0xFFFF, "PSB32 SCI-Adapter D31x(0x0658)"},
{0x11C8, 0xD665, 0xFFFF, 0xFFFF, "PSB64 SCI-Adapter D32x(0xD665)"},
{0x11C8, 0xD667, 0xFFFF, 0xFFFF, "PSB66 SCI-Adapter D33x(0xD667)"},
}; /* pci_vid_11C8[] */

static pci_id_t const pci_vid_11C9[] = {
{0x11C9, 0xFFFF, 0xFFFF, 0xFFFF, "Magma(0x11C9)"},
{0x11C9, 0x0010, 0xFFFF, 0xFFFF, "16-line serial port w/- DMA(0x0010)"},
{0x11C9, 0x0011, 0xFFFF, 0xFFFF, "4-line serial port w/- DMA(0x0011)"},
}; /* pci_vid_11C9[] */

static pci_id_t const pci_vid_11CA[] = {
{0x11CA, 0xFFFF, 0xFFFF, 0xFFFF, "LSI Systems, Inc(0x11CA)"},
}; /* pci_vid_11CA[] */

static pci_id_t const pci_vid_11CB[] = {
{0x11CB, 0xFFFF, 0xFFFF, 0xFFFF, "Specialix Research Ltd.(0x11CB)"},
{0x11CB, 0x2000, 0xFFFF, 0xFFFF, "PCI_9050(0x2000)"},
{0x11CB, 0x2000, 0x11CB, 0x0200, "SX(0x11CB-0x0200)"},
{0x11CB, 0x2000, 0x11CB, 0xB008, "I/O8+(0x11CB-0xB008)"},
{0x11CB, 0x4000, 0xFFFF, 0xFFFF, "SUPI_1(0x4000)"},
{0x11CB, 0x8000, 0xFFFF, 0xFFFF, "T225(0x8000)"},
}; /* pci_vid_11CB[] */

static pci_id_t const pci_vid_11CC[] = {
{0x11CC, 0xFFFF, 0xFFFF, 0xFFFF, "Michels & Kleberhoff Computer GmbH(0x11CC)"},
}; /* pci_vid_11CC[] */

static pci_id_t const pci_vid_11CD[] = {
{0x11CD, 0xFFFF, 0xFFFF, 0xFFFF, "HAL Computer Systems, Inc.(0x11CD)"},
}; /* pci_vid_11CD[] */

static pci_id_t const pci_vid_11CE[] = {
{0x11CE, 0xFFFF, 0xFFFF, 0xFFFF, "Netaccess(0x11CE)"},
}; /* pci_vid_11CE[] */

static pci_id_t const pci_vid_11CF[] = {
{0x11CF, 0xFFFF, 0xFFFF, 0xFFFF, "Pioneer Electronic Corporation(0x11CF)"},
}; /* pci_vid_11CF[] */

static pci_id_t const pci_vid_11D0[] = {
{0x11D0, 0xFFFF, 0xFFFF, 0xFFFF, "Lockheed Martin Federal Systems-Manassas(0x11D0)"},
}; /* pci_vid_11D0[] */

static pci_id_t const pci_vid_11D1[] = {
{0x11D1, 0xFFFF, 0xFFFF, 0xFFFF, "Auravision(0x11D1)"},
{0x11D1, 0x01F7, 0xFFFF, 0xFFFF, "VxP524(0x01F7)"},
{0x11D1, 0x01F9, 0xFFFF, 0xFFFF, "VxP951(0x01F9)"},
}; /* pci_vid_11D1[] */

static pci_id_t const pci_vid_11D2[] = {
{0x11D2, 0xFFFF, 0xFFFF, 0xFFFF, "Intercom Inc.(0x11D2)"},
}; /* pci_vid_11D2[] */

static pci_id_t const pci_vid_11D3[] = {
{0x11D3, 0xFFFF, 0xFFFF, 0xFFFF, "Trancell Systems Inc(0x11D3)"},
}; /* pci_vid_11D3[] */

static pci_id_t const pci_vid_11D4[] = {
{0x11D4, 0xFFFF, 0xFFFF, 0xFFFF, "Analog Devices(0x11D4)"},
{0x11D4, 0x1535, 0xFFFF, 0xFFFF, "Blackfin BF535 processor(0x1535)"},
{0x11D4, 0x1805, 0xFFFF, 0xFFFF, "SM56 PCI modem(0x1805)"},
}; /* pci_vid_11D4[] */

static pci_id_t const pci_vid_11D5[] = {
{0x11D5, 0xFFFF, 0xFFFF, 0xFFFF, "Ikon Corporation(0x11D5)"},
{0x11D5, 0x0115, 0xFFFF, 0xFFFF, "10115(0x0115)"},
{0x11D5, 0x0117, 0xFFFF, 0xFFFF, "10117(0x0117)"},
}; /* pci_vid_11D5[] */

static pci_id_t const pci_vid_11D6[] = {
{0x11D6, 0xFFFF, 0xFFFF, 0xFFFF, "Tekelec Telecom(0x11D6)"},
}; /* pci_vid_11D6[] */

static pci_id_t const pci_vid_11D7[] = {
{0x11D7, 0xFFFF, 0xFFFF, 0xFFFF, "Trenton Technology, Inc.(0x11D7)"},
}; /* pci_vid_11D7[] */

static pci_id_t const pci_vid_11D8[] = {
{0x11D8, 0xFFFF, 0xFFFF, 0xFFFF, "Image Technologies Development(0x11D8)"},
}; /* pci_vid_11D8[] */

static pci_id_t const pci_vid_11D9[] = {
{0x11D9, 0xFFFF, 0xFFFF, 0xFFFF, "TEC Corporation(0x11D9)"},
}; /* pci_vid_11D9[] */

static pci_id_t const pci_vid_11DA[] = {
{0x11DA, 0xFFFF, 0xFFFF, 0xFFFF, "Novell(0x11DA)"},
}; /* pci_vid_11DA[] */

static pci_id_t const pci_vid_11DB[] = {
{0x11DB, 0xFFFF, 0xFFFF, 0xFFFF, "Sega Enterprises Ltd(0x11DB)"},
}; /* pci_vid_11DB[] */

static pci_id_t const pci_vid_11DC[] = {
{0x11DC, 0xFFFF, 0xFFFF, 0xFFFF, "Questra Corporation(0x11DC)"},
}; /* pci_vid_11DC[] */

static pci_id_t const pci_vid_11DD[] = {
{0x11DD, 0xFFFF, 0xFFFF, 0xFFFF, "Crosfield Electronics Limited(0x11DD)"},
}; /* pci_vid_11DD[] */

static pci_id_t const pci_vid_11DE[] = {
{0x11DE, 0xFFFF, 0xFFFF, 0xFFFF, "Zoran Corporation(0x11DE)"},
{0x11DE, 0x6017, 0xFFFF, 0xFFFF, "miroVIDEO DC30(0x6017)"},
{0x11DE, 0x6057, 0xFFFF, 0xFFFF, "ZR36057PQC Video cutting chipset(0x6057)"},
{0x11DE, 0x6057, 0x1031, 0x7EFE, "DC10 Plus(0x1031-0x7EFE)"},
{0x11DE, 0x6057, 0x1031, 0xFC00, "MiroVIDEO DC50, Motion JPEG Capture/CODEC Board(0x1031-0xFC00)"},
{0x11DE, 0x6057, 0x12F8, 0x8A02, "Tekram Video Kit(0x12F8-0x8A02)"},
{0x11DE, 0x6057, 0x13CA, 0x4231, "JPEG/TV Card(0x13CA-0x4231)"},
{0x11DE, 0x6120, 0xFFFF, 0xFFFF, "ZR36120(0x6120)"},
{0x11DE, 0x6120, 0x1328, 0xF001, "Cinemaster C DVD Decoder(0x1328-0xF001)"},
{0x11DE, 0x6120, 0x13C2, 0x0000, "MediaFocus Satellite TV Card(0x13C2-0x0000)"},
{0x11DE, 0x6120, 0x1DE1, 0x9FFF, "Video Kit C210(0x1DE1-0x9FFF)"},
}; /* pci_vid_11DE[] */

static pci_id_t const pci_vid_11DF[] = {
{0x11DF, 0xFFFF, 0xFFFF, 0xFFFF, "New Wave PDG(0x11DF)"},
}; /* pci_vid_11DF[] */

static pci_id_t const pci_vid_11E0[] = {
{0x11E0, 0xFFFF, 0xFFFF, 0xFFFF, "Cray Communications A/S(0x11E0)"},
}; /* pci_vid_11E0[] */

static pci_id_t const pci_vid_11E1[] = {
{0x11E1, 0xFFFF, 0xFFFF, 0xFFFF, "GEC Plessey Semi Inc.(0x11E1)"},
}; /* pci_vid_11E1[] */

static pci_id_t const pci_vid_11E2[] = {
{0x11E2, 0xFFFF, 0xFFFF, 0xFFFF, "Samsung Information Systems America(0x11E2)"},
}; /* pci_vid_11E2[] */

static pci_id_t const pci_vid_11E3[] = {
{0x11E3, 0xFFFF, 0xFFFF, 0xFFFF, "Quicklogic Corporation(0x11E3)"},
{0x11E3, 0x0001, 0xFFFF, 0xFFFF, "COM-ON-AIR Dosch&Amand DECT(0x0001)"},
{0x11E3, 0x0010, 0xFFFF, 0xFFFF, "QL5032 (PQFP208) [QuickPCI] 33 MHz/32-bit PCI Master/Target with Embedded Programmable Logic and Dual Port SRAM(0x0010)"},
{0x11E3, 0x0011, 0xFFFF, 0xFFFF, "QL5032 (PBGA256) [QuickPCI] 33 MHz/32-bit PCI Master/Target with Embedded Programmable Logic and Dual Port SRAM(0x0011)"},
{0x11E3, 0x0012, 0xFFFF, 0xFFFF, "QL5232 (PQFP208) [QuickPCI] 33 MHz/32-bit PCI Master/Target with Embedded Programmable Logic and Dual Port SRAM(0x0012)"},
{0x11E3, 0x0012, 0x11E3, 0x1204, "Becker & Hickl SPC-130(0x11E3-0x1204)"},
{0x11E3, 0x0012, 0x11E3, 0x1207, "Becker & Hickl DDG-200(0x11E3-0x1207)"},
{0x11E3, 0x0012, 0x11E3, 0x1209, "Becker & Hickl SHM-180(0x11E3-0x1209)"},
{0x11E3, 0x0012, 0x11E3, 0x120C, "Becker & Hickl PMM-428(0x11E3-0x120C)"},
{0x11E3, 0x0013, 0xFFFF, 0xFFFF, "QL5232 (PBGA456) [QuickPCI] 33 MHz/32-bit PCI Master/Target with Embedded Programmable Logic and Dual Port SRAM(0x0013)"},
{0x11E3, 0x0014, 0xFFFF, 0xFFFF, "QL5030 (TQFP144) [QuickPCI] 33 MHz/32-bit PCI Target with Embedded Programmable Logic and Dual Port SRAM(0x0014)"},
{0x11E3, 0x0015, 0xFFFF, 0xFFFF, "QL5130 (TQFP144) [QuickPCI] 33 MHz/32-bit PCI Target with Embedded Programmable Logic and Dual Port SRAM(0x0015)"},
{0x11E3, 0x0016, 0xFFFF, 0xFFFF, "QL5130 (PQFP208) [QuickPCI] 33 MHz/32-bit PCI Target with Embedded Programmable Logic and Dual Port SRAM(0x0016)"},
{0x11E3, 0x0016, 0x11E3, 0x120B, "Becker & Hickl DEL-350(0x11E3-0x120B)"},
{0x11E3, 0x0017, 0xFFFF, 0xFFFF, "QL5130 (PBGA256) [QuickPCI] 33 MHz/32-bit PCI Target with Embedded Programmable Logic and Dual Port SRAM(0x0017)"},
{0x11E3, 0x0019, 0xFFFF, 0xFFFF, "QL5332 (PQFP208) [QuickPCI] 33 MHz/32-bit PCI Master/Target with Embedded Programmable Logic and Dual Port SRAM(0x0019)"},
{0x11E3, 0x001A, 0xFFFF, 0xFFFF, "QL5332 (PBGA256) [QuickPCI] 33 MHz/32-bit PCI Master/Target with Embedded Programmable Logic and Dual Port SRAM(0x001A)"},
{0x11E3, 0x001B, 0xFFFF, 0xFFFF, "QL5432 (PQFP208) [QuickPCI] 33 MHz/32-bit PCI Master/Target with Embedded Programmable Logic and Dual Port SRAM(0x001B)"},
{0x11E3, 0x001B, 0x11E3, 0x120D, "Becker & Hickl SPC-140(0x11E3-0x120D)"},
{0x11E3, 0x001B, 0x11E3, 0x1211, "Becker & Hickl GVD-120(0x11E3-0x1211)"},
{0x11E3, 0x001B, 0x11E3, 0x1212, "Becker & Hickl DDG-210(0x11E3-0x1212)"},
{0x11E3, 0x001C, 0xFFFF, 0xFFFF, "QL5432 (PBGA456) [QuickPCI] 33 MHz/32-bit PCI Master/Target with Embedded Programmable Logic and Dual Port SRAM(0x001C)"},
{0x11E3, 0x001D, 0xFFFF, 0xFFFF, "QL5632 (PQFP208) [QuickPCI] 33 MHz/32-bit PCI Master/Target with Embedded Programmable Logic and Dual Port SRAM(0x001D)"},
{0x11E3, 0x001E, 0xFFFF, 0xFFFF, "QL5632 (PBGA280) [QuickPCI] 33 MHz/32-bit PCI Master/Target with Embedded Programmable Logic and Dual Port SRAM(0x001E)"},
{0x11E3, 0x001F, 0xFFFF, 0xFFFF, "QL5632 (PBGA484) [QuickPCI] 33 MHz/32-bit PCI Master/Target with Embedded Programmable Logic and Dual Port SRAM(0x001F)"},
{0x11E3, 0x0020, 0xFFFF, 0xFFFF, "QL5632 (PBGA516) [QuickPCI] 33 MHz/32-bit PCI Master/Target with Embedded Programmable Logic and Dual Port SRAM(0x0020)"},
{0x11E3, 0x0021, 0xFFFF, 0xFFFF, "QL5732 (PQFP208) [QuickPCI] 33 MHz/32-bit PCI Master/Target with Embedded Programmable Logic and Dual Port SRAM(0x0021)"},
{0x11E3, 0x0022, 0xFFFF, 0xFFFF, "QL5732 (PBGA280) [QuickPCI] 33 MHz/32-bit PCI Master/Target with Embedded Programmable Logic and Dual Port SRAM(0x0022)"},
{0x11E3, 0x0023, 0xFFFF, 0xFFFF, "QL5732 (PBGA484) [QuickPCI] 33 MHz/32-bit PCI Master/Target with Embedded Programmable Logic and Dual Port SRAM(0x0023)"},
{0x11E3, 0x0024, 0xFFFF, 0xFFFF, "QL5732 (PBGA516) [QuickPCI] 33 MHz/32-bit PCI Master/Target with Embedded Programmable Logic and Dual Port SRAM(0x0024)"},
{0x11E3, 0x002D, 0xFFFF, 0xFFFF, "QL5022 (TQFP144) [QuickPCI] 33 MHz/32-bit PCI Master/Target with Embedded Programmable Logic and Dual Port SRAM(0x002D)"},
{0x11E3, 0x002E, 0xFFFF, 0xFFFF, "QL5022 (PQFP208) [QuickPCI] 33 MHz/32-bit PCI Master/Target with Embedded Programmable Logic and Dual Port SRAM(0x002E)"},
{0x11E3, 0x002F, 0xFFFF, 0xFFFF, "QL5020 (TQFP144) [QuickPCI] 33 MHz/32-bit PCI Target with Embedded Programmable Logic and Dual Port SRAM(0x002F)"},
{0x11E3, 0x0030, 0xFFFF, 0xFFFF, "QL5020 (PQFP208) [QuickPCI] 33 MHz/32-bit PCI Target with Embedded Programmable Logic and Dual Port SRAM(0x0030)"},
{0x11E3, 0x0560, 0xFFFF, 0xFFFF, "QL5064 Companion Design Demo Board(0x0560)"},
{0x11E3, 0x5030, 0xFFFF, 0xFFFF, "PC Watchdog(0x5030)"},
{0x11E3, 0x8417, 0xFFFF, 0xFFFF, "QL5064 [QuickPCI] PCI v2.2 bridge for SMT417 Dual TMS320C6416T PMC Module(0x8417)"},
}; /* pci_vid_11E3[] */

static pci_id_t const pci_vid_11E4[] = {
{0x11E4, 0xFFFF, 0xFFFF, 0xFFFF, "Second Wave Inc(0x11E4)"},
}; /* pci_vid_11E4[] */

static pci_id_t const pci_vid_11E5[] = {
{0x11E5, 0xFFFF, 0xFFFF, 0xFFFF, "IIX Consulting(0x11E5)"},
}; /* pci_vid_11E5[] */

static pci_id_t const pci_vid_11E6[] = {
{0x11E6, 0xFFFF, 0xFFFF, 0xFFFF, "Mitsui-Zosen System Research(0x11E6)"},
}; /* pci_vid_11E6[] */

static pci_id_t const pci_vid_11E7[] = {
{0x11E7, 0xFFFF, 0xFFFF, 0xFFFF, "Toshiba America, Elec. Company(0x11E7)"},
}; /* pci_vid_11E7[] */

static pci_id_t const pci_vid_11E8[] = {
{0x11E8, 0xFFFF, 0xFFFF, 0xFFFF, "Digital Processing Systems Inc.(0x11E8)"},
}; /* pci_vid_11E8[] */

static pci_id_t const pci_vid_11E9[] = {
{0x11E9, 0xFFFF, 0xFFFF, 0xFFFF, "Highwater Designs Ltd.(0x11E9)"},
}; /* pci_vid_11E9[] */

static pci_id_t const pci_vid_11EA[] = {
{0x11EA, 0xFFFF, 0xFFFF, 0xFFFF, "Elsag Bailey(0x11EA)"},
}; /* pci_vid_11EA[] */

static pci_id_t const pci_vid_11EB[] = {
{0x11EB, 0xFFFF, 0xFFFF, 0xFFFF, "Formation Inc.(0x11EB)"},
}; /* pci_vid_11EB[] */

static pci_id_t const pci_vid_11EC[] = {
{0x11EC, 0xFFFF, 0xFFFF, 0xFFFF, "Coreco Inc(0x11EC)"},
{0x11EC, 0x000D, 0xFFFF, 0xFFFF, "Oculus-F/64P(0x000D)"},
{0x11EC, 0x1800, 0xFFFF, 0xFFFF, "Cobra/C6(0x1800)"},
}; /* pci_vid_11EC[] */

static pci_id_t const pci_vid_11ED[] = {
{0x11ED, 0xFFFF, 0xFFFF, 0xFFFF, "Mediamatics(0x11ED)"},
}; /* pci_vid_11ED[] */

static pci_id_t const pci_vid_11EE[] = {
{0x11EE, 0xFFFF, 0xFFFF, 0xFFFF, "Dome Imaging Systems Inc(0x11EE)"},
}; /* pci_vid_11EE[] */

static pci_id_t const pci_vid_11EF[] = {
{0x11EF, 0xFFFF, 0xFFFF, 0xFFFF, "Nicolet Technologies B.V.(0x11EF)"},
}; /* pci_vid_11EF[] */

static pci_id_t const pci_vid_11F0[] = {
{0x11F0, 0xFFFF, 0xFFFF, 0xFFFF, "Compu-Shack(0x11F0)"},
{0x11F0, 0x4231, 0xFFFF, 0xFFFF, "FDDI(0x4231)"},
{0x11F0, 0x4232, 0xFFFF, 0xFFFF, "FASTline UTP Quattro(0x4232)"},
{0x11F0, 0x4233, 0xFFFF, 0xFFFF, "FASTline FO(0x4233)"},
{0x11F0, 0x4234, 0xFFFF, 0xFFFF, "FASTline UTP(0x4234)"},
{0x11F0, 0x4235, 0xFFFF, 0xFFFF, "FASTline-II UTP(0x4235)"},
{0x11F0, 0x4236, 0xFFFF, 0xFFFF, "FASTline-II FO(0x4236)"},
{0x11F0, 0x4731, 0xFFFF, 0xFFFF, "GIGAline(0x4731)"},
}; /* pci_vid_11F0[] */

static pci_id_t const pci_vid_11F1[] = {
{0x11F1, 0xFFFF, 0xFFFF, 0xFFFF, "Symbios Logic Inc(0x11F1)"},
}; /* pci_vid_11F1[] */

static pci_id_t const pci_vid_11F2[] = {
{0x11F2, 0xFFFF, 0xFFFF, 0xFFFF, "Picture Tel Japan K.K.(0x11F2)"},
}; /* pci_vid_11F2[] */

static pci_id_t const pci_vid_11F3[] = {
{0x11F3, 0xFFFF, 0xFFFF, 0xFFFF, "Keithley Metrabyte(0x11F3)"},
{0x11F3, 0x0011, 0xFFFF, 0xFFFF, "KPCI-PIO24(0x0011)"},
}; /* pci_vid_11F3[] */

static pci_id_t const pci_vid_11F4[] = {
{0x11F4, 0xFFFF, 0xFFFF, 0xFFFF, "Kinetic Systems Corporation(0x11F4)"},
{0x11F4, 0x2915, 0xFFFF, 0xFFFF, "CAMAC controller(0x2915)"},
}; /* pci_vid_11F4[] */

static pci_id_t const pci_vid_11F5[] = {
{0x11F5, 0xFFFF, 0xFFFF, 0xFFFF, "Computing Devices International(0x11F5)"},
}; /* pci_vid_11F5[] */

static pci_id_t const pci_vid_11F6[] = {
{0x11F6, 0xFFFF, 0xFFFF, 0xFFFF, "Compex(0x11F6)"},
{0x11F6, 0x0112, 0xFFFF, 0xFFFF, "ENet100VG4(0x0112)"},
{0x11F6, 0x0113, 0xFFFF, 0xFFFF, "FreedomLine 100(0x0113)"},
{0x11F6, 0x1401, 0xFFFF, 0xFFFF, "ReadyLink 2000(0x1401)"},
{0x11F6, 0x2011, 0xFFFF, 0xFFFF, "RL100-ATX 10/100(0x2011)"},
{0x11F6, 0x2011, 0x11F6, 0x2011, "RL100-ATX(0x11F6-0x2011)"},
{0x11F6, 0x2201, 0xFFFF, 0xFFFF, "ReadyLink 100TX (Winbond W89C840)(0x2201)"},
{0x11F6, 0x2201, 0x11F6, 0x2011, "ReadyLink 100TX(0x11F6-0x2011)"},
{0x11F6, 0x9881, 0xFFFF, 0xFFFF, "RL100TX Fast Ethernet(0x9881)"},
}; /* pci_vid_11F6[] */

static pci_id_t const pci_vid_11F7[] = {
{0x11F7, 0xFFFF, 0xFFFF, 0xFFFF, "Scientific Atlanta(0x11F7)"},
}; /* pci_vid_11F7[] */

static pci_id_t const pci_vid_11F8[] = {
{0x11F8, 0xFFFF, 0xFFFF, 0xFFFF, "PMC-Sierra Inc.(0x11F8)"},
{0x11F8, 0x5220, 0xFFFF, 0xFFFF, "BR522x [PMC-Sierra maxRAID SAS Controller](0x5220)"},
{0x11F8, 0x7364, 0xFFFF, 0xFFFF, "PM7364 [FREEDM - 32 Frame Engine & Datalink Mgr](0x7364)"},
{0x11F8, 0x7375, 0xFFFF, 0xFFFF, "PM7375 [LASAR-155 ATM SAR](0x7375)"},
{0x11F8, 0x7384, 0xFFFF, 0xFFFF, "PM7384 [FREEDM - 84P672 Frm Engine & Datalink Mgr](0x7384)"},
{0x11F8, 0x8000, 0xFFFF, 0xFFFF, "PM8000  [SPC - SAS Protocol Controller](0x8000)"},
{0x11F8, 0x8009, 0xFFFF, 0xFFFF, "PM8009 SPCve 8x6G(0x8009)"},
{0x11F8, 0x8018, 0xFFFF, 0xFFFF, "PM8018 Adaptec SAS Adaptor ASA-70165H PCIe Gen3 x8 6 Gbps 16-lane 4x SFF-8644(0x8018)"},
{0x11F8, 0x8032, 0xFFFF, 0xFFFF, "PM8032 Tachyon QE8(0x8032)"},
{0x11F8, 0x8032, 0x117C, 0x003A, "Celerity FC-81EN Fibre Channel Adapter(0x117C-0x003A)"},
{0x11F8, 0x8032, 0x117C, 0x003B, "Celerity FC-82EN Fibre Channel Adapter(0x117C-0x003B)"},
{0x11F8, 0x8032, 0x117C, 0x003C, "Celerity FC-84EN Fibre Channel Adapter(0x117C-0x003C)"},
{0x11F8, 0x8032, 0x117C, 0x403B, "ThunderLink FC 1082 Fibre Channel Adapter(0x117C-0x403B)"},
{0x11F8, 0x8053, 0xFFFF, 0xFFFF, "PM8053 SXP 12G 24-port SAS/SATA expander(0x8053)"},
{0x11F8, 0x8054, 0xFFFF, 0xFFFF, "PM8054 SXP 12G 36-port SAS/SATA expander(0x8054)"},
{0x11F8, 0x8055, 0xFFFF, 0xFFFF, "PM8055 SXP 12G 48-port SAS/SATA expander(0x8055)"},
{0x11F8, 0x8056, 0xFFFF, 0xFFFF, "PM8056 SXP 12G 68-port SAS/SATA expander(0x8056)"},
{0x11F8, 0x8060, 0xFFFF, 0xFFFF, "PM8060 SRCv 12G eight-port SAS/SATA RoC(0x8060)"},
{0x11F8, 0x8063, 0xFFFF, 0xFFFF, "PM8063 SRCv 12G 16-port SAS/SATA RoC(0x8063)"},
{0x11F8, 0x8070, 0xFFFF, 0xFFFF, "PM8070 Tachyon SPCv 12G eight-port SAS/SATA controller(0x8070)"},
{0x11F8, 0x8071, 0xFFFF, 0xFFFF, "PM8071 Tachyon SPCve 12G eight-port SAS/SATA controller(0x8071)"},
{0x11F8, 0x8072, 0xFFFF, 0xFFFF, "PM8072 Tachyon SPCv 12G 16-port SAS/SATA controller(0x8072)"},
{0x11F8, 0x8073, 0xFFFF, 0xFFFF, "PM8073 Tachyon SPCve 12G 16-port SAS/SATA controller(0x8073)"},
{0x11F8, 0x8531, 0xFFFF, 0xFFFF, "PM8531 PFX 24xG3 PCIe Fanout Switch(0x8531)"},
{0x11F8, 0x8532, 0xFFFF, 0xFFFF, "PM8532 PFX 32xG3 PCIe Fanout Switch(0x8532)"},
{0x11F8, 0x8533, 0xFFFF, 0xFFFF, "PM8533 PFX 48xG3 PCIe Fanout Switch(0x8533)"},
{0x11F8, 0x8534, 0xFFFF, 0xFFFF, "PM8534 PFX 64xG3 PCIe Fanout Switch(0x8534)"},
{0x11F8, 0x8535, 0xFFFF, 0xFFFF, "PM8535 PFX 80xG3 PCIe Fanout Switch(0x8535)"},
{0x11F8, 0x8536, 0xFFFF, 0xFFFF, "PM8536 PFX 96xG3 PCIe Fanout Switch(0x8536)"},
{0x11F8, 0x8536, 0x1BD4, 0x0081, "PM8536 PFX 96xG3 PCIe Fanout Switch(0x1BD4-0x0081)"},
{0x11F8, 0x8546, 0xFFFF, 0xFFFF, "PM8546 B-FEIP PSX 96xG3 PCIe Storage Switch(0x8546)"},
{0x11F8, 0x8562, 0xFFFF, 0xFFFF, "PM8562 Switchtec PFX-L 32xG3 Fanout-Lite PCIe Gen3 Switch(0x8562)"},
}; /* pci_vid_11F8[] */

static pci_id_t const pci_vid_11F9[] = {
{0x11F9, 0xFFFF, 0xFFFF, 0xFFFF, "I-Cube Inc(0x11F9)"},
}; /* pci_vid_11F9[] */

static pci_id_t const pci_vid_11FA[] = {
{0x11FA, 0xFFFF, 0xFFFF, 0xFFFF, "Kasan Electronics Company, Ltd.(0x11FA)"},
}; /* pci_vid_11FA[] */

static pci_id_t const pci_vid_11FB[] = {
{0x11FB, 0xFFFF, 0xFFFF, 0xFFFF, "Datel Inc(0x11FB)"},
}; /* pci_vid_11FB[] */

static pci_id_t const pci_vid_11FC[] = {
{0x11FC, 0xFFFF, 0xFFFF, 0xFFFF, "Silicon Magic(0x11FC)"},
}; /* pci_vid_11FC[] */

static pci_id_t const pci_vid_11FD[] = {
{0x11FD, 0xFFFF, 0xFFFF, 0xFFFF, "High Street Consultants(0x11FD)"},
}; /* pci_vid_11FD[] */

static pci_id_t const pci_vid_11FE[] = {
{0x11FE, 0xFFFF, 0xFFFF, 0xFFFF, "Pepperl+Fuchs(0x11FE)"},
{0x11FE, 0x0001, 0xFFFF, 0xFFFF, "RocketPort PCI 32-port w/external I/F(0x0001)"},
{0x11FE, 0x0002, 0xFFFF, 0xFFFF, "RocketPort PCI 8-port w/external I/F(0x0002)"},
{0x11FE, 0x0003, 0xFFFF, 0xFFFF, "RocketPort PCI 16-port w/external I/F(0x0003)"},
{0x11FE, 0x0004, 0xFFFF, 0xFFFF, "RocketPort PCI 4-port w/Quad Cable(0x0004)"},
{0x11FE, 0x0005, 0xFFFF, 0xFFFF, "RocketPort PCI 8-port w/Octa Cable(0x0005)"},
{0x11FE, 0x0006, 0xFFFF, 0xFFFF, "RocketPort PCI 8-port w/RJ11 connectors(0x0006)"},
{0x11FE, 0x0007, 0xFFFF, 0xFFFF, "RocketPort PCI 4-port w/RJ45 connectors(0x0007)"},
{0x11FE, 0x0008, 0xFFFF, 0xFFFF, "RocketPort PCI 8-port w/DB78 SNI connector (Siemens)(0x0008)"},
{0x11FE, 0x0009, 0xFFFF, 0xFFFF, "RocketPort PCI 16-port w/DB78 SNI connector (Siemens)(0x0009)"},
{0x11FE, 0x000A, 0xFFFF, 0xFFFF, "RocketPort PCI Plus 4-port w/Quad Cable(0x000A)"},
{0x11FE, 0x000B, 0xFFFF, 0xFFFF, "RocketPort PCI Plus 8-port w/Octa Cable(0x000B)"},
{0x11FE, 0x000C, 0xFFFF, 0xFFFF, "RocketModem II 6-port(0x000C)"},
{0x11FE, 0x000D, 0xFFFF, 0xFFFF, "RocketModem 4-port(0x000D)"},
{0x11FE, 0x000E, 0xFFFF, 0xFFFF, "RocketPort PCI Plus 2-port RS-232 w/DB9 connectors(0x000E)"},
{0x11FE, 0x000F, 0xFFFF, 0xFFFF, "RocketPort PCI Plus 2-port SMPTE w/DB9 connectors(0x000F)"},
{0x11FE, 0x0040, 0xFFFF, 0xFFFF, "RocketPort INFINITY 8-port w/Octa Cable RJ45(0x0040)"},
{0x11FE, 0x0041, 0xFFFF, 0xFFFF, "RocketPort INFINITY 32-port w/external I/F(0x0041)"},
{0x11FE, 0x0042, 0xFFFF, 0xFFFF, "RocketPort INFINITY 8-port w/external I/F(0x0042)"},
{0x11FE, 0x0043, 0xFFFF, 0xFFFF, "RocketPort INFINITY 16-port w/external I/F(0x0043)"},
{0x11FE, 0x0044, 0xFFFF, 0xFFFF, "RocketPort INFINITY 4-port w/Quad Cable DB(0x0044)"},
{0x11FE, 0x0045, 0xFFFF, 0xFFFF, "RocketPort INFINITY 8-port w/Octa Cable DB(0x0045)"},
{0x11FE, 0x0046, 0xFFFF, 0xFFFF, "RocketPort INFINITY 4-port w/external I/F(0x0046)"},
{0x11FE, 0x0047, 0xFFFF, 0xFFFF, "RocketPort INFINITY 4J (4-port) w/RJ45 connectors(0x0047)"},
{0x11FE, 0x0048, 0xFFFF, 0xFFFF, "RocketPort INFINITY 4J (4-port) w/RJ45 connectors(0x0048)"},
{0x11FE, 0x004A, 0xFFFF, 0xFFFF, "RocketPort INFINITY Plus 4-port(0x004A)"},
{0x11FE, 0x004B, 0xFFFF, 0xFFFF, "RocketPort INFINITY Plus 8-port(0x004B)"},
{0x11FE, 0x004C, 0xFFFF, 0xFFFF, "RocketModem INFINITY III 8-port(0x004C)"},
{0x11FE, 0x004D, 0xFFFF, 0xFFFF, "RocketModem INFINITY III 4-port(0x004D)"},
{0x11FE, 0x004E, 0xFFFF, 0xFFFF, "RocketPort INFINITY Plus 2-port(0x004E)"},
{0x11FE, 0x004F, 0xFFFF, 0xFFFF, "RocketPort INFINITY 2-port SMPTE w/DB9 connectors(0x004F)"},
{0x11FE, 0x0050, 0xFFFF, 0xFFFF, "RocketPort INFINITY Plus 4-port RJ45(0x0050)"},
{0x11FE, 0x0051, 0xFFFF, 0xFFFF, "RocketPort INFINITY Plus 8-port RJ11(0x0051)"},
{0x11FE, 0x0052, 0xFFFF, 0xFFFF, "RocketPort INFINITY 8-port SMPTE w/DB9 Connectors(0x0052)"},
{0x11FE, 0x0060, 0xFFFF, 0xFFFF, "RocketPort EXPRESS 8-port w/Octa Cable(0x0060)"},
{0x11FE, 0x0061, 0xFFFF, 0xFFFF, "RocketPort EXPRESS 32-port w/external I/F(0x0061)"},
{0x11FE, 0x0062, 0xFFFF, 0xFFFF, "RocketPort EXPRESS 8-Port w/external I/F(0x0062)"},
{0x11FE, 0x0063, 0xFFFF, 0xFFFF, "RocketPort EXPRESS 16-port w/external I/F(0x0063)"},
{0x11FE, 0x0064, 0xFFFF, 0xFFFF, "RocketPort EXPRESS 4-port w/Quad Cable(0x0064)"},
{0x11FE, 0x0065, 0xFFFF, 0xFFFF, "RocketPort EXPRESS 8-port w/Octa Cable(0x0065)"},
{0x11FE, 0x0066, 0xFFFF, 0xFFFF, "RocketPort EXPRESS 4-port w/external I/F(0x0066)"},
{0x11FE, 0x0067, 0xFFFF, 0xFFFF, "RocketPort EXPRESS 4J (4-port) w/RJ45 connectors(0x0067)"},
{0x11FE, 0x0068, 0xFFFF, 0xFFFF, "RocketPort EXPRESS 8J (8-port) w/RJ11 connectors(0x0068)"},
{0x11FE, 0x006F, 0xFFFF, 0xFFFF, "RocketPort EXPRESS SMPTE 2-port(0x006F)"},
{0x11FE, 0x0072, 0xFFFF, 0xFFFF, "RocketPort EXPRESS SMPTE 8-port w/external I/F(0x0072)"},
{0x11FE, 0x0801, 0xFFFF, 0xFFFF, "RocketPort uPCI 32-port w/external I/F(0x0801)"},
{0x11FE, 0x0802, 0xFFFF, 0xFFFF, "RocketPort uPCI 8-port w/external I/F(0x0802)"},
{0x11FE, 0x0803, 0xFFFF, 0xFFFF, "RocketPort uPCI 16-port w/external I/F(0x0803)"},
{0x11FE, 0x0805, 0xFFFF, 0xFFFF, "RocketPort uPCI 8-port w/Octa Cable(0x0805)"},
{0x11FE, 0x080B, 0xFFFF, 0xFFFF, "RocketPort Plus uPCI 8-port w/Octa Cable(0x080B)"},
{0x11FE, 0x080C, 0xFFFF, 0xFFFF, "RocketModem III 8-port(0x080C)"},
{0x11FE, 0x080D, 0xFFFF, 0xFFFF, "RocketModem III 4-port(0x080D)"},
{0x11FE, 0x080E, 0xFFFF, 0xFFFF, "RocketPort uPCI 2-port RS232 w/DB9 connectors(0x080E)"},
{0x11FE, 0x080F, 0xFFFF, 0xFFFF, "RocketPort uPCI SMPTE 2-port(0x080F)"},
{0x11FE, 0x0810, 0xFFFF, 0xFFFF, "RocketPort Plus uPCI 4J (4-port) w/RJ45 connectors(0x0810)"},
{0x11FE, 0x0811, 0xFFFF, 0xFFFF, "RocketPort Plus uPCI 8J (8-port) w/RJ11 connectors(0x0811)"},
{0x11FE, 0x0812, 0xFFFF, 0xFFFF, "RocketPort Plus uPCI 422 8-port(0x0812)"},
{0x11FE, 0x0813, 0xFFFF, 0xFFFF, "RocketModem IV uPCI 8-port(0x0813)"},
{0x11FE, 0x0814, 0xFFFF, 0xFFFF, "RocketModem IV uPCI 4-port(0x0814)"},
{0x11FE, 0x0903, 0xFFFF, 0xFFFF, "RocketPort Compact PCI 16 port w/external I/F(0x0903)"},
{0x11FE, 0x8015, 0xFFFF, 0xFFFF, "RocketPort 550 4-port(0x8015)"},
{0x11FE, 0x8805, 0xFFFF, 0xFFFF, "RocketPort uPCI 4-port w/Quad Cable(0x8805)"},
{0x11FE, 0x880B, 0xFFFF, 0xFFFF, "RocketPort Plus uPCI 4-port w/Quad Cable(0x880B)"},
{0x11FE, 0x8812, 0xFFFF, 0xFFFF, "RocketPort Plus uPCI 4-port RS422 w/Quad Cable(0x8812)"},
}; /* pci_vid_11FE[] */

static pci_id_t const pci_vid_11FF[] = {
{0x11FF, 0xFFFF, 0xFFFF, 0xFFFF, "Scion Corporation(0x11FF)"},
{0x11FF, 0x0003, 0xFFFF, 0xFFFF, "AG-5(0x0003)"},
}; /* pci_vid_11FF[] */

static pci_id_t const pci_vid_1200[] = {
{0x1200, 0xFFFF, 0xFFFF, 0xFFFF, "CSS Corporation(0x1200)"},
}; /* pci_vid_1200[] */

static pci_id_t const pci_vid_1201[] = {
{0x1201, 0xFFFF, 0xFFFF, 0xFFFF, "Vista Controls Corp(0x1201)"},
}; /* pci_vid_1201[] */

static pci_id_t const pci_vid_1202[] = {
{0x1202, 0xFFFF, 0xFFFF, 0xFFFF, "Network General Corp.(0x1202)"},
{0x1202, 0x4300, 0xFFFF, 0xFFFF, "Gigabit Ethernet Adapter(0x4300)"},
{0x1202, 0x4300, 0x1202, 0x9841, "SK-9841 LX(0x1202-0x9841)"},
{0x1202, 0x4300, 0x1202, 0x9842, "SK-9841 LX dual link(0x1202-0x9842)"},
{0x1202, 0x4300, 0x1202, 0x9843, "SK-9843 SX(0x1202-0x9843)"},
{0x1202, 0x4300, 0x1202, 0x9844, "SK-9843 SX dual link(0x1202-0x9844)"},
}; /* pci_vid_1202[] */

static pci_id_t const pci_vid_1203[] = {
{0x1203, 0xFFFF, 0xFFFF, 0xFFFF, "Bayer Corporation, Agfa Division(0x1203)"},
}; /* pci_vid_1203[] */

static pci_id_t const pci_vid_1204[] = {
{0x1204, 0xFFFF, 0xFFFF, 0xFFFF, "Lattice Semiconductor Corporation(0x1204)"},
{0x1204, 0x1965, 0xFFFF, 0xFFFF, "SB6501 802.11ad Wireless Network Adapter(0x1965)"},
}; /* pci_vid_1204[] */

static pci_id_t const pci_vid_1205[] = {
{0x1205, 0xFFFF, 0xFFFF, 0xFFFF, "Array Corporation(0x1205)"},
}; /* pci_vid_1205[] */

static pci_id_t const pci_vid_1206[] = {
{0x1206, 0xFFFF, 0xFFFF, 0xFFFF, "Amdahl Corporation(0x1206)"},
}; /* pci_vid_1206[] */

static pci_id_t const pci_vid_1208[] = {
{0x1208, 0xFFFF, 0xFFFF, 0xFFFF, "Parsytec GmbH(0x1208)"},
{0x1208, 0x4853, 0xFFFF, 0xFFFF, "HS-Link Device(0x4853)"},
}; /* pci_vid_1208[] */

static pci_id_t const pci_vid_1209[] = {
{0x1209, 0xFFFF, 0xFFFF, 0xFFFF, "SCI Systems Inc(0x1209)"},
}; /* pci_vid_1209[] */

static pci_id_t const pci_vid_120A[] = {
{0x120A, 0xFFFF, 0xFFFF, 0xFFFF, "Synaptel(0x120A)"},
}; /* pci_vid_120A[] */

static pci_id_t const pci_vid_120B[] = {
{0x120B, 0xFFFF, 0xFFFF, 0xFFFF, "Adaptive Solutions(0x120B)"},
}; /* pci_vid_120B[] */

static pci_id_t const pci_vid_120C[] = {
{0x120C, 0xFFFF, 0xFFFF, 0xFFFF, "Technical Corp.(0x120C)"},
}; /* pci_vid_120C[] */

static pci_id_t const pci_vid_120D[] = {
{0x120D, 0xFFFF, 0xFFFF, 0xFFFF, "Compression Labs, Inc.(0x120D)"},
}; /* pci_vid_120D[] */

static pci_id_t const pci_vid_120E[] = {
{0x120E, 0xFFFF, 0xFFFF, 0xFFFF, "Cyclades Corporation(0x120E)"},
{0x120E, 0x0100, 0xFFFF, 0xFFFF, "Cyclom-Y below first megabyte(0x0100)"},
{0x120E, 0x0101, 0xFFFF, 0xFFFF, "Cyclom-Y above first megabyte(0x0101)"},
{0x120E, 0x0102, 0xFFFF, 0xFFFF, "Cyclom-4Y below first megabyte(0x0102)"},
{0x120E, 0x0103, 0xFFFF, 0xFFFF, "Cyclom-4Y above first megabyte(0x0103)"},
{0x120E, 0x0104, 0xFFFF, 0xFFFF, "Cyclom-8Y below first megabyte(0x0104)"},
{0x120E, 0x0105, 0xFFFF, 0xFFFF, "Cyclom-8Y above first megabyte(0x0105)"},
{0x120E, 0x0200, 0xFFFF, 0xFFFF, "Cyclades-Z below first megabyte(0x0200)"},
{0x120E, 0x0201, 0xFFFF, 0xFFFF, "Cyclades-Z above first megabyte(0x0201)"},
{0x120E, 0x0300, 0xFFFF, 0xFFFF, "PC300/RSV or /X21 (2 ports)(0x0300)"},
{0x120E, 0x0301, 0xFFFF, 0xFFFF, "PC300/RSV or /X21 (1 port)(0x0301)"},
{0x120E, 0x0310, 0xFFFF, 0xFFFF, "PC300/TE (2 ports)(0x0310)"},
{0x120E, 0x0311, 0xFFFF, 0xFFFF, "PC300/TE (1 port)(0x0311)"},
{0x120E, 0x0320, 0xFFFF, 0xFFFF, "PC300/TE-M (2 ports)(0x0320)"},
{0x120E, 0x0321, 0xFFFF, 0xFFFF, "PC300/TE-M (1 port)(0x0321)"},
{0x120E, 0x0400, 0xFFFF, 0xFFFF, "PC400(0x0400)"},
}; /* pci_vid_120E[] */

static pci_id_t const pci_vid_120F[] = {
{0x120F, 0xFFFF, 0xFFFF, 0xFFFF, "Essential Communications(0x120F)"},
{0x120F, 0x0001, 0xFFFF, 0xFFFF, "Roadrunner serial HIPPI(0x0001)"},
}; /* pci_vid_120F[] */

static pci_id_t const pci_vid_1210[] = {
{0x1210, 0xFFFF, 0xFFFF, 0xFFFF, "Hyperparallel Technologies(0x1210)"},
}; /* pci_vid_1210[] */

static pci_id_t const pci_vid_1211[] = {
{0x1211, 0xFFFF, 0xFFFF, 0xFFFF, "Braintech Inc(0x1211)"},
}; /* pci_vid_1211[] */

static pci_id_t const pci_vid_1213[] = {
{0x1213, 0xFFFF, 0xFFFF, 0xFFFF, "Applied Intelligent Systems, Inc.(0x1213)"},
}; /* pci_vid_1213[] */

static pci_id_t const pci_vid_1214[] = {
{0x1214, 0xFFFF, 0xFFFF, 0xFFFF, "Performance Technologies, Inc.(0x1214)"},
}; /* pci_vid_1214[] */

static pci_id_t const pci_vid_1215[] = {
{0x1215, 0xFFFF, 0xFFFF, 0xFFFF, "Interware Co., Ltd(0x1215)"},
}; /* pci_vid_1215[] */

static pci_id_t const pci_vid_1216[] = {
{0x1216, 0xFFFF, 0xFFFF, 0xFFFF, "Purup Prepress A/S(0x1216)"},
}; /* pci_vid_1216[] */

static pci_id_t const pci_vid_1217[] = {
{0x1217, 0xFFFF, 0xFFFF, 0xFFFF, "O2 Micro, Inc.(0x1217)"},
{0x1217, 0x00F7, 0xFFFF, 0xFFFF, "Firewire (IEEE 1394)(0x00F7)"},
{0x1217, 0x00F7, 0x1071, 0x8209, "Medion MIM 2240 Notebook PC [MD98100](0x1071-0x8209)"},
{0x1217, 0x00F7, 0x1179, 0xFF50, "Satellite P305D-S8995E(0x1179-0xFF50)"},
{0x1217, 0x10F7, 0xFFFF, 0xFFFF, "1394 OHCI Compliant Host Controller(0x10F7)"},
{0x1217, 0x11F7, 0xFFFF, 0xFFFF, "OZ600 1394a-2000 Controller(0x11F7)"},
{0x1217, 0x11F7, 0x1028, 0x04A3, "Precision M4600(0x1028-0x04A3)"},
{0x1217, 0x13F7, 0xFFFF, 0xFFFF, "1394 OHCI Compliant Host Controller(0x13F7)"},
{0x1217, 0x6729, 0xFFFF, 0xFFFF, "OZ6729(0x6729)"},
{0x1217, 0x673A, 0xFFFF, 0xFFFF, "OZ6730(0x673A)"},
{0x1217, 0x6832, 0xFFFF, 0xFFFF, "OZ6832/6833 CardBus Controller [Saturn](0x6832)"},
{0x1217, 0x6836, 0xFFFF, 0xFFFF, "OZ6836/6860 CardBus Controller [Mercury](0x6836)"},
{0x1217, 0x6872, 0xFFFF, 0xFFFF, "OZ6812 CardBus Controller [Challenger](0x6872)"},
{0x1217, 0x6925, 0xFFFF, 0xFFFF, "OZ6922 CardBus Controller(0x6925)"},
{0x1217, 0x6933, 0xFFFF, 0xFFFF, "OZ6933/711E1 CardBus/SmartCardBus Controller(0x6933)"},
{0x1217, 0x6933, 0x1025, 0x1016, "Travelmate 612 TX(0x1025-0x1016)"},
{0x1217, 0x6972, 0xFFFF, 0xFFFF, "OZ601/6912/711E0 CardBus/SmartCardBus Controller(0x6972)"},
{0x1217, 0x6972, 0x1014, 0x020C, "ThinkPad R30(0x1014-0x020C)"},
{0x1217, 0x6972, 0x1028, 0x0152, "Latitude D500(0x1028-0x0152)"},
{0x1217, 0x6972, 0x1179, 0x0001, "Magnia Z310(0x1179-0x0001)"},
{0x1217, 0x7110, 0xFFFF, 0xFFFF, "OZ711Mx 4-in-1 MemoryCardBus Accelerator(0x7110)"},
{0x1217, 0x7110, 0x103C, 0x088C, "NC8000 laptop(0x103C-0x088C)"},
{0x1217, 0x7110, 0x103C, 0x0890, "NC6000 laptop(0x103C-0x0890)"},
{0x1217, 0x7110, 0x1734, 0x106C, "Amilo A1645(0x1734-0x106C)"},
{0x1217, 0x7112, 0xFFFF, 0xFFFF, "OZ711EC1/M1 SmartCardBus/MemoryCardBus Controller(0x7112)"},
{0x1217, 0x7113, 0xFFFF, 0xFFFF, "OZ711EC1 SmartCardBus Controller(0x7113)"},
{0x1217, 0x7113, 0x1025, 0x0035, "TravelMate 660(0x1025-0x0035)"},
{0x1217, 0x7114, 0xFFFF, 0xFFFF, "OZ711M1/MC1 4-in-1 MemoryCardBus Controller(0x7114)"},
{0x1217, 0x7120, 0xFFFF, 0xFFFF, "Integrated MMC/SD Controller(0x7120)"},
{0x1217, 0x7120, 0x1071, 0x8209, "Medion MIM 2240 Notebook PC [MD98100](0x1071-0x8209)"},
{0x1217, 0x7120, 0x1179, 0xFF50, "Satellite P305D-S8995E(0x1179-0xFF50)"},
{0x1217, 0x7130, 0xFFFF, 0xFFFF, "Integrated MS/xD Controller(0x7130)"},
{0x1217, 0x7130, 0x1071, 0x8209, "Medion MIM 2240 Notebook PC [MD98100](0x1071-0x8209)"},
{0x1217, 0x7130, 0x1179, 0xFF50, "Satellite P305D-S8995E(0x1179-0xFF50)"},
{0x1217, 0x7134, 0xFFFF, 0xFFFF, "OZ711MP1/MS1 MemoryCardBus Controller(0x7134)"},
{0x1217, 0x7135, 0xFFFF, 0xFFFF, "Cardbus bridge(0x7135)"},
{0x1217, 0x7136, 0xFFFF, 0xFFFF, "OZ711SP1 Memory CardBus Controller(0x7136)"},
{0x1217, 0x71E2, 0xFFFF, 0xFFFF, "OZ711E2 SmartCardBus Controller(0x71E2)"},
{0x1217, 0x7212, 0xFFFF, 0xFFFF, "OZ711M2 4-in-1 MemoryCardBus Controller(0x7212)"},
{0x1217, 0x7213, 0xFFFF, 0xFFFF, "OZ6933E CardBus Controller(0x7213)"},
{0x1217, 0x7223, 0xFFFF, 0xFFFF, "OZ711M3/MC3 4-in-1 MemoryCardBus Controller(0x7223)"},
{0x1217, 0x7223, 0x103C, 0x088C, "NC8000 laptop(0x103C-0x088C)"},
{0x1217, 0x7223, 0x103C, 0x0890, "NC6000 laptop(0x103C-0x0890)"},
{0x1217, 0x7223, 0x10CF, 0x11C4, "Lifebook P5020D Laptop(0x10CF-0x11C4)"},
{0x1217, 0x7233, 0xFFFF, 0xFFFF, "OZ711MP3/MS3 4-in-1 MemoryCardBus Controller(0x7233)"},
{0x1217, 0x8120, 0xFFFF, 0xFFFF, "Integrated MMC/SD Controller(0x8120)"},
{0x1217, 0x8130, 0xFFFF, 0xFFFF, "Integrated MS/MSPRO/xD Controller(0x8130)"},
{0x1217, 0x8220, 0xFFFF, 0xFFFF, "OZ600FJ1/OZ900FJ1 SD/MMC Card Reader Controller(0x8220)"},
{0x1217, 0x8221, 0xFFFF, 0xFFFF, "OZ600FJ0/OZ900FJ0/OZ600FJS SD/MMC Card Reader Controller(0x8221)"},
{0x1217, 0x8320, 0xFFFF, 0xFFFF, "OZ600RJ1/OZ900RJ1 SD/MMC Card Reader Controller(0x8320)"},
{0x1217, 0x8320, 0x1028, 0x04A3, "Precision M4600(0x1028-0x04A3)"},
{0x1217, 0x8321, 0xFFFF, 0xFFFF, "OZ600RJ0/OZ900RJ0/OZ600RJS SD/MMC Card Reader Controller(0x8321)"},
{0x1217, 0x8330, 0xFFFF, 0xFFFF, "OZ600 MS/xD Controller(0x8330)"},
{0x1217, 0x8330, 0x1028, 0x04A3, "Precision M4600(0x1028-0x04A3)"},
{0x1217, 0x8331, 0xFFFF, 0xFFFF, "O2 Flash Memory Card(0x8331)"},
{0x1217, 0x8520, 0xFFFF, 0xFFFF, "SD/MMC Card Reader Controller(0x8520)"},
{0x1217, 0x8621, 0xFFFF, 0xFFFF, "SD/MMC Card Reader Controller(0x8621)"},
{0x1217, 0x8621, 0x17AA, 0x5068, "Thinkpad E480/E580(0x17AA-0x5068)"},
{0x1217, 0x8760, 0xFFFF, 0xFFFF, "FORESEE E2M2 NVMe SSD(0x8760)"},
}; /* pci_vid_1217[] */

static pci_id_t const pci_vid_1218[] = {
{0x1218, 0xFFFF, 0xFFFF, 0xFFFF, "Hybricon Corp.(0x1218)"},
}; /* pci_vid_1218[] */

static pci_id_t const pci_vid_1219[] = {
{0x1219, 0xFFFF, 0xFFFF, 0xFFFF, "First Virtual Corporation(0x1219)"},
}; /* pci_vid_1219[] */

static pci_id_t const pci_vid_121A[] = {
{0x121A, 0xFFFF, 0xFFFF, 0xFFFF, "3Dfx Interactive, Inc.(0x121A)"},
{0x121A, 0x0001, 0xFFFF, 0xFFFF, "Voodoo(0x0001)"},
{0x121A, 0x0002, 0xFFFF, 0xFFFF, "Voodoo 2(0x0002)"},
{0x121A, 0x0003, 0xFFFF, 0xFFFF, "Voodoo Banshee(0x0003)"},
{0x121A, 0x0003, 0x1092, 0x0003, "Monster Fusion(0x1092-0x0003)"},
{0x121A, 0x0003, 0x1092, 0x4000, "Monster Fusion(0x1092-0x4000)"},
{0x121A, 0x0003, 0x1092, 0x4002, "Monster Fusion(0x1092-0x4002)"},
{0x121A, 0x0003, 0x1092, 0x4801, "Monster Fusion AGP(0x1092-0x4801)"},
{0x121A, 0x0003, 0x1092, 0x4803, "Monster Fusion AGP(0x1092-0x4803)"},
{0x121A, 0x0003, 0x1092, 0x8030, "Monster Fusion(0x1092-0x8030)"},
{0x121A, 0x0003, 0x1092, 0x8035, "Monster Fusion AGP(0x1092-0x8035)"},
{0x121A, 0x0003, 0x10B0, 0x0001, "Dragon 4000(0x10B0-0x0001)"},
{0x121A, 0x0003, 0x1102, 0x1017, "3D Blaster Banshee PCI (CT6760)(0x1102-0x1017)"},
{0x121A, 0x0003, 0x1102, 0x1018, "3D Blaster Banshee VE(0x1102-0x1018)"},
{0x121A, 0x0003, 0x121A, 0x0001, "Voodoo Banshee AGP(0x121A-0x0001)"},
{0x121A, 0x0003, 0x121A, 0x0003, "Voodoo Banshee AGP SGRAM(0x121A-0x0003)"},
{0x121A, 0x0003, 0x121A, 0x0004, "Voodoo Banshee(0x121A-0x0004)"},
{0x121A, 0x0003, 0x139C, 0x0016, "Raven(0x139C-0x0016)"},
{0x121A, 0x0003, 0x139C, 0x0017, "Raven(0x139C-0x0017)"},
{0x121A, 0x0003, 0x14AF, 0x0002, "Maxi Gamer Phoenix(0x14AF-0x0002)"},
{0x121A, 0x0004, 0xFFFF, 0xFFFF, "Voodoo Banshee [Velocity 100](0x0004)"},
{0x121A, 0x0005, 0xFFFF, 0xFFFF, "Voodoo 3(0x0005)"},
{0x121A, 0x0005, 0x121A, 0x0004, "Voodoo3 AGP(0x121A-0x0004)"},
{0x121A, 0x0005, 0x121A, 0x0030, "Voodoo3 AGP(0x121A-0x0030)"},
{0x121A, 0x0005, 0x121A, 0x0031, "Voodoo3 AGP(0x121A-0x0031)"},
{0x121A, 0x0005, 0x121A, 0x0034, "Voodoo3 AGP(0x121A-0x0034)"},
{0x121A, 0x0005, 0x121A, 0x0036, "Voodoo3 2000 PCI(0x121A-0x0036)"},
{0x121A, 0x0005, 0x121A, 0x0037, "Voodoo3 AGP(0x121A-0x0037)"},
{0x121A, 0x0005, 0x121A, 0x0038, "Voodoo3 AGP(0x121A-0x0038)"},
{0x121A, 0x0005, 0x121A, 0x003A, "Voodoo3 AGP(0x121A-0x003A)"},
{0x121A, 0x0005, 0x121A, 0x0044, "Voodoo3(0x121A-0x0044)"},
{0x121A, 0x0005, 0x121A, 0x004B, "Velocity 100(0x121A-0x004B)"},
{0x121A, 0x0005, 0x121A, 0x004C, "Velocity 200(0x121A-0x004C)"},
{0x121A, 0x0005, 0x121A, 0x004D, "Voodoo3 AGP(0x121A-0x004D)"},
{0x121A, 0x0005, 0x121A, 0x004E, "Voodoo3 AGP(0x121A-0x004E)"},
{0x121A, 0x0005, 0x121A, 0x0051, "Voodoo3 AGP(0x121A-0x0051)"},
{0x121A, 0x0005, 0x121A, 0x0052, "Voodoo3 AGP(0x121A-0x0052)"},
{0x121A, 0x0005, 0x121A, 0x0057, "Voodoo3 3000 PCI(0x121A-0x0057)"},
{0x121A, 0x0005, 0x121A, 0x0060, "Voodoo3 3500 TV (NTSC)(0x121A-0x0060)"},
{0x121A, 0x0005, 0x121A, 0x0061, "Voodoo3 3500 TV (PAL)(0x121A-0x0061)"},
{0x121A, 0x0005, 0x121A, 0x0062, "Voodoo3 3500 TV (SECAM)(0x121A-0x0062)"},
{0x121A, 0x0009, 0xFFFF, 0xFFFF, "Voodoo 4 / Voodoo 5(0x0009)"},
{0x121A, 0x0009, 0x121A, 0x0003, "Voodoo5 PCI 5500(0x121A-0x0003)"},
{0x121A, 0x0009, 0x121A, 0x0009, "Voodoo5 AGP 5500/6000(0x121A-0x0009)"},
{0x121A, 0x0057, 0xFFFF, 0xFFFF, "Voodoo 3/3000 [Avenger](0x0057)"},
}; /* pci_vid_121A[] */

static pci_id_t const pci_vid_121B[] = {
{0x121B, 0xFFFF, 0xFFFF, 0xFFFF, "Advanced Telecommunications Modules(0x121B)"},
}; /* pci_vid_121B[] */

static pci_id_t const pci_vid_121C[] = {
{0x121C, 0xFFFF, 0xFFFF, 0xFFFF, "Nippon Texaco., Ltd(0x121C)"},
}; /* pci_vid_121C[] */

static pci_id_t const pci_vid_121D[] = {
{0x121D, 0xFFFF, 0xFFFF, 0xFFFF, "LiPPERT ADLINK Technology GmbH(0x121D)"},
}; /* pci_vid_121D[] */

static pci_id_t const pci_vid_121E[] = {
{0x121E, 0xFFFF, 0xFFFF, 0xFFFF, "CSPI(0x121E)"},
{0x121E, 0x0201, 0xFFFF, 0xFFFF, "Myrinet 2000 Scalable Cluster Interconnect(0x0201)"},
}; /* pci_vid_121E[] */

static pci_id_t const pci_vid_121F[] = {
{0x121F, 0xFFFF, 0xFFFF, 0xFFFF, "Arcus Technology, Inc.(0x121F)"},
}; /* pci_vid_121F[] */

static pci_id_t const pci_vid_1220[] = {
{0x1220, 0xFFFF, 0xFFFF, 0xFFFF, "Ariel Corporation(0x1220)"},
{0x1220, 0x1220, 0xFFFF, 0xFFFF, "AMCC 5933 TMS320C80 DSP/Imaging board(0x1220)"},
}; /* pci_vid_1220[] */

static pci_id_t const pci_vid_1221[] = {
{0x1221, 0xFFFF, 0xFFFF, 0xFFFF, "Contec Co., Ltd(0x1221)"},
{0x1221, 0x9172, 0xFFFF, 0xFFFF, "PO-64L(PCI)H [Isolated Digital Output Board for PCI](0x9172)"},
{0x1221, 0x91A2, 0xFFFF, 0xFFFF, "PO-32L(PCI)H [Isolated Digital Output Board for PCI](0x91A2)"},
{0x1221, 0x91C3, 0xFFFF, 0xFFFF, "DA16-16(LPCI)L [Un-insulated highly precise analog output board for Low Profile PCI](0x91C3)"},
{0x1221, 0xB152, 0xFFFF, 0xFFFF, "DIO-96D2-LPCI(0xB152)"},
{0x1221, 0xC103, 0xFFFF, 0xFFFF, "ADA16-32/2(PCI)F [High-Speed Analog I/O Board for PCI](0xC103)"},
}; /* pci_vid_1221[] */

static pci_id_t const pci_vid_1222[] = {
{0x1222, 0xFFFF, 0xFFFF, 0xFFFF, "Ancor Communications, Inc.(0x1222)"},
}; /* pci_vid_1222[] */

static pci_id_t const pci_vid_1223[] = {
{0x1223, 0xFFFF, 0xFFFF, 0xFFFF, "Artesyn Communication Products(0x1223)"},
{0x1223, 0x0003, 0xFFFF, 0xFFFF, "PM/Link(0x0003)"},
{0x1223, 0x0004, 0xFFFF, 0xFFFF, "PM/T1(0x0004)"},
{0x1223, 0x0005, 0xFFFF, 0xFFFF, "PM/E1(0x0005)"},
{0x1223, 0x0008, 0xFFFF, 0xFFFF, "PM/SLS(0x0008)"},
{0x1223, 0x0009, 0xFFFF, 0xFFFF, "BajaSpan Resource Target(0x0009)"},
{0x1223, 0x000A, 0xFFFF, 0xFFFF, "BajaSpan Section 0(0x000A)"},
{0x1223, 0x000B, 0xFFFF, 0xFFFF, "BajaSpan Section 1(0x000B)"},
{0x1223, 0x000C, 0xFFFF, 0xFFFF, "BajaSpan Section 2(0x000C)"},
{0x1223, 0x000D, 0xFFFF, 0xFFFF, "BajaSpan Section 3(0x000D)"},
{0x1223, 0x000E, 0xFFFF, 0xFFFF, "PM/PPC(0x000E)"},
}; /* pci_vid_1223[] */

static pci_id_t const pci_vid_1224[] = {
{0x1224, 0xFFFF, 0xFFFF, 0xFFFF, "Interactive Images(0x1224)"},
}; /* pci_vid_1224[] */

static pci_id_t const pci_vid_1225[] = {
{0x1225, 0xFFFF, 0xFFFF, 0xFFFF, "Power I/O, Inc.(0x1225)"},
}; /* pci_vid_1225[] */

static pci_id_t const pci_vid_1227[] = {
{0x1227, 0xFFFF, 0xFFFF, 0xFFFF, "EIZO Rugged Solutions(0x1227)"},
{0x1227, 0x0006, 0xFFFF, 0xFFFF, "Raptor GFX 8P(0x0006)"},
{0x1227, 0x0023, 0xFFFF, 0xFFFF, "Raptor GFX [1100T](0x0023)"},
{0x1227, 0x0045, 0xFFFF, 0xFFFF, "Raptor 4000-L [Linux version](0x0045)"},
{0x1227, 0x004A, 0xFFFF, 0xFFFF, "Raptor 4000-LR-L [Linux version](0x004A)"},
}; /* pci_vid_1227[] */

static pci_id_t const pci_vid_1228[] = {
{0x1228, 0xFFFF, 0xFFFF, 0xFFFF, "Norsk Elektro Optikk A/S(0x1228)"},
}; /* pci_vid_1228[] */

static pci_id_t const pci_vid_1229[] = {
{0x1229, 0xFFFF, 0xFFFF, 0xFFFF, "Data Kinesis Inc.(0x1229)"},
}; /* pci_vid_1229[] */

static pci_id_t const pci_vid_122A[] = {
{0x122A, 0xFFFF, 0xFFFF, 0xFFFF, "Integrated Telecom(0x122A)"},
}; /* pci_vid_122A[] */

static pci_id_t const pci_vid_122B[] = {
{0x122B, 0xFFFF, 0xFFFF, 0xFFFF, "LG Industrial Systems Co., Ltd(0x122B)"},
}; /* pci_vid_122B[] */

static pci_id_t const pci_vid_122C[] = {
{0x122C, 0xFFFF, 0xFFFF, 0xFFFF, "Sican GmbH(0x122C)"},
}; /* pci_vid_122C[] */

static pci_id_t const pci_vid_122D[] = {
{0x122D, 0xFFFF, 0xFFFF, 0xFFFF, "Aztech System Ltd(0x122D)"},
{0x122D, 0x1206, 0xFFFF, 0xFFFF, "368DSP(0x1206)"},
{0x122D, 0x1400, 0xFFFF, 0xFFFF, "Trident PCI288-Q3DII (NX)(0x1400)"},
{0x122D, 0x50DC, 0xFFFF, 0xFFFF, "3328 Audio(0x50DC)"},
{0x122D, 0x50DC, 0x122D, 0x0001, "3328 Audio(0x122D-0x0001)"},
{0x122D, 0x80DA, 0xFFFF, 0xFFFF, "3328 Audio(0x80DA)"},
{0x122D, 0x80DA, 0x122D, 0x0001, "3328 Audio(0x122D-0x0001)"},
}; /* pci_vid_122D[] */

static pci_id_t const pci_vid_122E[] = {
{0x122E, 0xFFFF, 0xFFFF, 0xFFFF, "Xyratex(0x122E)"},
{0x122E, 0x7722, 0xFFFF, 0xFFFF, "Napatech XL1(0x7722)"},
{0x122E, 0x7724, 0xFFFF, 0xFFFF, "Napatech XL2/XA(0x7724)"},
{0x122E, 0x7729, 0xFFFF, 0xFFFF, "Napatech XD(0x7729)"},
}; /* pci_vid_122E[] */

static pci_id_t const pci_vid_122F[] = {
{0x122F, 0xFFFF, 0xFFFF, 0xFFFF, "Andrew Corporation(0x122F)"},
}; /* pci_vid_122F[] */

static pci_id_t const pci_vid_1230[] = {
{0x1230, 0xFFFF, 0xFFFF, 0xFFFF, "Fishcamp Engineering(0x1230)"},
}; /* pci_vid_1230[] */

static pci_id_t const pci_vid_1231[] = {
{0x1231, 0xFFFF, 0xFFFF, 0xFFFF, "Woodward McCoach, Inc.(0x1231)"},
{0x1231, 0x04E1, 0xFFFF, 0xFFFF, "Desktop PCI Telephony 4(0x04E1)"},
{0x1231, 0x05E1, 0xFFFF, 0xFFFF, "Desktop PCI Telephony 5/6(0x05E1)"},
{0x1231, 0x0D00, 0xFFFF, 0xFFFF, "LightParser(0x0D00)"},
{0x1231, 0x0D02, 0xFFFF, 0xFFFF, "LightParser 2(0x0D02)"},
{0x1231, 0x0D13, 0xFFFF, 0xFFFF, "Desktop PCI L1/L3 Telephony(0x0D13)"},
}; /* pci_vid_1231[] */

static pci_id_t const pci_vid_1232[] = {
{0x1232, 0xFFFF, 0xFFFF, 0xFFFF, "GPT Limited(0x1232)"},
}; /* pci_vid_1232[] */

static pci_id_t const pci_vid_1233[] = {
{0x1233, 0xFFFF, 0xFFFF, 0xFFFF, "Bus-Tech, Inc.(0x1233)"},
}; /* pci_vid_1233[] */

static pci_id_t const pci_vid_1235[] = {
{0x1235, 0xFFFF, 0xFFFF, 0xFFFF, "SMART Modular Technologies(0x1235)"},
}; /* pci_vid_1235[] */

static pci_id_t const pci_vid_1236[] = {
{0x1236, 0xFFFF, 0xFFFF, 0xFFFF, "Sigma Designs Corporation(0x1236)"},
{0x1236, 0x0000, 0xFFFF, 0xFFFF, "RealMagic64/GX(0x0000)"},
{0x1236, 0x6401, 0xFFFF, 0xFFFF, "REALmagic 64/GX (SD 6425)(0x6401)"},
}; /* pci_vid_1236[] */

static pci_id_t const pci_vid_1237[] = {
{0x1237, 0xFFFF, 0xFFFF, 0xFFFF, "Alta Technology Corporation(0x1237)"},
}; /* pci_vid_1237[] */

static pci_id_t const pci_vid_1238[] = {
{0x1238, 0xFFFF, 0xFFFF, 0xFFFF, "Adtran(0x1238)"},
}; /* pci_vid_1238[] */

static pci_id_t const pci_vid_1239[] = {
{0x1239, 0xFFFF, 0xFFFF, 0xFFFF, "3DO Company(0x1239)"},
}; /* pci_vid_1239[] */

static pci_id_t const pci_vid_123A[] = {
{0x123A, 0xFFFF, 0xFFFF, 0xFFFF, "Visicom Laboratories, Inc.(0x123A)"},
}; /* pci_vid_123A[] */

static pci_id_t const pci_vid_123B[] = {
{0x123B, 0xFFFF, 0xFFFF, 0xFFFF, "Seeq Technology, Inc.(0x123B)"},
}; /* pci_vid_123B[] */

static pci_id_t const pci_vid_123C[] = {
{0x123C, 0xFFFF, 0xFFFF, 0xFFFF, "Century Systems, Inc.(0x123C)"},
}; /* pci_vid_123C[] */

static pci_id_t const pci_vid_123D[] = {
{0x123D, 0xFFFF, 0xFFFF, 0xFFFF, "Engineering Design Team, Inc.(0x123D)"},
{0x123D, 0x0000, 0xFFFF, 0xFFFF, "EasyConnect 8/32(0x0000)"},
{0x123D, 0x0002, 0xFFFF, 0xFFFF, "EasyConnect 8/64(0x0002)"},
{0x123D, 0x0003, 0xFFFF, 0xFFFF, "EasyIO(0x0003)"},
{0x123D, 0x0047, 0xFFFF, 0xFFFF, "PCIe4 CDa(0x0047)"},
{0x123D, 0x004B, 0xFFFF, 0xFFFF, "PCIe4 CDa 16(0x004B)"},
{0x123D, 0x009D, 0xFFFF, 0xFFFF, "VisionLink F1(0x009D)"},
{0x123D, 0x00A0, 0xFFFF, 0xFFFF, "PCIe8g3 S5 (10G/40G)(0x00A0)"},
{0x123D, 0x00A3, 0xFFFF, 0xFFFF, "VisionLink F4(0x00A3)"},
{0x123D, 0x00A9, 0xFFFF, 0xFFFF, "VisionLink CLS(0x00A9)"},
{0x123D, 0x00AB, 0xFFFF, 0xFFFF, "PCIe8g3 A5 10G(0x00AB)"},
{0x123D, 0x00B5, 0xFFFF, 0xFFFF, "PCIe8 RFx SDR(0x00B5)"},
}; /* pci_vid_123D[] */

static pci_id_t const pci_vid_123E[] = {
{0x123E, 0xFFFF, 0xFFFF, 0xFFFF, "Simutech, Inc.(0x123E)"},
}; /* pci_vid_123E[] */

static pci_id_t const pci_vid_123F[] = {
{0x123F, 0xFFFF, 0xFFFF, 0xFFFF, "LSI Logic(0x123F)"},
{0x123F, 0x00E4, 0xFFFF, 0xFFFF, "MPEG(0x00E4)"},
{0x123F, 0x8120, 0xFFFF, 0xFFFF, "DVxplore Codec(0x8120)"},
{0x123F, 0x8120, 0x10DE, 0x01E1, "NVTV PAL(0x10DE-0x01E1)"},
{0x123F, 0x8120, 0x10DE, 0x01E2, "NVTV NTSC(0x10DE-0x01E2)"},
{0x123F, 0x8120, 0x10DE, 0x01E3, "NVTV PAL(0x10DE-0x01E3)"},
{0x123F, 0x8120, 0x10DE, 0x0248, "NVTV NTSC(0x10DE-0x0248)"},
{0x123F, 0x8120, 0x10DE, 0x0249, "NVTV PAL(0x10DE-0x0249)"},
{0x123F, 0x8120, 0x11BD, 0x0006, "DV500 E4(0x11BD-0x0006)"},
{0x123F, 0x8120, 0x11BD, 0x000A, "DV500 E4(0x11BD-0x000A)"},
{0x123F, 0x8120, 0x11BD, 0x000F, "DV500 E4(0x11BD-0x000F)"},
{0x123F, 0x8120, 0x1809, 0x0016, "Emuzed MAUI-III PCI PVR FM TV(0x1809-0x0016)"},
{0x123F, 0x8888, 0xFFFF, 0xFFFF, "Cinemaster C 3.0 DVD Decoder(0x8888)"},
{0x123F, 0x8888, 0x1002, 0x0001, "Cinemaster C 3.0 DVD Decoder(0x1002-0x0001)"},
{0x123F, 0x8888, 0x1002, 0x0002, "Cinemaster C 3.0 DVD Decoder(0x1002-0x0002)"},
{0x123F, 0x8888, 0x1328, 0x0001, "Cinemaster C 3.0 DVD Decoder(0x1328-0x0001)"},
}; /* pci_vid_123F[] */

static pci_id_t const pci_vid_1240[] = {
{0x1240, 0xFFFF, 0xFFFF, 0xFFFF, "Marathon Technologies Corp.(0x1240)"},
}; /* pci_vid_1240[] */

static pci_id_t const pci_vid_1241[] = {
{0x1241, 0xFFFF, 0xFFFF, 0xFFFF, "DSC Communications(0x1241)"},
}; /* pci_vid_1241[] */

static pci_id_t const pci_vid_1242[] = {
{0x1242, 0xFFFF, 0xFFFF, 0xFFFF, "JNI Corporation(0x1242)"},
{0x1242, 0x1560, 0xFFFF, 0xFFFF, "JNIC-1560 PCI-X Fibre Channel Controller(0x1560)"},
{0x1242, 0x1560, 0x1242, 0x6562, "FCX2-6562 Dual Channel PCI-X Fibre Channel Adapter(0x1242-0x6562)"},
{0x1242, 0x1560, 0x1242, 0x656A, "FCX-6562 PCI-X Fibre Channel Adapter(0x1242-0x656A)"},
{0x1242, 0x4643, 0xFFFF, 0xFFFF, "FCI-1063 Fibre Channel Adapter(0x4643)"},
{0x1242, 0x6562, 0xFFFF, 0xFFFF, "FCX2-6562 Dual Channel PCI-X Fibre Channel Adapter(0x6562)"},
{0x1242, 0x656A, 0xFFFF, 0xFFFF, "FCX-6562 PCI-X Fibre Channel Adapter(0x656A)"},
}; /* pci_vid_1242[] */

static pci_id_t const pci_vid_1243[] = {
{0x1243, 0xFFFF, 0xFFFF, 0xFFFF, "Delphax(0x1243)"},
}; /* pci_vid_1243[] */

static pci_id_t const pci_vid_1244[] = {
{0x1244, 0xFFFF, 0xFFFF, 0xFFFF, "AVM GmbH(0x1244)"},
{0x1244, 0x0700, 0xFFFF, 0xFFFF, "B1 ISDN(0x0700)"},
{0x1244, 0x0800, 0xFFFF, 0xFFFF, "C4 ISDN(0x0800)"},
{0x1244, 0x0A00, 0xFFFF, 0xFFFF, "A1 ISDN [Fritz](0x0A00)"},
{0x1244, 0x0A00, 0x1244, 0x0A00, "FRITZ!Card ISDN Controller(0x1244-0x0A00)"},
{0x1244, 0x0E00, 0xFFFF, 0xFFFF, "Fritz!Card PCI v2.0 ISDN(0x0E00)"},
{0x1244, 0x0E80, 0xFFFF, 0xFFFF, "Fritz!Card PCI v2.1 ISDN(0x0E80)"},
{0x1244, 0x0E80, 0x1244, 0x0E00, "PSB 3100F (AVM KAFKA) [Fritz!Card PCI v2.1](0x1244-0x0E00)"},
{0x1244, 0x1100, 0xFFFF, 0xFFFF, "C2 ISDN(0x1100)"},
{0x1244, 0x1200, 0xFFFF, 0xFFFF, "T1 ISDN(0x1200)"},
{0x1244, 0x2700, 0xFFFF, 0xFFFF, "Fritz!Card DSL SL(0x2700)"},
{0x1244, 0x2900, 0xFFFF, 0xFFFF, "Fritz!Card DSL v2.0(0x2900)"},
}; /* pci_vid_1244[] */

static pci_id_t const pci_vid_1245[] = {
{0x1245, 0xFFFF, 0xFFFF, 0xFFFF, "A.P.D., S.A.(0x1245)"},
}; /* pci_vid_1245[] */

static pci_id_t const pci_vid_1246[] = {
{0x1246, 0xFFFF, 0xFFFF, 0xFFFF, "Dipix Technologies, Inc.(0x1246)"},
}; /* pci_vid_1246[] */

static pci_id_t const pci_vid_1247[] = {
{0x1247, 0xFFFF, 0xFFFF, 0xFFFF, "Xylon Research, Inc.(0x1247)"},
}; /* pci_vid_1247[] */

static pci_id_t const pci_vid_1248[] = {
{0x1248, 0xFFFF, 0xFFFF, 0xFFFF, "Central Data Corporation(0x1248)"},
}; /* pci_vid_1248[] */

static pci_id_t const pci_vid_1249[] = {
{0x1249, 0xFFFF, 0xFFFF, 0xFFFF, "Samsung Electronics Co., Ltd.(0x1249)"},
}; /* pci_vid_1249[] */

static pci_id_t const pci_vid_124A[] = {
{0x124A, 0xFFFF, 0xFFFF, 0xFFFF, "AEG Electrocom GmbH(0x124A)"},
}; /* pci_vid_124A[] */

static pci_id_t const pci_vid_124B[] = {
{0x124B, 0xFFFF, 0xFFFF, 0xFFFF, "SBS/Greenspring Modular I/O(0x124B)"},
{0x124B, 0x0040, 0xFFFF, 0xFFFF, "PCI-40A or cPCI-200 Quad IndustryPack carrier(0x0040)"},
{0x124B, 0x0040, 0x124B, 0x9080, "PCI9080 Bridge(0x124B-0x9080)"},
}; /* pci_vid_124B[] */

static pci_id_t const pci_vid_124C[] = {
{0x124C, 0xFFFF, 0xFFFF, 0xFFFF, "Solitron Technologies, Inc.(0x124C)"},
}; /* pci_vid_124C[] */

static pci_id_t const pci_vid_124D[] = {
{0x124D, 0xFFFF, 0xFFFF, 0xFFFF, "Stallion Technologies, Inc.(0x124D)"},
{0x124D, 0x0000, 0xFFFF, 0xFFFF, "EasyConnection 8/32(0x0000)"},
{0x124D, 0x0002, 0xFFFF, 0xFFFF, "EasyConnection 8/64(0x0002)"},
{0x124D, 0x0003, 0xFFFF, 0xFFFF, "EasyIO(0x0003)"},
{0x124D, 0x0004, 0xFFFF, 0xFFFF, "EasyConnection/RA(0x0004)"},
}; /* pci_vid_124D[] */

static pci_id_t const pci_vid_124E[] = {
{0x124E, 0xFFFF, 0xFFFF, 0xFFFF, "Cylink(0x124E)"},
}; /* pci_vid_124E[] */

static pci_id_t const pci_vid_124F[] = {
{0x124F, 0xFFFF, 0xFFFF, 0xFFFF, "Infortrend Technology, Inc.(0x124F)"},
{0x124F, 0x0041, 0xFFFF, 0xFFFF, "IFT-2000 Series RAID Controller(0x0041)"},
}; /* pci_vid_124F[] */

static pci_id_t const pci_vid_1250[] = {
{0x1250, 0xFFFF, 0xFFFF, 0xFFFF, "Hitachi Microcomputer System Ltd(0x1250)"},
}; /* pci_vid_1250[] */

static pci_id_t const pci_vid_1251[] = {
{0x1251, 0xFFFF, 0xFFFF, 0xFFFF, "VLSI Solutions Oy(0x1251)"},
}; /* pci_vid_1251[] */

static pci_id_t const pci_vid_1253[] = {
{0x1253, 0xFFFF, 0xFFFF, 0xFFFF, "Guzik Technical Enterprises(0x1253)"},
}; /* pci_vid_1253[] */

static pci_id_t const pci_vid_1254[] = {
{0x1254, 0xFFFF, 0xFFFF, 0xFFFF, "Linear Systems Ltd.(0x1254)"},
{0x1254, 0x0065, 0xFFFF, 0xFFFF, "DVB Master FD(0x0065)"},
{0x1254, 0x007C, 0xFFFF, 0xFFFF, "DVB Master Quad/o(0x007C)"},
}; /* pci_vid_1254[] */

static pci_id_t const pci_vid_1255[] = {
{0x1255, 0xFFFF, 0xFFFF, 0xFFFF, "Optibase Ltd(0x1255)"},
{0x1255, 0x1110, 0xFFFF, 0xFFFF, "MPEG Forge(0x1110)"},
{0x1255, 0x1210, 0xFFFF, 0xFFFF, "MPEG Fusion(0x1210)"},
{0x1255, 0x2110, 0xFFFF, 0xFFFF, "VideoPlex(0x2110)"},
{0x1255, 0x2120, 0xFFFF, 0xFFFF, "VideoPlex CC(0x2120)"},
{0x1255, 0x2130, 0xFFFF, 0xFFFF, "VideoQuest(0x2130)"},
}; /* pci_vid_1255[] */

static pci_id_t const pci_vid_1256[] = {
{0x1256, 0xFFFF, 0xFFFF, 0xFFFF, "Perceptive Solutions, Inc.(0x1256)"},
{0x1256, 0x4201, 0xFFFF, 0xFFFF, "PCI-2220I(0x4201)"},
{0x1256, 0x4401, 0xFFFF, 0xFFFF, "PCI-2240I(0x4401)"},
{0x1256, 0x5201, 0xFFFF, 0xFFFF, "PCI-2000(0x5201)"},
}; /* pci_vid_1256[] */

static pci_id_t const pci_vid_1257[] = {
{0x1257, 0xFFFF, 0xFFFF, 0xFFFF, "Vertex Networks, Inc.(0x1257)"},
}; /* pci_vid_1257[] */

static pci_id_t const pci_vid_1258[] = {
{0x1258, 0xFFFF, 0xFFFF, 0xFFFF, "Gilbarco, Inc.(0x1258)"},
}; /* pci_vid_1258[] */

static pci_id_t const pci_vid_1259[] = {
{0x1259, 0xFFFF, 0xFFFF, 0xFFFF, "Allied Telesis(0x1259)"},
{0x1259, 0x2560, 0xFFFF, 0xFFFF, "AT-2560 Fast Ethernet Adapter (i82557B)(0x2560)"},
{0x1259, 0x2801, 0xFFFF, 0xFFFF, "AT-2801FX (RTL-8139)(0x2801)"},
{0x1259, 0xA117, 0xFFFF, 0xFFFF, "RTL81xx Fast Ethernet(0xA117)"},
{0x1259, 0xA11E, 0xFFFF, 0xFFFF, "RTL81xx Fast Ethernet(0xA11E)"},
{0x1259, 0xA120, 0xFFFF, 0xFFFF, "21x4x DEC-Tulip compatible 10/100 Ethernet(0xA120)"},
}; /* pci_vid_1259[] */

static pci_id_t const pci_vid_125A[] = {
{0x125A, 0xFFFF, 0xFFFF, 0xFFFF, "ABB Power Systems(0x125A)"},
}; /* pci_vid_125A[] */

static pci_id_t const pci_vid_125B[] = {
{0x125B, 0xFFFF, 0xFFFF, 0xFFFF, "Asix Electronics Corporation(0x125B)"},
{0x125B, 0x1400, 0xFFFF, 0xFFFF, "AX88141 Fast Ethernet Controller(0x1400)"},
{0x125B, 0x1400, 0x1186, 0x1100, "AX8814X Based PCI Fast Ethernet Adapter(0x1186-0x1100)"},
{0x125B, 0x9100, 0xFFFF, 0xFFFF, "AX99100 PCIe to Multi I/O Controller(0x9100)"},
{0x125B, 0x9100, 0xA000, 0x1000, "Serial Port(0xA000-0x1000)"},
{0x125B, 0x9100, 0xA000, 0x2000, "Parallel Port(0xA000-0x2000)"},
{0x125B, 0x9100, 0xA000, 0x6000, "SPI(0xA000-0x6000)"},
{0x125B, 0x9100, 0xA000, 0x7000, "Local Bus(0xA000-0x7000)"},
{0x125B, 0x9100, 0xEA50, 0x1C10, "RXi2-BP(0xEA50-0x1C10)"},
}; /* pci_vid_125B[] */

static pci_id_t const pci_vid_125C[] = {
{0x125C, 0xFFFF, 0xFFFF, 0xFFFF, "Aurora Technologies, Inc.(0x125C)"},
{0x125C, 0x0101, 0xFFFF, 0xFFFF, "Saturn 4520P(0x0101)"},
{0x125C, 0x0640, 0xFFFF, 0xFFFF, "Aries 16000P(0x0640)"},
}; /* pci_vid_125C[] */

static pci_id_t const pci_vid_125D[] = {
{0x125D, 0xFFFF, 0xFFFF, 0xFFFF, "ESS Technology(0x125D)"},
{0x125D, 0x0000, 0xFFFF, 0xFFFF, "ES336H Fax Modem (Early Model)(0x0000)"},
{0x125D, 0x1948, 0xFFFF, 0xFFFF, "ES1948 Maestro-1(0x1948)"},
{0x125D, 0x1968, 0xFFFF, 0xFFFF, "ES1968 Maestro 2(0x1968)"},
{0x125D, 0x1968, 0x1028, 0x0085, "ES1968 Maestro-2 PCI(0x1028-0x0085)"},
{0x125D, 0x1968, 0x1033, 0x8051, "ES1968 Maestro-2 Audiodrive(0x1033-0x8051)"},
{0x125D, 0x1969, 0xFFFF, 0xFFFF, "ES1938/ES1946/ES1969 Solo-1 Audiodrive(0x1969)"},
{0x125D, 0x1969, 0x1014, 0x0166, "ES1969 SOLO-1 AudioDrive on IBM Aptiva Mainboard(0x1014-0x0166)"},
{0x125D, 0x1969, 0x125D, 0x8888, "Solo-1 Audio Adapter(0x125D-0x8888)"},
{0x125D, 0x1969, 0x125D, 0x8898, "ES1938S TTSOLO1-SL [TerraTec 128i PCI](0x125D-0x8898)"},
{0x125D, 0x1969, 0x153B, 0x111B, "Terratec 128i PCI(0x153B-0x111B)"},
{0x125D, 0x1978, 0xFFFF, 0xFFFF, "ES1978 Maestro 2E(0x1978)"},
{0x125D, 0x1978, 0x0E11, 0xB112, "Armada M700/E500(0x0E11-0xB112)"},
{0x125D, 0x1978, 0x1033, 0x803C, "ES1978 Maestro-2E Audiodrive(0x1033-0x803C)"},
{0x125D, 0x1978, 0x1033, 0x8058, "ES1978 Maestro-2E Audiodrive(0x1033-0x8058)"},
{0x125D, 0x1978, 0x1092, 0x4000, "Monster Sound MX400(0x1092-0x4000)"},
{0x125D, 0x1978, 0x1179, 0x0001, "ES1978 Maestro-2E Audiodrive(0x1179-0x0001)"},
{0x125D, 0x1988, 0xFFFF, 0xFFFF, "ES1988 Allegro-1(0x1988)"},
{0x125D, 0x1988, 0x0E11, 0x0098, "Evo N600c(0x0E11-0x0098)"},
{0x125D, 0x1988, 0x1092, 0x4100, "Sonic Impact S100(0x1092-0x4100)"},
{0x125D, 0x1988, 0x125D, 0x0431, "Allegro AudioDrive(0x125D-0x0431)"},
{0x125D, 0x1988, 0x125D, 0x1988, "ESS Allegro-1 Audiodrive(0x125D-0x1988)"},
{0x125D, 0x1988, 0x125D, 0x1998, "Allegro AudioDrive(0x125D-0x1998)"},
{0x125D, 0x1988, 0x125D, 0x1999, "Allegro-1 AudioDrive(0x125D-0x1999)"},
{0x125D, 0x1989, 0xFFFF, 0xFFFF, "ESS Modem(0x1989)"},
{0x125D, 0x1989, 0x125D, 0x1989, "ESS Modem(0x125D-0x1989)"},
{0x125D, 0x1998, 0xFFFF, 0xFFFF, "ES1983S Maestro-3i PCI Audio Accelerator(0x1998)"},
{0x125D, 0x1998, 0x1028, 0x00B1, "Latitude C600(0x1028-0x00B1)"},
{0x125D, 0x1998, 0x1028, 0x00E5, "Latitude C810(0x1028-0x00E5)"},
{0x125D, 0x1998, 0x1028, 0x00E6, "ES1983S Maestro-3i (Dell Inspiron 8100)(0x1028-0x00E6)"},
{0x125D, 0x1999, 0xFFFF, 0xFFFF, "ES1983S Maestro-3i PCI Modem Accelerator(0x1999)"},
{0x125D, 0x199A, 0xFFFF, 0xFFFF, "ES1983S Maestro-3i PCI Audio Accelerator(0x199A)"},
{0x125D, 0x199B, 0xFFFF, 0xFFFF, "ES1983S Maestro-3i PCI Modem Accelerator(0x199B)"},
{0x125D, 0x2808, 0xFFFF, 0xFFFF, "ES336H Fax Modem (Later Model)(0x2808)"},
{0x125D, 0x2838, 0xFFFF, 0xFFFF, "ES2838/2839 SuperLink Modem(0x2838)"},
{0x125D, 0x2898, 0xFFFF, 0xFFFF, "ES2898 Modem(0x2898)"},
{0x125D, 0x2898, 0x125D, 0x0424, "ES56-PI Data Fax Modem(0x125D-0x0424)"},
{0x125D, 0x2898, 0x125D, 0x0425, "ES56T-PI Data Fax Modem(0x125D-0x0425)"},
{0x125D, 0x2898, 0x125D, 0x0426, "ES56V-PI Data Fax Modem(0x125D-0x0426)"},
{0x125D, 0x2898, 0x125D, 0x0427, "VW-PI Data Fax Modem(0x125D-0x0427)"},
{0x125D, 0x2898, 0x125D, 0x0428, "ES56ST-PI Data Fax Modem(0x125D-0x0428)"},
{0x125D, 0x2898, 0x125D, 0x0429, "ES56SV-PI Data Fax Modem(0x125D-0x0429)"},
{0x125D, 0x2898, 0x147A, 0xC001, "ES56-PI Data Fax Modem(0x147A-0xC001)"},
{0x125D, 0x2898, 0x148D, 0x1030, "HCF WV-PI56 [ESS ES56-PI Data Fax Modem](0x148D-0x1030)"},
{0x125D, 0x2898, 0x14FE, 0x0428, "ES56-PI Data Fax Modem(0x14FE-0x0428)"},
{0x125D, 0x2898, 0x14FE, 0x0429, "ES56-PI Data Fax Modem(0x14FE-0x0429)"},
}; /* pci_vid_125D[] */

static pci_id_t const pci_vid_125E[] = {
{0x125E, 0xFFFF, 0xFFFF, 0xFFFF, "Specialvideo Engineering SRL(0x125E)"},
}; /* pci_vid_125E[] */

static pci_id_t const pci_vid_125F[] = {
{0x125F, 0xFFFF, 0xFFFF, 0xFFFF, "Concurrent Technologies, Inc.(0x125F)"},
{0x125F, 0x2071, 0xFFFF, 0xFFFF, "CC PMC/232(0x2071)"},
{0x125F, 0x2084, 0xFFFF, 0xFFFF, "CC PMC/23P(0x2084)"},
{0x125F, 0x2091, 0xFFFF, 0xFFFF, "CC PMC/422(0x2091)"},
}; /* pci_vid_125F[] */

static pci_id_t const pci_vid_1260[] = {
{0x1260, 0xFFFF, 0xFFFF, 0xFFFF, "Intersil Corporation(0x1260)"},
{0x1260, 0x3872, 0xFFFF, 0xFFFF, "ISL3872 [Prism 3](0x3872)"},
{0x1260, 0x3872, 0x1468, 0x0202, "LAN-Express IEEE 802.11b Wireless LAN(0x1468-0x0202)"},
{0x1260, 0x3873, 0xFFFF, 0xFFFF, "ISL3874 [Prism 2.5]/ISL3872 [Prism 3](0x3873)"},
{0x1260, 0x3873, 0x10CF, 0x1169, "MBH7WM01-8734 802.11b Wireless Mini PCI Card [ISL3874](0x10CF-0x1169)"},
{0x1260, 0x3873, 0x1186, 0x3501, "DWL-520 Wireless PCI Adapter (rev A or B) [ISL3874](0x1186-0x3501)"},
{0x1260, 0x3873, 0x1186, 0x3700, "DWL-520 Wireless PCI Adapter (rev E1) [ISL3872](0x1186-0x3700)"},
{0x1260, 0x3873, 0x1385, 0x4105, "MA311 802.11b wireless adapter [ISL3874](0x1385-0x4105)"},
{0x1260, 0x3873, 0x1668, 0x0414, "HWP01170-01 802.11b PCI Wireless Adapter(0x1668-0x0414)"},
{0x1260, 0x3873, 0x16A5, 0x1601, "AIR.mate PC-400 PCI Wireless LAN Adapter(0x16A5-0x1601)"},
{0x1260, 0x3873, 0x1737, 0x3874, "WMP11 v1 802.11b Wireless-B PCI Adapter [ISL3874](0x1737-0x3874)"},
{0x1260, 0x3873, 0x4033, 0x7033, "PCW200 802.11b Wireless PCI Adapter [ISL3874](0x4033-0x7033)"},
{0x1260, 0x3873, 0x8086, 0x2510, "M3AWEB Wireless 802.11b MiniPCI Adapter(0x8086-0x2510)"},
{0x1260, 0x3873, 0x8086, 0x2513, "Wireless 802.11b MiniPCI Adapter(0x8086-0x2513)"},
{0x1260, 0x3877, 0xFFFF, 0xFFFF, "ISL3877 [Prism Indigo](0x3877)"},
{0x1260, 0x3886, 0xFFFF, 0xFFFF, "ISL3886 [Prism Javelin/Prism Xbow](0x3886)"},
{0x1260, 0x3886, 0x17CF, 0x0037, "XG-901 and clones Wireless Adapter(0x17CF-0x0037)"},
{0x1260, 0x3890, 0xFFFF, 0xFFFF, "ISL3890 [Prism GT/Prism Duette]/ISL3886 [Prism Javelin/Prism Xbow](0x3890)"},
{0x1260, 0x3890, 0x10B8, 0x2802, "SMC2802W V1 Wireless PCI Adapter [ISL3890](0x10B8-0x2802)"},
{0x1260, 0x3890, 0x10B8, 0x2835, "SMC2835W Wireless Cardbus Adapter(0x10B8-0x2835)"},
{0x1260, 0x3890, 0x10B8, 0xA835, "SMC2835W V2 Wireless Cardbus Adapter(0x10B8-0xA835)"},
{0x1260, 0x3890, 0x1113, 0x4203, "WN4201B(0x1113-0x4203)"},
{0x1260, 0x3890, 0x1113, 0x8201, "T-Com T-Sinus 154pcicard Wireless PCI Adapter(0x1113-0x8201)"},
{0x1260, 0x3890, 0x1113, 0xB301, "T-Sinus 154card Cardbus(0x1113-0xB301)"},
{0x1260, 0x3890, 0x1113, 0xEE03, "SMC2802W V2 Wireless PCI Adapter [ISL3886](0x1113-0xEE03)"},
{0x1260, 0x3890, 0x1113, 0xEE08, "SMC2835W V3 EU Wireless Cardbus Adapter(0x1113-0xEE08)"},
{0x1260, 0x3890, 0x1186, 0x3202, "DWL-G650 A1 Wireless Adapter(0x1186-0x3202)"},
{0x1260, 0x3890, 0x1259, 0xC104, "CG-WLCB54GT Wireless Adapter(0x1259-0xC104)"},
{0x1260, 0x3890, 0x1260, 0x0000, "WG511 v1 54 Mbps Wireless PC Card(0x1260-0x0000)"},
{0x1260, 0x3890, 0x1385, 0x4800, "WG511 v2/v3 54 Mbps Wireless PC Card(0x1385-0x4800)"},
{0x1260, 0x3890, 0x16A5, 0x1605, "ALLNET ALL0271 Wireless PCI Adapter(0x16A5-0x1605)"},
{0x1260, 0x3890, 0x17CF, 0x0014, "XG-600 and clones Wireless Adapter(0x17CF-0x0014)"},
{0x1260, 0x3890, 0x17CF, 0x0020, "XG-900 and clones Wireless Adapter(0x17CF-0x0020)"},
{0x1260, 0x3890, 0x187E, 0x3403, "G-110 802.11g Wireless Cardbus Adapter(0x187E-0x3403)"},
{0x1260, 0x8130, 0xFFFF, 0xFFFF, "HMP8130 NTSC/PAL Video Decoder(0x8130)"},
{0x1260, 0x8131, 0xFFFF, 0xFFFF, "HMP8131 NTSC/PAL Video Decoder(0x8131)"},
{0x1260, 0xFFFF, 0xFFFF, 0xFFFF, "ISL3886IK(0xFFFF)"},
{0x1260, 0xFFFF, 0x1260, 0x0000, "Senao 3054MP+ (J) mini-PCI WLAN 802.11g adapter(0x1260-0x0000)"},
}; /* pci_vid_1260[] */

static pci_id_t const pci_vid_1261[] = {
{0x1261, 0xFFFF, 0xFFFF, 0xFFFF, "Matsushita-Kotobuki Electronics Industries, Ltd.(0x1261)"},
}; /* pci_vid_1261[] */

static pci_id_t const pci_vid_1262[] = {
{0x1262, 0xFFFF, 0xFFFF, 0xFFFF, "ES Computer Company, Ltd.(0x1262)"},
}; /* pci_vid_1262[] */

static pci_id_t const pci_vid_1263[] = {
{0x1263, 0xFFFF, 0xFFFF, 0xFFFF, "Sonic Solutions(0x1263)"},
}; /* pci_vid_1263[] */

static pci_id_t const pci_vid_1264[] = {
{0x1264, 0xFFFF, 0xFFFF, 0xFFFF, "Aval Nagasaki Corporation(0x1264)"},
}; /* pci_vid_1264[] */

static pci_id_t const pci_vid_1265[] = {
{0x1265, 0xFFFF, 0xFFFF, 0xFFFF, "Casio Computer Co., Ltd.(0x1265)"},
}; /* pci_vid_1265[] */

static pci_id_t const pci_vid_1266[] = {
{0x1266, 0xFFFF, 0xFFFF, 0xFFFF, "Microdyne Corporation(0x1266)"},
{0x1266, 0x0001, 0xFFFF, 0xFFFF, "NE10/100 Adapter (i82557B)(0x0001)"},
{0x1266, 0x1910, 0xFFFF, 0xFFFF, "NE2000Plus (RT8029) Ethernet Adapter(0x1910)"},
{0x1266, 0x1910, 0x1266, 0x1910, "NE2000Plus Ethernet Adapter(0x1266-0x1910)"},
}; /* pci_vid_1266[] */

static pci_id_t const pci_vid_1267[] = {
{0x1267, 0xFFFF, 0xFFFF, 0xFFFF, "S. A. Telecommunications(0x1267)"},
{0x1267, 0x5352, 0xFFFF, 0xFFFF, "PCR2101(0x5352)"},
{0x1267, 0x5A4B, 0xFFFF, 0xFFFF, "Telsat Turbo(0x5A4B)"},
}; /* pci_vid_1267[] */

static pci_id_t const pci_vid_1268[] = {
{0x1268, 0xFFFF, 0xFFFF, 0xFFFF, "Tektronix(0x1268)"},
}; /* pci_vid_1268[] */

static pci_id_t const pci_vid_1269[] = {
{0x1269, 0xFFFF, 0xFFFF, 0xFFFF, "Thales(0x1269)"},
{0x1269, 0x00B3, 0xFFFF, 0xFFFF, "5G Data Card [Cinterion MV31-W](0x00B3)"},
}; /* pci_vid_1269[] */

static pci_id_t const pci_vid_126A[] = {
{0x126A, 0xFFFF, 0xFFFF, 0xFFFF, "Lexmark International, Inc.(0x126A)"},
}; /* pci_vid_126A[] */

static pci_id_t const pci_vid_126B[] = {
{0x126B, 0xFFFF, 0xFFFF, 0xFFFF, "Adax, Inc.(0x126B)"},
}; /* pci_vid_126B[] */

static pci_id_t const pci_vid_126C[] = {
{0x126C, 0xFFFF, 0xFFFF, 0xFFFF, "Northern Telecom(0x126C)"},
{0x126C, 0x1211, 0xFFFF, 0xFFFF, "10/100BaseTX [RTL81xx](0x1211)"},
{0x126C, 0x126C, 0xFFFF, 0xFFFF, "802.11b Wireless Ethernet Adapter(0x126C)"},
}; /* pci_vid_126C[] */

static pci_id_t const pci_vid_126D[] = {
{0x126D, 0xFFFF, 0xFFFF, 0xFFFF, "Splash Technology, Inc.(0x126D)"},
}; /* pci_vid_126D[] */

static pci_id_t const pci_vid_126E[] = {
{0x126E, 0xFFFF, 0xFFFF, 0xFFFF, "Sumitomo Metal Industries, Ltd.(0x126E)"},
}; /* pci_vid_126E[] */

static pci_id_t const pci_vid_126F[] = {
{0x126F, 0xFFFF, 0xFFFF, 0xFFFF, "Silicon Motion, Inc.(0x126F)"},
{0x126F, 0x0501, 0xFFFF, 0xFFFF, "SM501 VoyagerGX Rev. AA(0x0501)"},
{0x126F, 0x0510, 0xFFFF, 0xFFFF, "SM501 VoyagerGX Rev. B(0x0510)"},
{0x126F, 0x0710, 0xFFFF, 0xFFFF, "SM710 LynxEM(0x0710)"},
{0x126F, 0x0712, 0xFFFF, 0xFFFF, "SM712 LynxEM+(0x0712)"},
{0x126F, 0x0718, 0xFFFF, 0xFFFF, "SM718 LynxSE+(0x0718)"},
{0x126F, 0x0720, 0xFFFF, 0xFFFF, "SM720 Lynx3DM(0x0720)"},
{0x126F, 0x0730, 0xFFFF, 0xFFFF, "SM731 Cougar3DR(0x0730)"},
{0x126F, 0x0750, 0xFFFF, 0xFFFF, "SM750(0x0750)"},
{0x126F, 0x0768, 0xFFFF, 0xFFFF, "SM768(0x0768)"},
{0x126F, 0x0810, 0xFFFF, 0xFFFF, "SM810 LynxE(0x0810)"},
{0x126F, 0x0811, 0xFFFF, 0xFFFF, "SM811 LynxE(0x0811)"},
{0x126F, 0x0820, 0xFFFF, 0xFFFF, "SM820 Lynx3D(0x0820)"},
{0x126F, 0x0910, 0xFFFF, 0xFFFF, "SM910(0x0910)"},
{0x126F, 0x2260, 0xFFFF, 0xFFFF, "SM2260 NVMe SSD Controller(0x2260)"},
{0x126F, 0x2261, 0xFFFF, 0xFFFF, "SM2261XT x2 NVMe SSD Controller (DRAM-less)(0x2261)"},
{0x126F, 0x2262, 0xFFFF, 0xFFFF, "SM2262/SM2262EN SSD Controller(0x2262)"},
{0x126F, 0x2263, 0xFFFF, 0xFFFF, "SM2263EN/SM2263XT (DRAM-less) NVMe SSD Controllers(0x2263)"},
{0x126F, 0x2269, 0xFFFF, 0xFFFF, "SM2269XT (DRAM-less) NVMe SSD Controller(0x2269)"},
{0x126F, 0x8366, 0xFFFF, 0xFFFF, "SM8366 NVMe SSD Controller [MonTitan](0x8366)"},
}; /* pci_vid_126F[] */

static pci_id_t const pci_vid_1270[] = {
{0x1270, 0xFFFF, 0xFFFF, 0xFFFF, "Olympus Optical Co., Ltd.(0x1270)"},
}; /* pci_vid_1270[] */

static pci_id_t const pci_vid_1271[] = {
{0x1271, 0xFFFF, 0xFFFF, 0xFFFF, "GW Instruments(0x1271)"},
}; /* pci_vid_1271[] */

static pci_id_t const pci_vid_1272[] = {
{0x1272, 0xFFFF, 0xFFFF, 0xFFFF, "Telematics International(0x1272)"},
}; /* pci_vid_1272[] */

static pci_id_t const pci_vid_1273[] = {
{0x1273, 0xFFFF, 0xFFFF, 0xFFFF, "Hughes Network Systems(0x1273)"},
{0x1273, 0x0002, 0xFFFF, 0xFFFF, "DirecPC(0x0002)"},
}; /* pci_vid_1273[] */

static pci_id_t const pci_vid_1274[] = {
{0x1274, 0xFFFF, 0xFFFF, 0xFFFF, "Ensoniq(0x1274)"},
{0x1274, 0x1171, 0xFFFF, 0xFFFF, "ES1373 / Creative Labs CT5803 [AudioPCI](0x1171)"},
{0x1274, 0x1371, 0xFFFF, 0xFFFF, "ES1371/ES1373 / Creative Labs CT2518(0x1371)"},
{0x1274, 0x1371, 0x0E11, 0x0024, "AudioPCI on Motherboard Compaq Deskpro(0x0E11-0x0024)"},
{0x1274, 0x1371, 0x0E11, 0xB1A7, "ES1371, ES1373 AudioPCI(0x0E11-0xB1A7)"},
{0x1274, 0x1371, 0x1033, 0x80AC, "ES1371, ES1373 AudioPCI(0x1033-0x80AC)"},
{0x1274, 0x1371, 0x1042, 0x1854, "Tazer(0x1042-0x1854)"},
{0x1274, 0x1371, 0x107B, 0x8054, "Tabor2(0x107B-0x8054)"},
{0x1274, 0x1371, 0x1274, 0x1371, "Audio PCI 64V/128/5200 / Creative CT4810/CT5803/CT5806 [Sound Blaster PCI](0x1274-0x1371)"},
{0x1274, 0x1371, 0x1274, 0x8001, "CT4751 board(0x1274-0x8001)"},
{0x1274, 0x1371, 0x1462, 0x6470, "ES1371, ES1373 AudioPCI On Motherboard MS-6147 1.1A(0x1462-0x6470)"},
{0x1274, 0x1371, 0x1462, 0x6560, "ES1371, ES1373 AudioPCI On Motherboard MS-6156 1.10(0x1462-0x6560)"},
{0x1274, 0x1371, 0x1462, 0x6630, "ES1371, ES1373 AudioPCI On Motherboard MS-6163BX 1.0A(0x1462-0x6630)"},
{0x1274, 0x1371, 0x1462, 0x6631, "ES1371, ES1373 AudioPCI On Motherboard MS-6163VIA 1.0A(0x1462-0x6631)"},
{0x1274, 0x1371, 0x1462, 0x6632, "ES1371, ES1373 AudioPCI On Motherboard MS-6163BX 2.0A(0x1462-0x6632)"},
{0x1274, 0x1371, 0x1462, 0x6633, "ES1371, ES1373 AudioPCI On Motherboard MS-6163VIA 2.0A(0x1462-0x6633)"},
{0x1274, 0x1371, 0x1462, 0x6820, "ES1371, ES1373 AudioPCI On Motherboard MS-6182 1.00(0x1462-0x6820)"},
{0x1274, 0x1371, 0x1462, 0x6822, "ES1371, ES1373 AudioPCI On Motherboard MS-6182 1.00A(0x1462-0x6822)"},
{0x1274, 0x1371, 0x1462, 0x6830, "ES1371, ES1373 AudioPCI On Motherboard MS-6183 1.00(0x1462-0x6830)"},
{0x1274, 0x1371, 0x1462, 0x6880, "ES1371, ES1373 AudioPCI On Motherboard MS-6188 1.00(0x1462-0x6880)"},
{0x1274, 0x1371, 0x1462, 0x6900, "ES1371, ES1373 AudioPCI On Motherboard MS-6190 1.00(0x1462-0x6900)"},
{0x1274, 0x1371, 0x1462, 0x6910, "ES1371, ES1373 AudioPCI On Motherboard MS-6191(0x1462-0x6910)"},
{0x1274, 0x1371, 0x1462, 0x6930, "ES1371, ES1373 AudioPCI On Motherboard MS-6193(0x1462-0x6930)"},
{0x1274, 0x1371, 0x1462, 0x6990, "ES1371, ES1373 AudioPCI On Motherboard MS-6199BX 2.0A(0x1462-0x6990)"},
{0x1274, 0x1371, 0x1462, 0x6991, "ES1371, ES1373 AudioPCI On Motherboard MS-6199VIA 2.0A(0x1462-0x6991)"},
{0x1274, 0x1371, 0x14A4, 0x2077, "ES1371, ES1373 AudioPCI On Motherboard KR639(0x14A4-0x2077)"},
{0x1274, 0x1371, 0x14A4, 0x2105, "ES1371, ES1373 AudioPCI On Motherboard MR800(0x14A4-0x2105)"},
{0x1274, 0x1371, 0x14A4, 0x2107, "ES1371, ES1373 AudioPCI On Motherboard MR801(0x14A4-0x2107)"},
{0x1274, 0x1371, 0x14A4, 0x2172, "ES1371, ES1373 AudioPCI On Motherboard DR739(0x14A4-0x2172)"},
{0x1274, 0x1371, 0x1509, 0x9902, "ES1371, ES1373 AudioPCI On Motherboard KW11(0x1509-0x9902)"},
{0x1274, 0x1371, 0x1509, 0x9903, "ES1371, ES1373 AudioPCI On Motherboard KW31(0x1509-0x9903)"},
{0x1274, 0x1371, 0x1509, 0x9904, "ES1371, ES1373 AudioPCI On Motherboard KA11(0x1509-0x9904)"},
{0x1274, 0x1371, 0x1509, 0x9905, "ES1371, ES1373 AudioPCI On Motherboard KC13(0x1509-0x9905)"},
{0x1274, 0x1371, 0x152D, 0x8801, "ES1371, ES1373 AudioPCI On Motherboard CP810E(0x152D-0x8801)"},
{0x1274, 0x1371, 0x152D, 0x8802, "ES1371, ES1373 AudioPCI On Motherboard CP810(0x152D-0x8802)"},
{0x1274, 0x1371, 0x152D, 0x8803, "ES1371, ES1373 AudioPCI On Motherboard P3810E(0x152D-0x8803)"},
{0x1274, 0x1371, 0x152D, 0x8804, "ES1371, ES1373 AudioPCI On Motherboard P3810-S(0x152D-0x8804)"},
{0x1274, 0x1371, 0x152D, 0x8805, "ES1371, ES1373 AudioPCI On Motherboard P3820-S(0x152D-0x8805)"},
{0x1274, 0x1371, 0x270F, 0x2001, "ES1371, ES1373 AudioPCI On Motherboard 6CTR(0x270F-0x2001)"},
{0x1274, 0x1371, 0x270F, 0x2200, "ES1371, ES1373 AudioPCI On Motherboard 6WTX(0x270F-0x2200)"},
{0x1274, 0x1371, 0x270F, 0x3000, "ES1371, ES1373 AudioPCI On Motherboard 6WSV(0x270F-0x3000)"},
{0x1274, 0x1371, 0x270F, 0x3100, "ES1371, ES1373 AudioPCI On Motherboard 6WIV2(0x270F-0x3100)"},
{0x1274, 0x1371, 0x270F, 0x3102, "ES1371, ES1373 AudioPCI On Motherboard 6WIV(0x270F-0x3102)"},
{0x1274, 0x1371, 0x270F, 0x7060, "ES1371, ES1373 AudioPCI On Motherboard 6ASA2(0x270F-0x7060)"},
{0x1274, 0x1371, 0x8086, 0x4249, "ES1371, ES1373 AudioPCI On Motherboard BI440ZX(0x8086-0x4249)"},
{0x1274, 0x1371, 0x8086, 0x424C, "ES1371, ES1373 AudioPCI On Motherboard BL440ZX(0x8086-0x424C)"},
{0x1274, 0x1371, 0x8086, 0x425A, "ES1371, ES1373 AudioPCI On Motherboard BZ440ZX(0x8086-0x425A)"},
{0x1274, 0x1371, 0x8086, 0x4341, "ES1371, ES1373 AudioPCI On Motherboard Cayman(0x8086-0x4341)"},
{0x1274, 0x1371, 0x8086, 0x4343, "ES1371, ES1373 AudioPCI On Motherboard Cape Cod(0x8086-0x4343)"},
{0x1274, 0x1371, 0x8086, 0x4541, "D815EEA Motherboard(0x8086-0x4541)"},
{0x1274, 0x1371, 0x8086, 0x4649, "ES1371, ES1373 AudioPCI On Motherboard Fire Island(0x8086-0x4649)"},
{0x1274, 0x1371, 0x8086, 0x464A, "ES1371, ES1373 AudioPCI On Motherboard FJ440ZX(0x8086-0x464A)"},
{0x1274, 0x1371, 0x8086, 0x4D4F, "ES1371, ES1373 AudioPCI On Motherboard Montreal(0x8086-0x4D4F)"},
{0x1274, 0x1371, 0x8086, 0x4F43, "ES1371, ES1373 AudioPCI On Motherboard OC440LX(0x8086-0x4F43)"},
{0x1274, 0x1371, 0x8086, 0x5243, "ES1371, ES1373 AudioPCI On Motherboard RC440BX(0x8086-0x5243)"},
{0x1274, 0x1371, 0x8086, 0x5352, "ES1371, ES1373 AudioPCI On Motherboard SunRiver(0x8086-0x5352)"},
{0x1274, 0x1371, 0x8086, 0x5643, "ES1371, ES1373 AudioPCI On Motherboard Vancouver(0x8086-0x5643)"},
{0x1274, 0x1371, 0x8086, 0x5753, "ES1371, ES1373 AudioPCI On Motherboard WS440BX(0x8086-0x5753)"},
{0x1274, 0x5000, 0xFFFF, 0xFFFF, "ES1370 [AudioPCI](0x5000)"},
{0x1274, 0x5880, 0xFFFF, 0xFFFF, "5880B / Creative Labs CT5880(0x5880)"},
{0x1274, 0x5880, 0x1274, 0x2000, "Creative CT4810 [Sound Blaster AudioPCI 128](0x1274-0x2000)"},
{0x1274, 0x5880, 0x1274, 0x2003, "Creative SoundBlaster AudioPCI 128(0x1274-0x2003)"},
{0x1274, 0x5880, 0x1274, 0x5880, "Creative CT4750 [Sound Blaster PCI 128](0x1274-0x5880)"},
{0x1274, 0x5880, 0x1274, 0x8001, "Creative CT4750 [Sound Blaster 16 PCI/PCI 128/4.1 Digital](0x1274-0x8001)"},
{0x1274, 0x5880, 0x1458, 0xA000, "5880 AudioPCI On Motherboard 6OXET(0x1458-0xA000)"},
{0x1274, 0x5880, 0x1462, 0x6880, "5880 AudioPCI On Motherboard MS-6188 1.00(0x1462-0x6880)"},
{0x1274, 0x5880, 0x270F, 0x2001, "5880 AudioPCI On Motherboard 6CTR(0x270F-0x2001)"},
{0x1274, 0x5880, 0x270F, 0x2200, "5880 AudioPCI On Motherboard 6WTX(0x270F-0x2200)"},
{0x1274, 0x5880, 0x270F, 0x7040, "5880 AudioPCI On Motherboard 6ATA4(0x270F-0x7040)"},
{0x1274, 0x8001, 0xFFFF, 0xFFFF, "CT5880 [AudioPCI](0x8001)"},
{0x1274, 0x8002, 0xFFFF, 0xFFFF, "5880A [AudioPCI](0x8002)"},
}; /* pci_vid_1274[] */

static pci_id_t const pci_vid_1275[] = {
{0x1275, 0xFFFF, 0xFFFF, 0xFFFF, "Network Appliance Corporation(0x1275)"},
}; /* pci_vid_1275[] */

static pci_id_t const pci_vid_1276[] = {
{0x1276, 0xFFFF, 0xFFFF, 0xFFFF, "Switched Network Technologies, Inc.(0x1276)"},
}; /* pci_vid_1276[] */

static pci_id_t const pci_vid_1277[] = {
{0x1277, 0xFFFF, 0xFFFF, 0xFFFF, "Comstream(0x1277)"},
}; /* pci_vid_1277[] */

static pci_id_t const pci_vid_1278[] = {
{0x1278, 0xFFFF, 0xFFFF, 0xFFFF, "Transtech Parallel Systems Ltd.(0x1278)"},
{0x1278, 0x0701, 0xFFFF, 0xFFFF, "TPE3/TM3 PowerPC Node(0x0701)"},
{0x1278, 0x0710, 0xFFFF, 0xFFFF, "TPE5 PowerPC PCI board(0x0710)"},
{0x1278, 0x1100, 0xFFFF, 0xFFFF, "PMC-FPGA02(0x1100)"},
{0x1278, 0x1101, 0xFFFF, 0xFFFF, "TS-C43 card with 4 ADSP-TS101 processors(0x1101)"},
}; /* pci_vid_1278[] */

static pci_id_t const pci_vid_1279[] = {
{0x1279, 0xFFFF, 0xFFFF, 0xFFFF, "Transmeta Corporation(0x1279)"},
{0x1279, 0x0060, 0xFFFF, 0xFFFF, "TM8000 Northbridge(0x0060)"},
{0x1279, 0x0061, 0xFFFF, 0xFFFF, "TM8000 AGP bridge(0x0061)"},
{0x1279, 0x0295, 0xFFFF, 0xFFFF, "Northbridge(0x0295)"},
{0x1279, 0x0395, 0xFFFF, 0xFFFF, "LongRun Northbridge(0x0395)"},
{0x1279, 0x0396, 0xFFFF, 0xFFFF, "SDRAM controller(0x0396)"},
{0x1279, 0x0397, 0xFFFF, 0xFFFF, "BIOS scratchpad(0x0397)"},
}; /* pci_vid_1279[] */

static pci_id_t const pci_vid_127A[] = {
{0x127A, 0xFFFF, 0xFFFF, 0xFFFF, "Rockwell International(0x127A)"},
{0x127A, 0x1002, 0xFFFF, 0xFFFF, "HCF 56k Data/Fax Modem(0x1002)"},
{0x127A, 0x1002, 0x1092, 0x094C, "SupraExpress 56i PRO [Diamond SUP2380](0x1092-0x094C)"},
{0x127A, 0x1002, 0x122D, 0x4002, "HPG / MDP3858-U(0x122D-0x4002)"},
{0x127A, 0x1002, 0x122D, 0x4005, "MDP3858-E(0x122D-0x4005)"},
{0x127A, 0x1002, 0x122D, 0x4007, "MDP3858-A/-NZ(0x122D-0x4007)"},
{0x127A, 0x1002, 0x122D, 0x4012, "MDP3858-SA(0x122D-0x4012)"},
{0x127A, 0x1002, 0x122D, 0x4017, "MDP3858-W(0x122D-0x4017)"},
{0x127A, 0x1002, 0x122D, 0x4018, "MDP3858-W(0x122D-0x4018)"},
{0x127A, 0x1002, 0x127A, 0x1002, "Rockwell 56K D/F HCF Modem(0x127A-0x1002)"},
{0x127A, 0x1003, 0xFFFF, 0xFFFF, "HCF 56k Data/Fax Modem(0x1003)"},
{0x127A, 0x1003, 0x0E11, 0xB0BC, "229-DF Zephyr(0x0E11-0xB0BC)"},
{0x127A, 0x1003, 0x0E11, 0xB114, "229-DF Cheetah(0x0E11-0xB114)"},
{0x127A, 0x1003, 0x1033, 0x802B, "229-DF(0x1033-0x802B)"},
{0x127A, 0x1003, 0x13DF, 0x1003, "PCI56RX Modem(0x13DF-0x1003)"},
{0x127A, 0x1003, 0x13E0, 0x0117, "IBM(0x13E0-0x0117)"},
{0x127A, 0x1003, 0x13E0, 0x0147, "IBM F-1156IV+/R3 Spain V.90 Modem(0x13E0-0x0147)"},
{0x127A, 0x1003, 0x13E0, 0x0197, "IBM(0x13E0-0x0197)"},
{0x127A, 0x1003, 0x13E0, 0x01C7, "IBM F-1156IV+/R3 WW V.90 Modem(0x13E0-0x01C7)"},
{0x127A, 0x1003, 0x13E0, 0x01F7, "IBM(0x13E0-0x01F7)"},
{0x127A, 0x1003, 0x1436, 0x1003, "IBM(0x1436-0x1003)"},
{0x127A, 0x1003, 0x1436, 0x1103, "IBM 5614PM3G V.90 Modem(0x1436-0x1103)"},
{0x127A, 0x1003, 0x1436, 0x1602, "Compaq 229-DF Ducati(0x1436-0x1602)"},
{0x127A, 0x1004, 0xFFFF, 0xFFFF, "HCF 56k Data/Fax/Voice Modem(0x1004)"},
{0x127A, 0x1004, 0x1048, 0x1500, "MicroLink 56k Modem(0x1048-0x1500)"},
{0x127A, 0x1004, 0x10CF, 0x1059, "Fujitsu 229-DFRT(0x10CF-0x1059)"},
{0x127A, 0x1005, 0xFFFF, 0xFFFF, "HCF 56k Data/Fax/Voice/Spkp (w/Handset) Modem(0x1005)"},
{0x127A, 0x1005, 0x1005, 0x127A, "AOpen FM56-P(0x1005-0x127A)"},
{0x127A, 0x1005, 0x1033, 0x8029, "229-DFSV(0x1033-0x8029)"},
{0x127A, 0x1005, 0x1033, 0x8054, "Modem(0x1033-0x8054)"},
{0x127A, 0x1005, 0x10CF, 0x103C, "Fujitsu(0x10CF-0x103C)"},
{0x127A, 0x1005, 0x10CF, 0x1055, "Fujitsu 229-DFSV(0x10CF-0x1055)"},
{0x127A, 0x1005, 0x10CF, 0x1056, "Fujitsu 229-DFSV(0x10CF-0x1056)"},
{0x127A, 0x1005, 0x122D, 0x4003, "MDP3858SP-U(0x122D-0x4003)"},
{0x127A, 0x1005, 0x122D, 0x4006, "Packard Bell MDP3858V-E(0x122D-0x4006)"},
{0x127A, 0x1005, 0x122D, 0x4008, "MDP3858SP-A/SP-NZ(0x122D-0x4008)"},
{0x127A, 0x1005, 0x122D, 0x4009, "MDP3858SP-E(0x122D-0x4009)"},
{0x127A, 0x1005, 0x122D, 0x4010, "MDP3858V-U(0x122D-0x4010)"},
{0x127A, 0x1005, 0x122D, 0x4011, "MDP3858SP-SA(0x122D-0x4011)"},
{0x127A, 0x1005, 0x122D, 0x4013, "MDP3858V-A/V-NZ(0x122D-0x4013)"},
{0x127A, 0x1005, 0x122D, 0x4015, "MDP3858SP-W(0x122D-0x4015)"},
{0x127A, 0x1005, 0x122D, 0x4016, "MDP3858V-W(0x122D-0x4016)"},
{0x127A, 0x1005, 0x122D, 0x4019, "MDP3858V-SA(0x122D-0x4019)"},
{0x127A, 0x1005, 0x13DF, 0x1005, "PCI56RVP Modem(0x13DF-0x1005)"},
{0x127A, 0x1005, 0x13E0, 0x0187, "IBM(0x13E0-0x0187)"},
{0x127A, 0x1005, 0x13E0, 0x01A7, "IBM(0x13E0-0x01A7)"},
{0x127A, 0x1005, 0x13E0, 0x01B7, "IBM DF-1156IV+/R3 Spain V.90 Modem(0x13E0-0x01B7)"},
{0x127A, 0x1005, 0x13E0, 0x01D7, "IBM DF-1156IV+/R3 WW V.90 Modem(0x13E0-0x01D7)"},
{0x127A, 0x1005, 0x1436, 0x1005, "IBM(0x1436-0x1005)"},
{0x127A, 0x1005, 0x1436, 0x1105, "IBM(0x1436-0x1105)"},
{0x127A, 0x1005, 0x1437, 0x1105, "IBM 5614PS3G V.90 Modem(0x1437-0x1105)"},
{0x127A, 0x1022, 0xFFFF, 0xFFFF, "HCF 56k Modem(0x1022)"},
{0x127A, 0x1022, 0x1436, 0x1303, "M3-5614PM3G V.90 Modem(0x1436-0x1303)"},
{0x127A, 0x1023, 0xFFFF, 0xFFFF, "HCF 56k Data/Fax Modem(0x1023)"},
{0x127A, 0x1023, 0x122D, 0x4020, "Packard Bell MDP3858-WE(0x122D-0x4020)"},
{0x127A, 0x1023, 0x122D, 0x4023, "MDP3858-UE(0x122D-0x4023)"},
{0x127A, 0x1023, 0x13E0, 0x0247, "IBM F-1156IV+/R6 Spain V.90 Modem(0x13E0-0x0247)"},
{0x127A, 0x1023, 0x13E0, 0x0297, "IBM(0x13E0-0x0297)"},
{0x127A, 0x1023, 0x13E0, 0x02C7, "IBM F-1156IV+/R6 WW V.90 Modem(0x13E0-0x02C7)"},
{0x127A, 0x1023, 0x1436, 0x1203, "IBM(0x1436-0x1203)"},
{0x127A, 0x1023, 0x1436, 0x1303, "IBM(0x1436-0x1303)"},
{0x127A, 0x1024, 0xFFFF, 0xFFFF, "HCF 56k Data/Fax/Voice Modem(0x1024)"},
{0x127A, 0x1025, 0xFFFF, 0xFFFF, "HCF 56k Data/Fax/Voice/Spkp (w/Handset) Modem(0x1025)"},
{0x127A, 0x1025, 0x10CF, 0x106A, "Fujitsu 235-DFSV(0x10CF-0x106A)"},
{0x127A, 0x1025, 0x122D, 0x4021, "Packard Bell MDP3858V-WE(0x122D-0x4021)"},
{0x127A, 0x1025, 0x122D, 0x4022, "MDP3858SP-WE(0x122D-0x4022)"},
{0x127A, 0x1025, 0x122D, 0x4024, "MDP3858V-UE(0x122D-0x4024)"},
{0x127A, 0x1025, 0x122D, 0x4025, "MDP3858SP-UE(0x122D-0x4025)"},
{0x127A, 0x1026, 0xFFFF, 0xFFFF, "HCF 56k PCI Speakerphone Modem(0x1026)"},
{0x127A, 0x1032, 0xFFFF, 0xFFFF, "HCF 56k Modem(0x1032)"},
{0x127A, 0x1033, 0xFFFF, 0xFFFF, "HCF 56k Modem(0x1033)"},
{0x127A, 0x1034, 0xFFFF, 0xFFFF, "HCF 56k Modem(0x1034)"},
{0x127A, 0x1035, 0xFFFF, 0xFFFF, "HCF 56k PCI Speakerphone Modem(0x1035)"},
{0x127A, 0x1036, 0xFFFF, 0xFFFF, "HCF 56k Modem(0x1036)"},
{0x127A, 0x1085, 0xFFFF, 0xFFFF, "HCF 56k Volcano PCI Modem(0x1085)"},
{0x127A, 0x2004, 0xFFFF, 0xFFFF, "HSF 56k Data/Fax/Voice/Spkp (w/Handset) Modem(0x2004)"},
{0x127A, 0x2005, 0xFFFF, 0xFFFF, "HCF 56k Data/Fax Modem(0x2005)"},
{0x127A, 0x2005, 0x104D, 0x8044, "229-DFSV(0x104D-0x8044)"},
{0x127A, 0x2005, 0x104D, 0x8045, "229-DFSV(0x104D-0x8045)"},
{0x127A, 0x2005, 0x104D, 0x8055, "PBE/Aztech 235W-DFSV(0x104D-0x8055)"},
{0x127A, 0x2005, 0x104D, 0x8056, "235-DFSV(0x104D-0x8056)"},
{0x127A, 0x2005, 0x104D, 0x805A, "Modem(0x104D-0x805A)"},
{0x127A, 0x2005, 0x104D, 0x805F, "Modem(0x104D-0x805F)"},
{0x127A, 0x2005, 0x104D, 0x8074, "Modem(0x104D-0x8074)"},
{0x127A, 0x2013, 0xFFFF, 0xFFFF, "HSF 56k Data/Fax Modem(0x2013)"},
{0x127A, 0x2013, 0x1179, 0x0001, "Modem(0x1179-0x0001)"},
{0x127A, 0x2013, 0x1179, 0xFF00, "Modem(0x1179-0xFF00)"},
{0x127A, 0x2014, 0xFFFF, 0xFFFF, "HSF 56k Data/Fax/Voice Modem(0x2014)"},
{0x127A, 0x2014, 0x10CF, 0x1057, "Fujitsu Citicorp III(0x10CF-0x1057)"},
{0x127A, 0x2014, 0x122D, 0x4050, "MSP3880-U(0x122D-0x4050)"},
{0x127A, 0x2014, 0x122D, 0x4055, "MSP3880-W(0x122D-0x4055)"},
{0x127A, 0x2015, 0xFFFF, 0xFFFF, "HSF 56k Data/Fax/Voice/Spkp (w/Handset) Modem(0x2015)"},
{0x127A, 0x2015, 0x10CF, 0x1063, "Fujitsu(0x10CF-0x1063)"},
{0x127A, 0x2015, 0x10CF, 0x1064, "Fujitsu(0x10CF-0x1064)"},
{0x127A, 0x2015, 0x1468, 0x2015, "Fujitsu(0x1468-0x2015)"},
{0x127A, 0x2016, 0xFFFF, 0xFFFF, "HSF 56k Data/Fax/Voice/Spkp Modem(0x2016)"},
{0x127A, 0x2016, 0x122D, 0x4051, "MSP3880V-W(0x122D-0x4051)"},
{0x127A, 0x2016, 0x122D, 0x4052, "MSP3880SP-W(0x122D-0x4052)"},
{0x127A, 0x2016, 0x122D, 0x4054, "MSP3880V-U(0x122D-0x4054)"},
{0x127A, 0x2016, 0x122D, 0x4056, "MSP3880SP-U(0x122D-0x4056)"},
{0x127A, 0x2016, 0x122D, 0x4057, "MSP3880SP-A(0x122D-0x4057)"},
{0x127A, 0x4311, 0xFFFF, 0xFFFF, "Riptide HSF 56k PCI Modem(0x4311)"},
{0x127A, 0x4311, 0x127A, 0x4311, "Ring Modular?- Riptide HSF RT HP Dom(0x127A-0x4311)"},
{0x127A, 0x4311, 0x13E0, 0x0210, "HP-GVC(0x13E0-0x0210)"},
{0x127A, 0x4320, 0xFFFF, 0xFFFF, "Riptide PCI Audio Controller(0x4320)"},
{0x127A, 0x4320, 0x1235, 0x4320, "Riptide PCI Audio Controller(0x1235-0x4320)"},
{0x127A, 0x4321, 0xFFFF, 0xFFFF, "Riptide HCF 56k PCI Modem(0x4321)"},
{0x127A, 0x4321, 0x1235, 0x4321, "Hewlett Packard DF(0x1235-0x4321)"},
{0x127A, 0x4321, 0x1235, 0x4324, "Hewlett Packard DF(0x1235-0x4324)"},
{0x127A, 0x4321, 0x13E0, 0x0210, "Hewlett Packard DF(0x13E0-0x0210)"},
{0x127A, 0x4321, 0x144D, 0x2321, "Riptide(0x144D-0x2321)"},
{0x127A, 0x4322, 0xFFFF, 0xFFFF, "Riptide PCI Game Controller(0x4322)"},
{0x127A, 0x4322, 0x1235, 0x4322, "Riptide PCI Game Controller(0x1235-0x4322)"},
{0x127A, 0x8234, 0xFFFF, 0xFFFF, "RapidFire 616X ATM155 Adapter(0x8234)"},
{0x127A, 0x8234, 0x108D, 0x0022, "RapidFire 616X ATM155 Adapter(0x108D-0x0022)"},
{0x127A, 0x8234, 0x108D, 0x0027, "RapidFire 616X ATM155 Adapter(0x108D-0x0027)"},
}; /* pci_vid_127A[] */

static pci_id_t const pci_vid_127B[] = {
{0x127B, 0xFFFF, 0xFFFF, 0xFFFF, "Pixera Corporation(0x127B)"},
}; /* pci_vid_127B[] */

static pci_id_t const pci_vid_127C[] = {
{0x127C, 0xFFFF, 0xFFFF, 0xFFFF, "Crosspoint Solutions, Inc.(0x127C)"},
}; /* pci_vid_127C[] */

static pci_id_t const pci_vid_127D[] = {
{0x127D, 0xFFFF, 0xFFFF, 0xFFFF, "Vela Research(0x127D)"},
}; /* pci_vid_127D[] */

static pci_id_t const pci_vid_127E[] = {
{0x127E, 0xFFFF, 0xFFFF, 0xFFFF, "Winnov, L.P.(0x127E)"},
{0x127E, 0x0010, 0xFFFF, 0xFFFF, "Videum 1000 Plus(0x0010)"},
}; /* pci_vid_127E[] */

static pci_id_t const pci_vid_127F[] = {
{0x127F, 0xFFFF, 0xFFFF, 0xFFFF, "Fujifilm(0x127F)"},
}; /* pci_vid_127F[] */

static pci_id_t const pci_vid_1280[] = {
{0x1280, 0xFFFF, 0xFFFF, 0xFFFF, "Photoscript Group Ltd.(0x1280)"},
}; /* pci_vid_1280[] */

static pci_id_t const pci_vid_1281[] = {
{0x1281, 0xFFFF, 0xFFFF, 0xFFFF, "Yokogawa Electric Corporation(0x1281)"},
}; /* pci_vid_1281[] */

static pci_id_t const pci_vid_1282[] = {
{0x1282, 0xFFFF, 0xFFFF, 0xFFFF, "Davicom Semiconductor, Inc.(0x1282)"},
{0x1282, 0x6585, 0xFFFF, 0xFFFF, "DM562P V90 Modem(0x6585)"},
{0x1282, 0x9009, 0xFFFF, 0xFFFF, "DM9009 Ethernet Controller(0x9009)"},
{0x1282, 0x9100, 0xFFFF, 0xFFFF, "21x4x DEC-Tulip compatible 10/100 Ethernet(0x9100)"},
{0x1282, 0x9102, 0xFFFF, 0xFFFF, "DM9102 Fast Ethernet Controller(0x9102)"},
{0x1282, 0x9102, 0x0291, 0x8212, "DM9102A (DM9102AE, SM9102AF) Ethernet 100/10 MBit(0x0291-0x8212)"},
{0x1282, 0x9132, 0xFFFF, 0xFFFF, "Ethernet 100/10 MBit(0x9132)"},
}; /* pci_vid_1282[] */

static pci_id_t const pci_vid_1283[] = {
{0x1283, 0xFFFF, 0xFFFF, 0xFFFF, "Integrated Technology Express, Inc.(0x1283)"},
{0x1283, 0x673A, 0xFFFF, 0xFFFF, "IT8330G(0x673A)"},
{0x1283, 0x8152, 0xFFFF, 0xFFFF, "IT8152F/G Advanced RISC-to-PCI Companion Chip(0x8152)"},
{0x1283, 0x8211, 0xFFFF, 0xFFFF, "ITE 8211F Single Channel UDMA 133(0x8211)"},
{0x1283, 0x8211, 0x1043, 0x8138, "P5GD1-VW Mainboard(0x1043-0x8138)"},
{0x1283, 0x8212, 0xFFFF, 0xFFFF, "IT8212 Dual channel ATA RAID controller(0x8212)"},
{0x1283, 0x8212, 0x1283, 0x0001, "IT/ITE8212 Dual channel ATA RAID controller(0x1283-0x0001)"},
{0x1283, 0x8213, 0xFFFF, 0xFFFF, "IT8213 IDE Controller(0x8213)"},
{0x1283, 0x8213, 0x1458, 0xB000, "GA-EG45M-DS2H Mainboard(0x1458-0xB000)"},
{0x1283, 0x8330, 0xFFFF, 0xFFFF, "IT8330G(0x8330)"},
{0x1283, 0x8872, 0xFFFF, 0xFFFF, "IT887xF PCI to ISA I/O chip with SMB, GPIO, Serial or Parallel Port(0x8872)"},
{0x1283, 0x8888, 0xFFFF, 0xFFFF, "IT8888F/G PCI to ISA Bridge with SMB [Golden Gate](0x8888)"},
{0x1283, 0x8889, 0xFFFF, 0xFFFF, "IT8889F PCI to ISA Bridge(0x8889)"},
{0x1283, 0x8892, 0xFFFF, 0xFFFF, "IT8892E PCIe to PCI Bridge(0x8892)"},
{0x1283, 0x8892, 0x8086, 0x200D, "DH61CR motherboard(0x8086-0x200D)"},
{0x1283, 0x8893, 0xFFFF, 0xFFFF, "IT8893E PCIe to PCI Bridge(0x8893)"},
{0x1283, 0xE886, 0xFFFF, 0xFFFF, "IT8330G(0xE886)"},
}; /* pci_vid_1283[] */

static pci_id_t const pci_vid_1284[] = {
{0x1284, 0xFFFF, 0xFFFF, 0xFFFF, "Sahara Networks, Inc.(0x1284)"},
}; /* pci_vid_1284[] */

static pci_id_t const pci_vid_1285[] = {
{0x1285, 0xFFFF, 0xFFFF, 0xFFFF, "Platform Technologies, Inc.(0x1285)"},
{0x1285, 0x0100, 0xFFFF, 0xFFFF, "AGOGO sound chip (aka ESS Maestro 1)(0x0100)"},
}; /* pci_vid_1285[] */

static pci_id_t const pci_vid_1286[] = {
{0x1286, 0xFFFF, 0xFFFF, 0xFFFF, "Mazet GmbH(0x1286)"},
}; /* pci_vid_1286[] */

static pci_id_t const pci_vid_1287[] = {
{0x1287, 0xFFFF, 0xFFFF, 0xFFFF, "M-Pact, Inc.(0x1287)"},
{0x1287, 0x001E, 0xFFFF, 0xFFFF, "LS220D DVD Decoder(0x001E)"},
{0x1287, 0x001F, 0xFFFF, 0xFFFF, "LS220C DVD Decoder(0x001F)"},
}; /* pci_vid_1287[] */

static pci_id_t const pci_vid_1288[] = {
{0x1288, 0xFFFF, 0xFFFF, 0xFFFF, "Timestep Corporation(0x1288)"},
}; /* pci_vid_1288[] */

static pci_id_t const pci_vid_1289[] = {
{0x1289, 0xFFFF, 0xFFFF, 0xFFFF, "AVC Technology, Inc.(0x1289)"},
}; /* pci_vid_1289[] */

static pci_id_t const pci_vid_128A[] = {
{0x128A, 0xFFFF, 0xFFFF, 0xFFFF, "Asante Technologies, Inc.(0x128A)"},
}; /* pci_vid_128A[] */

static pci_id_t const pci_vid_128B[] = {
{0x128B, 0xFFFF, 0xFFFF, 0xFFFF, "Transwitch Corporation(0x128B)"},
}; /* pci_vid_128B[] */

static pci_id_t const pci_vid_128C[] = {
{0x128C, 0xFFFF, 0xFFFF, 0xFFFF, "Retix Corporation(0x128C)"},
}; /* pci_vid_128C[] */

static pci_id_t const pci_vid_128D[] = {
{0x128D, 0xFFFF, 0xFFFF, 0xFFFF, "G2 Networks, Inc.(0x128D)"},
{0x128D, 0x0021, 0xFFFF, 0xFFFF, "ATM155 Adapter(0x0021)"},
}; /* pci_vid_128D[] */

static pci_id_t const pci_vid_128E[] = {
{0x128E, 0xFFFF, 0xFFFF, 0xFFFF, "Hoontech Corporation/Samho Multi Tech Ltd.(0x128E)"},
{0x128E, 0x0008, 0xFFFF, 0xFFFF, "ST128 WSS/SB(0x0008)"},
{0x128E, 0x0009, 0xFFFF, 0xFFFF, "ST128 SAM9407(0x0009)"},
{0x128E, 0x000A, 0xFFFF, 0xFFFF, "ST128 Game Port(0x000A)"},
{0x128E, 0x000B, 0xFFFF, 0xFFFF, "ST128 MPU Port(0x000B)"},
{0x128E, 0x000C, 0xFFFF, 0xFFFF, "ST128 Ctrl Port(0x000C)"},
}; /* pci_vid_128E[] */

static pci_id_t const pci_vid_128F[] = {
{0x128F, 0xFFFF, 0xFFFF, 0xFFFF, "Tateno Dennou, Inc.(0x128F)"},
}; /* pci_vid_128F[] */

static pci_id_t const pci_vid_1290[] = {
{0x1290, 0xFFFF, 0xFFFF, 0xFFFF, "Sord Computer Corporation(0x1290)"},
}; /* pci_vid_1290[] */

static pci_id_t const pci_vid_1291[] = {
{0x1291, 0xFFFF, 0xFFFF, 0xFFFF, "NCS Computer Italia(0x1291)"},
}; /* pci_vid_1291[] */

static pci_id_t const pci_vid_1292[] = {
{0x1292, 0xFFFF, 0xFFFF, 0xFFFF, "Tritech Microelectronics Inc(0x1292)"},
{0x1292, 0xFC02, 0xFFFF, 0xFFFF, "Pyramid3D TR25202(0xFC02)"},
}; /* pci_vid_1292[] */

static pci_id_t const pci_vid_1293[] = {
{0x1293, 0xFFFF, 0xFFFF, 0xFFFF, "Media Reality Technology(0x1293)"},
}; /* pci_vid_1293[] */

static pci_id_t const pci_vid_1294[] = {
{0x1294, 0xFFFF, 0xFFFF, 0xFFFF, "Rhetorex, Inc.(0x1294)"},
}; /* pci_vid_1294[] */

static pci_id_t const pci_vid_1295[] = {
{0x1295, 0xFFFF, 0xFFFF, 0xFFFF, "Imagenation Corporation(0x1295)"},
{0x1295, 0x0800, 0xFFFF, 0xFFFF, "PXR800(0x0800)"},
{0x1295, 0x1000, 0xFFFF, 0xFFFF, "PXD1000(0x1000)"},
}; /* pci_vid_1295[] */

static pci_id_t const pci_vid_1296[] = {
{0x1296, 0xFFFF, 0xFFFF, 0xFFFF, "Kofax Image Products(0x1296)"},
}; /* pci_vid_1296[] */

static pci_id_t const pci_vid_1297[] = {
{0x1297, 0xFFFF, 0xFFFF, 0xFFFF, "Holco Enterprise Co, Ltd/Shuttle Computer(0x1297)"},
{0x1297, 0x9602, 0xFFFF, 0xFFFF, "RS780/RS880 PCI to PCI bridge (int gfx)(0x9602)"},
}; /* pci_vid_1297[] */

static pci_id_t const pci_vid_1298[] = {
{0x1298, 0xFFFF, 0xFFFF, 0xFFFF, "Spellcaster Telecommunications Inc.(0x1298)"},
}; /* pci_vid_1298[] */

static pci_id_t const pci_vid_1299[] = {
{0x1299, 0xFFFF, 0xFFFF, 0xFFFF, "Knowledge Technology Lab.(0x1299)"},
}; /* pci_vid_1299[] */

static pci_id_t const pci_vid_129A[] = {
{0x129A, 0xFFFF, 0xFFFF, 0xFFFF, "VMetro, inc.(0x129A)"},
{0x129A, 0x0615, 0xFFFF, 0xFFFF, "PBT-615 PCI-X Bus Analyzer(0x0615)"},
{0x129A, 0x0715, 0xFFFF, 0xFFFF, "cPCI Bus Analyzer(0x0715)"},
{0x129A, 0x1100, 0xFFFF, 0xFFFF, "PMC-FPGA05(0x1100)"},
{0x129A, 0x1106, 0xFFFF, 0xFFFF, "XMC-FPGA05F, PCI interface(0x1106)"},
{0x129A, 0x1107, 0xFFFF, 0xFFFF, "XMC-FPGA05F, PCIe interface(0x1107)"},
{0x129A, 0x1108, 0xFFFF, 0xFFFF, "XMC-FPGA05D, PCI interface(0x1108)"},
{0x129A, 0x1109, 0xFFFF, 0xFFFF, "XMC-FPGA05D, PCIe interface(0x1109)"},
}; /* pci_vid_129A[] */

static pci_id_t const pci_vid_129B[] = {
{0x129B, 0xFFFF, 0xFFFF, 0xFFFF, "Image Access(0x129B)"},
}; /* pci_vid_129B[] */

static pci_id_t const pci_vid_129C[] = {
{0x129C, 0xFFFF, 0xFFFF, 0xFFFF, "Jaycor(0x129C)"},
}; /* pci_vid_129C[] */

static pci_id_t const pci_vid_129D[] = {
{0x129D, 0xFFFF, 0xFFFF, 0xFFFF, "Compcore Multimedia, Inc.(0x129D)"},
}; /* pci_vid_129D[] */

static pci_id_t const pci_vid_129E[] = {
{0x129E, 0xFFFF, 0xFFFF, 0xFFFF, "Victor Company of Japan, Ltd.(0x129E)"},
}; /* pci_vid_129E[] */

static pci_id_t const pci_vid_129F[] = {
{0x129F, 0xFFFF, 0xFFFF, 0xFFFF, "OEC Medical Systems, Inc.(0x129F)"},
}; /* pci_vid_129F[] */

static pci_id_t const pci_vid_12A0[] = {
{0x12A0, 0xFFFF, 0xFFFF, 0xFFFF, "Allen-Bradley Company(0x12A0)"},
}; /* pci_vid_12A0[] */

static pci_id_t const pci_vid_12A1[] = {
{0x12A1, 0xFFFF, 0xFFFF, 0xFFFF, "Simpact Associates, Inc.(0x12A1)"},
}; /* pci_vid_12A1[] */

static pci_id_t const pci_vid_12A2[] = {
{0x12A2, 0xFFFF, 0xFFFF, 0xFFFF, "Newgen Systems Corporation(0x12A2)"},
}; /* pci_vid_12A2[] */

static pci_id_t const pci_vid_12A3[] = {
{0x12A3, 0xFFFF, 0xFFFF, 0xFFFF, "Lucent Technologies(0x12A3)"},
{0x12A3, 0x8105, 0xFFFF, 0xFFFF, "T8105 H100 Digital Switch(0x8105)"},
}; /* pci_vid_12A3[] */

static pci_id_t const pci_vid_12A4[] = {
{0x12A4, 0xFFFF, 0xFFFF, 0xFFFF, "NTT Innovative Devices Corporation(0x12A4)"},
}; /* pci_vid_12A4[] */

static pci_id_t const pci_vid_12A5[] = {
{0x12A5, 0xFFFF, 0xFFFF, 0xFFFF, "Vision Dynamics Ltd.(0x12A5)"},
}; /* pci_vid_12A5[] */

static pci_id_t const pci_vid_12A6[] = {
{0x12A6, 0xFFFF, 0xFFFF, 0xFFFF, "Scalable Networks, Inc.(0x12A6)"},
}; /* pci_vid_12A6[] */

static pci_id_t const pci_vid_12A7[] = {
{0x12A7, 0xFFFF, 0xFFFF, 0xFFFF, "AMO GmbH(0x12A7)"},
}; /* pci_vid_12A7[] */

static pci_id_t const pci_vid_12A8[] = {
{0x12A8, 0xFFFF, 0xFFFF, 0xFFFF, "News Datacom(0x12A8)"},
}; /* pci_vid_12A8[] */

static pci_id_t const pci_vid_12A9[] = {
{0x12A9, 0xFFFF, 0xFFFF, 0xFFFF, "Xiotech Corporation(0x12A9)"},
}; /* pci_vid_12A9[] */

static pci_id_t const pci_vid_12AA[] = {
{0x12AA, 0xFFFF, 0xFFFF, 0xFFFF, "SDL Communications, Inc.(0x12AA)"},
}; /* pci_vid_12AA[] */

static pci_id_t const pci_vid_12AB[] = {
{0x12AB, 0xFFFF, 0xFFFF, 0xFFFF, "YUAN High-Tech Development Co., Ltd.(0x12AB)"},
{0x12AB, 0x0000, 0xFFFF, 0xFFFF, "MPG160/Kuroutoshikou ITVC15-STVLP(0x0000)"},
{0x12AB, 0x0002, 0xFFFF, 0xFFFF, "AU8830 [Vortex2] Based Sound Card With A3D Support(0x0002)"},
{0x12AB, 0x0003, 0xFFFF, 0xFFFF, "T507 (DVB-T) TV tuner/capture device(0x0003)"},
{0x12AB, 0x2300, 0xFFFF, 0xFFFF, "Club-3D Zap TV2100(0x2300)"},
{0x12AB, 0x3000, 0xFFFF, 0xFFFF, "MPG-200C PCI DVD Decoder Card(0x3000)"},
{0x12AB, 0x4789, 0xFFFF, 0xFFFF, "MPC788 MiniPCI Hybrid TV Tuner(0x4789)"},
{0x12AB, 0xFFF3, 0xFFFF, 0xFFFF, "MPG600/Kuroutoshikou ITVC16-STVLP(0xFFF3)"},
{0x12AB, 0xFFFF, 0xFFFF, 0xFFFF, "MPG600/Kuroutoshikou ITVC16-STVLP(0xFFFF)"},
}; /* pci_vid_12AB[] */

static pci_id_t const pci_vid_12AC[] = {
{0x12AC, 0xFFFF, 0xFFFF, 0xFFFF, "Measurex Corporation(0x12AC)"},
}; /* pci_vid_12AC[] */

static pci_id_t const pci_vid_12AD[] = {
{0x12AD, 0xFFFF, 0xFFFF, 0xFFFF, "Multidata GmbH(0x12AD)"},
}; /* pci_vid_12AD[] */

static pci_id_t const pci_vid_12AE[] = {
{0x12AE, 0xFFFF, 0xFFFF, 0xFFFF, "Alteon Networks Inc.(0x12AE)"},
{0x12AE, 0x0001, 0xFFFF, 0xFFFF, "AceNIC Gigabit Ethernet(0x0001)"},
{0x12AE, 0x0001, 0x1014, 0x0104, "Gigabit Ethernet-SX PCI Adapter(0x1014-0x0104)"},
{0x12AE, 0x0001, 0x12AE, 0x0001, "Gigabit Ethernet-SX (Universal)(0x12AE-0x0001)"},
{0x12AE, 0x0002, 0xFFFF, 0xFFFF, "AceNIC Gigabit Ethernet (Copper)(0x0002)"},
{0x12AE, 0x0002, 0x10A9, 0x8002, "Acenic Gigabit Ethernet(0x10A9-0x8002)"},
{0x12AE, 0x0002, 0x12AE, 0x0002, "Gigabit Ethernet-T (3C986-T)(0x12AE-0x0002)"},
{0x12AE, 0x00FA, 0xFFFF, 0xFFFF, "Farallon PN9100-T Gigabit Ethernet(0x00FA)"},
}; /* pci_vid_12AE[] */

static pci_id_t const pci_vid_12AF[] = {
{0x12AF, 0xFFFF, 0xFFFF, 0xFFFF, "TDK Corporation(0x12AF)"},
{0x12AF, 0x5831, 0xFFFF, 0xFFFF, "GBDriver GX1 x2 NVMe SSD Controller (DRAM-less)(0x5831)"},
}; /* pci_vid_12AF[] */

static pci_id_t const pci_vid_12B0[] = {
{0x12B0, 0xFFFF, 0xFFFF, 0xFFFF, "Jorge Scientific Corp(0x12B0)"},
}; /* pci_vid_12B0[] */

static pci_id_t const pci_vid_12B1[] = {
{0x12B1, 0xFFFF, 0xFFFF, 0xFFFF, "GammaLink(0x12B1)"},
}; /* pci_vid_12B1[] */

static pci_id_t const pci_vid_12B2[] = {
{0x12B2, 0xFFFF, 0xFFFF, 0xFFFF, "General Signal Networks(0x12B2)"},
}; /* pci_vid_12B2[] */

static pci_id_t const pci_vid_12B3[] = {
{0x12B3, 0xFFFF, 0xFFFF, 0xFFFF, "Inter-Face Co Ltd(0x12B3)"},
}; /* pci_vid_12B3[] */

static pci_id_t const pci_vid_12B4[] = {
{0x12B4, 0xFFFF, 0xFFFF, 0xFFFF, "FutureTel Inc(0x12B4)"},
}; /* pci_vid_12B4[] */

static pci_id_t const pci_vid_12B5[] = {
{0x12B5, 0xFFFF, 0xFFFF, 0xFFFF, "Granite Systems Inc.(0x12B5)"},
}; /* pci_vid_12B5[] */

static pci_id_t const pci_vid_12B6[] = {
{0x12B6, 0xFFFF, 0xFFFF, 0xFFFF, "Natural Microsystems(0x12B6)"},
}; /* pci_vid_12B6[] */

static pci_id_t const pci_vid_12B7[] = {
{0x12B7, 0xFFFF, 0xFFFF, 0xFFFF, "Cognex Corporation(0x12B7)"},
}; /* pci_vid_12B7[] */

static pci_id_t const pci_vid_12B8[] = {
{0x12B8, 0xFFFF, 0xFFFF, 0xFFFF, "Korg(0x12B8)"},
}; /* pci_vid_12B8[] */

static pci_id_t const pci_vid_12B9[] = {
{0x12B9, 0xFFFF, 0xFFFF, 0xFFFF, "3Com Corp, Modem Division(0x12B9)"},
{0x12B9, 0x1006, 0xFFFF, 0xFFFF, "WinModem(0x1006)"},
{0x12B9, 0x1006, 0x12B9, 0x005C, "USR 56k Internal Voice WinModem (Model 3472)(0x12B9-0x005C)"},
{0x12B9, 0x1006, 0x12B9, 0x005E, "USR 56k Internal WinModem (Models 662975)(0x12B9-0x005E)"},
{0x12B9, 0x1006, 0x12B9, 0x0062, "USR 56k Internal Voice WinModem (Model 662978)(0x12B9-0x0062)"},
{0x12B9, 0x1006, 0x12B9, 0x0068, "USR 56k Internal Voice WinModem (Model 5690)(0x12B9-0x0068)"},
{0x12B9, 0x1006, 0x12B9, 0x007A, "USR 56k Internal Voice WinModem (Model 662974)(0x12B9-0x007A)"},
{0x12B9, 0x1006, 0x12B9, 0x007F, "USR 56k Internal WinModem (Models 5698, 5699)(0x12B9-0x007F)"},
{0x12B9, 0x1006, 0x12B9, 0x0080, "USR 56k Internal WinModem (Models 2975, 3528)(0x12B9-0x0080)"},
{0x12B9, 0x1006, 0x12B9, 0x0081, "USR 56k Internal Voice WinModem (Models 2974, 3529)(0x12B9-0x0081)"},
{0x12B9, 0x1006, 0x12B9, 0x0091, "USR 56k Internal Voice WinModem (Model 2978)(0x12B9-0x0091)"},
{0x12B9, 0x1007, 0xFFFF, 0xFFFF, "USR 56k Internal WinModem(0x1007)"},
{0x12B9, 0x1007, 0x12B9, 0x00A3, "USR 56k Internal WinModem (Model 3595)(0x12B9-0x00A3)"},
{0x12B9, 0x1007, 0x12B9, 0x00C4, "U.S. Robotics V.92 Voice Faxmodem (2884A/B/C)(0x12B9-0x00C4)"},
{0x12B9, 0x1008, 0xFFFF, 0xFFFF, "56K FaxModem Model 5610(0x1008)"},
{0x12B9, 0x1008, 0x12B9, 0x00A2, "USR 56k Internal FAX Modem (Model 2977)(0x12B9-0x00A2)"},
{0x12B9, 0x1008, 0x12B9, 0x00AA, "USR 56k Internal Voice Modem (Model 2976)(0x12B9-0x00AA)"},
{0x12B9, 0x1008, 0x12B9, 0x00AB, "USR 56k Internal Voice Modem (Model 5609)(0x12B9-0x00AB)"},
{0x12B9, 0x1008, 0x12B9, 0x00AC, "USR 56k Internal Voice Modem (Model 3298)(0x12B9-0x00AC)"},
{0x12B9, 0x1008, 0x12B9, 0x00AD, "USR 56k Internal FAX Modem (Model 5610)(0x12B9-0x00AD)"},
{0x12B9, 0x1008, 0x12B9, 0x00D3, "USR 56K Internal V92 FAX Modem (Model 5610)(0x12B9-0x00D3)"},
{0x12B9, 0x1008, 0x12B9, 0xBABA, "USR 56K Internal Voice Modem 3CP3298-DEL (Model 5601) [Hawk](0x12B9-0xBABA)"},
}; /* pci_vid_12B9[] */

static pci_id_t const pci_vid_12BA[] = {
{0x12BA, 0xFFFF, 0xFFFF, 0xFFFF, "BittWare, Inc.(0x12BA)"},
}; /* pci_vid_12BA[] */

static pci_id_t const pci_vid_12BB[] = {
{0x12BB, 0xFFFF, 0xFFFF, 0xFFFF, "Nippon Unisoft Corporation(0x12BB)"},
}; /* pci_vid_12BB[] */

static pci_id_t const pci_vid_12BC[] = {
{0x12BC, 0xFFFF, 0xFFFF, 0xFFFF, "Array Microsystems(0x12BC)"},
}; /* pci_vid_12BC[] */

static pci_id_t const pci_vid_12BD[] = {
{0x12BD, 0xFFFF, 0xFFFF, 0xFFFF, "Computerm Corp.(0x12BD)"},
}; /* pci_vid_12BD[] */

static pci_id_t const pci_vid_12BE[] = {
{0x12BE, 0xFFFF, 0xFFFF, 0xFFFF, "Anchor Chips Inc.(0x12BE)"},
{0x12BE, 0x3041, 0xFFFF, 0xFFFF, "AN3041Q CO-MEM(0x3041)"},
{0x12BE, 0x3042, 0xFFFF, 0xFFFF, "AN3042Q CO-MEM Lite(0x3042)"},
{0x12BE, 0x3042, 0x12BE, 0x3042, "Anchor Chips Lite Evaluation Board(0x12BE-0x3042)"},
}; /* pci_vid_12BE[] */

static pci_id_t const pci_vid_12BF[] = {
{0x12BF, 0xFFFF, 0xFFFF, 0xFFFF, "Fujifilm Microdevices(0x12BF)"},
}; /* pci_vid_12BF[] */

static pci_id_t const pci_vid_12C0[] = {
{0x12C0, 0xFFFF, 0xFFFF, 0xFFFF, "Infimed(0x12C0)"},
}; /* pci_vid_12C0[] */

static pci_id_t const pci_vid_12C1[] = {
{0x12C1, 0xFFFF, 0xFFFF, 0xFFFF, "GMM Research Corp(0x12C1)"},
}; /* pci_vid_12C1[] */

static pci_id_t const pci_vid_12C2[] = {
{0x12C2, 0xFFFF, 0xFFFF, 0xFFFF, "Mentec Limited(0x12C2)"},
}; /* pci_vid_12C2[] */

static pci_id_t const pci_vid_12C3[] = {
{0x12C3, 0xFFFF, 0xFFFF, 0xFFFF, "Holtek Microelectronics Inc(0x12C3)"},
{0x12C3, 0x0058, 0xFFFF, 0xFFFF, "PCI NE2K Ethernet(0x0058)"},
{0x12C3, 0x5598, 0xFFFF, 0xFFFF, "PCI NE2K Ethernet(0x5598)"},
}; /* pci_vid_12C3[] */

static pci_id_t const pci_vid_12C4[] = {
{0x12C4, 0xFFFF, 0xFFFF, 0xFFFF, "Connect Tech Inc(0x12C4)"},
{0x12C4, 0x0001, 0xFFFF, 0xFFFF, "Blue HEAT/PCI 8 (RS232/CL/RJ11)(0x0001)"},
{0x12C4, 0x0002, 0xFFFF, 0xFFFF, "Blue HEAT/PCI 4 (RS232)(0x0002)"},
{0x12C4, 0x0003, 0xFFFF, 0xFFFF, "Blue HEAT/PCI 2 (RS232)(0x0003)"},
{0x12C4, 0x0004, 0xFFFF, 0xFFFF, "Blue HEAT/PCI 8 (UNIV, RS485)(0x0004)"},
{0x12C4, 0x0005, 0xFFFF, 0xFFFF, "Blue HEAT/PCI 4+4/6+2 (UNIV, RS232/485)(0x0005)"},
{0x12C4, 0x0006, 0xFFFF, 0xFFFF, "Blue HEAT/PCI 4 (OPTO, RS485)(0x0006)"},
{0x12C4, 0x0007, 0xFFFF, 0xFFFF, "Blue HEAT/PCI 2+2 (RS232/485)(0x0007)"},
{0x12C4, 0x0008, 0xFFFF, 0xFFFF, "Blue HEAT/PCI 2 (OPTO, Tx, RS485)(0x0008)"},
{0x12C4, 0x0009, 0xFFFF, 0xFFFF, "Blue HEAT/PCI 2+6 (RS232/485)(0x0009)"},
{0x12C4, 0x000A, 0xFFFF, 0xFFFF, "Blue HEAT/PCI 8 (Tx, RS485)(0x000A)"},
{0x12C4, 0x000B, 0xFFFF, 0xFFFF, "Blue HEAT/PCI 4 (Tx, RS485)(0x000B)"},
{0x12C4, 0x000C, 0xFFFF, 0xFFFF, "Blue HEAT/PCI 2 (20 MHz, RS485)(0x000C)"},
{0x12C4, 0x000D, 0xFFFF, 0xFFFF, "Blue HEAT/PCI 2 PTM(0x000D)"},
{0x12C4, 0x0100, 0xFFFF, 0xFFFF, "NT960/PCI(0x0100)"},
{0x12C4, 0x0201, 0xFFFF, 0xFFFF, "cPCI Titan - 2 Port(0x0201)"},
{0x12C4, 0x0202, 0xFFFF, 0xFFFF, "cPCI Titan - 4 Port(0x0202)"},
{0x12C4, 0x0300, 0xFFFF, 0xFFFF, "CTI PCI UART 2 (RS232)(0x0300)"},
{0x12C4, 0x0301, 0xFFFF, 0xFFFF, "CTI PCI UART 4 (RS232)(0x0301)"},
{0x12C4, 0x0302, 0xFFFF, 0xFFFF, "CTI PCI UART 8 (RS232)(0x0302)"},
{0x12C4, 0x0310, 0xFFFF, 0xFFFF, "CTI PCI UART 1+1 (RS232/485)(0x0310)"},
{0x12C4, 0x0311, 0xFFFF, 0xFFFF, "CTI PCI UART 2+2 (RS232/485)(0x0311)"},
{0x12C4, 0x0312, 0xFFFF, 0xFFFF, "CTI PCI UART 4+4 (RS232/485)(0x0312)"},
{0x12C4, 0x0320, 0xFFFF, 0xFFFF, "CTI PCI UART 2(0x0320)"},
{0x12C4, 0x0321, 0xFFFF, 0xFFFF, "CTI PCI UART 4(0x0321)"},
{0x12C4, 0x0322, 0xFFFF, 0xFFFF, "CTI PCI UART 8(0x0322)"},
{0x12C4, 0x0330, 0xFFFF, 0xFFFF, "CTI PCI UART 2 (RS485)(0x0330)"},
{0x12C4, 0x0331, 0xFFFF, 0xFFFF, "CTI PCI UART 4 (RS485)(0x0331)"},
{0x12C4, 0x0332, 0xFFFF, 0xFFFF, "CTI PCI UART 8 (RS485)(0x0332)"},
}; /* pci_vid_12C4[] */

static pci_id_t const pci_vid_12C5[] = {
{0x12C5, 0xFFFF, 0xFFFF, 0xFFFF, "Picture Elements Incorporated(0x12C5)"},
{0x12C5, 0x007E, 0xFFFF, 0xFFFF, "Imaging/Scanning Subsystem Engine(0x007E)"},
{0x12C5, 0x007F, 0xFFFF, 0xFFFF, "Imaging/Scanning Subsystem Engine(0x007F)"},
{0x12C5, 0x0081, 0xFFFF, 0xFFFF, "PCIVST [Grayscale Thresholding Engine](0x0081)"},
{0x12C5, 0x0085, 0xFFFF, 0xFFFF, "Video Simulator/Sender(0x0085)"},
{0x12C5, 0x0086, 0xFFFF, 0xFFFF, "THR2 Multi-scale Thresholder(0x0086)"},
}; /* pci_vid_12C5[] */

static pci_id_t const pci_vid_12C6[] = {
{0x12C6, 0xFFFF, 0xFFFF, 0xFFFF, "Mitani Corporation(0x12C6)"},
}; /* pci_vid_12C6[] */

static pci_id_t const pci_vid_12C7[] = {
{0x12C7, 0xFFFF, 0xFFFF, 0xFFFF, "Dialogic Corp(0x12C7)"},
{0x12C7, 0x0546, 0xFFFF, 0xFFFF, "Springware D/120JCT-LS(0x0546)"},
{0x12C7, 0x0647, 0xFFFF, 0xFFFF, "Springware D/240JCT-T1(0x0647)"},
{0x12C7, 0x0676, 0xFFFF, 0xFFFF, "Springware D/41JCT-LS(0x0676)"},
{0x12C7, 0x0685, 0xFFFF, 0xFFFF, "Springware D/480JCT-2T1(0x0685)"},
}; /* pci_vid_12C7[] */

static pci_id_t const pci_vid_12C8[] = {
{0x12C8, 0xFFFF, 0xFFFF, 0xFFFF, "G Force Co, Ltd(0x12C8)"},
}; /* pci_vid_12C8[] */

static pci_id_t const pci_vid_12C9[] = {
{0x12C9, 0xFFFF, 0xFFFF, 0xFFFF, "Gigi Operations(0x12C9)"},
}; /* pci_vid_12C9[] */

static pci_id_t const pci_vid_12CA[] = {
{0x12CA, 0xFFFF, 0xFFFF, 0xFFFF, "Integrated Computing Engines(0x12CA)"},
}; /* pci_vid_12CA[] */

static pci_id_t const pci_vid_12CB[] = {
{0x12CB, 0xFFFF, 0xFFFF, 0xFFFF, "Antex Electronics Corporation(0x12CB)"},
{0x12CB, 0x0027, 0xFFFF, 0xFFFF, "SC4 (StudioCard)(0x0027)"},
{0x12CB, 0x002E, 0xFFFF, 0xFFFF, "StudioCard 2000(0x002E)"},
}; /* pci_vid_12CB[] */

static pci_id_t const pci_vid_12CC[] = {
{0x12CC, 0xFFFF, 0xFFFF, 0xFFFF, "Pluto Technologies International(0x12CC)"},
}; /* pci_vid_12CC[] */

static pci_id_t const pci_vid_12CD[] = {
{0x12CD, 0xFFFF, 0xFFFF, 0xFFFF, "Aims Lab(0x12CD)"},
}; /* pci_vid_12CD[] */

static pci_id_t const pci_vid_12CE[] = {
{0x12CE, 0xFFFF, 0xFFFF, 0xFFFF, "Netspeed Inc.(0x12CE)"},
}; /* pci_vid_12CE[] */

static pci_id_t const pci_vid_12CF[] = {
{0x12CF, 0xFFFF, 0xFFFF, 0xFFFF, "Prophet Systems, Inc.(0x12CF)"},
}; /* pci_vid_12CF[] */

static pci_id_t const pci_vid_12D0[] = {
{0x12D0, 0xFFFF, 0xFFFF, 0xFFFF, "GDE Systems, Inc.(0x12D0)"},
}; /* pci_vid_12D0[] */

static pci_id_t const pci_vid_12D1[] = {
{0x12D1, 0xFFFF, 0xFFFF, 0xFFFF, "PSITech(0x12D1)"},
}; /* pci_vid_12D1[] */

static pci_id_t const pci_vid_12D2[] = {
{0x12D2, 0xFFFF, 0xFFFF, 0xFFFF, "NVidia / SGS Thomson (Joint Venture)(0x12D2)"},
{0x12D2, 0x0008, 0xFFFF, 0xFFFF, "NV1(0x0008)"},
{0x12D2, 0x0009, 0xFFFF, 0xFFFF, "DAC64(0x0009)"},
{0x12D2, 0x0018, 0xFFFF, 0xFFFF, "Riva128(0x0018)"},
{0x12D2, 0x0018, 0x1048, 0x0C10, "VICTORY Erazor(0x1048-0x0C10)"},
{0x12D2, 0x0018, 0x1048, 0x0C15, "VICTORY Erazor LT-8(0x1048-0x0C15)"},
{0x12D2, 0x0018, 0x107B, 0x8030, "STB Velocity 128(0x107B-0x8030)"},
{0x12D2, 0x0018, 0x1092, 0x0350, "Viper V330(0x1092-0x0350)"},
{0x12D2, 0x0018, 0x1092, 0x1092, "Viper V330(0x1092-0x1092)"},
{0x12D2, 0x0018, 0x10B4, 0x1B1B, "STB Velocity 128(0x10B4-0x1B1B)"},
{0x12D2, 0x0018, 0x10B4, 0x1B1D, "STB Velocity 128(0x10B4-0x1B1D)"},
{0x12D2, 0x0018, 0x10B4, 0x1B1E, "STB Velocity 128, PAL TV-Out(0x10B4-0x1B1E)"},
{0x12D2, 0x0018, 0x10B4, 0x1B20, "STB Velocity 128 Sapphire(0x10B4-0x1B20)"},
{0x12D2, 0x0018, 0x10B4, 0x1B21, "STB Velocity 128(0x10B4-0x1B21)"},
{0x12D2, 0x0018, 0x10B4, 0x1B22, "STB Velocity 128 AGP, NTSC TV-Out(0x10B4-0x1B22)"},
{0x12D2, 0x0018, 0x10B4, 0x1B23, "STB Velocity 128 AGP, PAL TV-Out(0x10B4-0x1B23)"},
{0x12D2, 0x0018, 0x10B4, 0x1B27, "STB Velocity 128 DVD(0x10B4-0x1B27)"},
{0x12D2, 0x0018, 0x10B4, 0x1B88, "MVP Pro 128(0x10B4-0x1B88)"},
{0x12D2, 0x0018, 0x10B4, 0x222A, "STB Velocity 128 AGP(0x10B4-0x222A)"},
{0x12D2, 0x0018, 0x10B4, 0x2230, "STB Velocity 128(0x10B4-0x2230)"},
{0x12D2, 0x0018, 0x10B4, 0x2232, "STB Velocity 128(0x10B4-0x2232)"},
{0x12D2, 0x0018, 0x10B4, 0x2235, "STB Velocity 128 AGP(0x10B4-0x2235)"},
{0x12D2, 0x0018, 0x2A15, 0x54A3, "3DVision-SAGP / 3DexPlorer 3000(0x2A15-0x54A3)"},
{0x12D2, 0x0019, 0xFFFF, 0xFFFF, "Riva128ZX(0x0019)"},
{0x12D2, 0x0020, 0xFFFF, 0xFFFF, "TNT(0x0020)"},
{0x12D2, 0x0028, 0xFFFF, 0xFFFF, "TNT2(0x0028)"},
{0x12D2, 0x0029, 0xFFFF, 0xFFFF, "UTNT2(0x0029)"},
{0x12D2, 0x002C, 0xFFFF, 0xFFFF, "VTNT2(0x002C)"},
{0x12D2, 0x00A0, 0xFFFF, 0xFFFF, "ITNT2(0x00A0)"},
}; /* pci_vid_12D2[] */

static pci_id_t const pci_vid_12D3[] = {
{0x12D3, 0xFFFF, 0xFFFF, 0xFFFF, "Vingmed Sound A/S(0x12D3)"},
}; /* pci_vid_12D3[] */

static pci_id_t const pci_vid_12D4[] = {
{0x12D4, 0xFFFF, 0xFFFF, 0xFFFF, "Ulticom (Formerly DGM&S)(0x12D4)"},
{0x12D4, 0x0200, 0xFFFF, 0xFFFF, "T1 Card(0x0200)"},
}; /* pci_vid_12D4[] */

static pci_id_t const pci_vid_12D5[] = {
{0x12D5, 0xFFFF, 0xFFFF, 0xFFFF, "Equator Technologies Inc(0x12D5)"},
{0x12D5, 0x0003, 0xFFFF, 0xFFFF, "BSP16(0x0003)"},
{0x12D5, 0x1000, 0xFFFF, 0xFFFF, "BSP15(0x1000)"},
}; /* pci_vid_12D5[] */

static pci_id_t const pci_vid_12D6[] = {
{0x12D6, 0xFFFF, 0xFFFF, 0xFFFF, "Analogic Corp(0x12D6)"},
}; /* pci_vid_12D6[] */

static pci_id_t const pci_vid_12D7[] = {
{0x12D7, 0xFFFF, 0xFFFF, 0xFFFF, "Biotronic SRL(0x12D7)"},
}; /* pci_vid_12D7[] */

static pci_id_t const pci_vid_12D8[] = {
{0x12D8, 0xFFFF, 0xFFFF, 0xFFFF, "Pericom Semiconductor(0x12D8)"},
{0x12D8, 0x01A7, 0xFFFF, 0xFFFF, "7C21P100 2-port PCI-X to PCI-X Bridge(0x01A7)"},
{0x12D8, 0x0303, 0xFFFF, 0xFFFF, "PCI Express Switch 3-3(0x0303)"},
{0x12D8, 0x0508, 0xFFFF, 0xFFFF, "PI7C9X20508GP PCI Express Switch 5Port-8Lane(0x0508)"},
{0x12D8, 0x2304, 0xFFFF, 0xFFFF, "PI7C9X2G304 EL/SL PCIe2 3-Port/4-Lane Packet Switch(0x2304)"},
{0x12D8, 0x2308, 0xFFFF, 0xFFFF, "PI7C9X2G308GP 3-Ports/8-lane PCIe 2.0 Switch(0x2308)"},
{0x12D8, 0x2404, 0xFFFF, 0xFFFF, "PI7C9X2G404 EL/SL PCIe2 4-Port/4-Lane Packet Switch(0x2404)"},
{0x12D8, 0x2608, 0xFFFF, 0xFFFF, "PI7C9X2G608GP PCIe2 6-Port/8-Lane Packet Switch(0x2608)"},
{0x12D8, 0x2608, 0xEA50, 0xCC10, "RXi2-BP(0xEA50-0xCC10)"},
{0x12D8, 0x400A, 0xFFFF, 0xFFFF, "PI7C9X442SL PCIe Bridge Port(0x400A)"},
{0x12D8, 0x400C, 0xFFFF, 0xFFFF, "PI7C9X440SL PCIe Bridge Port(0x400C)"},
{0x12D8, 0x400E, 0xFFFF, 0xFFFF, "PI7C9X440SL/PI7C9X442SL USB OHCI Controller(0x400E)"},
{0x12D8, 0x400F, 0xFFFF, 0xFFFF, "PI7C9X440SL/PI7C9X442SL USB EHCI Controller(0x400F)"},
{0x12D8, 0x71E2, 0xFFFF, 0xFFFF, "PI7C7300A/PI7C7300D PCI-to-PCI Bridge(0x71E2)"},
{0x12D8, 0x71E3, 0xFFFF, 0xFFFF, "PI7C7300A/PI7C7300D PCI-to-PCI Bridge (Secondary Bus 2)(0x71E3)"},
{0x12D8, 0x8140, 0xFFFF, 0xFFFF, "PI7C8140A PCI-to-PCI Bridge(0x8140)"},
{0x12D8, 0x8148, 0xFFFF, 0xFFFF, "PI7C8148A/PI7C8148B PCI-to-PCI Bridge(0x8148)"},
{0x12D8, 0x8150, 0xFFFF, 0xFFFF, "PCI to PCI Bridge(0x8150)"},
{0x12D8, 0x8152, 0xFFFF, 0xFFFF, "PI7C8152A/PI7C8152B/PI7C8152BI PCI-to-PCI Bridge(0x8152)"},
{0x12D8, 0x8154, 0xFFFF, 0xFFFF, "PI7C8154A/PI7C8154B/PI7C8154BI PCI-to-PCI Bridge(0x8154)"},
{0x12D8, 0x8619, 0xFFFF, 0xFFFF, "PI7C9X2G1616PR PCIe2 16-Port/16-Lane Packet Switch(0x8619)"},
{0x12D8, 0xB404, 0xFFFF, 0xFFFF, "PI7C9X2G404 EV/SV PCIe2 4-Port/4-Lane Packet Switch(0xB404)"},
{0x12D8, 0xE110, 0xFFFF, 0xFFFF, "PI7C9X110 PCIe- to-PCI bridge(0xE110)"},
{0x12D8, 0xE110, 0x1775, 0x11CC, "CC11/CL11 CompactPCI Bridge(0x1775-0x11CC)"},
{0x12D8, 0xE111, 0xFFFF, 0xFFFF, "PI7C9X111SL PCIe-to-PCI Reversible Bridge(0xE111)"},
{0x12D8, 0xE112, 0xFFFF, 0xFFFF, "PI7C9X112SL PCIe-to-PCI Bridge(0xE112)"},
{0x12D8, 0xE113, 0xFFFF, 0xFFFF, "PI7C9X113SL/PI7C9X118SL PCIe-to-PCI Bridge(0xE113)"},
{0x12D8, 0xE130, 0xFFFF, 0xFFFF, "PCI Express to PCI-XPI7C9X130 PCI-X Bridge(0xE130)"},
}; /* pci_vid_12D8[] */

static pci_id_t const pci_vid_12D9[] = {
{0x12D9, 0xFFFF, 0xFFFF, 0xFFFF, "Aculab PLC(0x12D9)"},
{0x12D9, 0x0002, 0xFFFF, 0xFFFF, "PCI Prosody(0x0002)"},
{0x12D9, 0x0004, 0xFFFF, 0xFFFF, "cPCI Prosody(0x0004)"},
{0x12D9, 0x0005, 0xFFFF, 0xFFFF, "Aculab E1/T1 PCI card(0x0005)"},
{0x12D9, 0x1078, 0xFFFF, 0xFFFF, "Prosody X class e1000 device(0x1078)"},
{0x12D9, 0x1078, 0x12D9, 0x000D, "Prosody X PCI(0x12D9-0x000D)"},
{0x12D9, 0x1078, 0x12D9, 0x000E, "Prosody X cPCI(0x12D9-0x000E)"},
}; /* pci_vid_12D9[] */

static pci_id_t const pci_vid_12DA[] = {
{0x12DA, 0xFFFF, 0xFFFF, 0xFFFF, "True Time Inc.(0x12DA)"},
}; /* pci_vid_12DA[] */

static pci_id_t const pci_vid_12DB[] = {
{0x12DB, 0xFFFF, 0xFFFF, 0xFFFF, "Annapolis Micro Systems, Inc(0x12DB)"},
}; /* pci_vid_12DB[] */

static pci_id_t const pci_vid_12DC[] = {
{0x12DC, 0xFFFF, 0xFFFF, 0xFFFF, "Symicron Computer Communication Ltd.(0x12DC)"},
}; /* pci_vid_12DC[] */

static pci_id_t const pci_vid_12DD[] = {
{0x12DD, 0xFFFF, 0xFFFF, 0xFFFF, "Management Graphics(0x12DD)"},
}; /* pci_vid_12DD[] */

static pci_id_t const pci_vid_12DE[] = {
{0x12DE, 0xFFFF, 0xFFFF, 0xFFFF, "Rainbow Technologies(0x12DE)"},
{0x12DE, 0x0200, 0xFFFF, 0xFFFF, "CryptoSwift CS200(0x0200)"},
}; /* pci_vid_12DE[] */

static pci_id_t const pci_vid_12DF[] = {
{0x12DF, 0xFFFF, 0xFFFF, 0xFFFF, "SBS Technologies Inc(0x12DF)"},
}; /* pci_vid_12DF[] */

static pci_id_t const pci_vid_12E0[] = {
{0x12E0, 0xFFFF, 0xFFFF, 0xFFFF, "Chase Research(0x12E0)"},
{0x12E0, 0x0010, 0xFFFF, 0xFFFF, "ST16C654 Quad UART(0x0010)"},
{0x12E0, 0x0020, 0xFFFF, 0xFFFF, "ST16C654 Quad UART(0x0020)"},
{0x12E0, 0x0030, 0xFFFF, 0xFFFF, "ST16C654 Quad UART(0x0030)"},
}; /* pci_vid_12E0[] */

static pci_id_t const pci_vid_12E1[] = {
{0x12E1, 0xFFFF, 0xFFFF, 0xFFFF, "Nintendo Co, Ltd(0x12E1)"},
}; /* pci_vid_12E1[] */

static pci_id_t const pci_vid_12E2[] = {
{0x12E2, 0xFFFF, 0xFFFF, 0xFFFF, "Datum Inc. Bancomm-Timing Division(0x12E2)"},
}; /* pci_vid_12E2[] */

static pci_id_t const pci_vid_12E3[] = {
{0x12E3, 0xFFFF, 0xFFFF, 0xFFFF, "Imation Corp - Medical Imaging Systems(0x12E3)"},
}; /* pci_vid_12E3[] */

static pci_id_t const pci_vid_12E4[] = {
{0x12E4, 0xFFFF, 0xFFFF, 0xFFFF, "Brooktrout Technology Inc(0x12E4)"},
}; /* pci_vid_12E4[] */

static pci_id_t const pci_vid_12E5[] = {
{0x12E5, 0xFFFF, 0xFFFF, 0xFFFF, "Apex Semiconductor Inc(0x12E5)"},
}; /* pci_vid_12E5[] */

static pci_id_t const pci_vid_12E6[] = {
{0x12E6, 0xFFFF, 0xFFFF, 0xFFFF, "Cirel Systems(0x12E6)"},
}; /* pci_vid_12E6[] */

static pci_id_t const pci_vid_12E7[] = {
{0x12E7, 0xFFFF, 0xFFFF, 0xFFFF, "Sunsgroup Corporation(0x12E7)"},
}; /* pci_vid_12E7[] */

static pci_id_t const pci_vid_12E8[] = {
{0x12E8, 0xFFFF, 0xFFFF, 0xFFFF, "Crisc Corp(0x12E8)"},
}; /* pci_vid_12E8[] */

static pci_id_t const pci_vid_12E9[] = {
{0x12E9, 0xFFFF, 0xFFFF, 0xFFFF, "GE Spacenet(0x12E9)"},
}; /* pci_vid_12E9[] */

static pci_id_t const pci_vid_12EA[] = {
{0x12EA, 0xFFFF, 0xFFFF, 0xFFFF, "Zuken(0x12EA)"},
}; /* pci_vid_12EA[] */

static pci_id_t const pci_vid_12EB[] = {
{0x12EB, 0xFFFF, 0xFFFF, 0xFFFF, "Aureal Semiconductor(0x12EB)"},
{0x12EB, 0x0001, 0xFFFF, 0xFFFF, "Vortex 1(0x0001)"},
{0x12EB, 0x0001, 0x0000, 0x0300, "Terasound A3D PCI(0x0000-0x0300)"},
{0x12EB, 0x0001, 0x104D, 0x8036, "AU8820 Vortex Digital Audio Processor(0x104D-0x8036)"},
{0x12EB, 0x0001, 0x1092, 0x2000, "Sonic Impact A3D(0x1092-0x2000)"},
{0x12EB, 0x0001, 0x1092, 0x2100, "Sonic Impact A3D(0x1092-0x2100)"},
{0x12EB, 0x0001, 0x1092, 0x2110, "Sonic Impact A3D(0x1092-0x2110)"},
{0x12EB, 0x0001, 0x1092, 0x2200, "Sonic Impact A3D(0x1092-0x2200)"},
{0x12EB, 0x0001, 0x122D, 0x1002, "SC 338-A3D(0x122D-0x1002)"},
{0x12EB, 0x0001, 0x12EB, 0x0001, "AU8820 Vortex Digital Audio Processor(0x12EB-0x0001)"},
{0x12EB, 0x0001, 0x5053, 0x3355, "Montego(0x5053-0x3355)"},
{0x12EB, 0x0001, 0x50B2, 0x1111, "XLerate(0x50B2-0x1111)"},
{0x12EB, 0x0002, 0xFFFF, 0xFFFF, "Vortex 2(0x0002)"},
{0x12EB, 0x0002, 0x104D, 0x8049, "AU8830 Vortex 3D Digital Audio Processor(0x104D-0x8049)"},
{0x12EB, 0x0002, 0x104D, 0x807B, "AU8830 Vortex 3D Digital Audio Processor(0x104D-0x807B)"},
{0x12EB, 0x0002, 0x1092, 0x3000, "Monster Sound II(0x1092-0x3000)"},
{0x12EB, 0x0002, 0x1092, 0x3001, "Monster Sound II(0x1092-0x3001)"},
{0x12EB, 0x0002, 0x1092, 0x3002, "Monster Sound II(0x1092-0x3002)"},
{0x12EB, 0x0002, 0x1092, 0x3003, "Monster Sound II(0x1092-0x3003)"},
{0x12EB, 0x0002, 0x1092, 0x3004, "Monster Sound II(0x1092-0x3004)"},
{0x12EB, 0x0002, 0x12EB, 0x0002, "AU8830 Vortex 3D Digital Audio Processor(0x12EB-0x0002)"},
{0x12EB, 0x0002, 0x12EB, 0x0088, "AU8830 Vortex 3D Digital Audio Processor(0x12EB-0x0088)"},
{0x12EB, 0x0002, 0x144D, 0x3510, "AU8830 Vortex 3D Digital Audio Processor(0x144D-0x3510)"},
{0x12EB, 0x0002, 0x5053, 0x3356, "Montego II(0x5053-0x3356)"},
{0x12EB, 0x0003, 0xFFFF, 0xFFFF, "AU8810 Vortex Digital Audio Processor(0x0003)"},
{0x12EB, 0x0003, 0x104D, 0x8049, "AU8810 Vortex Digital Audio Processor(0x104D-0x8049)"},
{0x12EB, 0x0003, 0x104D, 0x8077, "AU8810 Vortex Digital Audio Processor(0x104D-0x8077)"},
{0x12EB, 0x0003, 0x109F, 0x1000, "AU8810 Vortex Digital Audio Processor(0x109F-0x1000)"},
{0x12EB, 0x0003, 0x12EB, 0x0003, "AU8810 Vortex Digital Audio Processor(0x12EB-0x0003)"},
{0x12EB, 0x0003, 0x1462, 0x6780, "AU8810 Vortex Digital Audio Processor(0x1462-0x6780)"},
{0x12EB, 0x0003, 0x14A4, 0x2073, "AU8810 Vortex Digital Audio Processor(0x14A4-0x2073)"},
{0x12EB, 0x0003, 0x14A4, 0x2091, "AU8810 Vortex Digital Audio Processor(0x14A4-0x2091)"},
{0x12EB, 0x0003, 0x14A4, 0x2104, "AU8810 Vortex Digital Audio Processor(0x14A4-0x2104)"},
{0x12EB, 0x0003, 0x14A4, 0x2106, "AU8810 Vortex Digital Audio Processor(0x14A4-0x2106)"},
{0x12EB, 0x8803, 0xFFFF, 0xFFFF, "Vortex 56k Software Modem(0x8803)"},
{0x12EB, 0x8803, 0x12EB, 0x8803, "Vortex 56k Software Modem(0x12EB-0x8803)"},
}; /* pci_vid_12EB[] */

static pci_id_t const pci_vid_12EC[] = {
{0x12EC, 0xFFFF, 0xFFFF, 0xFFFF, "3A International, Inc.(0x12EC)"},
}; /* pci_vid_12EC[] */

static pci_id_t const pci_vid_12ED[] = {
{0x12ED, 0xFFFF, 0xFFFF, 0xFFFF, "Optivision Inc.(0x12ED)"},
}; /* pci_vid_12ED[] */

static pci_id_t const pci_vid_12EE[] = {
{0x12EE, 0xFFFF, 0xFFFF, 0xFFFF, "Orange Micro(0x12EE)"},
}; /* pci_vid_12EE[] */

static pci_id_t const pci_vid_12EF[] = {
{0x12EF, 0xFFFF, 0xFFFF, 0xFFFF, "Vienna Systems(0x12EF)"},
}; /* pci_vid_12EF[] */

static pci_id_t const pci_vid_12F0[] = {
{0x12F0, 0xFFFF, 0xFFFF, 0xFFFF, "Pentek(0x12F0)"},
}; /* pci_vid_12F0[] */

static pci_id_t const pci_vid_12F1[] = {
{0x12F1, 0xFFFF, 0xFFFF, 0xFFFF, "Sorenson Vision Inc(0x12F1)"},
}; /* pci_vid_12F1[] */

static pci_id_t const pci_vid_12F2[] = {
{0x12F2, 0xFFFF, 0xFFFF, 0xFFFF, "Gammagraphx, Inc.(0x12F2)"},
}; /* pci_vid_12F2[] */

static pci_id_t const pci_vid_12F3[] = {
{0x12F3, 0xFFFF, 0xFFFF, 0xFFFF, "Radstone Technology(0x12F3)"},
}; /* pci_vid_12F3[] */

static pci_id_t const pci_vid_12F4[] = {
{0x12F4, 0xFFFF, 0xFFFF, 0xFFFF, "Megatel(0x12F4)"},
}; /* pci_vid_12F4[] */

static pci_id_t const pci_vid_12F5[] = {
{0x12F5, 0xFFFF, 0xFFFF, 0xFFFF, "Forks(0x12F5)"},
}; /* pci_vid_12F5[] */

static pci_id_t const pci_vid_12F6[] = {
{0x12F6, 0xFFFF, 0xFFFF, 0xFFFF, "Dawson France(0x12F6)"},
}; /* pci_vid_12F6[] */

static pci_id_t const pci_vid_12F7[] = {
{0x12F7, 0xFFFF, 0xFFFF, 0xFFFF, "Cognex(0x12F7)"},
}; /* pci_vid_12F7[] */

static pci_id_t const pci_vid_12F8[] = {
{0x12F8, 0xFFFF, 0xFFFF, 0xFFFF, "Electronic Design GmbH(0x12F8)"},
{0x12F8, 0x0002, 0xFFFF, 0xFFFF, "VideoMaker(0x0002)"},
}; /* pci_vid_12F8[] */

static pci_id_t const pci_vid_12F9[] = {
{0x12F9, 0xFFFF, 0xFFFF, 0xFFFF, "Four Fold Ltd(0x12F9)"},
}; /* pci_vid_12F9[] */

static pci_id_t const pci_vid_12FB[] = {
{0x12FB, 0xFFFF, 0xFFFF, 0xFFFF, "Spectrum Signal Processing(0x12FB)"},
{0x12FB, 0x0001, 0xFFFF, 0xFFFF, "PMC-MAI(0x0001)"},
{0x12FB, 0x00F5, 0xFFFF, 0xFFFF, "F5 Dakar(0x00F5)"},
{0x12FB, 0x02AD, 0xFFFF, 0xFFFF, "PMC-2MAI(0x02AD)"},
{0x12FB, 0x2ADC, 0xFFFF, 0xFFFF, "ePMC-2ADC(0x2ADC)"},
{0x12FB, 0x3100, 0xFFFF, 0xFFFF, "PRO-3100(0x3100)"},
{0x12FB, 0x3500, 0xFFFF, 0xFFFF, "PRO-3500(0x3500)"},
{0x12FB, 0x4D4F, 0xFFFF, 0xFFFF, "Modena(0x4D4F)"},
{0x12FB, 0x8120, 0xFFFF, 0xFFFF, "ePMC-8120(0x8120)"},
{0x12FB, 0xDA62, 0xFFFF, 0xFFFF, "Daytona C6201 PCI (Hurricane)(0xDA62)"},
{0x12FB, 0xDB62, 0xFFFF, 0xFFFF, "Ingliston XBIF(0xDB62)"},
{0x12FB, 0xDC62, 0xFFFF, 0xFFFF, "Ingliston PLX9054(0xDC62)"},
{0x12FB, 0xDD62, 0xFFFF, 0xFFFF, "Ingliston JTAG/ISP(0xDD62)"},
{0x12FB, 0xEDDC, 0xFFFF, 0xFFFF, "ePMC-MSDDC(0xEDDC)"},
{0x12FB, 0xFA01, 0xFFFF, 0xFFFF, "ePMC-FPGA(0xFA01)"},
}; /* pci_vid_12FB[] */

static pci_id_t const pci_vid_12FC[] = {
{0x12FC, 0xFFFF, 0xFFFF, 0xFFFF, "Capital Equipment Corp(0x12FC)"},
}; /* pci_vid_12FC[] */

static pci_id_t const pci_vid_12FD[] = {
{0x12FD, 0xFFFF, 0xFFFF, 0xFFFF, "I2S(0x12FD)"},
}; /* pci_vid_12FD[] */

static pci_id_t const pci_vid_12FE[] = {
{0x12FE, 0xFFFF, 0xFFFF, 0xFFFF, "ESD Electronic System Design GmbH(0x12FE)"},
}; /* pci_vid_12FE[] */

static pci_id_t const pci_vid_12FF[] = {
{0x12FF, 0xFFFF, 0xFFFF, 0xFFFF, "Lexicon(0x12FF)"},
}; /* pci_vid_12FF[] */

static pci_id_t const pci_vid_1300[] = {
{0x1300, 0xFFFF, 0xFFFF, 0xFFFF, "Harman International Industries Inc(0x1300)"},
}; /* pci_vid_1300[] */

static pci_id_t const pci_vid_1302[] = {
{0x1302, 0xFFFF, 0xFFFF, 0xFFFF, "Computer Sciences Corp(0x1302)"},
}; /* pci_vid_1302[] */

static pci_id_t const pci_vid_1303[] = {
{0x1303, 0xFFFF, 0xFFFF, 0xFFFF, "Innovative Integration(0x1303)"},
{0x1303, 0x0030, 0xFFFF, 0xFFFF, "X3-SDF 4-channel XMC acquisition board(0x0030)"},
}; /* pci_vid_1303[] */

static pci_id_t const pci_vid_1304[] = {
{0x1304, 0xFFFF, 0xFFFF, 0xFFFF, "Juniper Networks(0x1304)"},
}; /* pci_vid_1304[] */

static pci_id_t const pci_vid_1305[] = {
{0x1305, 0xFFFF, 0xFFFF, 0xFFFF, "Netphone, Inc(0x1305)"},
}; /* pci_vid_1305[] */

static pci_id_t const pci_vid_1306[] = {
{0x1306, 0xFFFF, 0xFFFF, 0xFFFF, "Duet Technologies(0x1306)"},
}; /* pci_vid_1306[] */

static pci_id_t const pci_vid_1307[] = {
{0x1307, 0xFFFF, 0xFFFF, 0xFFFF, "Measurement Computing(0x1307)"},
{0x1307, 0x0001, 0xFFFF, 0xFFFF, "PCI-DAS1602/16(0x0001)"},
{0x1307, 0x000B, 0xFFFF, 0xFFFF, "PCI-DIO48H(0x000B)"},
{0x1307, 0x000C, 0xFFFF, 0xFFFF, "PCI-PDISO8(0x000C)"},
{0x1307, 0x000D, 0xFFFF, 0xFFFF, "PCI-PDISO16(0x000D)"},
{0x1307, 0x000F, 0xFFFF, 0xFFFF, "PCI-DAS1200(0x000F)"},
{0x1307, 0x0010, 0xFFFF, 0xFFFF, "PCI-DAS1602/12(0x0010)"},
{0x1307, 0x0014, 0xFFFF, 0xFFFF, "PCI-DIO24H(0x0014)"},
{0x1307, 0x0015, 0xFFFF, 0xFFFF, "PCI-DIO24H/CTR3(0x0015)"},
{0x1307, 0x0016, 0xFFFF, 0xFFFF, "PCI-DIO48H/CTR15(0x0016)"},
{0x1307, 0x0017, 0xFFFF, 0xFFFF, "PCI-DIO96H(0x0017)"},
{0x1307, 0x0018, 0xFFFF, 0xFFFF, "PCI-CTR05(0x0018)"},
{0x1307, 0x0019, 0xFFFF, 0xFFFF, "PCI-DAS1200/JR(0x0019)"},
{0x1307, 0x001A, 0xFFFF, 0xFFFF, "PCI-DAS1001(0x001A)"},
{0x1307, 0x001B, 0xFFFF, 0xFFFF, "PCI-DAS1002(0x001B)"},
{0x1307, 0x001C, 0xFFFF, 0xFFFF, "PCI-DAS1602JR/16(0x001C)"},
{0x1307, 0x001D, 0xFFFF, 0xFFFF, "PCI-DAS6402/16(0x001D)"},
{0x1307, 0x001E, 0xFFFF, 0xFFFF, "PCI-DAS6402/12(0x001E)"},
{0x1307, 0x001F, 0xFFFF, 0xFFFF, "PCI-DAS16/M1(0x001F)"},
{0x1307, 0x0020, 0xFFFF, 0xFFFF, "PCI-DDA02/12(0x0020)"},
{0x1307, 0x0021, 0xFFFF, 0xFFFF, "PCI-DDA04/12(0x0021)"},
{0x1307, 0x0022, 0xFFFF, 0xFFFF, "PCI-DDA08/12(0x0022)"},
{0x1307, 0x0023, 0xFFFF, 0xFFFF, "PCI-DDA02/16(0x0023)"},
{0x1307, 0x0024, 0xFFFF, 0xFFFF, "PCI-DDA04/16(0x0024)"},
{0x1307, 0x0025, 0xFFFF, 0xFFFF, "PCI-DDA08/16(0x0025)"},
{0x1307, 0x0026, 0xFFFF, 0xFFFF, "PCI-DAC04/12-HS(0x0026)"},
{0x1307, 0x0027, 0xFFFF, 0xFFFF, "PCI-DAC04/16-HS(0x0027)"},
{0x1307, 0x0028, 0xFFFF, 0xFFFF, "PCI-DIO24(0x0028)"},
{0x1307, 0x0029, 0xFFFF, 0xFFFF, "PCI-DAS08(0x0029)"},
{0x1307, 0x002C, 0xFFFF, 0xFFFF, "PCI-INT32(0x002C)"},
{0x1307, 0x0033, 0xFFFF, 0xFFFF, "PCI-DUAL-AC5(0x0033)"},
{0x1307, 0x0034, 0xFFFF, 0xFFFF, "PCI-DAS-TC(0x0034)"},
{0x1307, 0x0035, 0xFFFF, 0xFFFF, "PCI-DAS64/M1/16(0x0035)"},
{0x1307, 0x0036, 0xFFFF, 0xFFFF, "PCI-DAS64/M2/16(0x0036)"},
{0x1307, 0x0037, 0xFFFF, 0xFFFF, "PCI-DAS64/M3/16(0x0037)"},
{0x1307, 0x004B, 0xFFFF, 0xFFFF, "PCI-MDB64(0x004B)"},
{0x1307, 0x004C, 0xFFFF, 0xFFFF, "PCI-DAS1000(0x004C)"},
{0x1307, 0x004D, 0xFFFF, 0xFFFF, "PCI-QUAD04(0x004D)"},
{0x1307, 0x0052, 0xFFFF, 0xFFFF, "PCI-DAS4020/12(0x0052)"},
{0x1307, 0x0053, 0xFFFF, 0xFFFF, "PCIM-DDA06/16(0x0053)"},
{0x1307, 0x0054, 0xFFFF, 0xFFFF, "PCI-DIO96(0x0054)"},
{0x1307, 0x0055, 0xFFFF, 0xFFFF, "CPCI-DIO24H(0x0055)"},
{0x1307, 0x0056, 0xFFFF, 0xFFFF, "PCIM-DAS1602/16(0x0056)"},
{0x1307, 0x0057, 0xFFFF, 0xFFFF, "PCI-DAS3202/16(0x0057)"},
{0x1307, 0x0059, 0xFFFF, 0xFFFF, "PCI-QUAD-AC5(0x0059)"},
{0x1307, 0x005A, 0xFFFF, 0xFFFF, "CPCI-DIO96H(0x005A)"},
{0x1307, 0x005B, 0xFFFF, 0xFFFF, "CPCI-DIO48H(0x005B)"},
{0x1307, 0x005D, 0xFFFF, 0xFFFF, "PCI-DAS6023(0x005D)"},
{0x1307, 0x005E, 0xFFFF, 0xFFFF, "PCI-DAS6025(0x005E)"},
{0x1307, 0x005F, 0xFFFF, 0xFFFF, "PCI-DAS6030(0x005F)"},
{0x1307, 0x0060, 0xFFFF, 0xFFFF, "PCI-DAS6031(0x0060)"},
{0x1307, 0x0061, 0xFFFF, 0xFFFF, "PCI-DAS6032(0x0061)"},
{0x1307, 0x0062, 0xFFFF, 0xFFFF, "PCI-DAS6033(0x0062)"},
{0x1307, 0x0063, 0xFFFF, 0xFFFF, "PCI-DAS6034(0x0063)"},
{0x1307, 0x0064, 0xFFFF, 0xFFFF, "PCI-DAS6035(0x0064)"},
{0x1307, 0x0065, 0xFFFF, 0xFFFF, "PCI-DAS6040(0x0065)"},
{0x1307, 0x0066, 0xFFFF, 0xFFFF, "PCI-DAS6052(0x0066)"},
{0x1307, 0x0067, 0xFFFF, 0xFFFF, "PCI-DAS6070(0x0067)"},
{0x1307, 0x0068, 0xFFFF, 0xFFFF, "PCI-DAS6071(0x0068)"},
{0x1307, 0x006E, 0xFFFF, 0xFFFF, "PCI-CTR10(0x006E)"},
{0x1307, 0x006F, 0xFFFF, 0xFFFF, "PCI-DAS6036(0x006F)"},
{0x1307, 0x0070, 0xFFFF, 0xFFFF, "PCI-DAC6702(0x0070)"},
{0x1307, 0x0071, 0xFFFF, 0xFFFF, "PCI-DAC6703(0x0071)"},
{0x1307, 0x0074, 0xFFFF, 0xFFFF, "PCI-CTR20HD(0x0074)"},
{0x1307, 0x0077, 0xFFFF, 0xFFFF, "PCI-DIO24/LP(0x0077)"},
{0x1307, 0x0078, 0xFFFF, 0xFFFF, "PCI-DAS6013(0x0078)"},
{0x1307, 0x0079, 0xFFFF, 0xFFFF, "PCI-DAS6014(0x0079)"},
{0x1307, 0x007B, 0xFFFF, 0xFFFF, "PCIM-DAS16JR/16(0x007B)"},
{0x1307, 0x007E, 0xFFFF, 0xFFFF, "PCI-DIO24/S(0x007E)"},
{0x1307, 0x00A5, 0xFFFF, 0xFFFF, "PCI-2511(0x00A5)"},
{0x1307, 0x00A6, 0xFFFF, 0xFFFF, "PCI-2513(0x00A6)"},
{0x1307, 0x00A7, 0xFFFF, 0xFFFF, "PCI-2515(0x00A7)"},
{0x1307, 0x00A8, 0xFFFF, 0xFFFF, "PCI-2517(0x00A8)"},
{0x1307, 0x00BE, 0xFFFF, 0xFFFF, "PCI-QUAD05(0x00BE)"},
{0x1307, 0x00DA, 0xFFFF, 0xFFFF, "PCIe-DIO96H(0x00DA)"},
{0x1307, 0x00DB, 0xFFFF, 0xFFFF, "PCIe-DIO24(0x00DB)"},
{0x1307, 0x0115, 0xFFFF, 0xFFFF, "PCIe-DAS1602/16(0x0115)"},
}; /* pci_vid_1307[] */

static pci_id_t const pci_vid_1308[] = {
{0x1308, 0xFFFF, 0xFFFF, 0xFFFF, "Jato Technologies Inc.(0x1308)"},
{0x1308, 0x0001, 0xFFFF, 0xFFFF, "NetCelerator Adapter(0x0001)"},
{0x1308, 0x0001, 0x1308, 0x0001, "NetCelerator Adapter(0x1308-0x0001)"},
}; /* pci_vid_1308[] */

static pci_id_t const pci_vid_1309[] = {
{0x1309, 0xFFFF, 0xFFFF, 0xFFFF, "AB Semiconductor Ltd(0x1309)"},
}; /* pci_vid_1309[] */

static pci_id_t const pci_vid_130A[] = {
{0x130A, 0xFFFF, 0xFFFF, 0xFFFF, "Mitsubishi Electric Microcomputer(0x130A)"},
}; /* pci_vid_130A[] */

static pci_id_t const pci_vid_130B[] = {
{0x130B, 0xFFFF, 0xFFFF, 0xFFFF, "Colorgraphic Communications Corp(0x130B)"},
}; /* pci_vid_130B[] */

static pci_id_t const pci_vid_130C[] = {
{0x130C, 0xFFFF, 0xFFFF, 0xFFFF, "Ambex Technologies, Inc(0x130C)"},
}; /* pci_vid_130C[] */

static pci_id_t const pci_vid_130D[] = {
{0x130D, 0xFFFF, 0xFFFF, 0xFFFF, "Accelerix Inc(0x130D)"},
}; /* pci_vid_130D[] */

static pci_id_t const pci_vid_130E[] = {
{0x130E, 0xFFFF, 0xFFFF, 0xFFFF, "Yamatake-Honeywell Co. Ltd(0x130E)"},
}; /* pci_vid_130E[] */

static pci_id_t const pci_vid_130F[] = {
{0x130F, 0xFFFF, 0xFFFF, 0xFFFF, "Advanet Inc(0x130F)"},
}; /* pci_vid_130F[] */

static pci_id_t const pci_vid_1310[] = {
{0x1310, 0xFFFF, 0xFFFF, 0xFFFF, "Gespac(0x1310)"},
}; /* pci_vid_1310[] */

static pci_id_t const pci_vid_1311[] = {
{0x1311, 0xFFFF, 0xFFFF, 0xFFFF, "Videoserver, Inc(0x1311)"},
}; /* pci_vid_1311[] */

static pci_id_t const pci_vid_1312[] = {
{0x1312, 0xFFFF, 0xFFFF, 0xFFFF, "Acuity Imaging, Inc(0x1312)"},
}; /* pci_vid_1312[] */

static pci_id_t const pci_vid_1313[] = {
{0x1313, 0xFFFF, 0xFFFF, 0xFFFF, "Yaskawa Electric Co.(0x1313)"},
}; /* pci_vid_1313[] */

static pci_id_t const pci_vid_1315[] = {
{0x1315, 0xFFFF, 0xFFFF, 0xFFFF, "Wavesat(0x1315)"},
}; /* pci_vid_1315[] */

static pci_id_t const pci_vid_1316[] = {
{0x1316, 0xFFFF, 0xFFFF, 0xFFFF, "Teradyne Inc(0x1316)"},
}; /* pci_vid_1316[] */

static pci_id_t const pci_vid_1317[] = {
{0x1317, 0xFFFF, 0xFFFF, 0xFFFF, "ADMtek(0x1317)"},
{0x1317, 0x0981, 0xFFFF, 0xFFFF, "21x4x DEC-Tulip compatible 10/100 Ethernet(0x0981)"},
{0x1317, 0x0985, 0xFFFF, 0xFFFF, "NC100 Network Everywhere Fast Ethernet 10/100(0x0985)"},
{0x1317, 0x0985, 0x1734, 0x100C, "Scenic N300 ADMtek AN983 10/100 Mbps PCI Adapter(0x1734-0x100C)"},
{0x1317, 0x1985, 0xFFFF, 0xFFFF, "21x4x DEC-Tulip compatible 10/100 Ethernet(0x1985)"},
{0x1317, 0x1985, 0x1385, 0x511A, "FA511(0x1385-0x511A)"},
{0x1317, 0x1985, 0x1395, 0x2103, "CB100-EZ (4-LED version)(0x1395-0x2103)"},
{0x1317, 0x2850, 0xFFFF, 0xFFFF, "HSP MicroModem 56(0x2850)"},
{0x1317, 0x5120, 0xFFFF, 0xFFFF, "ADM5120 OpenGate System-on-Chip(0x5120)"},
{0x1317, 0x8201, 0xFFFF, 0xFFFF, "ADM8211 802.11b Wireless Interface(0x8201)"},
{0x1317, 0x8201, 0x10B8, 0x2635, "SMC2635W v1 802.11b Wireless Cardbus Adapter(0x10B8-0x2635)"},
{0x1317, 0x8201, 0x1317, 0x8201, "SMC2635W v2 802.11b Wireless Cardbus Adapter(0x1317-0x8201)"},
{0x1317, 0x8211, 0xFFFF, 0xFFFF, "ADM8211 802.11b Wireless Interface(0x8211)"},
{0x1317, 0x9511, 0xFFFF, 0xFFFF, "21x4x DEC-Tulip compatible 10/100 Ethernet(0x9511)"},
}; /* pci_vid_1317[] */

static pci_id_t const pci_vid_1318[] = {
{0x1318, 0xFFFF, 0xFFFF, 0xFFFF, "Packet Engines Inc.(0x1318)"},
{0x1318, 0x0911, 0xFFFF, 0xFFFF, "GNIC-II PCI Gigabit Ethernet [Hamachi](0x0911)"},
}; /* pci_vid_1318[] */

static pci_id_t const pci_vid_1319[] = {
{0x1319, 0xFFFF, 0xFFFF, 0xFFFF, "Fortemedia, Inc(0x1319)"},
{0x1319, 0x0801, 0xFFFF, 0xFFFF, "Xwave QS3000A [FM801](0x0801)"},
{0x1319, 0x0801, 0x1319, 0x1319, "FM801 PCI Audio(0x1319-0x1319)"},
{0x1319, 0x0802, 0xFFFF, 0xFFFF, "Xwave QS3000A [FM801 game port](0x0802)"},
{0x1319, 0x0802, 0x1319, 0x1319, "FM801 PCI Joystick(0x1319-0x1319)"},
{0x1319, 0x1000, 0xFFFF, 0xFFFF, "FM801 PCI Audio(0x1000)"},
{0x1319, 0x1001, 0xFFFF, 0xFFFF, "FM801 PCI Joystick(0x1001)"},
}; /* pci_vid_1319[] */

static pci_id_t const pci_vid_131A[] = {
{0x131A, 0xFFFF, 0xFFFF, 0xFFFF, "Finisar Corp.(0x131A)"},
}; /* pci_vid_131A[] */

static pci_id_t const pci_vid_131C[] = {
{0x131C, 0xFFFF, 0xFFFF, 0xFFFF, "Nippon Electro-Sensory Devices Corp(0x131C)"},
}; /* pci_vid_131C[] */

static pci_id_t const pci_vid_131D[] = {
{0x131D, 0xFFFF, 0xFFFF, 0xFFFF, "Sysmic, Inc.(0x131D)"},
}; /* pci_vid_131D[] */

static pci_id_t const pci_vid_131E[] = {
{0x131E, 0xFFFF, 0xFFFF, 0xFFFF, "Xinex Networks Inc(0x131E)"},
}; /* pci_vid_131E[] */

static pci_id_t const pci_vid_131F[] = {
{0x131F, 0xFFFF, 0xFFFF, 0xFFFF, "Siig Inc(0x131F)"},
{0x131F, 0x1000, 0xFFFF, 0xFFFF, "CyberSerial (1-port) 16550(0x1000)"},
{0x131F, 0x1001, 0xFFFF, 0xFFFF, "CyberSerial (1-port) 16650(0x1001)"},
{0x131F, 0x1002, 0xFFFF, 0xFFFF, "CyberSerial (1-port) 16850(0x1002)"},
{0x131F, 0x1010, 0xFFFF, 0xFFFF, "Duet 1S(16550)+1P(0x1010)"},
{0x131F, 0x1011, 0xFFFF, 0xFFFF, "Duet 1S(16650)+1P(0x1011)"},
{0x131F, 0x1012, 0xFFFF, 0xFFFF, "Duet 1S(16850)+1P(0x1012)"},
{0x131F, 0x1020, 0xFFFF, 0xFFFF, "CyberParallel (1-port)(0x1020)"},
{0x131F, 0x1021, 0xFFFF, 0xFFFF, "CyberParallel (2-port)(0x1021)"},
{0x131F, 0x1030, 0xFFFF, 0xFFFF, "CyberSerial (2-port) 16550(0x1030)"},
{0x131F, 0x1031, 0xFFFF, 0xFFFF, "CyberSerial (2-port) 16650(0x1031)"},
{0x131F, 0x1032, 0xFFFF, 0xFFFF, "CyberSerial (2-port) 16850(0x1032)"},
{0x131F, 0x1034, 0xFFFF, 0xFFFF, "Trio 2S(16550)+1P(0x1034)"},
{0x131F, 0x1035, 0xFFFF, 0xFFFF, "Trio 2S(16650)+1P(0x1035)"},
{0x131F, 0x1036, 0xFFFF, 0xFFFF, "Trio 2S(16850)+1P(0x1036)"},
{0x131F, 0x1050, 0xFFFF, 0xFFFF, "CyberSerial (4-port) 16550(0x1050)"},
{0x131F, 0x1051, 0xFFFF, 0xFFFF, "CyberSerial (4-port) 16650(0x1051)"},
{0x131F, 0x1052, 0xFFFF, 0xFFFF, "CyberSerial (4-port) 16850(0x1052)"},
{0x131F, 0x2000, 0xFFFF, 0xFFFF, "CyberSerial (1-port) 16550(0x2000)"},
{0x131F, 0x2001, 0xFFFF, 0xFFFF, "CyberSerial (1-port) 16650(0x2001)"},
{0x131F, 0x2002, 0xFFFF, 0xFFFF, "CyberSerial (1-port) 16850(0x2002)"},
{0x131F, 0x2010, 0xFFFF, 0xFFFF, "Duet 1S(16550)+1P(0x2010)"},
{0x131F, 0x2011, 0xFFFF, 0xFFFF, "Duet 1S(16650)+1P(0x2011)"},
{0x131F, 0x2012, 0xFFFF, 0xFFFF, "Duet 1S(16850)+1P(0x2012)"},
{0x131F, 0x2020, 0xFFFF, 0xFFFF, "CyberParallel (1-port)(0x2020)"},
{0x131F, 0x2021, 0xFFFF, 0xFFFF, "CyberParallel (2-port)(0x2021)"},
{0x131F, 0x2030, 0xFFFF, 0xFFFF, "CyberSerial (2-port) 16550(0x2030)"},
{0x131F, 0x2030, 0x131F, 0x2030, "PCI Serial Card(0x131F-0x2030)"},
{0x131F, 0x2031, 0xFFFF, 0xFFFF, "CyberSerial (2-port) 16650(0x2031)"},
{0x131F, 0x2032, 0xFFFF, 0xFFFF, "CyberSerial (2-port) 16850(0x2032)"},
{0x131F, 0x2040, 0xFFFF, 0xFFFF, "Trio 1S(16550)+2P(0x2040)"},
{0x131F, 0x2041, 0xFFFF, 0xFFFF, "Trio 1S(16650)+2P(0x2041)"},
{0x131F, 0x2042, 0xFFFF, 0xFFFF, "Trio 1S(16850)+2P(0x2042)"},
{0x131F, 0x2050, 0xFFFF, 0xFFFF, "CyberSerial (4-port) 16550(0x2050)"},
{0x131F, 0x2051, 0xFFFF, 0xFFFF, "CyberSerial (4-port) 16650(0x2051)"},
{0x131F, 0x2052, 0xFFFF, 0xFFFF, "CyberSerial (4-port) 16850(0x2052)"},
{0x131F, 0x2060, 0xFFFF, 0xFFFF, "Trio 2S(16550)+1P(0x2060)"},
{0x131F, 0x2061, 0xFFFF, 0xFFFF, "Trio 2S(16650)+1P(0x2061)"},
{0x131F, 0x2062, 0xFFFF, 0xFFFF, "Trio 2S(16850)+1P(0x2062)"},
{0x131F, 0x2081, 0xFFFF, 0xFFFF, "CyberSerial (8-port) ST16654(0x2081)"},
}; /* pci_vid_131F[] */

static pci_id_t const pci_vid_1320[] = {
{0x1320, 0xFFFF, 0xFFFF, 0xFFFF, "Crypto AG(0x1320)"},
}; /* pci_vid_1320[] */

static pci_id_t const pci_vid_1321[] = {
{0x1321, 0xFFFF, 0xFFFF, 0xFFFF, "Arcobel Graphics BV(0x1321)"},
}; /* pci_vid_1321[] */

static pci_id_t const pci_vid_1322[] = {
{0x1322, 0xFFFF, 0xFFFF, 0xFFFF, "MTT Co., Ltd(0x1322)"},
}; /* pci_vid_1322[] */

static pci_id_t const pci_vid_1323[] = {
{0x1323, 0xFFFF, 0xFFFF, 0xFFFF, "Dome Inc(0x1323)"},
}; /* pci_vid_1323[] */

static pci_id_t const pci_vid_1324[] = {
{0x1324, 0xFFFF, 0xFFFF, 0xFFFF, "Sphere Communications(0x1324)"},
}; /* pci_vid_1324[] */

static pci_id_t const pci_vid_1325[] = {
{0x1325, 0xFFFF, 0xFFFF, 0xFFFF, "Salix Technologies, Inc(0x1325)"},
}; /* pci_vid_1325[] */

static pci_id_t const pci_vid_1326[] = {
{0x1326, 0xFFFF, 0xFFFF, 0xFFFF, "Seachange international(0x1326)"},
}; /* pci_vid_1326[] */

static pci_id_t const pci_vid_1327[] = {
{0x1327, 0xFFFF, 0xFFFF, 0xFFFF, "Voss scientific(0x1327)"},
}; /* pci_vid_1327[] */

static pci_id_t const pci_vid_1328[] = {
{0x1328, 0xFFFF, 0xFFFF, 0xFFFF, "quadrant international(0x1328)"},
}; /* pci_vid_1328[] */

static pci_id_t const pci_vid_1329[] = {
{0x1329, 0xFFFF, 0xFFFF, 0xFFFF, "Productivity Enhancement(0x1329)"},
}; /* pci_vid_1329[] */

static pci_id_t const pci_vid_132A[] = {
{0x132A, 0xFFFF, 0xFFFF, 0xFFFF, "Microcom Inc.(0x132A)"},
}; /* pci_vid_132A[] */

static pci_id_t const pci_vid_132B[] = {
{0x132B, 0xFFFF, 0xFFFF, 0xFFFF, "Broadband Technologies(0x132B)"},
}; /* pci_vid_132B[] */

static pci_id_t const pci_vid_132C[] = {
{0x132C, 0xFFFF, 0xFFFF, 0xFFFF, "Micrel Inc(0x132C)"},
}; /* pci_vid_132C[] */

static pci_id_t const pci_vid_132D[] = {
{0x132D, 0xFFFF, 0xFFFF, 0xFFFF, "Integrated Silicon Solution, Inc.(0x132D)"},
}; /* pci_vid_132D[] */

static pci_id_t const pci_vid_1330[] = {
{0x1330, 0xFFFF, 0xFFFF, 0xFFFF, "MMC Networks(0x1330)"},
}; /* pci_vid_1330[] */

static pci_id_t const pci_vid_1331[] = {
{0x1331, 0xFFFF, 0xFFFF, 0xFFFF, "RadiSys Corporation(0x1331)"},
{0x1331, 0x0030, 0xFFFF, 0xFFFF, "ENP-2611(0x0030)"},
{0x1331, 0x8200, 0xFFFF, 0xFFFF, "82600 Host Bridge(0x8200)"},
{0x1331, 0x8201, 0xFFFF, 0xFFFF, "82600 IDE(0x8201)"},
{0x1331, 0x8202, 0xFFFF, 0xFFFF, "82600 USB(0x8202)"},
{0x1331, 0x8210, 0xFFFF, 0xFFFF, "82600 PCI Bridge(0x8210)"},
}; /* pci_vid_1331[] */

static pci_id_t const pci_vid_1332[] = {
{0x1332, 0xFFFF, 0xFFFF, 0xFFFF, "Micro Memory(0x1332)"},
{0x1332, 0x5415, 0xFFFF, 0xFFFF, "MM-5415CN PCI Memory Module with Battery Backup(0x5415)"},
{0x1332, 0x5425, 0xFFFF, 0xFFFF, "MM-5425CN PCI 64/66 Memory Module with Battery Backup(0x5425)"},
{0x1332, 0x6140, 0xFFFF, 0xFFFF, "MM-6140D(0x6140)"},
}; /* pci_vid_1332[] */

static pci_id_t const pci_vid_1334[] = {
{0x1334, 0xFFFF, 0xFFFF, 0xFFFF, "Redcreek Communications, Inc(0x1334)"},
}; /* pci_vid_1334[] */

static pci_id_t const pci_vid_1335[] = {
{0x1335, 0xFFFF, 0xFFFF, 0xFFFF, "Videomail, Inc(0x1335)"},
}; /* pci_vid_1335[] */

static pci_id_t const pci_vid_1337[] = {
{0x1337, 0xFFFF, 0xFFFF, 0xFFFF, "Third Planet Publishing(0x1337)"},
}; /* pci_vid_1337[] */

static pci_id_t const pci_vid_1338[] = {
{0x1338, 0xFFFF, 0xFFFF, 0xFFFF, "BT Electronics(0x1338)"},
}; /* pci_vid_1338[] */

static pci_id_t const pci_vid_133A[] = {
{0x133A, 0xFFFF, 0xFFFF, 0xFFFF, "Vtel Corp(0x133A)"},
}; /* pci_vid_133A[] */

static pci_id_t const pci_vid_133B[] = {
{0x133B, 0xFFFF, 0xFFFF, 0xFFFF, "Softcom Microsystems(0x133B)"},
}; /* pci_vid_133B[] */

static pci_id_t const pci_vid_133C[] = {
{0x133C, 0xFFFF, 0xFFFF, 0xFFFF, "Holontech Corp(0x133C)"},
}; /* pci_vid_133C[] */

static pci_id_t const pci_vid_133D[] = {
{0x133D, 0xFFFF, 0xFFFF, 0xFFFF, "SS Technologies(0x133D)"},
}; /* pci_vid_133D[] */

static pci_id_t const pci_vid_133E[] = {
{0x133E, 0xFFFF, 0xFFFF, 0xFFFF, "Virtual Computer Corp(0x133E)"},
}; /* pci_vid_133E[] */

static pci_id_t const pci_vid_133F[] = {
{0x133F, 0xFFFF, 0xFFFF, 0xFFFF, "SCM Microsystems(0x133F)"},
}; /* pci_vid_133F[] */

static pci_id_t const pci_vid_1340[] = {
{0x1340, 0xFFFF, 0xFFFF, 0xFFFF, "Atalla Corp(0x1340)"},
}; /* pci_vid_1340[] */

static pci_id_t const pci_vid_1341[] = {
{0x1341, 0xFFFF, 0xFFFF, 0xFFFF, "Kyoto Microcomputer Co(0x1341)"},
}; /* pci_vid_1341[] */

static pci_id_t const pci_vid_1342[] = {
{0x1342, 0xFFFF, 0xFFFF, 0xFFFF, "Promax Systems Inc(0x1342)"},
}; /* pci_vid_1342[] */

static pci_id_t const pci_vid_1343[] = {
{0x1343, 0xFFFF, 0xFFFF, 0xFFFF, "Phylon Communications Inc(0x1343)"},
}; /* pci_vid_1343[] */

static pci_id_t const pci_vid_1344[] = {
{0x1344, 0xFFFF, 0xFFFF, 0xFFFF, "Micron Technology Inc(0x1344)"},
{0x1344, 0x5150, 0xFFFF, 0xFFFF, "RealSSD P320h(0x5150)"},
{0x1344, 0x5151, 0xFFFF, 0xFFFF, "RealSSD P320m(0x5151)"},
{0x1344, 0x5152, 0xFFFF, 0xFFFF, "RealSSD P320s(0x5152)"},
{0x1344, 0x5153, 0xFFFF, 0xFFFF, "RealSSD P325m(0x5153)"},
{0x1344, 0x5160, 0xFFFF, 0xFFFF, "RealSSD P420h(0x5160)"},
{0x1344, 0x5161, 0xFFFF, 0xFFFF, "RealSSD P420m(0x5161)"},
{0x1344, 0x5163, 0xFFFF, 0xFFFF, "RealSSD P425m(0x5163)"},
{0x1344, 0x5180, 0xFFFF, 0xFFFF, "9100 PRO NVMe SSD(0x5180)"},
{0x1344, 0x5181, 0xFFFF, 0xFFFF, "9100 MAX NVMe SSD(0x5181)"},
{0x1344, 0x5188, 0xFFFF, 0xFFFF, "7100 ECO NVMe SSD(0x5188)"},
{0x1344, 0x5189, 0xFFFF, 0xFFFF, "7100 MAX NVMe SSD(0x5189)"},
{0x1344, 0x5190, 0xFFFF, 0xFFFF, "9200 ECO NVMe SSD(0x5190)"},
{0x1344, 0x5191, 0xFFFF, 0xFFFF, "9200 PRO NVMe SSD(0x5191)"},
{0x1344, 0x5192, 0xFFFF, 0xFFFF, "9200 MAX NVMe SSD(0x5192)"},
{0x1344, 0x5196, 0xFFFF, 0xFFFF, "9400 PRO NVMe SSD(0x5196)"},
{0x1344, 0x5197, 0xFFFF, 0xFFFF, "9400 MAX NVMe SSD(0x5197)"},
{0x1344, 0x51A2, 0xFFFF, 0xFFFF, "7300 PRO NVMe SSD(0x51A2)"},
{0x1344, 0x51A2, 0x1344, 0x2000, "960GB U.2(0x1344-0x2000)"},
{0x1344, 0x51A2, 0x1344, 0x3000, "1920GB U.2(0x1344-0x3000)"},
{0x1344, 0x51A2, 0x1344, 0x4000, "3480GB U.2(0x1344-0x4000)"},
{0x1344, 0x51A2, 0x1344, 0x5000, "7680GB U.2(0x1344-0x5000)"},
{0x1344, 0x51A3, 0xFFFF, 0xFFFF, "7300 MAX NVMe SSD(0x51A3)"},
{0x1344, 0x51A3, 0x1344, 0x1100, "400GB M.2(0x1344-0x1100)"},
{0x1344, 0x51A3, 0x1344, 0x2000, "800GB U.2(0x1344-0x2000)"},
{0x1344, 0x51A3, 0x1344, 0x2100, "800GB M.2(0x1344-0x2100)"},
{0x1344, 0x51A3, 0x1344, 0x3000, "1600GB U.2(0x1344-0x3000)"},
{0x1344, 0x51A3, 0x1344, 0x4000, "3200GB U.2(0x1344-0x4000)"},
{0x1344, 0x51A3, 0x1344, 0x5000, "6400GB U.2(0x1344-0x5000)"},
{0x1344, 0x51B1, 0xFFFF, 0xFFFF, "9300 PRO NVMe SSD(0x51B1)"},
{0x1344, 0x51B1, 0x1344, 0x4000, "3.84TB U.2(0x1344-0x4000)"},
{0x1344, 0x51B1, 0x1344, 0x5000, "7.68TB U.2(0x1344-0x5000)"},
{0x1344, 0x51B1, 0x1344, 0x6000, "15.36TB U.2(0x1344-0x6000)"},
{0x1344, 0x51B2, 0xFFFF, 0xFFFF, "9300 MAX NVMe SSD(0x51B2)"},
{0x1344, 0x51B2, 0x1344, 0x4000, "3.2TB U.2(0x1344-0x4000)"},
{0x1344, 0x51B2, 0x1344, 0x5000, "6.4 TB U.2(0x1344-0x5000)"},
{0x1344, 0x51B2, 0x1344, 0x6000, "12.8TB U.2(0x1344-0x6000)"},
{0x1344, 0x51B7, 0xFFFF, 0xFFFF, "7500 PRO NVMe SSD(0x51B7)"},
{0x1344, 0x51B7, 0x1028, 0x22E7, "DC NVMe 7500 U.2 SED RI 15.36TB(0x1028-0x22E7)"},
{0x1344, 0x51B7, 0x1028, 0x22E8, "DC NVMe 7500 U.2 SED RI 7.68TB(0x1028-0x22E8)"},
{0x1344, 0x51B7, 0x1028, 0x22E9, "DC NVMe 7500 U.2 SED RI 3.84TB(0x1028-0x22E9)"},
{0x1344, 0x51B7, 0x1028, 0x22EA, "DC NVMe 7500 U.2 SED RI 1.92TB(0x1028-0x22EA)"},
{0x1344, 0x51B7, 0x1028, 0x22EB, "DC NVMe 7500 U.2 SED RI 960GB(0x1028-0x22EB)"},
{0x1344, 0x51B7, 0x1028, 0x22EC, "DC NVMe 7500 U.2 ISE RI 15.36TB(0x1028-0x22EC)"},
{0x1344, 0x51B7, 0x1028, 0x22ED, "DC NVMe 7500 U.2 ISE RI 7.68TB(0x1028-0x22ED)"},
{0x1344, 0x51B7, 0x1028, 0x22EE, "DC NVMe 7500 U.2 ISE RI 3.84TB(0x1028-0x22EE)"},
{0x1344, 0x51B7, 0x1028, 0x22EF, "DC NVMe 7500 U.2 ISE RI 1.92TB(0x1028-0x22EF)"},
{0x1344, 0x51B7, 0x1028, 0x22F0, "DC NVMe 7500 U.2 ISE RI 960GB(0x1028-0x22F0)"},
{0x1344, 0x51B8, 0xFFFF, 0xFFFF, "7500 MAX NVMe SSD(0x51B8)"},
{0x1344, 0x51B8, 0x1028, 0x22F1, "DC NVMe 7500 U.2 ISE MU 12.8TB(0x1028-0x22F1)"},
{0x1344, 0x51B8, 0x1028, 0x22F2, "DC NVMe 7500 U.2 ISE MU 6.4TB(0x1028-0x22F2)"},
{0x1344, 0x51B8, 0x1028, 0x22F3, "DC NVMe 7500 U.2 ISE MU 3.2TB(0x1028-0x22F3)"},
{0x1344, 0x51B8, 0x1028, 0x22F4, "DC NVMe 7500 U.2 ISE MU 1.6TB(0x1028-0x22F4)"},
{0x1344, 0x51B8, 0x1028, 0x22F5, "DC NVMe 7500 U.2 ISE MU 800GB(0x1028-0x22F5)"},
{0x1344, 0x51B9, 0xFFFF, 0xFFFF, "6500 ION NVMe SSD(0x51B9)"},
{0x1344, 0x51B9, 0x1028, 0x22E6, "Ent NVMe 6500 RI 30.72TB(0x1028-0x22E6)"},
{0x1344, 0x51B9, 0x1028, 0x22F6, "Ent NVMe 6500 RI FIPS 30.72TB(0x1028-0x22F6)"},
{0x1344, 0x51C0, 0xFFFF, 0xFFFF, "7400 PRO NVMe SSD(0x51C0)"},
{0x1344, 0x51C0, 0x1028, 0x2162, "EC NVMe OPAL 7400 RI M.2 480GB(0x1028-0x2162)"},
{0x1344, 0x51C0, 0x1028, 0x2163, "EC NVMe OPAL 7400 RI M.2 960GB(0x1028-0x2163)"},
{0x1344, 0x51C0, 0x1028, 0x2164, "EC NVMe ISE 7400 RI M.2 480GB(0x1028-0x2164)"},
{0x1344, 0x51C0, 0x1028, 0x2165, "EC NVMe ISE 7400 RI M.2 960GB(0x1028-0x2165)"},
{0x1344, 0x51C0, 0x1028, 0x216C, "EC NVMe ISE 7400 RI M.2 110 1.92TB(0x1028-0x216C)"},
{0x1344, 0x51C0, 0x1028, 0x216D, "EC NVMe ISE 7400 RI M.2 110 3.84TB(0x1028-0x216D)"},
{0x1344, 0x51C0, 0x1028, 0x216E, "EC NVMe OPAL 7400 RI M.2 110 1.92TB(0x1028-0x216E)"},
{0x1344, 0x51C0, 0x1028, 0x216F, "EC NVMe OPAL 7400 RI M.2 110 3.84TB(0x1028-0x216F)"},
{0x1344, 0x51C0, 0x1028, 0x2197, "EC NVMe OPAL 7400 RI M.2 110 960GB(0x1028-0x2197)"},
{0x1344, 0x51C0, 0x1028, 0x224D, "EC NVMe ISE 7400 RI M.2 110 960GB(0x1028-0x224D)"},
{0x1344, 0x51C0, 0x1344, 0x1100, "M.2 480GB(0x1344-0x1100)"},
{0x1344, 0x51C0, 0x1344, 0x2000, "U.3 960GB(0x1344-0x2000)"},
{0x1344, 0x51C0, 0x1344, 0x2100, "M.2 960GB(0x1344-0x2100)"},
{0x1344, 0x51C0, 0x1344, 0x2600, "E1.S 960GB(0x1344-0x2600)"},
{0x1344, 0x51C0, 0x1344, 0x2B00, "M.2 1920GB(0x1344-0x2B00)"},
{0x1344, 0x51C0, 0x1344, 0x2D00, "E1.2 1920GB(0x1344-0x2D00)"},
{0x1344, 0x51C0, 0x1344, 0x3000, "U.3 1920GB(0x1344-0x3000)"},
{0x1344, 0x51C0, 0x1344, 0x3E00, "M.2 3840GB(0x1344-0x3E00)"},
{0x1344, 0x51C0, 0x1344, 0x3F00, "E1.S 3840GB(0x1344-0x3F00)"},
{0x1344, 0x51C0, 0x1344, 0x4000, "U.3 3840GB(0x1344-0x4000)"},
{0x1344, 0x51C0, 0x1344, 0x5000, "U.3 7680GB(0x1344-0x5000)"},
{0x1344, 0x51C1, 0xFFFF, 0xFFFF, "7400 MAX NVMe SSD(0x51C1)"},
{0x1344, 0x51C1, 0x1028, 0x216A, "EC NVMe ISE 7400 MU M.2 80 800GB(0x1028-0x216A)"},
{0x1344, 0x51C1, 0x1028, 0x216B, "EC NVMe OPAL 7400 MU M.2 80 800GB(0x1028-0x216B)"},
{0x1344, 0x51C1, 0x1344, 0x1100, "M.2 400GB(0x1344-0x1100)"},
{0x1344, 0x51C1, 0x1344, 0x2000, "U.3 800GB(0x1344-0x2000)"},
{0x1344, 0x51C1, 0x1344, 0x2100, "M.2 800GB(0x1344-0x2100)"},
{0x1344, 0x51C1, 0x1344, 0x2600, "E1.S 800GB(0x1344-0x2600)"},
{0x1344, 0x51C1, 0x1344, 0x2B00, "M.2 1600GB(0x1344-0x2B00)"},
{0x1344, 0x51C1, 0x1344, 0x2D00, "E1.S 1600GB(0x1344-0x2D00)"},
{0x1344, 0x51C1, 0x1344, 0x3000, "U.3 1600GB(0x1344-0x3000)"},
{0x1344, 0x51C1, 0x1344, 0x3E00, "M.2 3200GB(0x1344-0x3E00)"},
{0x1344, 0x51C1, 0x1344, 0x3F00, "E1.S 3200GB(0x1344-0x3F00)"},
{0x1344, 0x51C1, 0x1344, 0x4000, "U.3 3200GB(0x1344-0x4000)"},
{0x1344, 0x51C1, 0x1344, 0x5000, "U.3 6400GB(0x1344-0x5000)"},
{0x1344, 0x51C3, 0xFFFF, 0xFFFF, "7450 PRO NVMe SSD(0x51C3)"},
{0x1344, 0x51C3, 0x1028, 0x226B, "EC NVMe FIPS 7450 RI M.2 110 960GB(0x1028-0x226B)"},
{0x1344, 0x51C3, 0x1028, 0x226C, "EC NVMe ISE 7450 RI M.2 80 480GB(0x1028-0x226C)"},
{0x1344, 0x51C3, 0x1028, 0x226D, "EC NVMe ISE 7450 RI M.2 80 960GB(0x1028-0x226D)"},
{0x1344, 0x51C3, 0x1028, 0x226E, "EC NVMe SED 7450 RI M.2 80 480GB(0x1028-0x226E)"},
{0x1344, 0x51C3, 0x1028, 0x226F, "EC NVMe SED 7450 RI M.2 80 960GB(0x1028-0x226F)"},
{0x1344, 0x51C3, 0x1028, 0x2270, "EC NVMe FIPS 7450 RI M.2 80 480GB(0x1028-0x2270)"},
{0x1344, 0x51C3, 0x1028, 0x2271, "EC NVMe FIPS 7450 RI M.2 80 960GB(0x1028-0x2271)"},
{0x1344, 0x51C3, 0x1028, 0x2273, "EC NVMe ISE 7450 RI M.2 110 960GB(0x1028-0x2273)"},
{0x1344, 0x51C3, 0x1028, 0x2274, "EC NVMe ISE 7450 RI M.2 110 1920GB(0x1028-0x2274)"},
{0x1344, 0x51C3, 0x1028, 0x2275, "EC NVMe ISE 7450 RI M.2 110 3840GB(0x1028-0x2275)"},
{0x1344, 0x51C3, 0x1028, 0x2278, "DC NVMe ISE 7450 RI U.2 960GB(0x1028-0x2278)"},
{0x1344, 0x51C3, 0x1028, 0x2279, "DC NVMe ISE 7450 RI U.2 1.92TB(0x1028-0x2279)"},
{0x1344, 0x51C3, 0x1028, 0x227A, "DC NVMe ISE 7450 RI U.2 3.84TB(0x1028-0x227A)"},
{0x1344, 0x51C3, 0x1028, 0x227B, "DC NVMe ISE 7450 RI U.2 7.68TB(0x1028-0x227B)"},
{0x1344, 0x51C3, 0x1028, 0x227C, "DC NVMe ISE 7450 RI U.2 15.36TB(0x1028-0x227C)"},
{0x1344, 0x51C3, 0x1028, 0x227D, "DC NVMe SED 7450 RI U.2 960GB(0x1028-0x227D)"},
{0x1344, 0x51C3, 0x1028, 0x227E, "DC NVMe SED 7450 RI U.2 1.92TB(0x1028-0x227E)"},
{0x1344, 0x51C3, 0x1028, 0x227F, "DC NVMe SED 7450 RI U.2 3.84TB(0x1028-0x227F)"},
{0x1344, 0x51C3, 0x1028, 0x2280, "DC NVMe SED 7450 RI U.2 7.68TB(0x1028-0x2280)"},
{0x1344, 0x51C3, 0x1028, 0x2281, "DC NVMe SED 7450 RI U.2 15.36TB(0x1028-0x2281)"},
{0x1344, 0x51C4, 0xFFFF, 0xFFFF, "7450 MAX NVMe SSD(0x51C4)"},
{0x1344, 0x51C4, 0x1028, 0x2272, "EC NVMe ISE 7450 MU M.2 80 800GB(0x1028-0x2272)"},
{0x1344, 0x51C4, 0x1028, 0x228B, "DC NVMe SED 7450 MU U.2 800GB(0x1028-0x228B)"},
{0x1344, 0x51C4, 0x1028, 0x228C, "DC NVMe ISE 7450 MU U.2 800GB(0x1028-0x228C)"},
{0x1344, 0x51C4, 0x1028, 0x228D, "DC NVMe SED 7450 MU U.2 1.6TB(0x1028-0x228D)"},
{0x1344, 0x51C4, 0x1028, 0x228E, "DC NVMe ISE 7450 MU U.2 1.6TB(0x1028-0x228E)"},
{0x1344, 0x51C4, 0x1028, 0x228F, "DC NVMe SED 7450 MU U.2 3.2TB(0x1028-0x228F)"},
{0x1344, 0x51C4, 0x1028, 0x2290, "DC NVMe ISE 7450 MU U.2 3.2TB(0x1028-0x2290)"},
{0x1344, 0x51C4, 0x1028, 0x2291, "DC NVMe SED 7450 MU U.2 6.4TB(0x1028-0x2291)"},
{0x1344, 0x51C4, 0x1028, 0x2292, "DC NVMe ISE 7450 MU U.2 6.4TB(0x1028-0x2292)"},
{0x1344, 0x51C4, 0x1028, 0x2293, "DC NVMe SED 7450 MU U.2 12.8TB(0x1028-0x2293)"},
{0x1344, 0x51C4, 0x1028, 0x2294, "DC NVMe ISE 7450 MU U.2 12.8TB(0x1028-0x2294)"},
{0x1344, 0x51C4, 0x1344, 0x3000, "U.3 1600GB [MTFDKCB1T6TFS/MTFDKCC1T6TFS](0x1344-0x3000)"},
{0x1344, 0x5404, 0xFFFF, 0xFFFF, "2210 NVMe SSD [Cobain](0x5404)"},
{0x1344, 0x5405, 0xFFFF, 0xFFFF, "2300 NVMe SSD [Santana](0x5405)"},
{0x1344, 0x5407, 0xFFFF, 0xFFFF, "3400 NVMe SSD [Hendrix](0x5407)"},
{0x1344, 0x5410, 0xFFFF, 0xFFFF, "2200S NVMe SSD [Cassandra](0x5410)"},
{0x1344, 0x5411, 0xFFFF, 0xFFFF, "2450 NVMe SSD [HendrixV] (DRAM-less)(0x5411)"},
{0x1344, 0x5413, 0xFFFF, 0xFFFF, "2400 NVMe SSD (DRAM-less)(0x5413)"},
{0x1344, 0x5414, 0xFFFF, 0xFFFF, "3460 NVMe SSD(0x5414)"},
{0x1344, 0x5415, 0xFFFF, 0xFFFF, "3500 NVMe SSD(0x5415)"},
{0x1344, 0x5416, 0xFFFF, 0xFFFF, "2550 NVMe SSD (DRAM-less)(0x5416)"},
{0x1344, 0x6001, 0xFFFF, 0xFFFF, "2100AI NVMe SSD [Nitro](0x6001)"},
}; /* pci_vid_1344[] */

static pci_id_t const pci_vid_1345[] = {
{0x1345, 0xFFFF, 0xFFFF, 0xFFFF, "Arescom Inc(0x1345)"},
}; /* pci_vid_1345[] */

static pci_id_t const pci_vid_1347[] = {
{0x1347, 0xFFFF, 0xFFFF, 0xFFFF, "Odetics(0x1347)"},
}; /* pci_vid_1347[] */

static pci_id_t const pci_vid_1349[] = {
{0x1349, 0xFFFF, 0xFFFF, 0xFFFF, "Sumitomo Electric Industries, Ltd.(0x1349)"},
}; /* pci_vid_1349[] */

static pci_id_t const pci_vid_134A[] = {
{0x134A, 0xFFFF, 0xFFFF, 0xFFFF, "DTC Technology Corp.(0x134A)"},
{0x134A, 0x0001, 0xFFFF, 0xFFFF, "Domex 536(0x0001)"},
{0x134A, 0x0002, 0xFFFF, 0xFFFF, "Domex DMX3194UP SCSI Adapter(0x0002)"},
}; /* pci_vid_134A[] */

static pci_id_t const pci_vid_134B[] = {
{0x134B, 0xFFFF, 0xFFFF, 0xFFFF, "ARK Research Corp.(0x134B)"},
}; /* pci_vid_134B[] */

static pci_id_t const pci_vid_134C[] = {
{0x134C, 0xFFFF, 0xFFFF, 0xFFFF, "Chori Joho System Co. Ltd(0x134C)"},
}; /* pci_vid_134C[] */

static pci_id_t const pci_vid_134D[] = {
{0x134D, 0xFFFF, 0xFFFF, 0xFFFF, "PCTel Inc(0x134D)"},
{0x134D, 0x2189, 0xFFFF, 0xFFFF, "HSP56 MicroModem(0x2189)"},
{0x134D, 0x2486, 0xFFFF, 0xFFFF, "2304WT V.92 MDC Modem(0x2486)"},
{0x134D, 0x7890, 0xFFFF, 0xFFFF, "HSP MicroModem 56(0x7890)"},
{0x134D, 0x7890, 0x134D, 0x0001, "PCT789 adapter(0x134D-0x0001)"},
{0x134D, 0x7891, 0xFFFF, 0xFFFF, "HSP MicroModem 56(0x7891)"},
{0x134D, 0x7891, 0x134D, 0x0001, "HSP MicroModem 56(0x134D-0x0001)"},
{0x134D, 0x7892, 0xFFFF, 0xFFFF, "HSP MicroModem 56(0x7892)"},
{0x134D, 0x7893, 0xFFFF, 0xFFFF, "HSP MicroModem 56(0x7893)"},
{0x134D, 0x7894, 0xFFFF, 0xFFFF, "HSP MicroModem 56(0x7894)"},
{0x134D, 0x7895, 0xFFFF, 0xFFFF, "HSP MicroModem 56(0x7895)"},
{0x134D, 0x7896, 0xFFFF, 0xFFFF, "HSP MicroModem 56(0x7896)"},
{0x134D, 0x7897, 0xFFFF, 0xFFFF, "HSP MicroModem 56(0x7897)"},
}; /* pci_vid_134D[] */

static pci_id_t const pci_vid_134E[] = {
{0x134E, 0xFFFF, 0xFFFF, 0xFFFF, "CSTI(0x134E)"},
}; /* pci_vid_134E[] */

static pci_id_t const pci_vid_134F[] = {
{0x134F, 0xFFFF, 0xFFFF, 0xFFFF, "Algo System Co Ltd(0x134F)"},
}; /* pci_vid_134F[] */

static pci_id_t const pci_vid_1350[] = {
{0x1350, 0xFFFF, 0xFFFF, 0xFFFF, "Systec Co. Ltd(0x1350)"},
}; /* pci_vid_1350[] */

static pci_id_t const pci_vid_1351[] = {
{0x1351, 0xFFFF, 0xFFFF, 0xFFFF, "Sonix Inc(0x1351)"},
}; /* pci_vid_1351[] */

static pci_id_t const pci_vid_1353[] = {
{0x1353, 0xFFFF, 0xFFFF, 0xFFFF, "dbeeSet Technology(0x1353)"},
{0x1353, 0x0002, 0xFFFF, 0xFFFF, "Proserver(0x0002)"},
{0x1353, 0x0003, 0xFFFF, 0xFFFF, "PCI-FUT(0x0003)"},
{0x1353, 0x0004, 0xFFFF, 0xFFFF, "PCI-S0(0x0004)"},
{0x1353, 0x0005, 0xFFFF, 0xFFFF, "PCI-FUT-S0(0x0005)"},
{0x1353, 0x0006, 0xFFFF, 0xFFFF, "OTDU-1U (FPGA Zynq-7000)(0x0006)"},
{0x1353, 0x0007, 0xFFFF, 0xFFFF, "OTDU-EX(0x0007)"},
}; /* pci_vid_1353[] */

static pci_id_t const pci_vid_1354[] = {
{0x1354, 0xFFFF, 0xFFFF, 0xFFFF, "Dwave System Inc(0x1354)"},
}; /* pci_vid_1354[] */

static pci_id_t const pci_vid_1355[] = {
{0x1355, 0xFFFF, 0xFFFF, 0xFFFF, "Kratos Analytical Ltd(0x1355)"},
}; /* pci_vid_1355[] */

static pci_id_t const pci_vid_1356[] = {
{0x1356, 0xFFFF, 0xFFFF, 0xFFFF, "The Logical Co(0x1356)"},
}; /* pci_vid_1356[] */

static pci_id_t const pci_vid_1359[] = {
{0x1359, 0xFFFF, 0xFFFF, 0xFFFF, "Prisa Networks(0x1359)"},
}; /* pci_vid_1359[] */

static pci_id_t const pci_vid_135A[] = {
{0x135A, 0xFFFF, 0xFFFF, 0xFFFF, "Brainboxes Ltd(0x135A)"},
{0x135A, 0x0841, 0xFFFF, 0xFFFF, "UC-268 4 port RS-232 card(0x0841)"},
{0x135A, 0x0861, 0xFFFF, 0xFFFF, "UC-257 2 port RS-232 + LPT card(0x0861)"},
{0x135A, 0x0862, 0xFFFF, 0xFFFF, "UC-257 2 port RS-232 + LPT card(0x0862)"},
{0x135A, 0x0863, 0xFFFF, 0xFFFF, "UC-257 2 port RS-232 + LPT card(0x0863)"},
{0x135A, 0x0881, 0xFFFF, 0xFFFF, "UC-279 8 port RS-232 card(0x0881)"},
{0x135A, 0x08A1, 0xFFFF, 0xFFFF, "UC-313 2 port RS-422/485 card(0x08A1)"},
{0x135A, 0x08A2, 0xFFFF, 0xFFFF, "UC-313 2 port RS-422/485 card(0x08A2)"},
{0x135A, 0x08A3, 0xFFFF, 0xFFFF, "UC-313 2 port RS-422/485 card(0x08A3)"},
{0x135A, 0x08C1, 0xFFFF, 0xFFFF, "UC-310 2 port RS-422/485 Opto Isolated card(0x08C1)"},
{0x135A, 0x08E1, 0xFFFF, 0xFFFF, "UC-302 2 port RS-232 card(0x08E1)"},
{0x135A, 0x08E2, 0xFFFF, 0xFFFF, "UC-302 2 port RS-232 card(0x08E2)"},
{0x135A, 0x08E3, 0xFFFF, 0xFFFF, "UC-302 2 port RS-232 card(0x08E3)"},
{0x135A, 0x0901, 0xFFFF, 0xFFFF, "UC-431 3 port RS-232 card(0x0901)"},
{0x135A, 0x0921, 0xFFFF, 0xFFFF, "UC-420 3 + 1 port RS-232 card(0x0921)"},
{0x135A, 0x0981, 0xFFFF, 0xFFFF, "UC-475 1 + 1 port RS-232 + LPT card(0x0981)"},
{0x135A, 0x0982, 0xFFFF, 0xFFFF, "UC-475 1 + 1 port RS-232 + LPT card(0x0982)"},
{0x135A, 0x09A1, 0xFFFF, 0xFFFF, "UC-607 2 port RS-232 card(0x09A1)"},
{0x135A, 0x09A2, 0xFFFF, 0xFFFF, "UC-607 2 port RS-232 card(0x09A2)"},
{0x135A, 0x09A3, 0xFFFF, 0xFFFF, "UC-607 2 port RS-232 card(0x09A3)"},
{0x135A, 0x0A61, 0xFFFF, 0xFFFF, "UC-324 1 port RS-422/485 card(0x0A61)"},
{0x135A, 0x0A81, 0xFFFF, 0xFFFF, "UC-357 1 port RS-232 + 1 port RS-422/485 card(0x0A81)"},
{0x135A, 0x0A82, 0xFFFF, 0xFFFF, "UC-357 1 port RS-232 + 1 port RS-422/485 card(0x0A82)"},
{0x135A, 0x0A83, 0xFFFF, 0xFFFF, "UC-357 1 port RS-232 + 1 port RS-422/485 card(0x0A83)"},
{0x135A, 0x0AA1, 0xFFFF, 0xFFFF, "UC-246 1 port RS-232 card(0x0AA1)"},
{0x135A, 0x0AA2, 0xFFFF, 0xFFFF, "UC-246 1 port RS-232 card(0x0AA2)"},
{0x135A, 0x0AC1, 0xFFFF, 0xFFFF, "UP-189 Powered 2 port RS-232 card(0x0AC1)"},
{0x135A, 0x0AC2, 0xFFFF, 0xFFFF, "UP-189 Powered 2 port RS-232 card(0x0AC2)"},
{0x135A, 0x0AC3, 0xFFFF, 0xFFFF, "UP-189 Powered 2 port RS-232 card(0x0AC3)"},
{0x135A, 0x0B01, 0xFFFF, 0xFFFF, "UC-346 4 port RS-422/485 card(0x0B01)"},
{0x135A, 0x0B02, 0xFFFF, 0xFFFF, "UC-346 4 port RS-422/485 card(0x0B02)"},
{0x135A, 0x0B21, 0xFFFF, 0xFFFF, "UP-200 Powered 2 port RS-232 card(0x0B21)"},
{0x135A, 0x0B22, 0xFFFF, 0xFFFF, "UP-200 Powered 2 port RS-232 card(0x0B22)"},
{0x135A, 0x0B23, 0xFFFF, 0xFFFF, "UP-200 Powered 2 port RS-232 card(0x0B23)"},
{0x135A, 0x0BA1, 0xFFFF, 0xFFFF, "UC-101 1 + 1 port RS-232 card(0x0BA1)"},
{0x135A, 0x0BC1, 0xFFFF, 0xFFFF, "UC-203 1 + 1 port RS-232 + LPT card(0x0BC1)"},
{0x135A, 0x0BC2, 0xFFFF, 0xFFFF, "UC-203 1 + 1 port RS-232 + LPT card(0x0BC2)"},
{0x135A, 0x0BE1, 0xFFFF, 0xFFFF, "UC-146 LPT card(0x0BE1)"},
{0x135A, 0x0BE2, 0xFFFF, 0xFFFF, "UC-146 LPT card(0x0BE2)"},
{0x135A, 0x0C01, 0xFFFF, 0xFFFF, "UP-869 Powered 2 port RS-232 card(0x0C01)"},
{0x135A, 0x0C02, 0xFFFF, 0xFFFF, "UP-869 Powered 2 port RS-232 card(0x0C02)"},
{0x135A, 0x0C03, 0xFFFF, 0xFFFF, "UP-869 Powered 2 port RS-232 card(0x0C03)"},
{0x135A, 0x0C21, 0xFFFF, 0xFFFF, "UP-880 Powered 2 port RS-232 card(0x0C21)"},
{0x135A, 0x0C22, 0xFFFF, 0xFFFF, "UP-880 Powered 2 port RS-232 card(0x0C22)"},
{0x135A, 0x0C23, 0xFFFF, 0xFFFF, "UP-880 Powered 2 port RS-232 card(0x0C23)"},
{0x135A, 0x0C41, 0xFFFF, 0xFFFF, "UC-368 4 port RS-422/485 Opto Isolated card(0x0C41)"},
{0x135A, 0x0CA1, 0xFFFF, 0xFFFF, "UC-253 2 port RS-232 card(0x0CA1)"},
{0x135A, 0x0D21, 0xFFFF, 0xFFFF, "UC-260 4 port RS-232 card(0x0D21)"},
{0x135A, 0x0D41, 0xFFFF, 0xFFFF, "UC-836 4 port RS-232 card(0x0D41)"},
{0x135A, 0x0D60, 0xFFFF, 0xFFFF, "IS-100 1 port RS-232 card(0x0D60)"},
{0x135A, 0x0D80, 0xFFFF, 0xFFFF, "IS-200 2 port RS-232 card(0x0D80)"},
{0x135A, 0x0DA0, 0xFFFF, 0xFFFF, "IS-300 1 port RS-232 + LPT card(0x0DA0)"},
{0x135A, 0x0DC0, 0xFFFF, 0xFFFF, "IS-400 4 port RS-232 card(0x0DC0)"},
{0x135A, 0x0DE0, 0xFFFF, 0xFFFF, "IS-500 LPT card(0x0DE0)"},
{0x135A, 0x0E41, 0xFFFF, 0xFFFF, "PX-279 8 port RS-232 card(0x0E41)"},
{0x135A, 0x0E61, 0xFFFF, 0xFFFF, "UC-414 3 + 1 port RS-232 + LPT card(0x0E61)"},
{0x135A, 0x4000, 0xFFFF, 0xFFFF, "PX-420 3 + 1 port RS-232 card(0x4000)"},
{0x135A, 0x4001, 0xFFFF, 0xFFFF, "PX-431 3 port RS-232 card(0x4001)"},
{0x135A, 0x4002, 0xFFFF, 0xFFFF, "PX-820 Powered 3 + 1 port RS-232 card(0x4002)"},
{0x135A, 0x4003, 0xFFFF, 0xFFFF, "PX-831 Powered 3 port RS-232 card(0x4003)"},
{0x135A, 0x4004, 0xFFFF, 0xFFFF, "PX-235 1 port RS-232 card(0x4004)"},
{0x135A, 0x4005, 0xFFFF, 0xFFFF, "PX-101 1 + 1 port RS-232 card(0x4005)"},
{0x135A, 0x4006, 0xFFFF, 0xFFFF, "PX-257 1 + 1 port RS-232 + LPT card (Serial port)(0x4006)"},
{0x135A, 0x4007, 0xFFFF, 0xFFFF, "PX-257 1 + 1 port RS-232 + LPT card (LPT port)(0x4007)"},
{0x135A, 0x4008, 0xFFFF, 0xFFFF, "PX-835 Powered 1 port RS-232 card(0x4008)"},
{0x135A, 0x4009, 0xFFFF, 0xFFFF, "PX-857 Powered 2 port RS-232 card(0x4009)"},
{0x135A, 0x400A, 0xFFFF, 0xFFFF, "PX-260 4 port RS-232 card(0x400A)"},
{0x135A, 0x400B, 0xFFFF, 0xFFFF, "PX-320 1 port RS-422/485 card(0x400B)"},
{0x135A, 0x400C, 0xFFFF, 0xFFFF, "PX-313 2 port RS-422/485 card(0x400C)"},
{0x135A, 0x400E, 0xFFFF, 0xFFFF, "PX-310 2 port RS-422/485 Opto Isolated card(0x400E)"},
{0x135A, 0x400F, 0xFFFF, 0xFFFF, "PX-346 4 port RS-422/485 card(0x400F)"},
{0x135A, 0x4010, 0xFFFF, 0xFFFF, "PX-368 4 port RS-422/485 Opto Isolated card(0x4010)"},
{0x135A, 0x4011, 0xFFFF, 0xFFFF, "PX-420 3 + 1 port RS-232 card(0x4011)"},
{0x135A, 0x4012, 0xFFFF, 0xFFFF, "PX-431 3 port RS-232 card(0x4012)"},
{0x135A, 0x4013, 0xFFFF, 0xFFFF, "PX-820 Powered 3 + 1 port RS-232 card(0x4013)"},
{0x135A, 0x4014, 0xFFFF, 0xFFFF, "PX-831 Powered 3 port RS-232 card(0x4014)"},
{0x135A, 0x4015, 0xFFFF, 0xFFFF, "PX-257 2 port RS-232 card(0x4015)"},
{0x135A, 0x4016, 0xFFFF, 0xFFFF, "PX-235 1 port RS-232 card(0x4016)"},
{0x135A, 0x4017, 0xFFFF, 0xFFFF, "PX-835 Powered 1 port RS-232 card(0x4017)"},
{0x135A, 0x4018, 0xFFFF, 0xFFFF, "PX-857 Powered 2 port RS-232 card(0x4018)"},
{0x135A, 0x4019, 0xFFFF, 0xFFFF, "PX-101 1 + 1 port RS-232 card(0x4019)"},
{0x135A, 0x401C, 0xFFFF, 0xFFFF, "PX-146 LPT card(0x401C)"},
{0x135A, 0x401D, 0xFFFF, 0xFFFF, "PX-475 1 port RS-232 + LPT card (Serial port)(0x401D)"},
{0x135A, 0x401E, 0xFFFF, 0xFFFF, "PX-803 Powered 1 + 1 port RS-232 card(0x401E)"},
{0x135A, 0x401F, 0xFFFF, 0xFFFF, "PX-475 1 port RS-232 + LPT card (LPT port)(0x401F)"},
{0x135A, 0x4027, 0xFFFF, 0xFFFF, "IX-100 1 port RS-232 card(0x4027)"},
{0x135A, 0x4028, 0xFFFF, 0xFFFF, "IX-200 2 port RS-232 card(0x4028)"},
{0x135A, 0x4029, 0xFFFF, 0xFFFF, "IX-400 4 port RS-232 card(0x4029)"},
{0x135A, 0x402A, 0xFFFF, 0xFFFF, "IX-500 LPT card(0x402A)"},
{0x135A, 0x402C, 0xFFFF, 0xFFFF, "PX-263 4 port RS-232 + LPT card(0x402C)"},
{0x135A, 0x4100, 0xFFFF, 0xFFFF, "PX-272 4 + 1 port RS-232 + LPT card(0x4100)"},
}; /* pci_vid_135A[] */

static pci_id_t const pci_vid_135B[] = {
{0x135B, 0xFFFF, 0xFFFF, 0xFFFF, "Giganet Inc(0x135B)"},
}; /* pci_vid_135B[] */

static pci_id_t const pci_vid_135C[] = {
{0x135C, 0xFFFF, 0xFFFF, 0xFFFF, "Quatech Inc(0x135C)"},
{0x135C, 0x0010, 0xFFFF, 0xFFFF, "QSC-100(0x0010)"},
{0x135C, 0x0020, 0xFFFF, 0xFFFF, "DSC-100(0x0020)"},
{0x135C, 0x0030, 0xFFFF, 0xFFFF, "DSC-200/300(0x0030)"},
{0x135C, 0x0040, 0xFFFF, 0xFFFF, "QSC-200/300(0x0040)"},
{0x135C, 0x0050, 0xFFFF, 0xFFFF, "ESC-100D(0x0050)"},
{0x135C, 0x0060, 0xFFFF, 0xFFFF, "ESC-100M(0x0060)"},
{0x135C, 0x00F0, 0xFFFF, 0xFFFF, "MPAC-100 Synchronous Serial Card (Zilog 85230)(0x00F0)"},
{0x135C, 0x0120, 0xFFFF, 0xFFFF, "QSCP-100(0x0120)"},
{0x135C, 0x0130, 0xFFFF, 0xFFFF, "DSCP-100(0x0130)"},
{0x135C, 0x0140, 0xFFFF, 0xFFFF, "QSCP-200/300(0x0140)"},
{0x135C, 0x0150, 0xFFFF, 0xFFFF, "DSCP-200/300(0x0150)"},
{0x135C, 0x0170, 0xFFFF, 0xFFFF, "QSCLP-100(0x0170)"},
{0x135C, 0x0180, 0xFFFF, 0xFFFF, "DSCLP-100(0x0180)"},
{0x135C, 0x0181, 0xFFFF, 0xFFFF, "DSC-100(0x0181)"},
{0x135C, 0x0190, 0xFFFF, 0xFFFF, "SSCLP-100(0x0190)"},
{0x135C, 0x01A0, 0xFFFF, 0xFFFF, "QSCLP-200/300(0x01A0)"},
{0x135C, 0x01B0, 0xFFFF, 0xFFFF, "DSCLP-200/300(0x01B0)"},
{0x135C, 0x01B1, 0xFFFF, 0xFFFF, "DSC-200/300(0x01B1)"},
{0x135C, 0x01C0, 0xFFFF, 0xFFFF, "SSCLP-200/300(0x01C0)"},
{0x135C, 0x01E0, 0xFFFF, 0xFFFF, "ESC(LP)-100(0x01E0)"},
{0x135C, 0x0258, 0xFFFF, 0xFFFF, "DSPSX-200/300(0x0258)"},
}; /* pci_vid_135C[] */

static pci_id_t const pci_vid_135D[] = {
{0x135D, 0xFFFF, 0xFFFF, 0xFFFF, "ABB Network Partner AB(0x135D)"},
}; /* pci_vid_135D[] */

static pci_id_t const pci_vid_135E[] = {
{0x135E, 0xFFFF, 0xFFFF, 0xFFFF, "Sealevel Systems Inc(0x135E)"},
{0x135E, 0x5101, 0xFFFF, 0xFFFF, "Route 56.PCI - Multi-Protocol Serial Interface (Zilog Z16C32)(0x5101)"},
{0x135E, 0x7101, 0xFFFF, 0xFFFF, "Single Port RS-232/422/485/530(0x7101)"},
{0x135E, 0x7201, 0xFFFF, 0xFFFF, "Dual Port RS-232/422/485 Interface(0x7201)"},
{0x135E, 0x7202, 0xFFFF, 0xFFFF, "Dual Port RS-232 Interface(0x7202)"},
{0x135E, 0x7401, 0xFFFF, 0xFFFF, "Four Port RS-232 Interface(0x7401)"},
{0x135E, 0x7402, 0xFFFF, 0xFFFF, "Four Port RS-422/485 Interface(0x7402)"},
{0x135E, 0x7801, 0xFFFF, 0xFFFF, "Eight Port RS-232 Interface(0x7801)"},
{0x135E, 0x7804, 0xFFFF, 0xFFFF, "Eight Port RS-232/422/485 Interface(0x7804)"},
{0x135E, 0x8001, 0xFFFF, 0xFFFF, "8001 Digital I/O Adapter(0x8001)"},
}; /* pci_vid_135E[] */

static pci_id_t const pci_vid_135F[] = {
{0x135F, 0xFFFF, 0xFFFF, 0xFFFF, "I-Data International A-S(0x135F)"},
}; /* pci_vid_135F[] */

static pci_id_t const pci_vid_1360[] = {
{0x1360, 0xFFFF, 0xFFFF, 0xFFFF, "Meinberg Funkuhren(0x1360)"},
{0x1360, 0x0101, 0xFFFF, 0xFFFF, "PCI32 DCF77 Radio Clock(0x0101)"},
{0x1360, 0x0102, 0xFFFF, 0xFFFF, "PCI509 DCF77 Radio Clock(0x0102)"},
{0x1360, 0x0103, 0xFFFF, 0xFFFF, "PCI510 DCF77 Radio Clock(0x0103)"},
{0x1360, 0x0104, 0xFFFF, 0xFFFF, "PCI511 DCF77 Radio Clock(0x0104)"},
{0x1360, 0x0105, 0xFFFF, 0xFFFF, "PEX511 DCF77 Radio Clock (PCI Express)(0x0105)"},
{0x1360, 0x0106, 0xFFFF, 0xFFFF, "PZF180PEX High Precision DCF77 Radio Clock (PCI Express)(0x0106)"},
{0x1360, 0x0201, 0xFFFF, 0xFFFF, "GPS167PCI GPS Receiver(0x0201)"},
{0x1360, 0x0202, 0xFFFF, 0xFFFF, "GPS168PCI GPS Receiver(0x0202)"},
{0x1360, 0x0203, 0xFFFF, 0xFFFF, "GPS169PCI GPS Receiver(0x0203)"},
{0x1360, 0x0204, 0xFFFF, 0xFFFF, "GPS170PCI GPS Receiver(0x0204)"},
{0x1360, 0x0205, 0xFFFF, 0xFFFF, "GPS170PEX GPS Receiver (PCI Express)(0x0205)"},
{0x1360, 0x0206, 0xFFFF, 0xFFFF, "GPS180PEX GPS Receiver (PCI Express)(0x0206)"},
{0x1360, 0x0207, 0xFFFF, 0xFFFF, "GLN180PEX GPS/GLONASS receiver (PCI Express)(0x0207)"},
{0x1360, 0x0208, 0xFFFF, 0xFFFF, "GPS180AMC GPS Receiver (PCI Express / MicroTCA / AdvancedMC)(0x0208)"},
{0x1360, 0x0209, 0xFFFF, 0xFFFF, "GNS181PEX GPS/Galileo/GLONASS/BEIDOU receiver (PCI Express)(0x0209)"},
{0x1360, 0x0301, 0xFFFF, 0xFFFF, "TCR510PCI IRIG Timecode Reader(0x0301)"},
{0x1360, 0x0302, 0xFFFF, 0xFFFF, "TCR167PCI IRIG Timecode Reader(0x0302)"},
{0x1360, 0x0303, 0xFFFF, 0xFFFF, "TCR511PCI IRIG Timecode Reader(0x0303)"},
{0x1360, 0x0304, 0xFFFF, 0xFFFF, "TCR511PEX IRIG Timecode Reader (PCI Express)(0x0304)"},
{0x1360, 0x0305, 0xFFFF, 0xFFFF, "TCR170PEX IRIG Timecode Reader (PCI Express)(0x0305)"},
{0x1360, 0x0306, 0xFFFF, 0xFFFF, "TCR180PEX IRIG Timecode Reader (PCI Express)(0x0306)"},
{0x1360, 0x0501, 0xFFFF, 0xFFFF, "PTP270PEX PTP/IEEE1588 slave card (PCI Express)(0x0501)"},
{0x1360, 0x0601, 0xFFFF, 0xFFFF, "FRC511PEX Free Running Clock (PCI Express)(0x0601)"},
}; /* pci_vid_1360[] */

static pci_id_t const pci_vid_1361[] = {
{0x1361, 0xFFFF, 0xFFFF, 0xFFFF, "Soliton Systems K.K.(0x1361)"},
}; /* pci_vid_1361[] */

static pci_id_t const pci_vid_1362[] = {
{0x1362, 0xFFFF, 0xFFFF, 0xFFFF, "Fujifacom Corporation(0x1362)"},
}; /* pci_vid_1362[] */

static pci_id_t const pci_vid_1363[] = {
{0x1363, 0xFFFF, 0xFFFF, 0xFFFF, "Phoenix Technology Ltd(0x1363)"},
}; /* pci_vid_1363[] */

static pci_id_t const pci_vid_1364[] = {
{0x1364, 0xFFFF, 0xFFFF, 0xFFFF, "ATM Communications Inc(0x1364)"},
}; /* pci_vid_1364[] */

static pci_id_t const pci_vid_1365[] = {
{0x1365, 0xFFFF, 0xFFFF, 0xFFFF, "Hypercope GmbH(0x1365)"},
}; /* pci_vid_1365[] */

static pci_id_t const pci_vid_1366[] = {
{0x1366, 0xFFFF, 0xFFFF, 0xFFFF, "Teijin Seiki Co. Ltd(0x1366)"},
}; /* pci_vid_1366[] */

static pci_id_t const pci_vid_1367[] = {
{0x1367, 0xFFFF, 0xFFFF, 0xFFFF, "Hitachi Zosen Corporation(0x1367)"},
}; /* pci_vid_1367[] */

static pci_id_t const pci_vid_1368[] = {
{0x1368, 0xFFFF, 0xFFFF, 0xFFFF, "Skyware Corporation(0x1368)"},
}; /* pci_vid_1368[] */

static pci_id_t const pci_vid_1369[] = {
{0x1369, 0xFFFF, 0xFFFF, 0xFFFF, "Digigram(0x1369)"},
}; /* pci_vid_1369[] */

static pci_id_t const pci_vid_136A[] = {
{0x136A, 0xFFFF, 0xFFFF, 0xFFFF, "High Soft Tech(0x136A)"},
{0x136A, 0x0004, 0xFFFF, 0xFFFF, "HST Saphir VII mini PCI(0x0004)"},
{0x136A, 0x0007, 0xFFFF, 0xFFFF, "HST Saphir III E MultiLink 4(0x0007)"},
{0x136A, 0x0008, 0xFFFF, 0xFFFF, "HST Saphir III E MultiLink 8(0x0008)"},
{0x136A, 0x000A, 0xFFFF, 0xFFFF, "HST Saphir III E MultiLink 2(0x000A)"},
}; /* pci_vid_136A[] */

static pci_id_t const pci_vid_136B[] = {
{0x136B, 0xFFFF, 0xFFFF, 0xFFFF, "Kawasaki Steel Corporation(0x136B)"},
{0x136B, 0xFF01, 0xFFFF, 0xFFFF, "KL5A72002 Motion JPEG(0xFF01)"},
}; /* pci_vid_136B[] */

static pci_id_t const pci_vid_136C[] = {
{0x136C, 0xFFFF, 0xFFFF, 0xFFFF, "Adtek System Science Co Ltd(0x136C)"},
}; /* pci_vid_136C[] */

static pci_id_t const pci_vid_136D[] = {
{0x136D, 0xFFFF, 0xFFFF, 0xFFFF, "Gigalabs Inc(0x136D)"},
}; /* pci_vid_136D[] */

static pci_id_t const pci_vid_136F[] = {
{0x136F, 0xFFFF, 0xFFFF, 0xFFFF, "Applied Magic Inc(0x136F)"},
}; /* pci_vid_136F[] */

static pci_id_t const pci_vid_1370[] = {
{0x1370, 0xFFFF, 0xFFFF, 0xFFFF, "ATL Products(0x1370)"},
}; /* pci_vid_1370[] */

static pci_id_t const pci_vid_1371[] = {
{0x1371, 0xFFFF, 0xFFFF, 0xFFFF, "CNet Technology Inc(0x1371)"},
{0x1371, 0x434E, 0xFFFF, 0xFFFF, "GigaCard Network Adapter(0x434E)"},
{0x1371, 0x434E, 0x1371, 0x434E, "N-Way PCI-Bus Giga-Card 1000/100/10Mbps(L)(0x1371-0x434E)"},
}; /* pci_vid_1371[] */

static pci_id_t const pci_vid_1373[] = {
{0x1373, 0xFFFF, 0xFFFF, 0xFFFF, "Silicon Vision Inc(0x1373)"},
}; /* pci_vid_1373[] */

static pci_id_t const pci_vid_1374[] = {
{0x1374, 0xFFFF, 0xFFFF, 0xFFFF, "Silicom Ltd.(0x1374)"},
{0x1374, 0x0024, 0xFFFF, 0xFFFF, "Silicom Dual port Giga Ethernet BGE Bypass Server Adapter(0x0024)"},
{0x1374, 0x0025, 0xFFFF, 0xFFFF, "Silicom Quad port Giga Ethernet BGE Bypass Server Adapter(0x0025)"},
{0x1374, 0x0026, 0xFFFF, 0xFFFF, "Silicom Dual port Fiber Giga Ethernet 546 Bypass Server Adapter(0x0026)"},
{0x1374, 0x0027, 0xFFFF, 0xFFFF, "Silicom Dual port Fiber LX Giga Ethernet 546 Bypass Server Adapter(0x0027)"},
{0x1374, 0x0029, 0xFFFF, 0xFFFF, "Silicom Dual port Copper Giga Ethernet 546GB Bypass Server Adapter(0x0029)"},
{0x1374, 0x002A, 0xFFFF, 0xFFFF, "Silicom Dual port Fiber Giga Ethernet 546 TAP/Bypass Server Adapter(0x002A)"},
{0x1374, 0x002B, 0xFFFF, 0xFFFF, "Silicom Dual port Copper Fast Ethernet 546 TAP/Bypass Server Adapter (PXE2TBI)(0x002B)"},
{0x1374, 0x002C, 0xFFFF, 0xFFFF, "Silicom Quad port Copper Giga Ethernet 546GB Bypass Server Adapter (PXG4BPI)(0x002C)"},
{0x1374, 0x002D, 0xFFFF, 0xFFFF, "Silicom Quad port Fiber-SX Giga Ethernet 546GB Bypass Server Adapter (PXG4BPFI)(0x002D)"},
{0x1374, 0x002E, 0xFFFF, 0xFFFF, "Silicom Quad port Fiber-LX Giga Ethernet 546GB Bypass Server Adapter (PXG4BPFI-LX)(0x002E)"},
{0x1374, 0x002F, 0xFFFF, 0xFFFF, "Silicom Dual port Fiber-SX Giga Ethernet 546GB Low profile Bypass Server Adapter (PXG2BPFIL)(0x002F)"},
{0x1374, 0x0030, 0xFFFF, 0xFFFF, "Silicom Dual port Fiber-LX Giga Ethernet 546GB Low profile Bypass Server Adapter(0x0030)"},
{0x1374, 0x0031, 0xFFFF, 0xFFFF, "Silicom Quad port Copper Giga Ethernet PCI-E Bypass Server Adapter(0x0031)"},
{0x1374, 0x0032, 0xFFFF, 0xFFFF, "Silicom Dual port Copper Fast Ethernet 546 TAP/Bypass Server Adapter(0x0032)"},
{0x1374, 0x0034, 0xFFFF, 0xFFFF, "Silicom Dual port Copper Giga Ethernet PCI-E BGE Bypass Server Adapter(0x0034)"},
{0x1374, 0x0035, 0xFFFF, 0xFFFF, "Silicom Quad port Copper Giga Ethernet PCI-E BGE Bypass Server Adapter(0x0035)"},
{0x1374, 0x0036, 0xFFFF, 0xFFFF, "Silicom Dual port Fiber Giga Ethernet PCI-E BGE Bypass Server Adapter(0x0036)"},
{0x1374, 0x0037, 0xFFFF, 0xFFFF, "Silicom Dual port Copper Ethernet PCI-E Intel based Bypass Server Adapter(0x0037)"},
{0x1374, 0x0038, 0xFFFF, 0xFFFF, "Silicom Quad port Copper Ethernet PCI-E Intel based Bypass Server Adapter(0x0038)"},
{0x1374, 0x0039, 0xFFFF, 0xFFFF, "Silicom Dual port Fiber-SX Ethernet PCI-E Intel based Bypass Server Adapter(0x0039)"},
{0x1374, 0x003A, 0xFFFF, 0xFFFF, "Silicom Dual port Fiber-LX Ethernet PCI-E Intel based Bypass Server Adapter(0x003A)"},
{0x1374, 0x003B, 0xFFFF, 0xFFFF, "Silicom Dual port Fiber Ethernet PMC Intel based Bypass Server Adapter (PMCX2BPFI)(0x003B)"},
{0x1374, 0x003C, 0xFFFF, 0xFFFF, "Silicom Dual port Copper Ethernet PCI-X BGE based Bypass Server Adapter (PXG2BPRB)(0x003C)"},
{0x1374, 0x003D, 0xFFFF, 0xFFFF, "2-port Copper GBE Bypass with Caviume 1010 PCI-X(0x003D)"},
{0x1374, 0x003E, 0xFFFF, 0xFFFF, "Silicom Dual port Fiber Giga Ethernet PCI-E 571 TAP/Bypass Server Adapter (PEG2TBFI)(0x003E)"},
{0x1374, 0x003F, 0xFFFF, 0xFFFF, "Silicom Dual port Copper Giga Ethernet PCI-X 546 TAP/Bypass Server Adapter (PXG2TBI)(0x003F)"},
{0x1374, 0x0040, 0xFFFF, 0xFFFF, "Silicom Quad port Fiber-SX Giga Ethernet 571 Bypass Server Adapter (PEG4BPFI)(0x0040)"},
{0x1374, 0x0042, 0xFFFF, 0xFFFF, "4-port Copper GBE PMC-X Bypass(0x0042)"},
{0x1374, 0x0043, 0xFFFF, 0xFFFF, "Silicom Quad port Fiber-SX Giga Ethernet 546 Bypass Server Adapter (PXG4BPFID)(0x0043)"},
{0x1374, 0x0045, 0xFFFF, 0xFFFF, "Silicom 6 port Copper Giga Ethernet 546 Bypass Server Adapter (PXG6BPI)(0x0045)"},
{0x1374, 0x0046, 0xFFFF, 0xFFFF, "4-port bypass PCI-E w disconnect low profile(0x0046)"},
{0x1374, 0x0047, 0xFFFF, 0xFFFF, "Silicom Dual port Fiber-SX Giga Ethernet 571 Bypass Disconnect Server Adapter (PEG2BPFID)(0x0047)"},
{0x1374, 0x004A, 0xFFFF, 0xFFFF, "Silicom Quad port Fiber-LX Giga Ethernet 571 Bypass Server Adapter (PEG4BPFI-LX)(0x004A)"},
{0x1374, 0x004D, 0xFFFF, 0xFFFF, "Dual port Copper Giga Ethernet PCI-E Bypass Server Adapter(0x004D)"},
{0x1374, 0x0401, 0xFFFF, 0xFFFF, "Gigabit Ethernet ExpressModule Bypass Server Adapter(0x0401)"},
{0x1374, 0x0420, 0xFFFF, 0xFFFF, "Gigabit Ethernet ExpressModule Bypass Server Adapter(0x0420)"},
{0x1374, 0x0460, 0xFFFF, 0xFFFF, "Gigabit Ethernet Express Module Bypass Server Adapter(0x0460)"},
{0x1374, 0x0461, 0xFFFF, 0xFFFF, "Gigabit Ethernet ExpressModule Bypass Server Adapter(0x0461)"},
{0x1374, 0x0462, 0xFFFF, 0xFFFF, "Gigabit Ethernet ExpressModule Bypass Server Adapter(0x0462)"},
{0x1374, 0x0470, 0xFFFF, 0xFFFF, "Octal-port Copper Gigabit Ethernet Express Module Bypass Server Adapter(0x0470)"},
{0x1374, 0x0482, 0xFFFF, 0xFFFF, "Dual-port Fiber (SR) 10 Gigabit Ethernet ExpressModule Bypass Server Adapter(0x0482)"},
{0x1374, 0x0483, 0xFFFF, 0xFFFF, "Dual-port Fiber (LR) 10 Gigabit Ethernet ExpressModule Bypass Server Adapter(0x0483)"},
}; /* pci_vid_1374[] */

static pci_id_t const pci_vid_1375[] = {
{0x1375, 0xFFFF, 0xFFFF, 0xFFFF, "Argosystems Inc(0x1375)"},
}; /* pci_vid_1375[] */

static pci_id_t const pci_vid_1376[] = {
{0x1376, 0xFFFF, 0xFFFF, 0xFFFF, "LMC(0x1376)"},
}; /* pci_vid_1376[] */

static pci_id_t const pci_vid_1377[] = {
{0x1377, 0xFFFF, 0xFFFF, 0xFFFF, "Electronic Equipment Production & Distribution GmbH(0x1377)"},
}; /* pci_vid_1377[] */

static pci_id_t const pci_vid_1378[] = {
{0x1378, 0xFFFF, 0xFFFF, 0xFFFF, "Telemann Co. Ltd(0x1378)"},
}; /* pci_vid_1378[] */

static pci_id_t const pci_vid_1379[] = {
{0x1379, 0xFFFF, 0xFFFF, 0xFFFF, "Asahi Kasei Microsystems Co Ltd(0x1379)"},
}; /* pci_vid_1379[] */

static pci_id_t const pci_vid_137A[] = {
{0x137A, 0xFFFF, 0xFFFF, 0xFFFF, "Mark of the Unicorn Inc(0x137A)"},
{0x137A, 0x0001, 0xFFFF, 0xFFFF, "PCI-324 Audiowire Interface(0x0001)"},
}; /* pci_vid_137A[] */

static pci_id_t const pci_vid_137B[] = {
{0x137B, 0xFFFF, 0xFFFF, 0xFFFF, "PPT Vision(0x137B)"},
}; /* pci_vid_137B[] */

static pci_id_t const pci_vid_137C[] = {
{0x137C, 0xFFFF, 0xFFFF, 0xFFFF, "Iwatsu Electric Co Ltd(0x137C)"},
}; /* pci_vid_137C[] */

static pci_id_t const pci_vid_137D[] = {
{0x137D, 0xFFFF, 0xFFFF, 0xFFFF, "Dynachip Corporation(0x137D)"},
}; /* pci_vid_137D[] */

static pci_id_t const pci_vid_137E[] = {
{0x137E, 0xFFFF, 0xFFFF, 0xFFFF, "Patriot Scientific Corporation(0x137E)"},
}; /* pci_vid_137E[] */

static pci_id_t const pci_vid_137F[] = {
{0x137F, 0xFFFF, 0xFFFF, 0xFFFF, "Japan Satellite Systems Inc(0x137F)"},
}; /* pci_vid_137F[] */

static pci_id_t const pci_vid_1380[] = {
{0x1380, 0xFFFF, 0xFFFF, 0xFFFF, "Sanritz Automation Co Ltd(0x1380)"},
}; /* pci_vid_1380[] */

static pci_id_t const pci_vid_1381[] = {
{0x1381, 0xFFFF, 0xFFFF, 0xFFFF, "Brains Co. Ltd(0x1381)"},
}; /* pci_vid_1381[] */

static pci_id_t const pci_vid_1382[] = {
{0x1382, 0xFFFF, 0xFFFF, 0xFFFF, "Marian - Electronic & Software(0x1382)"},
{0x1382, 0x0001, 0xFFFF, 0xFFFF, "ARC88 audio recording card(0x0001)"},
{0x1382, 0x2008, 0xFFFF, 0xFFFF, "Prodif 96 Pro sound system(0x2008)"},
{0x1382, 0x2048, 0xFFFF, 0xFFFF, "Prodif Plus sound system(0x2048)"},
{0x1382, 0x2088, 0xFFFF, 0xFFFF, "Marc 8 Midi sound system(0x2088)"},
{0x1382, 0x20C8, 0xFFFF, 0xFFFF, "Marc A sound system(0x20C8)"},
{0x1382, 0x4008, 0xFFFF, 0xFFFF, "Marc 2 sound system(0x4008)"},
{0x1382, 0x4010, 0xFFFF, 0xFFFF, "Marc 2 Pro sound system(0x4010)"},
{0x1382, 0x4048, 0xFFFF, 0xFFFF, "Marc 4 MIDI sound system(0x4048)"},
{0x1382, 0x4088, 0xFFFF, 0xFFFF, "Marc 4 Digi sound system(0x4088)"},
{0x1382, 0x4248, 0xFFFF, 0xFFFF, "Marc X sound system(0x4248)"},
{0x1382, 0x4424, 0xFFFF, 0xFFFF, "TRACE D4 Sound System(0x4424)"},
}; /* pci_vid_1382[] */

static pci_id_t const pci_vid_1383[] = {
{0x1383, 0xFFFF, 0xFFFF, 0xFFFF, "Controlnet Inc(0x1383)"},
}; /* pci_vid_1383[] */

static pci_id_t const pci_vid_1384[] = {
{0x1384, 0xFFFF, 0xFFFF, 0xFFFF, "Reality Simulation Systems Inc(0x1384)"},
}; /* pci_vid_1384[] */

static pci_id_t const pci_vid_1385[] = {
{0x1385, 0xFFFF, 0xFFFF, 0xFFFF, "Netgear(0x1385)"},
{0x1385, 0x006B, 0xFFFF, 0xFFFF, "WA301 802.11b Wireless PCI Adapter(0x006B)"},
{0x1385, 0x4100, 0xFFFF, 0xFFFF, "MA301 802.11b Wireless PCI Adapter(0x4100)"},
{0x1385, 0x4601, 0xFFFF, 0xFFFF, "WAG511 802.11a/b/g Dual Band Wireless PC Card(0x4601)"},
{0x1385, 0x620A, 0xFFFF, 0xFFFF, "GA620 Gigabit Ethernet(0x620A)"},
{0x1385, 0x630A, 0xFFFF, 0xFFFF, "GA630 Gigabit Ethernet(0x630A)"},
}; /* pci_vid_1385[] */

static pci_id_t const pci_vid_1386[] = {
{0x1386, 0xFFFF, 0xFFFF, 0xFFFF, "Video Domain Technologies(0x1386)"},
}; /* pci_vid_1386[] */

static pci_id_t const pci_vid_1387[] = {
{0x1387, 0xFFFF, 0xFFFF, 0xFFFF, "Systran Corp(0x1387)"},
}; /* pci_vid_1387[] */

static pci_id_t const pci_vid_1388[] = {
{0x1388, 0xFFFF, 0xFFFF, 0xFFFF, "Hitachi Information Technology Co Ltd(0x1388)"},
}; /* pci_vid_1388[] */

static pci_id_t const pci_vid_1389[] = {
{0x1389, 0xFFFF, 0xFFFF, 0xFFFF, "Applicom International(0x1389)"},
{0x1389, 0x0001, 0xFFFF, 0xFFFF, "PCI1500PFB [Intelligent fieldbus adaptor](0x0001)"},
}; /* pci_vid_1389[] */

static pci_id_t const pci_vid_138A[] = {
{0x138A, 0xFFFF, 0xFFFF, 0xFFFF, "Fusion Micromedia Corp(0x138A)"},
{0x138A, 0x003D, 0xFFFF, 0xFFFF, "VFS491 Validity Sensor(0x003D)"},
}; /* pci_vid_138A[] */

static pci_id_t const pci_vid_138B[] = {
{0x138B, 0xFFFF, 0xFFFF, 0xFFFF, "Tokimec Inc(0x138B)"},
}; /* pci_vid_138B[] */

static pci_id_t const pci_vid_138C[] = {
{0x138C, 0xFFFF, 0xFFFF, 0xFFFF, "Silicon Reality(0x138C)"},
}; /* pci_vid_138C[] */

static pci_id_t const pci_vid_138D[] = {
{0x138D, 0xFFFF, 0xFFFF, 0xFFFF, "Future Techno Designs pte Ltd(0x138D)"},
}; /* pci_vid_138D[] */

static pci_id_t const pci_vid_138E[] = {
{0x138E, 0xFFFF, 0xFFFF, 0xFFFF, "Basler GmbH(0x138E)"},
}; /* pci_vid_138E[] */

static pci_id_t const pci_vid_138F[] = {
{0x138F, 0xFFFF, 0xFFFF, 0xFFFF, "Patapsco Designs Inc(0x138F)"},
}; /* pci_vid_138F[] */

static pci_id_t const pci_vid_1390[] = {
{0x1390, 0xFFFF, 0xFFFF, 0xFFFF, "Concept Development Inc(0x1390)"},
}; /* pci_vid_1390[] */

static pci_id_t const pci_vid_1391[] = {
{0x1391, 0xFFFF, 0xFFFF, 0xFFFF, "Development Concepts Inc(0x1391)"},
}; /* pci_vid_1391[] */

static pci_id_t const pci_vid_1392[] = {
{0x1392, 0xFFFF, 0xFFFF, 0xFFFF, "Medialight Inc(0x1392)"},
}; /* pci_vid_1392[] */

static pci_id_t const pci_vid_1393[] = {
{0x1393, 0xFFFF, 0xFFFF, 0xFFFF, "Moxa Technologies Co Ltd(0x1393)"},
{0x1393, 0x0001, 0xFFFF, 0xFFFF, "UC7000 Serial(0x0001)"},
{0x1393, 0x1020, 0xFFFF, 0xFFFF, "CP-102 (2-port RS-232 PCI)(0x1020)"},
{0x1393, 0x1021, 0xFFFF, 0xFFFF, "CP-102UL (2-port RS-232 Universal PCI)(0x1021)"},
{0x1393, 0x1022, 0xFFFF, 0xFFFF, "CP-102U (2-port RS-232 Universal PCI)(0x1022)"},
{0x1393, 0x1023, 0xFFFF, 0xFFFF, "CP-102UF(0x1023)"},
{0x1393, 0x1024, 0xFFFF, 0xFFFF, "CP-102E (2-port RS-232 Smart PCI Express Serial Board)(0x1024)"},
{0x1393, 0x1025, 0xFFFF, 0xFFFF, "CP-102EL (2-port RS-232 Smart PCI Express Serial Board)(0x1025)"},
{0x1393, 0x1040, 0xFFFF, 0xFFFF, "Smartio C104H/PCI(0x1040)"},
{0x1393, 0x1041, 0xFFFF, 0xFFFF, "CP104U (4-port RS-232 Universal PCI)(0x1041)"},
{0x1393, 0x1042, 0xFFFF, 0xFFFF, "CP104JU (4-port RS-232 Universal PCI)(0x1042)"},
{0x1393, 0x1043, 0xFFFF, 0xFFFF, "CP104EL (4-port RS-232 Smart PCI Express)(0x1043)"},
{0x1393, 0x1044, 0xFFFF, 0xFFFF, "POS104UL (4-port RS-232 Universal PCI)(0x1044)"},
{0x1393, 0x1045, 0xFFFF, 0xFFFF, "CP-104EL-A (4-port RS-232 PCI Express Serial Board)(0x1045)"},
{0x1393, 0x1080, 0xFFFF, 0xFFFF, "CB108 (8-port RS-232 PC/104-plus Module)(0x1080)"},
{0x1393, 0x1140, 0xFFFF, 0xFFFF, "CT-114 series(0x1140)"},
{0x1393, 0x1141, 0xFFFF, 0xFFFF, "Industrio CP-114(0x1141)"},
{0x1393, 0x1142, 0xFFFF, 0xFFFF, "CB114 (4-port RS-232/422/485 PC/104-plus Module)(0x1142)"},
{0x1393, 0x1143, 0xFFFF, 0xFFFF, "CP-114UL (4-port RS-232/422/485 Smart Universal PCI Serial Board)(0x1143)"},
{0x1393, 0x1144, 0xFFFF, 0xFFFF, "CP-114EL (4-port RS-232/422/485 Smart PCI Express Serial Board)(0x1144)"},
{0x1393, 0x1180, 0xFFFF, 0xFFFF, "CP118U (8-port RS-232/422/485 Smart Universal PCI)(0x1180)"},
{0x1393, 0x1181, 0xFFFF, 0xFFFF, "CP118EL (8-port RS-232/422/485 Smart PCI Express)(0x1181)"},
{0x1393, 0x1182, 0xFFFF, 0xFFFF, "CP-118EL-A (8-port RS-232/422/485 PCI Express Serial Board)(0x1182)"},
{0x1393, 0x1320, 0xFFFF, 0xFFFF, "CP132 (2-port RS-422/485 PCI)(0x1320)"},
{0x1393, 0x1321, 0xFFFF, 0xFFFF, "CP132U (2-Port RS-422/485 Universal PCI)(0x1321)"},
{0x1393, 0x1322, 0xFFFF, 0xFFFF, "CP-132EL (2-port RS-422/485 Smart PCI Express Serial Board)(0x1322)"},
{0x1393, 0x1340, 0xFFFF, 0xFFFF, "CP134U (4-Port RS-422/485 Universal PCI)(0x1340)"},
{0x1393, 0x1341, 0xFFFF, 0xFFFF, "CB134I (4-port RS-422/485 PC/104-plus Module)(0x1341)"},
{0x1393, 0x1380, 0xFFFF, 0xFFFF, "CP138U (8-port RS-232/422/485 Smart Universal PCI)(0x1380)"},
{0x1393, 0x1680, 0xFFFF, 0xFFFF, "Smartio C168H/PCI(0x1680)"},
{0x1393, 0x1681, 0xFFFF, 0xFFFF, "CP-168U V2 Smart Serial Board (8-port RS-232)(0x1681)"},
{0x1393, 0x1682, 0xFFFF, 0xFFFF, "CP-168EL (8-port RS-232 Smart PCI Express)(0x1682)"},
{0x1393, 0x1683, 0xFFFF, 0xFFFF, "CP-168EL-A (8-port RS-232 PCI Express Serial Board)(0x1683)"},
{0x1393, 0x2040, 0xFFFF, 0xFFFF, "Intellio CP-204J(0x2040)"},
{0x1393, 0x2180, 0xFFFF, 0xFFFF, "Intellio C218 Turbo PCI(0x2180)"},
{0x1393, 0x3200, 0xFFFF, 0xFFFF, "Intellio C320 Turbo PCI(0x3200)"},
}; /* pci_vid_1393[] */

static pci_id_t const pci_vid_1394[] = {
{0x1394, 0xFFFF, 0xFFFF, 0xFFFF, "Level One Communications(0x1394)"},
{0x1394, 0x0001, 0xFFFF, 0xFFFF, "LXT1001 Gigabit Ethernet(0x0001)"},
{0x1394, 0x0001, 0x1186, 0x4800, "DGE-500SX(0x1186-0x4800)"},
{0x1394, 0x0001, 0x1394, 0x0001, "NetCelerator Adapter(0x1394-0x0001)"},
}; /* pci_vid_1394[] */

static pci_id_t const pci_vid_1395[] = {
{0x1395, 0xFFFF, 0xFFFF, 0xFFFF, "Ambicom Inc(0x1395)"},
}; /* pci_vid_1395[] */

static pci_id_t const pci_vid_1396[] = {
{0x1396, 0xFFFF, 0xFFFF, 0xFFFF, "Cipher Systems Inc(0x1396)"},
}; /* pci_vid_1396[] */

static pci_id_t const pci_vid_1397[] = {
{0x1397, 0xFFFF, 0xFFFF, 0xFFFF, "Cologne Chip Designs GmbH(0x1397)"},
{0x1397, 0x08B4, 0xFFFF, 0xFFFF, "ISDN network Controller [HFC-4S](0x08B4)"},
{0x1397, 0x08B4, 0x1397, 0x08B4, "HFC-4S [Cologne Chip HFC-4S Eval. Board](0x1397-0x08B4)"},
{0x1397, 0x08B4, 0x1397, 0xB51A, "HFC-4S [Allo.com BRI card](0x1397-0xB51A)"},
{0x1397, 0x08B4, 0x1397, 0xB520, "HFC-4S [IOB4ST](0x1397-0xB520)"},
{0x1397, 0x08B4, 0x1397, 0xB540, "HFC-4S [Swyx SX2 QuadBri](0x1397-0xB540)"},
{0x1397, 0x08B4, 0x1397, 0xB550, "HFC-4S [Junghanns.NET quadBRI](0x1397-0xB550)"},
{0x1397, 0x08B4, 0x1397, 0xB556, "HFC-4S [Junghanns.NET duoBRI](0x1397-0xB556)"},
{0x1397, 0x08B4, 0x1397, 0xB559, "HFC-4S [Junghanns.NET duoBRI miniPCI](0x1397-0xB559)"},
{0x1397, 0x08B4, 0x1397, 0xB560, "HFC-4S [BeroNet BN4S0](0x1397-0xB560)"},
{0x1397, 0x08B4, 0x1397, 0xB566, "HFC-4S [BeroNet BN2S0](0x1397-0xB566)"},
{0x1397, 0x08B4, 0x1397, 0xB567, "HFC-4S [BeroNet BN1S0 miniPCI](0x1397-0xB567)"},
{0x1397, 0x08B4, 0x1397, 0xB568, "HFC-4S [BeroNet BN4S0 miniPCI](0x1397-0xB568)"},
{0x1397, 0x08B4, 0x1397, 0xB569, "HFC-4S [BeroNet BN2S0 miniPCI](0x1397-0xB569)"},
{0x1397, 0x08B4, 0x1397, 0xB620, "HFC-4S(0x1397-0xB620)"},
{0x1397, 0x08B4, 0x1397, 0xB752, "HFC-4S [Junghanns.NET quadBRI PCIe](0x1397-0xB752)"},
{0x1397, 0x08B4, 0x1397, 0xB761, "HFC-4S [BeroNet BN2S0 PCIe](0x1397-0xB761)"},
{0x1397, 0x08B4, 0x1397, 0xB762, "HFC-4S [BeroNet BN4S0 PCIe](0x1397-0xB762)"},
{0x1397, 0x08B4, 0x1397, 0xE884, "HFC-4S [OpenVox B200P](0x1397-0xE884)"},
{0x1397, 0x08B4, 0x1397, 0xE888, "HFC-4S [OpenVox B200P / B400P](0x1397-0xE888)"},
{0x1397, 0x16B8, 0xFFFF, 0xFFFF, "ISDN network Controller [HFC-8S](0x16B8)"},
{0x1397, 0x16B8, 0x1397, 0x16B8, "HFC-8S [Cologne Chip HFC-8S Eval. Board](0x1397-0x16B8)"},
{0x1397, 0x16B8, 0x1397, 0xB521, "HFC-8S [IOB4ST Recording](0x1397-0xB521)"},
{0x1397, 0x16B8, 0x1397, 0xB522, "HFC-8S [IOB8ST](0x1397-0xB522)"},
{0x1397, 0x16B8, 0x1397, 0xB552, "HFC-8S [Junghanns.NET octoBRI](0x1397-0xB552)"},
{0x1397, 0x16B8, 0x1397, 0xB55B, "HFC-8S [Junghanns.NET octoBRI](0x1397-0xB55B)"},
{0x1397, 0x16B8, 0x1397, 0xB562, "HFC-8S [BeroNet BN8S0](0x1397-0xB562)"},
{0x1397, 0x16B8, 0x1397, 0xB56B, "HFC-8S [BeroNet BN8S0+](0x1397-0xB56B)"},
{0x1397, 0x16B8, 0x1397, 0xB622, "HFC-8S(0x1397-0xB622)"},
{0x1397, 0x16B8, 0x1397, 0xE998, "HFC-8S [OpenVox B800P](0x1397-0xE998)"},
{0x1397, 0x2BD0, 0xFFFF, 0xFFFF, "ISDN network controller [HFC-PCI](0x2BD0)"},
{0x1397, 0x2BD0, 0x0675, 0x1704, "ISDN Adapter (PCI Bus, D, C)(0x0675-0x1704)"},
{0x1397, 0x2BD0, 0x0675, 0x1708, "ISDN Adapter (PCI Bus, D, C, ACPI)(0x0675-0x1708)"},
{0x1397, 0x2BD0, 0x1397, 0x2BD0, "ISDN Board(0x1397-0x2BD0)"},
{0x1397, 0x2BD0, 0xE4BF, 0x1000, "CI1-1-Harp(0xE4BF-0x1000)"},
{0x1397, 0x30B1, 0xFFFF, 0xFFFF, "ISDN network Controller [HFC-E1](0x30B1)"},
{0x1397, 0x30B1, 0x1397, 0x30B1, "HFC-E1 [Cologne Chip HFC-E1 Eval. Board](0x1397-0x30B1)"},
{0x1397, 0x30B1, 0x1397, 0xB523, "HFC-E1 [IOB1E1](0x1397-0xB523)"},
{0x1397, 0x30B1, 0x1397, 0xB543, "HFC-E1 [Swyx SX2 SinglePRI V2](0x1397-0xB543)"},
{0x1397, 0x30B1, 0x1397, 0xB544, "HFC-E1 [Swyx SX2 DualPRI V2](0x1397-0xB544)"},
{0x1397, 0x30B1, 0x1397, 0xB553, "HFC-E1 [Junghanns.NET singleE1](0x1397-0xB553)"},
{0x1397, 0x30B1, 0x1397, 0xB554, "HFC-E1 [Junghanns.NET doubleE1](0x1397-0xB554)"},
{0x1397, 0x30B1, 0x1397, 0xB555, "HFC-E1 [Junghanns.NET doubleE1 2.0](0x1397-0xB555)"},
{0x1397, 0x30B1, 0x1397, 0xB55A, "HFC-E1 [Junghanns.NET singleE1 miniPCI](0x1397-0xB55A)"},
{0x1397, 0x30B1, 0x1397, 0xB563, "HFC-E1 [beroNet BN1E1](0x1397-0xB563)"},
{0x1397, 0x30B1, 0x1397, 0xB564, "HFC-E1 [beroNet BN2E1](0x1397-0xB564)"},
{0x1397, 0x30B1, 0x1397, 0xB565, "HFC-E1 [beroNet BN2E1+](0x1397-0xB565)"},
{0x1397, 0x30B1, 0x1397, 0xB56A, "HFC-E1 [beroNet BN1E1 miniPCI](0x1397-0xB56A)"},
{0x1397, 0xB700, 0xFFFF, 0xFFFF, "ISDN network controller PrimuX S0 [HFC-PCI](0xB700)"},
{0x1397, 0xF001, 0xFFFF, 0xFFFF, "GSM Network Controller [HFC-4GSM](0xF001)"},
}; /* pci_vid_1397[] */

static pci_id_t const pci_vid_1398[] = {
{0x1398, 0xFFFF, 0xFFFF, 0xFFFF, "Clarion co. Ltd(0x1398)"},
}; /* pci_vid_1398[] */

static pci_id_t const pci_vid_1399[] = {
{0x1399, 0xFFFF, 0xFFFF, 0xFFFF, "Rios systems Co Ltd(0x1399)"},
}; /* pci_vid_1399[] */

static pci_id_t const pci_vid_139A[] = {
{0x139A, 0xFFFF, 0xFFFF, 0xFFFF, "Alacritech Inc(0x139A)"},
{0x139A, 0x0001, 0xFFFF, 0xFFFF, "Quad Port 10/100 Server Accelerator(0x0001)"},
{0x139A, 0x0003, 0xFFFF, 0xFFFF, "Single Port 10/100 Server Accelerator(0x0003)"},
{0x139A, 0x0005, 0xFFFF, 0xFFFF, "Single Port Gigabit Server Accelerator(0x0005)"},
}; /* pci_vid_139A[] */

static pci_id_t const pci_vid_139B[] = {
{0x139B, 0xFFFF, 0xFFFF, 0xFFFF, "Mediasonic Multimedia Systems Ltd(0x139B)"},
}; /* pci_vid_139B[] */

static pci_id_t const pci_vid_139C[] = {
{0x139C, 0xFFFF, 0xFFFF, 0xFFFF, "Quantum 3d Inc(0x139C)"},
}; /* pci_vid_139C[] */

static pci_id_t const pci_vid_139D[] = {
{0x139D, 0xFFFF, 0xFFFF, 0xFFFF, "EPL limited(0x139D)"},
}; /* pci_vid_139D[] */

static pci_id_t const pci_vid_139E[] = {
{0x139E, 0xFFFF, 0xFFFF, 0xFFFF, "Media4(0x139E)"},
}; /* pci_vid_139E[] */

static pci_id_t const pci_vid_139F[] = {
{0x139F, 0xFFFF, 0xFFFF, 0xFFFF, "Aethra s.r.l.(0x139F)"},
}; /* pci_vid_139F[] */

static pci_id_t const pci_vid_13A0[] = {
{0x13A0, 0xFFFF, 0xFFFF, 0xFFFF, "Crystal Group Inc(0x13A0)"},
}; /* pci_vid_13A0[] */

static pci_id_t const pci_vid_13A1[] = {
{0x13A1, 0xFFFF, 0xFFFF, 0xFFFF, "Kawasaki Heavy Industries Ltd(0x13A1)"},
}; /* pci_vid_13A1[] */

static pci_id_t const pci_vid_13A2[] = {
{0x13A2, 0xFFFF, 0xFFFF, 0xFFFF, "Ositech Communications Inc(0x13A2)"},
}; /* pci_vid_13A2[] */

static pci_id_t const pci_vid_13A3[] = {
{0x13A3, 0xFFFF, 0xFFFF, 0xFFFF, "Hifn Inc.(0x13A3)"},
{0x13A3, 0x0005, 0xFFFF, 0xFFFF, "7751 Security Processor(0x0005)"},
{0x13A3, 0x0006, 0xFFFF, 0xFFFF, "6500 Public Key Processor(0x0006)"},
{0x13A3, 0x0007, 0xFFFF, 0xFFFF, "7811 Security Processor(0x0007)"},
{0x13A3, 0x0012, 0xFFFF, 0xFFFF, "7951 Security Processor(0x0012)"},
{0x13A3, 0x0014, 0xFFFF, 0xFFFF, "78XX Security Processor(0x0014)"},
{0x13A3, 0x0016, 0xFFFF, 0xFFFF, "8065 Security Processor(0x0016)"},
{0x13A3, 0x0017, 0xFFFF, 0xFFFF, "8165 Security Processor(0x0017)"},
{0x13A3, 0x0018, 0xFFFF, 0xFFFF, "8154 Security Processor(0x0018)"},
{0x13A3, 0x001D, 0xFFFF, 0xFFFF, "7956 Security Processor(0x001D)"},
{0x13A3, 0x001F, 0xFFFF, 0xFFFF, "7855 Security Processor(0x001F)"},
{0x13A3, 0x0020, 0xFFFF, 0xFFFF, "7955 Security Processor(0x0020)"},
{0x13A3, 0x0026, 0xFFFF, 0xFFFF, "8155 Security Processor(0x0026)"},
{0x13A3, 0x002E, 0xFFFF, 0xFFFF, "9630 Compression Processor(0x002E)"},
{0x13A3, 0x002F, 0xFFFF, 0xFFFF, "9725 Compression and Security Processor(0x002F)"},
{0x13A3, 0x002F, 0x13A3, 0x1600, "DR1600 Acceleration Card(0x13A3-0x1600)"},
{0x13A3, 0x002F, 0x13A3, 0x1605, "DR1605 Acceleration Card(0x13A3-0x1605)"},
{0x13A3, 0x002F, 0x13A3, 0x1610, "DR1610 Acceleration Card(0x13A3-0x1610)"},
{0x13A3, 0x002F, 0x13A3, 0x1615, "DR1615 Acceleration Card(0x13A3-0x1615)"},
{0x13A3, 0x002F, 0x13A3, 0x1620, "DR1620 Acceleration Card(0x13A3-0x1620)"},
{0x13A3, 0x002F, 0x13A3, 0x1625, "DR1625 Acceleration Card(0x13A3-0x1625)"},
{0x13A3, 0x0033, 0xFFFF, 0xFFFF, "8201 Acceleration Processor(0x0033)"},
{0x13A3, 0x0033, 0x13A3, 0x0036, "DX1710 Acceleration Card(0x13A3-0x0036)"},
{0x13A3, 0x0034, 0xFFFF, 0xFFFF, "8202 Acceleration Processor(0x0034)"},
{0x13A3, 0x0034, 0x13A3, 0x0036, "DX1720 Acceleration Card(0x13A3-0x0036)"},
{0x13A3, 0x0035, 0xFFFF, 0xFFFF, "8203 Acceleration Processor(0x0035)"},
{0x13A3, 0x0035, 0x13A3, 0x0036, "DX1730 Acceleration Card(0x13A3-0x0036)"},
{0x13A3, 0x0037, 0xFFFF, 0xFFFF, "8204 Acceleration Processor(0x0037)"},
{0x13A3, 0x0037, 0x13A3, 0x0036, "DX1740 Acceleration Card(0x13A3-0x0036)"},
{0x13A3, 0x9240, 0xFFFF, 0xFFFF, "XR9240 Compression and Security Coprocessor [Panther II](0x9240)"},
{0x13A3, 0x9240, 0x13A3, 0x9200, "DX2040 Compression and Security Acceleration Card [Panther II](0x13A3-0x9200)"},
}; /* pci_vid_13A3[] */

static pci_id_t const pci_vid_13A4[] = {
{0x13A4, 0xFFFF, 0xFFFF, 0xFFFF, "Rascom Inc(0x13A4)"},
}; /* pci_vid_13A4[] */

static pci_id_t const pci_vid_13A5[] = {
{0x13A5, 0xFFFF, 0xFFFF, 0xFFFF, "Audio Digital Imaging Inc(0x13A5)"},
}; /* pci_vid_13A5[] */

static pci_id_t const pci_vid_13A6[] = {
{0x13A6, 0xFFFF, 0xFFFF, 0xFFFF, "Videonics Inc(0x13A6)"},
}; /* pci_vid_13A6[] */

static pci_id_t const pci_vid_13A7[] = {
{0x13A7, 0xFFFF, 0xFFFF, 0xFFFF, "Teles AG(0x13A7)"},
}; /* pci_vid_13A7[] */

static pci_id_t const pci_vid_13A8[] = {
{0x13A8, 0xFFFF, 0xFFFF, 0xFFFF, "Exar Corp.(0x13A8)"},
{0x13A8, 0x0152, 0xFFFF, 0xFFFF, "XR17C/D152 Dual PCI UART(0x0152)"},
{0x13A8, 0x0154, 0xFFFF, 0xFFFF, "XR17C154 Quad UART(0x0154)"},
{0x13A8, 0x0158, 0xFFFF, 0xFFFF, "XR17C158 Octal UART(0x0158)"},
{0x13A8, 0x0252, 0xFFFF, 0xFFFF, "XR17V252 Dual UART PCI controller(0x0252)"},
{0x13A8, 0x0254, 0xFFFF, 0xFFFF, "XR17V254 Quad UART PCI controller(0x0254)"},
{0x13A8, 0x0258, 0xFFFF, 0xFFFF, "XR17V258 Octal UART PCI controller(0x0258)"},
{0x13A8, 0x0352, 0xFFFF, 0xFFFF, "XR17V3521 Dual PCIe UART(0x0352)"},
}; /* pci_vid_13A8[] */

static pci_id_t const pci_vid_13A9[] = {
{0x13A9, 0xFFFF, 0xFFFF, 0xFFFF, "Siemens Medical Systems, Ultrasound Group(0x13A9)"},
}; /* pci_vid_13A9[] */

static pci_id_t const pci_vid_13AA[] = {
{0x13AA, 0xFFFF, 0xFFFF, 0xFFFF, "Broadband Networks Inc(0x13AA)"},
}; /* pci_vid_13AA[] */

static pci_id_t const pci_vid_13AB[] = {
{0x13AB, 0xFFFF, 0xFFFF, 0xFFFF, "Arcom Control Systems Ltd(0x13AB)"},
}; /* pci_vid_13AB[] */

static pci_id_t const pci_vid_13AC[] = {
{0x13AC, 0xFFFF, 0xFFFF, 0xFFFF, "Motion Media Technology Ltd(0x13AC)"},
}; /* pci_vid_13AC[] */

static pci_id_t const pci_vid_13AD[] = {
{0x13AD, 0xFFFF, 0xFFFF, 0xFFFF, "Nexus Inc(0x13AD)"},
}; /* pci_vid_13AD[] */

static pci_id_t const pci_vid_13AE[] = {
{0x13AE, 0xFFFF, 0xFFFF, 0xFFFF, "ALD Technology Ltd(0x13AE)"},
}; /* pci_vid_13AE[] */

static pci_id_t const pci_vid_13AF[] = {
{0x13AF, 0xFFFF, 0xFFFF, 0xFFFF, "T.Sqware(0x13AF)"},
}; /* pci_vid_13AF[] */

static pci_id_t const pci_vid_13B0[] = {
{0x13B0, 0xFFFF, 0xFFFF, 0xFFFF, "Maxspeed Corp(0x13B0)"},
}; /* pci_vid_13B0[] */

static pci_id_t const pci_vid_13B1[] = {
{0x13B1, 0xFFFF, 0xFFFF, 0xFFFF, "Tamura corporation(0x13B1)"},
}; /* pci_vid_13B1[] */

static pci_id_t const pci_vid_13B2[] = {
{0x13B2, 0xFFFF, 0xFFFF, 0xFFFF, "Techno Chips Co. Ltd(0x13B2)"},
}; /* pci_vid_13B2[] */

static pci_id_t const pci_vid_13B3[] = {
{0x13B3, 0xFFFF, 0xFFFF, 0xFFFF, "Lanart Corporation(0x13B3)"},
}; /* pci_vid_13B3[] */

static pci_id_t const pci_vid_13B4[] = {
{0x13B4, 0xFFFF, 0xFFFF, 0xFFFF, "Wellbean Co Inc(0x13B4)"},
}; /* pci_vid_13B4[] */

static pci_id_t const pci_vid_13B5[] = {
{0x13B5, 0xFFFF, 0xFFFF, 0xFFFF, "ARM(0x13B5)"},
}; /* pci_vid_13B5[] */

static pci_id_t const pci_vid_13B6[] = {
{0x13B6, 0xFFFF, 0xFFFF, 0xFFFF, "Dlog GmbH(0x13B6)"},
}; /* pci_vid_13B6[] */

static pci_id_t const pci_vid_13B7[] = {
{0x13B7, 0xFFFF, 0xFFFF, 0xFFFF, "Logic Devices Inc(0x13B7)"},
}; /* pci_vid_13B7[] */

static pci_id_t const pci_vid_13B8[] = {
{0x13B8, 0xFFFF, 0xFFFF, 0xFFFF, "Nokia Telecommunications oy(0x13B8)"},
}; /* pci_vid_13B8[] */

static pci_id_t const pci_vid_13B9[] = {
{0x13B9, 0xFFFF, 0xFFFF, 0xFFFF, "Elecom Co Ltd(0x13B9)"},
}; /* pci_vid_13B9[] */

static pci_id_t const pci_vid_13BA[] = {
{0x13BA, 0xFFFF, 0xFFFF, 0xFFFF, "Oxford Instruments(0x13BA)"},
}; /* pci_vid_13BA[] */

static pci_id_t const pci_vid_13BB[] = {
{0x13BB, 0xFFFF, 0xFFFF, 0xFFFF, "Sanyo Technosound Co Ltd(0x13BB)"},
}; /* pci_vid_13BB[] */

static pci_id_t const pci_vid_13BC[] = {
{0x13BC, 0xFFFF, 0xFFFF, 0xFFFF, "Bitran Corporation(0x13BC)"},
}; /* pci_vid_13BC[] */

static pci_id_t const pci_vid_13BD[] = {
{0x13BD, 0xFFFF, 0xFFFF, 0xFFFF, "Sharp corporation(0x13BD)"},
}; /* pci_vid_13BD[] */

static pci_id_t const pci_vid_13BE[] = {
{0x13BE, 0xFFFF, 0xFFFF, 0xFFFF, "Miroku Jyoho Service Co. Ltd(0x13BE)"},
}; /* pci_vid_13BE[] */

static pci_id_t const pci_vid_13BF[] = {
{0x13BF, 0xFFFF, 0xFFFF, 0xFFFF, "Sharewave Inc(0x13BF)"},
}; /* pci_vid_13BF[] */

static pci_id_t const pci_vid_13C0[] = {
{0x13C0, 0xFFFF, 0xFFFF, 0xFFFF, "Microgate Corporation(0x13C0)"},
{0x13C0, 0x0010, 0xFFFF, 0xFFFF, "SyncLink Adapter v1(0x0010)"},
{0x13C0, 0x0020, 0xFFFF, 0xFFFF, "SyncLink SCC Adapter(0x0020)"},
{0x13C0, 0x0030, 0xFFFF, 0xFFFF, "SyncLink Multiport Adapter(0x0030)"},
{0x13C0, 0x0070, 0xFFFF, 0xFFFF, "SyncLink GT Adapter(0x0070)"},
{0x13C0, 0x0080, 0xFFFF, 0xFFFF, "SyncLink GT4 Adapter(0x0080)"},
{0x13C0, 0x00A0, 0xFFFF, 0xFFFF, "SyncLink GT2 Adapter(0x00A0)"},
{0x13C0, 0x0210, 0xFFFF, 0xFFFF, "SyncLink Adapter v2(0x0210)"},
}; /* pci_vid_13C0[] */

static pci_id_t const pci_vid_13C1[] = {
{0x13C1, 0xFFFF, 0xFFFF, 0xFFFF, "3ware Inc(0x13C1)"},
{0x13C1, 0x1000, 0xFFFF, 0xFFFF, "5xxx/6xxx-series PATA-RAID(0x1000)"},
{0x13C1, 0x1001, 0xFFFF, 0xFFFF, "7xxx/8xxx-series PATA/SATA-RAID(0x1001)"},
{0x13C1, 0x1001, 0x13C1, 0x1001, "7xxx/8xxx-series PATA/SATA-RAID(0x13C1-0x1001)"},
{0x13C1, 0x1002, 0xFFFF, 0xFFFF, "9xxx-series SATA-RAID(0x1002)"},
{0x13C1, 0x1003, 0xFFFF, 0xFFFF, "9550SX SATA-II RAID PCI-X(0x1003)"},
{0x13C1, 0x1004, 0xFFFF, 0xFFFF, "9650SE SATA-II RAID PCIe(0x1004)"},
{0x13C1, 0x1005, 0xFFFF, 0xFFFF, "9690SA SAS/SATA-II RAID PCIe(0x1005)"},
{0x13C1, 0x1010, 0xFFFF, 0xFFFF, "9750 SAS2/SATA-II RAID PCIe(0x1010)"},
}; /* pci_vid_13C1[] */

static pci_id_t const pci_vid_13C2[] = {
{0x13C2, 0xFFFF, 0xFFFF, 0xFFFF, "Technotrend Systemtechnik GmbH(0x13C2)"},
{0x13C2, 0x000E, 0xFFFF, 0xFFFF, "Technotrend/Hauppauge DVB card rev2.3(0x000E)"},
{0x13C2, 0x1019, 0xFFFF, 0xFFFF, "TTechnoTrend-budget DVB S2-3200(0x1019)"},
}; /* pci_vid_13C2[] */

static pci_id_t const pci_vid_13C3[] = {
{0x13C3, 0xFFFF, 0xFFFF, 0xFFFF, "Janz Computer AG(0x13C3)"},
}; /* pci_vid_13C3[] */

static pci_id_t const pci_vid_13C4[] = {
{0x13C4, 0xFFFF, 0xFFFF, 0xFFFF, "Phase Metrics(0x13C4)"},
}; /* pci_vid_13C4[] */

static pci_id_t const pci_vid_13C5[] = {
{0x13C5, 0xFFFF, 0xFFFF, 0xFFFF, "Alphi Technology Corp(0x13C5)"},
}; /* pci_vid_13C5[] */

static pci_id_t const pci_vid_13C6[] = {
{0x13C6, 0xFFFF, 0xFFFF, 0xFFFF, "Condor Engineering Inc(0x13C6)"},
{0x13C6, 0x0520, 0xFFFF, 0xFFFF, "CEI-520 A429 Card(0x0520)"},
{0x13C6, 0x0620, 0xFFFF, 0xFFFF, "CEI-620 A429 Card(0x0620)"},
{0x13C6, 0x0820, 0xFFFF, 0xFFFF, "CEI-820 A429 Card(0x0820)"},
{0x13C6, 0x0830, 0xFFFF, 0xFFFF, "CEI-830 A429 Card(0x0830)"},
{0x13C6, 0x1004, 0xFFFF, 0xFFFF, "P-SER Multi-channel PMC to RS-485/422/232 adapter(0x1004)"},
}; /* pci_vid_13C6[] */

static pci_id_t const pci_vid_13C7[] = {
{0x13C7, 0xFFFF, 0xFFFF, 0xFFFF, "Blue Chip Technology Ltd(0x13C7)"},
{0x13C7, 0x0ADC, 0xFFFF, 0xFFFF, "PCI-ADC(0x0ADC)"},
{0x13C7, 0x0B10, 0xFFFF, 0xFFFF, "PCI-PIO(0x0B10)"},
{0x13C7, 0x0D10, 0xFFFF, 0xFFFF, "PCI-DIO(0x0D10)"},
{0x13C7, 0x524C, 0xFFFF, 0xFFFF, "PCI-RLY(0x524C)"},
{0x13C7, 0x5744, 0xFFFF, 0xFFFF, "PCI-WDT(0x5744)"},
}; /* pci_vid_13C7[] */

static pci_id_t const pci_vid_13C8[] = {
{0x13C8, 0xFFFF, 0xFFFF, 0xFFFF, "Apptech Inc(0x13C8)"},
}; /* pci_vid_13C8[] */

static pci_id_t const pci_vid_13C9[] = {
{0x13C9, 0xFFFF, 0xFFFF, 0xFFFF, "Eaton Corporation(0x13C9)"},
}; /* pci_vid_13C9[] */

static pci_id_t const pci_vid_13CA[] = {
{0x13CA, 0xFFFF, 0xFFFF, 0xFFFF, "Iomega Corporation(0x13CA)"},
}; /* pci_vid_13CA[] */

static pci_id_t const pci_vid_13CB[] = {
{0x13CB, 0xFFFF, 0xFFFF, 0xFFFF, "Yano Electric Co Ltd(0x13CB)"},
}; /* pci_vid_13CB[] */

static pci_id_t const pci_vid_13CC[] = {
{0x13CC, 0xFFFF, 0xFFFF, 0xFFFF, "BARCO(0x13CC)"},
}; /* pci_vid_13CC[] */

static pci_id_t const pci_vid_13CD[] = {
{0x13CD, 0xFFFF, 0xFFFF, 0xFFFF, "Compatible Systems Corporation(0x13CD)"},
}; /* pci_vid_13CD[] */

static pci_id_t const pci_vid_13CE[] = {
{0x13CE, 0xFFFF, 0xFFFF, 0xFFFF, "Cocom A/S(0x13CE)"},
}; /* pci_vid_13CE[] */

static pci_id_t const pci_vid_13CF[] = {
{0x13CF, 0xFFFF, 0xFFFF, 0xFFFF, "Studio Audio & Video Ltd(0x13CF)"},
}; /* pci_vid_13CF[] */

static pci_id_t const pci_vid_13D0[] = {
{0x13D0, 0xFFFF, 0xFFFF, 0xFFFF, "Techsan Electronics Co Ltd(0x13D0)"},
{0x13D0, 0x2103, 0xFFFF, 0xFFFF, "B2C2 FlexCopII DVB chip / Technisat SkyStar2 DVB card(0x2103)"},
{0x13D0, 0x2104, 0xFFFF, 0xFFFF, "B2C2 FlexCopIII DVB chip / Technisat SkyStar2 DVB card (rev 01)(0x2104)"},
{0x13D0, 0x2200, 0xFFFF, 0xFFFF, "B2C2 FlexCopIII DVB chip / Technisat SkyStar2 DVB card(0x2200)"},
}; /* pci_vid_13D0[] */

static pci_id_t const pci_vid_13D1[] = {
{0x13D1, 0xFFFF, 0xFFFF, 0xFFFF, "Abocom Systems Inc(0x13D1)"},
{0x13D1, 0xAB02, 0xFFFF, 0xFFFF, "ADMtek Centaur-C rev 17 [D-Link DFE-680TX] CardBus Fast Ethernet Adapter(0xAB02)"},
{0x13D1, 0xAB03, 0xFFFF, 0xFFFF, "21x4x DEC-Tulip compatible 10/100 Ethernet(0xAB03)"},
{0x13D1, 0xAB06, 0xFFFF, 0xFFFF, "RTL8139 [FE2000VX] CardBus Fast Ethernet Attached Port Adapter(0xAB06)"},
{0x13D1, 0xAB08, 0xFFFF, 0xFFFF, "21x4x DEC-Tulip compatible 10/100 Ethernet(0xAB08)"},
}; /* pci_vid_13D1[] */

static pci_id_t const pci_vid_13D2[] = {
{0x13D2, 0xFFFF, 0xFFFF, 0xFFFF, "Shark Multimedia Inc(0x13D2)"},
}; /* pci_vid_13D2[] */

static pci_id_t const pci_vid_13D4[] = {
{0x13D4, 0xFFFF, 0xFFFF, 0xFFFF, "Graphics Microsystems Inc(0x13D4)"},
}; /* pci_vid_13D4[] */

static pci_id_t const pci_vid_13D5[] = {
{0x13D5, 0xFFFF, 0xFFFF, 0xFFFF, "Media 100 Inc(0x13D5)"},
}; /* pci_vid_13D5[] */

static pci_id_t const pci_vid_13D6[] = {
{0x13D6, 0xFFFF, 0xFFFF, 0xFFFF, "K.I. Technology Co Ltd(0x13D6)"},
}; /* pci_vid_13D6[] */

static pci_id_t const pci_vid_13D7[] = {
{0x13D7, 0xFFFF, 0xFFFF, 0xFFFF, "Toshiba Engineering Corporation(0x13D7)"},
}; /* pci_vid_13D7[] */

static pci_id_t const pci_vid_13D8[] = {
{0x13D8, 0xFFFF, 0xFFFF, 0xFFFF, "Phobos corporation(0x13D8)"},
}; /* pci_vid_13D8[] */

static pci_id_t const pci_vid_13D9[] = {
{0x13D9, 0xFFFF, 0xFFFF, 0xFFFF, "Apex PC Solutions Inc(0x13D9)"},
}; /* pci_vid_13D9[] */

static pci_id_t const pci_vid_13DA[] = {
{0x13DA, 0xFFFF, 0xFFFF, 0xFFFF, "Intresource Systems pte Ltd(0x13DA)"},
}; /* pci_vid_13DA[] */

static pci_id_t const pci_vid_13DB[] = {
{0x13DB, 0xFFFF, 0xFFFF, 0xFFFF, "Janich & Klass Computertechnik GmbH(0x13DB)"},
}; /* pci_vid_13DB[] */

static pci_id_t const pci_vid_13DC[] = {
{0x13DC, 0xFFFF, 0xFFFF, 0xFFFF, "Netboost Corporation(0x13DC)"},
}; /* pci_vid_13DC[] */

static pci_id_t const pci_vid_13DD[] = {
{0x13DD, 0xFFFF, 0xFFFF, 0xFFFF, "Multimedia Bundle Inc(0x13DD)"},
}; /* pci_vid_13DD[] */

static pci_id_t const pci_vid_13DE[] = {
{0x13DE, 0xFFFF, 0xFFFF, 0xFFFF, "ABB Robotics Products AB(0x13DE)"},
}; /* pci_vid_13DE[] */

static pci_id_t const pci_vid_13DF[] = {
{0x13DF, 0xFFFF, 0xFFFF, 0xFFFF, "E-Tech Inc(0x13DF)"},
{0x13DF, 0x0001, 0xFFFF, 0xFFFF, "PCI56RVP Modem(0x0001)"},
{0x13DF, 0x0001, 0x13DF, 0x0001, "PCI56RVP Modem(0x13DF-0x0001)"},
}; /* pci_vid_13DF[] */

static pci_id_t const pci_vid_13E0[] = {
{0x13E0, 0xFFFF, 0xFFFF, 0xFFFF, "GVC Corporation(0x13E0)"},
}; /* pci_vid_13E0[] */

static pci_id_t const pci_vid_13E1[] = {
{0x13E1, 0xFFFF, 0xFFFF, 0xFFFF, "Silicom Multimedia Systems Inc(0x13E1)"},
}; /* pci_vid_13E1[] */

static pci_id_t const pci_vid_13E2[] = {
{0x13E2, 0xFFFF, 0xFFFF, 0xFFFF, "Dynamics Research Corporation(0x13E2)"},
}; /* pci_vid_13E2[] */

static pci_id_t const pci_vid_13E3[] = {
{0x13E3, 0xFFFF, 0xFFFF, 0xFFFF, "Nest Inc(0x13E3)"},
}; /* pci_vid_13E3[] */

static pci_id_t const pci_vid_13E4[] = {
{0x13E4, 0xFFFF, 0xFFFF, 0xFFFF, "Calculex Inc(0x13E4)"},
}; /* pci_vid_13E4[] */

static pci_id_t const pci_vid_13E5[] = {
{0x13E5, 0xFFFF, 0xFFFF, 0xFFFF, "Telesoft Design Ltd(0x13E5)"},
}; /* pci_vid_13E5[] */

static pci_id_t const pci_vid_13E6[] = {
{0x13E6, 0xFFFF, 0xFFFF, 0xFFFF, "Argosy research Inc(0x13E6)"},
}; /* pci_vid_13E6[] */

static pci_id_t const pci_vid_13E7[] = {
{0x13E7, 0xFFFF, 0xFFFF, 0xFFFF, "NAC Incorporated(0x13E7)"},
}; /* pci_vid_13E7[] */

static pci_id_t const pci_vid_13E8[] = {
{0x13E8, 0xFFFF, 0xFFFF, 0xFFFF, "Chip Express Corporation(0x13E8)"},
}; /* pci_vid_13E8[] */

static pci_id_t const pci_vid_13E9[] = {
{0x13E9, 0xFFFF, 0xFFFF, 0xFFFF, "Intraserver Technology Inc(0x13E9)"},
}; /* pci_vid_13E9[] */

static pci_id_t const pci_vid_13EA[] = {
{0x13EA, 0xFFFF, 0xFFFF, 0xFFFF, "Dallas Semiconductor(0x13EA)"},
}; /* pci_vid_13EA[] */

static pci_id_t const pci_vid_13EB[] = {
{0x13EB, 0xFFFF, 0xFFFF, 0xFFFF, "Hauppauge Computer Works Inc(0x13EB)"},
}; /* pci_vid_13EB[] */

static pci_id_t const pci_vid_13EC[] = {
{0x13EC, 0xFFFF, 0xFFFF, 0xFFFF, "Zydacron Inc(0x13EC)"},
{0x13EC, 0x000A, 0xFFFF, 0xFFFF, "NPC-RC01 Remote control receiver(0x000A)"},
}; /* pci_vid_13EC[] */

static pci_id_t const pci_vid_13ED[] = {
{0x13ED, 0xFFFF, 0xFFFF, 0xFFFF, "Raytheion E-Systems(0x13ED)"},
}; /* pci_vid_13ED[] */

static pci_id_t const pci_vid_13EE[] = {
{0x13EE, 0xFFFF, 0xFFFF, 0xFFFF, "Hayes Microcomputer Products Inc(0x13EE)"},
}; /* pci_vid_13EE[] */

static pci_id_t const pci_vid_13EF[] = {
{0x13EF, 0xFFFF, 0xFFFF, 0xFFFF, "Coppercom Inc(0x13EF)"},
}; /* pci_vid_13EF[] */

static pci_id_t const pci_vid_13F0[] = {
{0x13F0, 0xFFFF, 0xFFFF, 0xFFFF, "Sundance Technology Inc / IC Plus Corp(0x13F0)"},
{0x13F0, 0x0200, 0xFFFF, 0xFFFF, "IC Plus IP100A Integrated 10/100 Ethernet MAC + PHY(0x0200)"},
{0x13F0, 0x0200, 0x1043, 0x8213, "NX1001(0x1043-0x8213)"},
{0x13F0, 0x0201, 0xFFFF, 0xFFFF, "ST201 Sundance Ethernet(0x0201)"},
{0x13F0, 0x1021, 0xFFFF, 0xFFFF, "TC902x Gigabit Ethernet(0x1021)"},
{0x13F0, 0x1023, 0xFFFF, 0xFFFF, "IP1000 Family Gigabit Ethernet(0x1023)"},
{0x13F0, 0x1023, 0x1043, 0x8180, "NX1101(0x1043-0x8180)"},
}; /* pci_vid_13F0[] */

static pci_id_t const pci_vid_13F1[] = {
{0x13F1, 0xFFFF, 0xFFFF, 0xFFFF, "Oce' - Technologies B.V.(0x13F1)"},
}; /* pci_vid_13F1[] */

static pci_id_t const pci_vid_13F2[] = {
{0x13F2, 0xFFFF, 0xFFFF, 0xFFFF, "Ford Microelectronics Inc(0x13F2)"},
}; /* pci_vid_13F2[] */

static pci_id_t const pci_vid_13F3[] = {
{0x13F3, 0xFFFF, 0xFFFF, 0xFFFF, "Brocade Communications Systems, Inc.(0x13F3)"},
}; /* pci_vid_13F3[] */

static pci_id_t const pci_vid_13F4[] = {
{0x13F4, 0xFFFF, 0xFFFF, 0xFFFF, "Troika Networks, Inc.(0x13F4)"},
{0x13F4, 0x1401, 0xFFFF, 0xFFFF, "Zentai Fibre Channel Adapter(0x1401)"},
}; /* pci_vid_13F4[] */

static pci_id_t const pci_vid_13F5[] = {
{0x13F5, 0xFFFF, 0xFFFF, 0xFFFF, "Kansai Electric Co. Ltd(0x13F5)"},
}; /* pci_vid_13F5[] */

static pci_id_t const pci_vid_13F6[] = {
{0x13F6, 0xFFFF, 0xFFFF, 0xFFFF, "C-Media Electronics Inc(0x13F6)"},
{0x13F6, 0x0011, 0xFFFF, 0xFFFF, "CMI8738(0x0011)"},
{0x13F6, 0x0100, 0xFFFF, 0xFFFF, "CM8338A(0x0100)"},
{0x13F6, 0x0100, 0x13F6, 0xFFFF, "CMI8338/C3DX PCI Audio Device(0x13F6-0xFFFF)"},
{0x13F6, 0x0101, 0xFFFF, 0xFFFF, "CM8338B(0x0101)"},
{0x13F6, 0x0101, 0x13F6, 0x0101, "CMI8338-031 PCI Audio Device(0x13F6-0x0101)"},
{0x13F6, 0x0111, 0xFFFF, 0xFFFF, "CMI8738/CMI8768 PCI Audio(0x0111)"},
{0x13F6, 0x0111, 0x1019, 0x0970, "P6STP-FL motherboard(0x1019-0x0970)"},
{0x13F6, 0x0111, 0x1043, 0x8035, "CUSI-FX motherboard(0x1043-0x8035)"},
{0x13F6, 0x0111, 0x1043, 0x8077, "CMI8738 6-channel audio controller(0x1043-0x8077)"},
{0x13F6, 0x0111, 0x1043, 0x80E2, "CMI8738 6ch-MX(0x1043-0x80E2)"},
{0x13F6, 0x0111, 0x13F6, 0x0111, "CMI8738/C3DX PCI Audio Device(0x13F6-0x0111)"},
{0x13F6, 0x0111, 0x13F6, 0x9761, "Theatron Agrippa(0x13F6-0x9761)"},
{0x13F6, 0x0111, 0x153B, 0x1144, "Aureon 5.1(0x153B-0x1144)"},
{0x13F6, 0x0111, 0x153B, 0x1170, "Aureon 7.1(0x153B-0x1170)"},
{0x13F6, 0x0111, 0x1681, 0xA000, "Gamesurround MUSE XL(0x1681-0xA000)"},
{0x13F6, 0x0111, 0x17AB, 0x0604, "PSC604 Dynamic Edge(0x17AB-0x0604)"},
{0x13F6, 0x0111, 0x17AB, 0x0605, "PSC605 Sonic Edge(0x17AB-0x0605)"},
{0x13F6, 0x0111, 0x17AB, 0x7777, "PSC605 Sonic Edge(0x17AB-0x7777)"},
{0x13F6, 0x0111, 0x270F, 0x1103, "CT-7NJS Ultra motherboard(0x270F-0x1103)"},
{0x13F6, 0x0111, 0x270F, 0xF462, "7NJL1 motherboard(0x270F-0xF462)"},
{0x13F6, 0x0111, 0x584D, 0x3731, "Digital X-Mystique(0x584D-0x3731)"},
{0x13F6, 0x0111, 0x584D, 0x3741, "X-Plosion 7.1(0x584D-0x3741)"},
{0x13F6, 0x0111, 0x584D, 0x3751, "X-Raider 7.1(0x584D-0x3751)"},
{0x13F6, 0x0111, 0x584D, 0x3761, "X-Mystique 7.1 LP(0x584D-0x3761)"},
{0x13F6, 0x0111, 0x584D, 0x3771, "X-Mystique 7.1 LP Value(0x584D-0x3771)"},
{0x13F6, 0x0111, 0x7284, 0x8384, "Striker 7.1(0x7284-0x8384)"},
{0x13F6, 0x0211, 0xFFFF, 0xFFFF, "CM8738(0x0211)"},
{0x13F6, 0x5011, 0xFFFF, 0xFFFF, "CM8888 [Oxygen Express](0x5011)"},
{0x13F6, 0x5011, 0x13F6, 0x5011, "HDA Controller(0x13F6-0x5011)"},
{0x13F6, 0x8788, 0xFFFF, 0xFFFF, "CMI8788 [Oxygen HD Audio](0x8788)"},
{0x13F6, 0x8788, 0x1043, 0x8269, "Virtuoso 200 (Xonar D2)(0x1043-0x8269)"},
{0x13F6, 0x8788, 0x1043, 0x8275, "Virtuoso 100 (Xonar DX)(0x1043-0x8275)"},
{0x13F6, 0x8788, 0x1043, 0x82B7, "Virtuoso 200 (Xonar D2X)(0x1043-0x82B7)"},
{0x13F6, 0x8788, 0x1043, 0x8314, "Virtuoso 200 (Xonar HDAV1.3)(0x1043-0x8314)"},
{0x13F6, 0x8788, 0x1043, 0x8327, "Virtuoso 100 (Xonar DX)(0x1043-0x8327)"},
{0x13F6, 0x8788, 0x1043, 0x834F, "Virtuoso 100 (Xonar D1)(0x1043-0x834F)"},
{0x13F6, 0x8788, 0x1043, 0x835C, "Virtuoso 100 (Xonar Essence STX)(0x1043-0x835C)"},
{0x13F6, 0x8788, 0x1043, 0x835D, "Virtuoso 100 (Xonar ST)(0x1043-0x835D)"},
{0x13F6, 0x8788, 0x1043, 0x835E, "Virtuoso 200 (Xonar HDAV1.3 Slim)(0x1043-0x835E)"},
{0x13F6, 0x8788, 0x1043, 0x838E, "Virtuoso 66 (Xonar DS)(0x1043-0x838E)"},
{0x13F6, 0x8788, 0x1043, 0x8428, "Virtuoso 100 (Xonar Xense)(0x1043-0x8428)"},
{0x13F6, 0x8788, 0x1043, 0x8467, "CMI8786 (Xonar DG)(0x1043-0x8467)"},
{0x13F6, 0x8788, 0x1043, 0x8521, "CMI8786 (Xonar DGX)(0x1043-0x8521)"},
{0x13F6, 0x8788, 0x1043, 0x8522, "Xonar DSX(0x1043-0x8522)"},
{0x13F6, 0x8788, 0x1043, 0x85F4, "Virtuoso 100 (Xonar Essence STX II)(0x1043-0x85F4)"},
{0x13F6, 0x8788, 0x13F6, 0x8782, "PCI 2.0 HD Audio(0x13F6-0x8782)"},
{0x13F6, 0x8788, 0x13F6, 0xFFFF, "CMI8787-HG2PCI(0x13F6-0xFFFF)"},
{0x13F6, 0x8788, 0x14C3, 0x1710, "HiFier Fantasia(0x14C3-0x1710)"},
{0x13F6, 0x8788, 0x14C3, 0x1711, "HiFier Serenade(0x14C3-0x1711)"},
{0x13F6, 0x8788, 0x14C3, 0x1713, "HiFier Serenade III(0x14C3-0x1713)"},
{0x13F6, 0x8788, 0x1A58, 0x0910, "Barracuda AC-1(0x1A58-0x0910)"},
{0x13F6, 0x8788, 0x415A, 0x5431, "X-Meridian 7.1(0x415A-0x5431)"},
{0x13F6, 0x8788, 0x5431, 0x017A, "X-Meridian 7.1 2G(0x5431-0x017A)"},
{0x13F6, 0x8788, 0x584D, 0x3781, "HDA X-Purity 7.1 Platinum(0x584D-0x3781)"},
{0x13F6, 0x8788, 0x7284, 0x9761, "CLARO(0x7284-0x9761)"},
{0x13F6, 0x8788, 0x7284, 0x9781, "CLARO halo(0x7284-0x9781)"},
{0x13F6, 0x8788, 0x7284, 0x9783, "eCLARO(0x7284-0x9783)"},
{0x13F6, 0x8788, 0x7284, 0x9787, "CLARO II(0x7284-0x9787)"},
}; /* pci_vid_13F6[] */

static pci_id_t const pci_vid_13F7[] = {
{0x13F7, 0xFFFF, 0xFFFF, 0xFFFF, "Wildfire Communications(0x13F7)"},
}; /* pci_vid_13F7[] */

static pci_id_t const pci_vid_13F8[] = {
{0x13F8, 0xFFFF, 0xFFFF, 0xFFFF, "Ad Lib Multimedia Inc(0x13F8)"},
}; /* pci_vid_13F8[] */

static pci_id_t const pci_vid_13F9[] = {
{0x13F9, 0xFFFF, 0xFFFF, 0xFFFF, "NTT Advanced Technology Corp.(0x13F9)"},
}; /* pci_vid_13F9[] */

static pci_id_t const pci_vid_13FA[] = {
{0x13FA, 0xFFFF, 0xFFFF, 0xFFFF, "Pentland Systems Ltd(0x13FA)"},
}; /* pci_vid_13FA[] */

static pci_id_t const pci_vid_13FB[] = {
{0x13FB, 0xFFFF, 0xFFFF, 0xFFFF, "Aydin Corp(0x13FB)"},
}; /* pci_vid_13FB[] */

static pci_id_t const pci_vid_13FC[] = {
{0x13FC, 0xFFFF, 0xFFFF, 0xFFFF, "Computer Peripherals International(0x13FC)"},
}; /* pci_vid_13FC[] */

static pci_id_t const pci_vid_13FD[] = {
{0x13FD, 0xFFFF, 0xFFFF, 0xFFFF, "Micro Science Inc(0x13FD)"},
}; /* pci_vid_13FD[] */

static pci_id_t const pci_vid_13FE[] = {
{0x13FE, 0xFFFF, 0xFFFF, 0xFFFF, "Advantech Co. Ltd(0x13FE)"},
{0x13FE, 0x0071, 0xFFFF, 0xFFFF, "PCIE-1761H, 8-ch Relay and 8-ch Isolated Digital Input Card(0x0071)"},
{0x13FE, 0x1240, 0xFFFF, 0xFFFF, "PCI-1240 4-channel stepper motor controller card(0x1240)"},
{0x13FE, 0x1600, 0xFFFF, 0xFFFF, "PCI-16xx series PCI multiport serial board (function 0)(0x1600)"},
{0x13FE, 0x1600, 0x1601, 0x0002, "PCI-1601 2-port unisolated RS-422/485(0x1601-0x0002)"},
{0x13FE, 0x1600, 0x1602, 0x0002, "PCI-1602 2-port isolated RS-422/485(0x1602-0x0002)"},
{0x13FE, 0x1600, 0x1612, 0x0004, "PCI-1612 4-port RS-232/422/485(0x1612-0x0004)"},
{0x13FE, 0x1603, 0xFFFF, 0xFFFF, "PCI-1603 2-port isolated RS-232/current loop(0x1603)"},
{0x13FE, 0x1604, 0xFFFF, 0xFFFF, "PCI-1604 2-port RS-232(0x1604)"},
{0x13FE, 0x1680, 0xFFFF, 0xFFFF, "PCI-1680 Rev.A1 2-port CAN-bus with isolation protection(0x1680)"},
{0x13FE, 0x16FF, 0xFFFF, 0xFFFF, "PCI-16xx series PCI multiport serial board (function 1: RX/TX steering CPLD)(0x16FF)"},
{0x13FE, 0x16FF, 0x1601, 0x0000, "PCI-1601 2-port unisolated RS-422/485 PCI communications card(0x1601-0x0000)"},
{0x13FE, 0x16FF, 0x1602, 0x0000, "PCI-1602 2-port isolated RS-422/485(0x1602-0x0000)"},
{0x13FE, 0x16FF, 0x1612, 0x0000, "PCI-1612 4-port RS-232/422/485(0x1612-0x0000)"},
{0x13FE, 0x1711, 0xFFFF, 0xFFFF, "PCI-1711 16-channel data acquisition card 12-bit, 100kS/s(0x1711)"},
{0x13FE, 0x1713, 0xFFFF, 0xFFFF, "PCI-1713 32-channel isolated analog input card(0x1713)"},
{0x13FE, 0x1733, 0xFFFF, 0xFFFF, "PCI-1733 32-channel isolated digital input card(0x1733)"},
{0x13FE, 0x1734, 0xFFFF, 0xFFFF, "PCI-1734 32-channel isolated digital output card(0x1734)"},
{0x13FE, 0x1752, 0xFFFF, 0xFFFF, "PCI-1752 64-channel Isolated Digital Output Card(0x1752)"},
{0x13FE, 0x1754, 0xFFFF, 0xFFFF, "PCI-1754 64-channel Isolated Digital Input Card(0x1754)"},
{0x13FE, 0x1756, 0xFFFF, 0xFFFF, "PCI-1756 64-ch Isolated Digital I/O PCI Card(0x1756)"},
{0x13FE, 0xA004, 0xFFFF, 0xFFFF, "PCI-1612 4-port RS-232/422/485(0xA004)"},
{0x13FE, 0xC302, 0xFFFF, 0xFFFF, "MIOe-3680 2-Port CAN-Bus MIOe Module with Isolation Protection(0xC302)"},
}; /* pci_vid_13FE[] */

static pci_id_t const pci_vid_13FF[] = {
{0x13FF, 0xFFFF, 0xFFFF, 0xFFFF, "Silicon Spice Inc(0x13FF)"},
}; /* pci_vid_13FF[] */

static pci_id_t const pci_vid_1400[] = {
{0x1400, 0xFFFF, 0xFFFF, 0xFFFF, "Artx Inc(0x1400)"},
{0x1400, 0x1401, 0xFFFF, 0xFFFF, "9432 TX(0x1401)"},
}; /* pci_vid_1400[] */

static pci_id_t const pci_vid_1401[] = {
{0x1401, 0xFFFF, 0xFFFF, 0xFFFF, "CR-Systems A/S(0x1401)"},
}; /* pci_vid_1401[] */

static pci_id_t const pci_vid_1402[] = {
{0x1402, 0xFFFF, 0xFFFF, 0xFFFF, "Meilhaus Electronic GmbH(0x1402)"},
{0x1402, 0x0630, 0xFFFF, 0xFFFF, "ME-630(0x0630)"},
{0x1402, 0x0940, 0xFFFF, 0xFFFF, "ME-94(0x0940)"},
{0x1402, 0x0950, 0xFFFF, 0xFFFF, "ME-95(0x0950)"},
{0x1402, 0x0960, 0xFFFF, 0xFFFF, "ME-96(0x0960)"},
{0x1402, 0x1000, 0xFFFF, 0xFFFF, "ME-1000(0x1000)"},
{0x1402, 0x100A, 0xFFFF, 0xFFFF, "ME-1000(0x100A)"},
{0x1402, 0x100B, 0xFFFF, 0xFFFF, "ME-1000(0x100B)"},
{0x1402, 0x1400, 0xFFFF, 0xFFFF, "ME-1400(0x1400)"},
{0x1402, 0x140A, 0xFFFF, 0xFFFF, "ME-1400A(0x140A)"},
{0x1402, 0x140B, 0xFFFF, 0xFFFF, "ME-1400B(0x140B)"},
{0x1402, 0x140C, 0xFFFF, 0xFFFF, "ME-1400C(0x140C)"},
{0x1402, 0x140D, 0xFFFF, 0xFFFF, "ME-1400D(0x140D)"},
{0x1402, 0x140E, 0xFFFF, 0xFFFF, "ME-1400E(0x140E)"},
{0x1402, 0x14EA, 0xFFFF, 0xFFFF, "ME-1400EA(0x14EA)"},
{0x1402, 0x14EB, 0xFFFF, 0xFFFF, "ME-1400EB(0x14EB)"},
{0x1402, 0x1604, 0xFFFF, 0xFFFF, "ME-1600/4U(0x1604)"},
{0x1402, 0x1608, 0xFFFF, 0xFFFF, "ME-1600/8U(0x1608)"},
{0x1402, 0x160C, 0xFFFF, 0xFFFF, "ME-1600/12U(0x160C)"},
{0x1402, 0x160F, 0xFFFF, 0xFFFF, "ME-1600/16U(0x160F)"},
{0x1402, 0x168F, 0xFFFF, 0xFFFF, "ME-1600/16U8I(0x168F)"},
{0x1402, 0x4610, 0xFFFF, 0xFFFF, "ME-4610(0x4610)"},
{0x1402, 0x4650, 0xFFFF, 0xFFFF, "ME-4650(0x4650)"},
{0x1402, 0x4660, 0xFFFF, 0xFFFF, "ME-4660(0x4660)"},
{0x1402, 0x4661, 0xFFFF, 0xFFFF, "ME-4660I(0x4661)"},
{0x1402, 0x4662, 0xFFFF, 0xFFFF, "ME-4660(0x4662)"},
{0x1402, 0x4663, 0xFFFF, 0xFFFF, "ME-4660I(0x4663)"},
{0x1402, 0x4670, 0xFFFF, 0xFFFF, "ME-4670(0x4670)"},
{0x1402, 0x4671, 0xFFFF, 0xFFFF, "ME-4670I(0x4671)"},
{0x1402, 0x4672, 0xFFFF, 0xFFFF, "ME-4670S(0x4672)"},
{0x1402, 0x4673, 0xFFFF, 0xFFFF, "ME-4670IS(0x4673)"},
{0x1402, 0x4680, 0xFFFF, 0xFFFF, "ME-4680(0x4680)"},
{0x1402, 0x4681, 0xFFFF, 0xFFFF, "ME-4680I(0x4681)"},
{0x1402, 0x4682, 0xFFFF, 0xFFFF, "ME-4680S(0x4682)"},
{0x1402, 0x4683, 0xFFFF, 0xFFFF, "ME-4680IS(0x4683)"},
{0x1402, 0x6004, 0xFFFF, 0xFFFF, "ME-6000/4(0x6004)"},
{0x1402, 0x6008, 0xFFFF, 0xFFFF, "ME-6000/8(0x6008)"},
{0x1402, 0x600F, 0xFFFF, 0xFFFF, "ME-6000/16(0x600F)"},
{0x1402, 0x6014, 0xFFFF, 0xFFFF, "ME-6000I/4(0x6014)"},
{0x1402, 0x6018, 0xFFFF, 0xFFFF, "ME-6000I/8(0x6018)"},
{0x1402, 0x601F, 0xFFFF, 0xFFFF, "ME-6000I/16(0x601F)"},
{0x1402, 0x6034, 0xFFFF, 0xFFFF, "ME-6000ISLE/4(0x6034)"},
{0x1402, 0x6038, 0xFFFF, 0xFFFF, "ME-6000ISLE/8(0x6038)"},
{0x1402, 0x603F, 0xFFFF, 0xFFFF, "ME-6000ISLE/16(0x603F)"},
{0x1402, 0x6044, 0xFFFF, 0xFFFF, "ME-6000/4/DIO(0x6044)"},
{0x1402, 0x6048, 0xFFFF, 0xFFFF, "ME-6000/8/DIO(0x6048)"},
{0x1402, 0x604F, 0xFFFF, 0xFFFF, "ME-6000/16/DIO(0x604F)"},
{0x1402, 0x6054, 0xFFFF, 0xFFFF, "ME-6000I/4/DIO(0x6054)"},
{0x1402, 0x6058, 0xFFFF, 0xFFFF, "ME-6000I/8/DIO(0x6058)"},
{0x1402, 0x605F, 0xFFFF, 0xFFFF, "ME-6000I/16/DIO(0x605F)"},
{0x1402, 0x6074, 0xFFFF, 0xFFFF, "ME-6000ISLE/4/DIO(0x6074)"},
{0x1402, 0x6078, 0xFFFF, 0xFFFF, "ME-6000ISLE/8/DIO(0x6078)"},
{0x1402, 0x607F, 0xFFFF, 0xFFFF, "ME-6000ISLE/16/DIO(0x607F)"},
{0x1402, 0x6104, 0xFFFF, 0xFFFF, "ME-6100/4(0x6104)"},
{0x1402, 0x6108, 0xFFFF, 0xFFFF, "ME-6100/8(0x6108)"},
{0x1402, 0x610F, 0xFFFF, 0xFFFF, "ME-6100/16(0x610F)"},
{0x1402, 0x6114, 0xFFFF, 0xFFFF, "ME-6100I/4(0x6114)"},
{0x1402, 0x6118, 0xFFFF, 0xFFFF, "ME-6100I/8(0x6118)"},
{0x1402, 0x611F, 0xFFFF, 0xFFFF, "ME-6100I/16(0x611F)"},
{0x1402, 0x6134, 0xFFFF, 0xFFFF, "ME-6100ISLE/4(0x6134)"},
{0x1402, 0x6138, 0xFFFF, 0xFFFF, "ME-6100ISLE/8(0x6138)"},
{0x1402, 0x613F, 0xFFFF, 0xFFFF, "ME-6100ISLE/16(0x613F)"},
{0x1402, 0x6144, 0xFFFF, 0xFFFF, "ME-6100/4/DIO(0x6144)"},
{0x1402, 0x6148, 0xFFFF, 0xFFFF, "ME-6100/8/DIO(0x6148)"},
{0x1402, 0x614F, 0xFFFF, 0xFFFF, "ME-6100/16/DIO(0x614F)"},
{0x1402, 0x6154, 0xFFFF, 0xFFFF, "ME-6100I/4/DIO(0x6154)"},
{0x1402, 0x6158, 0xFFFF, 0xFFFF, "ME-6100I/8/DIO(0x6158)"},
{0x1402, 0x615F, 0xFFFF, 0xFFFF, "ME-6100I/16/DIO(0x615F)"},
{0x1402, 0x6174, 0xFFFF, 0xFFFF, "ME-6100ISLE/4/DIO(0x6174)"},
{0x1402, 0x6178, 0xFFFF, 0xFFFF, "ME-6100ISLE/8/DIO(0x6178)"},
{0x1402, 0x617F, 0xFFFF, 0xFFFF, "ME-6100ISLE/16/DIO(0x617F)"},
{0x1402, 0x6259, 0xFFFF, 0xFFFF, "ME-6200I/9/DIO(0x6259)"},
{0x1402, 0x6359, 0xFFFF, 0xFFFF, "ME-6300I/9/DIO(0x6359)"},
{0x1402, 0x810A, 0xFFFF, 0xFFFF, "ME-8100A(0x810A)"},
{0x1402, 0x810B, 0xFFFF, 0xFFFF, "ME-8100B(0x810B)"},
{0x1402, 0x820A, 0xFFFF, 0xFFFF, "ME-8200A(0x820A)"},
{0x1402, 0x820B, 0xFFFF, 0xFFFF, "ME-8200B(0x820B)"},
}; /* pci_vid_1402[] */

static pci_id_t const pci_vid_1403[] = {
{0x1403, 0xFFFF, 0xFFFF, 0xFFFF, "Ascor Inc(0x1403)"},
}; /* pci_vid_1403[] */

static pci_id_t const pci_vid_1404[] = {
{0x1404, 0xFFFF, 0xFFFF, 0xFFFF, "Fundamental Software Inc(0x1404)"},
}; /* pci_vid_1404[] */

static pci_id_t const pci_vid_1405[] = {
{0x1405, 0xFFFF, 0xFFFF, 0xFFFF, "Excalibur Systems Inc(0x1405)"},
}; /* pci_vid_1405[] */

static pci_id_t const pci_vid_1406[] = {
{0x1406, 0xFFFF, 0xFFFF, 0xFFFF, "Oce' Printing Systems GmbH(0x1406)"},
}; /* pci_vid_1406[] */

static pci_id_t const pci_vid_1407[] = {
{0x1407, 0xFFFF, 0xFFFF, 0xFFFF, "Lava Computer mfg Inc(0x1407)"},
{0x1407, 0x0100, 0xFFFF, 0xFFFF, "Lava Dual Serial(0x0100)"},
{0x1407, 0x0101, 0xFFFF, 0xFFFF, "Lava Quatro A(0x0101)"},
{0x1407, 0x0102, 0xFFFF, 0xFFFF, "Lava Quatro B(0x0102)"},
{0x1407, 0x0110, 0xFFFF, 0xFFFF, "Lava DSerial-PCI Port A(0x0110)"},
{0x1407, 0x0111, 0xFFFF, 0xFFFF, "Lava DSerial-PCI Port B(0x0111)"},
{0x1407, 0x0120, 0xFFFF, 0xFFFF, "Quattro-PCI A(0x0120)"},
{0x1407, 0x0121, 0xFFFF, 0xFFFF, "Quattro-PCI B(0x0121)"},
{0x1407, 0x0180, 0xFFFF, 0xFFFF, "Lava Octo A(0x0180)"},
{0x1407, 0x0181, 0xFFFF, 0xFFFF, "Lava Octo B(0x0181)"},
{0x1407, 0x0200, 0xFFFF, 0xFFFF, "Lava Port Plus(0x0200)"},
{0x1407, 0x0201, 0xFFFF, 0xFFFF, "Lava Quad A(0x0201)"},
{0x1407, 0x0202, 0xFFFF, 0xFFFF, "Lava Quad B(0x0202)"},
{0x1407, 0x0220, 0xFFFF, 0xFFFF, "Lava Quattro PCI Ports A/B(0x0220)"},
{0x1407, 0x0221, 0xFFFF, 0xFFFF, "Lava Quattro PCI Ports C/D(0x0221)"},
{0x1407, 0x0400, 0xFFFF, 0xFFFF, "Lava 8255-PIO-PCI(0x0400)"},
{0x1407, 0x0500, 0xFFFF, 0xFFFF, "Lava Single Serial(0x0500)"},
{0x1407, 0x0520, 0xFFFF, 0xFFFF, "Lava RS422-SS-PCI(0x0520)"},
{0x1407, 0x0600, 0xFFFF, 0xFFFF, "Lava Port 650(0x0600)"},
{0x1407, 0x8000, 0xFFFF, 0xFFFF, "Lava Parallel(0x8000)"},
{0x1407, 0x8001, 0xFFFF, 0xFFFF, "Dual parallel port controller A(0x8001)"},
{0x1407, 0x8002, 0xFFFF, 0xFFFF, "Lava Dual Parallel port A(0x8002)"},
{0x1407, 0x8003, 0xFFFF, 0xFFFF, "Lava Dual Parallel port B(0x8003)"},
{0x1407, 0x8800, 0xFFFF, 0xFFFF, "BOCA Research IOPPAR(0x8800)"},
}; /* pci_vid_1407[] */

static pci_id_t const pci_vid_1408[] = {
{0x1408, 0xFFFF, 0xFFFF, 0xFFFF, "Aloka Co. Ltd(0x1408)"},
}; /* pci_vid_1408[] */

static pci_id_t const pci_vid_1409[] = {
{0x1409, 0xFFFF, 0xFFFF, 0xFFFF, "Timedia Technology Co Ltd(0x1409)"},
{0x1409, 0x7168, 0xFFFF, 0xFFFF, "PCI2S550 (Dual 16550 UART)(0x7168)"},
{0x1409, 0x7168, 0x1409, 0x0002, "SER4036A3V (2x RS232 port)(0x1409-0x0002)"},
{0x1409, 0x7168, 0x1409, 0x4027, "SER4027A (1x RS232 port)(0x1409-0x4027)"},
{0x1409, 0x7168, 0x1409, 0x4037, "SER4037A(L) [SUNIX SUN1889] (2x RS232 port)(0x1409-0x4037)"},
{0x1409, 0x7168, 0x1409, 0x4056, "SER4056A (4x RS232)(0x1409-0x4056)"},
{0x1409, 0x7168, 0x1409, 0x5027, "SER4027D(0x1409-0x5027)"},
{0x1409, 0x7168, 0x1409, 0x5037, "SER4037D (2x RS232 port)(0x1409-0x5037)"},
{0x1409, 0x7168, 0x1409, 0x5066, "SER4066R (8x RS232)(0x1409-0x5066)"},
{0x1409, 0x7168, 0x1409, 0x6056, "SER4056D (4x RS232 port)(0x1409-0x6056)"},
{0x1409, 0x7268, 0xFFFF, 0xFFFF, "SUN1888 (Dual IEEE1284 parallel port)(0x7268)"},
{0x1409, 0x7268, 0x1409, 0x0103, "PAR4008A(0x1409-0x0103)"},
{0x1409, 0x7268, 0x1409, 0x0104, "PAR4018A(0x1409-0x0104)"},
}; /* pci_vid_1409[] */

static pci_id_t const pci_vid_140A[] = {
{0x140A, 0xFFFF, 0xFFFF, 0xFFFF, "DSP Research Inc(0x140A)"},
}; /* pci_vid_140A[] */

static pci_id_t const pci_vid_140B[] = {
{0x140B, 0xFFFF, 0xFFFF, 0xFFFF, "Abaco Systems, Inc.(0x140B)"},
}; /* pci_vid_140B[] */

static pci_id_t const pci_vid_140C[] = {
{0x140C, 0xFFFF, 0xFFFF, 0xFFFF, "Elmic Systems Inc(0x140C)"},
}; /* pci_vid_140C[] */

static pci_id_t const pci_vid_140D[] = {
{0x140D, 0xFFFF, 0xFFFF, 0xFFFF, "Matsushita Electric Works Ltd(0x140D)"},
}; /* pci_vid_140D[] */

static pci_id_t const pci_vid_140E[] = {
{0x140E, 0xFFFF, 0xFFFF, 0xFFFF, "Goepel Electronic GmbH(0x140E)"},
}; /* pci_vid_140E[] */

static pci_id_t const pci_vid_140F[] = {
{0x140F, 0xFFFF, 0xFFFF, 0xFFFF, "Salient Systems Corp(0x140F)"},
}; /* pci_vid_140F[] */

static pci_id_t const pci_vid_1410[] = {
{0x1410, 0xFFFF, 0xFFFF, 0xFFFF, "Midas lab Inc(0x1410)"},
}; /* pci_vid_1410[] */

static pci_id_t const pci_vid_1411[] = {
{0x1411, 0xFFFF, 0xFFFF, 0xFFFF, "Ikos Systems Inc(0x1411)"},
}; /* pci_vid_1411[] */

static pci_id_t const pci_vid_1412[] = {
{0x1412, 0xFFFF, 0xFFFF, 0xFFFF, "VIA Technologies Inc.(0x1412)"},
{0x1412, 0x1712, 0xFFFF, 0xFFFF, "ICE1712 [Envy24] PCI Multi-Channel I/O Controller(0x1712)"},
{0x1412, 0x1712, 0x1412, 0x1712, "Hoontech ST Audio DSP 24(0x1412-0x1712)"},
{0x1412, 0x1712, 0x1412, 0xD630, "M-Audio Delta 1010(0x1412-0xD630)"},
{0x1412, 0x1712, 0x1412, 0xD631, "M-Audio Delta DiO(0x1412-0xD631)"},
{0x1412, 0x1712, 0x1412, 0xD632, "M-Audio Delta 66(0x1412-0xD632)"},
{0x1412, 0x1712, 0x1412, 0xD633, "M-Audio Delta 44(0x1412-0xD633)"},
{0x1412, 0x1712, 0x1412, 0xD634, "M-Audio Delta Audiophile 2496(0x1412-0xD634)"},
{0x1412, 0x1712, 0x1412, 0xD635, "M-Audio Delta TDIF(0x1412-0xD635)"},
{0x1412, 0x1712, 0x1412, 0xD637, "M-Audio Delta RBUS(0x1412-0xD637)"},
{0x1412, 0x1712, 0x1412, 0xD638, "M-Audio Delta 410(0x1412-0xD638)"},
{0x1412, 0x1712, 0x1412, 0xD63B, "M-Audio Delta 1010LT(0x1412-0xD63B)"},
{0x1412, 0x1712, 0x1412, 0xD63C, "Digigram VX442(0x1412-0xD63C)"},
{0x1412, 0x1712, 0x1416, 0x1712, "Hoontech ST Audio DSP 24 Media 7.1(0x1416-0x1712)"},
{0x1412, 0x1712, 0x153B, 0x1115, "EWS88 MT(0x153B-0x1115)"},
{0x1412, 0x1712, 0x153B, 0x1125, "EWS88 MT (Master)(0x153B-0x1125)"},
{0x1412, 0x1712, 0x153B, 0x112B, "EWS88 D(0x153B-0x112B)"},
{0x1412, 0x1712, 0x153B, 0x112C, "EWS88 D (Master)(0x153B-0x112C)"},
{0x1412, 0x1712, 0x153B, 0x1130, "EWX 24/96(0x153B-0x1130)"},
{0x1412, 0x1712, 0x153B, 0x1138, "DMX 6fire 24/96(0x153B-0x1138)"},
{0x1412, 0x1712, 0x153B, 0x1151, "PHASE88(0x153B-0x1151)"},
{0x1412, 0x1712, 0x16CE, 0x1040, "Edirol DA-2496(0x16CE-0x1040)"},
{0x1412, 0x1724, 0xFFFF, 0xFFFF, "VT1720/24 [Envy24PT/HT] PCI Multi-Channel Audio Controller(0x1724)"},
{0x1412, 0x1724, 0x10B0, 0x0200, "Hollywood@Home 7.1(0x10B0-0x0200)"},
{0x1412, 0x1724, 0x1412, 0x1724, "Albatron PX865PE 7.1(0x1412-0x1724)"},
{0x1412, 0x1724, 0x1412, 0x3630, "M-Audio Revolution 7.1(0x1412-0x3630)"},
{0x1412, 0x1724, 0x1412, 0x3631, "M-Audio Revolution 5.1(0x1412-0x3631)"},
{0x1412, 0x1724, 0x1412, 0x3632, "M-Audio Audiophile 192(0x1412-0x3632)"},
{0x1412, 0x1724, 0x153B, 0x1145, "Aureon 7.1 Space(0x153B-0x1145)"},
{0x1412, 0x1724, 0x153B, 0x1147, "Aureon 5.1 Sky(0x153B-0x1147)"},
{0x1412, 0x1724, 0x153B, 0x1150, "PHASE 22(0x153B-0x1150)"},
{0x1412, 0x1724, 0x153B, 0x1153, "Aureon 7.1 Universe(0x153B-0x1153)"},
{0x1412, 0x1724, 0x17AB, 0x1906, "PSC 724 [Ultimate Edge](0x17AB-0x1906)"},
{0x1412, 0x1724, 0x270F, 0xF641, "ZNF3-150(0x270F-0xF641)"},
{0x1412, 0x1724, 0x270F, 0xF645, "ZNF3-250(0x270F-0xF645)"},
{0x1412, 0x1724, 0x3130, 0x4154, "MAYA 44 MKII(0x3130-0x4154)"},
}; /* pci_vid_1412[] */

static pci_id_t const pci_vid_1413[] = {
{0x1413, 0xFFFF, 0xFFFF, 0xFFFF, "Addonics(0x1413)"},
}; /* pci_vid_1413[] */

static pci_id_t const pci_vid_1414[] = {
{0x1414, 0xFFFF, 0xFFFF, 0xFFFF, "Microsoft Corporation(0x1414)"},
{0x1414, 0x0001, 0xFFFF, 0xFFFF, "MN-120 (ADMtek Centaur-C based)(0x0001)"},
{0x1414, 0x0002, 0xFFFF, 0xFFFF, "MN-130 (ADMtek Centaur-P based)(0x0002)"},
{0x1414, 0x008C, 0xFFFF, 0xFFFF, "Basic Render Driver(0x008C)"},
{0x1414, 0x008E, 0xFFFF, 0xFFFF, "Basic Render Driver(0x008E)"},
{0x1414, 0x5353, 0xFFFF, 0xFFFF, "Hyper-V virtual VGA(0x5353)"},
{0x1414, 0x5801, 0xFFFF, 0xFFFF, "XMA Decoder (Xenon)(0x5801)"},
{0x1414, 0x5802, 0xFFFF, 0xFFFF, "SATA Controller - CdRom (Xenon)(0x5802)"},
{0x1414, 0x5803, 0xFFFF, 0xFFFF, "SATA Controller - Disk (Xenon)(0x5803)"},
{0x1414, 0x5804, 0xFFFF, 0xFFFF, "OHCI Controller 0 (Xenon)(0x5804)"},
{0x1414, 0x5805, 0xFFFF, 0xFFFF, "EHCI Controller 0 (Xenon)(0x5805)"},
{0x1414, 0x5806, 0xFFFF, 0xFFFF, "OHCI Controller 1 (Xenon)(0x5806)"},
{0x1414, 0x5807, 0xFFFF, 0xFFFF, "EHCI Controller 1 (Xenon)(0x5807)"},
{0x1414, 0x580A, 0xFFFF, 0xFFFF, "Fast Ethernet Adapter (Xenon)(0x580A)"},
{0x1414, 0x580B, 0xFFFF, 0xFFFF, "Secure Flash Controller (Xenon)(0x580B)"},
{0x1414, 0x580D, 0xFFFF, 0xFFFF, "System Management Controller (Xenon)(0x580D)"},
{0x1414, 0x5811, 0xFFFF, 0xFFFF, "Xenos GPU (Xenon)(0x5811)"},
{0x1414, 0x5821, 0xFFFF, 0xFFFF, "Xenos GPU (Zephyr/Falcon)(0x5821)"},
{0x1414, 0x5831, 0xFFFF, 0xFFFF, "Xenos GPU (Jasper)(0x5831)"},
{0x1414, 0x5841, 0xFFFF, 0xFFFF, "Xenos GPU (Slim)(0x5841)"},
}; /* pci_vid_1414[] */

static pci_id_t const pci_vid_1415[] = {
{0x1415, 0xFFFF, 0xFFFF, 0xFFFF, "Oxford Semiconductor Ltd(0x1415)"},
{0x1415, 0x8401, 0xFFFF, 0xFFFF, "OX9162 Mode 1 (8-bit bus)(0x8401)"},
{0x1415, 0x8403, 0xFFFF, 0xFFFF, "OX9162 Mode 0 (parallel port)(0x8403)"},
{0x1415, 0x9500, 0xFFFF, 0xFFFF, "OX16PCI954 (Quad 16950 UART) function 0 (Disabled)(0x9500)"},
{0x1415, 0x9501, 0xFFFF, 0xFFFF, "OX16PCI954 (Quad 16950 UART) function 0 (Uart)(0x9501)"},
{0x1415, 0x9501, 0x12C4, 0x0201, "Titan/cPCI (2 port)(0x12C4-0x0201)"},
{0x1415, 0x9501, 0x12C4, 0x0202, "Titan/cPCI (4 port)(0x12C4-0x0202)"},
{0x1415, 0x9501, 0x12C4, 0x0203, "Titan/cPCI (8 port)(0x12C4-0x0203)"},
{0x1415, 0x9501, 0x12C4, 0x0210, "Titan/104-Plus (8 port, p1-4)(0x12C4-0x0210)"},
{0x1415, 0x9501, 0x131F, 0x2050, "CyberPro (4-port)(0x131F-0x2050)"},
{0x1415, 0x9501, 0x131F, 0x2051, "CyberSerial 4S Plus(0x131F-0x2051)"},
{0x1415, 0x9501, 0x15ED, 0x2000, "MCCR Serial p0-3 of 8(0x15ED-0x2000)"},
{0x1415, 0x9501, 0x15ED, 0x2001, "MCCR Serial p0-3 of 16(0x15ED-0x2001)"},
{0x1415, 0x9505, 0xFFFF, 0xFFFF, "OXuPCI952 (Dual 16C950 UART)(0x9505)"},
{0x1415, 0x950A, 0xFFFF, 0xFFFF, "EXSYS EX-41092 Dual 16950 Serial adapter(0x950A)"},
{0x1415, 0x950B, 0xFFFF, 0xFFFF, "OXCB950 Cardbus 16950 UART(0x950B)"},
{0x1415, 0x9510, 0xFFFF, 0xFFFF, "OX16PCI954 (Quad 16950 UART) function 1 (Disabled)(0x9510)"},
{0x1415, 0x9510, 0x12C4, 0x0200, "Titan/cPCI (Unused)(0x12C4-0x0200)"},
{0x1415, 0x9511, 0xFFFF, 0xFFFF, "OX16PCI954 (Quad 16950 UART) function 1 (8bit bus)(0x9511)"},
{0x1415, 0x9511, 0x12C4, 0x0211, "Titan/104-Plus (8 port, p5-8)(0x12C4-0x0211)"},
{0x1415, 0x9511, 0x15ED, 0x2000, "MCCR Serial p4-7 of 8(0x15ED-0x2000)"},
{0x1415, 0x9511, 0x15ED, 0x2001, "MCCR Serial p4-15 of 16(0x15ED-0x2001)"},
{0x1415, 0x9512, 0xFFFF, 0xFFFF, "OX16PCI954 (Quad 16950 UART) function 1 (32bit bus)(0x9512)"},
{0x1415, 0x9513, 0xFFFF, 0xFFFF, "OX16PCI954 (Quad 16950 UART) function 1 (parallel port)(0x9513)"},
{0x1415, 0x9521, 0xFFFF, 0xFFFF, "OX16PCI952 (Dual 16950 UART)(0x9521)"},
{0x1415, 0x9523, 0xFFFF, 0xFFFF, "OX16PCI952 Integrated Parallel Port(0x9523)"},
{0x1415, 0xC000, 0xFFFF, 0xFFFF, "OXPCIe840 Parallel Port(0xC000)"},
{0x1415, 0xC004, 0xFFFF, 0xFFFF, "OXPCIe840 Parallel Port(0xC004)"},
{0x1415, 0xC006, 0xFFFF, 0xFFFF, "OXPCIe840 GPIO(0xC006)"},
{0x1415, 0xC100, 0xFFFF, 0xFFFF, "OXPCIe952 Parallel Port(0xC100)"},
{0x1415, 0xC101, 0xFFFF, 0xFFFF, "OXPCIe952 Legacy 950 UART(0xC101)"},
{0x1415, 0xC104, 0xFFFF, 0xFFFF, "OXPCIe952 Parallel Port(0xC104)"},
{0x1415, 0xC105, 0xFFFF, 0xFFFF, "OXPCIe952 Legacy 950 UART(0xC105)"},
{0x1415, 0xC106, 0xFFFF, 0xFFFF, "OXPCIe952 GPIO(0xC106)"},
{0x1415, 0xC108, 0xFFFF, 0xFFFF, "OXPCIe952 Parallel Port(0xC108)"},
{0x1415, 0xC109, 0xFFFF, 0xFFFF, "OXPCIe952 Legacy 950 UART(0xC109)"},
{0x1415, 0xC10C, 0xFFFF, 0xFFFF, "OXPCIe952 Parallel Port(0xC10C)"},
{0x1415, 0xC10D, 0xFFFF, 0xFFFF, "OXPCIe952 Legacy 950 UART(0xC10D)"},
{0x1415, 0xC10E, 0xFFFF, 0xFFFF, "OXPCIe952 GPIO(0xC10E)"},
{0x1415, 0xC110, 0xFFFF, 0xFFFF, "OXPCIe952 Parallel Port(0xC110)"},
{0x1415, 0xC114, 0xFFFF, 0xFFFF, "OXPCIe952 Parallel Port(0xC114)"},
{0x1415, 0xC118, 0xFFFF, 0xFFFF, "OXPCIe952 Parallel Port(0xC118)"},
{0x1415, 0xC11B, 0xFFFF, 0xFFFF, "OXPCIe952 Native 950 UART(0xC11B)"},
{0x1415, 0xC11C, 0xFFFF, 0xFFFF, "OXPCIe952 Parallel Port(0xC11C)"},
{0x1415, 0xC11E, 0xFFFF, 0xFFFF, "OXPCIe952 GPIO(0xC11E)"},
{0x1415, 0xC11F, 0xFFFF, 0xFFFF, "OXPCIe952 Native 950 UART(0xC11F)"},
{0x1415, 0xC120, 0xFFFF, 0xFFFF, "OXPCIe952 Legacy 950 UART(0xC120)"},
{0x1415, 0xC124, 0xFFFF, 0xFFFF, "OXPCIe952 Legacy 950 UART(0xC124)"},
{0x1415, 0xC126, 0xFFFF, 0xFFFF, "OXPCIe952 GPIO(0xC126)"},
{0x1415, 0xC128, 0xFFFF, 0xFFFF, "OXPCIe952 Legacy 950 UART(0xC128)"},
{0x1415, 0xC12C, 0xFFFF, 0xFFFF, "OXPCIe952 Legacy 950 UART(0xC12C)"},
{0x1415, 0xC12E, 0xFFFF, 0xFFFF, "OXPCIe952 GPIO(0xC12E)"},
{0x1415, 0xC134, 0xFFFF, 0xFFFF, "OXPCIe952 GPIO(0xC134)"},
{0x1415, 0xC138, 0xFFFF, 0xFFFF, "OXPCIe952 Native 950 UART(0xC138)"},
{0x1415, 0xC13C, 0xFFFF, 0xFFFF, "OXPCIe952 GPIO(0xC13C)"},
{0x1415, 0xC13D, 0xFFFF, 0xFFFF, "OXPCIe952 Native 950 UART(0xC13D)"},
{0x1415, 0xC140, 0xFFFF, 0xFFFF, "OXPCIe952 Legacy 950 UART #1(0xC140)"},
{0x1415, 0xC141, 0xFFFF, 0xFFFF, "OXPCIe952 Legacy 950 UART #2(0xC141)"},
{0x1415, 0xC144, 0xFFFF, 0xFFFF, "OXPCIe952 Legacy 950 UART #1(0xC144)"},
{0x1415, 0xC145, 0xFFFF, 0xFFFF, "OXPCIe952 Legacy 950 UART #2(0xC145)"},
{0x1415, 0xC146, 0xFFFF, 0xFFFF, "OXPCIe952 GPIO(0xC146)"},
{0x1415, 0xC148, 0xFFFF, 0xFFFF, "OXPCIe952 Legacy 950 UART #1(0xC148)"},
{0x1415, 0xC149, 0xFFFF, 0xFFFF, "OXPCIe952 Legacy 950 UART #2(0xC149)"},
{0x1415, 0xC14C, 0xFFFF, 0xFFFF, "OXPCIe952 Legacy 950 UART #1(0xC14C)"},
{0x1415, 0xC14D, 0xFFFF, 0xFFFF, "OXPCIe952 Legacy 950 UART #2(0xC14D)"},
{0x1415, 0xC14E, 0xFFFF, 0xFFFF, "OXPCIe952 GPIO(0xC14E)"},
{0x1415, 0xC154, 0xFFFF, 0xFFFF, "OXPCIe952 GPIO(0xC154)"},
{0x1415, 0xC158, 0xFFFF, 0xFFFF, "OXPCIe952 Dual Native 950 UART(0xC158)"},
{0x1415, 0xC158, 0xE4BF, 0xC504, "CP4-SCAT Wireless Technologies Carrier Board(0xE4BF-0xC504)"},
{0x1415, 0xC158, 0xE4BF, 0xD551, "DU1-MUSTANG Dual-Port RS-485 Interface(0xE4BF-0xD551)"},
{0x1415, 0xC15C, 0xFFFF, 0xFFFF, "OXPCIe952 GPIO(0xC15C)"},
{0x1415, 0xC15D, 0xFFFF, 0xFFFF, "OXPCIe952 Dual Native 950 UART(0xC15D)"},
{0x1415, 0xC204, 0xFFFF, 0xFFFF, "OXPCIe954 GPIO(0xC204)"},
{0x1415, 0xC208, 0xFFFF, 0xFFFF, "OXPCIe954 Quad Native 950 UART(0xC208)"},
{0x1415, 0xC20C, 0xFFFF, 0xFFFF, "OXPCIe954 GPIO(0xC20C)"},
{0x1415, 0xC20D, 0xFFFF, 0xFFFF, "OXPCIe954 Quad Native 950 UART(0xC20D)"},
{0x1415, 0xC304, 0xFFFF, 0xFFFF, "OXPCIe958 GPIO(0xC304)"},
{0x1415, 0xC308, 0xFFFF, 0xFFFF, "OXPCIe958 Quad Native 950 UART(0xC308)"},
{0x1415, 0xC30C, 0xFFFF, 0xFFFF, "OXPCIe958 GPIO(0xC30C)"},
{0x1415, 0xC30D, 0xFFFF, 0xFFFF, "OXPCIe958 Quad Native 950 UART(0xC30D)"},
{0x1415, 0xC530, 0xFFFF, 0xFFFF, "OXPCIe200 Dual OHCI USB Controller (ULPI/R-ULPI)(0xC530)"},
{0x1415, 0xC531, 0xFFFF, 0xFFFF, "OXPCIe200 Dual EHCI USB Controller (ULPI/R-ULPI)(0xC531)"},
{0x1415, 0xC534, 0xFFFF, 0xFFFF, "OXPCIe200 Dual OHCI USB Controller (ULPI/R-ULPI)(0xC534)"},
{0x1415, 0xC535, 0xFFFF, 0xFFFF, "OXPCIe200 Dual EHCI USB Controller (ULPI/R-ULPI)(0xC535)"},
{0x1415, 0xC536, 0xFFFF, 0xFFFF, "OXPCIe200 GPIO(0xC536)"},
{0x1415, 0xC538, 0xFFFF, 0xFFFF, "OXPCIe200 Dual OHCI USB Controller (ULPI/R-ULPI)(0xC538)"},
{0x1415, 0xC539, 0xFFFF, 0xFFFF, "OXPCIe200 Dual EHCI USB Controller (ULPI/R-ULPI)(0xC539)"},
{0x1415, 0xC53B, 0xFFFF, 0xFFFF, "OXPCIe200 Native 950 UART(0xC53B)"},
{0x1415, 0xC53C, 0xFFFF, 0xFFFF, "OXPCIe200 Dual OHCI USB Controller (ULPI/R-ULPI)(0xC53C)"},
{0x1415, 0xC53D, 0xFFFF, 0xFFFF, "OXPCIe200 Dual EHCI USB Controller (ULPI/R-ULPI)(0xC53D)"},
{0x1415, 0xC53E, 0xFFFF, 0xFFFF, "OXPCIe200 GPIO(0xC53E)"},
{0x1415, 0xC53F, 0xFFFF, 0xFFFF, "OXPCIe200 Native 950 UART(0xC53F)"},
{0x1415, 0xC540, 0xFFFF, 0xFFFF, "OXPCIe200 Dual OHCI USB Controller (R-ULPI)(0xC540)"},
{0x1415, 0xC541, 0xFFFF, 0xFFFF, "OXPCIe200 Dual EHCI USB Controller (R-ULPI)(0xC541)"},
{0x1415, 0xC544, 0xFFFF, 0xFFFF, "OXPCIe200 Dual OHCI USB Controller (R-ULPI)(0xC544)"},
{0x1415, 0xC545, 0xFFFF, 0xFFFF, "OXPCIe200 Dual EHCI USB Controller (R-ULPI)(0xC545)"},
{0x1415, 0xC546, 0xFFFF, 0xFFFF, "OXPCIe200 GPIO(0xC546)"},
{0x1415, 0xC548, 0xFFFF, 0xFFFF, "OXPCIe200 Dual OHCI USB Controller (R-ULPI)(0xC548)"},
{0x1415, 0xC549, 0xFFFF, 0xFFFF, "OXPCIe200 Dual EHCI USB Controller (R-ULPI)(0xC549)"},
{0x1415, 0xC54B, 0xFFFF, 0xFFFF, "OXPCIe200 Native 950 UART(0xC54B)"},
{0x1415, 0xC54C, 0xFFFF, 0xFFFF, "OXPCIe200 Dual OHCI USB Controller (R-ULPI)(0xC54C)"},
{0x1415, 0xC54D, 0xFFFF, 0xFFFF, "OXPCIe200 Dual EHCI USB Controller (R-ULPI)(0xC54D)"},
{0x1415, 0xC54E, 0xFFFF, 0xFFFF, "OXPCIe200 Dual GPIO(0xC54E)"},
{0x1415, 0xC54F, 0xFFFF, 0xFFFF, "OXPCIe200 Native 950 UART(0xC54F)"},
{0x1415, 0xC560, 0xFFFF, 0xFFFF, "OXPCIe200 Dual OHCI USB Controller (ULPI/analog)(0xC560)"},
{0x1415, 0xC561, 0xFFFF, 0xFFFF, "OXPCIe200 EHCI USB Controller (ULPI)(0xC561)"},
{0x1415, 0xC564, 0xFFFF, 0xFFFF, "OXPCIe200 Dual OHCI USB Controller (ULPI/analog)(0xC564)"},
{0x1415, 0xC565, 0xFFFF, 0xFFFF, "OXPCIe200 EHCI USB Controller (ULPI)(0xC565)"},
{0x1415, 0xC566, 0xFFFF, 0xFFFF, "OXPCIe200 GPIO(0xC566)"},
{0x1415, 0xC568, 0xFFFF, 0xFFFF, "OXPCIe200 Dual OHCI USB Controller (ULPI/analog)(0xC568)"},
{0x1415, 0xC569, 0xFFFF, 0xFFFF, "OXPCIe200 EHCI USB Controller (ULPI)(0xC569)"},
{0x1415, 0xC56B, 0xFFFF, 0xFFFF, "OXPCIe200 Native 950 UART(0xC56B)"},
{0x1415, 0xC56C, 0xFFFF, 0xFFFF, "OXPCIe200 Dual OHCI USB Controller (ULPI/analog)(0xC56C)"},
{0x1415, 0xC56D, 0xFFFF, 0xFFFF, "OXPCIe200 EHCI USB Controller (ULPI)(0xC56D)"},
{0x1415, 0xC56E, 0xFFFF, 0xFFFF, "OXPCIe200 GPIO(0xC56E)"},
{0x1415, 0xC56F, 0xFFFF, 0xFFFF, "OXPCIe200 Native 950 UART(0xC56F)"},
{0x1415, 0xC570, 0xFFFF, 0xFFFF, "OXPCIe200 Dual OHCI USB Controller (R-ULPI/analog)(0xC570)"},
{0x1415, 0xC571, 0xFFFF, 0xFFFF, "OXPCIe200 EHCI USB Controller (R-ULPI)(0xC571)"},
{0x1415, 0xC574, 0xFFFF, 0xFFFF, "OXPCIe200 Dual OHCI USB Controller (R-ULPI/analog)(0xC574)"},
{0x1415, 0xC575, 0xFFFF, 0xFFFF, "OXPCIe200 EHCI USB Controller (R-ULPI)(0xC575)"},
{0x1415, 0xC576, 0xFFFF, 0xFFFF, "OXPCIe200 GPIO(0xC576)"},
{0x1415, 0xC578, 0xFFFF, 0xFFFF, "OXPCIe200 Dual OHCI USB Controller (R-ULPI/analog)(0xC578)"},
{0x1415, 0xC579, 0xFFFF, 0xFFFF, "OXPCIe200 EHCI USB Controller (R-ULPI)(0xC579)"},
{0x1415, 0xC57B, 0xFFFF, 0xFFFF, "OXPCIe200 Native 950 UART(0xC57B)"},
{0x1415, 0xC57C, 0xFFFF, 0xFFFF, "OXPCIe200 Dual OHCI USB Controller (R-ULPI/analog)(0xC57C)"},
{0x1415, 0xC57D, 0xFFFF, 0xFFFF, "OXPCIe200 EHCI USB Controller (R-ULPI)(0xC57D)"},
{0x1415, 0xC57E, 0xFFFF, 0xFFFF, "OXPCIe200 GPIO(0xC57E)"},
{0x1415, 0xC57F, 0xFFFF, 0xFFFF, "OXPCIe200 Native 950 UART(0xC57F)"},
{0x1415, 0xC5A0, 0xFFFF, 0xFFFF, "OXPCIe200 OHCI USB Controller (ULPI)(0xC5A0)"},
{0x1415, 0xC5A1, 0xFFFF, 0xFFFF, "OXPCIe200 EHCI USB Controller (ULPI)(0xC5A1)"},
{0x1415, 0xC5A2, 0xFFFF, 0xFFFF, "OXPCIe200 Programmable Memory Interface(0xC5A2)"},
{0x1415, 0xC5A4, 0xFFFF, 0xFFFF, "OXPCIe200 OHCI USB Controller (ULPI)(0xC5A4)"},
{0x1415, 0xC5A5, 0xFFFF, 0xFFFF, "OXPCIe200 EHCI USB Controller (ULPI)(0xC5A5)"},
{0x1415, 0xC5A6, 0xFFFF, 0xFFFF, "OXPCIe200 Programmable Memory Interface & GPIO(0xC5A6)"},
{0x1415, 0xC5A8, 0xFFFF, 0xFFFF, "OXPCIe200 OHCI USB Controller (ULPI)(0xC5A8)"},
{0x1415, 0xC5A9, 0xFFFF, 0xFFFF, "OXPCIe200 EHCI USB Controller (ULPI)(0xC5A9)"},
{0x1415, 0xC5AA, 0xFFFF, 0xFFFF, "OXPCIe200 Programmable Memory Interface(0xC5AA)"},
{0x1415, 0xC5AB, 0xFFFF, 0xFFFF, "OXPCIe200 Native 950 UART(0xC5AB)"},
{0x1415, 0xC5AC, 0xFFFF, 0xFFFF, "OXPCIe200 OHCI USB Controller (ULPI)(0xC5AC)"},
{0x1415, 0xC5AD, 0xFFFF, 0xFFFF, "OXPCIe200 EHCI USB Controller (ULPI)(0xC5AD)"},
{0x1415, 0xC5AE, 0xFFFF, 0xFFFF, "OXPCIe200 Programmable Memory Interface & GPIO(0xC5AE)"},
{0x1415, 0xC5AF, 0xFFFF, 0xFFFF, "OXPCIe200 Native 950 UART(0xC5AF)"},
{0x1415, 0xC5B0, 0xFFFF, 0xFFFF, "OXPCIe200 OHCI USB Controller (R-ULPI)(0xC5B0)"},
{0x1415, 0xC5B1, 0xFFFF, 0xFFFF, "OXPCIe200 EHCI USB Controller (R-ULPI)(0xC5B1)"},
{0x1415, 0xC5B2, 0xFFFF, 0xFFFF, "OXPCIe200 Programmable Memory Interface(0xC5B2)"},
{0x1415, 0xC5B4, 0xFFFF, 0xFFFF, "OXPCIe200 OHCI USB Controller (R-ULPI)(0xC5B4)"},
{0x1415, 0xC5B5, 0xFFFF, 0xFFFF, "OXPCIe200 EHCI USB Controller (R-ULPI)(0xC5B5)"},
{0x1415, 0xC5B6, 0xFFFF, 0xFFFF, "OXPCIe200 Programmable Memory Interface & GPIO(0xC5B6)"},
{0x1415, 0xC5B8, 0xFFFF, 0xFFFF, "OXPCIe200 OHCI USB Controller (R-ULPI)(0xC5B8)"},
{0x1415, 0xC5B9, 0xFFFF, 0xFFFF, "OXPCIe200 EHCI USB Controller (R-ULPI)(0xC5B9)"},
{0x1415, 0xC5BA, 0xFFFF, 0xFFFF, "OXPCIe200 Programmable Memory Interface(0xC5BA)"},
{0x1415, 0xC5BB, 0xFFFF, 0xFFFF, "OXPCIe200 Native 950 UART(0xC5BB)"},
{0x1415, 0xC5BC, 0xFFFF, 0xFFFF, "OXPCIe200 OHCI USB Controller (R-ULPI)(0xC5BC)"},
{0x1415, 0xC5BD, 0xFFFF, 0xFFFF, "OXPCIe200 EHCI USB Controller (R-ULPI)(0xC5BD)"},
{0x1415, 0xC5BE, 0xFFFF, 0xFFFF, "OXPCIe200 Programmable Memory Interface & GPIO(0xC5BE)"},
{0x1415, 0xC5BF, 0xFFFF, 0xFFFF, "OXPCIe200 Native 950 UART(0xC5BF)"},
{0x1415, 0xC5C0, 0xFFFF, 0xFFFF, "OXPCIe200 OHCI USB Controller (analog)(0xC5C0)"},
{0x1415, 0xC5C2, 0xFFFF, 0xFFFF, "OXPCIe200 Programmable Memory Interface(0xC5C2)"},
{0x1415, 0xC5C4, 0xFFFF, 0xFFFF, "OXPCIe200 OHCI USB Controller (analog)(0xC5C4)"},
{0x1415, 0xC5C6, 0xFFFF, 0xFFFF, "OXPCIe200 Programmable Memory Interface & GPIO(0xC5C6)"},
{0x1415, 0xC5C8, 0xFFFF, 0xFFFF, "OXPCIe200 OHCI USB Controller (analog)(0xC5C8)"},
{0x1415, 0xC5CA, 0xFFFF, 0xFFFF, "OXPCIe200 Programmable Memory Interface(0xC5CA)"},
{0x1415, 0xC5CB, 0xFFFF, 0xFFFF, "OXPCIe200 Native 950 UART(0xC5CB)"},
{0x1415, 0xC5CC, 0xFFFF, 0xFFFF, "OXPCIe200 OHCI USB Controller (analog)(0xC5CC)"},
{0x1415, 0xC5CE, 0xFFFF, 0xFFFF, "OXPCIe200 Programmable Memory Interface & GPIO(0xC5CE)"},
{0x1415, 0xC5CF, 0xFFFF, 0xFFFF, "OXPCIe200 Native 950 UART(0xC5CF)"},
}; /* pci_vid_1415[] */

static pci_id_t const pci_vid_1416[] = {
{0x1416, 0xFFFF, 0xFFFF, 0xFFFF, "Multiwave Innovation pte Ltd(0x1416)"},
}; /* pci_vid_1416[] */

static pci_id_t const pci_vid_1417[] = {
{0x1417, 0xFFFF, 0xFFFF, 0xFFFF, "Convergenet Technologies Inc(0x1417)"},
}; /* pci_vid_1417[] */

static pci_id_t const pci_vid_1418[] = {
{0x1418, 0xFFFF, 0xFFFF, 0xFFFF, "Kyushu electronics systems Inc(0x1418)"},
}; /* pci_vid_1418[] */

static pci_id_t const pci_vid_1419[] = {
{0x1419, 0xFFFF, 0xFFFF, 0xFFFF, "Excel Switching Corp(0x1419)"},
}; /* pci_vid_1419[] */

static pci_id_t const pci_vid_141A[] = {
{0x141A, 0xFFFF, 0xFFFF, 0xFFFF, "Apache Micro Peripherals Inc(0x141A)"},
}; /* pci_vid_141A[] */

static pci_id_t const pci_vid_141B[] = {
{0x141B, 0xFFFF, 0xFFFF, 0xFFFF, "Zoom Telephonics Inc(0x141B)"},
}; /* pci_vid_141B[] */

static pci_id_t const pci_vid_141D[] = {
{0x141D, 0xFFFF, 0xFFFF, 0xFFFF, "Digitan Systems Inc(0x141D)"},
}; /* pci_vid_141D[] */

static pci_id_t const pci_vid_141E[] = {
{0x141E, 0xFFFF, 0xFFFF, 0xFFFF, "Fanuc Ltd(0x141E)"},
}; /* pci_vid_141E[] */

static pci_id_t const pci_vid_141F[] = {
{0x141F, 0xFFFF, 0xFFFF, 0xFFFF, "Visiontech Ltd(0x141F)"},
}; /* pci_vid_141F[] */

static pci_id_t const pci_vid_1420[] = {
{0x1420, 0xFFFF, 0xFFFF, 0xFFFF, "Psion Dacom plc(0x1420)"},
{0x1420, 0x8002, 0xFFFF, 0xFFFF, "Gold Card NetGlobal 56k+10/100Mb CardBus (Ethernet part)(0x8002)"},
{0x1420, 0x8003, 0xFFFF, 0xFFFF, "Gold Card NetGlobal 56k+10/100Mb CardBus (Modem part)(0x8003)"},
}; /* pci_vid_1420[] */

static pci_id_t const pci_vid_1421[] = {
{0x1421, 0xFFFF, 0xFFFF, 0xFFFF, "Ads Technologies Inc(0x1421)"},
}; /* pci_vid_1421[] */

static pci_id_t const pci_vid_1422[] = {
{0x1422, 0xFFFF, 0xFFFF, 0xFFFF, "Ygrec Systems Co Ltd(0x1422)"},
}; /* pci_vid_1422[] */

static pci_id_t const pci_vid_1423[] = {
{0x1423, 0xFFFF, 0xFFFF, 0xFFFF, "Custom Technology Corp.(0x1423)"},
}; /* pci_vid_1423[] */

static pci_id_t const pci_vid_1424[] = {
{0x1424, 0xFFFF, 0xFFFF, 0xFFFF, "Videoserver Connections(0x1424)"},
}; /* pci_vid_1424[] */

static pci_id_t const pci_vid_1425[] = {
{0x1425, 0xFFFF, 0xFFFF, 0xFFFF, "Chelsio Communications Inc(0x1425)"},
{0x1425, 0x000B, 0xFFFF, 0xFFFF, "T210 Protocol Engine(0x000B)"},
{0x1425, 0x000C, 0xFFFF, 0xFFFF, "T204 Protocol Engine(0x000C)"},
{0x1425, 0x0022, 0xFFFF, 0xFFFF, "10GbE Ethernet Adapter(0x0022)"},
{0x1425, 0x0030, 0xFFFF, 0xFFFF, "T310 10GbE Single Port Adapter(0x0030)"},
{0x1425, 0x0030, 0x103C, 0x705E, "PCIe 10GBase-SR [AD386A](0x103C-0x705E)"},
{0x1425, 0x0031, 0xFFFF, 0xFFFF, "T320 10GbE Dual Port Adapter(0x0031)"},
{0x1425, 0x0032, 0xFFFF, 0xFFFF, "T302 1GbE Dual Port Adapter(0x0032)"},
{0x1425, 0x0033, 0xFFFF, 0xFFFF, "T304 1GbE Quad Port Adapter(0x0033)"},
{0x1425, 0x0034, 0xFFFF, 0xFFFF, "B320 10GbE Dual Port Adapter(0x0034)"},
{0x1425, 0x0035, 0xFFFF, 0xFFFF, "S310-CR 10GbE Single Port Adapter(0x0035)"},
{0x1425, 0x0036, 0xFFFF, 0xFFFF, "S320-LP-CR 10GbE Dual Port Adapter(0x0036)"},
{0x1425, 0x0037, 0xFFFF, 0xFFFF, "N320-G2-CR 10GbE Dual Port Adapter(0x0037)"},
{0x1425, 0x4001, 0xFFFF, 0xFFFF, "T420-CR Unified Wire Ethernet Controller(0x4001)"},
{0x1425, 0x4002, 0xFFFF, 0xFFFF, "T422-CR Unified Wire Ethernet Controller(0x4002)"},
{0x1425, 0x4003, 0xFFFF, 0xFFFF, "T440-CR Unified Wire Ethernet Controller(0x4003)"},
{0x1425, 0x4004, 0xFFFF, 0xFFFF, "T420-BCH Unified Wire Ethernet Controller(0x4004)"},
{0x1425, 0x4005, 0xFFFF, 0xFFFF, "T440-BCH Unified Wire Ethernet Controller(0x4005)"},
{0x1425, 0x4006, 0xFFFF, 0xFFFF, "T440-CH Unified Wire Ethernet Controller(0x4006)"},
{0x1425, 0x4007, 0xFFFF, 0xFFFF, "T420-SO Unified Wire Ethernet Controller(0x4007)"},
{0x1425, 0x4008, 0xFFFF, 0xFFFF, "T420-CX Unified Wire Ethernet Controller(0x4008)"},
{0x1425, 0x4009, 0xFFFF, 0xFFFF, "T420-BT Unified Wire Ethernet Controller(0x4009)"},
{0x1425, 0x400A, 0xFFFF, 0xFFFF, "T404-BT Unified Wire Ethernet Controller(0x400A)"},
{0x1425, 0x400B, 0xFFFF, 0xFFFF, "B420-SR Unified Wire Ethernet Controller(0x400B)"},
{0x1425, 0x400C, 0xFFFF, 0xFFFF, "B404-BT Unified Wire Ethernet Controller(0x400C)"},
{0x1425, 0x400D, 0xFFFF, 0xFFFF, "T480 Unified Wire Ethernet Controller(0x400D)"},
{0x1425, 0x400E, 0xFFFF, 0xFFFF, "T440-LP-CR Unified Wire Ethernet Controller(0x400E)"},
{0x1425, 0x400F, 0xFFFF, 0xFFFF, "T440 [Amsterdam] Unified Wire Ethernet Controller(0x400F)"},
{0x1425, 0x4080, 0xFFFF, 0xFFFF, "T480-4080 T480 Unified Wire Ethernet Controller(0x4080)"},
{0x1425, 0x4081, 0xFFFF, 0xFFFF, "T440F-4081 T440-FCoE Unified Wire Ethernet Controller(0x4081)"},
{0x1425, 0x4082, 0xFFFF, 0xFFFF, "T420-4082  Unified Wire Ethernet Controller(0x4082)"},
{0x1425, 0x4083, 0xFFFF, 0xFFFF, "T420X-4083 Unified Wire Ethernet Controller(0x4083)"},
{0x1425, 0x4084, 0xFFFF, 0xFFFF, "T440-4084 Unified Wire Ethernet Controller(0x4084)"},
{0x1425, 0x4085, 0xFFFF, 0xFFFF, "T420-4085 SFP+ Unified Wire Ethernet Controller(0x4085)"},
{0x1425, 0x4086, 0xFFFF, 0xFFFF, "T440-4086 10Gbase-T Unified Wire Ethernet Controller(0x4086)"},
{0x1425, 0x4087, 0xFFFF, 0xFFFF, "T440T-4087 Unified Wire Ethernet Controller(0x4087)"},
{0x1425, 0x4088, 0xFFFF, 0xFFFF, "T440-4088 Unified Wire Ethernet Controller(0x4088)"},
{0x1425, 0x4401, 0xFFFF, 0xFFFF, "T420-CR Unified Wire Ethernet Controller(0x4401)"},
{0x1425, 0x4402, 0xFFFF, 0xFFFF, "T422-CR Unified Wire Ethernet Controller(0x4402)"},
{0x1425, 0x4403, 0xFFFF, 0xFFFF, "T440-CR Unified Wire Ethernet Controller(0x4403)"},
{0x1425, 0x4404, 0xFFFF, 0xFFFF, "T420-BCH Unified Wire Ethernet Controller(0x4404)"},
{0x1425, 0x4405, 0xFFFF, 0xFFFF, "T440-BCH Unified Wire Ethernet Controller(0x4405)"},
{0x1425, 0x4406, 0xFFFF, 0xFFFF, "T440-CH Unified Wire Ethernet Controller(0x4406)"},
{0x1425, 0x4407, 0xFFFF, 0xFFFF, "T420-SO Unified Wire Ethernet Controller(0x4407)"},
{0x1425, 0x4408, 0xFFFF, 0xFFFF, "T420-CX Unified Wire Ethernet Controller(0x4408)"},
{0x1425, 0x4409, 0xFFFF, 0xFFFF, "T420-BT Unified Wire Ethernet Controller(0x4409)"},
{0x1425, 0x440A, 0xFFFF, 0xFFFF, "T404-BT Unified Wire Ethernet Controller(0x440A)"},
{0x1425, 0x440B, 0xFFFF, 0xFFFF, "B420-SR Unified Wire Ethernet Controller(0x440B)"},
{0x1425, 0x440C, 0xFFFF, 0xFFFF, "B404-BT Unified Wire Ethernet Controller(0x440C)"},
{0x1425, 0x440D, 0xFFFF, 0xFFFF, "T480 Unified Wire Ethernet Controller(0x440D)"},
{0x1425, 0x440E, 0xFFFF, 0xFFFF, "T440-LP-CR Unified Wire Ethernet Controller(0x440E)"},
{0x1425, 0x440F, 0xFFFF, 0xFFFF, "T440 [Amsterdam] Unified Wire Ethernet Controller(0x440F)"},
{0x1425, 0x4480, 0xFFFF, 0xFFFF, "T480-4080 T480 Unified Wire Ethernet Controller(0x4480)"},
{0x1425, 0x4481, 0xFFFF, 0xFFFF, "T440F-4081 T440-FCoE Unified Wire Ethernet Controller(0x4481)"},
{0x1425, 0x4482, 0xFFFF, 0xFFFF, "T420-4082  Unified Wire Ethernet Controller(0x4482)"},
{0x1425, 0x4483, 0xFFFF, 0xFFFF, "T420X-4083 Unified Wire Ethernet Controller(0x4483)"},
{0x1425, 0x4484, 0xFFFF, 0xFFFF, "T440-4084 Unified Wire Ethernet Controller(0x4484)"},
{0x1425, 0x4485, 0xFFFF, 0xFFFF, "T420-4085 SFP+ Unified Wire Ethernet Controller(0x4485)"},
{0x1425, 0x4486, 0xFFFF, 0xFFFF, "T440-4086 10Gbase-T Unified Wire Ethernet Controller(0x4486)"},
{0x1425, 0x4487, 0xFFFF, 0xFFFF, "T440T-4087 Unified Wire Ethernet Controller(0x4487)"},
{0x1425, 0x4488, 0xFFFF, 0xFFFF, "T440-4088 Unified Wire Ethernet Controller(0x4488)"},
{0x1425, 0x4501, 0xFFFF, 0xFFFF, "T420-CR Unified Wire Storage Controller(0x4501)"},
{0x1425, 0x4502, 0xFFFF, 0xFFFF, "T422-CR Unified Wire Storage Controller(0x4502)"},
{0x1425, 0x4503, 0xFFFF, 0xFFFF, "T440-CR Unified Wire Storage Controller(0x4503)"},
{0x1425, 0x4504, 0xFFFF, 0xFFFF, "T420-BCH Unified Wire Storage Controller(0x4504)"},
{0x1425, 0x4505, 0xFFFF, 0xFFFF, "T440-BCH Unified Wire Storage Controller(0x4505)"},
{0x1425, 0x4506, 0xFFFF, 0xFFFF, "T440-CH Unified Wire Storage Controller(0x4506)"},
{0x1425, 0x4507, 0xFFFF, 0xFFFF, "T420-SO Unified Wire Storage Controller(0x4507)"},
{0x1425, 0x4508, 0xFFFF, 0xFFFF, "T420-CX Unified Wire Storage Controller(0x4508)"},
{0x1425, 0x4509, 0xFFFF, 0xFFFF, "T420-BT Unified Wire Storage Controller(0x4509)"},
{0x1425, 0x450A, 0xFFFF, 0xFFFF, "T404-BT Unified Wire Storage Controller(0x450A)"},
{0x1425, 0x450B, 0xFFFF, 0xFFFF, "B420-SR Unified Wire Storage Controller(0x450B)"},
{0x1425, 0x450C, 0xFFFF, 0xFFFF, "B404-BT Unified Wire Storage Controller(0x450C)"},
{0x1425, 0x450D, 0xFFFF, 0xFFFF, "T480 Unified Wire Storage Controller(0x450D)"},
{0x1425, 0x450E, 0xFFFF, 0xFFFF, "T440-LP-CR Unified Wire Storage Controller(0x450E)"},
{0x1425, 0x450F, 0xFFFF, 0xFFFF, "T440 [Amsterdam] Unified Wire Storage Controller(0x450F)"},
{0x1425, 0x4580, 0xFFFF, 0xFFFF, "T480-4080 T480 Unified Wire Storage Controller(0x4580)"},
{0x1425, 0x4581, 0xFFFF, 0xFFFF, "T440F-4081 T440-FCoE Unified Wire Storage Controller(0x4581)"},
{0x1425, 0x4582, 0xFFFF, 0xFFFF, "T420-4082  Unified Wire Storage Controller(0x4582)"},
{0x1425, 0x4583, 0xFFFF, 0xFFFF, "T420X-4083 Unified Wire Storage Controller(0x4583)"},
{0x1425, 0x4584, 0xFFFF, 0xFFFF, "T440-4084 Unified Wire Storage Controller(0x4584)"},
{0x1425, 0x4585, 0xFFFF, 0xFFFF, "T420-4085 SFP+ Unified Wire Storage Controller(0x4585)"},
{0x1425, 0x4586, 0xFFFF, 0xFFFF, "T440-4086 10Gbase-T Unified Wire Storage Controller(0x4586)"},
{0x1425, 0x4587, 0xFFFF, 0xFFFF, "T440T-4087 Unified Wire Storage Controller(0x4587)"},
{0x1425, 0x4588, 0xFFFF, 0xFFFF, "T440-4088 Unified Wire Storage Controller(0x4588)"},
{0x1425, 0x4601, 0xFFFF, 0xFFFF, "T420-CR Unified Wire Storage Controller(0x4601)"},
{0x1425, 0x4602, 0xFFFF, 0xFFFF, "T422-CR Unified Wire Storage Controller(0x4602)"},
{0x1425, 0x4603, 0xFFFF, 0xFFFF, "T440-CR Unified Wire Storage Controller(0x4603)"},
{0x1425, 0x4604, 0xFFFF, 0xFFFF, "T420-BCH Unified Wire Storage Controller(0x4604)"},
{0x1425, 0x4605, 0xFFFF, 0xFFFF, "T440-BCH Unified Wire Storage Controller(0x4605)"},
{0x1425, 0x4606, 0xFFFF, 0xFFFF, "T440-CH Unified Wire Storage Controller(0x4606)"},
{0x1425, 0x4607, 0xFFFF, 0xFFFF, "T420-SO Unified Wire Storage Controller(0x4607)"},
{0x1425, 0x4608, 0xFFFF, 0xFFFF, "T420-CX Unified Wire Storage Controller(0x4608)"},
{0x1425, 0x4609, 0xFFFF, 0xFFFF, "T420-BT Unified Wire Storage Controller(0x4609)"},
{0x1425, 0x460A, 0xFFFF, 0xFFFF, "T404-BT Unified Wire Storage Controller(0x460A)"},
{0x1425, 0x460B, 0xFFFF, 0xFFFF, "B420-SR Unified Wire Storage Controller(0x460B)"},
{0x1425, 0x460C, 0xFFFF, 0xFFFF, "B404-BT Unified Wire Storage Controller(0x460C)"},
{0x1425, 0x460D, 0xFFFF, 0xFFFF, "T480 Unified Wire Storage Controller(0x460D)"},
{0x1425, 0x460E, 0xFFFF, 0xFFFF, "T440-LP-CR Unified Wire Storage Controller(0x460E)"},
{0x1425, 0x460F, 0xFFFF, 0xFFFF, "T440 [Amsterdam] Unified Wire Storage Controller(0x460F)"},
{0x1425, 0x4680, 0xFFFF, 0xFFFF, "T480-4080 T480 Unified Wire Storage Controller(0x4680)"},
{0x1425, 0x4681, 0xFFFF, 0xFFFF, "T440F-4081 T440-FCoE Unified Wire Storage Controller(0x4681)"},
{0x1425, 0x4682, 0xFFFF, 0xFFFF, "T420-4082  Unified Wire Storage Controller(0x4682)"},
{0x1425, 0x4683, 0xFFFF, 0xFFFF, "T420X-4083 Unified Wire Storage Controller(0x4683)"},
{0x1425, 0x4684, 0xFFFF, 0xFFFF, "T440-4084 Unified Wire Storage Controller(0x4684)"},
{0x1425, 0x4685, 0xFFFF, 0xFFFF, "T420-4085 SFP+ Unified Wire Storage Controller(0x4685)"},
{0x1425, 0x4686, 0xFFFF, 0xFFFF, "T440-4086 10Gbase-T Unified Wire Storage Controller(0x4686)"},
{0x1425, 0x4687, 0xFFFF, 0xFFFF, "T440T-4087 Unified Wire Storage Controller(0x4687)"},
{0x1425, 0x4688, 0xFFFF, 0xFFFF, "T440-4088 Unified Wire Storage Controller(0x4688)"},
{0x1425, 0x4701, 0xFFFF, 0xFFFF, "T420-CR Unified Wire Ethernet Controller(0x4701)"},
{0x1425, 0x4702, 0xFFFF, 0xFFFF, "T422-CR Unified Wire Ethernet Controller(0x4702)"},
{0x1425, 0x4703, 0xFFFF, 0xFFFF, "T440-CR Unified Wire Ethernet Controller(0x4703)"},
{0x1425, 0x4704, 0xFFFF, 0xFFFF, "T420-BCH Unified Wire Ethernet Controller(0x4704)"},
{0x1425, 0x4705, 0xFFFF, 0xFFFF, "T440-BCH Unified Wire Ethernet Controller(0x4705)"},
{0x1425, 0x4706, 0xFFFF, 0xFFFF, "T440-CH Unified Wire Ethernet Controller(0x4706)"},
{0x1425, 0x4707, 0xFFFF, 0xFFFF, "T420-SO Unified Wire Ethernet Controller(0x4707)"},
{0x1425, 0x4708, 0xFFFF, 0xFFFF, "T420-CX Unified Wire Ethernet Controller(0x4708)"},
{0x1425, 0x4709, 0xFFFF, 0xFFFF, "T420-BT Unified Wire Ethernet Controller(0x4709)"},
{0x1425, 0x470A, 0xFFFF, 0xFFFF, "T404-BT Unified Wire Ethernet Controller(0x470A)"},
{0x1425, 0x470B, 0xFFFF, 0xFFFF, "B420-SR Unified Wire Ethernet Controller(0x470B)"},
{0x1425, 0x470C, 0xFFFF, 0xFFFF, "B404-BT Unified Wire Ethernet Controller(0x470C)"},
{0x1425, 0x470D, 0xFFFF, 0xFFFF, "T480 Unified Wire Ethernet Controller(0x470D)"},
{0x1425, 0x470E, 0xFFFF, 0xFFFF, "T440-LP-CR Unified Wire Ethernet Controller(0x470E)"},
{0x1425, 0x470F, 0xFFFF, 0xFFFF, "T440 [Amsterdam] Unified Wire Ethernet Controller(0x470F)"},
{0x1425, 0x4780, 0xFFFF, 0xFFFF, "T480-4080 T480 Unified Wire Ethernet Controller(0x4780)"},
{0x1425, 0x4781, 0xFFFF, 0xFFFF, "T440F-4081 T440-FCoE Unified Wire Ethernet Controller(0x4781)"},
{0x1425, 0x4782, 0xFFFF, 0xFFFF, "T420-4082  Unified Wire Ethernet Controller(0x4782)"},
{0x1425, 0x4783, 0xFFFF, 0xFFFF, "T420X-4083 Unified Wire Ethernet Controller(0x4783)"},
{0x1425, 0x4784, 0xFFFF, 0xFFFF, "T440-4084 Unified Wire Ethernet Controller(0x4784)"},
{0x1425, 0x4785, 0xFFFF, 0xFFFF, "T420-4085 SFP+ Unified Wire Ethernet Controller(0x4785)"},
{0x1425, 0x4786, 0xFFFF, 0xFFFF, "T440-4086 10Gbase-T Unified Wire Ethernet Controller(0x4786)"},
{0x1425, 0x4787, 0xFFFF, 0xFFFF, "T440T-4087 Unified Wire Ethernet Controller(0x4787)"},
{0x1425, 0x4788, 0xFFFF, 0xFFFF, "T440-4088 Unified Wire Ethernet Controller(0x4788)"},
{0x1425, 0x4801, 0xFFFF, 0xFFFF, "T420-CR Unified Wire Ethernet Controller [VF](0x4801)"},
{0x1425, 0x4802, 0xFFFF, 0xFFFF, "T422-CR Unified Wire Ethernet Controller [VF](0x4802)"},
{0x1425, 0x4803, 0xFFFF, 0xFFFF, "T440-CR Unified Wire Ethernet Controller [VF](0x4803)"},
{0x1425, 0x4804, 0xFFFF, 0xFFFF, "T420-BCH Unified Wire Ethernet Controller [VF](0x4804)"},
{0x1425, 0x4805, 0xFFFF, 0xFFFF, "T440-BCH Unified Wire Ethernet Controller [VF](0x4805)"},
{0x1425, 0x4806, 0xFFFF, 0xFFFF, "T440-CH Unified Wire Ethernet Controller [VF](0x4806)"},
{0x1425, 0x4807, 0xFFFF, 0xFFFF, "T420-SO Unified Wire Ethernet Controller [VF](0x4807)"},
{0x1425, 0x4808, 0xFFFF, 0xFFFF, "T420-CX Unified Wire Ethernet Controller [VF](0x4808)"},
{0x1425, 0x4809, 0xFFFF, 0xFFFF, "T420-BT Unified Wire Ethernet Controller [VF](0x4809)"},
{0x1425, 0x480A, 0xFFFF, 0xFFFF, "T404-BT Unified Wire Ethernet Controller [VF](0x480A)"},
{0x1425, 0x480B, 0xFFFF, 0xFFFF, "B420-SR Unified Wire Ethernet Controller [VF](0x480B)"},
{0x1425, 0x480C, 0xFFFF, 0xFFFF, "B404-BT Unified Wire Ethernet Controller [VF](0x480C)"},
{0x1425, 0x480D, 0xFFFF, 0xFFFF, "T480 Unified Wire Ethernet Controller [VF](0x480D)"},
{0x1425, 0x480E, 0xFFFF, 0xFFFF, "T440-LP-CR Unified Wire Ethernet Controller [VF](0x480E)"},
{0x1425, 0x480F, 0xFFFF, 0xFFFF, "T440 [Amsterdam] Unified Wire Ethernet Controller [VF](0x480F)"},
{0x1425, 0x4880, 0xFFFF, 0xFFFF, "T480-4080 T480 Unified Wire Ethernet Controller [VF](0x4880)"},
{0x1425, 0x4881, 0xFFFF, 0xFFFF, "T440F-4081 T440-FCoE Unified Wire Ethernet Controller [VF](0x4881)"},
{0x1425, 0x4882, 0xFFFF, 0xFFFF, "T420-4082 Unified Wire Ethernet Controller [VF](0x4882)"},
{0x1425, 0x4883, 0xFFFF, 0xFFFF, "T420X-4083 Unified Wire Ethernet Controller [VF](0x4883)"},
{0x1425, 0x4884, 0xFFFF, 0xFFFF, "T440-4084 Unified Wire Ethernet Controller [VF](0x4884)"},
{0x1425, 0x4885, 0xFFFF, 0xFFFF, "T420-4085 SFP+ Unified Wire Ethernet Controller [VF](0x4885)"},
{0x1425, 0x4886, 0xFFFF, 0xFFFF, "T440-4086 10Gbase-T Unified Wire Ethernet Controller [VF](0x4886)"},
{0x1425, 0x4887, 0xFFFF, 0xFFFF, "T440T-4087 Unified Wire Ethernet Controller [VF](0x4887)"},
{0x1425, 0x4888, 0xFFFF, 0xFFFF, "T440-4088 Unified Wire Ethernet Controller [VF](0x4888)"},
{0x1425, 0x5001, 0xFFFF, 0xFFFF, "T520-CR Unified Wire Ethernet Controller(0x5001)"},
{0x1425, 0x5001, 0x193D, 0x1001, "510F-B(0x193D-0x1001)"},
{0x1425, 0x5002, 0xFFFF, 0xFFFF, "T522-CR Unified Wire Ethernet Controller(0x5002)"},
{0x1425, 0x5003, 0xFFFF, 0xFFFF, "T540-CR Unified Wire Ethernet Controller(0x5003)"},
{0x1425, 0x5004, 0xFFFF, 0xFFFF, "T520-BCH Unified Wire Ethernet Controller(0x5004)"},
{0x1425, 0x5005, 0xFFFF, 0xFFFF, "T540-BCH Unified Wire Ethernet Controller(0x5005)"},
{0x1425, 0x5006, 0xFFFF, 0xFFFF, "T540-CH Unified Wire Ethernet Controller(0x5006)"},
{0x1425, 0x5007, 0xFFFF, 0xFFFF, "T520-SO Unified Wire Ethernet Controller(0x5007)"},
{0x1425, 0x5008, 0xFFFF, 0xFFFF, "T520-CX Unified Wire Ethernet Controller(0x5008)"},
{0x1425, 0x5009, 0xFFFF, 0xFFFF, "T520-BT Unified Wire Ethernet Controller(0x5009)"},
{0x1425, 0x500A, 0xFFFF, 0xFFFF, "T504-BT Unified Wire Ethernet Controller(0x500A)"},
{0x1425, 0x500B, 0xFFFF, 0xFFFF, "B520-SR Unified Wire Ethernet Controller(0x500B)"},
{0x1425, 0x500C, 0xFFFF, 0xFFFF, "B504-BT Unified Wire Ethernet Controller(0x500C)"},
{0x1425, 0x500D, 0xFFFF, 0xFFFF, "T580-CR Unified Wire Ethernet Controller(0x500D)"},
{0x1425, 0x500E, 0xFFFF, 0xFFFF, "T540-LP-CR Unified Wire Ethernet Controller(0x500E)"},
{0x1425, 0x500F, 0xFFFF, 0xFFFF, "T540 [Amsterdam] Unified Wire Ethernet Controller(0x500F)"},
{0x1425, 0x5010, 0xFFFF, 0xFFFF, "T580-LP-CR Unified Wire Ethernet Controller(0x5010)"},
{0x1425, 0x5011, 0xFFFF, 0xFFFF, "T520-LL-CR Unified Wire Ethernet Controller(0x5011)"},
{0x1425, 0x5012, 0xFFFF, 0xFFFF, "T560-CR Unified Wire Ethernet Controller(0x5012)"},
{0x1425, 0x5013, 0xFFFF, 0xFFFF, "T580-CHR Unified Wire Ethernet Controller(0x5013)"},
{0x1425, 0x5014, 0xFFFF, 0xFFFF, "T580-SO-CR Unified Wire Ethernet Controller(0x5014)"},
{0x1425, 0x5015, 0xFFFF, 0xFFFF, "T502-BT Unified Wire Ethernet Controller(0x5015)"},
{0x1425, 0x5016, 0xFFFF, 0xFFFF, "T580-OCP-SO Unified Wire Ethernet Controller(0x5016)"},
{0x1425, 0x5017, 0xFFFF, 0xFFFF, "T520-OCP-SO Unified Wire Ethernet Controller(0x5017)"},
{0x1425, 0x5018, 0xFFFF, 0xFFFF, "T540-BT Unified Wire Ethernet Controller(0x5018)"},
{0x1425, 0x5019, 0xFFFF, 0xFFFF, "T540-LP-BT Unified Wire Ethernet Controller(0x5019)"},
{0x1425, 0x501A, 0xFFFF, 0xFFFF, "T540-SO-BT Unified Wire Ethernet Controller(0x501A)"},
{0x1425, 0x501B, 0xFFFF, 0xFFFF, "T540-SO-CR Unified Wire Ethernet Controller(0x501B)"},
{0x1425, 0x5080, 0xFFFF, 0xFFFF, "T540-5080 Unified Wire Ethernet Controller(0x5080)"},
{0x1425, 0x5081, 0xFFFF, 0xFFFF, "T540-5081 Unified Wire Ethernet Controller(0x5081)"},
{0x1425, 0x5082, 0xFFFF, 0xFFFF, "T504-5082 Unified Wire Ethernet Controller(0x5082)"},
{0x1425, 0x5083, 0xFFFF, 0xFFFF, "T540-5083 Unified Wire Ethernet Controller(0x5083)"},
{0x1425, 0x5084, 0xFFFF, 0xFFFF, "T540-5084 Unified Wire Ethernet Controller(0x5084)"},
{0x1425, 0x5085, 0xFFFF, 0xFFFF, "T580-5085 Unified Wire Ethernet Controller(0x5085)"},
{0x1425, 0x5086, 0xFFFF, 0xFFFF, "T580-5086 Unified Wire Ethernet Controller(0x5086)"},
{0x1425, 0x5087, 0xFFFF, 0xFFFF, "T580-5087 Unified Wire Ethernet Controller(0x5087)"},
{0x1425, 0x5088, 0xFFFF, 0xFFFF, "T570-5088 Unified Wire Ethernet Controller(0x5088)"},
{0x1425, 0x5089, 0xFFFF, 0xFFFF, "T520-5089 Unified Wire Ethernet Controller(0x5089)"},
{0x1425, 0x5090, 0xFFFF, 0xFFFF, "T540-5090 Unified Wire Ethernet Controller(0x5090)"},
{0x1425, 0x5091, 0xFFFF, 0xFFFF, "T522-5091 Unified Wire Ethernet Controller(0x5091)"},
{0x1425, 0x5092, 0xFFFF, 0xFFFF, "T520-5092 Unified Wire Ethernet Controller(0x5092)"},
{0x1425, 0x5093, 0xFFFF, 0xFFFF, "T580-5093 Unified Wire Ethernet Controller(0x5093)"},
{0x1425, 0x5094, 0xFFFF, 0xFFFF, "T540-5094 Unified Wire Ethernet Controller(0x5094)"},
{0x1425, 0x5095, 0xFFFF, 0xFFFF, "T540-5095 Unified Wire Ethernet Controller(0x5095)"},
{0x1425, 0x5096, 0xFFFF, 0xFFFF, "T580-5096 Unified Wire Ethernet Controller(0x5096)"},
{0x1425, 0x5097, 0xFFFF, 0xFFFF, "T520-5097 Unified Wire Ethernet Controller(0x5097)"},
{0x1425, 0x5098, 0xFFFF, 0xFFFF, "T580-5098 Unified Wire Ethernet Controller(0x5098)"},
{0x1425, 0x5099, 0xFFFF, 0xFFFF, "T580-5099 Unified Wire Ethernet Controller(0x5099)"},
{0x1425, 0x509A, 0xFFFF, 0xFFFF, "T520-509A Unified Wire Ethernet Controller(0x509A)"},
{0x1425, 0x509B, 0xFFFF, 0xFFFF, "T540-509B Unified Wire Ethernet Controller(0x509B)"},
{0x1425, 0x509C, 0xFFFF, 0xFFFF, "T520-509C Unified Wire Ethernet Controller(0x509C)"},
{0x1425, 0x509D, 0xFFFF, 0xFFFF, "T540-509D Unified Wire Ethernet Controller(0x509D)"},
{0x1425, 0x509E, 0xFFFF, 0xFFFF, "T520-509E Unified Wire Ethernet Controller(0x509E)"},
{0x1425, 0x509F, 0xFFFF, 0xFFFF, "T540-509F Unified Wire Ethernet Controller(0x509F)"},
{0x1425, 0x50A0, 0xFFFF, 0xFFFF, "T540-50A0 Unified Wire Ethernet Controller(0x50A0)"},
{0x1425, 0x50A1, 0xFFFF, 0xFFFF, "T540-50A1 Unified Wire Ethernet Controller(0x50A1)"},
{0x1425, 0x50A2, 0xFFFF, 0xFFFF, "T580-50A2 Unified Wire Ethernet Controller(0x50A2)"},
{0x1425, 0x50A3, 0xFFFF, 0xFFFF, "T580-50A3 Unified Wire Ethernet Controller(0x50A3)"},
{0x1425, 0x50A4, 0xFFFF, 0xFFFF, "T540-50A4 Unified Wire Ethernet Controller(0x50A4)"},
{0x1425, 0x50A5, 0xFFFF, 0xFFFF, "T522-50A5 Unified Wire Ethernet Controller(0x50A5)"},
{0x1425, 0x50A6, 0xFFFF, 0xFFFF, "T522-50A6 Unified Wire Ethernet Controller(0x50A6)"},
{0x1425, 0x50A7, 0xFFFF, 0xFFFF, "T580-50A7 Unified Wire Ethernet Controller(0x50A7)"},
{0x1425, 0x50A8, 0xFFFF, 0xFFFF, "T580-50A8 Unified Wire Ethernet Controller(0x50A8)"},
{0x1425, 0x50A9, 0xFFFF, 0xFFFF, "T580-50A9 Unified Wire Ethernet Controller(0x50A9)"},
{0x1425, 0x50AA, 0xFFFF, 0xFFFF, "T580-50AA Unified Wire Ethernet Controller(0x50AA)"},
{0x1425, 0x50AB, 0xFFFF, 0xFFFF, "T520-50AB Unified Wire Ethernet Controller(0x50AB)"},
{0x1425, 0x50AC, 0xFFFF, 0xFFFF, "T540-50AC Unified Wire Ethernet Controller(0x50AC)"},
{0x1425, 0x50AD, 0xFFFF, 0xFFFF, "T520-50AD Unified Wire Ethernet Controller(0x50AD)"},
{0x1425, 0x50AE, 0xFFFF, 0xFFFF, "T540-50AE Unified Wire Ethernet Controller(0x50AE)"},
{0x1425, 0x50AF, 0xFFFF, 0xFFFF, "T580-50AF Unified Wire Ethernet Controller(0x50AF)"},
{0x1425, 0x50B0, 0xFFFF, 0xFFFF, "T520-50B0 Unified Wire Ethernet Controller(0x50B0)"},
{0x1425, 0x5401, 0xFFFF, 0xFFFF, "T520-CR Unified Wire Ethernet Controller(0x5401)"},
{0x1425, 0x5402, 0xFFFF, 0xFFFF, "T522-CR Unified Wire Ethernet Controller(0x5402)"},
{0x1425, 0x5403, 0xFFFF, 0xFFFF, "T540-CR Unified Wire Ethernet Controller(0x5403)"},
{0x1425, 0x5404, 0xFFFF, 0xFFFF, "T520-BCH Unified Wire Ethernet Controller(0x5404)"},
{0x1425, 0x5405, 0xFFFF, 0xFFFF, "T540-BCH Unified Wire Ethernet Controller(0x5405)"},
{0x1425, 0x5406, 0xFFFF, 0xFFFF, "T540-CH Unified Wire Ethernet Controller(0x5406)"},
{0x1425, 0x5407, 0xFFFF, 0xFFFF, "T520-SO Unified Wire Ethernet Controller(0x5407)"},
{0x1425, 0x5408, 0xFFFF, 0xFFFF, "T520-CX Unified Wire Ethernet Controller(0x5408)"},
{0x1425, 0x5409, 0xFFFF, 0xFFFF, "T520-BT Unified Wire Ethernet Controller(0x5409)"},
{0x1425, 0x540A, 0xFFFF, 0xFFFF, "T504-BT Unified Wire Ethernet Controller(0x540A)"},
{0x1425, 0x540B, 0xFFFF, 0xFFFF, "B520-SR Unified Wire Ethernet Controller(0x540B)"},
{0x1425, 0x540C, 0xFFFF, 0xFFFF, "B504-BT Unified Wire Ethernet Controller(0x540C)"},
{0x1425, 0x540D, 0xFFFF, 0xFFFF, "T580-CR Unified Wire Ethernet Controller(0x540D)"},
{0x1425, 0x540E, 0xFFFF, 0xFFFF, "T540-LP-CR Unified Wire Ethernet Controller(0x540E)"},
{0x1425, 0x540F, 0xFFFF, 0xFFFF, "T540 [Amsterdam] Unified Wire Ethernet Controller(0x540F)"},
{0x1425, 0x5410, 0xFFFF, 0xFFFF, "T580-LP-CR Unified Wire Ethernet Controller(0x5410)"},
{0x1425, 0x5411, 0xFFFF, 0xFFFF, "T520-LL-CR Unified Wire Ethernet Controller(0x5411)"},
{0x1425, 0x5412, 0xFFFF, 0xFFFF, "T560-CR Unified Wire Ethernet Controller(0x5412)"},
{0x1425, 0x5413, 0xFFFF, 0xFFFF, "T580-CHR Unified Wire Ethernet Controller(0x5413)"},
{0x1425, 0x5414, 0xFFFF, 0xFFFF, "T580-SO-CR Unified Wire Ethernet Controller(0x5414)"},
{0x1425, 0x5415, 0xFFFF, 0xFFFF, "T502-BT Unified Wire Ethernet Controller(0x5415)"},
{0x1425, 0x5416, 0xFFFF, 0xFFFF, "T580-OCP-SO Unified Wire Ethernet Controller(0x5416)"},
{0x1425, 0x5417, 0xFFFF, 0xFFFF, "T520-OCP-SO Unified Wire Ethernet Controller(0x5417)"},
{0x1425, 0x5418, 0xFFFF, 0xFFFF, "T540-BT Unified Wire Ethernet Controller(0x5418)"},
{0x1425, 0x5419, 0xFFFF, 0xFFFF, "T540-LP-BT Unified Wire Ethernet Controller(0x5419)"},
{0x1425, 0x541A, 0xFFFF, 0xFFFF, "T540-SO-BT Unified Wire Ethernet Controller(0x541A)"},
{0x1425, 0x541B, 0xFFFF, 0xFFFF, "T540-SO-CR Unified Wire Ethernet Controller(0x541B)"},
{0x1425, 0x5480, 0xFFFF, 0xFFFF, "T540-5080 Unified Wire Ethernet Controller(0x5480)"},
{0x1425, 0x5481, 0xFFFF, 0xFFFF, "T540-5081 Unified Wire Ethernet Controller(0x5481)"},
{0x1425, 0x5482, 0xFFFF, 0xFFFF, "T504-5082 Unified Wire Ethernet Controller(0x5482)"},
{0x1425, 0x5483, 0xFFFF, 0xFFFF, "T540-5083 Unified Wire Ethernet Controller(0x5483)"},
{0x1425, 0x5484, 0xFFFF, 0xFFFF, "T540-5084 Unified Wire Ethernet Controller(0x5484)"},
{0x1425, 0x5485, 0xFFFF, 0xFFFF, "T580-5085 Unified Wire Ethernet Controller(0x5485)"},
{0x1425, 0x5486, 0xFFFF, 0xFFFF, "T580-5086 Unified Wire Ethernet Controller(0x5486)"},
{0x1425, 0x5487, 0xFFFF, 0xFFFF, "T580-5087 Unified Wire Ethernet Controller(0x5487)"},
{0x1425, 0x5488, 0xFFFF, 0xFFFF, "T570-5088 Unified Wire Ethernet Controller(0x5488)"},
{0x1425, 0x5489, 0xFFFF, 0xFFFF, "T520-5089 Unified Wire Ethernet Controller(0x5489)"},
{0x1425, 0x5490, 0xFFFF, 0xFFFF, "T540-5090 Unified Wire Ethernet Controller(0x5490)"},
{0x1425, 0x5491, 0xFFFF, 0xFFFF, "T522-5091 Unified Wire Ethernet Controller(0x5491)"},
{0x1425, 0x5492, 0xFFFF, 0xFFFF, "T520-5092 Unified Wire Ethernet Controller(0x5492)"},
{0x1425, 0x5493, 0xFFFF, 0xFFFF, "T580-5093 Unified Wire Ethernet Controller(0x5493)"},
{0x1425, 0x5494, 0xFFFF, 0xFFFF, "T540-5094 Unified Wire Ethernet Controller(0x5494)"},
{0x1425, 0x5495, 0xFFFF, 0xFFFF, "T540-5095 Unified Wire Ethernet Controller(0x5495)"},
{0x1425, 0x5496, 0xFFFF, 0xFFFF, "T580-5096 Unified Wire Ethernet Controller(0x5496)"},
{0x1425, 0x5497, 0xFFFF, 0xFFFF, "T520-5097 Unified Wire Ethernet Controller(0x5497)"},
{0x1425, 0x5498, 0xFFFF, 0xFFFF, "T580-5098 Unified Wire Ethernet Controller(0x5498)"},
{0x1425, 0x5499, 0xFFFF, 0xFFFF, "T580-5099 Unified Wire Ethernet Controller(0x5499)"},
{0x1425, 0x549A, 0xFFFF, 0xFFFF, "T520-509A Unified Wire Ethernet Controller(0x549A)"},
{0x1425, 0x549B, 0xFFFF, 0xFFFF, "T540-509B Unified Wire Ethernet Controller(0x549B)"},
{0x1425, 0x549C, 0xFFFF, 0xFFFF, "T520-509C Unified Wire Ethernet Controller(0x549C)"},
{0x1425, 0x549D, 0xFFFF, 0xFFFF, "T540-509D Unified Wire Ethernet Controller(0x549D)"},
{0x1425, 0x549E, 0xFFFF, 0xFFFF, "T520-509E Unified Wire Ethernet Controller(0x549E)"},
{0x1425, 0x549F, 0xFFFF, 0xFFFF, "T540-509F Unified Wire Ethernet Controller(0x549F)"},
{0x1425, 0x54A0, 0xFFFF, 0xFFFF, "T540-50A0 Unified Wire Ethernet Controller(0x54A0)"},
{0x1425, 0x54A1, 0xFFFF, 0xFFFF, "T540-50A1 Unified Wire Ethernet Controller(0x54A1)"},
{0x1425, 0x54A2, 0xFFFF, 0xFFFF, "T580-50A2 Unified Wire Ethernet Controller(0x54A2)"},
{0x1425, 0x54A3, 0xFFFF, 0xFFFF, "T580-50A3 Unified Wire Ethernet Controller(0x54A3)"},
{0x1425, 0x54A4, 0xFFFF, 0xFFFF, "T540-50A4 Unified Wire Ethernet Controller(0x54A4)"},
{0x1425, 0x54A5, 0xFFFF, 0xFFFF, "T522-50A5 Unified Wire Ethernet Controller(0x54A5)"},
{0x1425, 0x54A6, 0xFFFF, 0xFFFF, "T522-50A6 Unified Wire Ethernet Controller(0x54A6)"},
{0x1425, 0x54A7, 0xFFFF, 0xFFFF, "T580-50A7 Unified Wire Ethernet Controller(0x54A7)"},
{0x1425, 0x54A8, 0xFFFF, 0xFFFF, "T580-50A8 Unified Wire Ethernet Controller(0x54A8)"},
{0x1425, 0x54A9, 0xFFFF, 0xFFFF, "T580-50A9 Unified Wire Ethernet Controller(0x54A9)"},
{0x1425, 0x54AA, 0xFFFF, 0xFFFF, "T580-50AA Unified Wire Ethernet Controller(0x54AA)"},
{0x1425, 0x54AB, 0xFFFF, 0xFFFF, "T520-50AB Unified Wire Ethernet Controller(0x54AB)"},
{0x1425, 0x54AC, 0xFFFF, 0xFFFF, "T540-50AC Unified Wire Ethernet Controller(0x54AC)"},
{0x1425, 0x54AD, 0xFFFF, 0xFFFF, "T520-50AD Unified Wire Ethernet Controller(0x54AD)"},
{0x1425, 0x54AE, 0xFFFF, 0xFFFF, "T540-50AE Unified Wire Ethernet Controller(0x54AE)"},
{0x1425, 0x54AF, 0xFFFF, 0xFFFF, "T580-50AF Unified Wire Ethernet Controller(0x54AF)"},
{0x1425, 0x54B0, 0xFFFF, 0xFFFF, "T520-50B0 Unified Wire Ethernet Controller(0x54B0)"},
{0x1425, 0x5501, 0xFFFF, 0xFFFF, "T520-CR Unified Wire Storage Controller(0x5501)"},
{0x1425, 0x5502, 0xFFFF, 0xFFFF, "T522-CR Unified Wire Storage Controller(0x5502)"},
{0x1425, 0x5503, 0xFFFF, 0xFFFF, "T540-CR Unified Wire Storage Controller(0x5503)"},
{0x1425, 0x5504, 0xFFFF, 0xFFFF, "T520-BCH Unified Wire Storage Controller(0x5504)"},
{0x1425, 0x5505, 0xFFFF, 0xFFFF, "T540-BCH Unified Wire Storage Controller(0x5505)"},
{0x1425, 0x5506, 0xFFFF, 0xFFFF, "T540-CH Unified Wire Storage Controller(0x5506)"},
{0x1425, 0x5507, 0xFFFF, 0xFFFF, "T520-SO Unified Wire Storage Controller(0x5507)"},
{0x1425, 0x5508, 0xFFFF, 0xFFFF, "T520-CX Unified Wire Storage Controller(0x5508)"},
{0x1425, 0x5509, 0xFFFF, 0xFFFF, "T520-BT Unified Wire Storage Controller(0x5509)"},
{0x1425, 0x550A, 0xFFFF, 0xFFFF, "T504-BT Unified Wire Storage Controller(0x550A)"},
{0x1425, 0x550B, 0xFFFF, 0xFFFF, "B520-SR Unified Wire Storage Controller(0x550B)"},
{0x1425, 0x550C, 0xFFFF, 0xFFFF, "B504-BT Unified Wire Storage Controller(0x550C)"},
{0x1425, 0x550D, 0xFFFF, 0xFFFF, "T580-CR Unified Wire Storage Controller(0x550D)"},
{0x1425, 0x550E, 0xFFFF, 0xFFFF, "T540-LP-CR Unified Wire Storage Controller(0x550E)"},
{0x1425, 0x550F, 0xFFFF, 0xFFFF, "T540 [Amsterdam] Unified Wire Storage Controller(0x550F)"},
{0x1425, 0x5510, 0xFFFF, 0xFFFF, "T580-LP-CR Unified Wire Storage Controller(0x5510)"},
{0x1425, 0x5511, 0xFFFF, 0xFFFF, "T520-LL-CR Unified Wire Storage Controller(0x5511)"},
{0x1425, 0x5512, 0xFFFF, 0xFFFF, "T560-CR Unified Wire Storage Controller(0x5512)"},
{0x1425, 0x5513, 0xFFFF, 0xFFFF, "T580-CHR Unified Wire Storage Controller(0x5513)"},
{0x1425, 0x5514, 0xFFFF, 0xFFFF, "T580-SO-CR Unified Wire Storage Controller(0x5514)"},
{0x1425, 0x5515, 0xFFFF, 0xFFFF, "T502-BT Unified Wire Storage Controller(0x5515)"},
{0x1425, 0x5516, 0xFFFF, 0xFFFF, "T580-OCP-SO Unified Wire Storage Controller(0x5516)"},
{0x1425, 0x5517, 0xFFFF, 0xFFFF, "T520-OCP-SO Unified Wire Storage Controller(0x5517)"},
{0x1425, 0x5518, 0xFFFF, 0xFFFF, "T540-BT Unified Wire Storage Controller(0x5518)"},
{0x1425, 0x5519, 0xFFFF, 0xFFFF, "T540-LP-BT Unified Wire Storage Controller(0x5519)"},
{0x1425, 0x551A, 0xFFFF, 0xFFFF, "T540-SO-BT Unified Wire Storage Controller(0x551A)"},
{0x1425, 0x551B, 0xFFFF, 0xFFFF, "T540-SO-CR Unified Wire Storage Controller(0x551B)"},
{0x1425, 0x5580, 0xFFFF, 0xFFFF, "T540-5080 Unified Wire Storage Controller(0x5580)"},
{0x1425, 0x5581, 0xFFFF, 0xFFFF, "T540-5081 Unified Wire Storage Controller(0x5581)"},
{0x1425, 0x5582, 0xFFFF, 0xFFFF, "T504-5082 Unified Wire Storage Controller(0x5582)"},
{0x1425, 0x5583, 0xFFFF, 0xFFFF, "T540-5083 Unified Wire Storage Controller(0x5583)"},
{0x1425, 0x5584, 0xFFFF, 0xFFFF, "T540-5084 Unified Wire Storage Controller(0x5584)"},
{0x1425, 0x5585, 0xFFFF, 0xFFFF, "T580-5085 Unified Wire Storage Controller(0x5585)"},
{0x1425, 0x5586, 0xFFFF, 0xFFFF, "T580-5086 Unified Wire Storage Controller(0x5586)"},
{0x1425, 0x5587, 0xFFFF, 0xFFFF, "T580-5087 Unified Wire Storage Controller(0x5587)"},
{0x1425, 0x5588, 0xFFFF, 0xFFFF, "T570-5088 Unified Wire Storage Controller(0x5588)"},
{0x1425, 0x5589, 0xFFFF, 0xFFFF, "T520-5089 Unified Wire Storage Controller(0x5589)"},
{0x1425, 0x5590, 0xFFFF, 0xFFFF, "T540-5090 Unified Wire Storage Controller(0x5590)"},
{0x1425, 0x5591, 0xFFFF, 0xFFFF, "T522-5091 Unified Wire Storage Controller(0x5591)"},
{0x1425, 0x5592, 0xFFFF, 0xFFFF, "T520-5092 Unified Wire Storage Controller(0x5592)"},
{0x1425, 0x5593, 0xFFFF, 0xFFFF, "T580-5093 Unified Wire Storage Controller(0x5593)"},
{0x1425, 0x5594, 0xFFFF, 0xFFFF, "T540-5094 Unified Wire Storage Controller(0x5594)"},
{0x1425, 0x5595, 0xFFFF, 0xFFFF, "T540-5095 Unified Wire Storage Controller(0x5595)"},
{0x1425, 0x5596, 0xFFFF, 0xFFFF, "T580-5096 Unified Wire Storage Controller(0x5596)"},
{0x1425, 0x5597, 0xFFFF, 0xFFFF, "T520-5097 Unified Wire Storage Controller(0x5597)"},
{0x1425, 0x5598, 0xFFFF, 0xFFFF, "T580-5098 Unified Wire Storage Controller(0x5598)"},
{0x1425, 0x5599, 0xFFFF, 0xFFFF, "T580-5099 Unified Wire Storage Controller(0x5599)"},
{0x1425, 0x559A, 0xFFFF, 0xFFFF, "T520-509A Unified Wire Storage Controller(0x559A)"},
{0x1425, 0x559B, 0xFFFF, 0xFFFF, "T540-509B Unified Wire Storage Controller(0x559B)"},
{0x1425, 0x559C, 0xFFFF, 0xFFFF, "T520-509C Unified Wire Storage Controller(0x559C)"},
{0x1425, 0x559D, 0xFFFF, 0xFFFF, "T540-509D Unified Wire Storage Controller(0x559D)"},
{0x1425, 0x559E, 0xFFFF, 0xFFFF, "T520-509E Unified Wire Storage Controller(0x559E)"},
{0x1425, 0x559F, 0xFFFF, 0xFFFF, "T540-509F Unified Wire Storage Controller(0x559F)"},
{0x1425, 0x55A0, 0xFFFF, 0xFFFF, "T540-50A0 Unified Wire Storage Controller(0x55A0)"},
{0x1425, 0x55A1, 0xFFFF, 0xFFFF, "T540-50A1 Unified Wire Storage Controller(0x55A1)"},
{0x1425, 0x55A2, 0xFFFF, 0xFFFF, "T580-50A2 Unified Wire Storage Controller(0x55A2)"},
{0x1425, 0x55A3, 0xFFFF, 0xFFFF, "T580-50A3 Unified Wire Storage Controller(0x55A3)"},
{0x1425, 0x55A4, 0xFFFF, 0xFFFF, "T540-50A4 Unified Wire Storage Controller(0x55A4)"},
{0x1425, 0x55A5, 0xFFFF, 0xFFFF, "T522-50A5 Unified Wire Storage Controller(0x55A5)"},
{0x1425, 0x55A6, 0xFFFF, 0xFFFF, "T522-50A6 Unified Wire Storage Controller(0x55A6)"},
{0x1425, 0x55A7, 0xFFFF, 0xFFFF, "T580-50A7 Unified Wire Storage Controller(0x55A7)"},
{0x1425, 0x55A8, 0xFFFF, 0xFFFF, "T580-50A8 Unified Wire Storage Controller(0x55A8)"},
{0x1425, 0x55A9, 0xFFFF, 0xFFFF, "T580-50A9 Unified Wire Storage Controller(0x55A9)"},
{0x1425, 0x55AA, 0xFFFF, 0xFFFF, "T580-50AA Unified Wire Storage Controller(0x55AA)"},
{0x1425, 0x55AB, 0xFFFF, 0xFFFF, "T520-50AB Unified Wire Storage Controller(0x55AB)"},
{0x1425, 0x55AC, 0xFFFF, 0xFFFF, "T540-50AC Unified Wire Storage Controller(0x55AC)"},
{0x1425, 0x55AD, 0xFFFF, 0xFFFF, "T520-50AD Unified Wire Storage Controller(0x55AD)"},
{0x1425, 0x55AE, 0xFFFF, 0xFFFF, "T540-50AE Unified Wire Storage Controller(0x55AE)"},
{0x1425, 0x55AF, 0xFFFF, 0xFFFF, "T580-50AF Unified Wire Storage Controller(0x55AF)"},
{0x1425, 0x55B0, 0xFFFF, 0xFFFF, "T520-50B0 Unified Wire Storage Controller(0x55B0)"},
{0x1425, 0x5601, 0xFFFF, 0xFFFF, "T520-CR Unified Wire Storage Controller(0x5601)"},
{0x1425, 0x5602, 0xFFFF, 0xFFFF, "T522-CR Unified Wire Storage Controller(0x5602)"},
{0x1425, 0x5603, 0xFFFF, 0xFFFF, "T540-CR Unified Wire Storage Controller(0x5603)"},
{0x1425, 0x5604, 0xFFFF, 0xFFFF, "T520-BCH Unified Wire Storage Controller(0x5604)"},
{0x1425, 0x5605, 0xFFFF, 0xFFFF, "T540-BCH Unified Wire Storage Controller(0x5605)"},
{0x1425, 0x5606, 0xFFFF, 0xFFFF, "T540-CH Unified Wire Storage Controller(0x5606)"},
{0x1425, 0x5607, 0xFFFF, 0xFFFF, "T520-SO Unified Wire Storage Controller(0x5607)"},
{0x1425, 0x5608, 0xFFFF, 0xFFFF, "T520-CX Unified Wire Storage Controller(0x5608)"},
{0x1425, 0x5609, 0xFFFF, 0xFFFF, "T520-BT Unified Wire Storage Controller(0x5609)"},
{0x1425, 0x560A, 0xFFFF, 0xFFFF, "T504-BT Unified Wire Storage Controller(0x560A)"},
{0x1425, 0x560B, 0xFFFF, 0xFFFF, "B520-SR Unified Wire Storage Controller(0x560B)"},
{0x1425, 0x560C, 0xFFFF, 0xFFFF, "B504-BT Unified Wire Storage Controller(0x560C)"},
{0x1425, 0x560D, 0xFFFF, 0xFFFF, "T580-CR Unified Wire Storage Controller(0x560D)"},
{0x1425, 0x560E, 0xFFFF, 0xFFFF, "T540-LP-CR Unified Wire Storage Controller(0x560E)"},
{0x1425, 0x560F, 0xFFFF, 0xFFFF, "T540 [Amsterdam] Unified Wire Storage Controller(0x560F)"},
{0x1425, 0x5610, 0xFFFF, 0xFFFF, "T580-LP-CR Unified Wire Storage Controller(0x5610)"},
{0x1425, 0x5611, 0xFFFF, 0xFFFF, "T520-LL-CR Unified Wire Storage Controller(0x5611)"},
{0x1425, 0x5612, 0xFFFF, 0xFFFF, "T560-CR Unified Wire Storage Controller(0x5612)"},
{0x1425, 0x5613, 0xFFFF, 0xFFFF, "T580-CHR Unified Wire Storage Controller(0x5613)"},
{0x1425, 0x5614, 0xFFFF, 0xFFFF, "T580-SO-CR Unified Wire Storage Controller(0x5614)"},
{0x1425, 0x5615, 0xFFFF, 0xFFFF, "T502-BT Unified Wire Storage Controller(0x5615)"},
{0x1425, 0x5616, 0xFFFF, 0xFFFF, "T580-OCP-SO Unified Wire Storage Controller(0x5616)"},
{0x1425, 0x5617, 0xFFFF, 0xFFFF, "T520-OCP-SO Unified Wire Storage Controller(0x5617)"},
{0x1425, 0x5618, 0xFFFF, 0xFFFF, "T540-BT Unified Wire Storage Controller(0x5618)"},
{0x1425, 0x5619, 0xFFFF, 0xFFFF, "T540-LP-BT Unified Wire Storage Controller(0x5619)"},
{0x1425, 0x561A, 0xFFFF, 0xFFFF, "T540-SO-BT Unified Wire Storage Controller(0x561A)"},
{0x1425, 0x561B, 0xFFFF, 0xFFFF, "T540-SO-CR Unified Wire Storage Controller(0x561B)"},
{0x1425, 0x5680, 0xFFFF, 0xFFFF, "T540-5080 Unified Wire Storage Controller(0x5680)"},
{0x1425, 0x5681, 0xFFFF, 0xFFFF, "T540-5081 Unified Wire Storage Controller(0x5681)"},
{0x1425, 0x5682, 0xFFFF, 0xFFFF, "T504-5082 Unified Wire Storage Controller(0x5682)"},
{0x1425, 0x5683, 0xFFFF, 0xFFFF, "T540-5083 Unified Wire Storage Controller(0x5683)"},
{0x1425, 0x5684, 0xFFFF, 0xFFFF, "T540-5084 Unified Wire Storage Controller(0x5684)"},
{0x1425, 0x5685, 0xFFFF, 0xFFFF, "T580-5085 Unified Wire Storage Controller(0x5685)"},
{0x1425, 0x5686, 0xFFFF, 0xFFFF, "T580-5086 Unified Wire Storage Controller(0x5686)"},
{0x1425, 0x5687, 0xFFFF, 0xFFFF, "T580-5087 Unified Wire Storage Controller(0x5687)"},
{0x1425, 0x5688, 0xFFFF, 0xFFFF, "T570-5088 Unified Wire Storage Controller(0x5688)"},
{0x1425, 0x5689, 0xFFFF, 0xFFFF, "T520-5089 Unified Wire Storage Controller(0x5689)"},
{0x1425, 0x5690, 0xFFFF, 0xFFFF, "T540-5090 Unified Wire Storage Controller(0x5690)"},
{0x1425, 0x5691, 0xFFFF, 0xFFFF, "T522-5091 Unified Wire Storage Controller(0x5691)"},
{0x1425, 0x5692, 0xFFFF, 0xFFFF, "T520-5092 Unified Wire Storage Controller(0x5692)"},
{0x1425, 0x5693, 0xFFFF, 0xFFFF, "T580-5093 Unified Wire Storage Controller(0x5693)"},
{0x1425, 0x5694, 0xFFFF, 0xFFFF, "T540-5094 Unified Wire Storage Controller(0x5694)"},
{0x1425, 0x5695, 0xFFFF, 0xFFFF, "T540-5095 Unified Wire Storage Controller(0x5695)"},
{0x1425, 0x5696, 0xFFFF, 0xFFFF, "T580-5096 Unified Wire Storage Controller(0x5696)"},
{0x1425, 0x5697, 0xFFFF, 0xFFFF, "T520-5097 Unified Wire Storage Controller(0x5697)"},
{0x1425, 0x5698, 0xFFFF, 0xFFFF, "T580-5098 Unified Wire Storage Controller(0x5698)"},
{0x1425, 0x5699, 0xFFFF, 0xFFFF, "T580-5099 Unified Wire Storage Controller(0x5699)"},
{0x1425, 0x569A, 0xFFFF, 0xFFFF, "T520-509A Unified Wire Storage Controller(0x569A)"},
{0x1425, 0x569B, 0xFFFF, 0xFFFF, "T540-509B Unified Wire Storage Controller(0x569B)"},
{0x1425, 0x569C, 0xFFFF, 0xFFFF, "T520-509C Unified Wire Storage Controller(0x569C)"},
{0x1425, 0x569D, 0xFFFF, 0xFFFF, "T540-509D Unified Wire Storage Controller(0x569D)"},
{0x1425, 0x569E, 0xFFFF, 0xFFFF, "T520-509E Unified Wire Storage Controller(0x569E)"},
{0x1425, 0x569F, 0xFFFF, 0xFFFF, "T540-509F Unified Wire Storage Controller(0x569F)"},
{0x1425, 0x56A0, 0xFFFF, 0xFFFF, "T540-50A0 Unified Wire Storage Controller(0x56A0)"},
{0x1425, 0x56A1, 0xFFFF, 0xFFFF, "T540-50A1 Unified Wire Storage Controller(0x56A1)"},
{0x1425, 0x56A2, 0xFFFF, 0xFFFF, "T580-50A2 Unified Wire Storage Controller(0x56A2)"},
{0x1425, 0x56A3, 0xFFFF, 0xFFFF, "T580-50A3 Unified Wire Storage Controller(0x56A3)"},
{0x1425, 0x56A4, 0xFFFF, 0xFFFF, "T540-50A4 Unified Wire Storage Controller(0x56A4)"},
{0x1425, 0x56A5, 0xFFFF, 0xFFFF, "T522-50A5 Unified Wire Storage Controller(0x56A5)"},
{0x1425, 0x56A6, 0xFFFF, 0xFFFF, "T522-50A6 Unified Wire Storage Controller(0x56A6)"},
{0x1425, 0x56A7, 0xFFFF, 0xFFFF, "T580-50A7 Unified Wire Storage Controller(0x56A7)"},
{0x1425, 0x56A8, 0xFFFF, 0xFFFF, "T580-50A8 Unified Wire Storage Controller(0x56A8)"},
{0x1425, 0x56A9, 0xFFFF, 0xFFFF, "T580-50A9 Unified Wire Storage Controller(0x56A9)"},
{0x1425, 0x56AA, 0xFFFF, 0xFFFF, "T580-50AA Unified Wire Storage Controller(0x56AA)"},
{0x1425, 0x56AB, 0xFFFF, 0xFFFF, "T520-50AB Unified Wire Storage Controller(0x56AB)"},
{0x1425, 0x56AC, 0xFFFF, 0xFFFF, "T540-50AC Unified Wire Storage Controller(0x56AC)"},
{0x1425, 0x56AD, 0xFFFF, 0xFFFF, "T520-50AD Unified Wire Storage Controller(0x56AD)"},
{0x1425, 0x56AE, 0xFFFF, 0xFFFF, "T540-50AE Unified Wire Storage Controller(0x56AE)"},
{0x1425, 0x56AF, 0xFFFF, 0xFFFF, "T580-50AF Unified Wire Storage Controller(0x56AF)"},
{0x1425, 0x56B0, 0xFFFF, 0xFFFF, "T520-50B0 Unified Wire Storage Controller(0x56B0)"},
{0x1425, 0x5701, 0xFFFF, 0xFFFF, "T520-CR Unified Wire Ethernet Controller(0x5701)"},
{0x1425, 0x5702, 0xFFFF, 0xFFFF, "T522-CR Unified Wire Ethernet Controller(0x5702)"},
{0x1425, 0x5703, 0xFFFF, 0xFFFF, "T540-CR Unified Wire Ethernet Controller(0x5703)"},
{0x1425, 0x5704, 0xFFFF, 0xFFFF, "T520-BCH Unified Wire Ethernet Controller(0x5704)"},
{0x1425, 0x5705, 0xFFFF, 0xFFFF, "T540-BCH Unified Wire Ethernet Controller(0x5705)"},
{0x1425, 0x5706, 0xFFFF, 0xFFFF, "T540-CH Unified Wire Ethernet Controller(0x5706)"},
{0x1425, 0x5707, 0xFFFF, 0xFFFF, "T520-SO Unified Wire Ethernet Controller(0x5707)"},
{0x1425, 0x5708, 0xFFFF, 0xFFFF, "T520-CX Unified Wire Ethernet Controller(0x5708)"},
{0x1425, 0x5709, 0xFFFF, 0xFFFF, "T520-BT Unified Wire Ethernet Controller(0x5709)"},
{0x1425, 0x570A, 0xFFFF, 0xFFFF, "T504-BT Unified Wire Ethernet Controller(0x570A)"},
{0x1425, 0x570B, 0xFFFF, 0xFFFF, "B520-SR Unified Wire Ethernet Controller(0x570B)"},
{0x1425, 0x570C, 0xFFFF, 0xFFFF, "B504-BT Unified Wire Ethernet Controller(0x570C)"},
{0x1425, 0x570D, 0xFFFF, 0xFFFF, "T580-CR Unified Wire Ethernet Controller(0x570D)"},
{0x1425, 0x570E, 0xFFFF, 0xFFFF, "T540-LP-CR Unified Wire Ethernet Controller(0x570E)"},
{0x1425, 0x570F, 0xFFFF, 0xFFFF, "T540 [Amsterdam] Unified Wire Ethernet Controller(0x570F)"},
{0x1425, 0x5710, 0xFFFF, 0xFFFF, "T580-LP-CR Unified Wire Ethernet Controller(0x5710)"},
{0x1425, 0x5711, 0xFFFF, 0xFFFF, "T520-LL-CR Unified Wire Ethernet Controller(0x5711)"},
{0x1425, 0x5712, 0xFFFF, 0xFFFF, "T560-CR Unified Wire Ethernet Controller(0x5712)"},
{0x1425, 0x5713, 0xFFFF, 0xFFFF, "T580-CR Unified Wire Ethernet Controller(0x5713)"},
{0x1425, 0x5714, 0xFFFF, 0xFFFF, "T580-SO-CR Unified Wire Ethernet Controller(0x5714)"},
{0x1425, 0x5715, 0xFFFF, 0xFFFF, "T502-BT Unified Wire Ethernet Controller(0x5715)"},
{0x1425, 0x5780, 0xFFFF, 0xFFFF, "T540-5080 Unified Wire Ethernet Controller(0x5780)"},
{0x1425, 0x5781, 0xFFFF, 0xFFFF, "T540-5081 Unified Wire Ethernet Controller(0x5781)"},
{0x1425, 0x5782, 0xFFFF, 0xFFFF, "T504-5082 Unified Wire Ethernet Controller(0x5782)"},
{0x1425, 0x5783, 0xFFFF, 0xFFFF, "T540-5083 Unified Wire Ethernet Controller(0x5783)"},
{0x1425, 0x5784, 0xFFFF, 0xFFFF, "T580-5084 Unified Wire Ethernet Controller(0x5784)"},
{0x1425, 0x5785, 0xFFFF, 0xFFFF, "T580-5085 Unified Wire Ethernet Controller(0x5785)"},
{0x1425, 0x5786, 0xFFFF, 0xFFFF, "T580-5086 Unified Wire Ethernet Controller(0x5786)"},
{0x1425, 0x5787, 0xFFFF, 0xFFFF, "T580-5087 Unified Wire Ethernet Controller(0x5787)"},
{0x1425, 0x5788, 0xFFFF, 0xFFFF, "T570-5088 Unified Wire Ethernet Controller(0x5788)"},
{0x1425, 0x5789, 0xFFFF, 0xFFFF, "T520-5089 Unified Wire Ethernet Controller(0x5789)"},
{0x1425, 0x5790, 0xFFFF, 0xFFFF, "T540-5090 Unified Wire Ethernet Controller(0x5790)"},
{0x1425, 0x5791, 0xFFFF, 0xFFFF, "T522-5091 Unified Wire Ethernet Controller(0x5791)"},
{0x1425, 0x5792, 0xFFFF, 0xFFFF, "T520-5092 Unified Wire Ethernet Controller(0x5792)"},
{0x1425, 0x5793, 0xFFFF, 0xFFFF, "T580-5093 Unified Wire Ethernet Controller(0x5793)"},
{0x1425, 0x5794, 0xFFFF, 0xFFFF, "T540-5094 Unified Wire Ethernet Controller(0x5794)"},
{0x1425, 0x5795, 0xFFFF, 0xFFFF, "T540-5095 Unified Wire Ethernet Controller(0x5795)"},
{0x1425, 0x5796, 0xFFFF, 0xFFFF, "T580-5096 Unified Wire Ethernet Controller(0x5796)"},
{0x1425, 0x5797, 0xFFFF, 0xFFFF, "T520-5097 Unified Wire Ethernet Controller(0x5797)"},
{0x1425, 0x5801, 0xFFFF, 0xFFFF, "T520-CR Unified Wire Ethernet Controller [VF](0x5801)"},
{0x1425, 0x5802, 0xFFFF, 0xFFFF, "T522-CR Unified Wire Ethernet Controller [VF](0x5802)"},
{0x1425, 0x5803, 0xFFFF, 0xFFFF, "T540-CR Unified Wire Ethernet Controller [VF](0x5803)"},
{0x1425, 0x5804, 0xFFFF, 0xFFFF, "T520-BCH Unified Wire Ethernet Controller [VF](0x5804)"},
{0x1425, 0x5805, 0xFFFF, 0xFFFF, "T540-BCH Unified Wire Ethernet Controller [VF](0x5805)"},
{0x1425, 0x5806, 0xFFFF, 0xFFFF, "T540-CH Unified Wire Ethernet Controller [VF](0x5806)"},
{0x1425, 0x5807, 0xFFFF, 0xFFFF, "T520-SO Unified Wire Ethernet Controller [VF](0x5807)"},
{0x1425, 0x5808, 0xFFFF, 0xFFFF, "T520-CX Unified Wire Ethernet Controller [VF](0x5808)"},
{0x1425, 0x5809, 0xFFFF, 0xFFFF, "T520-BT Unified Wire Ethernet Controller [VF](0x5809)"},
{0x1425, 0x580A, 0xFFFF, 0xFFFF, "T504-BT Unified Wire Ethernet Controller [VF](0x580A)"},
{0x1425, 0x580B, 0xFFFF, 0xFFFF, "B520-SR Unified Wire Ethernet Controller [VF](0x580B)"},
{0x1425, 0x580C, 0xFFFF, 0xFFFF, "B504-BT Unified Wire Ethernet Controller [VF](0x580C)"},
{0x1425, 0x580D, 0xFFFF, 0xFFFF, "T580-CR Unified Wire Ethernet Controller [VF](0x580D)"},
{0x1425, 0x580E, 0xFFFF, 0xFFFF, "T540-LP-CR Unified Wire Ethernet Controller [VF](0x580E)"},
{0x1425, 0x580F, 0xFFFF, 0xFFFF, "T540 [Amsterdam] Unified Wire Ethernet Controller [VF](0x580F)"},
{0x1425, 0x5810, 0xFFFF, 0xFFFF, "T580-LP-CR Unified Wire Ethernet Controller [VF](0x5810)"},
{0x1425, 0x5811, 0xFFFF, 0xFFFF, "T520-LL-CR Unified Wire Ethernet Controller [VF](0x5811)"},
{0x1425, 0x5812, 0xFFFF, 0xFFFF, "T560-CR Unified Wire Ethernet Controller [VF](0x5812)"},
{0x1425, 0x5813, 0xFFFF, 0xFFFF, "T580-CHR Unified Wire Ethernet Controller [VF](0x5813)"},
{0x1425, 0x5814, 0xFFFF, 0xFFFF, "T580-SO-CR Unified Wire Ethernet Controller [VF](0x5814)"},
{0x1425, 0x5815, 0xFFFF, 0xFFFF, "T502-BT Unified Wire Ethernet Controller [VF](0x5815)"},
{0x1425, 0x5816, 0xFFFF, 0xFFFF, "T580-OCP-SO Unified Wire Ethernet Controller [VF](0x5816)"},
{0x1425, 0x5817, 0xFFFF, 0xFFFF, "T520-OCP-SO Unified Wire Ethernet Controller [VF](0x5817)"},
{0x1425, 0x5818, 0xFFFF, 0xFFFF, "T540-BT Unified Wire Ethernet Controller [VF](0x5818)"},
{0x1425, 0x5819, 0xFFFF, 0xFFFF, "T540-LP-BT Unified Wire Ethernet Controller [VF](0x5819)"},
{0x1425, 0x581A, 0xFFFF, 0xFFFF, "T540-SO-BT Unified Wire Ethernet Controller [VF](0x581A)"},
{0x1425, 0x581B, 0xFFFF, 0xFFFF, "T540-SO-CR Unified Wire Ethernet Controller [VF](0x581B)"},
{0x1425, 0x5880, 0xFFFF, 0xFFFF, "T540-5080 Unified Wire Ethernet Controller [VF](0x5880)"},
{0x1425, 0x5881, 0xFFFF, 0xFFFF, "T540-5081 Unified Wire Ethernet Controller [VF](0x5881)"},
{0x1425, 0x5882, 0xFFFF, 0xFFFF, "T504-5082 Unified Wire Ethernet Controller [VF](0x5882)"},
{0x1425, 0x5883, 0xFFFF, 0xFFFF, "T540-5083 Unified Wire Ethernet Controller [VF](0x5883)"},
{0x1425, 0x5884, 0xFFFF, 0xFFFF, "T540-5084 Unified Wire Ethernet Controller [VF](0x5884)"},
{0x1425, 0x5885, 0xFFFF, 0xFFFF, "T580-5085 Unified Wire Ethernet Controller [VF](0x5885)"},
{0x1425, 0x5886, 0xFFFF, 0xFFFF, "T580-5086 Unified Wire Ethernet Controller [VF](0x5886)"},
{0x1425, 0x5887, 0xFFFF, 0xFFFF, "T580-5087 Unified Wire Ethernet Controller [VF](0x5887)"},
{0x1425, 0x5888, 0xFFFF, 0xFFFF, "T570-5088 Unified Wire Ethernet Controller [VF](0x5888)"},
{0x1425, 0x5889, 0xFFFF, 0xFFFF, "T520-5089 Unified Wire Ethernet Controller [VF](0x5889)"},
{0x1425, 0x5890, 0xFFFF, 0xFFFF, "T540-5090 Unified Wire Ethernet Controller [VF](0x5890)"},
{0x1425, 0x5891, 0xFFFF, 0xFFFF, "T522-5091 Unified Wire Ethernet Controller [VF](0x5891)"},
{0x1425, 0x5892, 0xFFFF, 0xFFFF, "T520-5092 Unified Wire Ethernet Controller [VF](0x5892)"},
{0x1425, 0x5893, 0xFFFF, 0xFFFF, "T580-5093 Unified Wire Ethernet Controller [VF](0x5893)"},
{0x1425, 0x5894, 0xFFFF, 0xFFFF, "T540-5094 Unified Wire Ethernet Controller [VF](0x5894)"},
{0x1425, 0x5895, 0xFFFF, 0xFFFF, "T540-5095 Unified Wire Ethernet Controller [VF](0x5895)"},
{0x1425, 0x5896, 0xFFFF, 0xFFFF, "T580-5096 Unified Wire Ethernet Controller [VF](0x5896)"},
{0x1425, 0x5897, 0xFFFF, 0xFFFF, "T520-5097 Unified Wire Ethernet Controller [VF](0x5897)"},
{0x1425, 0x5898, 0xFFFF, 0xFFFF, "T580-5098 Unified Wire Ethernet Controller [VF](0x5898)"},
{0x1425, 0x5899, 0xFFFF, 0xFFFF, "T580-5099 Unified Wire Ethernet Controller [VF](0x5899)"},
{0x1425, 0x589A, 0xFFFF, 0xFFFF, "T520-509A Unified Wire Ethernet Controller [VF](0x589A)"},
{0x1425, 0x589B, 0xFFFF, 0xFFFF, "T540-509B Unified Wire Ethernet Controller [VF](0x589B)"},
{0x1425, 0x589C, 0xFFFF, 0xFFFF, "T520-509C Unified Wire Ethernet Controller [VF](0x589C)"},
{0x1425, 0x589D, 0xFFFF, 0xFFFF, "T540-509D Unified Wire Ethernet Controller [VF](0x589D)"},
{0x1425, 0x589E, 0xFFFF, 0xFFFF, "T520-509E Unified Wire Ethernet Controller [VF](0x589E)"},
{0x1425, 0x589F, 0xFFFF, 0xFFFF, "T540-509F Unified Wire Ethernet Controller [VF](0x589F)"},
{0x1425, 0x58A0, 0xFFFF, 0xFFFF, "T540-50A0 Unified Wire Ethernet Controller [VF](0x58A0)"},
{0x1425, 0x58A1, 0xFFFF, 0xFFFF, "T540-50A1 Unified Wire Ethernet Controller [VF](0x58A1)"},
{0x1425, 0x58A2, 0xFFFF, 0xFFFF, "T580-50A2 Unified Wire Ethernet Controller [VF](0x58A2)"},
{0x1425, 0x58A3, 0xFFFF, 0xFFFF, "T580-50A3 Unified Wire Ethernet Controller [VF](0x58A3)"},
{0x1425, 0x58A4, 0xFFFF, 0xFFFF, "T540-50A4 Unified Wire Ethernet Controller [VF](0x58A4)"},
{0x1425, 0x58A5, 0xFFFF, 0xFFFF, "T522-50A5 Unified Wire Ethernet Controller [VF](0x58A5)"},
{0x1425, 0x58A6, 0xFFFF, 0xFFFF, "T522-50A6 Unified Wire Ethernet Controller [VF](0x58A6)"},
{0x1425, 0x58A7, 0xFFFF, 0xFFFF, "T580-50A7 Unified Wire Ethernet Controller [VF](0x58A7)"},
{0x1425, 0x58A8, 0xFFFF, 0xFFFF, "T580-50A8 Unified Wire Ethernet Controller [VF](0x58A8)"},
{0x1425, 0x58A9, 0xFFFF, 0xFFFF, "T580-50A9 Unified Wire Ethernet Controller [VF](0x58A9)"},
{0x1425, 0x58AA, 0xFFFF, 0xFFFF, "T580-50AA Unified Wire Ethernet Controller [VF](0x58AA)"},
{0x1425, 0x58AB, 0xFFFF, 0xFFFF, "T520-50AB Unified Wire Ethernet Controller [VF](0x58AB)"},
{0x1425, 0x58AC, 0xFFFF, 0xFFFF, "T540-50AC Unified Wire Ethernet Controller [VF](0x58AC)"},
{0x1425, 0x58AD, 0xFFFF, 0xFFFF, "T520-50AD Unified Wire Ethernet Controller [VF](0x58AD)"},
{0x1425, 0x58AE, 0xFFFF, 0xFFFF, "T540-50AE Unified Wire Ethernet Controller [VF](0x58AE)"},
{0x1425, 0x58AF, 0xFFFF, 0xFFFF, "T580-50AF Unified Wire Ethernet Controller [VF](0x58AF)"},
{0x1425, 0x58B0, 0xFFFF, 0xFFFF, "T520-50B0 Unified Wire Ethernet Controller [VF](0x58B0)"},
{0x1425, 0x6001, 0xFFFF, 0xFFFF, "T6225-CR Unified Wire Ethernet Controller(0x6001)"},
{0x1425, 0x6002, 0xFFFF, 0xFFFF, "T6225-SO-CR Unified Wire Ethernet Controller(0x6002)"},
{0x1425, 0x6003, 0xFFFF, 0xFFFF, "T6425-CR Unified Wire Ethernet Controller(0x6003)"},
{0x1425, 0x6004, 0xFFFF, 0xFFFF, "T6425-SO-CR Unified Wire Ethernet Controller(0x6004)"},
{0x1425, 0x6005, 0xFFFF, 0xFFFF, "T6225-SO-OCP3 Unified Wire Ethernet Controller(0x6005)"},
{0x1425, 0x6006, 0xFFFF, 0xFFFF, "T6225-OCP3 Unified Wire Ethernet Controller(0x6006)"},
{0x1425, 0x6007, 0xFFFF, 0xFFFF, "T62100-LP-CR Unified Wire Ethernet Controller(0x6007)"},
{0x1425, 0x6008, 0xFFFF, 0xFFFF, "T62100-SO-CR Unified Wire Ethernet Controller(0x6008)"},
{0x1425, 0x6009, 0xFFFF, 0xFFFF, "T6210-BT Unified Wire Ethernet Controller(0x6009)"},
{0x1425, 0x600D, 0xFFFF, 0xFFFF, "T62100-CR Unified Wire Ethernet Controller(0x600D)"},
{0x1425, 0x6011, 0xFFFF, 0xFFFF, "T6225-LL-CR Unified Wire Ethernet Controller(0x6011)"},
{0x1425, 0x6014, 0xFFFF, 0xFFFF, "T62100-SO-OCP3 Unified Wire Ethernet Controller(0x6014)"},
{0x1425, 0x6015, 0xFFFF, 0xFFFF, "T6201-BT Unified Wire Ethernet Controller(0x6015)"},
{0x1425, 0x6080, 0xFFFF, 0xFFFF, "T6225-6080 Unified Wire Ethernet Controller(0x6080)"},
{0x1425, 0x6081, 0xFFFF, 0xFFFF, "T62100-6081 Unified Wire Ethernet Controller(0x6081)"},
{0x1425, 0x6082, 0xFFFF, 0xFFFF, "T6225-6082 Unified Wire Ethernet Controller(0x6082)"},
{0x1425, 0x6083, 0xFFFF, 0xFFFF, "T62100-6083 Unified Wire Ethernet Controller(0x6083)"},
{0x1425, 0x6084, 0xFFFF, 0xFFFF, "T64100-6084 Unified Wire Ethernet Controller(0x6084)"},
{0x1425, 0x6085, 0xFFFF, 0xFFFF, "T6240-6085 Unified Wire Ethernet Controller(0x6085)"},
{0x1425, 0x6086, 0xFFFF, 0xFFFF, "T6225-6086 Unified Wire Ethernet Controller(0x6086)"},
{0x1425, 0x6087, 0xFFFF, 0xFFFF, "T6225-6087 Unified Wire Ethernet Controller(0x6087)"},
{0x1425, 0x6088, 0xFFFF, 0xFFFF, "T62100-6088 Unified Wire Ethernet Controller(0x6088)"},
{0x1425, 0x6089, 0xFFFF, 0xFFFF, "T62100-6089 Unified Wire Ethernet Controller(0x6089)"},
{0x1425, 0x608A, 0xFFFF, 0xFFFF, "T62100-608a Unified Wire Ethernet Controller(0x608A)"},
{0x1425, 0x6092, 0xFFFF, 0xFFFF, "T62100-KR Unified Wire Ethernet Controller(0x6092)"},
{0x1425, 0x6092, 0x01DE, 0xFFF9, "Gimlet Baseboard(0x01DE-0xFFF9)"},
{0x1425, 0x6401, 0xFFFF, 0xFFFF, "T6225-CR Unified Wire Ethernet Controller(0x6401)"},
{0x1425, 0x6402, 0xFFFF, 0xFFFF, "T6225-SO-CR Unified Wire Ethernet Controller(0x6402)"},
{0x1425, 0x6403, 0xFFFF, 0xFFFF, "T6425-CR Unified Wire Ethernet Controller(0x6403)"},
{0x1425, 0x6404, 0xFFFF, 0xFFFF, "T6425-SO-CR Unified Wire Ethernet Controller(0x6404)"},
{0x1425, 0x6405, 0xFFFF, 0xFFFF, "T6225-SO-OCP3 Unified Wire Ethernet Controller(0x6405)"},
{0x1425, 0x6406, 0xFFFF, 0xFFFF, "T6225-OCP3 Unified Wire Ethernet Controller(0x6406)"},
{0x1425, 0x6407, 0xFFFF, 0xFFFF, "T62100-LP-CR Unified Wire Ethernet Controller(0x6407)"},
{0x1425, 0x6408, 0xFFFF, 0xFFFF, "T62100-SO-CR Unified Wire Ethernet Controller(0x6408)"},
{0x1425, 0x6409, 0xFFFF, 0xFFFF, "T6210-BT Unified Wire Ethernet Controller(0x6409)"},
{0x1425, 0x640D, 0xFFFF, 0xFFFF, "T62100-CR Unified Wire Ethernet Controller(0x640D)"},
{0x1425, 0x6411, 0xFFFF, 0xFFFF, "T6225-LL-CR Unified Wire Ethernet Controller(0x6411)"},
{0x1425, 0x6414, 0xFFFF, 0xFFFF, "T62100-SO-OCP3 Unified Wire Ethernet Controller(0x6414)"},
{0x1425, 0x6415, 0xFFFF, 0xFFFF, "T6201-BT Unified Wire Ethernet Controller(0x6415)"},
{0x1425, 0x6480, 0xFFFF, 0xFFFF, "T6225-6080 Unified Wire Ethernet Controller(0x6480)"},
{0x1425, 0x6481, 0xFFFF, 0xFFFF, "T62100-6081 Unified Wire Ethernet Controller(0x6481)"},
{0x1425, 0x6482, 0xFFFF, 0xFFFF, "T6225-6082 Unified Wire Ethernet Controller(0x6482)"},
{0x1425, 0x6483, 0xFFFF, 0xFFFF, "T62100-6083 Unified Wire Ethernet Controller(0x6483)"},
{0x1425, 0x6484, 0xFFFF, 0xFFFF, "T64100-6084 Unified Wire Ethernet Controller(0x6484)"},
{0x1425, 0x6485, 0xFFFF, 0xFFFF, "T6240-6085 Unified Wire Ethernet Controller(0x6485)"},
{0x1425, 0x6486, 0xFFFF, 0xFFFF, "T6225-6086 Unified Wire Ethernet Controller(0x6486)"},
{0x1425, 0x6487, 0xFFFF, 0xFFFF, "T6225-6087 Unified Wire Ethernet Controller(0x6487)"},
{0x1425, 0x6488, 0xFFFF, 0xFFFF, "T62100-6088 Unified Wire Ethernet Controller(0x6488)"},
{0x1425, 0x6489, 0xFFFF, 0xFFFF, "T62100-6089 Unified Wire Ethernet Controller(0x6489)"},
{0x1425, 0x648A, 0xFFFF, 0xFFFF, "T62100-608a Unified Wire Ethernet Controller(0x648A)"},
{0x1425, 0x6492, 0xFFFF, 0xFFFF, "T62100-KR Unified Wire Ethernet Controller(0x6492)"},
{0x1425, 0x6492, 0x01DE, 0xFFF9, "Gimlet Baseboard(0x01DE-0xFFF9)"},
{0x1425, 0x6501, 0xFFFF, 0xFFFF, "T6225-CR Unified Wire Storage Controller(0x6501)"},
{0x1425, 0x6502, 0xFFFF, 0xFFFF, "T6225-SO-CR Unified Wire Storage Controller(0x6502)"},
{0x1425, 0x6503, 0xFFFF, 0xFFFF, "T6425-CR Unified Wire Storage Controller(0x6503)"},
{0x1425, 0x6504, 0xFFFF, 0xFFFF, "T6425-SO-CR Unified Wire Storage Controller(0x6504)"},
{0x1425, 0x6505, 0xFFFF, 0xFFFF, "T6225-SO-OCP3 Unified Wire Storage Controller(0x6505)"},
{0x1425, 0x6506, 0xFFFF, 0xFFFF, "T6225-OCP3 Unified Wire Storage Controller(0x6506)"},
{0x1425, 0x6507, 0xFFFF, 0xFFFF, "T62100-LP-CR Unified Wire Storage Controller(0x6507)"},
{0x1425, 0x6508, 0xFFFF, 0xFFFF, "T62100-SO-CR Unified Wire Storage Controller(0x6508)"},
{0x1425, 0x6509, 0xFFFF, 0xFFFF, "T6210-BT Unified Wire Storage Controller(0x6509)"},
{0x1425, 0x650D, 0xFFFF, 0xFFFF, "T62100-CR Unified Wire Storage Controller(0x650D)"},
{0x1425, 0x6511, 0xFFFF, 0xFFFF, "T6225-LL-CR Unified Wire Storage Controller(0x6511)"},
{0x1425, 0x6514, 0xFFFF, 0xFFFF, "T62100-SO-OCP3 Unified Wire Storage Controller(0x6514)"},
{0x1425, 0x6515, 0xFFFF, 0xFFFF, "T6201-BT Unified Wire Storage Controller(0x6515)"},
{0x1425, 0x6580, 0xFFFF, 0xFFFF, "T6225-6080 Unified Wire Storage Controller(0x6580)"},
{0x1425, 0x6581, 0xFFFF, 0xFFFF, "T62100-6081 Unified Wire Storage Controller(0x6581)"},
{0x1425, 0x6582, 0xFFFF, 0xFFFF, "T6225-6082 Unified Wire Storage Controller(0x6582)"},
{0x1425, 0x6583, 0xFFFF, 0xFFFF, "T62100-6083 Unified Wire Storage Controller(0x6583)"},
{0x1425, 0x6584, 0xFFFF, 0xFFFF, "T64100-6084 Unified Wire Storage Controller(0x6584)"},
{0x1425, 0x6585, 0xFFFF, 0xFFFF, "T6240-6085 Unified Wire Storage Controller(0x6585)"},
{0x1425, 0x6586, 0xFFFF, 0xFFFF, "T6225-6086 Unified Wire Storage Controller(0x6586)"},
{0x1425, 0x6587, 0xFFFF, 0xFFFF, "T6225-6087 Unified Wire Storage Controller(0x6587)"},
{0x1425, 0x6588, 0xFFFF, 0xFFFF, "T62100-6088 Unified Wire Storage Controller(0x6588)"},
{0x1425, 0x6589, 0xFFFF, 0xFFFF, "T62100-6089 Unified Wire Storage Controller(0x6589)"},
{0x1425, 0x658A, 0xFFFF, 0xFFFF, "T62100-608a Unified Wire Storage Controller(0x658A)"},
{0x1425, 0x6592, 0xFFFF, 0xFFFF, "T62100-KR Unified Wire Storage Controller(0x6592)"},
{0x1425, 0x6601, 0xFFFF, 0xFFFF, "T6225-CR Unified Wire Storage Controller(0x6601)"},
{0x1425, 0x6602, 0xFFFF, 0xFFFF, "T6225-SO-CR Unified Wire Storage Controller(0x6602)"},
{0x1425, 0x6603, 0xFFFF, 0xFFFF, "T6425-CR Unified Wire Storage Controller(0x6603)"},
{0x1425, 0x6604, 0xFFFF, 0xFFFF, "T6425-SO-CR Unified Wire Storage Controller(0x6604)"},
{0x1425, 0x6605, 0xFFFF, 0xFFFF, "T6225-SO-OCP3 Unified Wire Storage Controller(0x6605)"},
{0x1425, 0x6606, 0xFFFF, 0xFFFF, "T6225-OCP3 Unified Wire Storage Controller(0x6606)"},
{0x1425, 0x6607, 0xFFFF, 0xFFFF, "T62100-LP-CR Unified Wire Storage Controller(0x6607)"},
{0x1425, 0x6608, 0xFFFF, 0xFFFF, "T62100-SO-CR Unified Wire Storage Controller(0x6608)"},
{0x1425, 0x6609, 0xFFFF, 0xFFFF, "T6210-BT Unified Wire Storage Controller(0x6609)"},
{0x1425, 0x660D, 0xFFFF, 0xFFFF, "T62100-CR Unified Wire Storage Controller(0x660D)"},
{0x1425, 0x6611, 0xFFFF, 0xFFFF, "T6225-LL-CR Unified Wire Storage Controller(0x6611)"},
{0x1425, 0x6614, 0xFFFF, 0xFFFF, "T62100-SO-OCP3 Unified Wire Storage Controller(0x6614)"},
{0x1425, 0x6615, 0xFFFF, 0xFFFF, "T6201-BT Unified Wire Storage Controller(0x6615)"},
{0x1425, 0x6680, 0xFFFF, 0xFFFF, "T6225-6080 Unified Wire Storage Controller(0x6680)"},
{0x1425, 0x6681, 0xFFFF, 0xFFFF, "T62100-6081 Unified Wire Storage Controller(0x6681)"},
{0x1425, 0x6682, 0xFFFF, 0xFFFF, "T6225-6082 Unified Wire Storage Controller(0x6682)"},
{0x1425, 0x6683, 0xFFFF, 0xFFFF, "T62100-6083 Unified Wire Storage Controller(0x6683)"},
{0x1425, 0x6684, 0xFFFF, 0xFFFF, "T64100-6084 Unified Wire Storage Controller(0x6684)"},
{0x1425, 0x6685, 0xFFFF, 0xFFFF, "T6240-6085 Unified Wire Storage Controller(0x6685)"},
{0x1425, 0x6686, 0xFFFF, 0xFFFF, "T6225-6086 Unified Wire Storage Controller(0x6686)"},
{0x1425, 0x6687, 0xFFFF, 0xFFFF, "T6225-6087 Unified Wire Storage Controller(0x6687)"},
{0x1425, 0x6688, 0xFFFF, 0xFFFF, "T62100-6088 Unified Wire Storage Controller(0x6688)"},
{0x1425, 0x6689, 0xFFFF, 0xFFFF, "T62100-6089 Unified Wire Storage Controller(0x6689)"},
{0x1425, 0x668A, 0xFFFF, 0xFFFF, "T62100-608a Unified Wire Storage Controller(0x668A)"},
{0x1425, 0x6692, 0xFFFF, 0xFFFF, "T62100-KR Unified Wire Storage Controller(0x6692)"},
{0x1425, 0x6801, 0xFFFF, 0xFFFF, "T6225-CR Unified Wire Ethernet Controller [VF](0x6801)"},
{0x1425, 0x6802, 0xFFFF, 0xFFFF, "T6225-SO-CR Unified Wire Ethernet Controller [VF](0x6802)"},
{0x1425, 0x6803, 0xFFFF, 0xFFFF, "T6425-CR Unified Wire Ethernet Controller [VF](0x6803)"},
{0x1425, 0x6804, 0xFFFF, 0xFFFF, "T6425-SO-CR Unified Wire Ethernet Controller [VF](0x6804)"},
{0x1425, 0x6805, 0xFFFF, 0xFFFF, "T6225-SO-OCP3 Unified Wire Ethernet Controller [VF](0x6805)"},
{0x1425, 0x6806, 0xFFFF, 0xFFFF, "T6225-OCP3 Unified Wire Ethernet Controller [VF](0x6806)"},
{0x1425, 0x6807, 0xFFFF, 0xFFFF, "T62100-LP-CR Unified Wire Ethernet Controller [VF](0x6807)"},
{0x1425, 0x6808, 0xFFFF, 0xFFFF, "T62100-SO-CR Unified Wire Ethernet Controller [VF](0x6808)"},
{0x1425, 0x6809, 0xFFFF, 0xFFFF, "T6210-BT Unified Wire Ethernet Controller [VF](0x6809)"},
{0x1425, 0x680D, 0xFFFF, 0xFFFF, "T62100-CR Unified Wire Ethernet Controller [VF](0x680D)"},
{0x1425, 0x6811, 0xFFFF, 0xFFFF, "T6225-LL-CR Unified Wire Ethernet Controller [VF](0x6811)"},
{0x1425, 0x6814, 0xFFFF, 0xFFFF, "T62100-SO-OCP3 Unified Wire Ethernet Controller [VF](0x6814)"},
{0x1425, 0x6815, 0xFFFF, 0xFFFF, "T6201-BT Unified Wire Ethernet Controller [VF](0x6815)"},
{0x1425, 0x6880, 0xFFFF, 0xFFFF, "T6225-6080 Unified Wire Ethernet Controller [VF](0x6880)"},
{0x1425, 0x6881, 0xFFFF, 0xFFFF, "T62100-6081 Unified Wire Ethernet Controller [VF](0x6881)"},
{0x1425, 0x6882, 0xFFFF, 0xFFFF, "T6225-6082 Unified Wire Ethernet Controller [VF](0x6882)"},
{0x1425, 0x6883, 0xFFFF, 0xFFFF, "T62100-6083 Unified Wire Ethernet Controller [VF](0x6883)"},
{0x1425, 0x6884, 0xFFFF, 0xFFFF, "T64100-6084 Unified Wire Ethernet Controller [VF](0x6884)"},
{0x1425, 0x6885, 0xFFFF, 0xFFFF, "T6240-6085 Unified Wire Ethernet Controller [VF](0x6885)"},
{0x1425, 0x6886, 0xFFFF, 0xFFFF, "T6225-6086 Unified Wire Ethernet Controller [VF](0x6886)"},
{0x1425, 0x6887, 0xFFFF, 0xFFFF, "T6225-6087 Unified Wire Ethernet Controller [VF](0x6887)"},
{0x1425, 0x6888, 0xFFFF, 0xFFFF, "T62100-6088 Unified Wire Ethernet Controller [VF](0x6888)"},
{0x1425, 0x6889, 0xFFFF, 0xFFFF, "T62100-6089 Unified Wire Ethernet Controller [VF](0x6889)"},
{0x1425, 0x688A, 0xFFFF, 0xFFFF, "T62100-608a Unified Wire Ethernet Controller [VF](0x688A)"},
{0x1425, 0xA000, 0xFFFF, 0xFFFF, "PE10K Unified Wire Ethernet Controller(0xA000)"},
}; /* pci_vid_1425[] */

static pci_id_t const pci_vid_1426[] = {
{0x1426, 0xFFFF, 0xFFFF, 0xFFFF, "Storage Technology Corp.(0x1426)"},
}; /* pci_vid_1426[] */

static pci_id_t const pci_vid_1427[] = {
{0x1427, 0xFFFF, 0xFFFF, 0xFFFF, "Better On-Line Solutions(0x1427)"},
}; /* pci_vid_1427[] */

static pci_id_t const pci_vid_1428[] = {
{0x1428, 0xFFFF, 0xFFFF, 0xFFFF, "Edec Co Ltd(0x1428)"},
}; /* pci_vid_1428[] */

static pci_id_t const pci_vid_1429[] = {
{0x1429, 0xFFFF, 0xFFFF, 0xFFFF, "Unex Technology Corp.(0x1429)"},
}; /* pci_vid_1429[] */

static pci_id_t const pci_vid_142A[] = {
{0x142A, 0xFFFF, 0xFFFF, 0xFFFF, "Kingmax Technology Inc(0x142A)"},
}; /* pci_vid_142A[] */

static pci_id_t const pci_vid_142B[] = {
{0x142B, 0xFFFF, 0xFFFF, 0xFFFF, "Radiolan(0x142B)"},
}; /* pci_vid_142B[] */

static pci_id_t const pci_vid_142C[] = {
{0x142C, 0xFFFF, 0xFFFF, 0xFFFF, "Minton Optic Industry Co Ltd(0x142C)"},
}; /* pci_vid_142C[] */

static pci_id_t const pci_vid_142D[] = {
{0x142D, 0xFFFF, 0xFFFF, 0xFFFF, "Pix stream Inc(0x142D)"},
}; /* pci_vid_142D[] */

static pci_id_t const pci_vid_142E[] = {
{0x142E, 0xFFFF, 0xFFFF, 0xFFFF, "Vitec Multimedia(0x142E)"},
{0x142E, 0x4020, 0xFFFF, 0xFFFF, "VM2-2 [Video Maker 2] MPEG1/2 Encoder(0x4020)"},
{0x142E, 0x4337, 0xFFFF, 0xFFFF, "VM2-2-C7 [Video Maker 2 rev. C7] MPEG1/2 Encoder(0x4337)"},
}; /* pci_vid_142E[] */

static pci_id_t const pci_vid_142F[] = {
{0x142F, 0xFFFF, 0xFFFF, 0xFFFF, "Radicom Research Inc(0x142F)"},
}; /* pci_vid_142F[] */

static pci_id_t const pci_vid_1430[] = {
{0x1430, 0xFFFF, 0xFFFF, 0xFFFF, "ITT Aerospace/Communications Division(0x1430)"},
}; /* pci_vid_1430[] */

static pci_id_t const pci_vid_1431[] = {
{0x1431, 0xFFFF, 0xFFFF, 0xFFFF, "Gilat Satellite Networks(0x1431)"},
}; /* pci_vid_1431[] */

static pci_id_t const pci_vid_1432[] = {
{0x1432, 0xFFFF, 0xFFFF, 0xFFFF, "Edimax Computer Co.(0x1432)"},
{0x1432, 0x9130, 0xFFFF, 0xFFFF, "RTL81xx Fast Ethernet(0x9130)"},
}; /* pci_vid_1432[] */

static pci_id_t const pci_vid_1433[] = {
{0x1433, 0xFFFF, 0xFFFF, 0xFFFF, "Eltec Elektronik GmbH(0x1433)"},
}; /* pci_vid_1433[] */

static pci_id_t const pci_vid_1435[] = {
{0x1435, 0xFFFF, 0xFFFF, 0xFFFF, "RTD Embedded Technologies, Inc.(0x1435)"},
{0x1435, 0x4520, 0xFFFF, 0xFFFF, "PCI4520(0x4520)"},
{0x1435, 0x6020, 0xFFFF, 0xFFFF, "SPM6020(0x6020)"},
{0x1435, 0x6030, 0xFFFF, 0xFFFF, "SPM6030(0x6030)"},
{0x1435, 0x6420, 0xFFFF, 0xFFFF, "SPM186420(0x6420)"},
{0x1435, 0x6430, 0xFFFF, 0xFFFF, "SPM176430(0x6430)"},
{0x1435, 0x6431, 0xFFFF, 0xFFFF, "SPM176431(0x6431)"},
{0x1435, 0x7520, 0xFFFF, 0xFFFF, "DM7520(0x7520)"},
{0x1435, 0x7540, 0xFFFF, 0xFFFF, "SDM7540(0x7540)"},
{0x1435, 0x7820, 0xFFFF, 0xFFFF, "DM7820(0x7820)"},
}; /* pci_vid_1435[] */

static pci_id_t const pci_vid_1436[] = {
{0x1436, 0xFFFF, 0xFFFF, 0xFFFF, "CIS Technology Inc(0x1436)"},
}; /* pci_vid_1436[] */

static pci_id_t const pci_vid_1437[] = {
{0x1437, 0xFFFF, 0xFFFF, 0xFFFF, "Nissin Inc Co(0x1437)"},
}; /* pci_vid_1437[] */

static pci_id_t const pci_vid_1438[] = {
{0x1438, 0xFFFF, 0xFFFF, 0xFFFF, "Atmel-dream(0x1438)"},
}; /* pci_vid_1438[] */

static pci_id_t const pci_vid_1439[] = {
{0x1439, 0xFFFF, 0xFFFF, 0xFFFF, "Outsource Engineering & Mfg. Inc(0x1439)"},
}; /* pci_vid_1439[] */

static pci_id_t const pci_vid_143A[] = {
{0x143A, 0xFFFF, 0xFFFF, 0xFFFF, "Stargate Solutions Inc(0x143A)"},
}; /* pci_vid_143A[] */

static pci_id_t const pci_vid_143B[] = {
{0x143B, 0xFFFF, 0xFFFF, 0xFFFF, "Canon Research Center, America(0x143B)"},
}; /* pci_vid_143B[] */

static pci_id_t const pci_vid_143C[] = {
{0x143C, 0xFFFF, 0xFFFF, 0xFFFF, "Amlogic Inc(0x143C)"},
}; /* pci_vid_143C[] */

static pci_id_t const pci_vid_143D[] = {
{0x143D, 0xFFFF, 0xFFFF, 0xFFFF, "Tamarack Microelectronics Inc(0x143D)"},
}; /* pci_vid_143D[] */

static pci_id_t const pci_vid_143E[] = {
{0x143E, 0xFFFF, 0xFFFF, 0xFFFF, "Jones Futurex Inc(0x143E)"},
}; /* pci_vid_143E[] */

static pci_id_t const pci_vid_143F[] = {
{0x143F, 0xFFFF, 0xFFFF, 0xFFFF, "Lightwell Co Ltd - Zax Division(0x143F)"},
}; /* pci_vid_143F[] */

static pci_id_t const pci_vid_1440[] = {
{0x1440, 0xFFFF, 0xFFFF, 0xFFFF, "ALGOL Corp.(0x1440)"},
}; /* pci_vid_1440[] */

static pci_id_t const pci_vid_1441[] = {
{0x1441, 0xFFFF, 0xFFFF, 0xFFFF, "AGIE Ltd(0x1441)"},
}; /* pci_vid_1441[] */

static pci_id_t const pci_vid_1442[] = {
{0x1442, 0xFFFF, 0xFFFF, 0xFFFF, "Phoenix Contact GmbH & Co.(0x1442)"},
}; /* pci_vid_1442[] */

static pci_id_t const pci_vid_1443[] = {
{0x1443, 0xFFFF, 0xFFFF, 0xFFFF, "Unibrain S.A.(0x1443)"},
}; /* pci_vid_1443[] */

static pci_id_t const pci_vid_1444[] = {
{0x1444, 0xFFFF, 0xFFFF, 0xFFFF, "TRW(0x1444)"},
}; /* pci_vid_1444[] */

static pci_id_t const pci_vid_1445[] = {
{0x1445, 0xFFFF, 0xFFFF, 0xFFFF, "Logical DO Ltd(0x1445)"},
}; /* pci_vid_1445[] */

static pci_id_t const pci_vid_1446[] = {
{0x1446, 0xFFFF, 0xFFFF, 0xFFFF, "Graphin Co Ltd(0x1446)"},
}; /* pci_vid_1446[] */

static pci_id_t const pci_vid_1447[] = {
{0x1447, 0xFFFF, 0xFFFF, 0xFFFF, "AIM GmBH(0x1447)"},
}; /* pci_vid_1447[] */

static pci_id_t const pci_vid_1448[] = {
{0x1448, 0xFFFF, 0xFFFF, 0xFFFF, "Alesis Studio Electronics(0x1448)"},
}; /* pci_vid_1448[] */

static pci_id_t const pci_vid_1449[] = {
{0x1449, 0xFFFF, 0xFFFF, 0xFFFF, "TUT Systems Inc(0x1449)"},
}; /* pci_vid_1449[] */

static pci_id_t const pci_vid_144A[] = {
{0x144A, 0xFFFF, 0xFFFF, 0xFFFF, "Adlink Technology(0x144A)"},
{0x144A, 0x6208, 0xFFFF, 0xFFFF, "PCI-6208V(0x6208)"},
{0x144A, 0x7250, 0xFFFF, 0xFFFF, "PCI-7250(0x7250)"},
{0x144A, 0x7296, 0xFFFF, 0xFFFF, "PCI-7296(0x7296)"},
{0x144A, 0x7432, 0xFFFF, 0xFFFF, "PCI-7432(0x7432)"},
{0x144A, 0x7433, 0xFFFF, 0xFFFF, "PCI-7433(0x7433)"},
{0x144A, 0x7434, 0xFFFF, 0xFFFF, "PCI-7434(0x7434)"},
{0x144A, 0x7841, 0xFFFF, 0xFFFF, "PCI-7841(0x7841)"},
{0x144A, 0x8133, 0xFFFF, 0xFFFF, "PCI-8133(0x8133)"},
{0x144A, 0x8164, 0xFFFF, 0xFFFF, "PCI-8164(0x8164)"},
{0x144A, 0x8554, 0xFFFF, 0xFFFF, "PCI-8554(0x8554)"},
{0x144A, 0x9111, 0xFFFF, 0xFFFF, "PCI-9111(0x9111)"},
{0x144A, 0x9113, 0xFFFF, 0xFFFF, "PCI-9113(0x9113)"},
{0x144A, 0x9114, 0xFFFF, 0xFFFF, "PCI-9114(0x9114)"},
{0x144A, 0xA001, 0xFFFF, 0xFFFF, "ADi-BSEC(0xA001)"},
}; /* pci_vid_144A[] */

static pci_id_t const pci_vid_144B[] = {
{0x144B, 0xFFFF, 0xFFFF, 0xFFFF, "Verint Systems Inc.(0x144B)"},
}; /* pci_vid_144B[] */

static pci_id_t const pci_vid_144C[] = {
{0x144C, 0xFFFF, 0xFFFF, 0xFFFF, "Catalina Research Inc(0x144C)"},
}; /* pci_vid_144C[] */

static pci_id_t const pci_vid_144D[] = {
{0x144D, 0xFFFF, 0xFFFF, 0xFFFF, "Samsung Electronics Co Ltd(0x144D)"},
{0x144D, 0x1600, 0xFFFF, 0xFFFF, "S4LN053X01 AHCI SSD Controller(Apple slot)(0x1600)"},
{0x144D, 0x9602, 0xFFFF, 0xFFFF, "RS780/RS880 PCI to PCI bridge (int gfx)(0x9602)"},
{0x144D, 0xA544, 0xFFFF, 0xFFFF, "Exynos 8890 PCIe Root Complex(0xA544)"},
{0x144D, 0xA575, 0xFFFF, 0xFFFF, "Exynos 7420 PCIe Root Complex(0xA575)"},
{0x144D, 0xA5E3, 0xFFFF, 0xFFFF, "Exynos 5433 PCIe Root Complex(0xA5E3)"},
{0x144D, 0xA800, 0xFFFF, 0xFFFF, "XP941 PCIe SSD(0xA800)"},
{0x144D, 0xA801, 0xFFFF, 0xFFFF, "S4LN058A01[SSUBX] AHCI SSD Controller (Apple slot)(0xA801)"},
{0x144D, 0xA802, 0xFFFF, 0xFFFF, "NVMe SSD Controller SM951/PM951(0xA802)"},
{0x144D, 0xA802, 0x144D, 0xA801, "PM963 2.5\" NVMe PCIe SSD(0x144D-0xA801)"},
{0x144D, 0xA804, 0xFFFF, 0xFFFF, "NVMe SSD Controller SM961/PM961/SM963(0xA804)"},
{0x144D, 0xA804, 0x144D, 0xA801, "SM963 2.5\" NVMe PCIe SSD(0x144D-0xA801)"},
{0x144D, 0xA806, 0xFFFF, 0xFFFF, "NVMe SSD SM0032L(0xA806)"},
{0x144D, 0xA808, 0xFFFF, 0xFFFF, "NVMe SSD Controller SM981/PM981/PM983(0xA808)"},
{0x144D, 0xA808, 0x144D, 0xA801, "SSD 970 EVO/PRO(0x144D-0xA801)"},
{0x144D, 0xA808, 0x1D49, 0x403B, "Thinksystem U.2 PM983 NVMe SSD(0x1D49-0x403B)"},
{0x144D, 0xA809, 0xFFFF, 0xFFFF, "NVMe SSD Controller 980 (DRAM-less)(0xA809)"},
{0x144D, 0xA80A, 0xFFFF, 0xFFFF, "NVMe SSD Controller PM9A1/PM9A3/980PRO(0xA80A)"},
{0x144D, 0xA80A, 0x0128, 0x215A, "DC NVMe PM9A3 RI U.2 960GB(0x0128-0x215A)"},
{0x144D, 0xA80A, 0x0128, 0x215B, "DC NVMe PM9A3 RI U.2 1.92TB(0x0128-0x215B)"},
{0x144D, 0xA80A, 0x0128, 0x215C, "DC NVMe PM9A3 RI U.2 3.84TB(0x0128-0x215C)"},
{0x144D, 0xA80A, 0x0128, 0x215D, "DC NVMe PM9A3 RI U.2 7.68TB(0x0128-0x215D)"},
{0x144D, 0xA80A, 0x0128, 0x2166, "DC NVMe PM9A3 RI 110M.2 960GB(0x0128-0x2166)"},
{0x144D, 0xA80A, 0x0128, 0x2167, "DC NVMe PM9A3 RI 110M.2 1.92TB(0x0128-0x2167)"},
{0x144D, 0xA80A, 0x0128, 0x2168, "DC NVMe PM9A3 RI 80M.2 480GB(0x0128-0x2168)"},
{0x144D, 0xA80A, 0x0128, 0x2169, "DC NVMe PM9A3 RI 80M.2 960GB(0x0128-0x2169)"},
{0x144D, 0xA80A, 0x1028, 0x215A, "DC NVMe PM9A3 RI U.2 960GB(0x1028-0x215A)"},
{0x144D, 0xA80A, 0x1028, 0x215B, "DC NVMe PM9A3 RI U.2 1.92TB(0x1028-0x215B)"},
{0x144D, 0xA80A, 0x1028, 0x215C, "DC NVMe PM9A3 RI U.2 3.84TB(0x1028-0x215C)"},
{0x144D, 0xA80A, 0x1028, 0x2166, "DC NVMe PM9A3 RI 110M.2 960GB(0x1028-0x2166)"},
{0x144D, 0xA80A, 0x1028, 0x2167, "DC NVMe PM9A3 RI 110M.2 1.92TB(0x1028-0x2167)"},
{0x144D, 0xA80A, 0x1028, 0x2168, "DC NVMe PM9A3 RI 80M.2 480GB(0x1028-0x2168)"},
{0x144D, 0xA80A, 0x1028, 0x2169, "DC NVMe PM9A3 RI 80M.2 960GB(0x1028-0x2169)"},
{0x144D, 0xA80A, 0x1028, 0x2276, "DC NVMe PM9A3 RI 110M.2 960GB(0x1028-0x2276)"},
{0x144D, 0xA80A, 0x1028, 0x2277, "DC NVMe PM9A3 RI 110M.2 1.92TB(0x1028-0x2277)"},
{0x144D, 0xA80A, 0x1028, 0x512D, "DC NVMe PM9A3 RI U.2 7.68TB(0x1028-0x512D)"},
{0x144D, 0xA80A, 0x144D, 0xA801, "SSD 980 PRO(0x144D-0xA801)"},
{0x144D, 0xA80A, 0x144D, 0xA813, "General DC NVMe PM9A3(0x144D-0xA813)"},
{0x144D, 0xA80B, 0xFFFF, 0xFFFF, "NVMe SSD Controller PM9B1 (DRAM-less)(0xA80B)"},
{0x144D, 0xA80C, 0xFFFF, 0xFFFF, "NVMe SSD Controller S4LV008[Pascal](0xA80C)"},
{0x144D, 0xA80D, 0xFFFF, 0xFFFF, "NVMe SSD Controller PM9C1a (DRAM-less)(0xA80D)"},
{0x144D, 0xA820, 0xFFFF, 0xFFFF, "NVMe SSD Controller 171X(0xA820)"},
{0x144D, 0xA820, 0x1028, 0x1F95, "Express Flash NVMe XS1715 SSD 400GB(0x1028-0x1F95)"},
{0x144D, 0xA820, 0x1028, 0x1F96, "Express Flash NVMe XS1715 SSD 800GB(0x1028-0x1F96)"},
{0x144D, 0xA820, 0x1028, 0x1F97, "Express Flash NVMe XS1715 SSD 1600GB(0x1028-0x1F97)"},
{0x144D, 0xA820, 0x1028, 0x1FA4, "Express Flash NVMe SM1715 3.2TB SFF(0x1028-0x1FA4)"},
{0x144D, 0xA820, 0x1028, 0x1FA6, "Express Flash NVMe SM1715 3.2TB AIC(0x1028-0x1FA6)"},
{0x144D, 0xA820, 0x1028, 0x1FBA, "Express Flash NVMe SM1715 800GB SFF(0x1028-0x1FBA)"},
{0x144D, 0xA820, 0x1028, 0x1FBB, "Express Flash NVMe SM1715 1.6TB SFF(0x1028-0x1FBB)"},
{0x144D, 0xA820, 0x1028, 0x1FBC, "Express Flash NVMe SM1715 1.6TB AIC(0x1028-0x1FBC)"},
{0x144D, 0xA821, 0xFFFF, 0xFFFF, "NVMe SSD Controller 172X(0xA821)"},
{0x144D, 0xA821, 0x1028, 0x1FB7, "Express Flash NVMe PM1725 3.2TB SFF(0x1028-0x1FB7)"},
{0x144D, 0xA821, 0x1028, 0x1FB8, "Express Flash NVMe PM1725 3.2TB AIC(0x1028-0x1FB8)"},
{0x144D, 0xA821, 0x1028, 0x1FB9, "Express Flash NVMe PM1725 6.4TB AIC(0x1028-0x1FB9)"},
{0x144D, 0xA821, 0x1028, 0x1FC1, "Express Flash NVMe PM1725 800GB SFF(0x1028-0x1FC1)"},
{0x144D, 0xA821, 0x1028, 0x1FC2, "Express Flash NVMe PM1725 1.6TB SFF(0x1028-0x1FC2)"},
{0x144D, 0xA821, 0x1028, 0x1FC4, "Express Flash NVMe PM1725 1.6TB AIC(0x1028-0x1FC4)"},
{0x144D, 0xA822, 0xFFFF, 0xFFFF, "NVMe SSD Controller 172Xa/172Xb(0xA822)"},
{0x144D, 0xA822, 0x1014, 0x0621, "PCIe3 1.6TB NVMe Flash Adapter II x8(0x1014-0x0621)"},
{0x144D, 0xA822, 0x1014, 0x0622, "PCIe3 3.2TB NVMe Flash Adapter II x8(0x1014-0x0622)"},
{0x144D, 0xA822, 0x1014, 0x0629, "PCIe3 6.4TB NVMe Flash Adapter II x8(0x1014-0x0629)"},
{0x144D, 0xA822, 0x1014, 0x064A, "PCIe3 1.6TB NVMe Flash Adapter III x8(0x1014-0x064A)"},
{0x144D, 0xA822, 0x1014, 0x064B, "PCIe3 3.2TB NVMe Flash Adapter III x8(0x1014-0x064B)"},
{0x144D, 0xA822, 0x1014, 0x064C, "PCIe3 6.4TB NVMe Flash Adapter III x8(0x1014-0x064C)"},
{0x144D, 0xA822, 0x1028, 0x1FD9, "Express Flash PM1725a 800GB SFF(0x1028-0x1FD9)"},
{0x144D, 0xA822, 0x1028, 0x1FDA, "Express Flash PM1725a 1.6TB SFF(0x1028-0x1FDA)"},
{0x144D, 0xA822, 0x1028, 0x1FDB, "Express Flash PM1725a 3.2TB SFF(0x1028-0x1FDB)"},
{0x144D, 0xA822, 0x1028, 0x1FDC, "Express Flash PM1725a 6.4TB SFF(0x1028-0x1FDC)"},
{0x144D, 0xA822, 0x1028, 0x1FDD, "Express Flash PM1725a 1.6TB AIC(0x1028-0x1FDD)"},
{0x144D, 0xA822, 0x1028, 0x1FDE, "Express Flash PM1725a 3.2TB AIC(0x1028-0x1FDE)"},
{0x144D, 0xA822, 0x1028, 0x1FDF, "Express Flash PM1725a 6.4TB AIC(0x1028-0x1FDF)"},
{0x144D, 0xA822, 0x1028, 0x1FF3, "Express Flash PM1725b 1.6TB SFF(0x1028-0x1FF3)"},
{0x144D, 0xA822, 0x1028, 0x1FF4, "Express Flash PM1725b 3.2TB SFF(0x1028-0x1FF4)"},
{0x144D, 0xA822, 0x1028, 0x1FF5, "Express Flash PM1725b 6.4TB SFF(0x1028-0x1FF5)"},
{0x144D, 0xA822, 0x1028, 0x1FF6, "Express Flash PM1725b 12.8TB SFF(0x1028-0x1FF6)"},
{0x144D, 0xA822, 0x1028, 0x1FF7, "Express Flash PM1725b 1.6TB AIC(0x1028-0x1FF7)"},
{0x144D, 0xA822, 0x1028, 0x1FF8, "Express Flash PM1725b 3.2TB AIC(0x1028-0x1FF8)"},
{0x144D, 0xA822, 0x1028, 0x1FF9, "Express Flash PM1725b 6.4TB AIC(0x1028-0x1FF9)"},
{0x144D, 0xA822, 0x1028, 0x1FFA, "Express Flash PM1725b 12.8TB AIC(0x1028-0x1FFA)"},
{0x144D, 0xA824, 0xFFFF, 0xFFFF, "NVMe SSD Controller PM173X(0xA824)"},
{0x144D, 0xA824, 0x1028, 0x2040, "EMC PowerEdge Express Flash Ent NVMe AGN MU U.2 Gen4 1.6TB(0x1028-0x2040)"},
{0x144D, 0xA824, 0x1028, 0x2041, "EMC PowerEdge Express Flash Ent NVMe AGN MU U.2 Gen4 3.2TB(0x1028-0x2041)"},
{0x144D, 0xA824, 0x1028, 0x2042, "EMC PowerEdge Express Flash Ent NVMe AGN MU U.2 Gen4 6.4TB(0x1028-0x2042)"},
{0x144D, 0xA824, 0x1028, 0x2043, "EMC PowerEdge Express Flash Ent NVMe AGN MU U.2 Gen4 12.8TB(0x1028-0x2043)"},
{0x144D, 0xA824, 0x1028, 0x2044, "EMC PowerEdge Express Flash Ent NVMe AGN MU AIC Gen4 1.6TB(0x1028-0x2044)"},
{0x144D, 0xA824, 0x1028, 0x2045, "EMC PowerEdge Express Flash Ent NVMe AGN MU AIC Gen4 3.2TB(0x1028-0x2045)"},
{0x144D, 0xA824, 0x1028, 0x2046, "EMC PowerEdge Express Flash Ent NVMe AGN MU AIC Gen4 6.4TB(0x1028-0x2046)"},
{0x144D, 0xA824, 0x1028, 0x2070, "EMC PowerEdge Express Flash Ent NVMe AGN RI U.2 Gen4 1.92TB(0x1028-0x2070)"},
{0x144D, 0xA824, 0x1028, 0x2071, "EMC PowerEdge Express Flash Ent NVMe AGN RI U.2 Gen4 3.84TB(0x1028-0x2071)"},
{0x144D, 0xA824, 0x1028, 0x2072, "EMC PowerEdge Express Flash Ent NVMe AGN RI U.2 Gen4 7.68TB(0x1028-0x2072)"},
{0x144D, 0xA824, 0x1028, 0x2073, "EMC PowerEdge Express Flash Ent NVMe AGN RI U.2 Gen4 15.36TB(0x1028-0x2073)"},
{0x144D, 0xA824, 0x1028, 0x2074, "EMC PowerEdge Express Flash Ent NVMe AGN RI AIC Gen4 1.92TB(0x1028-0x2074)"},
{0x144D, 0xA824, 0x1028, 0x2075, "EMC PowerEdge Express Flash Ent NVMe AGN RI AIC Gen4 3.84TB(0x1028-0x2075)"},
{0x144D, 0xA824, 0x1028, 0x2076, "EMC PowerEdge Express Flash Ent NVMe AGN RI AIC Gen4 7.68TB(0x1028-0x2076)"},
{0x144D, 0xA824, 0x1028, 0x2090, "EMC PowerEdge Express Flash Ent NVMe AGN SED MU U.2 Gen4 1.6TB(0x1028-0x2090)"},
{0x144D, 0xA824, 0x1028, 0x2091, "EMC PowerEdge Express Flash Ent NVMe AGN SED MU U.2 Gen4 3.2TB(0x1028-0x2091)"},
{0x144D, 0xA824, 0x1028, 0x2092, "EMC PowerEdge Express Flash Ent NVMe AGN SED MU U.2 Gen4 6.4TB(0x1028-0x2092)"},
{0x144D, 0xA824, 0x1028, 0x2093, "EMC PowerEdge Express Flash Ent NVMe AGN SED MU U.2 Gen4 12.8TB(0x1028-0x2093)"},
{0x144D, 0xA824, 0x1028, 0x2094, "EMC PowerEdge Express Flash Ent NVMe AGN SED MU AIC Gen4 1.6TB(0x1028-0x2094)"},
{0x144D, 0xA824, 0x1028, 0x2095, "EMC PowerEdge Express Flash Ent NVMe AGN SED MU AIC Gen4 3.2TB(0x1028-0x2095)"},
{0x144D, 0xA824, 0x1028, 0x2096, "EMC PowerEdge Express Flash Ent NVMe AGN SED MU AIC Gen4 6.4TB(0x1028-0x2096)"},
{0x144D, 0xA824, 0x1028, 0x2097, "EMC PowerEdge Express Flash Ent NVMe AGN SED RI U.2 Gen4 1.92TB(0x1028-0x2097)"},
{0x144D, 0xA824, 0x1028, 0x2098, "EMC PowerEdge Express Flash Ent NVMe AGN SED RI U.2 Gen4 3.84TB(0x1028-0x2098)"},
{0x144D, 0xA824, 0x1028, 0x2099, "EMC PowerEdge Express Flash Ent NVMe AGN SED RI U.2 Gen4 7.68TB(0x1028-0x2099)"},
{0x144D, 0xA824, 0x1028, 0x2118, "Ent NVMe v2 AGN FIPS MU U.2 1.6TB(0x1028-0x2118)"},
{0x144D, 0xA824, 0x1028, 0x2119, "Ent NVMe v2 AGN MU U.2 1.6TB(0x1028-0x2119)"},
{0x144D, 0xA824, 0x1028, 0x2120, "Ent NVMe v2 AGN FIPS MU U.2 3.2T(0x1028-0x2120)"},
{0x144D, 0xA824, 0x1028, 0x2121, "Ent NVMe v2 AGN MU U.2 3.2TB(0x1028-0x2121)"},
{0x144D, 0xA824, 0x1028, 0x2122, "Ent NVMe v2 AGN FIPS MU U.2 6.4TB(0x1028-0x2122)"},
{0x144D, 0xA824, 0x1028, 0x2123, "Ent NVMe v2 AGN MU U.2 6.4TB(0x1028-0x2123)"},
{0x144D, 0xA824, 0x1028, 0x2124, "Ent NVMe v2 AGN FIPS MU U.2 6.4TB(0x1028-0x2124)"},
{0x144D, 0xA824, 0x1028, 0x2125, "Ent NVMe v2 AGN MU U.2 12.8TB(0x1028-0x2125)"},
{0x144D, 0xA824, 0x1028, 0x2126, "Ent NVMe v2 AGN FIPS RI U.2 1.92TB(0x1028-0x2126)"},
{0x144D, 0xA824, 0x1028, 0x2127, "Ent NVMe v2 AGN RI U.2 1.92TB(0x1028-0x2127)"},
{0x144D, 0xA824, 0x1028, 0x2128, "Ent NVMe v2 AGN FIPS RI U.2 3.84TB(0x1028-0x2128)"},
{0x144D, 0xA824, 0x1028, 0x2129, "Ent NVMe v2 AGN RI U.2 3.84TB(0x1028-0x2129)"},
{0x144D, 0xA824, 0x1028, 0x2130, "Ent NVMe v2 AGN FIPS RI U.2 7.68TB(0x1028-0x2130)"},
{0x144D, 0xA824, 0x1028, 0x2131, "Ent NVMe v2 AGN RI U.2 7.68TB(0x1028-0x2131)"},
{0x144D, 0xA824, 0x1028, 0x2132, "Ent NVMe v2 AGN FIPS RI U.2 15.36TB(0x1028-0x2132)"},
{0x144D, 0xA824, 0x1028, 0x2133, "Ent NVMe v2 AGN RI U.2 15.36TB(0x1028-0x2133)"},
{0x144D, 0xA825, 0xFFFF, 0xFFFF, "NVMe SSD Controller PM173Xa(0xA825)"},
{0x144D, 0xA825, 0x1028, 0x2178, "Ent NVMe FIPS PM1733a RI 1.92TB(0x1028-0x2178)"},
{0x144D, 0xA825, 0x1028, 0x2179, "Ent NVMe PM1733a RI 1.92TB(0x1028-0x2179)"},
{0x144D, 0xA825, 0x1028, 0x217A, "Ent NVMe FIPS PM1733a RI 3.84TB(0x1028-0x217A)"},
{0x144D, 0xA825, 0x1028, 0x217B, "Ent NVMe PM1733a RI 3.84TB(0x1028-0x217B)"},
{0x144D, 0xA825, 0x1028, 0x217C, "Ent NVMe FIPS PM1733a RI 7.68TB(0x1028-0x217C)"},
{0x144D, 0xA825, 0x1028, 0x217D, "Ent NVMe PM1733a RI 7.68TB(0x1028-0x217D)"},
{0x144D, 0xA825, 0x1028, 0x217E, "Ent NVMe FIPS PM1733a RI 15.36TB(0x1028-0x217E)"},
{0x144D, 0xA825, 0x1028, 0x217F, "Ent NVMe PM1733a RI 15.36TB(0x1028-0x217F)"},
{0x144D, 0xA825, 0x1028, 0x2180, "Ent NVMe FIPS PM1735a MU 1.6TB(0x1028-0x2180)"},
{0x144D, 0xA825, 0x1028, 0x2181, "Ent NVMe PM1735a MU 1.6TB(0x1028-0x2181)"},
{0x144D, 0xA825, 0x1028, 0x2182, "Ent NVMe FIPS PM1735a MU 3.2TB(0x1028-0x2182)"},
{0x144D, 0xA825, 0x1028, 0x2183, "Ent NVMe PM1735a MU 3.2TB(0x1028-0x2183)"},
{0x144D, 0xA825, 0x1028, 0x2184, "Ent NVMe FIPS PM1735a MU 6.4TB(0x1028-0x2184)"},
{0x144D, 0xA825, 0x1028, 0x2185, "Ent NVMe PM1735a MU 6.4TB(0x1028-0x2185)"},
{0x144D, 0xA825, 0x1028, 0x2186, "Ent NVMe FIPS PM1735a MU 12.8TB(0x1028-0x2186)"},
{0x144D, 0xA825, 0x1028, 0x2187, "Ent NVMe PM1735a MU 12.8TB(0x1028-0x2187)"},
{0x144D, 0xA825, 0x1028, 0x226A, "Ent NVMe FIPS PM1733a RI 30.72TB(0x1028-0x226A)"},
{0x144D, 0xA826, 0xFFFF, 0xFFFF, "NVMe SSD Controller PM174X(0xA826)"},
{0x144D, 0xA826, 0x1028, 0x2214, "NVMe PM1743 RI E3.S 1.92TB(0x1028-0x2214)"},
{0x144D, 0xA826, 0x1028, 0x2216, "NVMe PM1743 RI E3.S 3.84TB(0x1028-0x2216)"},
{0x144D, 0xA826, 0x1028, 0x2218, "NVMe PM1743 RI E3.S 7.68TB(0x1028-0x2218)"},
{0x144D, 0xA826, 0x1028, 0x221A, "NVMe PM1743 RI E3.S 15.36TB(0x1028-0x221A)"},
{0x144D, 0xA826, 0x1028, 0x221C, "NVMe PM1745 MU E3.S 1.6TB(0x1028-0x221C)"},
{0x144D, 0xA826, 0x1028, 0x221E, "NVMe PM1745 MU E3.S 3.2TB(0x1028-0x221E)"},
{0x144D, 0xA826, 0x1028, 0x2220, "NVMe PM1745 MU E3.S 6.4TB(0x1028-0x2220)"},
{0x144D, 0xA826, 0x1028, 0x2222, "NVMe PM1745 MU E3.S 12.8TB(0x1028-0x2222)"},
{0x144D, 0xA826, 0x1028, 0x224E, "NVMe FIPS PM1743 RI U.2 1.92TB(0x1028-0x224E)"},
{0x144D, 0xA826, 0x1028, 0x224F, "NVMe PM1743 RI U.2 1.92TB(0x1028-0x224F)"},
{0x144D, 0xA826, 0x1028, 0x2250, "NVMe FIPS PM1743 RI U.2 3.84TB(0x1028-0x2250)"},
{0x144D, 0xA826, 0x1028, 0x2251, "NVMe PM1743 RI U.2 3.84TB(0x1028-0x2251)"},
{0x144D, 0xA826, 0x1028, 0x2252, "NVMe FIPS PM1743 RI U.2 7.68TB(0x1028-0x2252)"},
{0x144D, 0xA826, 0x1028, 0x2253, "NVMe PM1743 RI U.2 7.68TB(0x1028-0x2253)"},
{0x144D, 0xA826, 0x1028, 0x2254, "NVMe FIPS PM1743 RI U.2 15.36TB(0x1028-0x2254)"},
{0x144D, 0xA826, 0x1028, 0x2255, "NVMe PM1743 RI U.2 15.36TB(0x1028-0x2255)"},
{0x144D, 0xA826, 0x1028, 0x2258, "NVMe FIPS PM1745 MU U.2 1.6TB(0x1028-0x2258)"},
{0x144D, 0xA826, 0x1028, 0x2259, "NVMe PM1745 MU U.2 1.6TB(0x1028-0x2259)"},
{0x144D, 0xA826, 0x1028, 0x225A, "NVMe FIPS PM1745 MU U.2 3.2TB(0x1028-0x225A)"},
{0x144D, 0xA826, 0x1028, 0x225B, "NVMe PM1745 MU U.2 3.2TB(0x1028-0x225B)"},
{0x144D, 0xA826, 0x1028, 0x225C, "NVMe FIPS PM1745 MU U.2 6.4TB(0x1028-0x225C)"},
{0x144D, 0xA826, 0x1028, 0x225D, "NVMe PM1745 MU U.2 6.4TB(0x1028-0x225D)"},
{0x144D, 0xA826, 0x1028, 0x225E, "NVMe FIPS PM1745 MU U.2 12.8TB(0x1028-0x225E)"},
{0x144D, 0xA826, 0x1028, 0x225F, "NVMe PM1745 MU U.2 12.8TB(0x1028-0x225F)"},
{0x144D, 0xA900, 0xFFFF, 0xFFFF, "NVMe SSD Controller PM9DXa(0xA900)"},
{0x144D, 0xECEC, 0xFFFF, 0xFFFF, "Exynos 8895 PCIe Root Complex(0xECEC)"},
}; /* pci_vid_144D[] */

static pci_id_t const pci_vid_144E[] = {
{0x144E, 0xFFFF, 0xFFFF, 0xFFFF, "OLITEC(0x144E)"},
}; /* pci_vid_144E[] */

static pci_id_t const pci_vid_144F[] = {
{0x144F, 0xFFFF, 0xFFFF, 0xFFFF, "Askey Computer Corp.(0x144F)"},
}; /* pci_vid_144F[] */

static pci_id_t const pci_vid_1450[] = {
{0x1450, 0xFFFF, 0xFFFF, 0xFFFF, "Octave Communications Ind.(0x1450)"},
}; /* pci_vid_1450[] */

static pci_id_t const pci_vid_1451[] = {
{0x1451, 0xFFFF, 0xFFFF, 0xFFFF, "SP3D Chip Design GmBH(0x1451)"},
}; /* pci_vid_1451[] */

static pci_id_t const pci_vid_1453[] = {
{0x1453, 0xFFFF, 0xFFFF, 0xFFFF, "MYCOM Inc(0x1453)"},
}; /* pci_vid_1453[] */

static pci_id_t const pci_vid_1454[] = {
{0x1454, 0xFFFF, 0xFFFF, 0xFFFF, "Altiga Networks(0x1454)"},
}; /* pci_vid_1454[] */

static pci_id_t const pci_vid_1455[] = {
{0x1455, 0xFFFF, 0xFFFF, 0xFFFF, "Logic Plus Plus Inc(0x1455)"},
}; /* pci_vid_1455[] */

static pci_id_t const pci_vid_1456[] = {
{0x1456, 0xFFFF, 0xFFFF, 0xFFFF, "Advanced Hardware Architectures(0x1456)"},
}; /* pci_vid_1456[] */

static pci_id_t const pci_vid_1457[] = {
{0x1457, 0xFFFF, 0xFFFF, 0xFFFF, "Nuera Communications Inc(0x1457)"},
}; /* pci_vid_1457[] */

static pci_id_t const pci_vid_1458[] = {
{0x1458, 0xFFFF, 0xFFFF, 0xFFFF, "Gigabyte Technology Co., Ltd(0x1458)"},
{0x1458, 0x1002, 0xFFFF, 0xFFFF, "Aourus Radeon RX6900XT Xtreme Waterforce WB 16G(0x1002)"},
{0x1458, 0x22E8, 0xFFFF, 0xFFFF, "Ellesmere [Radeon RX 480](0x22E8)"},
{0x1458, 0x3483, 0xFFFF, 0xFFFF, "USB 3.0 Controller (VIA VL80x-based xHCI Controller)(0x3483)"},
}; /* pci_vid_1458[] */

static pci_id_t const pci_vid_1459[] = {
{0x1459, 0xFFFF, 0xFFFF, 0xFFFF, "DOOIN Electronics(0x1459)"},
}; /* pci_vid_1459[] */

static pci_id_t const pci_vid_145A[] = {
{0x145A, 0xFFFF, 0xFFFF, 0xFFFF, "Escalate Networks Inc(0x145A)"},
}; /* pci_vid_145A[] */

static pci_id_t const pci_vid_145B[] = {
{0x145B, 0xFFFF, 0xFFFF, 0xFFFF, "PRAIM SRL(0x145B)"},
}; /* pci_vid_145B[] */

static pci_id_t const pci_vid_145C[] = {
{0x145C, 0xFFFF, 0xFFFF, 0xFFFF, "Cryptek(0x145C)"},
}; /* pci_vid_145C[] */

static pci_id_t const pci_vid_145D[] = {
{0x145D, 0xFFFF, 0xFFFF, 0xFFFF, "Gallant Computer Inc(0x145D)"},
}; /* pci_vid_145D[] */

static pci_id_t const pci_vid_145E[] = {
{0x145E, 0xFFFF, 0xFFFF, 0xFFFF, "Aashima Technology B.V.(0x145E)"},
}; /* pci_vid_145E[] */

static pci_id_t const pci_vid_145F[] = {
{0x145F, 0xFFFF, 0xFFFF, 0xFFFF, "Baldor Electric Company(0x145F)"},
{0x145F, 0x0001, 0xFFFF, 0xFFFF, "NextMove PCI(0x0001)"},
}; /* pci_vid_145F[] */

static pci_id_t const pci_vid_1460[] = {
{0x1460, 0xFFFF, 0xFFFF, 0xFFFF, "DYNARC INC(0x1460)"},
}; /* pci_vid_1460[] */

static pci_id_t const pci_vid_1461[] = {
{0x1461, 0xFFFF, 0xFFFF, 0xFFFF, "Avermedia Technologies Inc(0x1461)"},
{0x1461, 0xA3CE, 0xFFFF, 0xFFFF, "M179(0xA3CE)"},
{0x1461, 0xA3CF, 0xFFFF, 0xFFFF, "M179(0xA3CF)"},
{0x1461, 0xA836, 0xFFFF, 0xFFFF, "M115 DVB-T, PAL/SECAM/NTSC Tuner(0xA836)"},
{0x1461, 0xE836, 0xFFFF, 0xFFFF, "M115S Hybrid Analog/DVB PAL/SECAM/NTSC Tuner(0xE836)"},
{0x1461, 0xF436, 0xFFFF, 0xFFFF, "AVerTV Hybrid+FM(0xF436)"},
}; /* pci_vid_1461[] */

static pci_id_t const pci_vid_1462[] = {
{0x1462, 0xFFFF, 0xFFFF, 0xFFFF, "Micro-Star International Co., Ltd. [MSI](0x1462)"},
{0x1462, 0x3483, 0xFFFF, 0xFFFF, "MSI USB 3.0 (VIA VL80x-based xHCI USB Controller)(0x3483)"},
{0x1462, 0x7C56, 0xFFFF, 0xFFFF, "Realtek Ethernet controller RTL8111H(0x7C56)"},
{0x1462, 0xAAF0, 0xFFFF, 0xFFFF, "Radeon RX 580 Gaming X 8G(0xAAF0)"},
}; /* pci_vid_1462[] */

static pci_id_t const pci_vid_1463[] = {
{0x1463, 0xFFFF, 0xFFFF, 0xFFFF, "Fast Corporation(0x1463)"},
}; /* pci_vid_1463[] */

static pci_id_t const pci_vid_1464[] = {
{0x1464, 0xFFFF, 0xFFFF, 0xFFFF, "Interactive Circuits & Systems Ltd(0x1464)"},
}; /* pci_vid_1464[] */

static pci_id_t const pci_vid_1465[] = {
{0x1465, 0xFFFF, 0xFFFF, 0xFFFF, "GN NETTEST Telecom DIV.(0x1465)"},
}; /* pci_vid_1465[] */

static pci_id_t const pci_vid_1466[] = {
{0x1466, 0xFFFF, 0xFFFF, 0xFFFF, "Designpro Inc.(0x1466)"},
}; /* pci_vid_1466[] */

static pci_id_t const pci_vid_1467[] = {
{0x1467, 0xFFFF, 0xFFFF, 0xFFFF, "DIGICOM SPA(0x1467)"},
}; /* pci_vid_1467[] */

static pci_id_t const pci_vid_1468[] = {
{0x1468, 0xFFFF, 0xFFFF, 0xFFFF, "AMBIT Microsystem Corp.(0x1468)"},
}; /* pci_vid_1468[] */

static pci_id_t const pci_vid_1469[] = {
{0x1469, 0xFFFF, 0xFFFF, 0xFFFF, "Cleveland Motion Controls(0x1469)"},
}; /* pci_vid_1469[] */

static pci_id_t const pci_vid_146A[] = {
{0x146A, 0xFFFF, 0xFFFF, 0xFFFF, "Aeroflex(0x146A)"},
{0x146A, 0x3010, 0xFFFF, 0xFFFF, "3010 RF Synthesizer(0x3010)"},
{0x146A, 0x3A11, 0xFFFF, 0xFFFF, "3011A PXI RF Synthesizer(0x3A11)"},
}; /* pci_vid_146A[] */

static pci_id_t const pci_vid_146B[] = {
{0x146B, 0xFFFF, 0xFFFF, 0xFFFF, "Parascan Technologies Ltd(0x146B)"},
}; /* pci_vid_146B[] */

static pci_id_t const pci_vid_146C[] = {
{0x146C, 0xFFFF, 0xFFFF, 0xFFFF, "Ruby Tech Corp.(0x146C)"},
{0x146C, 0x1430, 0xFFFF, 0xFFFF, "FE-1430TX Fast Ethernet PCI Adapter(0x1430)"},
}; /* pci_vid_146C[] */

static pci_id_t const pci_vid_146D[] = {
{0x146D, 0xFFFF, 0xFFFF, 0xFFFF, "Tachyon, INC.(0x146D)"},
}; /* pci_vid_146D[] */

static pci_id_t const pci_vid_146E[] = {
{0x146E, 0xFFFF, 0xFFFF, 0xFFFF, "Williams Electronics Games, Inc.(0x146E)"},
}; /* pci_vid_146E[] */

static pci_id_t const pci_vid_146F[] = {
{0x146F, 0xFFFF, 0xFFFF, 0xFFFF, "Multi Dimensional Consulting Inc(0x146F)"},
}; /* pci_vid_146F[] */

static pci_id_t const pci_vid_1470[] = {
{0x1470, 0xFFFF, 0xFFFF, 0xFFFF, "Bay Networks(0x1470)"},
}; /* pci_vid_1470[] */

static pci_id_t const pci_vid_1471[] = {
{0x1471, 0xFFFF, 0xFFFF, 0xFFFF, "Integrated Telecom Express Inc(0x1471)"},
}; /* pci_vid_1471[] */

static pci_id_t const pci_vid_1472[] = {
{0x1472, 0xFFFF, 0xFFFF, 0xFFFF, "DAIKIN Industries, Ltd(0x1472)"},
}; /* pci_vid_1472[] */

static pci_id_t const pci_vid_1473[] = {
{0x1473, 0xFFFF, 0xFFFF, 0xFFFF, "ZAPEX Technologies Inc(0x1473)"},
}; /* pci_vid_1473[] */

static pci_id_t const pci_vid_1474[] = {
{0x1474, 0xFFFF, 0xFFFF, 0xFFFF, "Doug Carson & Associates(0x1474)"},
}; /* pci_vid_1474[] */

static pci_id_t const pci_vid_1475[] = {
{0x1475, 0xFFFF, 0xFFFF, 0xFFFF, "PICAZO Communications(0x1475)"},
}; /* pci_vid_1475[] */

static pci_id_t const pci_vid_1476[] = {
{0x1476, 0xFFFF, 0xFFFF, 0xFFFF, "MORTARA Instrument Inc(0x1476)"},
}; /* pci_vid_1476[] */

static pci_id_t const pci_vid_1477[] = {
{0x1477, 0xFFFF, 0xFFFF, 0xFFFF, "Net Insight(0x1477)"},
}; /* pci_vid_1477[] */

static pci_id_t const pci_vid_1478[] = {
{0x1478, 0xFFFF, 0xFFFF, 0xFFFF, "DIATREND Corporation(0x1478)"},
}; /* pci_vid_1478[] */

static pci_id_t const pci_vid_1479[] = {
{0x1479, 0xFFFF, 0xFFFF, 0xFFFF, "TORAY Industries Inc(0x1479)"},
}; /* pci_vid_1479[] */

static pci_id_t const pci_vid_147A[] = {
{0x147A, 0xFFFF, 0xFFFF, 0xFFFF, "FORMOSA Industrial Computing(0x147A)"},
}; /* pci_vid_147A[] */

static pci_id_t const pci_vid_147B[] = {
{0x147B, 0xFFFF, 0xFFFF, 0xFFFF, "ABIT Computer Corp.(0x147B)"},
{0x147B, 0x1084, 0xFFFF, 0xFFFF, "IP35 [Dark Raider](0x1084)"},
}; /* pci_vid_147B[] */

static pci_id_t const pci_vid_147C[] = {
{0x147C, 0xFFFF, 0xFFFF, 0xFFFF, "AWARE, Inc.(0x147C)"},
}; /* pci_vid_147C[] */

static pci_id_t const pci_vid_147D[] = {
{0x147D, 0xFFFF, 0xFFFF, 0xFFFF, "Interworks Computer Products(0x147D)"},
}; /* pci_vid_147D[] */

static pci_id_t const pci_vid_147E[] = {
{0x147E, 0xFFFF, 0xFFFF, 0xFFFF, "Matsushita Graphic Communication Systems, Inc.(0x147E)"},
}; /* pci_vid_147E[] */

static pci_id_t const pci_vid_147F[] = {
{0x147F, 0xFFFF, 0xFFFF, 0xFFFF, "NIHON UNISYS, Ltd.(0x147F)"},
}; /* pci_vid_147F[] */

static pci_id_t const pci_vid_1480[] = {
{0x1480, 0xFFFF, 0xFFFF, 0xFFFF, "SCII Telecom(0x1480)"},
}; /* pci_vid_1480[] */

static pci_id_t const pci_vid_1481[] = {
{0x1481, 0xFFFF, 0xFFFF, 0xFFFF, "BIOPAC Systems Inc(0x1481)"},
}; /* pci_vid_1481[] */

static pci_id_t const pci_vid_1482[] = {
{0x1482, 0xFFFF, 0xFFFF, 0xFFFF, "ISYTEC - Integrierte Systemtechnik GmBH(0x1482)"},
{0x1482, 0x0001, 0xFFFF, 0xFFFF, "PCI-16 Host Interface for ITC-16(0x0001)"},
}; /* pci_vid_1482[] */

static pci_id_t const pci_vid_1483[] = {
{0x1483, 0xFFFF, 0xFFFF, 0xFFFF, "LABWAY Corporation(0x1483)"},
}; /* pci_vid_1483[] */

static pci_id_t const pci_vid_1484[] = {
{0x1484, 0xFFFF, 0xFFFF, 0xFFFF, "Logic Corporation(0x1484)"},
}; /* pci_vid_1484[] */

static pci_id_t const pci_vid_1485[] = {
{0x1485, 0xFFFF, 0xFFFF, 0xFFFF, "ERMA - Electronic GmBH(0x1485)"},
}; /* pci_vid_1485[] */

static pci_id_t const pci_vid_1486[] = {
{0x1486, 0xFFFF, 0xFFFF, 0xFFFF, "L3 Communications Telemetry & Instrumentation(0x1486)"},
}; /* pci_vid_1486[] */

static pci_id_t const pci_vid_1487[] = {
{0x1487, 0xFFFF, 0xFFFF, 0xFFFF, "MARQUETTE Medical Systems(0x1487)"},
}; /* pci_vid_1487[] */

static pci_id_t const pci_vid_1489[] = {
{0x1489, 0xFFFF, 0xFFFF, 0xFFFF, "KYE Systems Corporation(0x1489)"},
}; /* pci_vid_1489[] */

static pci_id_t const pci_vid_148A[] = {
{0x148A, 0xFFFF, 0xFFFF, 0xFFFF, "OPTO(0x148A)"},
}; /* pci_vid_148A[] */

static pci_id_t const pci_vid_148B[] = {
{0x148B, 0xFFFF, 0xFFFF, 0xFFFF, "INNOMEDIALOGIC Inc.(0x148B)"},
}; /* pci_vid_148B[] */

static pci_id_t const pci_vid_148C[] = {
{0x148C, 0xFFFF, 0xFFFF, 0xFFFF, "Tul Corporation / PowerColor(0x148C)"},
{0x148C, 0x2391, 0xFFFF, 0xFFFF, "Radeon RX 590 [Red Devil](0x2391)"},
{0x148C, 0x2398, 0xFFFF, 0xFFFF, "AXRX 5700 XT 8GBD6-3DHE/OC [PowerColor Red Devil Radeon RX 5700 XT](0x2398)"},
}; /* pci_vid_148C[] */

static pci_id_t const pci_vid_148D[] = {
{0x148D, 0xFFFF, 0xFFFF, 0xFFFF, "DIGICOM Systems, Inc.(0x148D)"},
{0x148D, 0x1003, 0xFFFF, 0xFFFF, "HCF 56k Data/Fax Modem(0x1003)"},
}; /* pci_vid_148D[] */

static pci_id_t const pci_vid_148E[] = {
{0x148E, 0xFFFF, 0xFFFF, 0xFFFF, "OSI Plus Corporation(0x148E)"},
}; /* pci_vid_148E[] */

static pci_id_t const pci_vid_148F[] = {
{0x148F, 0xFFFF, 0xFFFF, 0xFFFF, "Plant Equipment, Inc.(0x148F)"},
}; /* pci_vid_148F[] */

static pci_id_t const pci_vid_1490[] = {
{0x1490, 0xFFFF, 0xFFFF, 0xFFFF, "Stone Microsystems PTY Ltd.(0x1490)"},
}; /* pci_vid_1490[] */

static pci_id_t const pci_vid_1491[] = {
{0x1491, 0xFFFF, 0xFFFF, 0xFFFF, "ZEAL Corporation(0x1491)"},
}; /* pci_vid_1491[] */

static pci_id_t const pci_vid_1492[] = {
{0x1492, 0xFFFF, 0xFFFF, 0xFFFF, "Time Logic Corporation(0x1492)"},
}; /* pci_vid_1492[] */

static pci_id_t const pci_vid_1493[] = {
{0x1493, 0xFFFF, 0xFFFF, 0xFFFF, "MAKER Communications(0x1493)"},
}; /* pci_vid_1493[] */

static pci_id_t const pci_vid_1494[] = {
{0x1494, 0xFFFF, 0xFFFF, 0xFFFF, "WINTOP Technology, Inc.(0x1494)"},
}; /* pci_vid_1494[] */

static pci_id_t const pci_vid_1495[] = {
{0x1495, 0xFFFF, 0xFFFF, 0xFFFF, "TOKAI Communications Industry Co. Ltd(0x1495)"},
}; /* pci_vid_1495[] */

static pci_id_t const pci_vid_1496[] = {
{0x1496, 0xFFFF, 0xFFFF, 0xFFFF, "JOYTECH Computer Co., Ltd.(0x1496)"},
}; /* pci_vid_1496[] */

static pci_id_t const pci_vid_1497[] = {
{0x1497, 0xFFFF, 0xFFFF, 0xFFFF, "SMA Regelsysteme GmBH(0x1497)"},
{0x1497, 0x1497, 0xFFFF, 0xFFFF, "SMA Technologie AG(0x1497)"},
}; /* pci_vid_1497[] */

static pci_id_t const pci_vid_1498[] = {
{0x1498, 0xFFFF, 0xFFFF, 0xFFFF, "TEWS Technologies GmbH(0x1498)"},
{0x1498, 0x0330, 0xFFFF, 0xFFFF, "TPMC816 2 Channel CAN bus controller.(0x0330)"},
{0x1498, 0x035D, 0xFFFF, 0xFFFF, "TPMC861 4-Channel Isolated Serial Interface RS422/RS485(0x035D)"},
{0x1498, 0x0385, 0xFFFF, 0xFFFF, "TPMC901 Extended CAN bus with 2/4/6 CAN controller(0x0385)"},
{0x1498, 0x21CC, 0xFFFF, 0xFFFF, "TCP460 CompactPCI 16 Channel Serial Interface RS232/RS422(0x21CC)"},
{0x1498, 0x21CD, 0xFFFF, 0xFFFF, "TCP461 CompactPCI 8 Channel Serial Interface RS232/RS422(0x21CD)"},
{0x1498, 0x3064, 0xFFFF, 0xFFFF, "TPCI100 (2 Slot IndustryPack PCI Carrier)(0x3064)"},
{0x1498, 0x30C8, 0xFFFF, 0xFFFF, "TPCI200 4 Slot IndustryPack PCI Carrier(0x30C8)"},
{0x1498, 0x70C8, 0xFFFF, 0xFFFF, "TPCE200 4 Slot IndustryPack PCIe Carrier(0x70C8)"},
{0x1498, 0x9177, 0xFFFF, 0xFFFF, "TXMC375 8 channel RS232/RS422/RS485 programmable serial interface(0x9177)"},
}; /* pci_vid_1498[] */

static pci_id_t const pci_vid_1499[] = {
{0x1499, 0xFFFF, 0xFFFF, 0xFFFF, "EMTEC CO., Ltd(0x1499)"},
}; /* pci_vid_1499[] */

static pci_id_t const pci_vid_149A[] = {
{0x149A, 0xFFFF, 0xFFFF, 0xFFFF, "ANDOR Technology Ltd(0x149A)"},
}; /* pci_vid_149A[] */

static pci_id_t const pci_vid_149B[] = {
{0x149B, 0xFFFF, 0xFFFF, 0xFFFF, "SEIKO Instruments Inc(0x149B)"},
}; /* pci_vid_149B[] */

static pci_id_t const pci_vid_149C[] = {
{0x149C, 0xFFFF, 0xFFFF, 0xFFFF, "OVISLINK Corp.(0x149C)"},
}; /* pci_vid_149C[] */

static pci_id_t const pci_vid_149D[] = {
{0x149D, 0xFFFF, 0xFFFF, 0xFFFF, "NEWTEK Inc(0x149D)"},
{0x149D, 0x0001, 0xFFFF, 0xFFFF, "Video Toaster for PC(0x0001)"},
}; /* pci_vid_149D[] */

static pci_id_t const pci_vid_149E[] = {
{0x149E, 0xFFFF, 0xFFFF, 0xFFFF, "Mapletree Networks Inc.(0x149E)"},
}; /* pci_vid_149E[] */

static pci_id_t const pci_vid_149F[] = {
{0x149F, 0xFFFF, 0xFFFF, 0xFFFF, "LECTRON Co Ltd(0x149F)"},
}; /* pci_vid_149F[] */

static pci_id_t const pci_vid_14A0[] = {
{0x14A0, 0xFFFF, 0xFFFF, 0xFFFF, "SOFTING GmBH(0x14A0)"},
}; /* pci_vid_14A0[] */

static pci_id_t const pci_vid_14A1[] = {
{0x14A1, 0xFFFF, 0xFFFF, 0xFFFF, "Systembase Co Ltd(0x14A1)"},
{0x14A1, 0x4D02, 0xFFFF, 0xFFFF, "SB16C1052PCI [Multi-2/PCIe RS232](0x4D02)"},
}; /* pci_vid_14A1[] */

static pci_id_t const pci_vid_14A2[] = {
{0x14A2, 0xFFFF, 0xFFFF, 0xFFFF, "Millennium Engineering Inc(0x14A2)"},
}; /* pci_vid_14A2[] */

static pci_id_t const pci_vid_14A3[] = {
{0x14A3, 0xFFFF, 0xFFFF, 0xFFFF, "Maverick Networks(0x14A3)"},
}; /* pci_vid_14A3[] */

static pci_id_t const pci_vid_14A4[] = {
{0x14A4, 0xFFFF, 0xFFFF, 0xFFFF, "Lite-On Technology Corporation(0x14A4)"},
{0x14A4, 0x2100, 0xFFFF, 0xFFFF, "CA1-8D128 NVMe SSD(0x2100)"},
{0x14A4, 0x2200, 0xFFFF, 0xFFFF, "CX2-8B256, CX2-8B512 NVMe SSD(0x2200)"},
{0x14A4, 0x22A0, 0xFFFF, 0xFFFF, "EP2-KB960 NVMe SSD(0x22A0)"},
{0x14A4, 0x22F1, 0xFFFF, 0xFFFF, "M8Pe Series NVMe SSD(0x22F1)"},
{0x14A4, 0x2300, 0xFFFF, 0xFFFF, "CA3-8D256, CA3-8D512 NVMe SSD(0x2300)"},
{0x14A4, 0x23F1, 0xFFFF, 0xFFFF, "M9PeG, M9PeGN, M9PeY NVMe SSD(0x23F1)"},
{0x14A4, 0x2F00, 0xFFFF, 0xFFFF, "CAZ-82512 NVMe SSD(0x2F00)"},
{0x14A4, 0x3500, 0xFFFF, 0xFFFF, "CA5-8D512 NVMe SSD(0x3500)"},
{0x14A4, 0x4318, 0xFFFF, 0xFFFF, "Broadcom BCM4318 [AirForce One 54g] 802.11g WLAN Controller(0x4318)"},
{0x14A4, 0x5100, 0xFFFF, 0xFFFF, "CB1-SD256, CB1-SD512 NVMe SSD(0x5100)"},
{0x14A4, 0x9100, 0xFFFF, 0xFFFF, "CL1-3D256, CL1-8D512 NVMe SSD (DRAM-less)(0x9100)"},
}; /* pci_vid_14A4[] */

static pci_id_t const pci_vid_14A5[] = {
{0x14A5, 0xFFFF, 0xFFFF, 0xFFFF, "XIONICS Document Technologies Inc(0x14A5)"},
}; /* pci_vid_14A5[] */

static pci_id_t const pci_vid_14A6[] = {
{0x14A6, 0xFFFF, 0xFFFF, 0xFFFF, "INOVA Computers GmBH & Co KG(0x14A6)"},
}; /* pci_vid_14A6[] */

static pci_id_t const pci_vid_14A7[] = {
{0x14A7, 0xFFFF, 0xFFFF, 0xFFFF, "MYTHOS Systems Inc(0x14A7)"},
}; /* pci_vid_14A7[] */

static pci_id_t const pci_vid_14A8[] = {
{0x14A8, 0xFFFF, 0xFFFF, 0xFFFF, "FEATRON Technologies Corporation(0x14A8)"},
}; /* pci_vid_14A8[] */

static pci_id_t const pci_vid_14A9[] = {
{0x14A9, 0xFFFF, 0xFFFF, 0xFFFF, "HIVERTEC Inc(0x14A9)"},
}; /* pci_vid_14A9[] */

static pci_id_t const pci_vid_14AA[] = {
{0x14AA, 0xFFFF, 0xFFFF, 0xFFFF, "Advanced MOS Technology Inc(0x14AA)"},
}; /* pci_vid_14AA[] */

static pci_id_t const pci_vid_14AB[] = {
{0x14AB, 0xFFFF, 0xFFFF, 0xFFFF, "Siemens Industry Software Inc.(0x14AB)"},
}; /* pci_vid_14AB[] */

static pci_id_t const pci_vid_14AC[] = {
{0x14AC, 0xFFFF, 0xFFFF, 0xFFFF, "Novaweb Technologies Inc(0x14AC)"},
}; /* pci_vid_14AC[] */

static pci_id_t const pci_vid_14AD[] = {
{0x14AD, 0xFFFF, 0xFFFF, 0xFFFF, "Time Space Radio AB(0x14AD)"},
}; /* pci_vid_14AD[] */

static pci_id_t const pci_vid_14AE[] = {
{0x14AE, 0xFFFF, 0xFFFF, 0xFFFF, "CTI, Inc(0x14AE)"},
}; /* pci_vid_14AE[] */

static pci_id_t const pci_vid_14AF[] = {
{0x14AF, 0xFFFF, 0xFFFF, 0xFFFF, "Guillemot Corporation(0x14AF)"},
{0x14AF, 0x7102, 0xFFFF, 0xFFFF, "3D Prophet II MX(0x7102)"},
}; /* pci_vid_14AF[] */

static pci_id_t const pci_vid_14B0[] = {
{0x14B0, 0xFFFF, 0xFFFF, 0xFFFF, "BST Communication Technology Ltd(0x14B0)"},
}; /* pci_vid_14B0[] */

static pci_id_t const pci_vid_14B1[] = {
{0x14B1, 0xFFFF, 0xFFFF, 0xFFFF, "Nextcom K.K.(0x14B1)"},
}; /* pci_vid_14B1[] */

static pci_id_t const pci_vid_14B2[] = {
{0x14B2, 0xFFFF, 0xFFFF, 0xFFFF, "ENNOVATE Networks Inc(0x14B2)"},
}; /* pci_vid_14B2[] */

static pci_id_t const pci_vid_14B3[] = {
{0x14B3, 0xFFFF, 0xFFFF, 0xFFFF, "XPEED Inc(0x14B3)"},
{0x14B3, 0x0000, 0xFFFF, 0xFFFF, "DSL NIC(0x0000)"},
}; /* pci_vid_14B3[] */

static pci_id_t const pci_vid_14B4[] = {
{0x14B4, 0xFFFF, 0xFFFF, 0xFFFF, "PHILIPS Business Electronics B.V.(0x14B4)"},
}; /* pci_vid_14B4[] */

static pci_id_t const pci_vid_14B5[] = {
{0x14B5, 0xFFFF, 0xFFFF, 0xFFFF, "Creamware GmBH(0x14B5)"},
{0x14B5, 0x0200, 0xFFFF, 0xFFFF, "Scope(0x0200)"},
{0x14B5, 0x0300, 0xFFFF, 0xFFFF, "Pulsar(0x0300)"},
{0x14B5, 0x0400, 0xFFFF, 0xFFFF, "PulsarSRB(0x0400)"},
{0x14B5, 0x0600, 0xFFFF, 0xFFFF, "Pulsar2(0x0600)"},
{0x14B5, 0x0800, 0xFFFF, 0xFFFF, "DSP-Board(0x0800)"},
{0x14B5, 0x0900, 0xFFFF, 0xFFFF, "DSP-Board(0x0900)"},
{0x14B5, 0x0A00, 0xFFFF, 0xFFFF, "DSP-Board(0x0A00)"},
{0x14B5, 0x0B00, 0xFFFF, 0xFFFF, "DSP-Board(0x0B00)"},
}; /* pci_vid_14B5[] */

static pci_id_t const pci_vid_14B6[] = {
{0x14B6, 0xFFFF, 0xFFFF, 0xFFFF, "Quantum Data Corp.(0x14B6)"},
}; /* pci_vid_14B6[] */

static pci_id_t const pci_vid_14B7[] = {
{0x14B7, 0xFFFF, 0xFFFF, 0xFFFF, "PROXIM Inc(0x14B7)"},
{0x14B7, 0x0001, 0xFFFF, 0xFFFF, "Symphony 4110(0x0001)"},
}; /* pci_vid_14B7[] */

static pci_id_t const pci_vid_14B8[] = {
{0x14B8, 0xFFFF, 0xFFFF, 0xFFFF, "Techsoft Technology Co Ltd(0x14B8)"},
}; /* pci_vid_14B8[] */

static pci_id_t const pci_vid_14B9[] = {
{0x14B9, 0xFFFF, 0xFFFF, 0xFFFF, "Cisco Aironet Wireless Communications(0x14B9)"},
{0x14B9, 0x0001, 0xFFFF, 0xFFFF, "PC4800(0x0001)"},
{0x14B9, 0x0340, 0xFFFF, 0xFFFF, "PC4800(0x0340)"},
{0x14B9, 0x0350, 0xFFFF, 0xFFFF, "350 series 802.11b Wireless LAN Adapter(0x0350)"},
{0x14B9, 0x4500, 0xFFFF, 0xFFFF, "PC4500(0x4500)"},
{0x14B9, 0x4800, 0xFFFF, 0xFFFF, "Cisco Aironet 340 802.11b Wireless LAN Adapter/Aironet PC4800(0x4800)"},
{0x14B9, 0xA504, 0xFFFF, 0xFFFF, "Cisco Aironet Wireless 802.11b(0xA504)"},
{0x14B9, 0xA505, 0xFFFF, 0xFFFF, "Cisco Aironet CB20a 802.11a Wireless LAN Adapter(0xA505)"},
{0x14B9, 0xA506, 0xFFFF, 0xFFFF, "Cisco Aironet Mini PCI b/g(0xA506)"},
}; /* pci_vid_14B9[] */

static pci_id_t const pci_vid_14BA[] = {
{0x14BA, 0xFFFF, 0xFFFF, 0xFFFF, "INTERNIX Inc.(0x14BA)"},
{0x14BA, 0x0600, 0xFFFF, 0xFFFF, "ARC-PCI/22(0x0600)"},
}; /* pci_vid_14BA[] */

static pci_id_t const pci_vid_14BB[] = {
{0x14BB, 0xFFFF, 0xFFFF, 0xFFFF, "SEMTECH Corporation(0x14BB)"},
}; /* pci_vid_14BB[] */

static pci_id_t const pci_vid_14BC[] = {
{0x14BC, 0xFFFF, 0xFFFF, 0xFFFF, "Globespan Semiconductor Inc.(0x14BC)"},
{0x14BC, 0xD002, 0xFFFF, 0xFFFF, "Pulsar [PCI ADSL Card](0xD002)"},
{0x14BC, 0xD00F, 0xFFFF, 0xFFFF, "Pulsar [PCI ADSL Card](0xD00F)"},
}; /* pci_vid_14BC[] */

static pci_id_t const pci_vid_14BD[] = {
{0x14BD, 0xFFFF, 0xFFFF, 0xFFFF, "CARDIO Control N.V.(0x14BD)"},
}; /* pci_vid_14BD[] */

static pci_id_t const pci_vid_14BE[] = {
{0x14BE, 0xFFFF, 0xFFFF, 0xFFFF, "L3 Communications(0x14BE)"},
}; /* pci_vid_14BE[] */

static pci_id_t const pci_vid_14BF[] = {
{0x14BF, 0xFFFF, 0xFFFF, 0xFFFF, "SPIDER Communications Inc.(0x14BF)"},
}; /* pci_vid_14BF[] */

static pci_id_t const pci_vid_14C0[] = {
{0x14C0, 0xFFFF, 0xFFFF, 0xFFFF, "COMPAL Electronics Inc(0x14C0)"},
{0x14C0, 0x1201, 0xFFFF, 0xFFFF, "X550 10Gb 2P RJ45 OCP Mezz(0x1201)"},
}; /* pci_vid_14C0[] */

static pci_id_t const pci_vid_14C1[] = {
{0x14C1, 0xFFFF, 0xFFFF, 0xFFFF, "MYRICOM Inc.(0x14C1)"},
{0x14C1, 0x0008, 0xFFFF, 0xFFFF, "Myri-10G Dual-Protocol NIC(0x0008)"},
{0x14C1, 0x0008, 0x14C1, 0x0008, "10G-PCIE-8A(0x14C1-0x0008)"},
{0x14C1, 0x0008, 0x14C1, 0x0009, "10G-PCIE-8A (MSI-X firmware)(0x14C1-0x0009)"},
{0x14C1, 0x0008, 0x14C1, 0x000A, "10G-PCIE-8B(0x14C1-0x000A)"},
{0x14C1, 0x8043, 0xFFFF, 0xFFFF, "Myrinet 2000 Scalable Cluster Interconnect(0x8043)"},
{0x14C1, 0x8043, 0x103C, 0x1240, "Myrinet M2L-PCI64/2-3.0 LANai 7.4 (HP OEM)(0x103C-0x1240)"},
}; /* pci_vid_14C1[] */

static pci_id_t const pci_vid_14C2[] = {
{0x14C2, 0xFFFF, 0xFFFF, 0xFFFF, "DTK Computer(0x14C2)"},
}; /* pci_vid_14C2[] */

static pci_id_t const pci_vid_14C3[] = {
{0x14C3, 0xFFFF, 0xFFFF, 0xFFFF, "MEDIATEK Corp.(0x14C3)"},
{0x14C3, 0x0608, 0xFFFF, 0xFFFF, "MT7921K (RZ608) Wi-Fi 6E 80MHz(0x0608)"},
{0x14C3, 0x0616, 0xFFFF, 0xFFFF, "MT7922 802.11ax PCI Express Wireless Network Adapter(0x0616)"},
{0x14C3, 0x7603, 0xFFFF, 0xFFFF, "MT7603E 802.11bgn PCI Express Wireless Network Adapter(0x7603)"},
{0x14C3, 0x7612, 0xFFFF, 0xFFFF, "MT7612E 802.11acbgn PCI Express Wireless Network Adapter(0x7612)"},
{0x14C3, 0x7615, 0xFFFF, 0xFFFF, "MT7615E 802.11ac PCI Express Wireless Network Adapter(0x7615)"},
{0x14C3, 0x7630, 0xFFFF, 0xFFFF, "MT7630e 802.11bgn Wireless Network Adapter(0x7630)"},
{0x14C3, 0x7650, 0xFFFF, 0xFFFF, "MT7650 802.11ac(0x7650)"},
{0x14C3, 0x7662, 0xFFFF, 0xFFFF, "MT7662E 802.11ac PCI Express Wireless Network Adapter(0x7662)"},
{0x14C3, 0x7915, 0xFFFF, 0xFFFF, "MT7915E 802.11ax PCI Express Wireless Network Adapter(0x7915)"},
{0x14C3, 0x7916, 0xFFFF, 0xFFFF, "MT7905D/MT7975(0x7916)"},
{0x14C3, 0x7922, 0xFFFF, 0xFFFF, "MT7922 802.11ax PCI Express Wireless Network Adapter(0x7922)"},
{0x14C3, 0x7922, 0x1A3B, 0x5300, "ASUS PCE-AXE59BT(0x1A3B-0x5300)"},
{0x14C3, 0x7961, 0xFFFF, 0xFFFF, "MT7921 802.11ax PCI Express Wireless Network Adapter(0x7961)"},
{0x14C3, 0x8650, 0xFFFF, 0xFFFF, "MT7650 Bluetooth(0x8650)"},
}; /* pci_vid_14C3[] */

static pci_id_t const pci_vid_14C4[] = {
{0x14C4, 0xFFFF, 0xFFFF, 0xFFFF, "IWASAKI Information Systems Co Ltd(0x14C4)"},
}; /* pci_vid_14C4[] */

static pci_id_t const pci_vid_14C5[] = {
{0x14C5, 0xFFFF, 0xFFFF, 0xFFFF, "Automation Products AB(0x14C5)"},
}; /* pci_vid_14C5[] */

static pci_id_t const pci_vid_14C6[] = {
{0x14C6, 0xFFFF, 0xFFFF, 0xFFFF, "Data Race Inc(0x14C6)"},
}; /* pci_vid_14C6[] */

static pci_id_t const pci_vid_14C7[] = {
{0x14C7, 0xFFFF, 0xFFFF, 0xFFFF, "Modular Technology Holdings Ltd(0x14C7)"},
}; /* pci_vid_14C7[] */

static pci_id_t const pci_vid_14C8[] = {
{0x14C8, 0xFFFF, 0xFFFF, 0xFFFF, "Turbocomm Tech. Inc.(0x14C8)"},
}; /* pci_vid_14C8[] */

static pci_id_t const pci_vid_14C9[] = {
{0x14C9, 0xFFFF, 0xFFFF, 0xFFFF, "ODIN Telesystems Inc(0x14C9)"},
}; /* pci_vid_14C9[] */

static pci_id_t const pci_vid_14CA[] = {
{0x14CA, 0xFFFF, 0xFFFF, 0xFFFF, "PE Logic Corp.(0x14CA)"},
}; /* pci_vid_14CA[] */

static pci_id_t const pci_vid_14CB[] = {
{0x14CB, 0xFFFF, 0xFFFF, 0xFFFF, "Billionton Systems Inc(0x14CB)"},
}; /* pci_vid_14CB[] */

static pci_id_t const pci_vid_14CC[] = {
{0x14CC, 0xFFFF, 0xFFFF, 0xFFFF, "NAKAYO Telecommunications Inc(0x14CC)"},
}; /* pci_vid_14CC[] */

static pci_id_t const pci_vid_14CD[] = {
{0x14CD, 0xFFFF, 0xFFFF, 0xFFFF, "Universal Global Scientific Industrial Co.,Ltd(0x14CD)"},
{0x14CD, 0x0001, 0xFFFF, 0xFFFF, "USI-1514-1GbaseT [OCP1](0x0001)"},
{0x14CD, 0x0002, 0xFFFF, 0xFFFF, "USI-4227-SFP [OCP2](0x0002)"},
{0x14CD, 0x0003, 0xFFFF, 0xFFFF, "USI-X557-10GbaseT [OCP3](0x0003)"},
}; /* pci_vid_14CD[] */

static pci_id_t const pci_vid_14CE[] = {
{0x14CE, 0xFFFF, 0xFFFF, 0xFFFF, "Whistle Communications(0x14CE)"},
}; /* pci_vid_14CE[] */

static pci_id_t const pci_vid_14CF[] = {
{0x14CF, 0xFFFF, 0xFFFF, 0xFFFF, "TEK Microsystems Inc.(0x14CF)"},
}; /* pci_vid_14CF[] */

static pci_id_t const pci_vid_14D0[] = {
{0x14D0, 0xFFFF, 0xFFFF, 0xFFFF, "Ericsson Axe R & D(0x14D0)"},
}; /* pci_vid_14D0[] */

static pci_id_t const pci_vid_14D1[] = {
{0x14D1, 0xFFFF, 0xFFFF, 0xFFFF, "Computer Hi-Tech Co Ltd(0x14D1)"},
}; /* pci_vid_14D1[] */

static pci_id_t const pci_vid_14D2[] = {
{0x14D2, 0xFFFF, 0xFFFF, 0xFFFF, "Titan Electronics Inc(0x14D2)"},
{0x14D2, 0x8001, 0xFFFF, 0xFFFF, "VScom 010L 1 port parallel adaptor(0x8001)"},
{0x14D2, 0x8002, 0xFFFF, 0xFFFF, "VScom 020L 2 port parallel adaptor(0x8002)"},
{0x14D2, 0x8010, 0xFFFF, 0xFFFF, "VScom 100L 1 port serial adaptor(0x8010)"},
{0x14D2, 0x8011, 0xFFFF, 0xFFFF, "VScom 110L 1 port serial and 1 port parallel adaptor(0x8011)"},
{0x14D2, 0x8020, 0xFFFF, 0xFFFF, "VScom 200L 1 or 2 port serial adaptor(0x8020)"},
{0x14D2, 0x8021, 0xFFFF, 0xFFFF, "VScom 210L 2 port serial and 1 port parallel adaptor(0x8021)"},
{0x14D2, 0x8028, 0xFFFF, 0xFFFF, "VScom 200I/200I-SI 2-port serial adapter(0x8028)"},
{0x14D2, 0x8040, 0xFFFF, 0xFFFF, "VScom 400L 4 port serial adaptor(0x8040)"},
{0x14D2, 0x8043, 0xFFFF, 0xFFFF, "VScom 430L 4-port serial and 3-port parallel adapter(0x8043)"},
{0x14D2, 0x8048, 0xFFFF, 0xFFFF, "VScom 400I 4-port serial adapter(0x8048)"},
{0x14D2, 0x8080, 0xFFFF, 0xFFFF, "VScom 800L 8 port serial adaptor(0x8080)"},
{0x14D2, 0x8088, 0xFFFF, 0xFFFF, "VScom 800I 8-port serial adapter(0x8088)"},
{0x14D2, 0xA000, 0xFFFF, 0xFFFF, "VScom 010H 1 port parallel adaptor(0xA000)"},
{0x14D2, 0xA001, 0xFFFF, 0xFFFF, "VScom 100H 1 port serial adaptor(0xA001)"},
{0x14D2, 0xA003, 0xFFFF, 0xFFFF, "VScom 400H 4 port serial adaptor(0xA003)"},
{0x14D2, 0xA004, 0xFFFF, 0xFFFF, "VScom 400HF1 4 port serial adaptor(0xA004)"},
{0x14D2, 0xA005, 0xFFFF, 0xFFFF, "VScom 200H 2 port serial adaptor(0xA005)"},
{0x14D2, 0xA007, 0xFFFF, 0xFFFF, "VScom PCI800EH (PCIe) 8-port serial adapter Port 1-4(0xA007)"},
{0x14D2, 0xA008, 0xFFFF, 0xFFFF, "VScom PCI800EH (PCIe) 8-port serial adapter Port 5-8(0xA008)"},
{0x14D2, 0xA009, 0xFFFF, 0xFFFF, "VScom PCI400EH (PCIe) 4-port serial adapter(0xA009)"},
{0x14D2, 0xE001, 0xFFFF, 0xFFFF, "VScom 010HV2 1 port parallel adaptor(0xE001)"},
{0x14D2, 0xE010, 0xFFFF, 0xFFFF, "VScom 100HV2 1 port serial adaptor(0xE010)"},
{0x14D2, 0xE020, 0xFFFF, 0xFFFF, "VScom 200HV2 2 port serial adaptor(0xE020)"},
}; /* pci_vid_14D2[] */

static pci_id_t const pci_vid_14D3[] = {
{0x14D3, 0xFFFF, 0xFFFF, 0xFFFF, "CIRTECH (UK) Ltd(0x14D3)"},
{0x14D3, 0x0002, 0xFFFF, 0xFFFF, "DTL-T14000 Rev. 1 [PS2 TOOL CD/DVD Emulator](0x0002)"},
{0x14D3, 0x0003, 0xFFFF, 0xFFFF, "DTL-T14000 Rev. 2 [PS2 TOOL CD/DVD Emulator](0x0003)"},
{0x14D3, 0x0004, 0xFFFF, 0xFFFF, "DTL-T14000 Rev. 3 [PS2 TOOL CD/DVD Emulator](0x0004)"},
}; /* pci_vid_14D3[] */

static pci_id_t const pci_vid_14D4[] = {
{0x14D4, 0xFFFF, 0xFFFF, 0xFFFF, "Panacom Technology Corp(0x14D4)"},
}; /* pci_vid_14D4[] */

static pci_id_t const pci_vid_14D5[] = {
{0x14D5, 0xFFFF, 0xFFFF, 0xFFFF, "Nitsuko Corporation(0x14D5)"},
}; /* pci_vid_14D5[] */

static pci_id_t const pci_vid_14D6[] = {
{0x14D6, 0xFFFF, 0xFFFF, 0xFFFF, "Accusys Inc(0x14D6)"},
{0x14D6, 0x6101, 0xFFFF, 0xFFFF, "ACS-61xxx, PCIe to SAS/SATA RAID HBA(0x6101)"},
{0x14D6, 0x6201, 0xFFFF, 0xFFFF, "ACS-62xxx, External PCIe to SAS/SATA RAID controller(0x6201)"},
}; /* pci_vid_14D6[] */

static pci_id_t const pci_vid_14D7[] = {
{0x14D7, 0xFFFF, 0xFFFF, 0xFFFF, "Hirakawa Hewtech Corp(0x14D7)"},
}; /* pci_vid_14D7[] */

static pci_id_t const pci_vid_14D8[] = {
{0x14D8, 0xFFFF, 0xFFFF, 0xFFFF, "HOPF Elektronik GmBH(0x14D8)"},
}; /* pci_vid_14D8[] */

static pci_id_t const pci_vid_14D9[] = {
{0x14D9, 0xFFFF, 0xFFFF, 0xFFFF, "Alliance Semiconductor Corporation(0x14D9)"},
{0x14D9, 0x0010, 0xFFFF, 0xFFFF, "AP1011/SP1011 HyperTransport-PCI Bridge [Sturgeon](0x0010)"},
{0x14D9, 0x9000, 0xFFFF, 0xFFFF, "AS90L10204/10208 HyperTransport to PCI-X Bridge(0x9000)"},
}; /* pci_vid_14D9[] */

static pci_id_t const pci_vid_14DA[] = {
{0x14DA, 0xFFFF, 0xFFFF, 0xFFFF, "National Aerospace Laboratories(0x14DA)"},
}; /* pci_vid_14DA[] */

static pci_id_t const pci_vid_14DB[] = {
{0x14DB, 0xFFFF, 0xFFFF, 0xFFFF, "AFAVLAB Technology Inc(0x14DB)"},
{0x14DB, 0x2120, 0xFFFF, 0xFFFF, "TK9902(0x2120)"},
{0x14DB, 0x2182, 0xFFFF, 0xFFFF, "AFAVLAB Technology Inc. 8-port serial card(0x2182)"},
}; /* pci_vid_14DB[] */

static pci_id_t const pci_vid_14DC[] = {
{0x14DC, 0xFFFF, 0xFFFF, 0xFFFF, "Amplicon Liveline Ltd(0x14DC)"},
{0x14DC, 0x0000, 0xFFFF, 0xFFFF, "PCI230(0x0000)"},
{0x14DC, 0x0001, 0xFFFF, 0xFFFF, "PCI242(0x0001)"},
{0x14DC, 0x0002, 0xFFFF, 0xFFFF, "PCI244(0x0002)"},
{0x14DC, 0x0003, 0xFFFF, 0xFFFF, "PCI247(0x0003)"},
{0x14DC, 0x0004, 0xFFFF, 0xFFFF, "PCI248(0x0004)"},
{0x14DC, 0x0005, 0xFFFF, 0xFFFF, "PCI249(0x0005)"},
{0x14DC, 0x0006, 0xFFFF, 0xFFFF, "PCI260(0x0006)"},
{0x14DC, 0x0007, 0xFFFF, 0xFFFF, "PCI224(0x0007)"},
{0x14DC, 0x0008, 0xFFFF, 0xFFFF, "PCI234(0x0008)"},
{0x14DC, 0x0009, 0xFFFF, 0xFFFF, "PCI236(0x0009)"},
{0x14DC, 0x000A, 0xFFFF, 0xFFFF, "PCI272(0x000A)"},
{0x14DC, 0x000B, 0xFFFF, 0xFFFF, "PCI215(0x000B)"},
}; /* pci_vid_14DC[] */

static pci_id_t const pci_vid_14DD[] = {
{0x14DD, 0xFFFF, 0xFFFF, 0xFFFF, "Boulder Design Labs Inc(0x14DD)"},
}; /* pci_vid_14DD[] */

static pci_id_t const pci_vid_14DE[] = {
{0x14DE, 0xFFFF, 0xFFFF, 0xFFFF, "Applied Integration Corporation(0x14DE)"},
}; /* pci_vid_14DE[] */

static pci_id_t const pci_vid_14DF[] = {
{0x14DF, 0xFFFF, 0xFFFF, 0xFFFF, "ASIC Communications Corp(0x14DF)"},
}; /* pci_vid_14DF[] */

static pci_id_t const pci_vid_14E1[] = {
{0x14E1, 0xFFFF, 0xFFFF, 0xFFFF, "INVERTEX(0x14E1)"},
}; /* pci_vid_14E1[] */

static pci_id_t const pci_vid_14E2[] = {
{0x14E2, 0xFFFF, 0xFFFF, 0xFFFF, "INFOLIBRIA(0x14E2)"},
}; /* pci_vid_14E2[] */

static pci_id_t const pci_vid_14E3[] = {
{0x14E3, 0xFFFF, 0xFFFF, 0xFFFF, "AMTELCO(0x14E3)"},
}; /* pci_vid_14E3[] */

static pci_id_t const pci_vid_14E4[] = {
{0x14E4, 0xFFFF, 0xFFFF, 0xFFFF, "Broadcom Inc. and subsidiaries(0x14E4)"},
{0x14E4, 0x0576, 0xFFFF, 0xFFFF, "BCM43224 802.11a/b/g/n(0x0576)"},
{0x14E4, 0x0800, 0xFFFF, 0xFFFF, "Sentry5 Chipcommon I/O Controller(0x0800)"},
{0x14E4, 0x0804, 0xFFFF, 0xFFFF, "Sentry5 PCI Bridge(0x0804)"},
{0x14E4, 0x0805, 0xFFFF, 0xFFFF, "Sentry5 MIPS32 CPU(0x0805)"},
{0x14E4, 0x0806, 0xFFFF, 0xFFFF, "Sentry5 Ethernet Controller(0x0806)"},
{0x14E4, 0x080B, 0xFFFF, 0xFFFF, "Sentry5 Crypto Accelerator(0x080B)"},
{0x14E4, 0x080F, 0xFFFF, 0xFFFF, "Sentry5 DDR/SDR RAM Controller(0x080F)"},
{0x14E4, 0x0811, 0xFFFF, 0xFFFF, "Sentry5 External Interface Core(0x0811)"},
{0x14E4, 0x0816, 0xFFFF, 0xFFFF, "BCM3302 Sentry5 MIPS32 CPU(0x0816)"},
{0x14E4, 0x1570, 0xFFFF, 0xFFFF, "720p FaceTime HD Camera(0x1570)"},
{0x14E4, 0x1600, 0xFFFF, 0xFFFF, "NetXtreme BCM5752 Gigabit Ethernet PCI Express(0x1600)"},
{0x14E4, 0x1600, 0x1028, 0x01C1, "Precision 490(0x1028-0x01C1)"},
{0x14E4, 0x1600, 0x1028, 0x01C2, "Latitude D620(0x1028-0x01C2)"},
{0x14E4, 0x1600, 0x103C, 0x3015, "PCIe LAN on Motherboard(0x103C-0x3015)"},
{0x14E4, 0x1600, 0x107B, 0x5048, "E4500 Onboard(0x107B-0x5048)"},
{0x14E4, 0x1600, 0x1259, 0x2705, "AT-2711FX(0x1259-0x2705)"},
{0x14E4, 0x1601, 0xFFFF, 0xFFFF, "NetXtreme BCM5752M Gigabit Ethernet PCI Express(0x1601)"},
{0x14E4, 0x1604, 0xFFFF, 0xFFFF, "BCM5745X NetXtreme-E Ethernet Partition(0x1604)"},
{0x14E4, 0x1605, 0xFFFF, 0xFFFF, "BCM5745X NetXtreme-E RDMA Partition(0x1605)"},
{0x14E4, 0x1606, 0xFFFF, 0xFFFF, "BCM5745X NetXtreme-E RDMA Virtual Function(0x1606)"},
{0x14E4, 0x1609, 0xFFFF, 0xFFFF, "BCM5745X NetXtreme-E Ethernet Virtual Function(0x1609)"},
{0x14E4, 0x1612, 0xFFFF, 0xFFFF, "BCM70012 Video Decoder [Crystal HD](0x1612)"},
{0x14E4, 0x1614, 0xFFFF, 0xFFFF, "BCM57454 NetXtreme-E 10Gb/25Gb/40Gb/50Gb/100Gb Ethernet(0x1614)"},
{0x14E4, 0x1614, 0x14E4, 0xD140, "NetXtreme-E Quad-port 10GBASE-T Ethernet PCIe Adapter (BCM957454-P410SDBT)(0x14E4-0xD140)"},
{0x14E4, 0x1614, 0x14E4, 0xD340, "NetXtreme-E Quad-port 10GBASE-T Ethernet OCP 3.0 Adapter (BCM957454-N410SDBT)(0x14E4-0xD340)"},
{0x14E4, 0x1615, 0xFFFF, 0xFFFF, "BCM70015 Video Decoder [Crystal HD](0x1615)"},
{0x14E4, 0x1639, 0xFFFF, 0xFFFF, "NetXtreme II BCM5709 Gigabit Ethernet(0x1639)"},
{0x14E4, 0x1639, 0x1028, 0x0235, "PowerEdge R710 BCM5709 Gigabit Ethernet(0x1028-0x0235)"},
{0x14E4, 0x1639, 0x1028, 0x0236, "PowerEdge R610 BCM5709 Gigabit Ethernet(0x1028-0x0236)"},
{0x14E4, 0x1639, 0x1028, 0x0237, "PowerEdge T610 BCM5709 Gigabit Ethernet(0x1028-0x0237)"},
{0x14E4, 0x1639, 0x103C, 0x7055, "NC382i Integrated Multi-port PCI Express Gigabit Server Adapter(0x103C-0x7055)"},
{0x14E4, 0x1639, 0x103C, 0x7059, "NC382T PCIe Dual Port Multifunction Gigabit Server Adapter(0x103C-0x7059)"},
{0x14E4, 0x1639, 0x10A9, 0x8027, "Quad port Gigabit Ethernet Controller(0x10A9-0x8027)"},
{0x14E4, 0x163A, 0xFFFF, 0xFFFF, "NetXtreme II BCM5709S Gigabit Ethernet(0x163A)"},
{0x14E4, 0x163A, 0x1028, 0x027B, "PowerEdge M805 Broadcom NetXtreme II BCM5709S(0x1028-0x027B)"},
{0x14E4, 0x163A, 0x1028, 0x029C, "PowerEdge M710 BCM5709S Gigabit Ethernet(0x1028-0x029C)"},
{0x14E4, 0x163A, 0x103C, 0x171D, "NC382m Dual Port 1GbE Multifunction BL-c Adapter(0x103C-0x171D)"},
{0x14E4, 0x163A, 0x103C, 0x7056, "NC382i Integrated Quad Port PCI Express Gigabit Server Adapter(0x103C-0x7056)"},
{0x14E4, 0x163A, 0x1259, 0x2984, "AT-2973SX(0x1259-0x2984)"},
{0x14E4, 0x163B, 0xFFFF, 0xFFFF, "NetXtreme II BCM5716 Gigabit Ethernet(0x163B)"},
{0x14E4, 0x163B, 0x1028, 0x028C, "PowerEdge R410 BCM5716 Gigabit Ethernet(0x1028-0x028C)"},
{0x14E4, 0x163B, 0x1028, 0x028D, "PowerEdge T410 BCM5716 Gigabit Ethernet(0x1028-0x028D)"},
{0x14E4, 0x163B, 0x1028, 0x02F1, "PowerEdge R510 BCM5716 Gigabit Ethernet(0x1028-0x02F1)"},
{0x14E4, 0x163C, 0xFFFF, 0xFFFF, "NetXtreme II BCM5716S Gigabit Ethernet(0x163C)"},
{0x14E4, 0x163D, 0xFFFF, 0xFFFF, "NetXtreme II BCM57811 10-Gigabit Ethernet(0x163D)"},
{0x14E4, 0x163D, 0x1043, 0x858A, "PEB-10G/57811-1S(0x1043-0x858A)"},
{0x14E4, 0x163E, 0xFFFF, 0xFFFF, "NetXtreme II BCM57811 10 Gigabit Ethernet Multi Function(0x163E)"},
{0x14E4, 0x163F, 0xFFFF, 0xFFFF, "NetXtreme II BCM57811 10-Gigabit Ethernet Virtual Function(0x163F)"},
{0x14E4, 0x1641, 0xFFFF, 0xFFFF, "NetXtreme BCM57787 Gigabit Ethernet PCIe(0x1641)"},
{0x14E4, 0x1642, 0xFFFF, 0xFFFF, "NetXtreme BCM57764 Gigabit Ethernet PCIe(0x1642)"},
{0x14E4, 0x1643, 0xFFFF, 0xFFFF, "NetXtreme BCM5725 Gigabit Ethernet PCIe(0x1643)"},
{0x14E4, 0x1644, 0xFFFF, 0xFFFF, "NetXtreme BCM5700 Gigabit Ethernet(0x1644)"},
{0x14E4, 0x1644, 0x1014, 0x0277, "Broadcom Vigil B5700 1000Base-T(0x1014-0x0277)"},
{0x14E4, 0x1644, 0x1028, 0x00D1, "Broadcom BCM5700(0x1028-0x00D1)"},
{0x14E4, 0x1644, 0x1028, 0x0106, "Broadcom BCM5700(0x1028-0x0106)"},
{0x14E4, 0x1644, 0x1028, 0x0109, "Broadcom BCM5700 1000Base-T(0x1028-0x0109)"},
{0x14E4, 0x1644, 0x1028, 0x010A, "Broadcom BCM5700 1000BaseTX(0x1028-0x010A)"},
{0x14E4, 0x1644, 0x10B7, 0x1000, "3C996-T 1000Base-T(0x10B7-0x1000)"},
{0x14E4, 0x1644, 0x10B7, 0x1001, "3C996B-T 1000Base-T(0x10B7-0x1001)"},
{0x14E4, 0x1644, 0x10B7, 0x1002, "3C996C-T 1000Base-T(0x10B7-0x1002)"},
{0x14E4, 0x1644, 0x10B7, 0x1003, "3C997-T 1000Base-T Dual Port(0x10B7-0x1003)"},
{0x14E4, 0x1644, 0x10B7, 0x1004, "3C996-SX 1000Base-SX(0x10B7-0x1004)"},
{0x14E4, 0x1644, 0x10B7, 0x1005, "3C997-SX 1000Base-SX Dual Port(0x10B7-0x1005)"},
{0x14E4, 0x1644, 0x10B7, 0x1008, "3C942 Gigabit LOM (31X31)(0x10B7-0x1008)"},
{0x14E4, 0x1644, 0x14E4, 0x0002, "NetXtreme 1000Base-SX(0x14E4-0x0002)"},
{0x14E4, 0x1644, 0x14E4, 0x0003, "NetXtreme 1000Base-SX(0x14E4-0x0003)"},
{0x14E4, 0x1644, 0x14E4, 0x0004, "NetXtreme 1000Base-T(0x14E4-0x0004)"},
{0x14E4, 0x1644, 0x14E4, 0x1028, "NetXtreme 1000BaseTX(0x14E4-0x1028)"},
{0x14E4, 0x1644, 0x14E4, 0x1644, "BCM5700 1000Base-T(0x14E4-0x1644)"},
{0x14E4, 0x1645, 0xFFFF, 0xFFFF, "NetXtreme BCM5701 Gigabit Ethernet(0x1645)"},
{0x14E4, 0x1645, 0x0E11, 0x007C, "NC7770 Gigabit Server Adapter (PCI-X, 10/100/1000-T)(0x0E11-0x007C)"},
{0x14E4, 0x1645, 0x0E11, 0x007D, "NC6770 Gigabit Server Adapter (PCI-X, 1000-SX)(0x0E11-0x007D)"},
{0x14E4, 0x1645, 0x0E11, 0x0085, "NC7780 Gigabit Server Adapter (embedded, WOL)(0x0E11-0x0085)"},
{0x14E4, 0x1645, 0x0E11, 0x0099, "NC7780 Gigabit Server Adapter (embedded, WOL)(0x0E11-0x0099)"},
{0x14E4, 0x1645, 0x0E11, 0x009A, "NC7770 Gigabit Server Adapter (PCI-X, 10/100/1000-T)(0x0E11-0x009A)"},
{0x14E4, 0x1645, 0x0E11, 0x00C1, "NC6770 Gigabit Server Adapter (PCI-X, 1000-SX)(0x0E11-0x00C1)"},
{0x14E4, 0x1645, 0x1028, 0x0121, "Broadcom BCM5701 1000Base-T(0x1028-0x0121)"},
{0x14E4, 0x1645, 0x103C, 0x128A, "BCM5701 1000Base-T (HP, OEM 3COM)(0x103C-0x128A)"},
{0x14E4, 0x1645, 0x103C, 0x128B, "1000Base-SX (PCI) [A7073A](0x103C-0x128B)"},
{0x14E4, 0x1645, 0x103C, 0x12A4, "Core Lan 1000Base-T(0x103C-0x12A4)"},
{0x14E4, 0x1645, 0x103C, 0x12C1, "IOX Core Lan 1000Base-T [A7109AX](0x103C-0x12C1)"},
{0x14E4, 0x1645, 0x103C, 0x1300, "Core LAN/SCSI Combo [A6794A](0x103C-0x1300)"},
{0x14E4, 0x1645, 0x10A9, 0x8010, "IO9/IO10 Gigabit Ethernet (Copper)(0x10A9-0x8010)"},
{0x14E4, 0x1645, 0x10A9, 0x8011, "Gigabit Ethernet (Copper)(0x10A9-0x8011)"},
{0x14E4, 0x1645, 0x10A9, 0x8012, "Gigabit Ethernet (Fiber)(0x10A9-0x8012)"},
{0x14E4, 0x1645, 0x10B7, 0x1004, "3C996-SX 1000Base-SX(0x10B7-0x1004)"},
{0x14E4, 0x1645, 0x10B7, 0x1006, "3C996B-T 1000Base-T(0x10B7-0x1006)"},
{0x14E4, 0x1645, 0x10B7, 0x1007, "3C1000-T 1000Base-T(0x10B7-0x1007)"},
{0x14E4, 0x1645, 0x10B7, 0x1008, "3C940-BR01 1000Base-T(0x10B7-0x1008)"},
{0x14E4, 0x1645, 0x14E4, 0x0001, "BCM5701 1000Base-T(0x14E4-0x0001)"},
{0x14E4, 0x1645, 0x14E4, 0x0005, "BCM5701 1000Base-T(0x14E4-0x0005)"},
{0x14E4, 0x1645, 0x14E4, 0x0006, "BCM5701 1000Base-T(0x14E4-0x0006)"},
{0x14E4, 0x1645, 0x14E4, 0x0007, "BCM5701 1000Base-SX(0x14E4-0x0007)"},
{0x14E4, 0x1645, 0x14E4, 0x0008, "BCM5701 1000Base-T(0x14E4-0x0008)"},
{0x14E4, 0x1645, 0x14E4, 0x1645, "NetXtreme BCM5701 Gigabit Ethernet(0x14E4-0x1645)"},
{0x14E4, 0x1645, 0x14E4, 0x8008, "BCM5701 1000Base-T(0x14E4-0x8008)"},
{0x14E4, 0x1646, 0xFFFF, 0xFFFF, "NetXtreme BCM5702 Gigabit Ethernet(0x1646)"},
{0x14E4, 0x1646, 0x0E11, 0x00BB, "NC7760 1000BaseTX(0x0E11-0x00BB)"},
{0x14E4, 0x1646, 0x1028, 0x0126, "Broadcom BCM5702 1000BaseTX(0x1028-0x0126)"},
{0x14E4, 0x1646, 0x14E4, 0x8009, "BCM5702 1000BaseTX(0x14E4-0x8009)"},
{0x14E4, 0x1647, 0xFFFF, 0xFFFF, "NetXtreme BCM5703 Gigabit Ethernet(0x1647)"},
{0x14E4, 0x1647, 0x0E11, 0x0099, "NC7780 1000BaseTX(0x0E11-0x0099)"},
{0x14E4, 0x1647, 0x0E11, 0x009A, "NC7770 1000BaseTX(0x0E11-0x009A)"},
{0x14E4, 0x1647, 0x10A9, 0x8010, "IO9 Gigabit Ethernet (Copper)(0x10A9-0x8010)"},
{0x14E4, 0x1647, 0x14E4, 0x0009, "BCM5703 1000BaseTX(0x14E4-0x0009)"},
{0x14E4, 0x1647, 0x14E4, 0x000A, "BCM5703 1000BaseSX(0x14E4-0x000A)"},
{0x14E4, 0x1647, 0x14E4, 0x000B, "BCM5703 1000BaseTX(0x14E4-0x000B)"},
{0x14E4, 0x1647, 0x14E4, 0x8009, "BCM5703 1000BaseTX(0x14E4-0x8009)"},
{0x14E4, 0x1647, 0x14E4, 0x800A, "BCM5703 1000BaseTX(0x14E4-0x800A)"},
{0x14E4, 0x1648, 0xFFFF, 0xFFFF, "NetXtreme BCM5704 Gigabit Ethernet(0x1648)"},
{0x14E4, 0x1648, 0x0E11, 0x00CF, "NC7772 Gigabit Server Adapter (PCI-X, 10,100,1000-T)(0x0E11-0x00CF)"},
{0x14E4, 0x1648, 0x0E11, 0x00D0, "NC7782 Gigabit Server Adapter (PCI-X, 10,100,1000-T)(0x0E11-0x00D0)"},
{0x14E4, 0x1648, 0x0E11, 0x00D1, "NC7783 Gigabit Server Adapter (PCI-X, 10,100,1000-T)(0x0E11-0x00D1)"},
{0x14E4, 0x1648, 0x1028, 0x014A, "PowerEdge 1750(0x1028-0x014A)"},
{0x14E4, 0x1648, 0x1028, 0x0170, "PowerEdge 6850 Broadcom NetXtreme BCM5704(0x1028-0x0170)"},
{0x14E4, 0x1648, 0x103C, 0x310F, "NC7782 Gigabit Server Adapter (PCI-X, 10,100,1000-T)(0x103C-0x310F)"},
{0x14E4, 0x1648, 0x10A9, 0x8013, "Dual Port Gigabit Ethernet (PCI-X,Copper)(0x10A9-0x8013)"},
{0x14E4, 0x1648, 0x10A9, 0x8018, "Dual Port Gigabit Ethernet (A330)(0x10A9-0x8018)"},
{0x14E4, 0x1648, 0x10A9, 0x801A, "Dual Port Gigabit Ethernet (IA-blade)(0x10A9-0x801A)"},
{0x14E4, 0x1648, 0x10A9, 0x801B, "Quad Port Gigabit Ethernet (PCI-E,Copper)(0x10A9-0x801B)"},
{0x14E4, 0x1648, 0x10B7, 0x2000, "3C998-T Dual Port 10/100/1000 PCI-X(0x10B7-0x2000)"},
{0x14E4, 0x1648, 0x10B7, 0x3000, "3C999-T Quad Port 10/100/1000 PCI-X(0x10B7-0x3000)"},
{0x14E4, 0x1648, 0x1166, 0x1648, "NetXtreme CIOB-E 1000Base-T(0x1166-0x1648)"},
{0x14E4, 0x1648, 0x1734, 0x100B, "PRIMERGY RX/TX series onboard LAN(0x1734-0x100B)"},
{0x14E4, 0x1649, 0xFFFF, 0xFFFF, "NetXtreme BCM5704S_2 Gigabit Ethernet(0x1649)"},
{0x14E4, 0x164A, 0xFFFF, 0xFFFF, "NetXtreme II BCM5706 Gigabit Ethernet(0x164A)"},
{0x14E4, 0x164A, 0x103C, 0x1709, "NC371i Integrated PCI-X Multifunction Gigabit Server Adapter(0x103C-0x1709)"},
{0x14E4, 0x164A, 0x103C, 0x3070, "NC380T PCI Express Dual Port Multifunction Gigabit Server Adapter(0x103C-0x3070)"},
{0x14E4, 0x164A, 0x103C, 0x3101, "NC370T MultifuNCtion Gigabit Server Adapter(0x103C-0x3101)"},
{0x14E4, 0x164A, 0x103C, 0x3106, "NC370i Multifunction Gigabit Server Adapter(0x103C-0x3106)"},
{0x14E4, 0x164C, 0xFFFF, 0xFFFF, "NetXtreme II BCM5708 Gigabit Ethernet(0x164C)"},
{0x14E4, 0x164C, 0x1028, 0x01F0, "PowerEdge R900 Broadcom NetXtreme II BCM5708(0x1028-0x01F0)"},
{0x14E4, 0x164C, 0x1028, 0x0205, "PowerEdge 2970 Broadcom NetXtreme II BCM5708(0x1028-0x0205)"},
{0x14E4, 0x164C, 0x1028, 0x020B, "PowerEdge T605 Broadcom NetXtreme II BCM5708(0x1028-0x020B)"},
{0x14E4, 0x164C, 0x1028, 0x0221, "PowerEdge R805 Broadcom NetXtreme II BCM5708(0x1028-0x0221)"},
{0x14E4, 0x164C, 0x1028, 0x0223, "PowerEdge R905 Broadcom NetXtreme II BCM5708(0x1028-0x0223)"},
{0x14E4, 0x164C, 0x1028, 0x1F12, "PowerEdge R805/R905 Broadcom NetXtreme II BCM5708(0x1028-0x1F12)"},
{0x14E4, 0x164C, 0x103C, 0x7037, "NC373T PCI Express Multifunction Gigabit Server Adapter(0x103C-0x7037)"},
{0x14E4, 0x164C, 0x103C, 0x7038, "NC373i Integrated Multifunction Gigabit Server Adapter(0x103C-0x7038)"},
{0x14E4, 0x164C, 0x103C, 0x7045, "NC374m PCI Express Dual Port Multifunction Gigabit Server Adapter(0x103C-0x7045)"},
{0x14E4, 0x164D, 0xFFFF, 0xFFFF, "NetXtreme BCM5702FE Gigabit Ethernet(0x164D)"},
{0x14E4, 0x164E, 0xFFFF, 0xFFFF, "NetXtreme II BCM57710 10-Gigabit PCIe [Everest](0x164E)"},
{0x14E4, 0x164E, 0x103C, 0x171C, "NC532m Dual Port 10GbE Multifunction BL-C Adapter(0x103C-0x171C)"},
{0x14E4, 0x164E, 0x103C, 0x7058, "NC532i Dual Port 10GbE Multifunction BL-C Adapter(0x103C-0x7058)"},
{0x14E4, 0x164F, 0xFFFF, 0xFFFF, "NetXtreme II BCM57711 10-Gigabit PCIe(0x164F)"},
{0x14E4, 0x1650, 0xFFFF, 0xFFFF, "NetXtreme II BCM57711E 10-Gigabit PCIe(0x1650)"},
{0x14E4, 0x1650, 0x103C, 0x171C, "NC532m Dual Port 10GbE Multifunction BL-C Adapter(0x103C-0x171C)"},
{0x14E4, 0x1650, 0x103C, 0x7058, "NC532i Dual Port 10GbE Multifunction BL-C Adapter(0x103C-0x7058)"},
{0x14E4, 0x1653, 0xFFFF, 0xFFFF, "NetXtreme BCM5705 Gigabit Ethernet(0x1653)"},
{0x14E4, 0x1653, 0x0E11, 0x00E3, "NC7761 Gigabit Server Adapter(0x0E11-0x00E3)"},
{0x14E4, 0x1653, 0x1734, 0x1073, "Primergy Econel 200 D2020 mainboard(0x1734-0x1073)"},
{0x14E4, 0x1654, 0xFFFF, 0xFFFF, "NetXtreme BCM5705_2 Gigabit Ethernet(0x1654)"},
{0x14E4, 0x1654, 0x0E11, 0x00E3, "NC7761 Gigabit Server Adapter(0x0E11-0x00E3)"},
{0x14E4, 0x1654, 0x103C, 0x3100, "NC1020 ProLiant Gigabit Server Adapter 32 PCI(0x103C-0x3100)"},
{0x14E4, 0x1654, 0x103C, 0x3226, "NC150T 4-port Gigabit Combo Switch & Adapter(0x103C-0x3226)"},
{0x14E4, 0x1655, 0xFFFF, 0xFFFF, "NetXtreme BCM5717 Gigabit Ethernet PCIe(0x1655)"},
{0x14E4, 0x1656, 0xFFFF, 0xFFFF, "NetXtreme BCM5718 Gigabit Ethernet PCIe(0x1656)"},
{0x14E4, 0x1657, 0xFFFF, 0xFFFF, "NetXtreme BCM5719 Gigabit Ethernet PCIe(0x1657)"},
{0x14E4, 0x1657, 0x1014, 0x0420, "FC 5260/5899 4-port 1 GbE Adapter for Power(0x1014-0x0420)"},
{0x14E4, 0x1657, 0x103C, 0x169D, "Ethernet 1Gb 4-port 331FLR Adapter(0x103C-0x169D)"},
{0x14E4, 0x1657, 0x103C, 0x22BE, "Ethernet 1Gb 4-port 331i Adapter(0x103C-0x22BE)"},
{0x14E4, 0x1657, 0x103C, 0x3383, "Ethernet 1Gb 4-port 331T Adapter(0x103C-0x3383)"},
{0x14E4, 0x1657, 0x14E4, 0x1904, "4-port 1Gb Ethernet Adapter(0x14E4-0x1904)"},
{0x14E4, 0x1657, 0x14E4, 0x1909, "Broadcom NetXtreme 5719 Quad Port Gigabit NIC(0x14E4-0x1909)"},
{0x14E4, 0x1657, 0x14E4, 0xD166, "BCM95719-P41 4x1GBT Ethernet NIC(0x14E4-0xD166)"},
{0x14E4, 0x1657, 0x14E4, 0xD366, "BCM95719-N41 4x1GBT Ethernet NIC(0x14E4-0xD366)"},
{0x14E4, 0x1657, 0x193D, 0x1025, "NIC-ETH330T-LP-4P(0x193D-0x1025)"},
{0x14E4, 0x1657, 0x193D, 0x1086, "NIC-ETH330T-3S-4P(0x193D-0x1086)"},
{0x14E4, 0x1659, 0xFFFF, 0xFFFF, "NetXtreme BCM5721 Gigabit Ethernet PCI Express(0x1659)"},
{0x14E4, 0x1659, 0x1014, 0x02C6, "eServer xSeries server mainboard(0x1014-0x02C6)"},
{0x14E4, 0x1659, 0x1028, 0x01E6, "PowerEdge 860(0x1028-0x01E6)"},
{0x14E4, 0x1659, 0x1028, 0x023C, "PowerEdge R200 Broadcom NetXtreme BCM5721(0x1028-0x023C)"},
{0x14E4, 0x1659, 0x103C, 0x170B, "NC320m PCI Express Dual Port Gigabit Server Adapter(0x103C-0x170B)"},
{0x14E4, 0x1659, 0x103C, 0x7031, "NC320T PCIe Gigabit Server Adapter(0x103C-0x7031)"},
{0x14E4, 0x1659, 0x103C, 0x7032, "NC320i PCIe Gigabit Server Adapter(0x103C-0x7032)"},
{0x14E4, 0x1659, 0x1734, 0x1061, "PRIMERGY RX/TX S2 series onboard LAN(0x1734-0x1061)"},
{0x14E4, 0x165A, 0xFFFF, 0xFFFF, "NetXtreme BCM5722 Gigabit Ethernet PCI Express(0x165A)"},
{0x14E4, 0x165A, 0x1014, 0x0378, "System x3350 (Machine type 4192)(0x1014-0x0378)"},
{0x14E4, 0x165A, 0x1028, 0x020F, "PowerEdge R300 Broadcom NetXtreme 5722(0x1028-0x020F)"},
{0x14E4, 0x165A, 0x1028, 0x0210, "PowerEdge T300 Broadcom NetXtreme 5722(0x1028-0x0210)"},
{0x14E4, 0x165A, 0x1028, 0x0225, "PowerEdge T105 Broadcom NetXtreme 5722(0x1028-0x0225)"},
{0x14E4, 0x165A, 0x103C, 0x7051, "NC105i PCIe Gigabit Server Adapter(0x103C-0x7051)"},
{0x14E4, 0x165A, 0x103C, 0x7052, "NC105T PCIe Gigabit Server Adapter(0x103C-0x7052)"},
{0x14E4, 0x165B, 0xFFFF, 0xFFFF, "NetXtreme BCM5723 Gigabit Ethernet PCIe(0x165B)"},
{0x14E4, 0x165B, 0x103C, 0x705D, "NC107i Integrated PCI Express Gigabit Server Adapter(0x103C-0x705D)"},
{0x14E4, 0x165C, 0xFFFF, 0xFFFF, "NetXtreme BCM5724 Gigabit Ethernet PCIe(0x165C)"},
{0x14E4, 0x165D, 0xFFFF, 0xFFFF, "NetXtreme BCM5705M Gigabit Ethernet(0x165D)"},
{0x14E4, 0x165D, 0x1028, 0x865D, "Latitude D400(0x1028-0x865D)"},
{0x14E4, 0x165D, 0x14E4, 0x165D, "Dell Latitude D600(0x14E4-0x165D)"},
{0x14E4, 0x165E, 0xFFFF, 0xFFFF, "NetXtreme BCM5705M_2 Gigabit Ethernet(0x165E)"},
{0x14E4, 0x165E, 0x103C, 0x088C, "NC8000 laptop(0x103C-0x088C)"},
{0x14E4, 0x165E, 0x103C, 0x0890, "NC6000 laptop(0x103C-0x0890)"},
{0x14E4, 0x165E, 0x103C, 0x099C, "NX6110/NC6120(0x103C-0x099C)"},
{0x14E4, 0x165E, 0x10CF, 0x1279, "LifeBook E8010D(0x10CF-0x1279)"},
{0x14E4, 0x165F, 0xFFFF, 0xFFFF, "NetXtreme BCM5720 Gigabit Ethernet PCIe(0x165F)"},
{0x14E4, 0x165F, 0x1028, 0x04F7, "PowerEdge R320 server(0x1028-0x04F7)"},
{0x14E4, 0x165F, 0x1028, 0x08FD, "PowerEdge R6515/R7515 LOM(0x1028-0x08FD)"},
{0x14E4, 0x165F, 0x1028, 0x08FF, "PowerEdge Rx5xx LOM Board(0x1028-0x08FF)"},
{0x14E4, 0x165F, 0x1028, 0x0900, "PowerEdge C6525 LOM(0x1028-0x0900)"},
{0x14E4, 0x165F, 0x1028, 0x0917, "PowerEdge C6520 LOM(0x1028-0x0917)"},
{0x14E4, 0x165F, 0x103C, 0x1786, "NC332T Adapter(0x103C-0x1786)"},
{0x14E4, 0x165F, 0x103C, 0x193D, "NC332i Adapter(0x103C-0x193D)"},
{0x14E4, 0x165F, 0x103C, 0x2133, "NC332i Adapter(0x103C-0x2133)"},
{0x14E4, 0x165F, 0x103C, 0x22E8, "NC332i Adapter(0x103C-0x22E8)"},
{0x14E4, 0x165F, 0x103C, 0x22EB, "NC332i Adapter(0x103C-0x22EB)"},
{0x14E4, 0x165F, 0x15D9, 0x165F, "H12SSL-i(0x15D9-0x165F)"},
{0x14E4, 0x1662, 0xFFFF, 0xFFFF, "NetXtreme II BCM57712 10 Gigabit Ethernet(0x1662)"},
{0x14E4, 0x1663, 0xFFFF, 0xFFFF, "NetXtreme II BCM57712 10 Gigabit Ethernet Multi Function(0x1663)"},
{0x14E4, 0x1665, 0xFFFF, 0xFFFF, "NetXtreme BCM5717 Gigabit Ethernet PCIe(0x1665)"},
{0x14E4, 0x1668, 0xFFFF, 0xFFFF, "NetXtreme BCM5714 Gigabit Ethernet(0x1668)"},
{0x14E4, 0x1668, 0x103C, 0x7039, "NC324i PCIe Dual Port Gigabit Server Adapter(0x103C-0x7039)"},
{0x14E4, 0x1669, 0xFFFF, 0xFFFF, "NetXtreme 5714S Gigabit Ethernet(0x1669)"},
{0x14E4, 0x166A, 0xFFFF, 0xFFFF, "NetXtreme BCM5780 Gigabit Ethernet(0x166A)"},
{0x14E4, 0x166A, 0x103C, 0x7035, "NC325i Integrated Dual port PCIe Express Gigabit Server Adapter(0x103C-0x7035)"},
{0x14E4, 0x166B, 0xFFFF, 0xFFFF, "NetXtreme BCM5780S Gigabit Ethernet(0x166B)"},
{0x14E4, 0x166E, 0xFFFF, 0xFFFF, "570x 10/100 Integrated Controller(0x166E)"},
{0x14E4, 0x166F, 0xFFFF, 0xFFFF, "NetXtreme II BCM57712 10 Gigabit Ethernet Virtual Function(0x166F)"},
{0x14E4, 0x1672, 0xFFFF, 0xFFFF, "NetXtreme BCM5754M Gigabit Ethernet PCI Express(0x1672)"},
{0x14E4, 0x1673, 0xFFFF, 0xFFFF, "NetXtreme BCM5755M Gigabit Ethernet PCI Express(0x1673)"},
{0x14E4, 0x1674, 0xFFFF, 0xFFFF, "NetXtreme BCM5756ME Gigabit Ethernet PCI Express(0x1674)"},
{0x14E4, 0x1677, 0xFFFF, 0xFFFF, "NetXtreme BCM5751 Gigabit Ethernet PCI Express(0x1677)"},
{0x14E4, 0x1677, 0x1028, 0x0176, "Dimension XPS Gen 4(0x1028-0x0176)"},
{0x14E4, 0x1677, 0x1028, 0x0177, "Dimension 8400(0x1028-0x0177)"},
{0x14E4, 0x1677, 0x1028, 0x0179, "Optiplex GX280(0x1028-0x0179)"},
{0x14E4, 0x1677, 0x1028, 0x0182, "Latitude D610(0x1028-0x0182)"},
{0x14E4, 0x1677, 0x1028, 0x0187, "Precision M70(0x1028-0x0187)"},
{0x14E4, 0x1677, 0x1028, 0x01A3, "Latitude X1(0x1028-0x01A3)"},
{0x14E4, 0x1677, 0x1028, 0x01A8, "Precision 380(0x1028-0x01A8)"},
{0x14E4, 0x1677, 0x1028, 0x01AD, "OptiPlex GX620(0x1028-0x01AD)"},
{0x14E4, 0x1677, 0x103C, 0x3006, "DC7100 SFF(DX878AV)(0x103C-0x3006)"},
{0x14E4, 0x1677, 0x1462, 0x028C, "915P/G Neo2(0x1462-0x028C)"},
{0x14E4, 0x1677, 0x1734, 0x105D, "Scenic W620(0x1734-0x105D)"},
{0x14E4, 0x1678, 0xFFFF, 0xFFFF, "NetXtreme BCM5715 Gigabit Ethernet(0x1678)"},
{0x14E4, 0x1678, 0x103C, 0x703E, "NC326i PCIe Dual Port Gigabit Server Adapter(0x103C-0x703E)"},
{0x14E4, 0x1679, 0xFFFF, 0xFFFF, "NetXtreme BCM5715S Gigabit Ethernet(0x1679)"},
{0x14E4, 0x1679, 0x103C, 0x1707, "NC326m PCIe Dual Port Adapter(0x103C-0x1707)"},
{0x14E4, 0x1679, 0x103C, 0x170C, "NC325m PCIe Quad Port Adapter(0x103C-0x170C)"},
{0x14E4, 0x1679, 0x103C, 0x703C, "NC326i PCIe Dual Port Gigabit Server Adapter(0x103C-0x703C)"},
{0x14E4, 0x167A, 0xFFFF, 0xFFFF, "NetXtreme BCM5754 Gigabit Ethernet PCI Express(0x167A)"},
{0x14E4, 0x167A, 0x1028, 0x01DA, "OptiPlex 745(0x1028-0x01DA)"},
{0x14E4, 0x167A, 0x1028, 0x01DE, "Precision 390(0x1028-0x01DE)"},
{0x14E4, 0x167A, 0x1028, 0x01DF, "PowerEdge SC440(0x1028-0x01DF)"},
{0x14E4, 0x167A, 0x1028, 0x0214, "Precision T3400(0x1028-0x0214)"},
{0x14E4, 0x167A, 0x1028, 0x021E, "Precision T5400(0x1028-0x021E)"},
{0x14E4, 0x167B, 0xFFFF, 0xFFFF, "NetXtreme BCM5755 Gigabit Ethernet PCI Express(0x167B)"},
{0x14E4, 0x167B, 0x103C, 0x280A, "DC5750 Microtower(0x103C-0x280A)"},
{0x14E4, 0x167D, 0xFFFF, 0xFFFF, "NetXtreme BCM5751M Gigabit Ethernet PCI Express(0x167D)"},
{0x14E4, 0x167D, 0x1014, 0x0577, "ThinkPad X41 / Z60t(0x1014-0x0577)"},
{0x14E4, 0x167D, 0x103C, 0x0934, "nx8220(0x103C-0x0934)"},
{0x14E4, 0x167D, 0x103C, 0x0940, "Compaq nw8240 Mobile Workstation(0x103C-0x0940)"},
{0x14E4, 0x167D, 0x103C, 0x0944, "Compaq nc6220 Notebook PC(0x103C-0x0944)"},
{0x14E4, 0x167D, 0x17AA, 0x2081, "ThinkPad R60e(0x17AA-0x2081)"},
{0x14E4, 0x167E, 0xFFFF, 0xFFFF, "NetXtreme BCM5751F Fast Ethernet PCI Express(0x167E)"},
{0x14E4, 0x167F, 0xFFFF, 0xFFFF, "NetLink BCM5787F Fast Ethernet PCI Express(0x167F)"},
{0x14E4, 0x1680, 0xFFFF, 0xFFFF, "NetXtreme BCM5761e Gigabit Ethernet PCIe(0x1680)"},
{0x14E4, 0x1681, 0xFFFF, 0xFFFF, "NetXtreme BCM5761 Gigabit Ethernet PCIe(0x1681)"},
{0x14E4, 0x1681, 0x1028, 0x0433, "OptiPlex 580(0x1028-0x0433)"},
{0x14E4, 0x1682, 0xFFFF, 0xFFFF, "NetXtreme BCM57762 Gigabit Ethernet PCIe(0x1682)"},
{0x14E4, 0x1682, 0x106B, 0x00F6, "Thunderbolt to Gigabit Ethernet Adapter(0x106B-0x00F6)"},
{0x14E4, 0x1683, 0xFFFF, 0xFFFF, "NetXtreme BCM57767 Gigabit Ethernet PCIe(0x1683)"},
{0x14E4, 0x1684, 0xFFFF, 0xFFFF, "NetXtreme BCM5764M Gigabit Ethernet PCIe(0x1684)"},
{0x14E4, 0x1685, 0xFFFF, 0xFFFF, "NetXtreme II BCM57500S Gigabit Ethernet(0x1685)"},
{0x14E4, 0x1686, 0xFFFF, 0xFFFF, "NetXtreme BCM57766 Gigabit Ethernet PCIe(0x1686)"},
{0x14E4, 0x1687, 0xFFFF, 0xFFFF, "NetXtreme BCM5762 Gigabit Ethernet PCIe(0x1687)"},
{0x14E4, 0x1688, 0xFFFF, 0xFFFF, "NetXtreme BCM5761 10/100/1000BASE-T Ethernet(0x1688)"},
{0x14E4, 0x1688, 0x1259, 0x2708, "AT-2712 FX(0x1259-0x2708)"},
{0x14E4, 0x168A, 0xFFFF, 0xFFFF, "NetXtreme II BCM57800 1/10 Gigabit Ethernet(0x168A)"},
{0x14E4, 0x168A, 0x1014, 0x0493, "PCIe2 LP 4-Port (10Gb+1GbE) SR+RJ45 Adapter (FC EN0T; CCIN 2CC3)(0x1014-0x0493)"},
{0x14E4, 0x168A, 0x1014, 0x0494, "PCIe2 LP 4-Port (10Gb+1GbE) SR+RJ45 Adapter (FC EN0T; CCIN 2CC3)(0x1014-0x0494)"},
{0x14E4, 0x168A, 0x1028, 0x1F5C, "BCM57800 10-Gigabit Ethernet(0x1028-0x1F5C)"},
{0x14E4, 0x168A, 0x1028, 0x1F5D, "BCM57800 10-Gigabit Ethernet(0x1028-0x1F5D)"},
{0x14E4, 0x168A, 0x1028, 0x1F67, "BCM57800 1-Gigabit Ethernet(0x1028-0x1F67)"},
{0x14E4, 0x168A, 0x1028, 0x1F68, "BCM57800 1-Gigabit Ethernet(0x1028-0x1F68)"},
{0x14E4, 0x168D, 0xFFFF, 0xFFFF, "NetXtreme II BCM57840 10/20 Gigabit Ethernet(0x168D)"},
{0x14E4, 0x168E, 0xFFFF, 0xFFFF, "NetXtreme II BCM57810 10 Gigabit Ethernet(0x168E)"},
{0x14E4, 0x168E, 0x1014, 0x0492, "PCIe2 2-port 10 GbE BaseT RJ45 Adapter (FC EN0W; CCIN 2CC4)(0x1014-0x0492)"},
{0x14E4, 0x168E, 0x103C, 0x1798, "Flex-10 10Gb 2-port 530FLB Adapter [Meru](0x103C-0x1798)"},
{0x14E4, 0x168E, 0x103C, 0x17A5, "Flex-10 10Gb 2-port 530M Adapter(0x103C-0x17A5)"},
{0x14E4, 0x168E, 0x103C, 0x18D3, "Ethernet 10Gb 2-port 530T Adapter(0x103C-0x18D3)"},
{0x14E4, 0x168E, 0x103C, 0x1930, "FlexFabric 10Gb 2-port 534FLR-SFP+ Adapter(0x103C-0x1930)"},
{0x14E4, 0x168E, 0x103C, 0x1931, "StoreFabric CN1100R Dual Port Converged Network Adapter(0x103C-0x1931)"},
{0x14E4, 0x168E, 0x103C, 0x1932, "FlexFabric 10Gb 2-port 534FLB Adapter(0x103C-0x1932)"},
{0x14E4, 0x168E, 0x103C, 0x1933, "FlexFabric 10Gb 2-port 534M Adapter(0x103C-0x1933)"},
{0x14E4, 0x168E, 0x103C, 0x193A, "FlexFabric 10Gb 2-port 533FLR-T Adapter(0x103C-0x193A)"},
{0x14E4, 0x168E, 0x103C, 0x3382, "Ethernet 10Gb 2-port 530FLR-SFP+ Adapter(0x103C-0x3382)"},
{0x14E4, 0x168E, 0x103C, 0x339D, "Ethernet 10Gb 2-port 530SFP+ Adapter(0x103C-0x339D)"},
{0x14E4, 0x168E, 0x193D, 0x1003, "530F-B(0x193D-0x1003)"},
{0x14E4, 0x168E, 0x193D, 0x1006, "530F-L(0x193D-0x1006)"},
{0x14E4, 0x168E, 0x193D, 0x100F, "NIC-ETH522i-Mb-2x10G(0x193D-0x100F)"},
{0x14E4, 0x168E, 0x4C52, 0x9812, "LREC9812AF Dual-port 10Gb Ethernet Server Adapter(0x4C52-0x9812)"},
{0x14E4, 0x1690, 0xFFFF, 0xFFFF, "NetXtreme BCM57760 Gigabit Ethernet PCIe(0x1690)"},
{0x14E4, 0x1691, 0xFFFF, 0xFFFF, "NetLink BCM57788 Gigabit Ethernet PCIe(0x1691)"},
{0x14E4, 0x1691, 0x1028, 0x04AA, "XPS 8300(0x1028-0x04AA)"},
{0x14E4, 0x1692, 0xFFFF, 0xFFFF, "NetLink BCM57780 Gigabit Ethernet PCIe(0x1692)"},
{0x14E4, 0x1692, 0x1025, 0x033D, "Aspire 7740G(0x1025-0x033D)"},
{0x14E4, 0x1693, 0xFFFF, 0xFFFF, "NetLink BCM5787M Gigabit Ethernet PCI Express(0x1693)"},
{0x14E4, 0x1693, 0x1025, 0x0121, "Aspire 5920G(0x1025-0x0121)"},
{0x14E4, 0x1693, 0x103C, 0x30C0, "6710b(0x103C-0x30C0)"},
{0x14E4, 0x1693, 0x17AA, 0x20D5, "ThinkPad R61(0x17AA-0x20D5)"},
{0x14E4, 0x1694, 0xFFFF, 0xFFFF, "NetLink BCM57790 Gigabit Ethernet PCIe(0x1694)"},
{0x14E4, 0x1696, 0xFFFF, 0xFFFF, "NetXtreme BCM5782 Gigabit Ethernet(0x1696)"},
{0x14E4, 0x1696, 0x103C, 0x12BC, "d530 CMT (DG746A)(0x103C-0x12BC)"},
{0x14E4, 0x1696, 0x14E4, 0x000D, "NetXtreme BCM5782 1000Base-T(0x14E4-0x000D)"},
{0x14E4, 0x1698, 0xFFFF, 0xFFFF, "NetLink BCM5784M Gigabit Ethernet PCIe(0x1698)"},
{0x14E4, 0x1699, 0xFFFF, 0xFFFF, "NetLink BCM5785 Gigabit Ethernet(0x1699)"},
{0x14E4, 0x169A, 0xFFFF, 0xFFFF, "NetLink BCM5786 Gigabit Ethernet PCI Express(0x169A)"},
{0x14E4, 0x169B, 0xFFFF, 0xFFFF, "NetLink BCM5787 Gigabit Ethernet PCI Express(0x169B)"},
{0x14E4, 0x169C, 0xFFFF, 0xFFFF, "NetXtreme BCM5788 Gigabit Ethernet(0x169C)"},
{0x14E4, 0x169C, 0x103C, 0x308B, "MX6125(0x103C-0x308B)"},
{0x14E4, 0x169C, 0x103C, 0x30A1, "NC2400(0x103C-0x30A1)"},
{0x14E4, 0x169C, 0x144D, 0xC018, "X20(0x144D-0xC018)"},
{0x14E4, 0x169C, 0x1462, 0x590C, "KT6 Delta-FIS2R (MS-6590)(0x1462-0x590C)"},
{0x14E4, 0x169D, 0xFFFF, 0xFFFF, "NetLink BCM5789 Gigabit Ethernet PCI Express(0x169D)"},
{0x14E4, 0x16A0, 0xFFFF, 0xFFFF, "NetLink BCM5785 Fast Ethernet(0x16A0)"},
{0x14E4, 0x16A1, 0xFFFF, 0xFFFF, "BCM57840 NetXtreme II 10 Gigabit Ethernet(0x16A1)"},
{0x14E4, 0x16A1, 0x1043, 0x866E, "PEB-10G/57840-2T 10GBase-T Network Adapter(0x1043-0x866E)"},
{0x14E4, 0x16A1, 0x193D, 0x100B, "NIC-ETH521i-Mb-4x10G(0x193D-0x100B)"},
{0x14E4, 0x16A1, 0x4C52, 0x9814, "LREC9814AF Quad-port 10Gb Ethernet Server Adapter(0x4C52-0x9814)"},
{0x14E4, 0x16A2, 0xFFFF, 0xFFFF, "BCM57840 NetXtreme II 10/20-Gigabit Ethernet(0x16A2)"},
{0x14E4, 0x16A2, 0x103C, 0x1916, "FlexFabric 20Gb 2-port 630FLB Adapter(0x103C-0x1916)"},
{0x14E4, 0x16A2, 0x103C, 0x1917, "FlexFabric 20Gb 2-port 630M Adapter(0x103C-0x1917)"},
{0x14E4, 0x16A2, 0x103C, 0x2231, "3820C 10/20Gb Converged Network Adapter(0x103C-0x2231)"},
{0x14E4, 0x16A2, 0x103C, 0x22FA, "FlexFabric 10Gb 2-port 536FLB Adapter(0x103C-0x22FA)"},
{0x14E4, 0x16A3, 0xFFFF, 0xFFFF, "NetXtreme BCM57786 Gigabit Ethernet PCIe(0x16A3)"},
{0x14E4, 0x16A4, 0xFFFF, 0xFFFF, "BCM57840 NetXtreme II Ethernet Multi Function(0x16A4)"},
{0x14E4, 0x16A4, 0x103C, 0x1916, "NPAR 20Gb 2-port 630FLB Adapter(0x103C-0x1916)"},
{0x14E4, 0x16A4, 0x103C, 0x1917, "NPAR 20Gb 2-port 630M Adapter(0x103C-0x1917)"},
{0x14E4, 0x16A4, 0x103C, 0x2231, "3820C 10/20Gb Converged Network Adapter (NPAR 1.5)(0x103C-0x2231)"},
{0x14E4, 0x16A4, 0x103C, 0x22FA, "FlexFabric 10Gb 2-port 536FLB Adapter (NPAR 1.5)(0x103C-0x22FA)"},
{0x14E4, 0x16A5, 0xFFFF, 0xFFFF, "NetXtreme II BCM57800 1/10 Gigabit Ethernet Multi Function(0x16A5)"},
{0x14E4, 0x16A5, 0x1028, 0x1F5C, "NetXtreme II BCM57800 10-Gigabit Ethernet Multi Function(0x1028-0x1F5C)"},
{0x14E4, 0x16A5, 0x1028, 0x1F5D, "NetXtreme II BCM57800 10-Gigabit Ethernet Multi Function(0x1028-0x1F5D)"},
{0x14E4, 0x16A5, 0x1028, 0x1F67, "NetXtreme II BCM57800 1-Gigabit Ethernet Multi Function(0x1028-0x1F67)"},
{0x14E4, 0x16A5, 0x1028, 0x1F68, "NetXtreme II BCM57800 1-Gigabit Ethernet Multi Function(0x1028-0x1F68)"},
{0x14E4, 0x16A6, 0xFFFF, 0xFFFF, "NetXtreme BCM5702X Gigabit Ethernet(0x16A6)"},
{0x14E4, 0x16A6, 0x0E11, 0x00BB, "NC7760 Gigabit Server Adapter (PCI-X, 10/100/1000-T)(0x0E11-0x00BB)"},
{0x14E4, 0x16A6, 0x1028, 0x0126, "BCM5702 1000Base-T(0x1028-0x0126)"},
{0x14E4, 0x16A6, 0x14E4, 0x000C, "BCM5702 1000Base-T(0x14E4-0x000C)"},
{0x14E4, 0x16A6, 0x14E4, 0x8009, "BCM5702 1000Base-T(0x14E4-0x8009)"},
{0x14E4, 0x16A7, 0xFFFF, 0xFFFF, "NetXtreme BCM5703X Gigabit Ethernet(0x16A7)"},
{0x14E4, 0x16A7, 0x0E11, 0x00CA, "NC7771 Gigabit Server Adapter (PCI-X, 10,100,1000-T)(0x0E11-0x00CA)"},
{0x14E4, 0x16A7, 0x0E11, 0x00CB, "NC7781 Gigabit Server Adapter (PCI-X, 10,100,1000-T)(0x0E11-0x00CB)"},
{0x14E4, 0x16A7, 0x1014, 0x026F, "eServer xSeries server mainboard(0x1014-0x026F)"},
{0x14E4, 0x16A7, 0x14E4, 0x0009, "NetXtreme BCM5703 1000Base-T(0x14E4-0x0009)"},
{0x14E4, 0x16A7, 0x14E4, 0x000A, "NetXtreme BCM5703 1000Base-SX(0x14E4-0x000A)"},
{0x14E4, 0x16A7, 0x14E4, 0x000B, "NetXtreme BCM5703 1000Base-T(0x14E4-0x000B)"},
{0x14E4, 0x16A7, 0x14E4, 0x800A, "NetXtreme BCM5703 1000Base-T(0x14E4-0x800A)"},
{0x14E4, 0x16A8, 0xFFFF, 0xFFFF, "NetXtreme BCM5704S Gigabit Ethernet(0x16A8)"},
{0x14E4, 0x16A8, 0x103C, 0x132B, "PCI-X 1000Mbps Dual-port Built-in(0x103C-0x132B)"},
{0x14E4, 0x16A8, 0x10A9, 0x8014, "Dual Port Gigabit Ethernet (PCI-X,Fiber)(0x10A9-0x8014)"},
{0x14E4, 0x16A8, 0x10A9, 0x801C, "Quad Port Gigabit Ethernet (PCI-E,Fiber)(0x10A9-0x801C)"},
{0x14E4, 0x16A8, 0x10B7, 0x2001, "3C998-SX Dual Port 1000-SX PCI-X(0x10B7-0x2001)"},
{0x14E4, 0x16A9, 0xFFFF, 0xFFFF, "NetXtreme II BCM57800 1/10 Gigabit Ethernet Virtual Function(0x16A9)"},
{0x14E4, 0x16A9, 0x1028, 0x1F5C, "NetXtreme II BCM57800 10-Gigabit Ethernet Virtual Function(0x1028-0x1F5C)"},
{0x14E4, 0x16A9, 0x1028, 0x1F5D, "NetXtreme II BCM57800 10-Gigabit Ethernet Virtual Function(0x1028-0x1F5D)"},
{0x14E4, 0x16A9, 0x1028, 0x1F67, "NetXtreme II BCM57800 1-Gigabit Ethernet Virtual Function(0x1028-0x1F67)"},
{0x14E4, 0x16A9, 0x1028, 0x1F68, "NetXtreme II BCM57800 1-Gigabit Ethernet Virtual Function(0x1028-0x1F68)"},
{0x14E4, 0x16AA, 0xFFFF, 0xFFFF, "NetXtreme II BCM5706S Gigabit Ethernet(0x16AA)"},
{0x14E4, 0x16AA, 0x103C, 0x3102, "NC370F MultifuNCtion Gigabit Server Adapter(0x103C-0x3102)"},
{0x14E4, 0x16AA, 0x103C, 0x310C, "NC370i Multifunction Gigabit Server Adapter(0x103C-0x310C)"},
{0x14E4, 0x16AB, 0xFFFF, 0xFFFF, "NetXtreme II BCM57840 10/20 Gigabit Ethernet Multi Function(0x16AB)"},
{0x14E4, 0x16AC, 0xFFFF, 0xFFFF, "NetXtreme II BCM5708S Gigabit Ethernet(0x16AC)"},
{0x14E4, 0x16AC, 0x1014, 0x0304, "NetXtreme II BCM5708S Gigabit Ethernet(0x1014-0x0304)"},
{0x14E4, 0x16AC, 0x1028, 0x01BB, "PowerEdge 1955 Broadcom NetXtreme II BCM5708S(0x1028-0x01BB)"},
{0x14E4, 0x16AC, 0x1028, 0x020C, "PowerEdge M605 Broadcom NetXtreme II BCM5708S(0x1028-0x020C)"},
{0x14E4, 0x16AC, 0x103C, 0x1706, "NC373m Multifunction Gigabit Server Adapter(0x103C-0x1706)"},
{0x14E4, 0x16AC, 0x103C, 0x7038, "NC373i PCI Express Multifunction Gigabit Server Adapter(0x103C-0x7038)"},
{0x14E4, 0x16AC, 0x103C, 0x703B, "NC373i Integrated Multifunction Gigabit Server Adapter(0x103C-0x703B)"},
{0x14E4, 0x16AC, 0x103C, 0x703D, "NC373F PCI Express Multifunction Gigabit Server Adapter(0x103C-0x703D)"},
{0x14E4, 0x16AD, 0xFFFF, 0xFFFF, "NetXtreme II BCM57840 10/20 Gigabit Ethernet Virtual Function(0x16AD)"},
{0x14E4, 0x16AD, 0x103C, 0x1916, "FlexFabric 20Gb 2-port 630FLB Adapter(0x103C-0x1916)"},
{0x14E4, 0x16AD, 0x103C, 0x1917, "FlexFabric 20Gb 2-port 630M Adapter(0x103C-0x1917)"},
{0x14E4, 0x16AD, 0x103C, 0x2231, "3820C 10/20Gb Converged Network Adapter (SR-IOV VF)(0x103C-0x2231)"},
{0x14E4, 0x16AD, 0x103C, 0x22FA, "FlexFabric 10Gb 2-port 536FLB Adapter (SR-IOV VF)(0x103C-0x22FA)"},
{0x14E4, 0x16AE, 0xFFFF, 0xFFFF, "NetXtreme II BCM57810 10 Gigabit Ethernet Multi Function(0x16AE)"},
{0x14E4, 0x16AE, 0x103C, 0x1798, "NPAR 10Gb 2-port 530FLB Adapter(0x103C-0x1798)"},
{0x14E4, 0x16AE, 0x103C, 0x17A5, "NPAR 10Gb 2-port 530M Adapter(0x103C-0x17A5)"},
{0x14E4, 0x16AE, 0x103C, 0x18D3, "NPAR 10Gb 2-port 530T Adapter(0x103C-0x18D3)"},
{0x14E4, 0x16AE, 0x103C, 0x1930, "NPAR 10Gb 2-port 534FLR-SFP+ Adapter(0x103C-0x1930)"},
{0x14E4, 0x16AE, 0x103C, 0x1931, "NPAR CN1100R Dual Port Converged Network Adapter(0x103C-0x1931)"},
{0x14E4, 0x16AE, 0x103C, 0x1932, "NPAR 10Gb 2-port 534FLB Adapter(0x103C-0x1932)"},
{0x14E4, 0x16AE, 0x103C, 0x1933, "NPAR 10Gb 2-port 534M Adapter(0x103C-0x1933)"},
{0x14E4, 0x16AE, 0x103C, 0x193A, "NPAR 10Gb 2-port 533FLR-T Adapter(0x103C-0x193A)"},
{0x14E4, 0x16AE, 0x103C, 0x3382, "NPAR 10Gb 2-port 530FLR-SFP+ Adapter(0x103C-0x3382)"},
{0x14E4, 0x16AE, 0x103C, 0x339D, "NPAR 10Gb 2-port 530SFP+ Adapter(0x103C-0x339D)"},
{0x14E4, 0x16AF, 0xFFFF, 0xFFFF, "NetXtreme II BCM57810 10 Gigabit Ethernet Virtual Function(0x16AF)"},
{0x14E4, 0x16AF, 0x103C, 0x1798, "Flex-10 10Gb 2-port 530FLB Adapter(0x103C-0x1798)"},
{0x14E4, 0x16AF, 0x103C, 0x17A5, "Flex-10 10Gb 2-port 530M Adapter(0x103C-0x17A5)"},
{0x14E4, 0x16AF, 0x103C, 0x18D3, "Ethernet 10Gb 2-port 530T Adapter(0x103C-0x18D3)"},
{0x14E4, 0x16AF, 0x103C, 0x1930, "FlexFabric 10Gb 2-port 534FLR-SFP+ Adapter(0x103C-0x1930)"},
{0x14E4, 0x16AF, 0x103C, 0x1931, "StoreFabric CN1100R Dual Port Converged Network Adapter(0x103C-0x1931)"},
{0x14E4, 0x16AF, 0x103C, 0x1932, "FlexFabric 10Gb 2-port 534FLB Adapter(0x103C-0x1932)"},
{0x14E4, 0x16AF, 0x103C, 0x1933, "FlexFabric 10Gb 2-port 534M Adapter(0x103C-0x1933)"},
{0x14E4, 0x16AF, 0x103C, 0x193A, "FlexFabric 10Gb 2-port 533FLR-T Adapter(0x103C-0x193A)"},
{0x14E4, 0x16AF, 0x103C, 0x3382, "Ethernet 10Gb 2-port 530FLR-SFP+ Adapter(0x103C-0x3382)"},
{0x14E4, 0x16AF, 0x103C, 0x339D, "Ethernet 10Gb 2-port 530SFP+ Adapter(0x103C-0x339D)"},
{0x14E4, 0x16B0, 0xFFFF, 0xFFFF, "NetXtreme BCM57761 Gigabit Ethernet PCIe(0x16B0)"},
{0x14E4, 0x16B1, 0xFFFF, 0xFFFF, "NetLink BCM57781 Gigabit Ethernet PCIe(0x16B1)"},
{0x14E4, 0x16B1, 0x1849, 0x96B1, "Z77 Extreme4 motherboard(0x1849-0x96B1)"},
{0x14E4, 0x16B2, 0xFFFF, 0xFFFF, "NetLink BCM57791 Gigabit Ethernet PCIe(0x16B2)"},
{0x14E4, 0x16B3, 0xFFFF, 0xFFFF, "NetXtreme BCM57786 Gigabit Ethernet PCIe(0x16B3)"},
{0x14E4, 0x16B4, 0xFFFF, 0xFFFF, "NetXtreme BCM57765 Gigabit Ethernet PCIe(0x16B4)"},
{0x14E4, 0x16B5, 0xFFFF, 0xFFFF, "NetLink BCM57785 Gigabit Ethernet PCIe(0x16B5)"},
{0x14E4, 0x16B6, 0xFFFF, 0xFFFF, "NetLink BCM57795 Gigabit Ethernet PCIe(0x16B6)"},
{0x14E4, 0x16B7, 0xFFFF, 0xFFFF, "NetXtreme BCM57782 Gigabit Ethernet PCIe(0x16B7)"},
{0x14E4, 0x16BC, 0xFFFF, 0xFFFF, "BCM57765/57785 SDXC/MMC Card Reader(0x16BC)"},
{0x14E4, 0x16BE, 0xFFFF, 0xFFFF, "BCM57765/57785 MS Card Reader(0x16BE)"},
{0x14E4, 0x16BF, 0xFFFF, 0xFFFF, "BCM57765/57785 xD-Picture Card Reader(0x16BF)"},
{0x14E4, 0x16C1, 0xFFFF, 0xFFFF, "NetXtreme-E RDMA Virtual Function(0x16C1)"},
{0x14E4, 0x16C6, 0xFFFF, 0xFFFF, "NetXtreme BCM5702A3 Gigabit Ethernet(0x16C6)"},
{0x14E4, 0x16C6, 0x10B7, 0x1100, "3C1000B-T 10/100/1000 PCI(0x10B7-0x1100)"},
{0x14E4, 0x16C6, 0x14E4, 0x000C, "BCM5702 1000Base-T(0x14E4-0x000C)"},
{0x14E4, 0x16C6, 0x14E4, 0x8009, "BCM5702 1000Base-T(0x14E4-0x8009)"},
{0x14E4, 0x16C7, 0xFFFF, 0xFFFF, "NetXtreme BCM5703 Gigabit Ethernet(0x16C7)"},
{0x14E4, 0x16C7, 0x0E11, 0x00CA, "NC7771 Gigabit Server Adapter (PCI-X, 10,100,1000-T)(0x0E11-0x00CA)"},
{0x14E4, 0x16C7, 0x0E11, 0x00CB, "NC7781 Gigabit Server Adapter (PCI-X, 10,100,1000-T)(0x0E11-0x00CB)"},
{0x14E4, 0x16C7, 0x103C, 0x12C3, "Combo FC/GigE-SX [A9782A](0x103C-0x12C3)"},
{0x14E4, 0x16C7, 0x103C, 0x12CA, "Combo FC/GigE-T [A9784A](0x103C-0x12CA)"},
{0x14E4, 0x16C7, 0x103C, 0x1321, "Core I/O LAN/SCSI Combo [AB314A](0x103C-0x1321)"},
{0x14E4, 0x16C7, 0x14E4, 0x0009, "NetXtreme BCM5703 1000Base-T(0x14E4-0x0009)"},
{0x14E4, 0x16C7, 0x14E4, 0x000A, "NetXtreme BCM5703 1000Base-SX(0x14E4-0x000A)"},
{0x14E4, 0x16C8, 0xFFFF, 0xFFFF, "BCM57301 NetXtreme-C 10Gb Ethernet Controller(0x16C8)"},
{0x14E4, 0x16C9, 0xFFFF, 0xFFFF, "BCM57302 NetXtreme-C 10Gb/25Gb Ethernet Controller(0x16C9)"},
{0x14E4, 0x16CA, 0xFFFF, 0xFFFF, "BCM57304 NetXtreme-C 10Gb/25Gb/40Gb/50Gb Ethernet Controller(0x16CA)"},
{0x14E4, 0x16CB, 0xFFFF, 0xFFFF, "NetXtreme-C Ethernet Virtual Function(0x16CB)"},
{0x14E4, 0x16CC, 0xFFFF, 0xFFFF, "BCM57417 NetXtreme-E Ethernet Partition(0x16CC)"},
{0x14E4, 0x16CE, 0xFFFF, 0xFFFF, "BCM57311 NetXtreme-C 10Gb RDMA Ethernet Controller(0x16CE)"},
{0x14E4, 0x16CF, 0xFFFF, 0xFFFF, "BCM57312 NetXtreme-C 10Gb/25Gb RDMA Ethernet Controller(0x16CF)"},
{0x14E4, 0x16D0, 0xFFFF, 0xFFFF, "BCM57402 NetXtreme-E 10Gb Ethernet Controller(0x16D0)"},
{0x14E4, 0x16D1, 0xFFFF, 0xFFFF, "BCM57404 NetXtreme-E 10Gb/25Gb Ethernet Controller(0x16D1)"},
{0x14E4, 0x16D2, 0xFFFF, 0xFFFF, "BCM57406 NetXtreme-E 10GBASE-T Ethernet Controller(0x16D2)"},
{0x14E4, 0x16D3, 0xFFFF, 0xFFFF, "NetXtreme-E Ethernet Virtual Function(0x16D3)"},
{0x14E4, 0x16D4, 0xFFFF, 0xFFFF, "BCM57402 NetXtreme-E Ethernet Partition(0x16D4)"},
{0x14E4, 0x16D5, 0xFFFF, 0xFFFF, "BCM57407 NetXtreme-E 10GBase-T Ethernet Controller(0x16D5)"},
{0x14E4, 0x16D6, 0xFFFF, 0xFFFF, "BCM57412 NetXtreme-E 10Gb RDMA Ethernet Controller(0x16D6)"},
{0x14E4, 0x16D6, 0x117C, 0x00CD, "FastFrame N4S2 Dual-port 10Gb Ethernet Adapter(0x117C-0x00CD)"},
{0x14E4, 0x16D6, 0x14E4, 0x1202, "BCM957412M4122C OCP 1x25G Type1 wRoCE(0x14E4-0x1202)"},
{0x14E4, 0x16D6, 0x14E4, 0x4120, "NetXtreme E-Series Advanced Dual-port 10Gb SFP+ Ethernet Network Daughter Card(0x14E4-0x4120)"},
{0x14E4, 0x16D6, 0x14E4, 0x4126, "NetXtreme-E Dual-port 10G SFP+ Ethernet OCP 3.0 Adapter (BCM957412N4120C)(0x14E4-0x4126)"},
{0x14E4, 0x16D6, 0x152D, 0x8B20, "BCM57412 NetXtreme-E 10Gb RDMA Ethernet Controller(0x152D-0x8B20)"},
{0x14E4, 0x16D6, 0x152D, 0x8B22, "BCM57412 NetXtreme-E 25Gb RDMA Ethernet Controller(0x152D-0x8B22)"},
{0x14E4, 0x16D6, 0x193D, 0x1024, "NIC-ETH531F-LP-2P(0x193D-0x1024)"},
{0x14E4, 0x16D6, 0x193D, 0x1087, "NIC-ETH531F-3S-2P(0x193D-0x1087)"},
{0x14E4, 0x16D7, 0xFFFF, 0xFFFF, "BCM57414 NetXtreme-E 10Gb/25Gb RDMA Ethernet Controller(0x16D7)"},
{0x14E4, 0x16D7, 0x117C, 0x00CC, "FastFrame N422 Dual-port 25Gb Ethernet Adapter(0x117C-0x00CC)"},
{0x14E4, 0x16D7, 0x14E4, 0x1402, "BCM957414A4142CC 10Gb/25Gb Ethernet PCIe(0x14E4-0x1402)"},
{0x14E4, 0x16D7, 0x14E4, 0x1404, "BCM957414M4142C OCP 2x25G Type1 wRoCE(0x14E4-0x1404)"},
{0x14E4, 0x16D7, 0x14E4, 0x4140, "NetXtreme E-Series Advanced Dual-port 25Gb SFP28 Network Daughter Card(0x14E4-0x4140)"},
{0x14E4, 0x16D7, 0x14E4, 0x4143, "NetXtreme-E Single-port 40Gb/50Gb Ethernet OCP 2.0 Adapter (BCM957414M4143C)(0x14E4-0x4143)"},
{0x14E4, 0x16D7, 0x14E4, 0x4146, "NetXtreme-E Dual-port 25G SFP28 Ethernet OCP 3.0 Adapter (BCM957414N4140C)(0x14E4-0x4146)"},
{0x14E4, 0x16D7, 0x1590, 0x020E, "Ethernet 25Gb 2-port 631SFP28 Adapter(0x1590-0x020E)"},
{0x14E4, 0x16D7, 0x1590, 0x0211, "Ethernet 25Gb 2-port 631FLR-SFP28 Adapter(0x1590-0x0211)"},
{0x14E4, 0x16D7, 0x193D, 0x1033, "NIC-ETH630F-LP-2P(0x193D-0x1033)"},
{0x14E4, 0x16D7, 0x1BD4, 0x008E, "ENFB2251-SP2(0x1BD4-0x008E)"},
{0x14E4, 0x16D7, 0x1BD4, 0x008F, "ENPB2251-SP2(0x1BD4-0x008F)"},
{0x14E4, 0x16D7, 0x1EEC, 0x0101, "VSE-225-31S Dual-port 10Gb/25Gb Ethernet PCIe(0x1EEC-0x0101)"},
{0x14E4, 0x16D8, 0xFFFF, 0xFFFF, "BCM57416 NetXtreme-E Dual-Media 10G RDMA Ethernet Controller(0x16D8)"},
{0x14E4, 0x16D8, 0x1028, 0x1FEB, "NetXtreme-E 10Gb SFP+ Adapter(0x1028-0x1FEB)"},
{0x14E4, 0x16D8, 0x117C, 0x00CE, "FastFrame N4T2 Dual-port 10GBASE-T Ethernet Adapter(0x117C-0x00CE)"},
{0x14E4, 0x16D8, 0x14E4, 0x4163, "NetXtreme-E Dual-port 10GBASE-T Ethernet OCP 2.0 Adapter (BCM957416M4163C)(0x14E4-0x4163)"},
{0x14E4, 0x16D8, 0x14E4, 0x4166, "NetXtreme-E Dual-port 10GBASE-T Ethernet OCP 3.0 Adapter (BCM957416N4160C)(0x14E4-0x4166)"},
{0x14E4, 0x16D8, 0x14E4, 0xD140, "BCM957416-P410 4x10GBT Ethernet NIC(0x14E4-0xD140)"},
{0x14E4, 0x16D8, 0x14E4, 0xD340, "BCM957416-N410 4x10GBT Ethernet NIC(0x14E4-0xD340)"},
{0x14E4, 0x16D8, 0x1590, 0x020C, "Ethernet 10Gb 2-port 535T Adapter(0x1590-0x020C)"},
{0x14E4, 0x16D8, 0x1590, 0x0212, "Ethernet 10Gb 2-port 535FLR-T Adapter(0x1590-0x0212)"},
{0x14E4, 0x16D9, 0xFFFF, 0xFFFF, "BCM57417 NetXtreme-E 10GBASE-T RDMA Ethernet Controller(0x16D9)"},
{0x14E4, 0x16D9, 0x108E, 0x4866, "Dual Port 10GBase-T Ethernet Controller(0x108E-0x4866)"},
{0x14E4, 0x16DC, 0xFFFF, 0xFFFF, "NetXtreme-E Ethernet Virtual Function(0x16DC)"},
{0x14E4, 0x16DD, 0xFFFF, 0xFFFF, "NetLink BCM5781 Gigabit Ethernet PCI Express(0x16DD)"},
{0x14E4, 0x16DE, 0xFFFF, 0xFFFF, "BCM57412 NetXtreme-E Ethernet Partition(0x16DE)"},
{0x14E4, 0x16DF, 0xFFFF, 0xFFFF, "BCM57314 NetXtreme-C 10Gb/25Gb/40Gb/50Gb RDMA Ethernet Controller(0x16DF)"},
{0x14E4, 0x16E1, 0xFFFF, 0xFFFF, "NetXtreme-C Ethernet Virtual Function(0x16E1)"},
{0x14E4, 0x16E2, 0xFFFF, 0xFFFF, "BCM57417 NetXtreme-E 10Gb/25Gb RDMA Ethernet Controller(0x16E2)"},
{0x14E4, 0x16E2, 0x108E, 0x4866, "Dual Port 10Gb/25Gb SFP28 Ethernet Controller(0x108E-0x4866)"},
{0x14E4, 0x16E3, 0xFFFF, 0xFFFF, "BCM57416 NetXtreme-E 10Gb RDMA Ethernet Controller(0x16E3)"},
{0x14E4, 0x16E5, 0xFFFF, 0xFFFF, "NetXtreme-C RDMA Virtual Function(0x16E5)"},
{0x14E4, 0x16E7, 0xFFFF, 0xFFFF, "BCM57404 NetXtreme-E Ethernet Partition(0x16E7)"},
{0x14E4, 0x16E8, 0xFFFF, 0xFFFF, "BCM57406 NetXtreme-E Ethernet Partition(0x16E8)"},
{0x14E4, 0x16E9, 0xFFFF, 0xFFFF, "BCM57407 NetXtreme-E 25Gb Ethernet Controller(0x16E9)"},
{0x14E4, 0x16EB, 0xFFFF, 0xFFFF, "BCM57412 NetXtreme-E RDMA Partition(0x16EB)"},
{0x14E4, 0x16EC, 0xFFFF, 0xFFFF, "BCM57414 NetXtreme-E Ethernet Partition(0x16EC)"},
{0x14E4, 0x16ED, 0xFFFF, 0xFFFF, "BCM57414 NetXtreme-E RDMA Partition(0x16ED)"},
{0x14E4, 0x16EE, 0xFFFF, 0xFFFF, "BCM57416 NetXtreme-E Ethernet Partition(0x16EE)"},
{0x14E4, 0x16EF, 0xFFFF, 0xFFFF, "BCM57416 NetXtreme-E RDMA Partition(0x16EF)"},
{0x14E4, 0x16F1, 0xFFFF, 0xFFFF, "BCM57452 NetXtreme-E 10Gb/25Gb/40Gb/50Gb Ethernet(0x16F1)"},
{0x14E4, 0x16F3, 0xFFFF, 0xFFFF, "NetXtreme BCM5727 Gigabit Ethernet PCIe(0x16F3)"},
{0x14E4, 0x16F7, 0xFFFF, 0xFFFF, "NetXtreme BCM5753 Gigabit Ethernet PCI Express(0x16F7)"},
{0x14E4, 0x16FD, 0xFFFF, 0xFFFF, "NetXtreme BCM5753M Gigabit Ethernet PCI Express(0x16FD)"},
{0x14E4, 0x16FD, 0x103C, 0x309F, "Compaq nx9420 Notebook(0x103C-0x309F)"},
{0x14E4, 0x16FD, 0x103C, 0x30A3, "Compaq nw8440(0x103C-0x30A3)"},
{0x14E4, 0x16FE, 0xFFFF, 0xFFFF, "NetXtreme BCM5753F Fast Ethernet PCI Express(0x16FE)"},
{0x14E4, 0x170C, 0xFFFF, 0xFFFF, "BCM4401-B0 100Base-TX(0x170C)"},
{0x14E4, 0x170C, 0x1028, 0x0188, "Inspiron 6000 laptop(0x1028-0x0188)"},
{0x14E4, 0x170C, 0x1028, 0x018D, "Inspiron 700m/710m(0x1028-0x018D)"},
{0x14E4, 0x170C, 0x1028, 0x0196, "Inspiron 5160(0x1028-0x0196)"},
{0x14E4, 0x170C, 0x1028, 0x01AF, "Inspiron 6400(0x1028-0x01AF)"},
{0x14E4, 0x170C, 0x1028, 0x01CD, "Inspiron 9400 Laptop(0x1028-0x01CD)"},
{0x14E4, 0x170C, 0x1028, 0x01D7, "XPS M1210(0x1028-0x01D7)"},
{0x14E4, 0x170C, 0x1028, 0x01D8, "Inspiron E1405(0x1028-0x01D8)"},
{0x14E4, 0x170C, 0x103C, 0x099C, "NX6110/NC6120(0x103C-0x099C)"},
{0x14E4, 0x170C, 0x103C, 0x30A2, "NX7300 laptop(0x103C-0x30A2)"},
{0x14E4, 0x170C, 0x14E4, 0x170C, "HP Compaq 6720t Mobile Thin Client(0x14E4-0x170C)"},
{0x14E4, 0x170D, 0xFFFF, 0xFFFF, "NetXtreme BCM5901 100Base-TX(0x170D)"},
{0x14E4, 0x170D, 0x1014, 0x0545, "ThinkPad R40e(0x1014-0x0545)"},
{0x14E4, 0x170E, 0xFFFF, 0xFFFF, "NetXtreme BCM5901 100Base-TX(0x170E)"},
{0x14E4, 0x1712, 0xFFFF, 0xFFFF, "NetLink BCM5906 Fast Ethernet PCI Express(0x1712)"},
{0x14E4, 0x1713, 0xFFFF, 0xFFFF, "NetLink BCM5906M Fast Ethernet PCI Express(0x1713)"},
{0x14E4, 0x1713, 0x1028, 0x01F3, "Inspiron 1420(0x1028-0x01F3)"},
{0x14E4, 0x1713, 0x1028, 0x0209, "XPS M1330(0x1028-0x0209)"},
{0x14E4, 0x1713, 0x103C, 0x30C0, "Compaq 6710b(0x103C-0x30C0)"},
{0x14E4, 0x1713, 0x17AA, 0x3A23, "IdeaPad S10e(0x17AA-0x3A23)"},
{0x14E4, 0x1750, 0xFFFF, 0xFFFF, "BCM57508 NetXtreme-E 10Gb/25Gb/40Gb/50Gb/100Gb/200Gb Ethernet(0x1750)"},
{0x14E4, 0x1750, 0x117C, 0x00CF, "FastFrame N412 Dual-port 100Gb Ethernet Adapter(0x117C-0x00CF)"},
{0x14E4, 0x1750, 0x14E4, 0x2100, "NetXtreme-E Dual-port 100G QSFP56 Ethernet PCIe4.0 x16 Adapter (BCM957508-P2100G)(0x14E4-0x2100)"},
{0x14E4, 0x1750, 0x14E4, 0x5208, "NetXtreme-E Dual-port 100G QSFP56 Ethernet OCP 3.0 Adapter (BCM957508-N2100G)(0x14E4-0x5208)"},
{0x14E4, 0x1750, 0x14E4, 0x520A, "NetXtreme-E Dual-port 100G DSFP Ethernet OCP 3.0 Adapter (BCM957508-N2100GD)(0x14E4-0x520A)"},
{0x14E4, 0x1750, 0x14E4, 0xD124, "NetXtreme-E P2100D BCM57508 2x100G QSFP PCIE(0x14E4-0xD124)"},
{0x14E4, 0x1750, 0x14E4, 0xD324, "NetXtreme-E N2100D BCM57508 2x100G QSFP OCP3.0 Ethernet(0x14E4-0xD324)"},
{0x14E4, 0x1750, 0x14E4, 0xDF24, "NetXtreme-E NGM2100D BCM57508 2x100G KR Mezz Ethernet(0x14E4-0xDF24)"},
{0x14E4, 0x1751, 0xFFFF, 0xFFFF, "BCM57504 NetXtreme-E 10Gb/25Gb/40Gb/50Gb/100Gb/200Gb Ethernet(0x1751)"},
{0x14E4, 0x1751, 0x1028, 0x09D4, "PowerEdge XR11/XR12 LOM(0x1028-0x09D4)"},
{0x14E4, 0x1751, 0x1028, 0x0B1B, "PowerEdge XR5610 LOM(0x1028-0x0B1B)"},
{0x14E4, 0x1751, 0x14E4, 0x4250, "NetXtreme-E Quad-port 25G SFP28 Ethernet PCIe4.0 x16 Adapter (BCM957504-P425G)(0x14E4-0x4250)"},
{0x14E4, 0x1751, 0x14E4, 0x5045, "NetXtreme-E BCM57504 4x25G OCP3.0(0x14E4-0x5045)"},
{0x14E4, 0x1751, 0x14E4, 0x5100, "NetXtreme-E Single-port 100G QSFP56 Ethernet OCP 3.0 Adapter (BCM957504-N1100G)(0x14E4-0x5100)"},
{0x14E4, 0x1751, 0x14E4, 0x5105, "NetXtreme-E Single-port 100G DSFP Ethernet OCP 3.0 Adapter (BCM957504-N1100GD)(0x14E4-0x5105)"},
{0x14E4, 0x1751, 0x14E4, 0x5250, "NetXtreme-E BCM57504 4x25G KR Mezz(0x14E4-0x5250)"},
{0x14E4, 0x1751, 0x14E4, 0x5425, "NetXtreme-E Quad-port 25G SFP28 Ethernet OCP 3.0 Adapter (BCM957504-N425G)(0x14E4-0x5425)"},
{0x14E4, 0x1751, 0x14E4, 0xD142, "NetXtreme-E P425D BCM57504 4x25G SFP28 PCIE(0x14E4-0xD142)"},
{0x14E4, 0x1751, 0x1590, 0x0420, "HPE Ethernet 25/50Gb 2-port 6310C Adapter(0x1590-0x0420)"},
{0x14E4, 0x1752, 0xFFFF, 0xFFFF, "BCM57502 NetXtreme-E 10Gb/25Gb/40Gb/50Gb Ethernet(0x1752)"},
{0x14E4, 0x1760, 0xFFFF, 0xFFFF, "BCM57608 10Gb/25Gb/50Gb/100Gb/200Gb/400Gb Ethernet(0x1760)"},
{0x14E4, 0x1760, 0x14E4, 0xD125, "BCM57608 2x200G PCIe Ethernet NIC(0x14E4-0xD125)"},
{0x14E4, 0x1800, 0xFFFF, 0xFFFF, "BCM57502 NetXtreme-E Ethernet Partition(0x1800)"},
{0x14E4, 0x1801, 0xFFFF, 0xFFFF, "BCM57504 NetXtreme-E Ethernet Partition(0x1801)"},
{0x14E4, 0x1802, 0xFFFF, 0xFFFF, "BCM57508 NetXtreme-E Ethernet Partition(0x1802)"},
{0x14E4, 0x1802, 0x14E4, 0xDF24, "BCM57508 NetXtreme-E NGM2100D 2x100G KR Mezz Ethernet Partition(0x14E4-0xDF24)"},
{0x14E4, 0x1803, 0xFFFF, 0xFFFF, "BCM57502 NetXtreme-E RDMA Partition(0x1803)"},
{0x14E4, 0x1804, 0xFFFF, 0xFFFF, "BCM57504 NetXtreme-E RDMA Partition(0x1804)"},
{0x14E4, 0x1805, 0xFFFF, 0xFFFF, "BCM57508 NetXtreme-E RDMA Partition(0x1805)"},
{0x14E4, 0x1805, 0x14E4, 0xDF24, "NetXtreme-E NGM2100D BCM57508 2x100G KR Mezz RDMA Partition(0x14E4-0xDF24)"},
{0x14E4, 0x1806, 0xFFFF, 0xFFFF, "BCM5750X NetXtreme-E Ethernet Virtual Function(0x1806)"},
{0x14E4, 0x1806, 0x14E4, 0xDF24, "BCM57508 NetXtreme-E NGM2100D 2x100G KR Mezz Ethernet Virtual Function(0x14E4-0xDF24)"},
{0x14E4, 0x1807, 0xFFFF, 0xFFFF, "BCM5750X NetXtreme-E RDMA Virtual Function(0x1807)"},
{0x14E4, 0x1807, 0x14E4, 0xDF24, "BCM57508 NetXtreme-E NGM2100D 2x100G KR Mezz RDMA Virtual Function(0x14E4-0xDF24)"},
{0x14E4, 0x1808, 0xFFFF, 0xFFFF, "BCM5750X NetXtreme-E Ethernet Virtual Function(0x1808)"},
{0x14E4, 0x1808, 0x14E4, 0xDF24, "BCM57508 NetXtreme-E NGM2100D 2x100G KR Mezz Ethernet Virtual Function(0x14E4-0xDF24)"},
{0x14E4, 0x1809, 0xFFFF, 0xFFFF, "BCM5750X NetXtreme-E RDMA Virtual Function(0x1809)"},
{0x14E4, 0x1809, 0x14E4, 0xDF24, "BCM57508 NetXtreme-E NGM2100D 2x100G KR Mezz RDMA Virtual Function(0x14E4-0xDF24)"},
{0x14E4, 0x2711, 0xFFFF, 0xFFFF, "BCM2711 PCIe Bridge(0x2711)"},
{0x14E4, 0x2712, 0xFFFF, 0xFFFF, "BCM2712 PCIe Bridge(0x2712)"},
{0x14E4, 0x3352, 0xFFFF, 0xFFFF, "BCM3352(0x3352)"},
{0x14E4, 0x3360, 0xFFFF, 0xFFFF, "BCM3360(0x3360)"},
{0x14E4, 0x4210, 0xFFFF, 0xFFFF, "BCM4210 iLine10 HomePNA 2.0(0x4210)"},
{0x14E4, 0x4211, 0xFFFF, 0xFFFF, "BCM4211 iLine10 HomePNA 2.0 + V.90 56k modem(0x4211)"},
{0x14E4, 0x4212, 0xFFFF, 0xFFFF, "BCM4212 v.90 56k modem(0x4212)"},
{0x14E4, 0x4220, 0xFFFF, 0xFFFF, "802-11b/g Wireless PCI controller, packaged as a Linksys WPC54G ver 1.2 PCMCIA card(0x4220)"},
{0x14E4, 0x4222, 0xFFFF, 0xFFFF, "NetXtreme BCM5753M Gigabit Ethernet PCI Express(0x4222)"},
{0x14E4, 0x4301, 0xFFFF, 0xFFFF, "BCM4301 802.11b Wireless LAN Controller(0x4301)"},
{0x14E4, 0x4301, 0x1028, 0x0407, "TrueMobile 1180 Onboard WLAN(0x1028-0x0407)"},
{0x14E4, 0x4301, 0x1043, 0x0120, "WL-103b Wireless LAN PC Card(0x1043-0x0120)"},
{0x14E4, 0x4301, 0x16A5, 0x1602, "B-300 802.11b Wireless CardBus Adapter(0x16A5-0x1602)"},
{0x14E4, 0x4301, 0x1737, 0x4301, "WMP11 v2.7 802.11b Wireless-B PCI Adapter(0x1737-0x4301)"},
{0x14E4, 0x4305, 0xFFFF, 0xFFFF, "BCM4307 V.90 56k Modem(0x4305)"},
{0x14E4, 0x4306, 0xFFFF, 0xFFFF, "BCM4306 802.11bg Wireless LAN controller(0x4306)"},
{0x14E4, 0x4307, 0xFFFF, 0xFFFF, "BCM4306 802.11bg Wireless LAN Controller(0x4307)"},
{0x14E4, 0x4310, 0xFFFF, 0xFFFF, "BCM4310 Chipcommon I/OController(0x4310)"},
{0x14E4, 0x4311, 0xFFFF, 0xFFFF, "BCM4311 802.11b/g WLAN(0x4311)"},
{0x14E4, 0x4311, 0x1028, 0x0007, "Wireless 1390 WLAN Mini-Card(0x1028-0x0007)"},
{0x14E4, 0x4311, 0x1028, 0x0008, "Wireless 1390 WLAN ExpressCard(0x1028-0x0008)"},
{0x14E4, 0x4311, 0x103C, 0x1363, "BCM4311 802.11b/g Wireless LAN Controller(0x103C-0x1363)"},
{0x14E4, 0x4311, 0x103C, 0x1364, "BCM4311 802.11b/g Wireless LAN Controller(0x103C-0x1364)"},
{0x14E4, 0x4311, 0x103C, 0x1365, "BCM4311 802.11b/g Wireless LAN Controller(0x103C-0x1365)"},
{0x14E4, 0x4311, 0x103C, 0x1374, "BCM4311 802.11b/g Wireless LAN Controller(0x103C-0x1374)"},
{0x14E4, 0x4311, 0x103C, 0x1375, "BCM4311 802.11b/g Wireless LAN Controller(0x103C-0x1375)"},
{0x14E4, 0x4311, 0x103C, 0x1376, "BCM4311 802.11b/g Wireless LAN Controller(0x103C-0x1376)"},
{0x14E4, 0x4311, 0x103C, 0x1377, "BCM4311 802.11b/g Wireless LAN Controller(0x103C-0x1377)"},
{0x14E4, 0x4311, 0x103C, 0x137F, "BCM4322 802.11a/b/g/n Wireless LAN Controller(0x103C-0x137F)"},
{0x14E4, 0x4311, 0x103C, 0x1380, "BCM4322 802.11a/b/g/n Wireless LAN Controller(0x103C-0x1380)"},
{0x14E4, 0x4311, 0x14E4, 0x4311, "BCM94311MCG(0x14E4-0x4311)"},
{0x14E4, 0x4312, 0xFFFF, 0xFFFF, "BCM4311 802.11a/b/g(0x4312)"},
{0x14E4, 0x4312, 0x1028, 0x0007, "Wireless 1490 Dual Band WLAN Mini-Card(0x1028-0x0007)"},
{0x14E4, 0x4312, 0x1028, 0x0008, "Wireless 1490 Dual Band WLAN ExpressCard(0x1028-0x0008)"},
{0x14E4, 0x4312, 0x103C, 0x135A, "Broadcom 802.11a/b/g WLAN(0x103C-0x135A)"},
{0x14E4, 0x4312, 0x103C, 0x135F, "Broadcom 802.11a/b/g WLAN(0x103C-0x135F)"},
{0x14E4, 0x4312, 0x103C, 0x1360, "Broadcom 802.11a/b/g WLAN(0x103C-0x1360)"},
{0x14E4, 0x4312, 0x103C, 0x1361, "Broadcom 802.11a/b/g WLAN(0x103C-0x1361)"},
{0x14E4, 0x4312, 0x103C, 0x1362, "Broadcom 802.11a/b/g WLAN(0x103C-0x1362)"},
{0x14E4, 0x4312, 0x103C, 0x1370, "Broadcom 802.11a/b/g WLAN(0x103C-0x1370)"},
{0x14E4, 0x4312, 0x103C, 0x1371, "Broadcom 802.11a/b/g WLAN(0x103C-0x1371)"},
{0x14E4, 0x4312, 0x103C, 0x1372, "Broadcom 802.11a/b/g WLAN(0x103C-0x1372)"},
{0x14E4, 0x4312, 0x103C, 0x1373, "Broadcom 802.11a/b/g WLAN(0x103C-0x1373)"},
{0x14E4, 0x4312, 0x103C, 0x30B5, "Presario V3242AU(0x103C-0x30B5)"},
{0x14E4, 0x4312, 0x106B, 0x0089, "AirPort Extreme(0x106B-0x0089)"},
{0x14E4, 0x4312, 0x1371, 0x103C, "Broadcom 802.11 Multiband-netwerkadapter(6715s)(0x1371-0x103C)"},
{0x14E4, 0x4313, 0xFFFF, 0xFFFF, "BCM4311 802.11a(0x4313)"},
{0x14E4, 0x4315, 0xFFFF, 0xFFFF, "BCM4312 802.11b/g LP-PHY(0x4315)"},
{0x14E4, 0x4315, 0x1028, 0x000B, "Wireless 1395 WLAN Mini-Card(0x1028-0x000B)"},
{0x14E4, 0x4315, 0x1028, 0x000C, "Wireless 1397 WLAN Mini-Card(0x1028-0x000C)"},
{0x14E4, 0x4315, 0x103C, 0x137C, "BCM4312 802.11b/g Wireless LAN Controller(0x103C-0x137C)"},
{0x14E4, 0x4315, 0x103C, 0x137D, "BCM4312 802.11b/g Wireless LAN Controller(0x103C-0x137D)"},
{0x14E4, 0x4315, 0x103C, 0x1507, "U98Z049.00 Wireless Mini PCIe Card(0x103C-0x1507)"},
{0x14E4, 0x4315, 0x105B, 0xE003, "T77H030.00 Wireless Mini PCIe Card(0x105B-0xE003)"},
{0x14E4, 0x4315, 0x105B, 0xE01B, "T77H106.00 Wireless Half-size Mini PCIe Card(0x105B-0xE01B)"},
{0x14E4, 0x4318, 0xFFFF, 0xFFFF, "BCM4318 [AirForce One 54g] 802.11g Wireless LAN Controller(0x4318)"},
{0x14E4, 0x4318, 0x1028, 0x0005, "Wireless 1370 WLAN Mini-PCI Card(0x1028-0x0005)"},
{0x14E4, 0x4318, 0x1028, 0x0006, "Wireless 1370 WLAN PC Card(0x1028-0x0006)"},
{0x14E4, 0x4318, 0x103C, 0x1355, "Broadcom 802.11b/g WLAN(0x103C-0x1355)"},
{0x14E4, 0x4318, 0x103C, 0x1356, "Broadcom 802.11b/g WLAN(0x103C-0x1356)"},
{0x14E4, 0x4318, 0x103C, 0x1357, "Broadcom 802.11b/g WLAN(0x103C-0x1357)"},
{0x14E4, 0x4318, 0x1043, 0x100F, "WL-138G v2 / WL-138gE / WL-100gE(0x1043-0x100F)"},
{0x14E4, 0x4318, 0x1043, 0x120F, "A6U notebook embedded card(0x1043-0x120F)"},
{0x14E4, 0x4318, 0x1154, 0x0355, "Buffalo WLI2-PCI-G54S High Speed Mode Wireless Adapter(0x1154-0x0355)"},
{0x14E4, 0x4318, 0x1468, 0x0311, "Aspire 3022WLMi, 5024WLMi, 5020(0x1468-0x0311)"},
{0x14E4, 0x4318, 0x1468, 0x0312, "TravelMate 2410(0x1468-0x0312)"},
{0x14E4, 0x4318, 0x14E4, 0x0449, "Gateway 7510GX(0x14E4-0x0449)"},
{0x14E4, 0x4318, 0x16EC, 0x0119, "U.S.Robotics Wireless MAXg PC Card(0x16EC-0x0119)"},
{0x14E4, 0x4318, 0x1737, 0x0042, "WMP54GS v1.1 802.11g Wireless-G PCI Adapter with SpeedBooster(0x1737-0x0042)"},
{0x14E4, 0x4318, 0x1737, 0x0048, "WPC54G v3 802.11g Wireless-G Notebook Adapter(0x1737-0x0048)"},
{0x14E4, 0x4318, 0x1737, 0x0049, "WPC54GS v2 802.11g Wireless-G Notebook Adapter with SpeedBooster(0x1737-0x0049)"},
{0x14E4, 0x4318, 0x1799, 0x7000, "F5D7000 v4000 Wireless G Desktop Card(0x1799-0x7000)"},
{0x14E4, 0x4318, 0x1799, 0x7001, "F5D7001 v2000 Wireless G Plus Desktop Card(0x1799-0x7001)"},
{0x14E4, 0x4318, 0x1799, 0x7010, "F5D7010 v4000 Wireless G Notebook Card(0x1799-0x7010)"},
{0x14E4, 0x4318, 0x1799, 0x7011, "F5D7011 v2000 High-Speed Mode Wireless G Notebook Card(0x1799-0x7011)"},
{0x14E4, 0x4319, 0xFFFF, 0xFFFF, "BCM4318 [AirForce 54g] 802.11a/b/g PCI Express Transceiver(0x4319)"},
{0x14E4, 0x4319, 0x1028, 0x0005, "Wireless 1470 Dual Band WLAN Mini-PCI Card(0x1028-0x0005)"},
{0x14E4, 0x4319, 0x1028, 0x0006, "Wireless 1470 Dual Band WLAN PC Card(0x1028-0x0006)"},
{0x14E4, 0x4319, 0x103C, 0x1358, "Broadcom 802.11a/b/g WLAN(0x103C-0x1358)"},
{0x14E4, 0x4319, 0x103C, 0x1359, "Broadcom 802.11a/b/g WLAN(0x103C-0x1359)"},
{0x14E4, 0x4319, 0x103C, 0x135A, "Broadcom 802.11a/b/g WLAN(0x103C-0x135A)"},
{0x14E4, 0x4320, 0xFFFF, 0xFFFF, "BCM4306 802.11b/g Wireless LAN Controller(0x4320)"},
{0x14E4, 0x4320, 0x1028, 0x0001, "TrueMobile 1300 WLAN Mini-PCI Card(0x1028-0x0001)"},
{0x14E4, 0x4320, 0x1028, 0x0002, "TrueMobile 1300 WLAN PC Card(0x1028-0x0002)"},
{0x14E4, 0x4320, 0x1028, 0x0003, "Wireless 1350 WLAN Mini-PCI Card(0x1028-0x0003)"},
{0x14E4, 0x4320, 0x1028, 0x0004, "Wireless 1350 WLAN PC Card(0x1028-0x0004)"},
{0x14E4, 0x4320, 0x103C, 0x12F4, "Broadcom 802.11b/g WLAN(0x103C-0x12F4)"},
{0x14E4, 0x4320, 0x103C, 0x12F8, "Broadcom 802.11b/g WLAN(0x103C-0x12F8)"},
{0x14E4, 0x4320, 0x103C, 0x12FA, "Broadcom 802.11b/g WLAN(0x103C-0x12FA)"},
{0x14E4, 0x4320, 0x103C, 0x12FB, "Broadcom 802.11b/g WLAN(0x103C-0x12FB)"},
{0x14E4, 0x4320, 0x1043, 0x100F, "WL-100G(0x1043-0x100F)"},
{0x14E4, 0x4320, 0x1057, 0x7025, "WN825G(0x1057-0x7025)"},
{0x14E4, 0x4320, 0x106B, 0x004E, "AirPort Extreme(0x106B-0x004E)"},
{0x14E4, 0x4320, 0x1154, 0x0330, "Buffalo WLI2-PCI-G54S High Speed Mode Wireless Desktop Adapter(0x1154-0x0330)"},
{0x14E4, 0x4320, 0x144F, 0x7050, "eMachines M6805 802.11g Built-in Wireless(0x144F-0x7050)"},
{0x14E4, 0x4320, 0x144F, 0x7051, "Sonnet Aria Extreme PCI(0x144F-0x7051)"},
{0x14E4, 0x4320, 0x1737, 0x0013, "WMP54G v1 802.11g PCI Adapter(0x1737-0x0013)"},
{0x14E4, 0x4320, 0x1737, 0x0014, "WMP54G v2 802.11g PCI Adapter(0x1737-0x0014)"},
{0x14E4, 0x4320, 0x1737, 0x0015, "WMP54GS v1.0 802.11g Wireless-G PCI Adapter with SpeedBooster(0x1737-0x0015)"},
{0x14E4, 0x4320, 0x1737, 0x4320, "WPC54G v1 / WPC54GS v1 802.11g Wireless-G Notebook Adapter(0x1737-0x4320)"},
{0x14E4, 0x4320, 0x1799, 0x7000, "F5D7000 v1000 Wireless G Desktop Card(0x1799-0x7000)"},
{0x14E4, 0x4320, 0x1799, 0x7001, "F5D7001 v1000 Wireless G Plus Desktop Card(0x1799-0x7001)"},
{0x14E4, 0x4320, 0x1799, 0x7010, "F5D7010 v1000 Wireless G Notebook Card(0x1799-0x7010)"},
{0x14E4, 0x4320, 0x1799, 0x7011, "F5D7011 v1000 High-Speed Mode Wireless G Notebook Card(0x1799-0x7011)"},
{0x14E4, 0x4320, 0x185F, 0x1220, "TravelMate 290E WLAN Mini-PCI Card(0x185F-0x1220)"},
{0x14E4, 0x4321, 0xFFFF, 0xFFFF, "BCM4321 802.11a Wireless Network Controller(0x4321)"},
{0x14E4, 0x4322, 0xFFFF, 0xFFFF, "BCM4322 802.11bgn Wireless Network Controller(0x4322)"},
{0x14E4, 0x4324, 0xFFFF, 0xFFFF, "BCM4309 802.11abg Wireless Network Controller(0x4324)"},
{0x14E4, 0x4324, 0x1028, 0x0001, "Truemobile 1400(0x1028-0x0001)"},
{0x14E4, 0x4324, 0x1028, 0x0002, "TrueMobile 1400 Dual Band WLAN PC Card(0x1028-0x0002)"},
{0x14E4, 0x4324, 0x1028, 0x0003, "Truemobile 1450 MiniPCI(0x1028-0x0003)"},
{0x14E4, 0x4324, 0x1028, 0x0004, "Wireless 1450 Dual Band WLAN PC Card(0x1028-0x0004)"},
{0x14E4, 0x4324, 0x103C, 0x12F9, "Broadcom 802.11a/b/g WLAN(0x103C-0x12F9)"},
{0x14E4, 0x4324, 0x103C, 0x12FC, "Broadcom 802.11a/b/g WLAN(0x103C-0x12FC)"},
{0x14E4, 0x4325, 0xFFFF, 0xFFFF, "BCM4306 802.11bg Wireless Network Controller(0x4325)"},
{0x14E4, 0x4325, 0x1414, 0x0003, "Wireless Notebook Adapter MN-720(0x1414-0x0003)"},
{0x14E4, 0x4325, 0x1414, 0x0004, "Wireless PCI Adapter MN-730(0x1414-0x0004)"},
{0x14E4, 0x4326, 0xFFFF, 0xFFFF, "BCM4307 Chipcommon I/O Controller?-(0x4326)"},
{0x14E4, 0x4328, 0xFFFF, 0xFFFF, "BCM4321 802.11a/b/g/n(0x4328)"},
{0x14E4, 0x4328, 0x1028, 0x0009, "Wireless 1500 Draft 802.11n WLAN Mini-Card(0x1028-0x0009)"},
{0x14E4, 0x4328, 0x1028, 0x000A, "Wireless 1500 Draft 802.11n WLAN Mini-card(0x1028-0x000A)"},
{0x14E4, 0x4328, 0x103C, 0x1366, "BCM4321 802.11a/b/g/n Wireless LAN Controller(0x103C-0x1366)"},
{0x14E4, 0x4328, 0x103C, 0x1367, "BCM4321 802.11a/b/g/n Wireless LAN Controller(0x103C-0x1367)"},
{0x14E4, 0x4328, 0x103C, 0x1368, "BCM4321 802.11a/b/g/n Wireless LAN Controller(0x103C-0x1368)"},
{0x14E4, 0x4328, 0x103C, 0x1369, "BCM4321 802.11a/b/g/n Wireless LAN Controller(0x103C-0x1369)"},
{0x14E4, 0x4328, 0x106B, 0x0087, "AirPort Extreme(0x106B-0x0087)"},
{0x14E4, 0x4328, 0x106B, 0x0088, "AirPort Extreme(0x106B-0x0088)"},
{0x14E4, 0x4328, 0x106B, 0x008B, "AirPort Extreme(0x106B-0x008B)"},
{0x14E4, 0x4328, 0x106B, 0x008C, "AirPort Extreme(0x106B-0x008C)"},
{0x14E4, 0x4328, 0x106B, 0x0090, "AirPort Extreme(0x106B-0x0090)"},
{0x14E4, 0x4328, 0x14E4, 0x4328, "BCM4328 802.11a/b/g/n(0x14E4-0x4328)"},
{0x14E4, 0x4328, 0x1737, 0x0066, "WPC600N v1 802.11a/b/g/n Wireless-N CardBus Adapter(0x1737-0x0066)"},
{0x14E4, 0x4328, 0x1737, 0x0068, "WEC600N v1 802.11a/b/g/n Wireless-N ExpressCard(0x1737-0x0068)"},
{0x14E4, 0x4329, 0xFFFF, 0xFFFF, "BCM4321 802.11b/g/n(0x4329)"},
{0x14E4, 0x4329, 0x1385, 0x7B00, "WN511B RangeMax NEXT Wireless Notebook Adapter(0x1385-0x7B00)"},
{0x14E4, 0x4329, 0x1385, 0x7D00, "WN311B RangeMax Next 270 Mbps Wireless PCI Adapter(0x1385-0x7D00)"},
{0x14E4, 0x4329, 0x1737, 0x0058, "WPC300N v1 Wireless-N Notebook Adapter(0x1737-0x0058)"},
{0x14E4, 0x432A, 0xFFFF, 0xFFFF, "BCM4321 802.11an Wireless Network Controller(0x432A)"},
{0x14E4, 0x432B, 0xFFFF, 0xFFFF, "BCM4322 802.11a/b/g/n Wireless LAN Controller(0x432B)"},
{0x14E4, 0x432B, 0x1028, 0x000D, "Wireless 1510 Wireless-N WLAN Mini-Card(0x1028-0x000D)"},
{0x14E4, 0x432B, 0x106B, 0x008D, "AirPort Extreme(0x106B-0x008D)"},
{0x14E4, 0x432B, 0x106B, 0x008E, "AirPort Extreme(0x106B-0x008E)"},
{0x14E4, 0x432C, 0xFFFF, 0xFFFF, "BCM4322 802.11b/g/n(0x432C)"},
{0x14E4, 0x432C, 0x1799, 0xD311, "Dynex DX-NNBX 802.11n WLAN Cardbus Card(0x1799-0xD311)"},
{0x14E4, 0x432D, 0xFFFF, 0xFFFF, "BCM4322 802.11an Wireless Network Controller(0x432D)"},
{0x14E4, 0x4331, 0xFFFF, 0xFFFF, "BCM4331 802.11a/b/g/n(0x4331)"},
{0x14E4, 0x4331, 0x106B, 0x00D6, "AirPort Extreme(0x106B-0x00D6)"},
{0x14E4, 0x4331, 0x106B, 0x00E4, "AirPort Extreme(0x106B-0x00E4)"},
{0x14E4, 0x4331, 0x106B, 0x00EF, "AirPort Extreme(0x106B-0x00EF)"},
{0x14E4, 0x4331, 0x106B, 0x00F4, "AirPort Extreme(0x106B-0x00F4)"},
{0x14E4, 0x4331, 0x106B, 0x00F5, "AirPort Extreme(0x106B-0x00F5)"},
{0x14E4, 0x4331, 0x106B, 0x010E, "AirPort Extreme(0x106B-0x010E)"},
{0x14E4, 0x4331, 0x106B, 0x010F, "AirPort Extreme(0x106B-0x010F)"},
{0x14E4, 0x4333, 0xFFFF, 0xFFFF, "Serial (EDGE/GPRS modem part of Option GT Combo Edge)(0x4333)"},
{0x14E4, 0x4344, 0xFFFF, 0xFFFF, "EDGE/GPRS data and 802.11b/g combo cardbus [GC89](0x4344)"},
{0x14E4, 0x4350, 0xFFFF, 0xFFFF, "BCM43222 Wireless Network Adapter(0x4350)"},
{0x14E4, 0x4351, 0xFFFF, 0xFFFF, "BCM43222 802.11abgn Wireless Network Adapter(0x4351)"},
{0x14E4, 0x4353, 0xFFFF, 0xFFFF, "BCM43224 802.11a/b/g/n(0x4353)"},
{0x14E4, 0x4353, 0x1028, 0x000E, "Wireless 1520 Half-size Mini PCIe Card(0x1028-0x000E)"},
{0x14E4, 0x4353, 0x103C, 0x1509, "WMIB-275N Half-size Mini PCIe Card(0x103C-0x1509)"},
{0x14E4, 0x4353, 0x106B, 0x0093, "AirPort Extreme(0x106B-0x0093)"},
{0x14E4, 0x4353, 0x106B, 0x00D1, "AirPort Extreme(0x106B-0x00D1)"},
{0x14E4, 0x4353, 0x106B, 0x00E9, "AirPort Extreme(0x106B-0x00E9)"},
{0x14E4, 0x4353, 0x14E4, 0x04D8, "Pegatron UPWL6024(0x14E4-0x04D8)"},
{0x14E4, 0x4357, 0xFFFF, 0xFFFF, "BCM43225 802.11b/g/n(0x4357)"},
{0x14E4, 0x4357, 0x105B, 0xE021, "T77H103.00 Wireless Half-size Mini PCIe Card(0x105B-0xE021)"},
{0x14E4, 0x4358, 0xFFFF, 0xFFFF, "BCM43227 802.11b/g/n(0x4358)"},
{0x14E4, 0x4359, 0xFFFF, 0xFFFF, "BCM43228 802.11a/b/g/n(0x4359)"},
{0x14E4, 0x4359, 0x1028, 0x0011, "Wireless 1530 Half-size Mini PCIe Card(0x1028-0x0011)"},
{0x14E4, 0x4359, 0x103C, 0x182C, "BCM943228HM4L 802.11a/b/g/n 2x2 Wi-Fi Adapter(0x103C-0x182C)"},
{0x14E4, 0x4360, 0xFFFF, 0xFFFF, "BCM4360 802.11ac Wireless Network Adapter(0x4360)"},
{0x14E4, 0x4365, 0xFFFF, 0xFFFF, "BCM43142 802.11b/g/n(0x4365)"},
{0x14E4, 0x4365, 0x1028, 0x0016, "Wireless 1704 802.11n + BT 4.0(0x1028-0x0016)"},
{0x14E4, 0x43A0, 0xFFFF, 0xFFFF, "BCM4360 802.11ac Dual Band Wireless Network Adapter(0x43A0)"},
{0x14E4, 0x43A1, 0xFFFF, 0xFFFF, "BCM4360 802.11ac 2,4G Wireless Network Adapter(0x43A1)"},
{0x14E4, 0x43A2, 0xFFFF, 0xFFFF, "BCM4360 802.11ac 5G Wireless Network Adapter(0x43A2)"},
{0x14E4, 0x43A3, 0xFFFF, 0xFFFF, "BCM4350 802.11ac Wireless Network Adapter(0x43A3)"},
{0x14E4, 0x43A3, 0x17AA, 0x075A, "00JT494(0x17AA-0x075A)"},
{0x14E4, 0x43A9, 0xFFFF, 0xFFFF, "BCM43217 802.11b/g/n(0x43A9)"},
{0x14E4, 0x43AA, 0xFFFF, 0xFFFF, "BCM43131 802.11b/g/n(0x43AA)"},
{0x14E4, 0x43AE, 0xFFFF, 0xFFFF, "BCM43162 802.11ac Wireless Network Adapter(0x43AE)"},
{0x14E4, 0x43B1, 0xFFFF, 0xFFFF, "BCM4352 802.11ac Dual Band Wireless Network Adapter(0x43B1)"},
{0x14E4, 0x43B1, 0x1043, 0x85BA, "PCE-AC56 Dual-Band Wireless PCI-E Adapter(0x1043-0x85BA)"},
{0x14E4, 0x43BA, 0xFFFF, 0xFFFF, "BCM43602 802.11ac Wireless LAN SoC(0x43BA)"},
{0x14E4, 0x43BB, 0xFFFF, 0xFFFF, "BCM43602 802.11ac Wireless LAN SoC(0x43BB)"},
{0x14E4, 0x43BC, 0xFFFF, 0xFFFF, "BCM43602 802.11ac Wireless LAN SoC(0x43BC)"},
{0x14E4, 0x43D3, 0xFFFF, 0xFFFF, "BCM43567 802.11ac Wireless Network Adapter(0x43D3)"},
{0x14E4, 0x43D9, 0xFFFF, 0xFFFF, "BCM43570 802.11ac Wireless Network Adapter(0x43D9)"},
{0x14E4, 0x43DC, 0xFFFF, 0xFFFF, "BCM4355 802.11ac Wireless LAN SoC(0x43DC)"},
{0x14E4, 0x43DF, 0xFFFF, 0xFFFF, "BCM4354 802.11ac Wireless LAN SoC(0x43DF)"},
{0x14E4, 0x43E9, 0xFFFF, 0xFFFF, "BCM4358 802.11ac Wireless LAN SoC(0x43E9)"},
{0x14E4, 0x43EC, 0xFFFF, 0xFFFF, "BCM4356 802.11ac Wireless Network Adapter(0x43EC)"},
{0x14E4, 0x4401, 0xFFFF, 0xFFFF, "BCM4401 100Base-T(0x4401)"},
{0x14E4, 0x4401, 0x1025, 0x0035, "TravelMate 660(0x1025-0x0035)"},
{0x14E4, 0x4401, 0x1025, 0x0064, "Extensa 3000 series laptop(0x1025-0x0064)"},
{0x14E4, 0x4401, 0x1028, 0x8127, "Dimension 2400(0x1028-0x8127)"},
{0x14E4, 0x4401, 0x103C, 0x08B0, "tc1100 tablet(0x103C-0x08B0)"},
{0x14E4, 0x4401, 0x1043, 0x80A8, "A7V8X motherboard(0x1043-0x80A8)"},
{0x14E4, 0x4402, 0xFFFF, 0xFFFF, "BCM4402 Integrated 10/100BaseT(0x4402)"},
{0x14E4, 0x4403, 0xFFFF, 0xFFFF, "BCM4402 V.90 56k Modem(0x4403)"},
{0x14E4, 0x4410, 0xFFFF, 0xFFFF, "BCM4413 iLine32 HomePNA 2.0(0x4410)"},
{0x14E4, 0x4411, 0xFFFF, 0xFFFF, "BCM4413 V.90 56k modem(0x4411)"},
{0x14E4, 0x4412, 0xFFFF, 0xFFFF, "BCM4412 10/100BaseT(0x4412)"},
{0x14E4, 0x4415, 0xFFFF, 0xFFFF, "BCM4359 802.11ac Dual-Band Wireless Network Controller(0x4415)"},
{0x14E4, 0x441F, 0xFFFF, 0xFFFF, "BCM4361 802.11ac Dual-Band Wireless Network Controller(0x441F)"},
{0x14E4, 0x4420, 0xFFFF, 0xFFFF, "BCM4361 802.11ac 2.4 GHz Wireless Network Controller(0x4420)"},
{0x14E4, 0x4421, 0xFFFF, 0xFFFF, "BCM4361 802.11ac 5 GHz Wireless Network Controller(0x4421)"},
{0x14E4, 0x4425, 0xFFFF, 0xFFFF, "BCM4378 802.11ax Dual Band Wireless Network Adapter(0x4425)"},
{0x14E4, 0x4430, 0xFFFF, 0xFFFF, "BCM44xx CardBus iLine32 HomePNA 2.0(0x4430)"},
{0x14E4, 0x4432, 0xFFFF, 0xFFFF, "BCM4432 CardBus 10/100BaseT(0x4432)"},
{0x14E4, 0x4433, 0xFFFF, 0xFFFF, "BCM4387 802.11ax Dual Band Wireless LAN Controller(0x4433)"},
{0x14E4, 0x4464, 0xFFFF, 0xFFFF, "BCM4364 802.11ac Wireless Network Adapter(0x4464)"},
{0x14E4, 0x4488, 0xFFFF, 0xFFFF, "BCM4377b Wireless Network Adapter(0x4488)"},
{0x14E4, 0x449D, 0xFFFF, 0xFFFF, "BCM43752 802.11ax Dual Band Wireless LAN Controller(0x449D)"},
{0x14E4, 0x4610, 0xFFFF, 0xFFFF, "BCM4610 Sentry5 PCI to SB Bridge(0x4610)"},
{0x14E4, 0x4611, 0xFFFF, 0xFFFF, "BCM4610 Sentry5 iLine32 HomePNA 1.0(0x4611)"},
{0x14E4, 0x4612, 0xFFFF, 0xFFFF, "BCM4610 Sentry5 V.90 56k Modem(0x4612)"},
{0x14E4, 0x4613, 0xFFFF, 0xFFFF, "BCM4610 Sentry5 Ethernet Controller(0x4613)"},
{0x14E4, 0x4614, 0xFFFF, 0xFFFF, "BCM4610 Sentry5 External Interface(0x4614)"},
{0x14E4, 0x4615, 0xFFFF, 0xFFFF, "BCM4610 Sentry5 USB Controller(0x4615)"},
{0x14E4, 0x4704, 0xFFFF, 0xFFFF, "BCM4704 PCI to SB Bridge(0x4704)"},
{0x14E4, 0x4705, 0xFFFF, 0xFFFF, "BCM4704 Sentry5 802.11b Wireless LAN Controller(0x4705)"},
{0x14E4, 0x4706, 0xFFFF, 0xFFFF, "BCM4704 Sentry5 Ethernet Controller(0x4706)"},
{0x14E4, 0x4707, 0xFFFF, 0xFFFF, "BCM4704 Sentry5 USB Controller(0x4707)"},
{0x14E4, 0x4708, 0xFFFF, 0xFFFF, "BCM4704 Crypto Accelerator(0x4708)"},
{0x14E4, 0x4710, 0xFFFF, 0xFFFF, "BCM4710 Sentry5 PCI to SB Bridge(0x4710)"},
{0x14E4, 0x4711, 0xFFFF, 0xFFFF, "BCM47xx Sentry5 iLine32 HomePNA 2.0(0x4711)"},
{0x14E4, 0x4712, 0xFFFF, 0xFFFF, "BCM47xx V.92 56k modem(0x4712)"},
{0x14E4, 0x4713, 0xFFFF, 0xFFFF, "Sentry5 Ethernet Controller(0x4713)"},
{0x14E4, 0x4714, 0xFFFF, 0xFFFF, "BCM47xx Sentry5 External Interface(0x4714)"},
{0x14E4, 0x4715, 0xFFFF, 0xFFFF, "BCM47xx Sentry5 USB / Ethernet Controller(0x4715)"},
{0x14E4, 0x4716, 0xFFFF, 0xFFFF, "BCM47xx Sentry5 USB Host Controller(0x4716)"},
{0x14E4, 0x4717, 0xFFFF, 0xFFFF, "BCM47xx Sentry5 USB Device Controller(0x4717)"},
{0x14E4, 0x4718, 0xFFFF, 0xFFFF, "Sentry5 Crypto Accelerator(0x4718)"},
{0x14E4, 0x4719, 0xFFFF, 0xFFFF, "BCM47xx/53xx RoboSwitch Core(0x4719)"},
{0x14E4, 0x4720, 0xFFFF, 0xFFFF, "BCM4712 MIPS CPU(0x4720)"},
{0x14E4, 0x4727, 0xFFFF, 0xFFFF, "BCM4313 802.11bgn Wireless Network Adapter(0x4727)"},
{0x14E4, 0x4727, 0x1028, 0x0010, "Inspiron M5010 / XPS 8300(0x1028-0x0010)"},
{0x14E4, 0x5365, 0xFFFF, 0xFFFF, "BCM5365P Sentry5 Host Bridge(0x5365)"},
{0x14E4, 0x5600, 0xFFFF, 0xFFFF, "BCM5600 StrataSwitch 24+2 Ethernet Switch Controller(0x5600)"},
{0x14E4, 0x5605, 0xFFFF, 0xFFFF, "BCM5605 StrataSwitch 24+2 Ethernet Switch Controller(0x5605)"},
{0x14E4, 0x5615, 0xFFFF, 0xFFFF, "BCM5615 StrataSwitch 24+2 Ethernet Switch Controller(0x5615)"},
{0x14E4, 0x5625, 0xFFFF, 0xFFFF, "BCM5625 StrataSwitch 24+2 Ethernet Switch Controller(0x5625)"},
{0x14E4, 0x5645, 0xFFFF, 0xFFFF, "BCM5645 StrataSwitch 24+2 Ethernet Switch Controller(0x5645)"},
{0x14E4, 0x5670, 0xFFFF, 0xFFFF, "BCM5670 8-Port 10GE Ethernet Switch Fabric(0x5670)"},
{0x14E4, 0x5680, 0xFFFF, 0xFFFF, "BCM5680 G-Switch 8 Port Gigabit Ethernet Switch Controller(0x5680)"},
{0x14E4, 0x5690, 0xFFFF, 0xFFFF, "BCM5690 12-port Multi-Layer Gigabit Ethernet Switch(0x5690)"},
{0x14E4, 0x5691, 0xFFFF, 0xFFFF, "BCM5691 GE/10GE 8+2 Gigabit Ethernet Switch Controller(0x5691)"},
{0x14E4, 0x5692, 0xFFFF, 0xFFFF, "BCM5692 12-port Multi-Layer Gigabit Ethernet Switch(0x5692)"},
{0x14E4, 0x5695, 0xFFFF, 0xFFFF, "BCM5695 12-port + HiGig Multi-Layer Gigabit Ethernet Switch(0x5695)"},
{0x14E4, 0x5698, 0xFFFF, 0xFFFF, "BCM5698 12-port Multi-Layer Gigabit Ethernet Switch(0x5698)"},
{0x14E4, 0x5820, 0xFFFF, 0xFFFF, "BCM5820 Crypto Accelerator(0x5820)"},
{0x14E4, 0x5821, 0xFFFF, 0xFFFF, "BCM5821 Crypto Accelerator(0x5821)"},
{0x14E4, 0x5822, 0xFFFF, 0xFFFF, "BCM5822 Crypto Accelerator(0x5822)"},
{0x14E4, 0x5823, 0xFFFF, 0xFFFF, "BCM5823 Crypto Accelerator(0x5823)"},
{0x14E4, 0x5824, 0xFFFF, 0xFFFF, "BCM5824 Crypto Accelerator(0x5824)"},
{0x14E4, 0x5840, 0xFFFF, 0xFFFF, "BCM5840 Crypto Accelerator(0x5840)"},
{0x14E4, 0x5841, 0xFFFF, 0xFFFF, "BCM5841 Crypto Accelerator(0x5841)"},
{0x14E4, 0x5850, 0xFFFF, 0xFFFF, "BCM5850 Crypto Accelerator(0x5850)"},
{0x14E4, 0x5E87, 0xFFFF, 0xFFFF, "Valkyrie offload engine(0x5E87)"},
{0x14E4, 0x5E88, 0xFFFF, 0xFFFF, "Viper Offload Engine(0x5E88)"},
{0x14E4, 0x5F69, 0xFFFF, 0xFFFF, "BRCM4378 Bluetooth Controller(0x5F69)"},
{0x14E4, 0x5F71, 0xFFFF, 0xFFFF, "BRCM4387 Bluetooth Controller(0x5F71)"},
{0x14E4, 0x5FA0, 0xFFFF, 0xFFFF, "BRCM4377 Bluetooth Controller(0x5FA0)"},
{0x14E4, 0x8602, 0xFFFF, 0xFFFF, "BCM7400/BCM7405 Serial ATA Controller(0x8602)"},
{0x14E4, 0x9026, 0xFFFF, 0xFFFF, "CN99xx [ThunderX2] Integrated USB 3.0 xHCI Host Controller(0x9026)"},
{0x14E4, 0x9027, 0xFFFF, 0xFFFF, "CN99xx [ThunderX2] Integrated AHCI/SATA 3 Host Controller(0x9027)"},
{0x14E4, 0xA8D8, 0xFFFF, 0xFFFF, "BCM43224/5 Wireless Network Adapter(0xA8D8)"},
{0x14E4, 0xAA52, 0xFFFF, 0xFFFF, "BCM43602 802.11ac Wireless LAN SoC(0xAA52)"},
{0x14E4, 0xB080, 0xFFFF, 0xFFFF, "BCM56080 Firelight2 Switch ASIC(0xB080)"},
{0x14E4, 0xB302, 0xFFFF, 0xFFFF, "BCM56302 StrataXGS 24x1GE 2x10GE Switch Controller(0xB302)"},
{0x14E4, 0xB334, 0xFFFF, 0xFFFF, "BCM56334 StrataXGS 24x1GE 4x10GE Switch Controller(0xB334)"},
{0x14E4, 0xB370, 0xFFFF, 0xFFFF, "BCM56370 Switch ASIC(0xB370)"},
{0x14E4, 0xB371, 0xFFFF, 0xFFFF, "BCM56371 Switch ASIC(0xB371)"},
{0x14E4, 0xB372, 0xFFFF, 0xFFFF, "BCM56372 Switch ASIC(0xB372)"},
{0x14E4, 0xB375, 0xFFFF, 0xFFFF, "BCM56375 Switch ASIC(0xB375)"},
{0x14E4, 0xB376, 0xFFFF, 0xFFFF, "BCM56376 Switch ASIC(0xB376)"},
{0x14E4, 0xB377, 0xFFFF, 0xFFFF, "BCM56377 Switch ASIC(0xB377)"},
{0x14E4, 0xB379, 0xFFFF, 0xFFFF, "Broadcom BCM56379 Switch ASIC(0xB379)"},
{0x14E4, 0xB470, 0xFFFF, 0xFFFF, "BCM56470 SWITCH ASIC(0xB470)"},
{0x14E4, 0xB471, 0xFFFF, 0xFFFF, "BCM56471 SWITCH ASIC(0xB471)"},
{0x14E4, 0xB472, 0xFFFF, 0xFFFF, "BCM56472 SWITCH ASIC(0xB472)"},
{0x14E4, 0xB800, 0xFFFF, 0xFFFF, "BCM56800 StrataXGS 10GE Switch Controller(0xB800)"},
{0x14E4, 0xB842, 0xFFFF, 0xFFFF, "BCM56842 Trident 10GE Switch Controller(0xB842)"},
{0x14E4, 0xB850, 0xFFFF, 0xFFFF, "BCM56850 Switch ASIC [Trident2](0xB850)"},
{0x14E4, 0xB880, 0xFFFF, 0xFFFF, "BCM56880 Switch ASIC(0xB880)"},
{0x14E4, 0xB960, 0xFFFF, 0xFFFF, "BCM56960 Switch ASIC [Tomahawk](0xB960)"},
{0x14E4, 0xB990, 0xFFFF, 0xFFFF, "BCM56990 Switch ASIC [Tomahawk4](0xB990)"},
{0x14E4, 0xB991, 0xFFFF, 0xFFFF, "Tomahawk4(0xB991)"},
{0x14E4, 0xB992, 0xFFFF, 0xFFFF, "BCM56992 [Tomahawk4](0xB992)"},
{0x14E4, 0xB993, 0xFFFF, 0xFFFF, "BCM56993 Switch ASIC [Tomahawk4](0xB993)"},
{0x14E4, 0xB995, 0xFFFF, 0xFFFF, "BCM56995 Switch ASIC [Tomahawk4](0xB995)"},
{0x14E4, 0xB996, 0xFFFF, 0xFFFF, "BCM56996 106G Switch ASIC [Tomahawk4G](0xB996)"},
{0x14E4, 0xB998, 0xFFFF, 0xFFFF, "BCM56998 106G Switch ASIC [Tomahawk4GT](0xB998)"},
{0x14E4, 0xB999, 0xFFFF, 0xFFFF, "BCM56999 106G Switch ASIC [Tomahawk4D](0xB999)"},
{0x14E4, 0xC909, 0xFFFF, 0xFFFF, "BCM78909 Switch ASIC(0xC909)"},
{0x14E4, 0xD802, 0xFFFF, 0xFFFF, "BCM58802 Stingray 50Gb Ethernet SoC(0xD802)"},
{0x14E4, 0xD802, 0x14E4, 0x8021, "Stingray Dual-Port 25Gb Ethernet PCIe SmartNIC w16GB DRAM (Part No BCM958802A8046C)(0x14E4-0x8021)"},
{0x14E4, 0xD802, 0x14E4, 0x8023, "PS410T-H04 NetXtreme-S 4x10G 10GBaseT PCIe SmartNIC(0x14E4-0x8023)"},
{0x14E4, 0xD802, 0x14E4, 0x8024, "Stingray Dual-Port 25Gb Ethernet PCIe SmartNIC w4GB DRAM (Part No BCM958802A8044C)(0x14E4-0x8024)"},
{0x14E4, 0xD802, 0x14E4, 0x8028, "Stingray Dual-Port 25Gb Ethernet PCIe SmartNIC w8GB DRAM (Part No BCM958802A8048C)(0x14E4-0x8028)"},
{0x14E4, 0xD802, 0x1BB0, 0x0021, "HPE SimpliVity Accelerator(0x1BB0-0x0021)"},
{0x14E4, 0xD804, 0xFFFF, 0xFFFF, "BCM58804 Stingray 100Gb Ethernet SoC(0xD804)"},
{0x14E4, 0xF800, 0xFFFF, 0xFFFF, "BCM78800 Switch ASIC [Trident5-X12](0xF800)"},
{0x14E4, 0xF900, 0xFFFF, 0xFFFF, "BCM78900 Switch ASIC [Tomahawk5](0xF900)"},
{0x14E4, 0xF902, 0xFFFF, 0xFFFF, "BCM78902 Switch ASIC [Tomahawk5T](0xF902)"},
{0x14E4, 0xF903, 0xFFFF, 0xFFFF, "BCM78903 Switch ASIC [Tomahawk5](0xF903)"},
{0x14E4, 0xF905, 0xFFFF, 0xFFFF, "BCM78905 Switch ASIC [Tomahawk5+](0xF905)"},
{0x14E4, 0xF910, 0xFFFF, 0xFFFF, "BCM78910 Switch ASIC [Tomahawk6](0xF910)"},
{0x14E4, 0xF914, 0xFFFF, 0xFFFF, "BCM78914 Switch ASIC [Tomahawk6](0xF914)"},
{0x14E4, 0xF917, 0xFFFF, 0xFFFF, "BCM78917 Switch ASIC [Tomahawk6](0xF917)"},
}; /* pci_vid_14E4[] */

static pci_id_t const pci_vid_14E5[] = {
{0x14E5, 0xFFFF, 0xFFFF, 0xFFFF, "Pixelfusion Ltd(0x14E5)"},
}; /* pci_vid_14E5[] */

static pci_id_t const pci_vid_14E6[] = {
{0x14E6, 0xFFFF, 0xFFFF, 0xFFFF, "SHINING Technology Inc(0x14E6)"},
}; /* pci_vid_14E6[] */

static pci_id_t const pci_vid_14E7[] = {
{0x14E7, 0xFFFF, 0xFFFF, 0xFFFF, "3CX(0x14E7)"},
}; /* pci_vid_14E7[] */

static pci_id_t const pci_vid_14E8[] = {
{0x14E8, 0xFFFF, 0xFFFF, 0xFFFF, "RAYCER Inc(0x14E8)"},
}; /* pci_vid_14E8[] */

static pci_id_t const pci_vid_14E9[] = {
{0x14E9, 0xFFFF, 0xFFFF, 0xFFFF, "GARNETS System CO Ltd(0x14E9)"},
}; /* pci_vid_14E9[] */

static pci_id_t const pci_vid_14EA[] = {
{0x14EA, 0xFFFF, 0xFFFF, 0xFFFF, "Planex Communications, Inc(0x14EA)"},
{0x14EA, 0xAB06, 0xFFFF, 0xFFFF, "FNW-3603-TX CardBus Fast Ethernet(0xAB06)"},
{0x14EA, 0xAB07, 0xFFFF, 0xFFFF, "RTL81xx RealTek Ethernet(0xAB07)"},
{0x14EA, 0xAB08, 0xFFFF, 0xFFFF, "FNW-3602-TX CardBus Fast Ethernet(0xAB08)"},
}; /* pci_vid_14EA[] */

static pci_id_t const pci_vid_14EB[] = {
{0x14EB, 0xFFFF, 0xFFFF, 0xFFFF, "SEIKO EPSON Corp(0x14EB)"},
}; /* pci_vid_14EB[] */

static pci_id_t const pci_vid_14EC[] = {
{0x14EC, 0xFFFF, 0xFFFF, 0xFFFF, "Agilent Technologies(0x14EC)"},
{0x14EC, 0x0000, 0xFFFF, 0xFFFF, "Aciris Digitizer (malformed ID)(0x0000)"},
}; /* pci_vid_14EC[] */

static pci_id_t const pci_vid_14ED[] = {
{0x14ED, 0xFFFF, 0xFFFF, 0xFFFF, "DATAKINETICS Ltd(0x14ED)"},
}; /* pci_vid_14ED[] */

static pci_id_t const pci_vid_14EE[] = {
{0x14EE, 0xFFFF, 0xFFFF, 0xFFFF, "MASPRO KENKOH Corp(0x14EE)"},
}; /* pci_vid_14EE[] */

static pci_id_t const pci_vid_14EF[] = {
{0x14EF, 0xFFFF, 0xFFFF, 0xFFFF, "CARRY Computer ENG. CO Ltd(0x14EF)"},
}; /* pci_vid_14EF[] */

static pci_id_t const pci_vid_14F0[] = {
{0x14F0, 0xFFFF, 0xFFFF, 0xFFFF, "CANON RESEACH CENTRE FRANCE(0x14F0)"},
}; /* pci_vid_14F0[] */

static pci_id_t const pci_vid_14F1[] = {
{0x14F1, 0xFFFF, 0xFFFF, 0xFFFF, "Conexant Systems, Inc.(0x14F1)"},
{0x14F1, 0x1002, 0xFFFF, 0xFFFF, "HCF 56k Modem(0x1002)"},
{0x14F1, 0x1003, 0xFFFF, 0xFFFF, "HCF 56k Modem(0x1003)"},
{0x14F1, 0x1004, 0xFFFF, 0xFFFF, "HCF 56k Modem(0x1004)"},
{0x14F1, 0x1005, 0xFFFF, 0xFFFF, "HCF 56k Modem(0x1005)"},
{0x14F1, 0x1006, 0xFFFF, 0xFFFF, "HCF 56k Modem(0x1006)"},
{0x14F1, 0x1022, 0xFFFF, 0xFFFF, "HCF 56k Modem(0x1022)"},
{0x14F1, 0x1023, 0xFFFF, 0xFFFF, "HCF 56k Modem(0x1023)"},
{0x14F1, 0x1024, 0xFFFF, 0xFFFF, "HCF 56k Modem(0x1024)"},
{0x14F1, 0x1025, 0xFFFF, 0xFFFF, "HCF 56k Modem(0x1025)"},
{0x14F1, 0x1026, 0xFFFF, 0xFFFF, "HCF 56k Modem(0x1026)"},
{0x14F1, 0x1032, 0xFFFF, 0xFFFF, "HCF 56k Modem(0x1032)"},
{0x14F1, 0x1033, 0xFFFF, 0xFFFF, "HCF 56k Data/Fax Modem(0x1033)"},
{0x14F1, 0x1033, 0x1033, 0x8077, "NEC(0x1033-0x8077)"},
{0x14F1, 0x1033, 0x122D, 0x4027, "Dell Zeus - MDP3880-W(B) Data Fax Modem(0x122D-0x4027)"},
{0x14F1, 0x1033, 0x122D, 0x4030, "Dell Mercury - MDP3880-U(B) Data Fax Modem(0x122D-0x4030)"},
{0x14F1, 0x1033, 0x122D, 0x4034, "Dell Thor - MDP3880-W(U) Data Fax Modem(0x122D-0x4034)"},
{0x14F1, 0x1033, 0x13E0, 0x020D, "Dell Copper(0x13E0-0x020D)"},
{0x14F1, 0x1033, 0x13E0, 0x020E, "Dell Silver(0x13E0-0x020E)"},
{0x14F1, 0x1033, 0x13E0, 0x0261, "IBM(0x13E0-0x0261)"},
{0x14F1, 0x1033, 0x13E0, 0x0290, "Compaq Goldwing(0x13E0-0x0290)"},
{0x14F1, 0x1033, 0x13E0, 0x02A0, "IBM(0x13E0-0x02A0)"},
{0x14F1, 0x1033, 0x13E0, 0x02B0, "IBM(0x13E0-0x02B0)"},
{0x14F1, 0x1033, 0x13E0, 0x02C0, "Compaq Scooter(0x13E0-0x02C0)"},
{0x14F1, 0x1033, 0x13E0, 0x02D0, "IBM(0x13E0-0x02D0)"},
{0x14F1, 0x1033, 0x144F, 0x1500, "IBM P85-DF (1)(0x144F-0x1500)"},
{0x14F1, 0x1033, 0x144F, 0x1501, "IBM P85-DF (2)(0x144F-0x1501)"},
{0x14F1, 0x1033, 0x144F, 0x150A, "IBM P85-DF (3)(0x144F-0x150A)"},
{0x14F1, 0x1033, 0x144F, 0x150B, "IBM P85-DF Low Profile (1)(0x144F-0x150B)"},
{0x14F1, 0x1033, 0x144F, 0x1510, "IBM P85-DF Low Profile (2)(0x144F-0x1510)"},
{0x14F1, 0x1034, 0xFFFF, 0xFFFF, "HCF 56k Data/Fax/Voice Modem(0x1034)"},
{0x14F1, 0x1035, 0xFFFF, 0xFFFF, "HCF 56k Data/Fax/Voice/Spkp (w/Handset) Modem(0x1035)"},
{0x14F1, 0x1035, 0x10CF, 0x1098, "Fujitsu P85-DFSV(0x10CF-0x1098)"},
{0x14F1, 0x1036, 0xFFFF, 0xFFFF, "HCF 56k Data/Fax/Voice/Spkp Modem(0x1036)"},
{0x14F1, 0x1036, 0x104D, 0x8067, "HCF 56k Modem(0x104D-0x8067)"},
{0x14F1, 0x1036, 0x122D, 0x4029, "MDP3880SP-W(0x122D-0x4029)"},
{0x14F1, 0x1036, 0x122D, 0x4031, "MDP3880SP-U(0x122D-0x4031)"},
{0x14F1, 0x1036, 0x13E0, 0x0209, "Dell Titanium(0x13E0-0x0209)"},
{0x14F1, 0x1036, 0x13E0, 0x020A, "Dell Graphite(0x13E0-0x020A)"},
{0x14F1, 0x1036, 0x13E0, 0x0260, "Gateway Red Owl(0x13E0-0x0260)"},
{0x14F1, 0x1036, 0x13E0, 0x0270, "Gateway White Horse(0x13E0-0x0270)"},
{0x14F1, 0x1052, 0xFFFF, 0xFFFF, "HCF 56k Data/Fax Modem (Worldwide)(0x1052)"},
{0x14F1, 0x1053, 0xFFFF, 0xFFFF, "HCF 56k Data/Fax Modem (Worldwide)(0x1053)"},
{0x14F1, 0x1054, 0xFFFF, 0xFFFF, "HCF 56k Data/Fax/Voice Modem (Worldwide)(0x1054)"},
{0x14F1, 0x1055, 0xFFFF, 0xFFFF, "HCF 56k Data/Fax/Voice/Spkp (w/Handset) Modem (Worldwide)(0x1055)"},
{0x14F1, 0x1056, 0xFFFF, 0xFFFF, "HCF 56k Data/Fax/Voice/Spkp Modem (Worldwide)(0x1056)"},
{0x14F1, 0x1056, 0x122D, 0x4035, "MDP3900V-W(0x122D-0x4035)"},
{0x14F1, 0x1057, 0xFFFF, 0xFFFF, "HCF 56k Data/Fax/Voice/Spkp Modem (Worldwide)(0x1057)"},
{0x14F1, 0x1059, 0xFFFF, 0xFFFF, "HCF 56k Data/Fax/Voice Modem (Worldwide)(0x1059)"},
{0x14F1, 0x1063, 0xFFFF, 0xFFFF, "HCF 56k Data/Fax Modem(0x1063)"},
{0x14F1, 0x1064, 0xFFFF, 0xFFFF, "HCF 56k Data/Fax/Voice Modem(0x1064)"},
{0x14F1, 0x1065, 0xFFFF, 0xFFFF, "HCF 56k Data/Fax/Voice/Spkp (w/Handset) Modem(0x1065)"},
{0x14F1, 0x1066, 0xFFFF, 0xFFFF, "HCF 56k Data/Fax/Voice/Spkp Modem(0x1066)"},
{0x14F1, 0x1066, 0x122D, 0x4033, "Dell Athena - MDP3900V-U(0x122D-0x4033)"},
{0x14F1, 0x1085, 0xFFFF, 0xFFFF, "HCF V90 56k Data/Fax/Voice/Spkp PCI Modem(0x1085)"},
{0x14F1, 0x10B6, 0xFFFF, 0xFFFF, "CX06834-11 HCF V.92 56k Data/Fax/Voice/Spkp Modem(0x10B6)"},
{0x14F1, 0x1433, 0xFFFF, 0xFFFF, "HCF 56k Data/Fax Modem(0x1433)"},
{0x14F1, 0x1434, 0xFFFF, 0xFFFF, "HCF 56k Data/Fax/Voice Modem(0x1434)"},
{0x14F1, 0x1435, 0xFFFF, 0xFFFF, "HCF 56k Data/Fax/Voice/Spkp (w/Handset) Modem(0x1435)"},
{0x14F1, 0x1436, 0xFFFF, 0xFFFF, "HCF 56k Data/Fax Modem(0x1436)"},
{0x14F1, 0x1453, 0xFFFF, 0xFFFF, "HCF 56k Data/Fax Modem(0x1453)"},
{0x14F1, 0x1453, 0x13E0, 0x0240, "IBM(0x13E0-0x0240)"},
{0x14F1, 0x1453, 0x13E0, 0x0250, "IBM(0x13E0-0x0250)"},
{0x14F1, 0x1453, 0x144F, 0x1502, "IBM P95-DF (1)(0x144F-0x1502)"},
{0x14F1, 0x1453, 0x144F, 0x1503, "IBM P95-DF (2)(0x144F-0x1503)"},
{0x14F1, 0x1454, 0xFFFF, 0xFFFF, "HCF 56k Data/Fax/Voice Modem(0x1454)"},
{0x14F1, 0x1455, 0xFFFF, 0xFFFF, "HCF 56k Data/Fax/Voice/Spkp (w/Handset) Modem(0x1455)"},
{0x14F1, 0x1456, 0xFFFF, 0xFFFF, "HCF 56k Data/Fax/Voice/Spkp Modem(0x1456)"},
{0x14F1, 0x1456, 0x122D, 0x4035, "Dell Europa - MDP3900V-W(0x122D-0x4035)"},
{0x14F1, 0x1456, 0x122D, 0x4302, "Dell MP3930V-W(C) MiniPCI(0x122D-0x4302)"},
{0x14F1, 0x1610, 0xFFFF, 0xFFFF, "ADSL AccessRunner PCI Arbitration Device(0x1610)"},
{0x14F1, 0x1611, 0xFFFF, 0xFFFF, "AccessRunner PCI ADSL Interface Device(0x1611)"},
{0x14F1, 0x1620, 0xFFFF, 0xFFFF, "AccessRunner V2 PCI ADSL Arbitration Device(0x1620)"},
{0x14F1, 0x1621, 0xFFFF, 0xFFFF, "AccessRunner V2 PCI ADSL Interface Device(0x1621)"},
{0x14F1, 0x1622, 0xFFFF, 0xFFFF, "AccessRunner V2 PCI ADSL Yukon WAN Adapter(0x1622)"},
{0x14F1, 0x1803, 0xFFFF, 0xFFFF, "HCF 56k Modem(0x1803)"},
{0x14F1, 0x1803, 0x0E11, 0x0023, "623-LAN Grizzly(0x0E11-0x0023)"},
{0x14F1, 0x1803, 0x0E11, 0x0043, "623-LAN Yogi(0x0E11-0x0043)"},
{0x14F1, 0x1811, 0xFFFF, 0xFFFF, "MiniPCI Network Adapter(0x1811)"},
{0x14F1, 0x1815, 0xFFFF, 0xFFFF, "HCF 56k Modem(0x1815)"},
{0x14F1, 0x1815, 0x0E11, 0x0022, "Grizzly(0x0E11-0x0022)"},
{0x14F1, 0x1815, 0x0E11, 0x0042, "Yogi(0x0E11-0x0042)"},
{0x14F1, 0x1830, 0xFFFF, 0xFFFF, "CX861xx Integrated Host Bridge(0x1830)"},
{0x14F1, 0x2003, 0xFFFF, 0xFFFF, "HSF 56k Data/Fax Modem(0x2003)"},
{0x14F1, 0x2004, 0xFFFF, 0xFFFF, "HSF 56k Data/Fax/Voice Modem(0x2004)"},
{0x14F1, 0x2005, 0xFFFF, 0xFFFF, "HSF 56k Data/Fax/Voice/Spkp (w/Handset) Modem(0x2005)"},
{0x14F1, 0x2006, 0xFFFF, 0xFFFF, "HSF 56k Data/Fax/Voice/Spkp Modem(0x2006)"},
{0x14F1, 0x2013, 0xFFFF, 0xFFFF, "HSF 56k Data/Fax Modem(0x2013)"},
{0x14F1, 0x2013, 0x0E11, 0xB195, "Bear(0x0E11-0xB195)"},
{0x14F1, 0x2013, 0x0E11, 0xB196, "Seminole 1(0x0E11-0xB196)"},
{0x14F1, 0x2013, 0x0E11, 0xB1BE, "Seminole 2(0x0E11-0xB1BE)"},
{0x14F1, 0x2013, 0x1025, 0x8013, "Acer(0x1025-0x8013)"},
{0x14F1, 0x2013, 0x1033, 0x809D, "NEC(0x1033-0x809D)"},
{0x14F1, 0x2013, 0x1033, 0x80BC, "NEC(0x1033-0x80BC)"},
{0x14F1, 0x2013, 0x155D, 0x6793, "HP(0x155D-0x6793)"},
{0x14F1, 0x2013, 0x155D, 0x8850, "E Machines(0x155D-0x8850)"},
{0x14F1, 0x2014, 0xFFFF, 0xFFFF, "HSF 56k Data/Fax/Voice Modem(0x2014)"},
{0x14F1, 0x2015, 0xFFFF, 0xFFFF, "HSF 56k Data/Fax/Voice/Spkp (w/Handset) Modem(0x2015)"},
{0x14F1, 0x2016, 0xFFFF, 0xFFFF, "HSF 56k Data/Fax/Voice/Spkp Modem(0x2016)"},
{0x14F1, 0x2043, 0xFFFF, 0xFFFF, "HSF 56k Data/Fax Modem (WorldW SmartDAA)(0x2043)"},
{0x14F1, 0x2044, 0xFFFF, 0xFFFF, "HSF 56k Data/Fax/Voice Modem (WorldW SmartDAA)(0x2044)"},
{0x14F1, 0x2045, 0xFFFF, 0xFFFF, "HSF 56k Data/Fax/Voice/Spkp (w/Handset) Modem (WorldW SmartDAA)(0x2045)"},
{0x14F1, 0x2045, 0x14F1, 0x2045, "Generic SoftK56(0x14F1-0x2045)"},
{0x14F1, 0x2046, 0xFFFF, 0xFFFF, "HSF 56k Data/Fax/Voice/Spkp Modem (WorldW SmartDAA)(0x2046)"},
{0x14F1, 0x2063, 0xFFFF, 0xFFFF, "HSF 56k Data/Fax Modem (SmartDAA)(0x2063)"},
{0x14F1, 0x2064, 0xFFFF, 0xFFFF, "HSF 56k Data/Fax/Voice Modem (SmartDAA)(0x2064)"},
{0x14F1, 0x2065, 0xFFFF, 0xFFFF, "HSF 56k Data/Fax/Voice/Spkp (w/Handset) Modem (SmartDAA)(0x2065)"},
{0x14F1, 0x2066, 0xFFFF, 0xFFFF, "HSF 56k Data/Fax/Voice/Spkp Modem (SmartDAA)(0x2066)"},
{0x14F1, 0x2093, 0xFFFF, 0xFFFF, "HSF 56k Modem(0x2093)"},
{0x14F1, 0x2093, 0x155D, 0x2F07, "Legend(0x155D-0x2F07)"},
{0x14F1, 0x2143, 0xFFFF, 0xFFFF, "HSF 56k Data/Fax/Cell Modem (Mob WorldW SmartDAA)(0x2143)"},
{0x14F1, 0x2144, 0xFFFF, 0xFFFF, "HSF 56k Data/Fax/Voice/Cell Modem (Mob WorldW SmartDAA)(0x2144)"},
{0x14F1, 0x2145, 0xFFFF, 0xFFFF, "HSF 56k Data/Fax/Voice/Spkp (w/HS)/Cell Modem (Mob WorldW SmartDAA)(0x2145)"},
{0x14F1, 0x2146, 0xFFFF, 0xFFFF, "HSF 56k Data/Fax/Voice/Spkp/Cell Modem (Mob WorldW SmartDAA)(0x2146)"},
{0x14F1, 0x2163, 0xFFFF, 0xFFFF, "HSF 56k Data/Fax/Cell Modem (Mob SmartDAA)(0x2163)"},
{0x14F1, 0x2164, 0xFFFF, 0xFFFF, "HSF 56k Data/Fax/Voice/Cell Modem (Mob SmartDAA)(0x2164)"},
{0x14F1, 0x2165, 0xFFFF, 0xFFFF, "HSF 56k Data/Fax/Voice/Spkp (w/HS)/Cell Modem (Mob SmartDAA)(0x2165)"},
{0x14F1, 0x2166, 0xFFFF, 0xFFFF, "HSF 56k Data/Fax/Voice/Spkp/Cell Modem (Mob SmartDAA)(0x2166)"},
{0x14F1, 0x2343, 0xFFFF, 0xFFFF, "HSF 56k Data/Fax CardBus Modem (Mob WorldW SmartDAA)(0x2343)"},
{0x14F1, 0x2344, 0xFFFF, 0xFFFF, "HSF 56k Data/Fax/Voice CardBus Modem (Mob WorldW SmartDAA)(0x2344)"},
{0x14F1, 0x2345, 0xFFFF, 0xFFFF, "HSF 56k Data/Fax/Voice/Spkp (w/HS) CardBus Modem (Mob WorldW SmartDAA)(0x2345)"},
{0x14F1, 0x2346, 0xFFFF, 0xFFFF, "HSF 56k Data/Fax/Voice/Spkp CardBus Modem (Mob WorldW SmartDAA)(0x2346)"},
{0x14F1, 0x2363, 0xFFFF, 0xFFFF, "HSF 56k Data/Fax CardBus Modem (Mob SmartDAA)(0x2363)"},
{0x14F1, 0x2364, 0xFFFF, 0xFFFF, "HSF 56k Data/Fax/Voice CardBus Modem (Mob SmartDAA)(0x2364)"},
{0x14F1, 0x2365, 0xFFFF, 0xFFFF, "HSF 56k Data/Fax/Voice/Spkp (w/HS) CardBus Modem (Mob SmartDAA)(0x2365)"},
{0x14F1, 0x2366, 0xFFFF, 0xFFFF, "HSF 56k Data/Fax/Voice/Spkp CardBus Modem (Mob SmartDAA)(0x2366)"},
{0x14F1, 0x2443, 0xFFFF, 0xFFFF, "HSF 56k Data/Fax Modem (Mob WorldW SmartDAA)(0x2443)"},
{0x14F1, 0x2443, 0x104D, 0x8075, "Modem(0x104D-0x8075)"},
{0x14F1, 0x2443, 0x104D, 0x8083, "Modem(0x104D-0x8083)"},
{0x14F1, 0x2443, 0x104D, 0x8097, "Modem(0x104D-0x8097)"},
{0x14F1, 0x2444, 0xFFFF, 0xFFFF, "HSF 56k Data/Fax/Voice Modem (Mob WorldW SmartDAA)(0x2444)"},
{0x14F1, 0x2445, 0xFFFF, 0xFFFF, "HSF 56k Data/Fax/Voice/Spkp (w/HS) Modem (Mob WorldW SmartDAA)(0x2445)"},
{0x14F1, 0x2446, 0xFFFF, 0xFFFF, "HSF 56k Data/Fax/Voice/Spkp Modem (Mob WorldW SmartDAA)(0x2446)"},
{0x14F1, 0x2463, 0xFFFF, 0xFFFF, "HSF 56k Data/Fax Modem (Mob SmartDAA)(0x2463)"},
{0x14F1, 0x2464, 0xFFFF, 0xFFFF, "HSF 56k Data/Fax/Voice Modem (Mob SmartDAA)(0x2464)"},
{0x14F1, 0x2465, 0xFFFF, 0xFFFF, "HSF 56k Data/Fax/Voice/Spkp (w/HS) Modem (Mob SmartDAA)(0x2465)"},
{0x14F1, 0x2466, 0xFFFF, 0xFFFF, "HSF 56k Data/Fax/Voice/Spkp Modem (Mob SmartDAA)(0x2466)"},
{0x14F1, 0x2702, 0xFFFF, 0xFFFF, "HSFi modem RD01-D270(0x2702)"},
{0x14F1, 0x2702, 0x1028, 0x8D88, "SmartHSFi V92 56K PCI Modem(0x1028-0x8D88)"},
{0x14F1, 0x2F00, 0xFFFF, 0xFFFF, "HSF 56k HSFi Modem(0x2F00)"},
{0x14F1, 0x2F00, 0x13E0, 0x8D84, "IBM HSFi V.90(0x13E0-0x8D84)"},
{0x14F1, 0x2F00, 0x13E0, 0x8D85, "Compaq Stinger(0x13E0-0x8D85)"},
{0x14F1, 0x2F00, 0x14F1, 0x2004, "Dynalink 56PMi(0x14F1-0x2004)"},
{0x14F1, 0x2F02, 0xFFFF, 0xFFFF, "HSF 56k HSFi Data/Fax(0x2F02)"},
{0x14F1, 0x2F11, 0xFFFF, 0xFFFF, "HSF 56k HSFi Modem(0x2F11)"},
{0x14F1, 0x2F20, 0xFFFF, 0xFFFF, "HSF 56k Data/Fax Modem(0x2F20)"},
{0x14F1, 0x2F20, 0x14F1, 0x200C, "Soft Data Fax Modem with SmartCP(0x14F1-0x200C)"},
{0x14F1, 0x2F20, 0x14F1, 0x200F, "Dimension 3000(0x14F1-0x200F)"},
{0x14F1, 0x2F30, 0xFFFF, 0xFFFF, "SoftV92 SpeakerPhone SoftRing Modem with SmartSP(0x2F30)"},
{0x14F1, 0x2F30, 0x14F1, 0x2014, "Devolo MikroLink 56K Modem PCI(0x14F1-0x2014)"},
{0x14F1, 0x2F50, 0xFFFF, 0xFFFF, "Conexant SoftK56 Data/Fax Modem(0x2F50)"},
{0x14F1, 0x510F, 0xFFFF, 0xFFFF, "Conexant CX 20751/20752(0x510F)"},
{0x14F1, 0x5B7A, 0xFFFF, 0xFFFF, "CX23418 Single-Chip MPEG-2 Encoder with Integrated Analog Video/Broadcast Audio Decoder(0x5B7A)"},
{0x14F1, 0x5B7A, 0x0070, 0x7444, "WinTV HVR-1600(0x0070-0x7444)"},
{0x14F1, 0x5B7A, 0x107D, 0x6F34, "WinFast DVR3100 H(0x107D-0x6F34)"},
{0x14F1, 0x5B7A, 0x5854, 0x3343, "GoTView PCI DVD3 Hybrid(0x5854-0x3343)"},
{0x14F1, 0x8200, 0xFFFF, 0xFFFF, "CX25850(0x8200)"},
{0x14F1, 0x8234, 0xFFFF, 0xFFFF, "RS8234 ATM SAR Controller [ServiceSAR Plus](0x8234)"},
{0x14F1, 0x8800, 0xFFFF, 0xFFFF, "CX23880/1/2/3 PCI Video and Audio Decoder(0x8800)"},
{0x14F1, 0x8800, 0x0070, 0x2801, "Hauppauge WinTV 28xxx (Roslyn) models(0x0070-0x2801)"},
{0x14F1, 0x8800, 0x0070, 0x3400, "WinTV 34604(0x0070-0x3400)"},
{0x14F1, 0x8800, 0x0070, 0x3401, "Hauppauge WinTV 34xxx models(0x0070-0x3401)"},
{0x14F1, 0x8800, 0x0070, 0x6902, "WinTV HVR-4000-HD(0x0070-0x6902)"},
{0x14F1, 0x8800, 0x0070, 0x7801, "WinTV HVR-1800 MCE(0x0070-0x7801)"},
{0x14F1, 0x8800, 0x0070, 0x9001, "Nova-T DVB-T(0x0070-0x9001)"},
{0x14F1, 0x8800, 0x0070, 0x9002, "Nova-T DVB-T Model 909(0x0070-0x9002)"},
{0x14F1, 0x8800, 0x0070, 0x9200, "Nova-SE2 DVB-S(0x0070-0x9200)"},
{0x14F1, 0x8800, 0x0070, 0x9202, "Nova-S-Plus DVB-S(0x0070-0x9202)"},
{0x14F1, 0x8800, 0x0070, 0x9402, "WinTV-HVR1100 DVB-T/Hybrid(0x0070-0x9402)"},
{0x14F1, 0x8800, 0x0070, 0x9600, "WinTV 88x Video(0x0070-0x9600)"},
{0x14F1, 0x8800, 0x0070, 0x9802, "WinTV-HVR1100 DVB-T/Hybrid (Low Profile)(0x0070-0x9802)"},
{0x14F1, 0x8800, 0x1002, 0x00F8, "ATI TV Wonder Pro(0x1002-0x00F8)"},
{0x14F1, 0x8800, 0x1002, 0x00F9, "ATI TV Wonder(0x1002-0x00F9)"},
{0x14F1, 0x8800, 0x1002, 0xA101, "HDTV Wonder(0x1002-0xA101)"},
{0x14F1, 0x8800, 0x1043, 0x4823, "PVR-416(0x1043-0x4823)"},
{0x14F1, 0x8800, 0x107D, 0x6611, "Winfast TV 2000XP Expert(0x107D-0x6611)"},
{0x14F1, 0x8800, 0x107D, 0x6613, "Leadtek Winfast 2000XP Expert(0x107D-0x6613)"},
{0x14F1, 0x8800, 0x107D, 0x6620, "Leadtek Winfast DV2000(0x107D-0x6620)"},
{0x14F1, 0x8800, 0x107D, 0x663C, "Leadtek PVR 2000(0x107D-0x663C)"},
{0x14F1, 0x8800, 0x107D, 0x665F, "WinFast DTV1000-T(0x107D-0x665F)"},
{0x14F1, 0x8800, 0x10FC, 0xD003, "IODATA GV-VCP3/PCI(0x10FC-0xD003)"},
{0x14F1, 0x8800, 0x10FC, 0xD035, "IODATA GV/BCTV7E(0x10FC-0xD035)"},
{0x14F1, 0x8800, 0x1421, 0x0334, "Instant TV DVB-T PCI(0x1421-0x0334)"},
{0x14F1, 0x8800, 0x1461, 0x000A, "AVerTV 303 (M126)(0x1461-0x000A)"},
{0x14F1, 0x8800, 0x1461, 0x000B, "AverTV Studio 303 (M126)(0x1461-0x000B)"},
{0x14F1, 0x8800, 0x1461, 0x8011, "UltraTV Media Center PCI 550(0x1461-0x8011)"},
{0x14F1, 0x8800, 0x1462, 0x8606, "MSI TV-@nywhere Master(0x1462-0x8606)"},
{0x14F1, 0x8800, 0x14C7, 0x0107, "GDI Black Gold(0x14C7-0x0107)"},
{0x14F1, 0x8800, 0x14F1, 0x0187, "Conexant DVB-T reference design(0x14F1-0x0187)"},
{0x14F1, 0x8800, 0x14F1, 0x0342, "Digital-Logic MICROSPACE Entertainment Center (MEC)(0x14F1-0x0342)"},
{0x14F1, 0x8800, 0x153B, 0x1166, "Cinergy 1400 DVB-T(0x153B-0x1166)"},
{0x14F1, 0x8800, 0x1540, 0x2580, "Provideo PV259(0x1540-0x2580)"},
{0x14F1, 0x8800, 0x1554, 0x4811, "PixelView(0x1554-0x4811)"},
{0x14F1, 0x8800, 0x1554, 0x4813, "Club 3D  ZAP1000 MCE Edition(0x1554-0x4813)"},
{0x14F1, 0x8800, 0x17DE, 0x08A1, "KWorld/VStream XPert DVB-T with cx22702(0x17DE-0x08A1)"},
{0x14F1, 0x8800, 0x17DE, 0x08A6, "KWorld/VStream XPert DVB-T(0x17DE-0x08A6)"},
{0x14F1, 0x8800, 0x17DE, 0x08B2, "KWorld DVB-S 100(0x17DE-0x08B2)"},
{0x14F1, 0x8800, 0x17DE, 0xA8A6, "digitalnow DNTV Live! DVB-T(0x17DE-0xA8A6)"},
{0x14F1, 0x8800, 0x1805, 0x0111, "PICOLO Jet-X Video(0x1805-0x0111)"},
{0x14F1, 0x8800, 0x1805, 0x0112, "PICOLO Jet-X Video(0x1805-0x0112)"},
{0x14F1, 0x8800, 0x1805, 0x0113, "PICOLO Jet-X Video(0x1805-0x0113)"},
{0x14F1, 0x8800, 0x1805, 0x0114, "PICOLO Jet-X Video(0x1805-0x0114)"},
{0x14F1, 0x8800, 0x1822, 0x0025, "digitalnow DNTV Live! DVB-T Pro(0x1822-0x0025)"},
{0x14F1, 0x8800, 0x185B, 0xE000, "VideoMate X500(0x185B-0xE000)"},
{0x14F1, 0x8800, 0x18AC, 0xD500, "FusionHDTV 5 Gold(0x18AC-0xD500)"},
{0x14F1, 0x8800, 0x18AC, 0xD810, "FusionHDTV 3 Gold-Q(0x18AC-0xD810)"},
{0x14F1, 0x8800, 0x18AC, 0xD820, "FusionHDTV 3 Gold-T(0x18AC-0xD820)"},
{0x14F1, 0x8800, 0x18AC, 0xDB00, "FusionHDTV DVB-T1(0x18AC-0xDB00)"},
{0x14F1, 0x8800, 0x18AC, 0xDB11, "FusionHDTV DVB-T Plus(0x18AC-0xDB11)"},
{0x14F1, 0x8800, 0x18AC, 0xDB50, "FusionHDTV DVB-T Dual Digital(0x18AC-0xDB50)"},
{0x14F1, 0x8800, 0x5654, 0x2388, "GoTView PCI Hybrid TV Tuner Card(0x5654-0x2388)"},
{0x14F1, 0x8800, 0x7063, 0x3000, "pcHDTV HD3000 HDTV(0x7063-0x3000)"},
{0x14F1, 0x8800, 0x7063, 0x5500, "pcHDTV HD-5500(0x7063-0x5500)"},
{0x14F1, 0x8801, 0xFFFF, 0xFFFF, "CX23880/1/2/3 PCI Video and Audio Decoder [Audio Port](0x8801)"},
{0x14F1, 0x8801, 0x0070, 0x2801, "Hauppauge WinTV 28xxx (Roslyn) models(0x0070-0x2801)"},
{0x14F1, 0x8801, 0x185B, 0xE000, "VideoMate X500(0x185B-0xE000)"},
{0x14F1, 0x8801, 0x5654, 0x2388, "GoTView PCI Hybrid Audio AVStream Device(0x5654-0x2388)"},
{0x14F1, 0x8801, 0x7063, 0x5500, "pcHDTV HD-5500(0x7063-0x5500)"},
{0x14F1, 0x8802, 0xFFFF, 0xFFFF, "CX23880/1/2/3 PCI Video and Audio Decoder [MPEG Port](0x8802)"},
{0x14F1, 0x8802, 0x0070, 0x2801, "Hauppauge WinTV 28xxx (Roslyn) models(0x0070-0x2801)"},
{0x14F1, 0x8802, 0x0070, 0x6902, "WinTV HVR-4000-HD(0x0070-0x6902)"},
{0x14F1, 0x8802, 0x0070, 0x9002, "Nova-T DVB-T Model 909(0x0070-0x9002)"},
{0x14F1, 0x8802, 0x0070, 0x9402, "WinTV-HVR1100 DVB-T/Hybrid(0x0070-0x9402)"},
{0x14F1, 0x8802, 0x0070, 0x9600, "WinTV 88x MPEG Encoder(0x0070-0x9600)"},
{0x14F1, 0x8802, 0x1043, 0x4823, "PVR-416(0x1043-0x4823)"},
{0x14F1, 0x8802, 0x107D, 0x663C, "Leadtek PVR 2000(0x107D-0x663C)"},
{0x14F1, 0x8802, 0x107D, 0x665F, "WinFast DTV1000-T(0x107D-0x665F)"},
{0x14F1, 0x8802, 0x14F1, 0x0187, "Conexant DVB-T reference design(0x14F1-0x0187)"},
{0x14F1, 0x8802, 0x17DE, 0x08A1, "XPert DVB-T PCI BDA DVBT 23880 Transport Stream Capture(0x17DE-0x08A1)"},
{0x14F1, 0x8802, 0x17DE, 0x08A6, "KWorld/VStream XPert DVB-T(0x17DE-0x08A6)"},
{0x14F1, 0x8802, 0x1805, 0x0111, "PICOLO Jet-X Jpeg(0x1805-0x0111)"},
{0x14F1, 0x8802, 0x1805, 0x0112, "PICOLO Jet-X Jpeg(0x1805-0x0112)"},
{0x14F1, 0x8802, 0x1805, 0x0113, "PICOLO Jet-X Jpeg(0x1805-0x0113)"},
{0x14F1, 0x8802, 0x1805, 0x0114, "PICOLO Jet-X Jpeg(0x1805-0x0114)"},
{0x14F1, 0x8802, 0x18AC, 0xD500, "DViCO FusionHDTV5 Gold(0x18AC-0xD500)"},
{0x14F1, 0x8802, 0x18AC, 0xD810, "DViCO FusionHDTV3 Gold-Q(0x18AC-0xD810)"},
{0x14F1, 0x8802, 0x18AC, 0xD820, "DViCO FusionHDTV3 Gold-T(0x18AC-0xD820)"},
{0x14F1, 0x8802, 0x18AC, 0xDB00, "DVICO FusionHDTV DVB-T1(0x18AC-0xDB00)"},
{0x14F1, 0x8802, 0x18AC, 0xDB10, "DVICO FusionHDTV DVB-T Plus(0x18AC-0xDB10)"},
{0x14F1, 0x8802, 0x5654, 0x2388, "GoTView PCI Hybrid TS Capture Device(0x5654-0x2388)"},
{0x14F1, 0x8802, 0x7063, 0x3000, "pcHDTV HD3000 HDTV(0x7063-0x3000)"},
{0x14F1, 0x8802, 0x7063, 0x5500, "pcHDTV HD-5500(0x7063-0x5500)"},
{0x14F1, 0x8804, 0xFFFF, 0xFFFF, "CX23880/1/2/3 PCI Video and Audio Decoder [IR Port](0x8804)"},
{0x14F1, 0x8804, 0x0070, 0x6902, "WinTV HVR-4000-HD(0x0070-0x6902)"},
{0x14F1, 0x8804, 0x0070, 0x9002, "Nova-T DVB-T Model 909(0x0070-0x9002)"},
{0x14F1, 0x8804, 0x0070, 0x9402, "WinTV-HVR1100 DVB-T/Hybrid(0x0070-0x9402)"},
{0x14F1, 0x8804, 0x1805, 0x0111, "PICOLO Jet-X Control(0x1805-0x0111)"},
{0x14F1, 0x8804, 0x1805, 0x0112, "PICOLO Jet-X Control(0x1805-0x0112)"},
{0x14F1, 0x8804, 0x1805, 0x0113, "PICOLO Jet-X Control(0x1805-0x0113)"},
{0x14F1, 0x8804, 0x1805, 0x0114, "PICOLO Jet-X Control(0x1805-0x0114)"},
{0x14F1, 0x8804, 0x7063, 0x5500, "pcHDTV HD-5500(0x7063-0x5500)"},
{0x14F1, 0x8811, 0xFFFF, 0xFFFF, "CX23880/1/2/3 PCI Video and Audio Decoder [Audio Port](0x8811)"},
{0x14F1, 0x8811, 0x0070, 0x3400, "WinTV 34604(0x0070-0x3400)"},
{0x14F1, 0x8811, 0x0070, 0x3401, "Hauppauge WinTV 34xxx models(0x0070-0x3401)"},
{0x14F1, 0x8811, 0x0070, 0x6902, "WinTV HVR-4000-HD(0x0070-0x6902)"},
{0x14F1, 0x8811, 0x0070, 0x9402, "WinTV-HVR1100 DVB-T/Hybrid(0x0070-0x9402)"},
{0x14F1, 0x8811, 0x0070, 0x9600, "WinTV 88x Audio(0x0070-0x9600)"},
{0x14F1, 0x8811, 0x1462, 0x8606, "MSI TV-@nywhere Master(0x1462-0x8606)"},
{0x14F1, 0x8811, 0x18AC, 0xD500, "DViCO FusionHDTV5 Gold(0x18AC-0xD500)"},
{0x14F1, 0x8811, 0x18AC, 0xD810, "DViCO FusionHDTV3 Gold-Q(0x18AC-0xD810)"},
{0x14F1, 0x8811, 0x18AC, 0xD820, "DViCO FusionHDTV3 Gold-T(0x18AC-0xD820)"},
{0x14F1, 0x8811, 0x18AC, 0xDB00, "DVICO FusionHDTV DVB-T1(0x18AC-0xDB00)"},
{0x14F1, 0x8811, 0x5654, 0x2388, "GoTView PCI Hybrid Audio Capture Device(0x5654-0x2388)"},
{0x14F1, 0x8852, 0xFFFF, 0xFFFF, "CX23885 PCI Video and Audio Decoder(0x8852)"},
{0x14F1, 0x8852, 0x0070, 0x8010, "WinTV HVR-1400 ExpressCard(0x0070-0x8010)"},
{0x14F1, 0x8852, 0x0070, 0xF038, "WinTV HVR-5525(0x0070-0xF038)"},
{0x14F1, 0x8852, 0x107D, 0x6F22, "WinFast PxTV1200(0x107D-0x6F22)"},
{0x14F1, 0x8852, 0x12AB, 0xD585, "PE988J Hybrid ATSC/QAM PCI-E AVS Video Capture (SoftEncoder)(0x12AB-0xD585)"},
{0x14F1, 0x8852, 0x13C2, 0x3013, "TT-budget CT2-4500 CI(0x13C2-0x3013)"},
{0x14F1, 0x8852, 0x1461, 0xC039, "AVerTV Hybrid Express (A577)(0x1461-0xC039)"},
{0x14F1, 0x8852, 0x153B, 0x117E, "Cinergy T PCIe Dual(0x153B-0x117E)"},
{0x14F1, 0x8852, 0x18AC, 0xDB78, "FusionHDTV DVB-T Dual Express(0x18AC-0xDB78)"},
{0x14F1, 0x8852, 0x4254, 0x0950, "S950(0x4254-0x0950)"},
{0x14F1, 0x8852, 0x4254, 0x0952, "S952(0x4254-0x0952)"},
{0x14F1, 0x8852, 0x4254, 0x0982, "T982(0x4254-0x0982)"},
{0x14F1, 0x8852, 0x4254, 0x9580, "T9580(0x4254-0x9580)"},
{0x14F1, 0x8852, 0x4254, 0x980C, "T980C(0x4254-0x980C)"},
{0x14F1, 0x8880, 0xFFFF, 0xFFFF, "CX23887/8 PCIe Broadcast Audio and Video Decoder with 3D Comb(0x8880)"},
{0x14F1, 0x8880, 0x0070, 0x2259, "WinTV HVR-1250(0x0070-0x2259)"},
{0x14F1, 0x8880, 0x0070, 0x6A18, "WinTV-quadHD(0x0070-0x6A18)"},
{0x14F1, 0x8880, 0x0070, 0xC108, "WinTV-HVR-4400-HD model 1278(0x0070-0xC108)"},
{0x14F1, 0x8880, 0x1461, 0x3100, "CE310B SD PCIe Video Capture Card(0x1461-0x3100)"},
{0x14F1, 0x8880, 0x5654, 0x2389, "GoTView X5 DVD Hybrid PCI-E(0x5654-0x2389)"},
{0x14F1, 0x8880, 0x5654, 0x2390, "GoTView X5 3D HYBRID PCI-E(0x5654-0x2390)"},
}; /* pci_vid_14F1[] */

static pci_id_t const pci_vid_14F2[] = {
{0x14F2, 0xFFFF, 0xFFFF, 0xFFFF, "MOBILITY Electronics(0x14F2)"},
{0x14F2, 0x0120, 0xFFFF, 0xFFFF, "EV1000 bridge(0x0120)"},
{0x14F2, 0x0121, 0xFFFF, 0xFFFF, "EV1000 Parallel port(0x0121)"},
{0x14F2, 0x0122, 0xFFFF, 0xFFFF, "EV1000 Serial port(0x0122)"},
{0x14F2, 0x0123, 0xFFFF, 0xFFFF, "EV1000 Keyboard controller(0x0123)"},
{0x14F2, 0x0124, 0xFFFF, 0xFFFF, "EV1000 Mouse controller(0x0124)"},
}; /* pci_vid_14F2[] */

static pci_id_t const pci_vid_14F3[] = {
{0x14F3, 0xFFFF, 0xFFFF, 0xFFFF, "BroadLogic(0x14F3)"},
{0x14F3, 0x2030, 0xFFFF, 0xFFFF, "2030 DVB-S Satellite Receiver(0x2030)"},
{0x14F3, 0x2035, 0xFFFF, 0xFFFF, "2035 DVB-S Satellite Receiver(0x2035)"},
{0x14F3, 0x2050, 0xFFFF, 0xFFFF, "2050 DVB-T Terrestrial (Cable) Receiver(0x2050)"},
{0x14F3, 0x2060, 0xFFFF, 0xFFFF, "2060 ATSC Terrestrial (Cable) Receiver(0x2060)"},
}; /* pci_vid_14F3[] */

static pci_id_t const pci_vid_14F4[] = {
{0x14F4, 0xFFFF, 0xFFFF, 0xFFFF, "TOKYO Electronic Industry CO Ltd(0x14F4)"},
}; /* pci_vid_14F4[] */

static pci_id_t const pci_vid_14F5[] = {
{0x14F5, 0xFFFF, 0xFFFF, 0xFFFF, "SOPAC Ltd(0x14F5)"},
}; /* pci_vid_14F5[] */

static pci_id_t const pci_vid_14F6[] = {
{0x14F6, 0xFFFF, 0xFFFF, 0xFFFF, "COYOTE Technologies LLC(0x14F6)"},
}; /* pci_vid_14F6[] */

static pci_id_t const pci_vid_14F7[] = {
{0x14F7, 0xFFFF, 0xFFFF, 0xFFFF, "WOLF Technology Inc(0x14F7)"},
}; /* pci_vid_14F7[] */

static pci_id_t const pci_vid_14F8[] = {
{0x14F8, 0xFFFF, 0xFFFF, 0xFFFF, "AUDIOCODES Inc(0x14F8)"},
{0x14F8, 0x2077, 0xFFFF, 0xFFFF, "TP-240 dual span E1 VoIP PCI card(0x2077)"},
}; /* pci_vid_14F8[] */

static pci_id_t const pci_vid_14F9[] = {
{0x14F9, 0xFFFF, 0xFFFF, 0xFFFF, "AG COMMUNICATIONS(0x14F9)"},
}; /* pci_vid_14F9[] */

static pci_id_t const pci_vid_14FA[] = {
{0x14FA, 0xFFFF, 0xFFFF, 0xFFFF, "WANDEL & GOLTERMANN(0x14FA)"},
}; /* pci_vid_14FA[] */

static pci_id_t const pci_vid_14FB[] = {
{0x14FB, 0xFFFF, 0xFFFF, 0xFFFF, "TRANSAS MARINE (UK) Ltd(0x14FB)"},
}; /* pci_vid_14FB[] */

static pci_id_t const pci_vid_14FC[] = {
{0x14FC, 0xFFFF, 0xFFFF, 0xFFFF, "Quadrics Ltd(0x14FC)"},
{0x14FC, 0x0000, 0xFFFF, 0xFFFF, "QsNet Elan3 Network Adapter(0x0000)"},
{0x14FC, 0x0001, 0xFFFF, 0xFFFF, "QsNetII Elan4 Network Adapter(0x0001)"},
{0x14FC, 0x0002, 0xFFFF, 0xFFFF, "QsNetIII Elan5 Network Adapter(0x0002)"},
}; /* pci_vid_14FC[] */

static pci_id_t const pci_vid_14FD[] = {
{0x14FD, 0xFFFF, 0xFFFF, 0xFFFF, "JAPAN Computer Industry Inc(0x14FD)"},
}; /* pci_vid_14FD[] */

static pci_id_t const pci_vid_14FE[] = {
{0x14FE, 0xFFFF, 0xFFFF, 0xFFFF, "ARCHTEK TELECOM Corp(0x14FE)"},
}; /* pci_vid_14FE[] */

static pci_id_t const pci_vid_14FF[] = {
{0x14FF, 0xFFFF, 0xFFFF, 0xFFFF, "TWINHEAD INTERNATIONAL Corp(0x14FF)"},
}; /* pci_vid_14FF[] */

static pci_id_t const pci_vid_1500[] = {
{0x1500, 0xFFFF, 0xFFFF, 0xFFFF, "DELTA Electronics, Inc(0x1500)"},
{0x1500, 0x1360, 0xFFFF, 0xFFFF, "RTL81xx RealTek Ethernet(0x1360)"},
}; /* pci_vid_1500[] */

static pci_id_t const pci_vid_1501[] = {
{0x1501, 0xFFFF, 0xFFFF, 0xFFFF, "BANKSOFT CANADA Ltd(0x1501)"},
}; /* pci_vid_1501[] */

static pci_id_t const pci_vid_1502[] = {
{0x1502, 0xFFFF, 0xFFFF, 0xFFFF, "MITSUBISHI ELECTRIC LOGISTICS SUPPORT Co Ltd(0x1502)"},
}; /* pci_vid_1502[] */

static pci_id_t const pci_vid_1503[] = {
{0x1503, 0xFFFF, 0xFFFF, 0xFFFF, "KAWASAKI LSI USA Inc(0x1503)"},
}; /* pci_vid_1503[] */

static pci_id_t const pci_vid_1504[] = {
{0x1504, 0xFFFF, 0xFFFF, 0xFFFF, "KAISER Electronics(0x1504)"},
}; /* pci_vid_1504[] */

static pci_id_t const pci_vid_1505[] = {
{0x1505, 0xFFFF, 0xFFFF, 0xFFFF, "ITA INGENIEURBURO FUR TESTAUFGABEN GmbH(0x1505)"},
}; /* pci_vid_1505[] */

static pci_id_t const pci_vid_1506[] = {
{0x1506, 0xFFFF, 0xFFFF, 0xFFFF, "CHAMELEON Systems Inc(0x1506)"},
}; /* pci_vid_1506[] */

static pci_id_t const pci_vid_1507[] = {
{0x1507, 0xFFFF, 0xFFFF, 0xFFFF, "Motorola ?-?- / HTEC(0x1507)"},
{0x1507, 0x0001, 0xFFFF, 0xFFFF, "MPC105 [Eagle](0x0001)"},
{0x1507, 0x0002, 0xFFFF, 0xFFFF, "MPC106 [Grackle](0x0002)"},
{0x1507, 0x0003, 0xFFFF, 0xFFFF, "MPC8240 [Kahlua](0x0003)"},
{0x1507, 0x0100, 0xFFFF, 0xFFFF, "MC145575 [HFC-PCI](0x0100)"},
{0x1507, 0x0431, 0xFFFF, 0xFFFF, "KTI829c 100VG(0x0431)"},
{0x1507, 0x4801, 0xFFFF, 0xFFFF, "Raven(0x4801)"},
{0x1507, 0x4802, 0xFFFF, 0xFFFF, "Falcon(0x4802)"},
{0x1507, 0x4803, 0xFFFF, 0xFFFF, "Hawk(0x4803)"},
{0x1507, 0x4806, 0xFFFF, 0xFFFF, "CPX8216(0x4806)"},
}; /* pci_vid_1507[] */

static pci_id_t const pci_vid_1508[] = {
{0x1508, 0xFFFF, 0xFFFF, 0xFFFF, "HONDA CONNECTORS/MHOTRONICS Inc(0x1508)"},
}; /* pci_vid_1508[] */

static pci_id_t const pci_vid_1509[] = {
{0x1509, 0xFFFF, 0xFFFF, 0xFFFF, "FIRST INTERNATIONAL Computer Inc(0x1509)"},
}; /* pci_vid_1509[] */

static pci_id_t const pci_vid_150A[] = {
{0x150A, 0xFFFF, 0xFFFF, 0xFFFF, "FORVUS RESEARCH Inc(0x150A)"},
}; /* pci_vid_150A[] */

static pci_id_t const pci_vid_150B[] = {
{0x150B, 0xFFFF, 0xFFFF, 0xFFFF, "YAMASHITA Systems Corp(0x150B)"},
}; /* pci_vid_150B[] */

static pci_id_t const pci_vid_150C[] = {
{0x150C, 0xFFFF, 0xFFFF, 0xFFFF, "KYOPAL CO Ltd(0x150C)"},
}; /* pci_vid_150C[] */

static pci_id_t const pci_vid_150D[] = {
{0x150D, 0xFFFF, 0xFFFF, 0xFFFF, "WARPSPPED Inc(0x150D)"},
}; /* pci_vid_150D[] */

static pci_id_t const pci_vid_150E[] = {
{0x150E, 0xFFFF, 0xFFFF, 0xFFFF, "C-PORT Corp(0x150E)"},
}; /* pci_vid_150E[] */

static pci_id_t const pci_vid_150F[] = {
{0x150F, 0xFFFF, 0xFFFF, 0xFFFF, "INTEC GmbH(0x150F)"},
}; /* pci_vid_150F[] */

static pci_id_t const pci_vid_1510[] = {
{0x1510, 0xFFFF, 0xFFFF, 0xFFFF, "BEHAVIOR TECH Computer Corp(0x1510)"},
}; /* pci_vid_1510[] */

static pci_id_t const pci_vid_1511[] = {
{0x1511, 0xFFFF, 0xFFFF, 0xFFFF, "CENTILLIUM Technology Corp(0x1511)"},
}; /* pci_vid_1511[] */

static pci_id_t const pci_vid_1512[] = {
{0x1512, 0xFFFF, 0xFFFF, 0xFFFF, "ROSUN Technologies Inc(0x1512)"},
}; /* pci_vid_1512[] */

static pci_id_t const pci_vid_1513[] = {
{0x1513, 0xFFFF, 0xFFFF, 0xFFFF, "Raychem(0x1513)"},
}; /* pci_vid_1513[] */

static pci_id_t const pci_vid_1514[] = {
{0x1514, 0xFFFF, 0xFFFF, 0xFFFF, "TFL LAN Inc(0x1514)"},
}; /* pci_vid_1514[] */

static pci_id_t const pci_vid_1515[] = {
{0x1515, 0xFFFF, 0xFFFF, 0xFFFF, "Advent design(0x1515)"},
}; /* pci_vid_1515[] */

static pci_id_t const pci_vid_1516[] = {
{0x1516, 0xFFFF, 0xFFFF, 0xFFFF, "MYSON Technology Inc(0x1516)"},
{0x1516, 0x0800, 0xFFFF, 0xFFFF, "MTD-8xx 100/10M Ethernet PCI Adapter(0x0800)"},
{0x1516, 0x0803, 0xFFFF, 0xFFFF, "SURECOM EP-320X-S 100/10M Ethernet PCI Adapter(0x0803)"},
{0x1516, 0x0803, 0x1320, 0x10BD, "SURECOM EP-320X-S 100/10M Ethernet PCI Adapter(0x1320-0x10BD)"},
{0x1516, 0x0891, 0xFFFF, 0xFFFF, "MTD-8xx 100/10M Ethernet PCI Adapter(0x0891)"},
}; /* pci_vid_1516[] */

static pci_id_t const pci_vid_1517[] = {
{0x1517, 0xFFFF, 0xFFFF, 0xFFFF, "ECHOTEK Corp(0x1517)"},
}; /* pci_vid_1517[] */

static pci_id_t const pci_vid_1518[] = {
{0x1518, 0xFFFF, 0xFFFF, 0xFFFF, "Kontron(0x1518)"},
}; /* pci_vid_1518[] */

static pci_id_t const pci_vid_1519[] = {
{0x1519, 0xFFFF, 0xFFFF, 0xFFFF, "TELEFON AKTIEBOLAGET LM Ericsson(0x1519)"},
}; /* pci_vid_1519[] */

static pci_id_t const pci_vid_151A[] = {
{0x151A, 0xFFFF, 0xFFFF, 0xFFFF, "Globetek(0x151A)"},
{0x151A, 0x1002, 0xFFFF, 0xFFFF, "PCI-1002(0x1002)"},
{0x151A, 0x1004, 0xFFFF, 0xFFFF, "PCI-1004(0x1004)"},
{0x151A, 0x1008, 0xFFFF, 0xFFFF, "PCI-1008(0x1008)"},
}; /* pci_vid_151A[] */

static pci_id_t const pci_vid_151B[] = {
{0x151B, 0xFFFF, 0xFFFF, 0xFFFF, "COMBOX Ltd(0x151B)"},
}; /* pci_vid_151B[] */

static pci_id_t const pci_vid_151C[] = {
{0x151C, 0xFFFF, 0xFFFF, 0xFFFF, "DIGITAL AUDIO LABS Inc(0x151C)"},
{0x151C, 0x0003, 0xFFFF, 0xFFFF, "Prodif T 2496(0x0003)"},
{0x151C, 0x4000, 0xFFFF, 0xFFFF, "Prodif 88(0x4000)"},
}; /* pci_vid_151C[] */

static pci_id_t const pci_vid_151D[] = {
{0x151D, 0xFFFF, 0xFFFF, 0xFFFF, "Fujitsu Computer Products Of America(0x151D)"},
}; /* pci_vid_151D[] */

static pci_id_t const pci_vid_151E[] = {
{0x151E, 0xFFFF, 0xFFFF, 0xFFFF, "MATRIX Corp(0x151E)"},
}; /* pci_vid_151E[] */

static pci_id_t const pci_vid_151F[] = {
{0x151F, 0xFFFF, 0xFFFF, 0xFFFF, "TOPIC SEMICONDUCTOR Corp(0x151F)"},
{0x151F, 0x0000, 0xFFFF, 0xFFFF, "TP560 Data/Fax/Voice 56k modem(0x0000)"},
}; /* pci_vid_151F[] */

static pci_id_t const pci_vid_1520[] = {
{0x1520, 0xFFFF, 0xFFFF, 0xFFFF, "CHAPLET System Inc(0x1520)"},
}; /* pci_vid_1520[] */

static pci_id_t const pci_vid_1521[] = {
{0x1521, 0xFFFF, 0xFFFF, 0xFFFF, "BELL Corp(0x1521)"},
}; /* pci_vid_1521[] */

static pci_id_t const pci_vid_1522[] = {
{0x1522, 0xFFFF, 0xFFFF, 0xFFFF, "MainPine Ltd(0x1522)"},
{0x1522, 0x0100, 0xFFFF, 0xFFFF, "PCI <-> IOBus Bridge(0x0100)"},
{0x1522, 0x0100, 0x1522, 0x0200, "RockForceDUO 2 Port V.92/V.44 Data/Fax/Voice Modem(0x1522-0x0200)"},
{0x1522, 0x0100, 0x1522, 0x0300, "RockForceQUATRO 4 Port V.92/V.44 Data/Fax/Voice Modem(0x1522-0x0300)"},
{0x1522, 0x0100, 0x1522, 0x0400, "RockForceDUO+ 2 Port V.92/V.44 Data/Fax/Voice Modem(0x1522-0x0400)"},
{0x1522, 0x0100, 0x1522, 0x0500, "RockForceQUATRO+ 4 Port V.92/V.44 Data/Fax/Voice Modem(0x1522-0x0500)"},
{0x1522, 0x0100, 0x1522, 0x0600, "RockForce+ 2 Port V.90 Data/Fax/Voice Modem(0x1522-0x0600)"},
{0x1522, 0x0100, 0x1522, 0x0700, "RockForce+ 4 Port V.90 Data/Fax/Voice Modem(0x1522-0x0700)"},
{0x1522, 0x0100, 0x1522, 0x0800, "RockForceOCTO+ 8 Port V.92/V.44 Data/Fax/Voice Modem(0x1522-0x0800)"},
{0x1522, 0x0100, 0x1522, 0x0C00, "RockForceDUO+ 2 Port V.92/V.44 Data, V.34 Super-G3 Fax, Voice Modem(0x1522-0x0C00)"},
{0x1522, 0x0100, 0x1522, 0x0D00, "RockForceQUATRO+ 4 Port V.92/V.44 Data, V.34 Super-G3 Fax, Voice Modem(0x1522-0x0D00)"},
{0x1522, 0x0100, 0x1522, 0x1D00, "RockForceOCTO+ 8 Port V.92/V.44 Data, V.34 Super-G3 Fax, Voice Modem(0x1522-0x1D00)"},
{0x1522, 0x0100, 0x1522, 0x2000, "RockForceD1 1 Port V.90 Data Modem(0x1522-0x2000)"},
{0x1522, 0x0100, 0x1522, 0x2100, "RockForceF1 1 Port V.34 Super-G3 Fax Modem(0x1522-0x2100)"},
{0x1522, 0x0100, 0x1522, 0x2200, "RockForceD2 2 Port V.90 Data Modem(0x1522-0x2200)"},
{0x1522, 0x0100, 0x1522, 0x2300, "RockForceF2 2 Port V.34 Super-G3 Fax Modem(0x1522-0x2300)"},
{0x1522, 0x0100, 0x1522, 0x2400, "RockForceD4 4 Port V.90 Data Modem(0x1522-0x2400)"},
{0x1522, 0x0100, 0x1522, 0x2500, "RockForceF4 4 Port V.34 Super-G3 Fax Modem(0x1522-0x2500)"},
{0x1522, 0x0100, 0x1522, 0x2600, "RockForceD8 8 Port V.90 Data Modem(0x1522-0x2600)"},
{0x1522, 0x0100, 0x1522, 0x2700, "RockForceF8 8 Port V.34 Super-G3 Fax Modem(0x1522-0x2700)"},
{0x1522, 0x0100, 0x1522, 0x3000, "IQ Express D1 - 1 Port V.92 Data Modem(0x1522-0x3000)"},
{0x1522, 0x0100, 0x1522, 0x3100, "IQ Express F1 - 1 Port V.34 Super-G3 Fax Modem(0x1522-0x3100)"},
{0x1522, 0x0100, 0x1522, 0x3200, "IQ Express D2 - 2 Port V.92 Data Modem(0x1522-0x3200)"},
{0x1522, 0x0100, 0x1522, 0x3300, "IQ Express F2 - 2 Port V.34 Super-G3 Fax Modem(0x1522-0x3300)"},
{0x1522, 0x0100, 0x1522, 0x3400, "IQ Express D4 - 4 Port V.92 Data Modem(0x1522-0x3400)"},
{0x1522, 0x0100, 0x1522, 0x3500, "IQ Express F4 - 4 Port V.34 Super-G3 Fax Modem(0x1522-0x3500)"},
{0x1522, 0x0100, 0x1522, 0x3C00, "IQ Express D8 - 8 Port V.92 Data Modem(0x1522-0x3C00)"},
{0x1522, 0x0100, 0x1522, 0x3D00, "IQ Express F8 - 8 Port V.34 Super-G3 Fax Modem(0x1522-0x3D00)"},
{0x1522, 0x4000, 0xFFFF, 0xFFFF, "PCI Express UART(0x4000)"},
{0x1522, 0x4000, 0x1522, 0x4001, "IQ Express 1-port V.34 Super-G3 Fax(0x1522-0x4001)"},
{0x1522, 0x4000, 0x1522, 0x4002, "IQ Express 2-port V.34 Super-G3 Fax(0x1522-0x4002)"},
{0x1522, 0x4000, 0x1522, 0x4004, "IQ Express 4-port V.34 Super-G3 Fax(0x1522-0x4004)"},
{0x1522, 0x4000, 0x1522, 0x4008, "IQ Express 8-port V.34 Super-G3 Fax(0x1522-0x4008)"},
{0x1522, 0x4000, 0x1522, 0x4100, "IQ Express SideBand(0x1522-0x4100)"},
}; /* pci_vid_1522[] */

static pci_id_t const pci_vid_1523[] = {
{0x1523, 0xFFFF, 0xFFFF, 0xFFFF, "MUSIC Semiconductors(0x1523)"},
}; /* pci_vid_1523[] */

static pci_id_t const pci_vid_1524[] = {
{0x1524, 0xFFFF, 0xFFFF, 0xFFFF, "ENE Technology Inc(0x1524)"},
{0x1524, 0x0510, 0xFFFF, 0xFFFF, "CB710 Memory Card Reader Controller(0x0510)"},
{0x1524, 0x0510, 0x103C, 0x006A, "NX9500(0x103C-0x006A)"},
{0x1524, 0x0520, 0xFFFF, 0xFFFF, "FLASH memory: ENE Technology Inc:(0x0520)"},
{0x1524, 0x0530, 0xFFFF, 0xFFFF, "ENE PCI Memory Stick Card Reader Controller(0x0530)"},
{0x1524, 0x0550, 0xFFFF, 0xFFFF, "ENE PCI Secure Digital Card Reader Controller(0x0550)"},
{0x1524, 0x0551, 0xFFFF, 0xFFFF, "SD/MMC Card Reader Controller(0x0551)"},
{0x1524, 0x0610, 0xFFFF, 0xFFFF, "PCI Smart Card Reader Controller(0x0610)"},
{0x1524, 0x0720, 0xFFFF, 0xFFFF, "Memory Stick Card Reader Controller(0x0720)"},
{0x1524, 0x0730, 0xFFFF, 0xFFFF, "ENE PCI Memory Stick Card Reader Controller(0x0730)"},
{0x1524, 0x0750, 0xFFFF, 0xFFFF, "ENE PCI SmartMedia / xD Card Reader Controller(0x0750)"},
{0x1524, 0x0751, 0xFFFF, 0xFFFF, "ENE PCI Secure Digital / MMC Card Reader Controller(0x0751)"},
{0x1524, 0x1211, 0xFFFF, 0xFFFF, "CB1211 Cardbus Controller(0x1211)"},
{0x1524, 0x1225, 0xFFFF, 0xFFFF, "CB1225 Cardbus Controller(0x1225)"},
{0x1524, 0x1410, 0xFFFF, 0xFFFF, "CB1410 Cardbus Controller(0x1410)"},
{0x1524, 0x1410, 0x1025, 0x003C, "CL50 motherboard(0x1025-0x003C)"},
{0x1524, 0x1410, 0x1025, 0x005A, "TravelMate 290(0x1025-0x005A)"},
{0x1524, 0x1410, 0x103C, 0x30D5, "530 Laptop(0x103C-0x30D5)"},
{0x1524, 0x1411, 0xFFFF, 0xFFFF, "CB-710/2/4 Cardbus Controller(0x1411)"},
{0x1524, 0x1411, 0x103C, 0x006A, "NX9500(0x103C-0x006A)"},
{0x1524, 0x1412, 0xFFFF, 0xFFFF, "CB-712/4 Cardbus Controller(0x1412)"},
{0x1524, 0x1420, 0xFFFF, 0xFFFF, "CB1420 Cardbus Controller(0x1420)"},
{0x1524, 0x1421, 0xFFFF, 0xFFFF, "CB-720/2/4 Cardbus Controller(0x1421)"},
{0x1524, 0x1422, 0xFFFF, 0xFFFF, "CB-722/4 Cardbus Controller(0x1422)"},
}; /* pci_vid_1524[] */

static pci_id_t const pci_vid_1525[] = {
{0x1525, 0xFFFF, 0xFFFF, 0xFFFF, "IMPACT Technologies(0x1525)"},
}; /* pci_vid_1525[] */

static pci_id_t const pci_vid_1526[] = {
{0x1526, 0xFFFF, 0xFFFF, 0xFFFF, "ISS, Inc(0x1526)"},
}; /* pci_vid_1526[] */

static pci_id_t const pci_vid_1527[] = {
{0x1527, 0xFFFF, 0xFFFF, 0xFFFF, "SOLECTRON(0x1527)"},
}; /* pci_vid_1527[] */

static pci_id_t const pci_vid_1528[] = {
{0x1528, 0xFFFF, 0xFFFF, 0xFFFF, "ACKSYS(0x1528)"},
}; /* pci_vid_1528[] */

static pci_id_t const pci_vid_1529[] = {
{0x1529, 0xFFFF, 0xFFFF, 0xFFFF, "ON Semiconductor(0x1529)"},
}; /* pci_vid_1529[] */

static pci_id_t const pci_vid_152A[] = {
{0x152A, 0xFFFF, 0xFFFF, 0xFFFF, "QUICKTURN DESIGN Systems(0x152A)"},
}; /* pci_vid_152A[] */

static pci_id_t const pci_vid_152B[] = {
{0x152B, 0xFFFF, 0xFFFF, 0xFFFF, "FLYTECH Technology CO Ltd(0x152B)"},
}; /* pci_vid_152B[] */

static pci_id_t const pci_vid_152C[] = {
{0x152C, 0xFFFF, 0xFFFF, 0xFFFF, "MACRAIGOR Systems LLC(0x152C)"},
}; /* pci_vid_152C[] */

static pci_id_t const pci_vid_152D[] = {
{0x152D, 0xFFFF, 0xFFFF, 0xFFFF, "QUANTA Computer Inc(0x152D)"},
}; /* pci_vid_152D[] */

static pci_id_t const pci_vid_152E[] = {
{0x152E, 0xFFFF, 0xFFFF, 0xFFFF, "MELEC Inc(0x152E)"},
}; /* pci_vid_152E[] */

static pci_id_t const pci_vid_152F[] = {
{0x152F, 0xFFFF, 0xFFFF, 0xFFFF, "PHILIPS - CRYPTO(0x152F)"},
}; /* pci_vid_152F[] */

static pci_id_t const pci_vid_1530[] = {
{0x1530, 0xFFFF, 0xFFFF, 0xFFFF, "ACQIS Technology Inc(0x1530)"},
}; /* pci_vid_1530[] */

static pci_id_t const pci_vid_1531[] = {
{0x1531, 0xFFFF, 0xFFFF, 0xFFFF, "CHRYON Corp(0x1531)"},
}; /* pci_vid_1531[] */

static pci_id_t const pci_vid_1532[] = {
{0x1532, 0xFFFF, 0xFFFF, 0xFFFF, "ECHELON Corp(0x1532)"},
{0x1532, 0x0020, 0xFFFF, 0xFFFF, "LonWorks PCLTA-20 PCI LonTalk Adapter(0x0020)"},
}; /* pci_vid_1532[] */

static pci_id_t const pci_vid_1533[] = {
{0x1533, 0xFFFF, 0xFFFF, 0xFFFF, "BALTIMORE(0x1533)"},
}; /* pci_vid_1533[] */

static pci_id_t const pci_vid_1534[] = {
{0x1534, 0xFFFF, 0xFFFF, 0xFFFF, "ROAD Corp(0x1534)"},
}; /* pci_vid_1534[] */

static pci_id_t const pci_vid_1535[] = {
{0x1535, 0xFFFF, 0xFFFF, 0xFFFF, "EVERGREEN Technologies Inc(0x1535)"},
}; /* pci_vid_1535[] */

static pci_id_t const pci_vid_1536[] = {
{0x1536, 0xFFFF, 0xFFFF, 0xFFFF, "ACTIS Computer(0x1536)"},
}; /* pci_vid_1536[] */

static pci_id_t const pci_vid_1537[] = {
{0x1537, 0xFFFF, 0xFFFF, 0xFFFF, "DATALEX COMMUNCATIONS(0x1537)"},
}; /* pci_vid_1537[] */

static pci_id_t const pci_vid_1538[] = {
{0x1538, 0xFFFF, 0xFFFF, 0xFFFF, "ARALION Inc(0x1538)"},
{0x1538, 0x0303, 0xFFFF, 0xFFFF, "ARS106S Ultra ATA 133/100/66 Host Controller(0x0303)"},
}; /* pci_vid_1538[] */

static pci_id_t const pci_vid_1539[] = {
{0x1539, 0xFFFF, 0xFFFF, 0xFFFF, "ATELIER INFORMATIQUES et ELECTRONIQUE ETUDES S.A.(0x1539)"},
}; /* pci_vid_1539[] */

static pci_id_t const pci_vid_153A[] = {
{0x153A, 0xFFFF, 0xFFFF, 0xFFFF, "ONO SOKKI(0x153A)"},
}; /* pci_vid_153A[] */

static pci_id_t const pci_vid_153B[] = {
{0x153B, 0xFFFF, 0xFFFF, 0xFFFF, "TERRATEC Electronic GmbH(0x153B)"},
{0x153B, 0x1144, 0xFFFF, 0xFFFF, "Aureon 5.1(0x1144)"},
{0x153B, 0x1147, 0xFFFF, 0xFFFF, "Aureon 5.1 Sky(0x1147)"},
{0x153B, 0x1158, 0xFFFF, 0xFFFF, "Philips Semiconductors SAA7134 (rev 01) [Terratec Cinergy 600 TV](0x1158)"},
}; /* pci_vid_153B[] */

static pci_id_t const pci_vid_153C[] = {
{0x153C, 0xFFFF, 0xFFFF, 0xFFFF, "ANTAL Electronic(0x153C)"},
}; /* pci_vid_153C[] */

static pci_id_t const pci_vid_153D[] = {
{0x153D, 0xFFFF, 0xFFFF, 0xFFFF, "FILANET Corp(0x153D)"},
}; /* pci_vid_153D[] */

static pci_id_t const pci_vid_153E[] = {
{0x153E, 0xFFFF, 0xFFFF, 0xFFFF, "TECHWELL Inc(0x153E)"},
}; /* pci_vid_153E[] */

static pci_id_t const pci_vid_153F[] = {
{0x153F, 0xFFFF, 0xFFFF, 0xFFFF, "MIPS Technologies, Inc.(0x153F)"},
{0x153F, 0x0001, 0xFFFF, 0xFFFF, "SOC-it 101 System Controller(0x0001)"},
}; /* pci_vid_153F[] */

static pci_id_t const pci_vid_1540[] = {
{0x1540, 0xFFFF, 0xFFFF, 0xFFFF, "PROVIDEO MULTIMEDIA Co Ltd(0x1540)"},
}; /* pci_vid_1540[] */

static pci_id_t const pci_vid_1541[] = {
{0x1541, 0xFFFF, 0xFFFF, 0xFFFF, "MACHONE Communications(0x1541)"},
}; /* pci_vid_1541[] */

static pci_id_t const pci_vid_1542[] = {
{0x1542, 0xFFFF, 0xFFFF, 0xFFFF, "Concurrent Real-Time(0x1542)"},
{0x1542, 0x9260, 0xFFFF, 0xFFFF, "RCIM-II Real-Time Clock & Interrupt Module(0x9260)"},
{0x1542, 0x9271, 0xFFFF, 0xFFFF, "RCIM-III Real-Time Clock & Interrupt Module (PCIe)(0x9271)"},
{0x1542, 0x9272, 0xFFFF, 0xFFFF, "Pulse Width Modulator Card(0x9272)"},
{0x1542, 0x9273, 0xFFFF, 0xFFFF, "RCIM-IV Real-Time Clock & Interrupt Module (PCIe)(0x9273)"},
{0x1542, 0x9277, 0xFFFF, 0xFFFF, "5 Volt Delta Sigma Converter Card(0x9277)"},
{0x1542, 0x9278, 0xFFFF, 0xFFFF, "10 Volt Delta Sigma Converter Card(0x9278)"},
{0x1542, 0x9287, 0xFFFF, 0xFFFF, "Analog Output Card(0x9287)"},
{0x1542, 0x9290, 0xFFFF, 0xFFFF, "FPGA Card(0x9290)"},
{0x1542, 0x9300, 0xFFFF, 0xFFFF, "Universal Exhaust Gas Oxygen Sensor Simulator(0x9300)"},
{0x1542, 0x9310, 0xFFFF, 0xFFFF, "Digital Programmable Resistor(0x9310)"},
{0x1542, 0x9320, 0xFFFF, 0xFFFF, "Arria 10 FPGA Card(0x9320)"},
{0x1542, 0x9350, 0xFFFF, 0xFFFF, "Analog Input Card(0x9350)"},
}; /* pci_vid_1542[] */

static pci_id_t const pci_vid_1543[] = {
{0x1543, 0xFFFF, 0xFFFF, 0xFFFF, "SILICON Laboratories(0x1543)"},
{0x1543, 0x3052, 0xFFFF, 0xFFFF, "Intel 537 [Winmodem](0x3052)"},
{0x1543, 0x4C22, 0xFFFF, 0xFFFF, "Si3036 MC'97 DAA(0x4C22)"},
}; /* pci_vid_1543[] */

static pci_id_t const pci_vid_1544[] = {
{0x1544, 0xFFFF, 0xFFFF, 0xFFFF, "DCM DATA Systems(0x1544)"},
}; /* pci_vid_1544[] */

static pci_id_t const pci_vid_1545[] = {
{0x1545, 0xFFFF, 0xFFFF, 0xFFFF, "VISIONTEK(0x1545)"},
}; /* pci_vid_1545[] */

static pci_id_t const pci_vid_1546[] = {
{0x1546, 0xFFFF, 0xFFFF, 0xFFFF, "IOI Technology Corp(0x1546)"},
}; /* pci_vid_1546[] */

static pci_id_t const pci_vid_1547[] = {
{0x1547, 0xFFFF, 0xFFFF, 0xFFFF, "MITUTOYO Corp(0x1547)"},
}; /* pci_vid_1547[] */

static pci_id_t const pci_vid_1548[] = {
{0x1548, 0xFFFF, 0xFFFF, 0xFFFF, "JET PROPULSION Laboratory(0x1548)"},
}; /* pci_vid_1548[] */

static pci_id_t const pci_vid_1549[] = {
{0x1549, 0xFFFF, 0xFFFF, 0xFFFF, "INTERCONNECT Systems Solutions(0x1549)"},
}; /* pci_vid_1549[] */

static pci_id_t const pci_vid_154A[] = {
{0x154A, 0xFFFF, 0xFFFF, 0xFFFF, "MAX Technologies Inc(0x154A)"},
}; /* pci_vid_154A[] */

static pci_id_t const pci_vid_154B[] = {
{0x154B, 0xFFFF, 0xFFFF, 0xFFFF, "COMPUTEX Co Ltd(0x154B)"},
}; /* pci_vid_154B[] */

static pci_id_t const pci_vid_154C[] = {
{0x154C, 0xFFFF, 0xFFFF, 0xFFFF, "VISUAL Technology Inc(0x154C)"},
}; /* pci_vid_154C[] */

static pci_id_t const pci_vid_154D[] = {
{0x154D, 0xFFFF, 0xFFFF, 0xFFFF, "PAN INTERNATIONAL Industrial Corp(0x154D)"},
}; /* pci_vid_154D[] */

static pci_id_t const pci_vid_154E[] = {
{0x154E, 0xFFFF, 0xFFFF, 0xFFFF, "SERVOTEST Ltd(0x154E)"},
}; /* pci_vid_154E[] */

static pci_id_t const pci_vid_154F[] = {
{0x154F, 0xFFFF, 0xFFFF, 0xFFFF, "STRATABEAM Technology(0x154F)"},
}; /* pci_vid_154F[] */

static pci_id_t const pci_vid_1550[] = {
{0x1550, 0xFFFF, 0xFFFF, 0xFFFF, "OPEN NETWORK Co Ltd(0x1550)"},
}; /* pci_vid_1550[] */

static pci_id_t const pci_vid_1551[] = {
{0x1551, 0xFFFF, 0xFFFF, 0xFFFF, "SMART Electronic DEVELOPMENT GmBH(0x1551)"},
}; /* pci_vid_1551[] */

static pci_id_t const pci_vid_1552[] = {
{0x1552, 0xFFFF, 0xFFFF, 0xFFFF, "RACAL AIRTECH Ltd(0x1552)"},
}; /* pci_vid_1552[] */

static pci_id_t const pci_vid_1553[] = {
{0x1553, 0xFFFF, 0xFFFF, 0xFFFF, "CHICONY Electronics Co Ltd(0x1553)"},
}; /* pci_vid_1553[] */

static pci_id_t const pci_vid_1554[] = {
{0x1554, 0xFFFF, 0xFFFF, 0xFFFF, "PROLINK Microsystems Corp(0x1554)"},
}; /* pci_vid_1554[] */

static pci_id_t const pci_vid_1555[] = {
{0x1555, 0xFFFF, 0xFFFF, 0xFFFF, "GESYTEC GmBH(0x1555)"},
}; /* pci_vid_1555[] */

static pci_id_t const pci_vid_1556[] = {
{0x1556, 0xFFFF, 0xFFFF, 0xFFFF, "PLDA(0x1556)"},
{0x1556, 0x1100, 0xFFFF, 0xFFFF, "PCI Express Core Reference Design(0x1100)"},
{0x1556, 0x110F, 0xFFFF, 0xFFFF, "PCI Express Core Reference Design Virtual Function(0x110F)"},
{0x1556, 0x1110, 0xFFFF, 0xFFFF, "XpressRich Reference Design(0x1110)"},
{0x1556, 0x1111, 0xFFFF, 0xFFFF, "XpressRich-AXI Ref Design(0x1111)"},
{0x1556, 0x1112, 0xFFFF, 0xFFFF, "QuickPCIe(0x1112)"},
{0x1556, 0x1113, 0xFFFF, 0xFFFF, "XpressSwitch(0x1113)"},
{0x1556, 0x1114, 0xFFFF, 0xFFFF, "Inspector(0x1114)"},
{0x1556, 0x1115, 0xFFFF, 0xFFFF, "XpressLINK Ref Design(0x1115)"},
{0x1556, 0x1116, 0xFFFF, 0xFFFF, "XpressLINK-SOC Ref Design(0x1116)"},
{0x1556, 0xBE00, 0xFFFF, 0xFFFF, "PCI Express Bridge(0xBE00)"},
}; /* pci_vid_1556[] */

static pci_id_t const pci_vid_1557[] = {
{0x1557, 0xFFFF, 0xFFFF, 0xFFFF, "MEDIASTAR Co Ltd(0x1557)"},
}; /* pci_vid_1557[] */

static pci_id_t const pci_vid_1558[] = {
{0x1558, 0xFFFF, 0xFFFF, 0xFFFF, "CLEVO/KAPOK Computer(0x1558)"},
{0x1558, 0x9602, 0xFFFF, 0xFFFF, "RS780/RS880 PCI to PCI bridge (int gfx)(0x9602)"},
}; /* pci_vid_1558[] */

static pci_id_t const pci_vid_1559[] = {
{0x1559, 0xFFFF, 0xFFFF, 0xFFFF, "SI LOGIC Ltd(0x1559)"},
}; /* pci_vid_1559[] */

static pci_id_t const pci_vid_155A[] = {
{0x155A, 0xFFFF, 0xFFFF, 0xFFFF, "INNOMEDIA Inc(0x155A)"},
}; /* pci_vid_155A[] */

static pci_id_t const pci_vid_155B[] = {
{0x155B, 0xFFFF, 0xFFFF, 0xFFFF, "PROTAC INTERNATIONAL Corp(0x155B)"},
}; /* pci_vid_155B[] */

static pci_id_t const pci_vid_155C[] = {
{0x155C, 0xFFFF, 0xFFFF, 0xFFFF, "Cemax-Icon Inc(0x155C)"},
}; /* pci_vid_155C[] */

static pci_id_t const pci_vid_155D[] = {
{0x155D, 0xFFFF, 0xFFFF, 0xFFFF, "Mac System Co Ltd(0x155D)"},
}; /* pci_vid_155D[] */

static pci_id_t const pci_vid_155E[] = {
{0x155E, 0xFFFF, 0xFFFF, 0xFFFF, "LP Elektronik GmbH(0x155E)"},
}; /* pci_vid_155E[] */

static pci_id_t const pci_vid_155F[] = {
{0x155F, 0xFFFF, 0xFFFF, 0xFFFF, "Perle Systems Ltd(0x155F)"},
}; /* pci_vid_155F[] */

static pci_id_t const pci_vid_1560[] = {
{0x1560, 0xFFFF, 0xFFFF, 0xFFFF, "Terayon Communications Systems(0x1560)"},
}; /* pci_vid_1560[] */

static pci_id_t const pci_vid_1561[] = {
{0x1561, 0xFFFF, 0xFFFF, 0xFFFF, "Viewgraphics Inc(0x1561)"},
}; /* pci_vid_1561[] */

static pci_id_t const pci_vid_1562[] = {
{0x1562, 0xFFFF, 0xFFFF, 0xFFFF, "Symbol Technologies(0x1562)"},
}; /* pci_vid_1562[] */

static pci_id_t const pci_vid_1563[] = {
{0x1563, 0xFFFF, 0xFFFF, 0xFFFF, "A-Trend Technology Co Ltd(0x1563)"},
}; /* pci_vid_1563[] */

static pci_id_t const pci_vid_1564[] = {
{0x1564, 0xFFFF, 0xFFFF, 0xFFFF, "Yamakatsu Electronics Industry Co Ltd(0x1564)"},
}; /* pci_vid_1564[] */

static pci_id_t const pci_vid_1565[] = {
{0x1565, 0xFFFF, 0xFFFF, 0xFFFF, "Biostar Microtech Int'l Corp(0x1565)"},
}; /* pci_vid_1565[] */

static pci_id_t const pci_vid_1566[] = {
{0x1566, 0xFFFF, 0xFFFF, 0xFFFF, "Ardent Technologies Inc(0x1566)"},
}; /* pci_vid_1566[] */

static pci_id_t const pci_vid_1567[] = {
{0x1567, 0xFFFF, 0xFFFF, 0xFFFF, "Jungsoft(0x1567)"},
}; /* pci_vid_1567[] */

static pci_id_t const pci_vid_1568[] = {
{0x1568, 0xFFFF, 0xFFFF, 0xFFFF, "DDK Electronics Inc(0x1568)"},
}; /* pci_vid_1568[] */

static pci_id_t const pci_vid_1569[] = {
{0x1569, 0xFFFF, 0xFFFF, 0xFFFF, "Palit Microsystems Inc.(0x1569)"},
}; /* pci_vid_1569[] */

static pci_id_t const pci_vid_156A[] = {
{0x156A, 0xFFFF, 0xFFFF, 0xFFFF, "Avtec Systems(0x156A)"},
}; /* pci_vid_156A[] */

static pci_id_t const pci_vid_156B[] = {
{0x156B, 0xFFFF, 0xFFFF, 0xFFFF, "2wire Inc(0x156B)"},
}; /* pci_vid_156B[] */

static pci_id_t const pci_vid_156C[] = {
{0x156C, 0xFFFF, 0xFFFF, 0xFFFF, "Vidac Electronics GmbH(0x156C)"},
}; /* pci_vid_156C[] */

static pci_id_t const pci_vid_156D[] = {
{0x156D, 0xFFFF, 0xFFFF, 0xFFFF, "Alpha-Top Corp(0x156D)"},
}; /* pci_vid_156D[] */

static pci_id_t const pci_vid_156E[] = {
{0x156E, 0xFFFF, 0xFFFF, 0xFFFF, "Alfa Inc(0x156E)"},
}; /* pci_vid_156E[] */

static pci_id_t const pci_vid_156F[] = {
{0x156F, 0xFFFF, 0xFFFF, 0xFFFF, "M-Systems Flash Disk Pioneers Ltd(0x156F)"},
}; /* pci_vid_156F[] */

static pci_id_t const pci_vid_1570[] = {
{0x1570, 0xFFFF, 0xFFFF, 0xFFFF, "Teledyne Lecroy(0x1570)"},
}; /* pci_vid_1570[] */

static pci_id_t const pci_vid_1571[] = {
{0x1571, 0xFFFF, 0xFFFF, 0xFFFF, "Contemporary Controls(0x1571)"},
{0x1571, 0xA001, 0xFFFF, 0xFFFF, "CCSI PCI20-485 ARCnet(0xA001)"},
{0x1571, 0xA002, 0xFFFF, 0xFFFF, "CCSI PCI20-485D ARCnet(0xA002)"},
{0x1571, 0xA003, 0xFFFF, 0xFFFF, "CCSI PCI20-485X ARCnet(0xA003)"},
{0x1571, 0xA004, 0xFFFF, 0xFFFF, "CCSI PCI20-CXB ARCnet(0xA004)"},
{0x1571, 0xA005, 0xFFFF, 0xFFFF, "CCSI PCI20-CXS ARCnet(0xA005)"},
{0x1571, 0xA006, 0xFFFF, 0xFFFF, "CCSI PCI20-FOG-SMA ARCnet(0xA006)"},
{0x1571, 0xA007, 0xFFFF, 0xFFFF, "CCSI PCI20-FOG-ST ARCnet(0xA007)"},
{0x1571, 0xA008, 0xFFFF, 0xFFFF, "CCSI PCI20-TB5 ARCnet(0xA008)"},
{0x1571, 0xA009, 0xFFFF, 0xFFFF, "CCSI PCI20-5-485 5Mbit ARCnet(0xA009)"},
{0x1571, 0xA00A, 0xFFFF, 0xFFFF, "CCSI PCI20-5-485D 5Mbit ARCnet(0xA00A)"},
{0x1571, 0xA00B, 0xFFFF, 0xFFFF, "CCSI PCI20-5-485X 5Mbit ARCnet(0xA00B)"},
{0x1571, 0xA00C, 0xFFFF, 0xFFFF, "CCSI PCI20-5-FOG-ST 5Mbit ARCnet(0xA00C)"},
{0x1571, 0xA00D, 0xFFFF, 0xFFFF, "CCSI PCI20-5-FOG-SMA 5Mbit ARCnet(0xA00D)"},
{0x1571, 0xA201, 0xFFFF, 0xFFFF, "CCSI PCI22-485 10Mbit ARCnet(0xA201)"},
{0x1571, 0xA202, 0xFFFF, 0xFFFF, "CCSI PCI22-485D 10Mbit ARCnet(0xA202)"},
{0x1571, 0xA203, 0xFFFF, 0xFFFF, "CCSI PCI22-485X 10Mbit ARCnet(0xA203)"},
{0x1571, 0xA204, 0xFFFF, 0xFFFF, "CCSI PCI22-CHB 10Mbit ARCnet(0xA204)"},
{0x1571, 0xA205, 0xFFFF, 0xFFFF, "CCSI PCI22-FOG_ST 10Mbit ARCnet(0xA205)"},
{0x1571, 0xA206, 0xFFFF, 0xFFFF, "CCSI PCI22-THB 10Mbit ARCnet(0xA206)"},
}; /* pci_vid_1571[] */

static pci_id_t const pci_vid_1572[] = {
{0x1572, 0xFFFF, 0xFFFF, 0xFFFF, "Otis Elevator Company(0x1572)"},
}; /* pci_vid_1572[] */

static pci_id_t const pci_vid_1573[] = {
{0x1573, 0xFFFF, 0xFFFF, 0xFFFF, "Lattice - Vantis(0x1573)"},
}; /* pci_vid_1573[] */

static pci_id_t const pci_vid_1574[] = {
{0x1574, 0xFFFF, 0xFFFF, 0xFFFF, "Fairchild Semiconductor(0x1574)"},
}; /* pci_vid_1574[] */

static pci_id_t const pci_vid_1575[] = {
{0x1575, 0xFFFF, 0xFFFF, 0xFFFF, "Voltaire Advanced Data Security Ltd(0x1575)"},
}; /* pci_vid_1575[] */

static pci_id_t const pci_vid_1576[] = {
{0x1576, 0xFFFF, 0xFFFF, 0xFFFF, "Viewcast COM(0x1576)"},
}; /* pci_vid_1576[] */

static pci_id_t const pci_vid_1578[] = {
{0x1578, 0xFFFF, 0xFFFF, 0xFFFF, "HITT(0x1578)"},
{0x1578, 0x4D34, 0xFFFF, 0xFFFF, "VPMK4 [Video Processor Mk IV](0x4D34)"},
{0x1578, 0x5615, 0xFFFF, 0xFFFF, "VPMK3 [Video Processor Mk III](0x5615)"},
}; /* pci_vid_1578[] */

static pci_id_t const pci_vid_1579[] = {
{0x1579, 0xFFFF, 0xFFFF, 0xFFFF, "Dual Technology Corp(0x1579)"},
}; /* pci_vid_1579[] */

static pci_id_t const pci_vid_157A[] = {
{0x157A, 0xFFFF, 0xFFFF, 0xFFFF, "Japan Elecronics Ind Inc(0x157A)"},
}; /* pci_vid_157A[] */

static pci_id_t const pci_vid_157B[] = {
{0x157B, 0xFFFF, 0xFFFF, 0xFFFF, "Star Multimedia Corp(0x157B)"},
}; /* pci_vid_157B[] */

static pci_id_t const pci_vid_157C[] = {
{0x157C, 0xFFFF, 0xFFFF, 0xFFFF, "Eurosoft (UK)(0x157C)"},
{0x157C, 0x8001, 0xFFFF, 0xFFFF, "Fix2000 PCI Y2K Compliance Card(0x8001)"},
}; /* pci_vid_157C[] */

static pci_id_t const pci_vid_157D[] = {
{0x157D, 0xFFFF, 0xFFFF, 0xFFFF, "Gemflex Networks(0x157D)"},
}; /* pci_vid_157D[] */

static pci_id_t const pci_vid_157E[] = {
{0x157E, 0xFFFF, 0xFFFF, 0xFFFF, "Transition Networks(0x157E)"},
}; /* pci_vid_157E[] */

static pci_id_t const pci_vid_157F[] = {
{0x157F, 0xFFFF, 0xFFFF, 0xFFFF, "PX Instruments Technology Ltd(0x157F)"},
}; /* pci_vid_157F[] */

static pci_id_t const pci_vid_1580[] = {
{0x1580, 0xFFFF, 0xFFFF, 0xFFFF, "Primex Aerospace Co(0x1580)"},
}; /* pci_vid_1580[] */

static pci_id_t const pci_vid_1581[] = {
{0x1581, 0xFFFF, 0xFFFF, 0xFFFF, "SEH Computertechnik GmbH(0x1581)"},
}; /* pci_vid_1581[] */

static pci_id_t const pci_vid_1582[] = {
{0x1582, 0xFFFF, 0xFFFF, 0xFFFF, "Cytec Corp(0x1582)"},
}; /* pci_vid_1582[] */

static pci_id_t const pci_vid_1583[] = {
{0x1583, 0xFFFF, 0xFFFF, 0xFFFF, "Inet Technologies Inc(0x1583)"},
}; /* pci_vid_1583[] */

static pci_id_t const pci_vid_1584[] = {
{0x1584, 0xFFFF, 0xFFFF, 0xFFFF, "Uniwill Computer Corp(0x1584)"},
}; /* pci_vid_1584[] */

static pci_id_t const pci_vid_1585[] = {
{0x1585, 0xFFFF, 0xFFFF, 0xFFFF, "Logitron(0x1585)"},
}; /* pci_vid_1585[] */

static pci_id_t const pci_vid_1586[] = {
{0x1586, 0xFFFF, 0xFFFF, 0xFFFF, "Lancast Inc(0x1586)"},
}; /* pci_vid_1586[] */

static pci_id_t const pci_vid_1587[] = {
{0x1587, 0xFFFF, 0xFFFF, 0xFFFF, "Konica Corp(0x1587)"},
}; /* pci_vid_1587[] */

static pci_id_t const pci_vid_1588[] = {
{0x1588, 0xFFFF, 0xFFFF, 0xFFFF, "Solidum Systems Corp(0x1588)"},
}; /* pci_vid_1588[] */

static pci_id_t const pci_vid_1589[] = {
{0x1589, 0xFFFF, 0xFFFF, 0xFFFF, "Atlantek Microsystems Pty Ltd(0x1589)"},
{0x1589, 0x0008, 0xFFFF, 0xFFFF, "Leutron Vision PicPortExpress CL(0x0008)"},
{0x1589, 0x0009, 0xFFFF, 0xFFFF, "Leutron Vision PicPortExpress CL Stereo(0x0009)"},
}; /* pci_vid_1589[] */

static pci_id_t const pci_vid_158A[] = {
{0x158A, 0xFFFF, 0xFFFF, 0xFFFF, "Digalog Systems Inc(0x158A)"},
}; /* pci_vid_158A[] */

static pci_id_t const pci_vid_158B[] = {
{0x158B, 0xFFFF, 0xFFFF, 0xFFFF, "Allied Data Technologies(0x158B)"},
}; /* pci_vid_158B[] */

static pci_id_t const pci_vid_158C[] = {
{0x158C, 0xFFFF, 0xFFFF, 0xFFFF, "Hitachi Semiconductor & Devices Sales Co Ltd(0x158C)"},
}; /* pci_vid_158C[] */

static pci_id_t const pci_vid_158D[] = {
{0x158D, 0xFFFF, 0xFFFF, 0xFFFF, "Point Multimedia Systems(0x158D)"},
}; /* pci_vid_158D[] */

static pci_id_t const pci_vid_158E[] = {
{0x158E, 0xFFFF, 0xFFFF, 0xFFFF, "Lara Technology Inc(0x158E)"},
}; /* pci_vid_158E[] */

static pci_id_t const pci_vid_158F[] = {
{0x158F, 0xFFFF, 0xFFFF, 0xFFFF, "Ditect Coop(0x158F)"},
}; /* pci_vid_158F[] */

static pci_id_t const pci_vid_1590[] = {
{0x1590, 0xFFFF, 0xFFFF, 0xFFFF, "Hewlett Packard Enterprise(0x1590)"},
{0x1590, 0x0001, 0xFFFF, 0xFFFF, "Eagle Cluster Manager(0x0001)"},
{0x1590, 0x0002, 0xFFFF, 0xFFFF, "Osprey Cluster Manager(0x0002)"},
{0x1590, 0x0003, 0xFFFF, 0xFFFF, "Harrier Cluster Manager(0x0003)"},
{0x1590, 0x0371, 0xFFFF, 0xFFFF, "Cassini 2 [Slingshot 400Gb](0x0371)"},
{0x1590, 0x0372, 0xFFFF, 0xFFFF, "Cassini 2 [Slingshot 400Gb] SR-IOV VF(0x0372)"},
{0x1590, 0xA01D, 0xFFFF, 0xFFFF, "FC044X Fibre Channel HBA(0xA01D)"},
}; /* pci_vid_1590[] */

static pci_id_t const pci_vid_1591[] = {
{0x1591, 0xFFFF, 0xFFFF, 0xFFFF, "ARN(0x1591)"},
}; /* pci_vid_1591[] */

static pci_id_t const pci_vid_1592[] = {
{0x1592, 0xFFFF, 0xFFFF, 0xFFFF, "Syba Tech Ltd(0x1592)"},
{0x1592, 0x0781, 0xFFFF, 0xFFFF, "Multi-IO Card(0x0781)"},
{0x1592, 0x0782, 0xFFFF, 0xFFFF, "Parallel Port Card 2xEPP(0x0782)"},
{0x1592, 0x0783, 0xFFFF, 0xFFFF, "Multi-IO Card(0x0783)"},
{0x1592, 0x0785, 0xFFFF, 0xFFFF, "Multi-IO Card(0x0785)"},
{0x1592, 0x0786, 0xFFFF, 0xFFFF, "Multi-IO Card(0x0786)"},
{0x1592, 0x0787, 0xFFFF, 0xFFFF, "Multi-IO Card(0x0787)"},
{0x1592, 0x0788, 0xFFFF, 0xFFFF, "Multi-IO Card(0x0788)"},
{0x1592, 0x078A, 0xFFFF, 0xFFFF, "Multi-IO Card(0x078A)"},
}; /* pci_vid_1592[] */

static pci_id_t const pci_vid_1593[] = {
{0x1593, 0xFFFF, 0xFFFF, 0xFFFF, "Bops Inc(0x1593)"},
}; /* pci_vid_1593[] */

static pci_id_t const pci_vid_1594[] = {
{0x1594, 0xFFFF, 0xFFFF, 0xFFFF, "Netgame Ltd(0x1594)"},
}; /* pci_vid_1594[] */

static pci_id_t const pci_vid_1595[] = {
{0x1595, 0xFFFF, 0xFFFF, 0xFFFF, "Diva Systems Corp(0x1595)"},
}; /* pci_vid_1595[] */

static pci_id_t const pci_vid_1596[] = {
{0x1596, 0xFFFF, 0xFFFF, 0xFFFF, "Folsom Research Inc(0x1596)"},
}; /* pci_vid_1596[] */

static pci_id_t const pci_vid_1597[] = {
{0x1597, 0xFFFF, 0xFFFF, 0xFFFF, "Memec Design Services(0x1597)"},
}; /* pci_vid_1597[] */

static pci_id_t const pci_vid_1598[] = {
{0x1598, 0xFFFF, 0xFFFF, 0xFFFF, "Granite Microsystems(0x1598)"},
}; /* pci_vid_1598[] */

static pci_id_t const pci_vid_1599[] = {
{0x1599, 0xFFFF, 0xFFFF, 0xFFFF, "Delta Electronics Inc(0x1599)"},
}; /* pci_vid_1599[] */

static pci_id_t const pci_vid_159A[] = {
{0x159A, 0xFFFF, 0xFFFF, 0xFFFF, "General Instrument(0x159A)"},
}; /* pci_vid_159A[] */

static pci_id_t const pci_vid_159B[] = {
{0x159B, 0xFFFF, 0xFFFF, 0xFFFF, "Faraday Technology Corp(0x159B)"},
{0x159B, 0x4321, 0xFFFF, 0xFFFF, "StorLink SL3516 (Gemini) Host Bridge(0x4321)"},
}; /* pci_vid_159B[] */

static pci_id_t const pci_vid_159C[] = {
{0x159C, 0xFFFF, 0xFFFF, 0xFFFF, "Stratus Computer Systems(0x159C)"},
}; /* pci_vid_159C[] */

static pci_id_t const pci_vid_159D[] = {
{0x159D, 0xFFFF, 0xFFFF, 0xFFFF, "Ningbo Harrison Electronics Co Ltd(0x159D)"},
}; /* pci_vid_159D[] */

static pci_id_t const pci_vid_159E[] = {
{0x159E, 0xFFFF, 0xFFFF, 0xFFFF, "A-Max Technology Co Ltd(0x159E)"},
}; /* pci_vid_159E[] */

static pci_id_t const pci_vid_159F[] = {
{0x159F, 0xFFFF, 0xFFFF, 0xFFFF, "Galea Network Security(0x159F)"},
}; /* pci_vid_159F[] */

static pci_id_t const pci_vid_15A0[] = {
{0x15A0, 0xFFFF, 0xFFFF, 0xFFFF, "Compumaster SRL(0x15A0)"},
}; /* pci_vid_15A0[] */

static pci_id_t const pci_vid_15A1[] = {
{0x15A1, 0xFFFF, 0xFFFF, 0xFFFF, "Geocast Network Systems(0x15A1)"},
}; /* pci_vid_15A1[] */

static pci_id_t const pci_vid_15A2[] = {
{0x15A2, 0xFFFF, 0xFFFF, 0xFFFF, "Catalyst Enterprises Inc(0x15A2)"},
{0x15A2, 0x0001, 0xFFFF, 0xFFFF, "TA700 PCI Bus Analyzer/Exerciser(0x0001)"},
}; /* pci_vid_15A2[] */

static pci_id_t const pci_vid_15A3[] = {
{0x15A3, 0xFFFF, 0xFFFF, 0xFFFF, "Italtel(0x15A3)"},
}; /* pci_vid_15A3[] */

static pci_id_t const pci_vid_15A4[] = {
{0x15A4, 0xFFFF, 0xFFFF, 0xFFFF, "X-Net OY(0x15A4)"},
}; /* pci_vid_15A4[] */

static pci_id_t const pci_vid_15A5[] = {
{0x15A5, 0xFFFF, 0xFFFF, 0xFFFF, "Toyota Macs Inc(0x15A5)"},
}; /* pci_vid_15A5[] */

static pci_id_t const pci_vid_15A6[] = {
{0x15A6, 0xFFFF, 0xFFFF, 0xFFFF, "Sunlight Ultrasound Technologies Ltd(0x15A6)"},
}; /* pci_vid_15A6[] */

static pci_id_t const pci_vid_15A7[] = {
{0x15A7, 0xFFFF, 0xFFFF, 0xFFFF, "SSE Telecom Inc(0x15A7)"},
}; /* pci_vid_15A7[] */

static pci_id_t const pci_vid_15A8[] = {
{0x15A8, 0xFFFF, 0xFFFF, 0xFFFF, "Shanghai Communications Technologies Center(0x15A8)"},
}; /* pci_vid_15A8[] */

static pci_id_t const pci_vid_15AA[] = {
{0x15AA, 0xFFFF, 0xFFFF, 0xFFFF, "Moreton Bay(0x15AA)"},
}; /* pci_vid_15AA[] */

static pci_id_t const pci_vid_15AB[] = {
{0x15AB, 0xFFFF, 0xFFFF, 0xFFFF, "Bluesteel Networks Inc(0x15AB)"},
}; /* pci_vid_15AB[] */

static pci_id_t const pci_vid_15AC[] = {
{0x15AC, 0xFFFF, 0xFFFF, 0xFFFF, "North Atlantic Instruments(0x15AC)"},
{0x15AC, 0x6893, 0xFFFF, 0xFFFF, "3U OpenVPX Multi-function I/O Board [Model 68C3](0x6893)"},
}; /* pci_vid_15AC[] */

static pci_id_t const pci_vid_15AD[] = {
{0x15AD, 0xFFFF, 0xFFFF, 0xFFFF, "VMware(0x15AD)"},
{0x15AD, 0x0405, 0xFFFF, 0xFFFF, "SVGA II Adapter(0x0405)"},
{0x15AD, 0x0710, 0xFFFF, 0xFFFF, "SVGA Adapter(0x0710)"},
{0x15AD, 0x0720, 0xFFFF, 0xFFFF, "VMXNET Ethernet Controller(0x0720)"},
{0x15AD, 0x0740, 0xFFFF, 0xFFFF, "Virtual Machine Communication Interface(0x0740)"},
{0x15AD, 0x0770, 0xFFFF, 0xFFFF, "USB2 EHCI Controller(0x0770)"},
{0x15AD, 0x0774, 0xFFFF, 0xFFFF, "USB1.1 UHCI Controller(0x0774)"},
{0x15AD, 0x0778, 0xFFFF, 0xFFFF, "USB3 xHCI 0.96 Controller(0x0778)"},
{0x15AD, 0x0779, 0xFFFF, 0xFFFF, "USB3 xHCI 1.0 Controller(0x0779)"},
{0x15AD, 0x0790, 0xFFFF, 0xFFFF, "PCI bridge(0x0790)"},
{0x15AD, 0x07A0, 0xFFFF, 0xFFFF, "PCI Express Root Port(0x07A0)"},
{0x15AD, 0x07B0, 0xFFFF, 0xFFFF, "VMXNET3 Ethernet Controller(0x07B0)"},
{0x15AD, 0x07C0, 0xFFFF, 0xFFFF, "PVSCSI SCSI Controller(0x07C0)"},
{0x15AD, 0x07E0, 0xFFFF, 0xFFFF, "SATA AHCI controller(0x07E0)"},
{0x15AD, 0x07F0, 0xFFFF, 0xFFFF, "NVMe SSD Controller(0x07F0)"},
{0x15AD, 0x0801, 0xFFFF, 0xFFFF, "Virtual Machine Interface(0x0801)"},
{0x15AD, 0x0801, 0x15AD, 0x0800, "Hypervisor ROM Interface(0x15AD-0x0800)"},
{0x15AD, 0x0820, 0xFFFF, 0xFFFF, "Paravirtual RDMA controller(0x0820)"},
{0x15AD, 0x1977, 0xFFFF, 0xFFFF, "HD Audio Controller(0x1977)"},
}; /* pci_vid_15AD[] */

static pci_id_t const pci_vid_15AE[] = {
{0x15AE, 0xFFFF, 0xFFFF, 0xFFFF, "Amersham Pharmacia Biotech(0x15AE)"},
}; /* pci_vid_15AE[] */

static pci_id_t const pci_vid_15B0[] = {
{0x15B0, 0xFFFF, 0xFFFF, 0xFFFF, "Zoltrix International Ltd(0x15B0)"},
}; /* pci_vid_15B0[] */

static pci_id_t const pci_vid_15B1[] = {
{0x15B1, 0xFFFF, 0xFFFF, 0xFFFF, "Source Technology Inc(0x15B1)"},
}; /* pci_vid_15B1[] */

static pci_id_t const pci_vid_15B2[] = {
{0x15B2, 0xFFFF, 0xFFFF, 0xFFFF, "Mosaid Technologies Inc(0x15B2)"},
}; /* pci_vid_15B2[] */

static pci_id_t const pci_vid_15B3[] = {
{0x15B3, 0xFFFF, 0xFFFF, 0xFFFF, "Mellanox Technologies(0x15B3)"},
{0x15B3, 0x0191, 0xFFFF, 0xFFFF, "MT25408 [ConnectX IB Flash Recovery](0x0191)"},
{0x15B3, 0x01F6, 0xFFFF, 0xFFFF, "MT27500 Family [ConnectX-3 Flash Recovery](0x01F6)"},
{0x15B3, 0x01F8, 0xFFFF, 0xFFFF, "MT27520 Family [ConnectX-3 Pro Flash Recovery](0x01F8)"},
{0x15B3, 0x01FF, 0xFFFF, 0xFFFF, "MT27600 Family [Connect-IB Flash Recovery](0x01FF)"},
{0x15B3, 0x0209, 0xFFFF, 0xFFFF, "MT27700 Family [ConnectX-4 Flash Recovery](0x0209)"},
{0x15B3, 0x020B, 0xFFFF, 0xFFFF, "MT27710 Family [ConnectX-4 Lx Flash Recovery](0x020B)"},
{0x15B3, 0x020D, 0xFFFF, 0xFFFF, "MT28800 Family [ConnectX-5 Flash Recovery](0x020D)"},
{0x15B3, 0x020F, 0xFFFF, 0xFFFF, "MT28908A0 Family [ConnectX-6 Flash Recovery](0x020F)"},
{0x15B3, 0x0210, 0xFFFF, 0xFFFF, "MT28908A0 Family [ConnectX-6 Secure Flash Recovery](0x0210)"},
{0x15B3, 0x0211, 0xFFFF, 0xFFFF, "MT416842 Family [BlueField SoC Flash Recovery](0x0211)"},
{0x15B3, 0x0212, 0xFFFF, 0xFFFF, "MT2892 Family [ConnectX-6 Dx Flash Recovery](0x0212)"},
{0x15B3, 0x0213, 0xFFFF, 0xFFFF, "MT2892 Family [ConnectX-6 Dx Secure Flash Recovery](0x0213)"},
{0x15B3, 0x0214, 0xFFFF, 0xFFFF, "MT42822 Family [BlueField-2 SoC Flash Recovery](0x0214)"},
{0x15B3, 0x0215, 0xFFFF, 0xFFFF, "MT42822 Family [BlueField-2 Secure Flash Recovery](0x0215)"},
{0x15B3, 0x0216, 0xFFFF, 0xFFFF, "MT2894 Family [ConnectX-6 Lx Flash Recovery](0x0216)"},
{0x15B3, 0x0217, 0xFFFF, 0xFFFF, "MT2894 Family [ConnectX-6 Lx Secure Flash Recovery](0x0217)"},
{0x15B3, 0x0218, 0xFFFF, 0xFFFF, "MT2910 Family [ConnectX-7 Flash Recovery](0x0218)"},
{0x15B3, 0x0219, 0xFFFF, 0xFFFF, "MT2910 Family [ConnectX-7 Secure Flash Recovery](0x0219)"},
{0x15B3, 0x021A, 0xFFFF, 0xFFFF, "MT43162 Family [BlueField-3 Lx SoC Flash Recovery](0x021A)"},
{0x15B3, 0x021B, 0xFFFF, 0xFFFF, "MT43162 Family [BlueField-3 Lx Secure Flash Recovery](0x021B)"},
{0x15B3, 0x021C, 0xFFFF, 0xFFFF, "MT43244 Family [BlueField-3 SoC Flash Recovery](0x021C)"},
{0x15B3, 0x021D, 0xFFFF, 0xFFFF, "MT43244 Family [BlueField-3 Secure Flash Recovery](0x021D)"},
{0x15B3, 0x021E, 0xFFFF, 0xFFFF, "CX8 Family [ConnectX-8 Flash Recovery](0x021E)"},
{0x15B3, 0x021F, 0xFFFF, 0xFFFF, "CX8 Family [ConnectX-8 Secure Flash Recovery](0x021F)"},
{0x15B3, 0x0220, 0xFFFF, 0xFFFF, "BF4 Family Flash Recovery [BlueField-4 SoC Flash Recovery](0x0220)"},
{0x15B3, 0x0221, 0xFFFF, 0xFFFF, "BF4 Family Secure Flash Recovery [BlueField-4 Secure Flash Recovery](0x0221)"},
{0x15B3, 0x0222, 0xFFFF, 0xFFFF, "CX8 PCIe Switch Family [ConnectX-8 PCIe Switch Flash Recovery](0x0222)"},
{0x15B3, 0x0223, 0xFFFF, 0xFFFF, "CX8 PCIe Switch Family [ConnectX-8 PCIe Switch Secure Flash Recovery-RMA](0x0223)"},
{0x15B3, 0x0224, 0xFFFF, 0xFFFF, "CX9 Family [ConnectX-9 Flash Recovery](0x0224)"},
{0x15B3, 0x0225, 0xFFFF, 0xFFFF, "CX9 Family [ConnectX-9 Secure Flash Recovery-RMA](0x0225)"},
{0x15B3, 0x024E, 0xFFFF, 0xFFFF, "MT53100 [Spectrum-2, Flash recovery mode](0x024E)"},
{0x15B3, 0x024F, 0xFFFF, 0xFFFF, "MT53100 [Spectrum-2, Secure Flash recovery mode](0x024F)"},
{0x15B3, 0x0250, 0xFFFF, 0xFFFF, "Spectrum-3, Flash recovery mode(0x0250)"},
{0x15B3, 0x0251, 0xFFFF, 0xFFFF, "Spectrum-3, Secure Flash recovery mode(0x0251)"},
{0x15B3, 0x0252, 0xFFFF, 0xFFFF, "Amos chiplet(0x0252)"},
{0x15B3, 0x0253, 0xFFFF, 0xFFFF, "Amos GearBox Manager(0x0253)"},
{0x15B3, 0x0254, 0xFFFF, 0xFFFF, "Spectrum-4, Flash recovery mode(0x0254)"},
{0x15B3, 0x0255, 0xFFFF, 0xFFFF, "Spectrum-4 RMA(0x0255)"},
{0x15B3, 0x0256, 0xFFFF, 0xFFFF, "Abir GearBox(0x0256)"},
{0x15B3, 0x0257, 0xFFFF, 0xFFFF, "Quantum-2 in Flash Recovery Mode(0x0257)"},
{0x15B3, 0x0258, 0xFFFF, 0xFFFF, "Quantum-2 RMA(0x0258)"},
{0x15B3, 0x0259, 0xFFFF, 0xFFFF, "Abir Chiplet(0x0259)"},
{0x15B3, 0x025B, 0xFFFF, 0xFFFF, "Quantum-3 in Flash Recovery Mode(0x025B)"},
{0x15B3, 0x025C, 0xFFFF, 0xFFFF, "Quantum-3 RMA(0x025C)"},
{0x15B3, 0x025D, 0xFFFF, 0xFFFF, "Quantum-3CPO in Flash Recovery Mode(0x025D)"},
{0x15B3, 0x025E, 0xFFFF, 0xFFFF, "Quantum-3CPO RMA(0x025E)"},
{0x15B3, 0x0262, 0xFFFF, 0xFFFF, "MT27710 [ConnectX-4 Lx Programmable] EN(0x0262)"},
{0x15B3, 0x0263, 0xFFFF, 0xFFFF, "MT27710 [ConnectX-4 Lx Programmable Virtual Function] EN(0x0263)"},
{0x15B3, 0x0264, 0xFFFF, 0xFFFF, "Innova-2 Flex Burn image(0x0264)"},
{0x15B3, 0x0270, 0xFFFF, 0xFFFF, "Spectrum-5 in Flash Recovery Mode(0x0270)"},
{0x15B3, 0x0271, 0xFFFF, 0xFFFF, "Spectrum-4L, RMA(0x0271)"},
{0x15B3, 0x0274, 0xFFFF, 0xFFFF, "Spectrum-6 in Flash Recovery Mode(0x0274)"},
{0x15B3, 0x0275, 0xFFFF, 0xFFFF, "Spectrum-4C RMA(0x0275)"},
{0x15B3, 0x0277, 0xFFFF, 0xFFFF, "Spectrum-4TOR RMA(0x0277)"},
{0x15B3, 0x0278, 0xFFFF, 0xFFFF, "Quantum-4 in Flash Recovery Mode(0x0278)"},
{0x15B3, 0x0279, 0xFFFF, 0xFFFF, "Quantum-4 RMA(0x0279)"},
{0x15B3, 0x0281, 0xFFFF, 0xFFFF, "NPS-600 Flash Recovery(0x0281)"},
{0x15B3, 0x0282, 0xFFFF, 0xFFFF, "ArcusE Flash recovery(0x0282)"},
{0x15B3, 0x0283, 0xFFFF, 0xFFFF, "ArcusE RMA(0x0283)"},
{0x15B3, 0x0284, 0xFFFF, 0xFFFF, "Sagitta(0x0284)"},
{0x15B3, 0x0285, 0xFFFF, 0xFFFF, "Sagitta RMA(0x0285)"},
{0x15B3, 0x0286, 0xFFFF, 0xFFFF, "LibraE Flash Recovery(0x0286)"},
{0x15B3, 0x0287, 0xFFFF, 0xFFFF, "LibraE RMA(0x0287)"},
{0x15B3, 0x0288, 0xFFFF, 0xFFFF, "Arcus2(0x0288)"},
{0x15B3, 0x0289, 0xFFFF, 0xFFFF, "Arcus2 RMA(0x0289)"},
{0x15B3, 0x1002, 0xFFFF, 0xFFFF, "MT25400 Family [ConnectX-2 Virtual Function](0x1002)"},
{0x15B3, 0x1003, 0xFFFF, 0xFFFF, "MT27500 Family [ConnectX-3](0x1003)"},
{0x15B3, 0x1003, 0x1014, 0x04B5, "PCIe3 40GbE RoCE Converged Host Bus Adapter for Power(0x1014-0x04B5)"},
{0x15B3, 0x1003, 0x103C, 0x1777, "InfiniBand FDR/EN 10/40Gb Dual Port 544FLR-QSFP Adapter (Rev Cx)(0x103C-0x1777)"},
{0x15B3, 0x1003, 0x103C, 0x17C9, "Infiniband QDR/Ethernet 10Gb 2-port 544i Adapter(0x103C-0x17C9)"},
{0x15B3, 0x1003, 0x103C, 0x18CE, "InfiniBand QDR/EN 10Gb Dual Port 544M Adapter(0x103C-0x18CE)"},
{0x15B3, 0x1003, 0x103C, 0x18CF, "InfiniBand FDR/EN 10/40Gb Dual Port 544M Adapter(0x103C-0x18CF)"},
{0x15B3, 0x1003, 0x103C, 0x18D6, "InfiniBand FDR/EN 10/40Gb Dual Port 544QSFP Adapter(0x103C-0x18D6)"},
{0x15B3, 0x1003, 0x15B3, 0x0025, "ConnectX-3 IB QDR Dual Port Mezzanine Card(0x15B3-0x0025)"},
{0x15B3, 0x1003, 0x15B3, 0x0026, "ConnectX-3 IB FDR Dual Port Mezzanine Card(0x15B3-0x0026)"},
{0x15B3, 0x1003, 0x15B3, 0x0028, "ConnectX-3 VPI Dual QSFP+ Port QDR Infiniband 40Gb/s or 10Gb Ethernet(0x15B3-0x0028)"},
{0x15B3, 0x1003, 0x15B3, 0x0055, "ConnectX-3 10 GbE Single Port SFP+ Adapter(0x15B3-0x0055)"},
{0x15B3, 0x1003, 0x15B3, 0x0059, "ConnectX-3 VPI IB FDR/40 GbE Single Port QSFP+ Mezzanine Card(0x15B3-0x0059)"},
{0x15B3, 0x1003, 0x15B3, 0x0064, "ConnectX-3 EN 10/40 GbE Single Port QSFP+ Adapter (MCX313A-BCBT)(0x15B3-0x0064)"},
{0x15B3, 0x1003, 0x15B3, 0x0065, "ConnectX-3 VPI IB FDR/40 GbE Dual Port QSFP+ Adapter(0x15B3-0x0065)"},
{0x15B3, 0x1003, 0x15B3, 0x0066, "ConnectX-3 IB FDR10 Dual Port Mezzanine Card(0x15B3-0x0066)"},
{0x15B3, 0x1003, 0x15B3, 0x0067, "ConnectX-3 VPI IB FDR/40 GbE Single Port QSFP+ Adapter(0x15B3-0x0067)"},
{0x15B3, 0x1003, 0x15B3, 0x0071, "ConnectX-3 VPI IB FDR/40 GbE Dual Port QSFP+ Mezzanine Card(0x15B3-0x0071)"},
{0x15B3, 0x1003, 0x15B3, 0x0078, "ConnectX-3 10 GbE Dual Port KR Mezzanine Card(0x15B3-0x0078)"},
{0x15B3, 0x1003, 0x15B3, 0x0079, "ConnectX-3 40 GbE Dual Port QSFP+ Adapter(0x15B3-0x0079)"},
{0x15B3, 0x1003, 0x15B3, 0x0080, "ConnectX-3 10 GbE Dual Port SFP+ Adapter(0x15B3-0x0080)"},
{0x15B3, 0x1004, 0xFFFF, 0xFFFF, "MT27500/MT27520 Family [ConnectX-3/ConnectX-3 Pro Virtual Function](0x1004)"},
{0x15B3, 0x1005, 0xFFFF, 0xFFFF, "MT27510 Family(0x1005)"},
{0x15B3, 0x1006, 0xFFFF, 0xFFFF, "MT27511 Family(0x1006)"},
{0x15B3, 0x1007, 0xFFFF, 0xFFFF, "MT27520 Family [ConnectX-3 Pro](0x1007)"},
{0x15B3, 0x1007, 0x1014, 0x04EB, "2-Port 10GbE NIC and RoCE SR PCIe3(0x1014-0x04EB)"},
{0x15B3, 0x1007, 0x103C, 0x22F3, "InfiniBand FDR/Ethernet 10Gb/40Gb 2-port 544+QSFP Adapter(0x103C-0x22F3)"},
{0x15B3, 0x1007, 0x103C, 0x22F4, "InfiniBand FDR/Ethernet 10Gb/40Gb 2-port 544+FLR-QSFP Adapter(0x103C-0x22F4)"},
{0x15B3, 0x1007, 0x103C, 0x801F, "Ethernet 10G 2-port 546SFP+ Adapter(0x103C-0x801F)"},
{0x15B3, 0x1007, 0x117C, 0x0090, "FastFrame NQ41(0x117C-0x0090)"},
{0x15B3, 0x1007, 0x117C, 0x0091, "FastFrame NQ42(0x117C-0x0091)"},
{0x15B3, 0x1007, 0x117C, 0x0092, "FastFrame NQ11(0x117C-0x0092)"},
{0x15B3, 0x1007, 0x117C, 0x0093, "FastFrame NQ12(0x117C-0x0093)"},
{0x15B3, 0x1007, 0x15B3, 0x0006, "Mellanox Technologies ConnectX-3 Pro Stand-up dual-port 40GbE MCX314A-BCCT(0x15B3-0x0006)"},
{0x15B3, 0x1007, 0x15B3, 0x000C, "ConnectX-3 Pro 10 GbE Dual Port SFP+ Adapter revision A1(0x15B3-0x000C)"},
{0x15B3, 0x1007, 0x15B3, 0x0078, "ConnectX-3 Pro 10 GbE Dual Port KR Mezzanine Card(0x15B3-0x0078)"},
{0x15B3, 0x1007, 0x15B3, 0x0079, "ConnectX-3 Pro 40 GbE Dual Port QSFP+ Adapter(0x15B3-0x0079)"},
{0x15B3, 0x1007, 0x15B3, 0x0080, "ConnectX-3 Pro 10 GbE Dual Port SFP+ Adapter(0x15B3-0x0080)"},
{0x15B3, 0x1007, 0x193D, 0x1002, "520F-B(0x193D-0x1002)"},
{0x15B3, 0x1009, 0xFFFF, 0xFFFF, "MT27530 Family(0x1009)"},
{0x15B3, 0x100A, 0xFFFF, 0xFFFF, "MT27531 Family(0x100A)"},
{0x15B3, 0x100B, 0xFFFF, 0xFFFF, "MT27540 Family(0x100B)"},
{0x15B3, 0x100C, 0xFFFF, 0xFFFF, "MT27541 Family(0x100C)"},
{0x15B3, 0x100D, 0xFFFF, 0xFFFF, "MT27550 Family(0x100D)"},
{0x15B3, 0x100E, 0xFFFF, 0xFFFF, "MT27551 Family(0x100E)"},
{0x15B3, 0x100F, 0xFFFF, 0xFFFF, "MT27560 Family(0x100F)"},
{0x15B3, 0x1010, 0xFFFF, 0xFFFF, "MT27561 Family(0x1010)"},
{0x15B3, 0x1011, 0xFFFF, 0xFFFF, "MT27600 [Connect-IB](0x1011)"},
{0x15B3, 0x1012, 0xFFFF, 0xFFFF, "MT27600 Family [Connect-IB Virtual Function](0x1012)"},
{0x15B3, 0x1013, 0xFFFF, 0xFFFF, "MT27700 Family [ConnectX-4](0x1013)"},
{0x15B3, 0x1013, 0x1014, 0x04F7, "PCIe3 2-port 100 GbE (NIC and RoCE) QSFP28 Adapter for Power(0x1014-0x04F7)"},
{0x15B3, 0x1013, 0x15B3, 0x0003, "Mellanox Technologies ConnectX-4 Stand-up single-port 40GbE MCX413A-BCAT(0x15B3-0x0003)"},
{0x15B3, 0x1013, 0x15B3, 0x0005, "Mellanox Technologies ConnectX-4 Stand-up single-port 40GbE MCX415A-BCAT(0x15B3-0x0005)"},
{0x15B3, 0x1013, 0x15B3, 0x0006, "MCX416A-BCAT, ConnectX-4 EN, 40/56GbE 2P, PCIe3.0 x16(0x15B3-0x0006)"},
{0x15B3, 0x1013, 0x15B3, 0x0007, "ConnectX-4 EN network interface card, 40/56GbE dual-port QSFP28, PCIe3.0 x16, tall bracket(0x15B3-0x0007)"},
{0x15B3, 0x1013, 0x15B3, 0x0008, "ConnectX-4 Stand-up dual-port 100GbE MCX416A-CCAT(0x15B3-0x0008)"},
{0x15B3, 0x1013, 0x15B3, 0x0033, "ConnectX-4 VPI IB EDR/100 GbE Single Port QSFP28 Adapter(0x15B3-0x0033)"},
{0x15B3, 0x1013, 0x15B3, 0x0034, "ConnectX-4 VPI IB EDR/100 GbE Dual Port QSFP28 Adapter(0x15B3-0x0034)"},
{0x15B3, 0x1013, 0x15B3, 0x0050, "ConnectX-4 100 GbE Dual Port QSFP28 Adapter(0x15B3-0x0050)"},
{0x15B3, 0x1014, 0xFFFF, 0xFFFF, "MT27700 Family [ConnectX-4 Virtual Function](0x1014)"},
{0x15B3, 0x1015, 0xFFFF, 0xFFFF, "MT27710 Family [ConnectX-4 Lx](0x1015)"},
{0x15B3, 0x1015, 0x15B3, 0x0001, "ConnectX-4 Lx EN network interface card, 25GbE single-port SFP28, PCIe3.0 x8, tall bracket, ROHS R6(0x15B3-0x0001)"},
{0x15B3, 0x1015, 0x15B3, 0x0003, "Stand-up ConnectX-4 Lx EN, 25GbE dual-port SFP28, PCIe3.0 x8, MCX4121A-ACAT(0x15B3-0x0003)"},
{0x15B3, 0x1015, 0x15B3, 0x0004, "ConnectX-4 Lx Stand-up dual-port 10GbE MCX4121A-XCAT(0x15B3-0x0004)"},
{0x15B3, 0x1015, 0x15B3, 0x0005, "Mellanox Technologies ConnectX-4 Lx Stand-up single-port 40GbE MCX4131A-BCAT(0x15B3-0x0005)"},
{0x15B3, 0x1015, 0x15B3, 0x0020, "MCX4411A-ACQN, ConnectX-4 Lx EN OCP, 1x25Gb(0x15B3-0x0020)"},
{0x15B3, 0x1015, 0x15B3, 0x0021, "MCX4421A-ACQN ConnectX-4 Lx EN OCP,2x25G(0x15B3-0x0021)"},
{0x15B3, 0x1015, 0x15B3, 0x0025, "ConnectX-4 Lx 25 GbE Dual Port SFP28 rNDC(0x15B3-0x0025)"},
{0x15B3, 0x1015, 0x193D, 0x100A, "620F-B(0x193D-0x100A)"},
{0x15B3, 0x1015, 0x193D, 0x1023, "NIC-ETH540F-LP-2P(0x193D-0x1023)"},
{0x15B3, 0x1015, 0x193D, 0x1031, "NIC-ETH640i-Mb-2x25G(0x193D-0x1031)"},
{0x15B3, 0x1015, 0x193D, 0x1083, "NIC-ETH640F-3S-2P(0x193D-0x1083)"},
{0x15B3, 0x1015, 0x193D, 0x1084, "NIC-ETH540F-3S-2P(0x193D-0x1084)"},
{0x15B3, 0x1016, 0xFFFF, 0xFFFF, "MT27710 Family [ConnectX-4 Lx Virtual Function](0x1016)"},
{0x15B3, 0x1017, 0xFFFF, 0xFFFF, "MT27800 Family [ConnectX-5](0x1017)"},
{0x15B3, 0x1017, 0x15B3, 0x0006, "ConnectX-5 EN network interface card, 100GbE single-port QSFP28, PCIe3.0 x16, tall bracket; MCX515A-CCAT(0x15B3-0x0006)"},
{0x15B3, 0x1017, 0x15B3, 0x0007, "Mellanox ConnectX-5 MCX516A-CCAT(0x15B3-0x0007)"},
{0x15B3, 0x1017, 0x15B3, 0x0020, "ConnectX-5 EN network interface card, 10/25GbE dual-port SFP28, PCIe3.0 x8, tall bracket ; MCX512A-ACAT(0x15B3-0x0020)"},
{0x15B3, 0x1017, 0x15B3, 0x0068, "ConnectX-5 EN network interface card for OCP2.0, Type 1, with host management, 25GbE dual-port SFP28, PCIe3.0 x8, no bracket Halogen free ; MCX542B-ACAN(0x15B3-0x0068)"},
{0x15B3, 0x1017, 0x193D, 0x1051, "NIC-IB1040i-Mb-2P(0x193D-0x1051)"},
{0x15B3, 0x1018, 0xFFFF, 0xFFFF, "MT27800 Family [ConnectX-5 Virtual Function](0x1018)"},
{0x15B3, 0x1019, 0xFFFF, 0xFFFF, "MT28800 Family [ConnectX-5 Ex](0x1019)"},
{0x15B3, 0x1019, 0x1014, 0x0617, "PCIe4 x16 2-Port EDR IB-only ConnectX-5 CAPI Capable Adapter [IBM EC64](0x1014-0x0617)"},
{0x15B3, 0x1019, 0x1014, 0x0635, "PCIe4 2-port 100 GbE RoCE x16 adapter [IBM EC66](0x1014-0x0635)"},
{0x15B3, 0x1019, 0x15B3, 0x0008, "ConnectX-5 Ex EN network interface card, 100GbE dual-port QSFP28, PCIe4.0 x16, tall bracket; MCX516A-CDAT(0x15B3-0x0008)"},
{0x15B3, 0x1019, 0x15B3, 0x0125, "Tencent ConnectX-5 EN Ex network interface card for OCP 3.0, with host management, 50GbE Dual-port QSFP28, PCIe4.0 x16, Thumbscrew (pull-tab) bracket(0x15B3-0x0125)"},
{0x15B3, 0x1019, 0x15B3, 0x0126, "PCIe4 x16 2-port EDR 100GbE ConnectX-5 CAPI Capable adapter [IBM AJP1](0x15B3-0x0126)"},
{0x15B3, 0x101A, 0xFFFF, 0xFFFF, "MT28800 Family [ConnectX-5 Ex Virtual Function](0x101A)"},
{0x15B3, 0x101B, 0xFFFF, 0xFFFF, "MT28908 Family [ConnectX-6](0x101B)"},
{0x15B3, 0x101C, 0xFFFF, 0xFFFF, "MT28908 Family [ConnectX-6 Virtual Function](0x101C)"},
{0x15B3, 0x101D, 0xFFFF, 0xFFFF, "MT2892 Family [ConnectX-6 Dx](0x101D)"},
{0x15B3, 0x101E, 0xFFFF, 0xFFFF, "ConnectX Family mlx5Gen Virtual Function(0x101E)"},
{0x15B3, 0x101F, 0xFFFF, 0xFFFF, "MT2894 Family [ConnectX-6 Lx](0x101F)"},
{0x15B3, 0x101F, 0x193D, 0x1035, "NIC-ETH641F-LP-2P SFP28 2x25GbE PCIe Network Adapter(0x193D-0x1035)"},
{0x15B3, 0x1020, 0xFFFF, 0xFFFF, "MT28860(0x1020)"},
{0x15B3, 0x1021, 0xFFFF, 0xFFFF, "MT2910 Family [ConnectX-7](0x1021)"},
{0x15B3, 0x1023, 0xFFFF, 0xFFFF, "CX8 Family [ConnectX-8](0x1023)"},
{0x15B3, 0x1024, 0xFFFF, 0xFFFF, "CX8 PCIe Switch Family [ConnectX-8 PCIe Switch](0x1024)"},
{0x15B3, 0x1025, 0xFFFF, 0xFFFF, "CX9 Family [ConnectX-9](0x1025)"},
{0x15B3, 0x1974, 0xFFFF, 0xFFFF, "MT28800 Family [ConnectX-5 PCIe Bridge](0x1974)"},
{0x15B3, 0x1975, 0xFFFF, 0xFFFF, "MT416842 Family [BlueField SoC PCIe Bridge](0x1975)"},
{0x15B3, 0x1976, 0xFFFF, 0xFFFF, "MT28908 Family [ConnectX-6 PCIe Bridge](0x1976)"},
{0x15B3, 0x1977, 0xFFFF, 0xFFFF, "MT2892 Family [ConnectX-6 Dx PCIe Bridge](0x1977)"},
{0x15B3, 0x1978, 0xFFFF, 0xFFFF, "MT42822 Family [BlueField-2 SoC PCIe Bridge](0x1978)"},
{0x15B3, 0x1979, 0xFFFF, 0xFFFF, "MT2910 Family [ConnectX-7 PCIe Bridge](0x1979)"},
{0x15B3, 0x197A, 0xFFFF, 0xFFFF, "MT43162 Family [BlueField-3 Lx SoC PCIe Bridge](0x197A)"},
{0x15B3, 0x197B, 0xFFFF, 0xFFFF, "MT43244 Family [BlueField-3 SoC PCIe Bridge](0x197B)"},
{0x15B3, 0x197C, 0xFFFF, 0xFFFF, "ConnectX/BlueField Family mlx5Gen PCIe Bridge [PCIe Bridge](0x197C)"},
{0x15B3, 0x197D, 0xFFFF, 0xFFFF, "CX8 Family [ConnectX-8 PCIe Bridge](0x197D)"},
{0x15B3, 0x197E, 0xFFFF, 0xFFFF, "CX9 Family [ConnectX-9 PCIe Bridge](0x197E)"},
{0x15B3, 0x2020, 0xFFFF, 0xFFFF, "MT2892 Family [ConnectX-6 Dx Emulated PCIe Bridge](0x2020)"},
{0x15B3, 0x2021, 0xFFFF, 0xFFFF, "MT42822 Family [BlueField-2 SoC Emulated PCIe Bridge](0x2021)"},
{0x15B3, 0x2023, 0xFFFF, 0xFFFF, "MT2910 Family [ConnectX-7 Emulated PCIe Bridge](0x2023)"},
{0x15B3, 0x2024, 0xFFFF, 0xFFFF, "MT43244 Family [BlueField-3 SoC Emulated PCIe Bridge](0x2024)"},
{0x15B3, 0x2025, 0xFFFF, 0xFFFF, "ConnectX/BlueField Family mlx5Gen Emulated PCIe Bridge [Emulated PCIe Bridge](0x2025)"},
{0x15B3, 0x2100, 0xFFFF, 0xFFFF, "CX8 Family [CX8 Data Direct Interface](0x2100)"},
{0x15B3, 0x4117, 0xFFFF, 0xFFFF, "MT27712A0-FDCF-AE(0x4117)"},
{0x15B3, 0x4117, 0x1BD4, 0x0039, "SN10XMP2P25(0x1BD4-0x0039)"},
{0x15B3, 0x4117, 0x1BD4, 0x003A, "25G SFP28 SP EO251FM9 Adapter(0x1BD4-0x003A)"},
{0x15B3, 0x4117, 0x1BD4, 0x004D, "SN10XMP2P25,YZPC-01191-101(0x1BD4-0x004D)"},
{0x15B3, 0x5274, 0xFFFF, 0xFFFF, "MT21108 InfiniBridge(0x5274)"},
{0x15B3, 0x5A44, 0xFFFF, 0xFFFF, "MT23108 InfiniHost(0x5A44)"},
{0x15B3, 0x5A45, 0xFFFF, 0xFFFF, "MT23108 [Infinihost HCA Flash Recovery](0x5A45)"},
{0x15B3, 0x5A46, 0xFFFF, 0xFFFF, "MT23108 PCI Bridge(0x5A46)"},
{0x15B3, 0x5E8C, 0xFFFF, 0xFFFF, "MT24204 [InfiniHost III Lx HCA](0x5E8C)"},
{0x15B3, 0x5E8D, 0xFFFF, 0xFFFF, "MT25204 [InfiniHost III Lx HCA Flash Recovery](0x5E8D)"},
{0x15B3, 0x6001, 0xFFFF, 0xFFFF, "NVMe SNAP Controller(0x6001)"},
{0x15B3, 0x6274, 0xFFFF, 0xFFFF, "MT25204 [InfiniHost III Lx HCA](0x6274)"},
{0x15B3, 0x6278, 0xFFFF, 0xFFFF, "MT25208 InfiniHost III Ex (Tavor compatibility mode)(0x6278)"},
{0x15B3, 0x6279, 0xFFFF, 0xFFFF, "MT25208 [InfiniHost III Ex HCA Flash Recovery](0x6279)"},
{0x15B3, 0x6282, 0xFFFF, 0xFFFF, "MT25208 [InfiniHost III Ex](0x6282)"},
{0x15B3, 0x6340, 0xFFFF, 0xFFFF, "MT25408A0-FCC-SI ConnectX, Dual Port 10Gb/s InfiniBand / 10GigE Adapter IC with PCIe 2.0 x8 2.5GT/s Interface(0x6340)"},
{0x15B3, 0x634A, 0xFFFF, 0xFFFF, "MT25408A0-FCC-DI ConnectX, Dual Port 20Gb/s InfiniBand / 10GigE Adapter IC with PCIe 2.0 x8 2.5GT/s Interface(0x634A)"},
{0x15B3, 0x634A, 0x1014, 0x1014, "4X InfiniBand DDR Expansion Card (CFFh) for IBM BladeCenter(0x1014-0x1014)"},
{0x15B3, 0x6368, 0xFFFF, 0xFFFF, "MT25448 [ConnectX EN 10GigE, PCIe 2.0 2.5GT/s](0x6368)"},
{0x15B3, 0x6372, 0xFFFF, 0xFFFF, "MT25458 ConnectX EN 10GBASE-T PCIe 2.5 GT/s(0x6372)"},
{0x15B3, 0x6732, 0xFFFF, 0xFFFF, "MT25408A0-FCC-GI ConnectX, Dual Port 20Gb/s InfiniBand / 10GigE Adapter IC with PCIe 2.0 x8 5.0GT/s Interface(0x6732)"},
{0x15B3, 0x673C, 0xFFFF, 0xFFFF, "MT25408A0-FCC-QI ConnectX, Dual Port 40Gb/s InfiniBand / 10GigE Adapter IC with PCIe 2.0 x8 5.0GT/s Interface(0x673C)"},
{0x15B3, 0x673C, 0x1014, 0x0415, "PCIe2 2-port 4X InfiniBand QDR Adapter for Power(0x1014-0x0415)"},
{0x15B3, 0x673C, 0x1014, 0x0487, "GX++ 1-port 4X IB QDR Adapter for Power 795(0x1014-0x0487)"},
{0x15B3, 0x673C, 0x103C, 0x1782, "4X QDR InfiniBand Mezzanine HCA for c-Class BladeSystem(0x103C-0x1782)"},
{0x15B3, 0x673C, 0x15B3, 0x0021, "HP InfiniBand 4X QDR CX-2 PCI-e G2 Dual Port HCA(0x15B3-0x0021)"},
{0x15B3, 0x6746, 0xFFFF, 0xFFFF, "MT26438 [ConnectX VPI PCIe 2.0 5GT/s - IB QDR / 10GigE Virtualization+](0x6746)"},
{0x15B3, 0x6746, 0x103C, 0x1781, "NC543i 1-port 4x QDR IB/Flex-10 10Gb Adapter(0x103C-0x1781)"},
{0x15B3, 0x6746, 0x103C, 0x3349, "NC543i 2-port 4xQDR IB/10Gb Adapter(0x103C-0x3349)"},
{0x15B3, 0x6750, 0xFFFF, 0xFFFF, "MT26448 [ConnectX EN 10GigE, PCIe 2.0 5GT/s](0x6750)"},
{0x15B3, 0x6750, 0x1014, 0x0416, "PCIe2 2-Port 10GbE RoCE SFP+ Adapter(0x1014-0x0416)"},
{0x15B3, 0x6750, 0x1014, 0x0461, "PCIe2 2-Port 10GbE RoCE SR Adapter(0x1014-0x0461)"},
{0x15B3, 0x6750, 0x15B3, 0x0018, "HP 10 GbE PCI-e G2 Dual-Port NIC (rev C1)(0x15B3-0x0018)"},
{0x15B3, 0x6750, 0x15B3, 0x6572, "IBM Flex System EN4132 2-port 10Gb RoCE Adapter(0x15B3-0x6572)"},
{0x15B3, 0x675A, 0xFFFF, 0xFFFF, "MT26458 ConnectX EN 10GBASE-T PCIe Gen2 5.0 GT/s(0x675A)"},
{0x15B3, 0x6764, 0xFFFF, 0xFFFF, "MT26468 [ConnectX EN 10GigE, PCIe 2.0 5GT/s Virtualization+](0x6764)"},
{0x15B3, 0x6764, 0x103C, 0x3313, "NC542m Dual Port Flex-10 10GbE BLc Adapter(0x103C-0x3313)"},
{0x15B3, 0x676E, 0xFFFF, 0xFFFF, "MT26478 [ConnectX EN 40GigE, PCIe 2.0 5GT/s](0x676E)"},
{0x15B3, 0x6778, 0xFFFF, 0xFFFF, "MT26488 [ConnectX VPI PCIe 2.0 5GT/s - IB DDR / 10GigE Virtualization+](0x6778)"},
{0x15B3, 0x7101, 0xFFFF, 0xFFFF, "NPS-400 configuration and management interface(0x7101)"},
{0x15B3, 0x7102, 0xFFFF, 0xFFFF, "NPS-400 network interface PF(0x7102)"},
{0x15B3, 0x7103, 0xFFFF, 0xFFFF, "NPS-400 network interface VF(0x7103)"},
{0x15B3, 0x7121, 0xFFFF, 0xFFFF, "NPS-600 configuration and management interface(0x7121)"},
{0x15B3, 0x7122, 0xFFFF, 0xFFFF, "NPS-600 network interface PF(0x7122)"},
{0x15B3, 0x7123, 0xFFFF, 0xFFFF, "NPS-600 network interface VF(0x7123)"},
{0x15B3, 0x8200, 0xFFFF, 0xFFFF, "Innova-2 Flex Shell Logic(0x8200)"},
{0x15B3, 0xA2D0, 0xFFFF, 0xFFFF, "MT416842 BlueField SoC Crypto enabled(0xA2D0)"},
{0x15B3, 0xA2D1, 0xFFFF, 0xFFFF, "MT416842 BlueField SoC Crypto disabled(0xA2D1)"},
{0x15B3, 0xA2D2, 0xFFFF, 0xFFFF, "MT416842 BlueField integrated ConnectX-5 network controller(0xA2D2)"},
{0x15B3, 0xA2D3, 0xFFFF, 0xFFFF, "MT416842 BlueField multicore SoC family VF(0xA2D3)"},
{0x15B3, 0xA2D4, 0xFFFF, 0xFFFF, "MT42822 BlueField-2 SoC Crypto enabled(0xA2D4)"},
{0x15B3, 0xA2D5, 0xFFFF, 0xFFFF, "MT42822 BlueField-2 SoC Crypto disabled(0xA2D5)"},
{0x15B3, 0xA2D6, 0xFFFF, 0xFFFF, "MT42822 BlueField-2 integrated ConnectX-6 Dx network controller(0xA2D6)"},
{0x15B3, 0xA2D7, 0xFFFF, 0xFFFF, "MT43162 BlueField-3 Lx SoC Crypto enabled(0xA2D7)"},
{0x15B3, 0xA2D8, 0xFFFF, 0xFFFF, "MT43162 BlueField-3 Lx SoC Crypto disabled(0xA2D8)"},
{0x15B3, 0xA2D9, 0xFFFF, 0xFFFF, "MT43162 BlueField-3 Lx integrated ConnectX-7 network controller(0xA2D9)"},
{0x15B3, 0xA2DA, 0xFFFF, 0xFFFF, "MT43244 BlueField-3 SoC Crypto enabled(0xA2DA)"},
{0x15B3, 0xA2DB, 0xFFFF, 0xFFFF, "MT43244 BlueField-3 SoC Crypto disabled(0xA2DB)"},
{0x15B3, 0xA2DC, 0xFFFF, 0xFFFF, "MT43244 BlueField-3 integrated ConnectX-7 network controller(0xA2DC)"},
{0x15B3, 0xA2DD, 0xFFFF, 0xFFFF, "BF4 Family Crypto enabled [BlueField-4 SoC Crypto enabled](0xA2DD)"},
{0x15B3, 0xA2DE, 0xFFFF, 0xFFFF, "BF4 Family Crypto disabled [BlueField-4 SoC Crypto disabled](0xA2DE)"},
{0x15B3, 0xA2DF, 0xFFFF, 0xFFFF, "BF4 Family integrated network controller [BlueField-4 integrated network controller](0xA2DF)"},
{0x15B3, 0xB200, 0xFFFF, 0xFFFF, "ArcusE(0xB200)"},
{0x15B3, 0xB201, 0xFFFF, 0xFFFF, "LibraE(0xB201)"},
{0x15B3, 0xB202, 0xFFFF, 0xFFFF, "Arcus2(0xB202)"},
{0x15B3, 0xC2D1, 0xFFFF, 0xFFFF, "BlueField DPU Family Auxiliary Communication Channel [BlueField Family](0xC2D1)"},
{0x15B3, 0xC2D2, 0xFFFF, 0xFFFF, "MT416842 BlueField SoC management interfac(0xC2D2)"},
{0x15B3, 0xC2D3, 0xFFFF, 0xFFFF, "MT42822 BlueField-2 SoC Management Interface(0xC2D3)"},
{0x15B3, 0xC2D4, 0xFFFF, 0xFFFF, "MT43162 BlueField-3 Lx SoC Management Interface(0xC2D4)"},
{0x15B3, 0xC2D5, 0xFFFF, 0xFFFF, "MT43244 BlueField-3 SoC Management Interface(0xC2D5)"},
{0x15B3, 0xC2D6, 0xFFFF, 0xFFFF, "BF4 Family Management Interface [BlueField-4 SoC Management Interface](0xC2D6)"},
{0x15B3, 0xC738, 0xFFFF, 0xFFFF, "MT51136(0xC738)"},
{0x15B3, 0xC739, 0xFFFF, 0xFFFF, "MT51136 GW(0xC739)"},
{0x15B3, 0xC838, 0xFFFF, 0xFFFF, "MT52236(0xC838)"},
{0x15B3, 0xC839, 0xFFFF, 0xFFFF, "MT52236 router(0xC839)"},
{0x15B3, 0xCAF1, 0xFFFF, 0xFFFF, "ConnectX-4 CAPI Function(0xCAF1)"},
{0x15B3, 0xCB84, 0xFFFF, 0xFFFF, "MT52100(0xCB84)"},
{0x15B3, 0xCF08, 0xFFFF, 0xFFFF, "Switch-IB2(0xCF08)"},
{0x15B3, 0xCF6C, 0xFFFF, 0xFFFF, "MT53100 [Spectrum-2](0xCF6C)"},
{0x15B3, 0xCF70, 0xFFFF, 0xFFFF, "Spectrum-3(0xCF70)"},
{0x15B3, 0xCF80, 0xFFFF, 0xFFFF, "Spectrum-4(0xCF80)"},
{0x15B3, 0xCF82, 0xFFFF, 0xFFFF, "Spectrum-4L(0xCF82)"},
{0x15B3, 0xCF84, 0xFFFF, 0xFFFF, "Spectrum-4C(0xCF84)"},
{0x15B3, 0xD2F0, 0xFFFF, 0xFFFF, "Quantum HDR (200Gbps) switch(0xD2F0)"},
{0x15B3, 0xD2F2, 0xFFFF, 0xFFFF, "Quantum-2 NDR (400Gbps) switch(0xD2F2)"},
{0x15B3, 0xD2F4, 0xFFFF, 0xFFFF, "Quantum-3(0xD2F4)"},
{0x15B3, 0xD2F6, 0xFFFF, 0xFFFF, "Quantum-3CPO(0xD2F6)"},
{0x15B3, 0xD2F8, 0xFFFF, 0xFFFF, "Quantum-4(0xD2F8)"},
}; /* pci_vid_15B3[] */

static pci_id_t const pci_vid_15B4[] = {
{0x15B4, 0xFFFF, 0xFFFF, 0xFFFF, "CCI/TRIAD(0x15B4)"},
}; /* pci_vid_15B4[] */

static pci_id_t const pci_vid_15B5[] = {
{0x15B5, 0xFFFF, 0xFFFF, 0xFFFF, "Cimetrics Inc(0x15B5)"},
}; /* pci_vid_15B5[] */

static pci_id_t const pci_vid_15B6[] = {
{0x15B6, 0xFFFF, 0xFFFF, 0xFFFF, "Texas Memory Systems Inc(0x15B6)"},
{0x15B6, 0x0001, 0xFFFF, 0xFFFF, "XP15 DSP Accelerator(0x0001)"},
{0x15B6, 0x0002, 0xFFFF, 0xFFFF, "XP30 DSP Accelerator(0x0002)"},
{0x15B6, 0x0003, 0xFFFF, 0xFFFF, "XP00 Data Acquisition Device(0x0003)"},
{0x15B6, 0x0004, 0xFFFF, 0xFFFF, "XP35 DSP Accelerator(0x0004)"},
{0x15B6, 0x0007, 0xFFFF, 0xFFFF, "XP100 DSP Accelerator [XP100-T0](0x0007)"},
{0x15B6, 0x0008, 0xFFFF, 0xFFFF, "XP100 DSP Accelerator [XP100-T1](0x0008)"},
{0x15B6, 0x0009, 0xFFFF, 0xFFFF, "XP100 DSP Accelerator [XP100-E0](0x0009)"},
{0x15B6, 0x000A, 0xFFFF, 0xFFFF, "XP100 DSP Accelerator [XP100-E1](0x000A)"},
{0x15B6, 0x000E, 0xFFFF, 0xFFFF, "XP100 DSP Accelerator [XP100-0](0x000E)"},
{0x15B6, 0x000F, 0xFFFF, 0xFFFF, "XP100 DSP Accelerator [XP100-1](0x000F)"},
{0x15B6, 0x0010, 0xFFFF, 0xFFFF, "XP100 DSP Accelerator [XP100-P0](0x0010)"},
{0x15B6, 0x0011, 0xFFFF, 0xFFFF, "XP100 DSP Accelerator [XP100-P1](0x0011)"},
{0x15B6, 0x0012, 0xFFFF, 0xFFFF, "XP100 DSP Accelerator [XP100-P2](0x0012)"},
{0x15B6, 0x0013, 0xFFFF, 0xFFFF, "XP100 DSP Accelerator [XP100-P3](0x0013)"},
{0x15B6, 0x0014, 0xFFFF, 0xFFFF, "RamSan Flash SSD(0x0014)"},
{0x15B6, 0x0015, 0xFFFF, 0xFFFF, "ZBox(0x0015)"},
}; /* pci_vid_15B6[] */

static pci_id_t const pci_vid_15B7[] = {
{0x15B7, 0xFFFF, 0xFFFF, 0xFFFF, "Sandisk Corp(0x15B7)"},
{0x15B7, 0x2001, 0xFFFF, 0xFFFF, "Skyhawk Series NVME SSD(0x2001)"},
{0x15B7, 0x5001, 0xFFFF, 0xFFFF, "WD Black NVMe SSD(0x5001)"},
{0x15B7, 0x5002, 0xFFFF, 0xFFFF, "SanDisk Extreme Pro / WD Black 2018/SN750/PC SN720 NVMe SSD(0x5002)"},
{0x15B7, 0x5003, 0xFFFF, 0xFFFF, "WD Blue SN500 / PC SN520 x2 M.2 2280 NVMe SSD(0x5003)"},
{0x15B7, 0x5004, 0xFFFF, 0xFFFF, "PC SN520 x2 M.2 2230 NVMe SSD(0x5004)"},
{0x15B7, 0x5005, 0xFFFF, 0xFFFF, "PC SN520 x2 M.2 2242 NVMe SSD(0x5005)"},
{0x15B7, 0x5006, 0xFFFF, 0xFFFF, "SanDisk Extreme Pro / WD Black SN750 / PC SN730 / Red SN700 NVMe SSD(0x5006)"},
{0x15B7, 0x5007, 0xFFFF, 0xFFFF, "IX SN530 NVMe SSD (DRAM-less)(0x5007)"},
{0x15B7, 0x5008, 0xFFFF, 0xFFFF, "PC SN530 NVMe SSD (DRAM-less)(0x5008)"},
{0x15B7, 0x5009, 0xFFFF, 0xFFFF, "SanDisk Ultra 3D / WD Blue SN550 NVMe SSD(0x5009)"},
{0x15B7, 0x5009, 0x15B7, 0x5009, "WD Blue SN550 NVMe SSD(0x15B7-0x5009)"},
{0x15B7, 0x500B, 0xFFFF, 0xFFFF, "PC SN530 NVMe SSD(0x500B)"},
{0x15B7, 0x500B, 0x1414, 0x500B, "Xbox Series X(0x1414-0x500B)"},
{0x15B7, 0x500D, 0xFFFF, 0xFFFF, "WD Ultrastar DC SN340 NVMe SSD(0x500D)"},
{0x15B7, 0x5011, 0xFFFF, 0xFFFF, "WD PC SN810 / Black SN850 NVMe SSD(0x5011)"},
{0x15B7, 0x5014, 0xFFFF, 0xFFFF, "WD PC SN540 / Green SN350 NVMe SSD 1 TB (DRAM-less)(0x5014)"},
{0x15B7, 0x5015, 0xFFFF, 0xFFFF, "PC SN740 NVMe SSD (DRAM-less)(0x5015)"},
{0x15B7, 0x5016, 0xFFFF, 0xFFFF, "WD PC SN740 NVMe SSD 512GB (DRAM-less)(0x5016)"},
{0x15B7, 0x5017, 0xFFFF, 0xFFFF, "WD Black SN770 / PC SN740 256GB / PC SN560 (DRAM-less) NVMe SSD(0x5017)"},
{0x15B7, 0x5019, 0xFFFF, 0xFFFF, "WD Green SN350 240GB (DRAM-less) / SN560E NVMe SSD(0x5019)"},
{0x15B7, 0x501A, 0xFFFF, 0xFFFF, "SanDisk Ultra 3D / WD Blue SN570 NVMe SSD (DRAM-less)(0x501A)"},
{0x15B7, 0x501D, 0xFFFF, 0xFFFF, "WD Blue SN550 NVMe SSD 2TB (DRAM-less)(0x501D)"},
{0x15B7, 0x501E, 0xFFFF, 0xFFFF, "PC SN735 / WD_BLACK SN750 SE NVMe SSD (DRAM-less)(0x501E)"},
{0x15B7, 0x501F, 0xFFFF, 0xFFFF, "WD PC SN735 NVMe SSD 512GB (DRAM-less)(0x501F)"},
{0x15B7, 0x5025, 0xFFFF, 0xFFFF, "WD Blue SN570 NVMe SSD 2TB(0x5025)"},
{0x15B7, 0x5026, 0xFFFF, 0xFFFF, "WD PC SN735 NVMe SSD 1TB (DRAM-less)(0x5026)"},
{0x15B7, 0x5028, 0xFFFF, 0xFFFF, "WD CH SN560 NVMe SSD(0x5028)"},
{0x15B7, 0x5030, 0xFFFF, 0xFFFF, "WD Black SN850X NVMe SSD(0x5030)"},
{0x15B7, 0x5034, 0xFFFF, 0xFFFF, "WD PC SN5000S M.2 2230 NVMe SSD (DRAM-less)(0x5034)"},
{0x15B7, 0x5036, 0xFFFF, 0xFFFF, "WD PC SN5000S M.2 2280 NVMe SSD (DRAM-less)(0x5036)"},
{0x15B7, 0x5041, 0xFFFF, 0xFFFF, "WD Blue SN580 NVMe SSD (DRAM-less)(0x5041)"},
{0x15B7, 0x5042, 0xFFFF, 0xFFFF, "WD Black SN770M NVMe SSD (DRAM-less)(0x5042)"},
}; /* pci_vid_15B7[] */

static pci_id_t const pci_vid_15B8[] = {
{0x15B8, 0xFFFF, 0xFFFF, 0xFFFF, "ADDI-DATA GmbH(0x15B8)"},
{0x15B8, 0x1001, 0xFFFF, 0xFFFF, "APCI1516 SP controller (16 digi outputs)(0x1001)"},
{0x15B8, 0x1003, 0xFFFF, 0xFFFF, "APCI1032 SP controller (32 digi inputs w/ opto coupler)(0x1003)"},
{0x15B8, 0x1004, 0xFFFF, 0xFFFF, "APCI2032 SP controller (32 digi outputs)(0x1004)"},
{0x15B8, 0x1005, 0xFFFF, 0xFFFF, "APCI2200 SP controller (8/16 digi outputs (relay))(0x1005)"},
{0x15B8, 0x1006, 0xFFFF, 0xFFFF, "APCI1564 SP controller (32 digi ins, 32 digi outs)(0x1006)"},
{0x15B8, 0x100A, 0xFFFF, 0xFFFF, "APCI1696 SP controller (96 TTL I/Os)(0x100A)"},
{0x15B8, 0x3001, 0xFFFF, 0xFFFF, "APCI3501 SP controller (analog output board)(0x3001)"},
{0x15B8, 0x300F, 0xFFFF, 0xFFFF, "APCI3600 Noise and vibration measurement board(0x300F)"},
{0x15B8, 0x7001, 0xFFFF, 0xFFFF, "APCI7420 2-port Serial Controller(0x7001)"},
{0x15B8, 0x7002, 0xFFFF, 0xFFFF, "APCI7300 Serial Controller(0x7002)"},
}; /* pci_vid_15B8[] */

static pci_id_t const pci_vid_15B9[] = {
{0x15B9, 0xFFFF, 0xFFFF, 0xFFFF, "Maestro Digital Communications(0x15B9)"},
}; /* pci_vid_15B9[] */

static pci_id_t const pci_vid_15BA[] = {
{0x15BA, 0xFFFF, 0xFFFF, 0xFFFF, "Impacct Technology Corp(0x15BA)"},
}; /* pci_vid_15BA[] */

static pci_id_t const pci_vid_15BB[] = {
{0x15BB, 0xFFFF, 0xFFFF, 0xFFFF, "Portwell Inc(0x15BB)"},
}; /* pci_vid_15BB[] */

static pci_id_t const pci_vid_15BC[] = {
{0x15BC, 0xFFFF, 0xFFFF, 0xFFFF, "Agilent Technologies(0x15BC)"},
{0x15BC, 0x0100, 0xFFFF, 0xFFFF, "HPFC-5600 Tachyon DX2+ FC(0x0100)"},
{0x15BC, 0x0103, 0xFFFF, 0xFFFF, "QX4 PCI Express quad 4-gigabit Fibre Channel controller(0x0103)"},
{0x15BC, 0x0105, 0xFFFF, 0xFFFF, "Celerity FC-44XS/FC-42XS/FC-41XS/FC-44ES/FC-42ES/FC-41ES(0x0105)"},
{0x15BC, 0x0105, 0x117C, 0x0022, "Celerity FC-42XS Fibre Channel Adapter(0x117C-0x0022)"},
{0x15BC, 0x0105, 0x117C, 0x0025, "Celerity FC-44ES Fibre Channel Adapter(0x117C-0x0025)"},
{0x15BC, 0x0105, 0x117C, 0x0026, "Celerity FC-42ES Fibre Channel Adapter(0x117C-0x0026)"},
{0x15BC, 0x0500, 0xFFFF, 0xFFFF, "Infiniium Memory Controller Interface(0x0500)"},
{0x15BC, 0x0501, 0xFFFF, 0xFFFF, "Infiniium Acquisition System Interface(0x0501)"},
{0x15BC, 0x0507, 0xFFFF, 0xFFFF, "Infiniium Acquisition System (80000 series)(0x0507)"},
{0x15BC, 0x0508, 0xFFFF, 0xFFFF, "Infiniium Acquisition Support(0x0508)"},
{0x15BC, 0x0B01, 0xFFFF, 0xFFFF, "82350B PCI GPIB(0x0B01)"},
{0x15BC, 0x1100, 0xFFFF, 0xFFFF, "E8001-66442 PCI Express CIC(0x1100)"},
{0x15BC, 0x1218, 0xFFFF, 0xFFFF, "82351A PCI Express GPIB(0x1218)"},
{0x15BC, 0x12D6, 0xFFFF, 0xFFFF, "82350C PCI GPIB(0x12D6)"},
{0x15BC, 0x12D7, 0xFFFF, 0xFFFF, "82351B PCI Express GPIB(0x12D7)"},
{0x15BC, 0x2922, 0xFFFF, 0xFFFF, "64 Bit, 133MHz PCI-X Exerciser & Protocol Checker(0x2922)"},
{0x15BC, 0x2928, 0xFFFF, 0xFFFF, "64 Bit, 66MHz PCI Exerciser & Analyzer(0x2928)"},
{0x15BC, 0x2929, 0xFFFF, 0xFFFF, "64 Bit, 133MHz PCI-X Analyzer & Exerciser(0x2929)"},
}; /* pci_vid_15BC[] */

static pci_id_t const pci_vid_15BD[] = {
{0x15BD, 0xFFFF, 0xFFFF, 0xFFFF, "DFI Inc(0x15BD)"},
}; /* pci_vid_15BD[] */

static pci_id_t const pci_vid_15BE[] = {
{0x15BE, 0xFFFF, 0xFFFF, 0xFFFF, "Sola Electronics(0x15BE)"},
}; /* pci_vid_15BE[] */

static pci_id_t const pci_vid_15BF[] = {
{0x15BF, 0xFFFF, 0xFFFF, 0xFFFF, "High Tech Computer Corp (HTC)(0x15BF)"},
}; /* pci_vid_15BF[] */

static pci_id_t const pci_vid_15C0[] = {
{0x15C0, 0xFFFF, 0xFFFF, 0xFFFF, "BVM Ltd(0x15C0)"},
}; /* pci_vid_15C0[] */

static pci_id_t const pci_vid_15C1[] = {
{0x15C1, 0xFFFF, 0xFFFF, 0xFFFF, "Quantel(0x15C1)"},
}; /* pci_vid_15C1[] */

static pci_id_t const pci_vid_15C2[] = {
{0x15C2, 0xFFFF, 0xFFFF, 0xFFFF, "Newer Technology Inc(0x15C2)"},
}; /* pci_vid_15C2[] */

static pci_id_t const pci_vid_15C3[] = {
{0x15C3, 0xFFFF, 0xFFFF, 0xFFFF, "Taiwan Mycomp Co Ltd(0x15C3)"},
}; /* pci_vid_15C3[] */

static pci_id_t const pci_vid_15C4[] = {
{0x15C4, 0xFFFF, 0xFFFF, 0xFFFF, "EVSX Inc(0x15C4)"},
}; /* pci_vid_15C4[] */

static pci_id_t const pci_vid_15C5[] = {
{0x15C5, 0xFFFF, 0xFFFF, 0xFFFF, "Procomp Informatics Ltd(0x15C5)"},
{0x15C5, 0x8010, 0xFFFF, 0xFFFF, "1394b - 1394 Firewire 3-Port Host Adapter Card(0x8010)"},
}; /* pci_vid_15C5[] */

static pci_id_t const pci_vid_15C6[] = {
{0x15C6, 0xFFFF, 0xFFFF, 0xFFFF, "Technical University of Budapest(0x15C6)"},
}; /* pci_vid_15C6[] */

static pci_id_t const pci_vid_15C7[] = {
{0x15C7, 0xFFFF, 0xFFFF, 0xFFFF, "Tateyama System Laboratory Co Ltd(0x15C7)"},
{0x15C7, 0x0349, 0xFFFF, 0xFFFF, "Tateyama C-PCI PLC/NC card Rev.01A(0x0349)"},
}; /* pci_vid_15C7[] */

static pci_id_t const pci_vid_15C8[] = {
{0x15C8, 0xFFFF, 0xFFFF, 0xFFFF, "Penta Media Co Ltd(0x15C8)"},
}; /* pci_vid_15C8[] */

static pci_id_t const pci_vid_15C9[] = {
{0x15C9, 0xFFFF, 0xFFFF, 0xFFFF, "Serome Technology Inc(0x15C9)"},
}; /* pci_vid_15C9[] */

static pci_id_t const pci_vid_15CA[] = {
{0x15CA, 0xFFFF, 0xFFFF, 0xFFFF, "Bitboys OY(0x15CA)"},
}; /* pci_vid_15CA[] */

static pci_id_t const pci_vid_15CB[] = {
{0x15CB, 0xFFFF, 0xFFFF, 0xFFFF, "AG Electronics Ltd(0x15CB)"},
}; /* pci_vid_15CB[] */

static pci_id_t const pci_vid_15CC[] = {
{0x15CC, 0xFFFF, 0xFFFF, 0xFFFF, "Hotrail Inc(0x15CC)"},
}; /* pci_vid_15CC[] */

static pci_id_t const pci_vid_15CD[] = {
{0x15CD, 0xFFFF, 0xFFFF, 0xFFFF, "Dreamtech Co Ltd(0x15CD)"},
}; /* pci_vid_15CD[] */

static pci_id_t const pci_vid_15CE[] = {
{0x15CE, 0xFFFF, 0xFFFF, 0xFFFF, "Genrad Inc(0x15CE)"},
}; /* pci_vid_15CE[] */

static pci_id_t const pci_vid_15CF[] = {
{0x15CF, 0xFFFF, 0xFFFF, 0xFFFF, "Hilscher Gesellschaft für Systemautomation mbH(0x15CF)"},
{0x15CF, 0x0000, 0xFFFF, 0xFFFF, "CIFX PCI/PCIe(0x0000)"},
}; /* pci_vid_15CF[] */

static pci_id_t const pci_vid_15D1[] = {
{0x15D1, 0xFFFF, 0xFFFF, 0xFFFF, "Infineon Technologies AG(0x15D1)"},
}; /* pci_vid_15D1[] */

static pci_id_t const pci_vid_15D2[] = {
{0x15D2, 0xFFFF, 0xFFFF, 0xFFFF, "FIC (First International Computer Inc)(0x15D2)"},
}; /* pci_vid_15D2[] */

static pci_id_t const pci_vid_15D3[] = {
{0x15D3, 0xFFFF, 0xFFFF, 0xFFFF, "NDS Technologies Israel Ltd(0x15D3)"},
}; /* pci_vid_15D3[] */

static pci_id_t const pci_vid_15D4[] = {
{0x15D4, 0xFFFF, 0xFFFF, 0xFFFF, "Iwill Corp(0x15D4)"},
}; /* pci_vid_15D4[] */

static pci_id_t const pci_vid_15D5[] = {
{0x15D5, 0xFFFF, 0xFFFF, 0xFFFF, "Tatung Co(0x15D5)"},
}; /* pci_vid_15D5[] */

static pci_id_t const pci_vid_15D6[] = {
{0x15D6, 0xFFFF, 0xFFFF, 0xFFFF, "Entridia Corp(0x15D6)"},
}; /* pci_vid_15D6[] */

static pci_id_t const pci_vid_15D7[] = {
{0x15D7, 0xFFFF, 0xFFFF, 0xFFFF, "Rockwell-Collins Inc(0x15D7)"},
}; /* pci_vid_15D7[] */

static pci_id_t const pci_vid_15D8[] = {
{0x15D8, 0xFFFF, 0xFFFF, 0xFFFF, "Cybernetics Technology Co Ltd(0x15D8)"},
}; /* pci_vid_15D8[] */

static pci_id_t const pci_vid_15D9[] = {
{0x15D9, 0xFFFF, 0xFFFF, 0xFFFF, "Super Micro Computer Inc(0x15D9)"},
{0x15D9, 0x1B64, 0xFFFF, 0xFFFF, "SCC-B8SB80-B1(0x1B64)"},
{0x15D9, 0x1B9D, 0xFFFF, 0xFFFF, "Supermicro AOC-S3816L-L16IR(0x1B9D)"},
{0x15D9, 0x1C6E, 0xFFFF, 0xFFFF, "Supermicro AOC-SLG4-2H8M2(0x1C6E)"},
}; /* pci_vid_15D9[] */

static pci_id_t const pci_vid_15DA[] = {
{0x15DA, 0xFFFF, 0xFFFF, 0xFFFF, "Cyberfirm Inc(0x15DA)"},
}; /* pci_vid_15DA[] */

static pci_id_t const pci_vid_15DB[] = {
{0x15DB, 0xFFFF, 0xFFFF, 0xFFFF, "Applied Computing Systems Inc(0x15DB)"},
}; /* pci_vid_15DB[] */

static pci_id_t const pci_vid_15DC[] = {
{0x15DC, 0xFFFF, 0xFFFF, 0xFFFF, "Litronic Inc(0x15DC)"},
{0x15DC, 0x0001, 0xFFFF, 0xFFFF, "Argus 300 PCI Cryptography Module(0x0001)"},
}; /* pci_vid_15DC[] */

static pci_id_t const pci_vid_15DD[] = {
{0x15DD, 0xFFFF, 0xFFFF, 0xFFFF, "Sigmatel Inc(0x15DD)"},
}; /* pci_vid_15DD[] */

static pci_id_t const pci_vid_15DE[] = {
{0x15DE, 0xFFFF, 0xFFFF, 0xFFFF, "Malleable Technologies Inc(0x15DE)"},
}; /* pci_vid_15DE[] */

static pci_id_t const pci_vid_15DF[] = {
{0x15DF, 0xFFFF, 0xFFFF, 0xFFFF, "Infinilink Corp(0x15DF)"},
}; /* pci_vid_15DF[] */

static pci_id_t const pci_vid_15E0[] = {
{0x15E0, 0xFFFF, 0xFFFF, 0xFFFF, "Cacheflow Inc(0x15E0)"},
}; /* pci_vid_15E0[] */

static pci_id_t const pci_vid_15E1[] = {
{0x15E1, 0xFFFF, 0xFFFF, 0xFFFF, "Voice Technologies Group Inc(0x15E1)"},
}; /* pci_vid_15E1[] */

static pci_id_t const pci_vid_15E2[] = {
{0x15E2, 0xFFFF, 0xFFFF, 0xFFFF, "Quicknet Technologies Inc(0x15E2)"},
{0x15E2, 0x0500, 0xFFFF, 0xFFFF, "PhoneJack-PCI(0x0500)"},
}; /* pci_vid_15E2[] */

static pci_id_t const pci_vid_15E3[] = {
{0x15E3, 0xFFFF, 0xFFFF, 0xFFFF, "Networth Technologies Inc(0x15E3)"},
}; /* pci_vid_15E3[] */

static pci_id_t const pci_vid_15E4[] = {
{0x15E4, 0xFFFF, 0xFFFF, 0xFFFF, "VSN Systemen BV(0x15E4)"},
}; /* pci_vid_15E4[] */

static pci_id_t const pci_vid_15E5[] = {
{0x15E5, 0xFFFF, 0xFFFF, 0xFFFF, "Valley technologies Inc(0x15E5)"},
}; /* pci_vid_15E5[] */

static pci_id_t const pci_vid_15E6[] = {
{0x15E6, 0xFFFF, 0xFFFF, 0xFFFF, "Agere Inc(0x15E6)"},
}; /* pci_vid_15E6[] */

static pci_id_t const pci_vid_15E7[] = {
{0x15E7, 0xFFFF, 0xFFFF, 0xFFFF, "Get Engineering Corp(0x15E7)"},
}; /* pci_vid_15E7[] */

static pci_id_t const pci_vid_15E8[] = {
{0x15E8, 0xFFFF, 0xFFFF, 0xFFFF, "National Datacomm Corp(0x15E8)"},
{0x15E8, 0x0130, 0xFFFF, 0xFFFF, "Wireless PCI Card(0x0130)"},
{0x15E8, 0x0131, 0xFFFF, 0xFFFF, "NCP130A2 Wireless NIC(0x0131)"},
}; /* pci_vid_15E8[] */

static pci_id_t const pci_vid_15E9[] = {
{0x15E9, 0xFFFF, 0xFFFF, 0xFFFF, "Pacific Digital Corp(0x15E9)"},
{0x15E9, 0x1841, 0xFFFF, 0xFFFF, "ADMA-100 DiscStaQ ATA Controller(0x1841)"},
}; /* pci_vid_15E9[] */

static pci_id_t const pci_vid_15EA[] = {
{0x15EA, 0xFFFF, 0xFFFF, 0xFFFF, "Tokyo Denshi Sekei K.K.(0x15EA)"},
}; /* pci_vid_15EA[] */

static pci_id_t const pci_vid_15EB[] = {
{0x15EB, 0xFFFF, 0xFFFF, 0xFFFF, "DResearch Digital Media Systems GmbH(0x15EB)"},
}; /* pci_vid_15EB[] */

static pci_id_t const pci_vid_15EC[] = {
{0x15EC, 0xFFFF, 0xFFFF, 0xFFFF, "Beckhoff GmbH(0x15EC)"},
{0x15EC, 0x3101, 0xFFFF, 0xFFFF, "FC3101 Profibus DP 1 Channel PCI(0x3101)"},
{0x15EC, 0x5102, 0xFFFF, 0xFFFF, "FC5102(0x5102)"},
}; /* pci_vid_15EC[] */

static pci_id_t const pci_vid_15ED[] = {
{0x15ED, 0xFFFF, 0xFFFF, 0xFFFF, "Macrolink Inc(0x15ED)"},
}; /* pci_vid_15ED[] */

static pci_id_t const pci_vid_15EE[] = {
{0x15EE, 0xFFFF, 0xFFFF, 0xFFFF, "In Win Development Inc(0x15EE)"},
}; /* pci_vid_15EE[] */

static pci_id_t const pci_vid_15EF[] = {
{0x15EF, 0xFFFF, 0xFFFF, 0xFFFF, "Intelligent Paradigm Inc(0x15EF)"},
}; /* pci_vid_15EF[] */

static pci_id_t const pci_vid_15F0[] = {
{0x15F0, 0xFFFF, 0xFFFF, 0xFFFF, "B-Tree Systems Inc(0x15F0)"},
}; /* pci_vid_15F0[] */

static pci_id_t const pci_vid_15F1[] = {
{0x15F1, 0xFFFF, 0xFFFF, 0xFFFF, "Times N Systems Inc(0x15F1)"},
}; /* pci_vid_15F1[] */

static pci_id_t const pci_vid_15F2[] = {
{0x15F2, 0xFFFF, 0xFFFF, 0xFFFF, "Diagnostic Instruments Inc(0x15F2)"},
}; /* pci_vid_15F2[] */

static pci_id_t const pci_vid_15F3[] = {
{0x15F3, 0xFFFF, 0xFFFF, 0xFFFF, "Digitmedia Corp(0x15F3)"},
}; /* pci_vid_15F3[] */

static pci_id_t const pci_vid_15F4[] = {
{0x15F4, 0xFFFF, 0xFFFF, 0xFFFF, "Valuesoft(0x15F4)"},
}; /* pci_vid_15F4[] */

static pci_id_t const pci_vid_15F5[] = {
{0x15F5, 0xFFFF, 0xFFFF, 0xFFFF, "Power Micro Research(0x15F5)"},
}; /* pci_vid_15F5[] */

static pci_id_t const pci_vid_15F6[] = {
{0x15F6, 0xFFFF, 0xFFFF, 0xFFFF, "Extreme Packet Device Inc(0x15F6)"},
}; /* pci_vid_15F6[] */

static pci_id_t const pci_vid_15F7[] = {
{0x15F7, 0xFFFF, 0xFFFF, 0xFFFF, "Banctec(0x15F7)"},
}; /* pci_vid_15F7[] */

static pci_id_t const pci_vid_15F8[] = {
{0x15F8, 0xFFFF, 0xFFFF, 0xFFFF, "Koga Electronics Co(0x15F8)"},
}; /* pci_vid_15F8[] */

static pci_id_t const pci_vid_15F9[] = {
{0x15F9, 0xFFFF, 0xFFFF, 0xFFFF, "Zenith Electronics Corp(0x15F9)"},
}; /* pci_vid_15F9[] */

static pci_id_t const pci_vid_15FA[] = {
{0x15FA, 0xFFFF, 0xFFFF, 0xFFFF, "J.P. Axzam Corp(0x15FA)"},
}; /* pci_vid_15FA[] */

static pci_id_t const pci_vid_15FB[] = {
{0x15FB, 0xFFFF, 0xFFFF, 0xFFFF, "Zilog Inc(0x15FB)"},
}; /* pci_vid_15FB[] */

static pci_id_t const pci_vid_15FC[] = {
{0x15FC, 0xFFFF, 0xFFFF, 0xFFFF, "Techsan Electronics Co Ltd(0x15FC)"},
}; /* pci_vid_15FC[] */

static pci_id_t const pci_vid_15FD[] = {
{0x15FD, 0xFFFF, 0xFFFF, 0xFFFF, "N-CUBED.NET(0x15FD)"},
}; /* pci_vid_15FD[] */

static pci_id_t const pci_vid_15FE[] = {
{0x15FE, 0xFFFF, 0xFFFF, 0xFFFF, "Kinpo Electronics Inc(0x15FE)"},
}; /* pci_vid_15FE[] */

static pci_id_t const pci_vid_15FF[] = {
{0x15FF, 0xFFFF, 0xFFFF, 0xFFFF, "Fastpoint Technologies Inc(0x15FF)"},
}; /* pci_vid_15FF[] */

static pci_id_t const pci_vid_1600[] = {
{0x1600, 0xFFFF, 0xFFFF, 0xFFFF, "Northrop Grumman - Canada Ltd(0x1600)"},
}; /* pci_vid_1600[] */

static pci_id_t const pci_vid_1601[] = {
{0x1601, 0xFFFF, 0xFFFF, 0xFFFF, "Tenta Technology(0x1601)"},
}; /* pci_vid_1601[] */

static pci_id_t const pci_vid_1602[] = {
{0x1602, 0xFFFF, 0xFFFF, 0xFFFF, "Prosys-tec Inc(0x1602)"},
}; /* pci_vid_1602[] */

static pci_id_t const pci_vid_1603[] = {
{0x1603, 0xFFFF, 0xFFFF, 0xFFFF, "Nokia Wireless Communications(0x1603)"},
}; /* pci_vid_1603[] */

static pci_id_t const pci_vid_1604[] = {
{0x1604, 0xFFFF, 0xFFFF, 0xFFFF, "Central System Research Co Ltd(0x1604)"},
}; /* pci_vid_1604[] */

static pci_id_t const pci_vid_1605[] = {
{0x1605, 0xFFFF, 0xFFFF, 0xFFFF, "Pairgain Technologies(0x1605)"},
}; /* pci_vid_1605[] */

static pci_id_t const pci_vid_1606[] = {
{0x1606, 0xFFFF, 0xFFFF, 0xFFFF, "Europop AG(0x1606)"},
}; /* pci_vid_1606[] */

static pci_id_t const pci_vid_1607[] = {
{0x1607, 0xFFFF, 0xFFFF, 0xFFFF, "Lava Semiconductor Manufacturing Inc(0x1607)"},
}; /* pci_vid_1607[] */

static pci_id_t const pci_vid_1608[] = {
{0x1608, 0xFFFF, 0xFFFF, 0xFFFF, "Automated Wagering International(0x1608)"},
}; /* pci_vid_1608[] */

static pci_id_t const pci_vid_1609[] = {
{0x1609, 0xFFFF, 0xFFFF, 0xFFFF, "Scimetric Instruments Inc(0x1609)"},
}; /* pci_vid_1609[] */

static pci_id_t const pci_vid_1612[] = {
{0x1612, 0xFFFF, 0xFFFF, 0xFFFF, "Telesynergy Research Inc.(0x1612)"},
}; /* pci_vid_1612[] */

static pci_id_t const pci_vid_1618[] = {
{0x1618, 0xFFFF, 0xFFFF, 0xFFFF, "Stone Ridge Technology(0x1618)"},
{0x1618, 0x0001, 0xFFFF, 0xFFFF, "RDX 11(0x0001)"},
{0x1618, 0x0002, 0xFFFF, 0xFFFF, "HFT-01(0x0002)"},
{0x1618, 0x0400, 0xFFFF, 0xFFFF, "FarSync T2P (2 port X.21/V.35/V.24)(0x0400)"},
{0x1618, 0x0440, 0xFFFF, 0xFFFF, "FarSync T4P (4 port X.21/V.35/V.24)(0x0440)"},
{0x1618, 0x0610, 0xFFFF, 0xFFFF, "FarSync T1U (1 port X.21/V.35/V.24)(0x0610)"},
{0x1618, 0x0620, 0xFFFF, 0xFFFF, "FarSync T2U (2 port X.21/V.35/V.24)(0x0620)"},
{0x1618, 0x0640, 0xFFFF, 0xFFFF, "FarSync T4U (4 port X.21/V.35/V.24)(0x0640)"},
{0x1618, 0x1610, 0xFFFF, 0xFFFF, "FarSync TE1 (T1,E1)(0x1610)"},
{0x1618, 0x2610, 0xFFFF, 0xFFFF, "FarSync DSL-S1 (SHDSL)(0x2610)"},
{0x1618, 0x3640, 0xFFFF, 0xFFFF, "FarSync T4E (4-port X.21/V.35/V.24)(0x3640)"},
{0x1618, 0x4620, 0xFFFF, 0xFFFF, "FarSync T2Ue PCI Express (2-port X.21/V.35/V.24)(0x4620)"},
{0x1618, 0x4640, 0xFFFF, 0xFFFF, "FarSync T4Ue PCI Express (4-port X.21/V.35/V.24)(0x4640)"},
}; /* pci_vid_1618[] */

static pci_id_t const pci_vid_1619[] = {
{0x1619, 0xFFFF, 0xFFFF, 0xFFFF, "FarSite Communications Ltd(0x1619)"},
{0x1619, 0x0400, 0xFFFF, 0xFFFF, "FarSync T2P (2 port X.21/V.35/V.24)(0x0400)"},
{0x1619, 0x0440, 0xFFFF, 0xFFFF, "FarSync T4P (4 port X.21/V.35/V.24)(0x0440)"},
{0x1619, 0x0610, 0xFFFF, 0xFFFF, "FarSync T1U (1 port X.21/V.35/V.24)(0x0610)"},
{0x1619, 0x0620, 0xFFFF, 0xFFFF, "FarSync T2U (2 port X.21/V.35/V.24)(0x0620)"},
{0x1619, 0x0640, 0xFFFF, 0xFFFF, "FarSync T4U (4 port X.21/V.35/V.24)(0x0640)"},
{0x1619, 0x1610, 0xFFFF, 0xFFFF, "FarSync TE1 (T1,E1)(0x1610)"},
{0x1619, 0x1612, 0xFFFF, 0xFFFF, "FarSync TE1 PCI Express (T1,E1)(0x1612)"},
{0x1619, 0x2610, 0xFFFF, 0xFFFF, "FarSync DSL-S1 (SHDSL)(0x2610)"},
{0x1619, 0x3640, 0xFFFF, 0xFFFF, "FarSync T4E (4-port X.21/V.35/V.24)(0x3640)"},
{0x1619, 0x4620, 0xFFFF, 0xFFFF, "FarSync T2Ue PCI Express (2-port X.21/V.35/V.24)(0x4620)"},
{0x1619, 0x4640, 0xFFFF, 0xFFFF, "FarSync T4Ue PCI Express (4-port X.21/V.35/V.24)(0x4640)"},
{0x1619, 0x5621, 0xFFFF, 0xFFFF, "FarSync T2Ee PCI Express (2 port X.21/V.35/V.24)(0x5621)"},
{0x1619, 0x5641, 0xFFFF, 0xFFFF, "FarSync T4Ee PCI Express (4 port X.21/V.35/V.24)(0x5641)"},
{0x1619, 0x6620, 0xFFFF, 0xFFFF, "FarSync T2U-PMC PCI Express (2 port X.21/V.35/V.24)(0x6620)"},
}; /* pci_vid_1619[] */

static pci_id_t const pci_vid_161F[] = {
{0x161F, 0xFFFF, 0xFFFF, 0xFFFF, "Rioworks(0x161F)"},
}; /* pci_vid_161F[] */

static pci_id_t const pci_vid_1621[] = {
{0x1621, 0xFFFF, 0xFFFF, 0xFFFF, "Lynx Studio Technology, Inc.(0x1621)"},
{0x1621, 0x0020, 0xFFFF, 0xFFFF, "LynxTWO-A(0x0020)"},
{0x1621, 0x0021, 0xFFFF, 0xFFFF, "LynxTWO-B(0x0021)"},
{0x1621, 0x0022, 0xFFFF, 0xFFFF, "LynxTWO-C(0x0022)"},
{0x1621, 0x0023, 0xFFFF, 0xFFFF, "Lynx L22(0x0023)"},
{0x1621, 0x0024, 0xFFFF, 0xFFFF, "Lynx AES16(0x0024)"},
{0x1621, 0x0025, 0xFFFF, 0xFFFF, "Lynx AES16-SRC(0x0025)"},
{0x1621, 0x0028, 0xFFFF, 0xFFFF, "Lynx AES16e(0x0028)"},
}; /* pci_vid_1621[] */

static pci_id_t const pci_vid_1626[] = {
{0x1626, 0xFFFF, 0xFFFF, 0xFFFF, "TDK Semiconductor Corp.(0x1626)"},
{0x1626, 0x8410, 0xFFFF, 0xFFFF, "RTL81xx Fast Ethernet(0x8410)"},
}; /* pci_vid_1626[] */

static pci_id_t const pci_vid_1629[] = {
{0x1629, 0xFFFF, 0xFFFF, 0xFFFF, "Kongsberg Spacetec AS(0x1629)"},
{0x1629, 0x1003, 0xFFFF, 0xFFFF, "Format synchronizer v3.0(0x1003)"},
{0x1629, 0x1006, 0xFFFF, 0xFFFF, "Format synchronizer, model 10500(0x1006)"},
{0x1629, 0x1007, 0xFFFF, 0xFFFF, "Format synchronizer, model 21000(0x1007)"},
{0x1629, 0x2002, 0xFFFF, 0xFFFF, "Fast Universal Data Output(0x2002)"},
{0x1629, 0x3100, 0xFFFF, 0xFFFF, "IO31000 Frame Synchronizer and I/O(0x3100)"},
{0x1629, 0x3200, 0xFFFF, 0xFFFF, "IO32000 Frame Synchronizer and I/O(0x3200)"},
{0x1629, 0x4002, 0xFFFF, 0xFFFF, "High Rate Demodulator(0x4002)"},
{0x1629, 0x5001, 0xFFFF, 0xFFFF, "High Rate FEC(0x5001)"},
{0x1629, 0x6001, 0xFFFF, 0xFFFF, "High Rate Demodulator and FEC(0x6001)"},
}; /* pci_vid_1629[] */

static pci_id_t const pci_vid_1631[] = {
{0x1631, 0xFFFF, 0xFFFF, 0xFFFF, "Packard Bell B.V.(0x1631)"},
}; /* pci_vid_1631[] */

static pci_id_t const pci_vid_1638[] = {
{0x1638, 0xFFFF, 0xFFFF, 0xFFFF, "Standard Microsystems Corp [SMC](0x1638)"},
{0x1638, 0x1100, 0xFFFF, 0xFFFF, "SMC2602W EZConnect / Addtron AWA-100 / Eumitcom PCI WL11000(0x1100)"},
}; /* pci_vid_1638[] */

static pci_id_t const pci_vid_163C[] = {
{0x163C, 0xFFFF, 0xFFFF, 0xFFFF, "Smart Link Ltd.(0x163C)"},
{0x163C, 0x3052, 0xFFFF, 0xFFFF, "SmartLink SmartPCI562 56K Modem(0x3052)"},
{0x163C, 0x5449, 0xFFFF, 0xFFFF, "SmartPCI561 Modem(0x5449)"},
}; /* pci_vid_163C[] */

static pci_id_t const pci_vid_1641[] = {
{0x1641, 0xFFFF, 0xFFFF, 0xFFFF, "MKNet Corp.(0x1641)"},
}; /* pci_vid_1641[] */

static pci_id_t const pci_vid_1642[] = {
{0x1642, 0xFFFF, 0xFFFF, 0xFFFF, "Bitland(ShenZhen) Information Technology Co., Ltd.(0x1642)"},
}; /* pci_vid_1642[] */

static pci_id_t const pci_vid_1657[] = {
{0x1657, 0xFFFF, 0xFFFF, 0xFFFF, "Cavium QLogic(0x1657)"},
{0x1657, 0x0013, 0xFFFF, 0xFFFF, "425/825/42B/82B 4Gbps/8Gbps PCIe dual port FC HBA(0x0013)"},
{0x1657, 0x0013, 0x103C, 0x1742, "82B 8Gbps dual port FC HBA(0x103C-0x1742)"},
{0x1657, 0x0013, 0x103C, 0x1744, "42B 4Gbps dual port FC HBA(0x103C-0x1744)"},
{0x1657, 0x0013, 0x1657, 0x0014, "425/825 4Gbps/8Gbps PCIe dual port FC HBA(0x1657-0x0014)"},
{0x1657, 0x0014, 0xFFFF, 0xFFFF, "1010/1020/1007/1741 10Gbps CNA(0x0014)"},
{0x1657, 0x0014, 0x1657, 0x0014, "1010/1020/1007/1741 10Gbps CNA - FCOE(0x1657-0x0014)"},
{0x1657, 0x0014, 0x1657, 0x0015, "1010/1020/1007/1741 10Gbps CNA - LL(0x1657-0x0015)"},
{0x1657, 0x0017, 0xFFFF, 0xFFFF, "415/815/41B/81B 4Gbps/8Gbps PCIe single port FC HBA(0x0017)"},
{0x1657, 0x0017, 0x103C, 0x1741, "41B 4Gbps single port FC HBA(0x103C-0x1741)"},
{0x1657, 0x0017, 0x103C, 0x1743, "81B 8Gbps single port FC HBA(0x103C-0x1743)"},
{0x1657, 0x0017, 0x1657, 0x0014, "415/815 4Gbps/8Gbps single port PCIe FC HBA(0x1657-0x0014)"},
{0x1657, 0x0021, 0xFFFF, 0xFFFF, "804 8Gbps FC HBA for HP Bladesystem c-class(0x0021)"},
{0x1657, 0x0022, 0xFFFF, 0xFFFF, "BR-1860 Fabric Adapter(0x0022)"},
{0x1657, 0x0022, 0x1657, 0x0022, "10Gbps CNA - FCOE(0x1657-0x0022)"},
{0x1657, 0x0022, 0x1657, 0x0023, "10Gbps CNA - LL(0x1657-0x0023)"},
{0x1657, 0x0022, 0x1657, 0x0024, "16Gbps FC HBA(0x1657-0x0024)"},
{0x1657, 0x0023, 0xFFFF, 0xFFFF, "1867/1869 16Gbps FC HBA(0x0023)"},
{0x1657, 0x0646, 0xFFFF, 0xFFFF, "400 4Gbps PCIe FC HBA(0x0646)"},
}; /* pci_vid_1657[] */

static pci_id_t const pci_vid_165A[] = {
{0x165A, 0xFFFF, 0xFFFF, 0xFFFF, "Epix Inc(0x165A)"},
{0x165A, 0xC100, 0xFFFF, 0xFFFF, "PIXCI(R) CL1 Camera Link Video Capture Board [custom QL5232](0xC100)"},
{0x165A, 0xD200, 0xFFFF, 0xFFFF, "PIXCI(R) D2X Digital Video Capture Board [custom QL5232](0xD200)"},
{0x165A, 0xD300, 0xFFFF, 0xFFFF, "PIXCI(R) D3X Digital Video Capture Board [custom QL5232](0xD300)"},
{0x165A, 0xEB01, 0xFFFF, 0xFFFF, "PIXCI(R) EB1 PCI Camera Link Video Capture Board(0xEB01)"},
}; /* pci_vid_165A[] */

static pci_id_t const pci_vid_165C[] = {
{0x165C, 0xFFFF, 0xFFFF, 0xFFFF, "Gidel Ltd.(0x165C)"},
{0x165C, 0x5361, 0xFFFF, 0xFFFF, "PROCStarII60-1(0x5361)"},
{0x165C, 0x5362, 0xFFFF, 0xFFFF, "PROCStarII60-2(0x5362)"},
{0x165C, 0x5364, 0xFFFF, 0xFFFF, "PROCStarII60-4(0x5364)"},
{0x165C, 0x5435, 0xFFFF, 0xFFFF, "ProcSparkII(0x5435)"},
{0x165C, 0x5661, 0xFFFF, 0xFFFF, "ProcE60(0x5661)"},
{0x165C, 0x56E1, 0xFFFF, 0xFFFF, "ProcE180(0x56E1)"},
{0x165C, 0x5911, 0xFFFF, 0xFFFF, "ProcStarIII110-1(0x5911)"},
{0x165C, 0x5912, 0xFFFF, 0xFFFF, "ProcStarIII110-2(0x5912)"},
{0x165C, 0x5913, 0xFFFF, 0xFFFF, "ProcStarIII110-3(0x5913)"},
{0x165C, 0x5914, 0xFFFF, 0xFFFF, "ProcStarIII110-4(0x5914)"},
{0x165C, 0x5921, 0xFFFF, 0xFFFF, "ProcStarIII150-1(0x5921)"},
{0x165C, 0x5922, 0xFFFF, 0xFFFF, "ProcStarIII150-2(0x5922)"},
{0x165C, 0x5923, 0xFFFF, 0xFFFF, "ProcStarIII150-3(0x5923)"},
{0x165C, 0x5924, 0xFFFF, 0xFFFF, "ProcStarIII150-4(0x5924)"},
{0x165C, 0x5931, 0xFFFF, 0xFFFF, "ProcStarIII260-1(0x5931)"},
{0x165C, 0x5932, 0xFFFF, 0xFFFF, "ProcStarIII260-2(0x5932)"},
{0x165C, 0x5933, 0xFFFF, 0xFFFF, "ProcStarIII260-3(0x5933)"},
{0x165C, 0x5934, 0xFFFF, 0xFFFF, "ProcStarIII260-4(0x5934)"},
{0x165C, 0x5941, 0xFFFF, 0xFFFF, "ProcStarIII340-1(0x5941)"},
{0x165C, 0x5942, 0xFFFF, 0xFFFF, "ProcStarIII340-2(0x5942)"},
{0x165C, 0x5943, 0xFFFF, 0xFFFF, "ProcStarIII340-3(0x5943)"},
{0x165C, 0x5944, 0xFFFF, 0xFFFF, "ProcStarIII340-4(0x5944)"},
{0x165C, 0x5A01, 0xFFFF, 0xFFFF, "ProceIII80(0x5A01)"},
{0x165C, 0x5A11, 0xFFFF, 0xFFFF, "ProceIII110(0x5A11)"},
{0x165C, 0x5A21, 0xFFFF, 0xFFFF, "ProceIII150(0x5A21)"},
{0x165C, 0x5A31, 0xFFFF, 0xFFFF, "ProceIII260(0x5A31)"},
{0x165C, 0x5A41, 0xFFFF, 0xFFFF, "ProceIII340(0x5A41)"},
{0x165C, 0x5B51, 0xFFFF, 0xFFFF, "ProceIV360(0x5B51)"},
{0x165C, 0x5B61, 0xFFFF, 0xFFFF, "ProceIV530(0x5B61)"},
{0x165C, 0x5B71, 0xFFFF, 0xFFFF, "ProceIV820(0x5B71)"},
{0x165C, 0x5C01, 0xFFFF, 0xFFFF, "ProcStarIV80-1(0x5C01)"},
{0x165C, 0x5C02, 0xFFFF, 0xFFFF, "ProcStarIV80-2(0x5C02)"},
{0x165C, 0x5C03, 0xFFFF, 0xFFFF, "ProcStarIV80-3(0x5C03)"},
{0x165C, 0x5C04, 0xFFFF, 0xFFFF, "ProcStarIV80-4(0x5C04)"},
{0x165C, 0x5C11, 0xFFFF, 0xFFFF, "ProcStarIV110-1(0x5C11)"},
{0x165C, 0x5C12, 0xFFFF, 0xFFFF, "ProcStarIV110-2(0x5C12)"},
{0x165C, 0x5C13, 0xFFFF, 0xFFFF, "ProcStarIV110-3(0x5C13)"},
{0x165C, 0x5C14, 0xFFFF, 0xFFFF, "ProcStarIV110-4(0x5C14)"},
{0x165C, 0x5C51, 0xFFFF, 0xFFFF, "ProcStarIV360-1(0x5C51)"},
{0x165C, 0x5C52, 0xFFFF, 0xFFFF, "ProcStarIV360-2(0x5C52)"},
{0x165C, 0x5C53, 0xFFFF, 0xFFFF, "ProcStarIV360-3(0x5C53)"},
{0x165C, 0x5C54, 0xFFFF, 0xFFFF, "ProcStarIV360-4(0x5C54)"},
{0x165C, 0x5C61, 0xFFFF, 0xFFFF, "ProcStarIV530-1(0x5C61)"},
{0x165C, 0x5C62, 0xFFFF, 0xFFFF, "ProcStarIV530-2(0x5C62)"},
{0x165C, 0x5C63, 0xFFFF, 0xFFFF, "ProcStarIV530-3(0x5C63)"},
{0x165C, 0x5C64, 0xFFFF, 0xFFFF, "ProcStarIV530-4(0x5C64)"},
{0x165C, 0x5C71, 0xFFFF, 0xFFFF, "ProcStarIV820-1(0x5C71)"},
{0x165C, 0x5C72, 0xFFFF, 0xFFFF, "ProcStarIV820-2(0x5C72)"},
{0x165C, 0x5C73, 0xFFFF, 0xFFFF, "ProcStarIV820-3(0x5C73)"},
{0x165C, 0x5C74, 0xFFFF, 0xFFFF, "ProcStarIV820-4(0x5C74)"},
{0x165C, 0x5D01, 0xFFFF, 0xFFFF, "Proc10480(0x5D01)"},
{0x165C, 0x5D11, 0xFFFF, 0xFFFF, "Proc104110(0x5D11)"},
{0x165C, 0x5F01, 0xFFFF, 0xFFFF, "ProceV_A3(0x5F01)"},
{0x165C, 0x5F11, 0xFFFF, 0xFFFF, "ProceV_A7(0x5F11)"},
{0x165C, 0x5F21, 0xFFFF, 0xFFFF, "ProceV_AB(0x5F21)"},
{0x165C, 0x5F31, 0xFFFF, 0xFFFF, "ProceV_D5(0x5F31)"},
{0x165C, 0x5F41, 0xFFFF, 0xFFFF, "ProceV_D8(0x5F41)"},
{0x165C, 0x6732, 0xFFFF, 0xFFFF, "Proc6M(0x6732)"},
{0x165C, 0x6832, 0xFFFF, 0xFFFF, "Proc12M(0x6832)"},
{0x165C, 0x7101, 0xFFFF, 0xFFFF, "Proc10a_27(0x7101)"},
{0x165C, 0x7111, 0xFFFF, 0xFFFF, "Proc10a_48(0x7111)"},
{0x165C, 0x7121, 0xFFFF, 0xFFFF, "Proc10a_66(0x7121)"},
{0x165C, 0x7141, 0xFFFF, 0xFFFF, "Proc10a_115(0x7141)"},
{0x165C, 0x7181, 0xFFFF, 0xFFFF, "Proc10a_27S(0x7181)"},
{0x165C, 0x7191, 0xFFFF, 0xFFFF, "Proc10a_48S(0x7191)"},
{0x165C, 0x71A1, 0xFFFF, 0xFFFF, "Proc10a_66S(0x71A1)"},
{0x165C, 0x71B1, 0xFFFF, 0xFFFF, "Proc10A(0x71B1)"},
{0x165C, 0x72B1, 0xFFFF, 0xFFFF, "HawkEye(0x72B1)"},
{0x165C, 0x73B1, 0xFFFF, 0xFFFF, "Proc10s(0x73B1)"},
}; /* pci_vid_165C[] */

static pci_id_t const pci_vid_165D[] = {
{0x165D, 0xFFFF, 0xFFFF, 0xFFFF, "Hsing Tech. Enterprise Co., Ltd.(0x165D)"},
}; /* pci_vid_165D[] */

static pci_id_t const pci_vid_165F[] = {
{0x165F, 0xFFFF, 0xFFFF, 0xFFFF, "Linux Media Labs, LLC(0x165F)"},
{0x165F, 0x1020, 0xFFFF, 0xFFFF, "LMLM4 MPEG-4 encoder(0x1020)"},
}; /* pci_vid_165F[] */

static pci_id_t const pci_vid_1661[] = {
{0x1661, 0xFFFF, 0xFFFF, 0xFFFF, "Worldspace Corp.(0x1661)"},
}; /* pci_vid_1661[] */

static pci_id_t const pci_vid_1665[] = {
{0x1665, 0xFFFF, 0xFFFF, 0xFFFF, "EDAX Inc(0x1665)"},
{0x1665, 0x1973, 0xFFFF, 0xFFFF, "DPP-II FR2 Board(0x1973)"},
{0x1665, 0x2000, 0xFFFF, 0xFFFF, "SG-IIP Board(0x2000)"},
}; /* pci_vid_1665[] */

static pci_id_t const pci_vid_1668[] = {
{0x1668, 0xFFFF, 0xFFFF, 0xFFFF, "Actiontec Electronics Inc(0x1668)"},
{0x1668, 0x0100, 0xFFFF, 0xFFFF, "Mini-PCI bridge(0x0100)"},
}; /* pci_vid_1668[] */

static pci_id_t const pci_vid_166D[] = {
{0x166D, 0xFFFF, 0xFFFF, 0xFFFF, "Broadcom Corporation(0x166D)"},
{0x166D, 0x0001, 0xFFFF, 0xFFFF, "SiByte BCM1125/1125H/1250 System-on-a-Chip PCI(0x0001)"},
{0x166D, 0x0002, 0xFFFF, 0xFFFF, "SiByte BCM1125H/1250 System-on-a-Chip HyperTransport(0x0002)"},
{0x166D, 0x0012, 0xFFFF, 0xFFFF, "SiByte BCM1280/BCM1480 System-on-a-Chip PCI-X(0x0012)"},
{0x166D, 0x0014, 0xFFFF, 0xFFFF, "Sibyte BCM1280/BCM1480 System-on-a-Chip HyperTransport(0x0014)"},
}; /* pci_vid_166D[] */

static pci_id_t const pci_vid_1677[] = {
{0x1677, 0xFFFF, 0xFFFF, 0xFFFF, "B&R Industrial Automation GmbH(0x1677)"},
{0x1677, 0x104E, 0xFFFF, 0xFFFF, "5LS172.6 B&R Dual CAN Interface Card(0x104E)"},
{0x1677, 0x12D7, 0xFFFF, 0xFFFF, "5LS172.61 B&R Dual CAN Interface Card(0x12D7)"},
{0x1677, 0x20AD, 0xFFFF, 0xFFFF, "5ACPCI.MFIO-K01 Profibus DP / K-Feldbus / COM(0x20AD)"},
}; /* pci_vid_1677[] */

static pci_id_t const pci_vid_1678[] = {
{0x1678, 0xFFFF, 0xFFFF, 0xFFFF, "NetEffect(0x1678)"},
{0x1678, 0x0100, 0xFFFF, 0xFFFF, "NE020 10Gb Accelerated Ethernet Adapter (iWARP RNIC)(0x0100)"},
}; /* pci_vid_1678[] */

static pci_id_t const pci_vid_1679[] = {
{0x1679, 0xFFFF, 0xFFFF, 0xFFFF, "Tokyo Electron Device Ltd.(0x1679)"},
{0x1679, 0x3000, 0xFFFF, 0xFFFF, "SD Standard host controller [Ellen](0x3000)"},
}; /* pci_vid_1679[] */

static pci_id_t const pci_vid_167B[] = {
{0x167B, 0xFFFF, 0xFFFF, 0xFFFF, "ZyDAS Technology Corp.(0x167B)"},
{0x167B, 0x2102, 0xFFFF, 0xFFFF, "ZyDAS ZD1202(0x2102)"},
{0x167B, 0x2102, 0x187E, 0x3406, "ZyAIR B-122 CardBus 11Mbs Wireless LAN Card(0x187E-0x3406)"},
{0x167B, 0x2102, 0x187E, 0x3407, "ZyAIR B-320 802.11b Wireless PCI Adapter(0x187E-0x3407)"},
{0x167B, 0x2116, 0xFFFF, 0xFFFF, "ZD1212B Wireless Adapter(0x2116)"},
}; /* pci_vid_167B[] */

static pci_id_t const pci_vid_167D[] = {
{0x167D, 0xFFFF, 0xFFFF, 0xFFFF, "Samsung Electro-Mechanics Co., Ltd.(0x167D)"},
{0x167D, 0xA000, 0xFFFF, 0xFFFF, "MagicLAN SWL-2210P 802.11b [Intersil ISL3874](0xA000)"},
}; /* pci_vid_167D[] */

static pci_id_t const pci_vid_167E[] = {
{0x167E, 0xFFFF, 0xFFFF, 0xFFFF, "ONNTO Corp.(0x167E)"},
}; /* pci_vid_167E[] */

static pci_id_t const pci_vid_1681[] = {
{0x1681, 0xFFFF, 0xFFFF, 0xFFFF, "Hercules(0x1681)"},
}; /* pci_vid_1681[] */

static pci_id_t const pci_vid_1682[] = {
{0x1682, 0xFFFF, 0xFFFF, 0xFFFF, "XFX Pine Group Inc.(0x1682)"},
{0x1682, 0x5701, 0xFFFF, 0xFFFF, "Radeon 5700 XT Thicc III Ultra(0x5701)"},
{0x1682, 0xC580, 0xFFFF, 0xFFFF, "Radeon RX 580(0xC580)"},
}; /* pci_vid_1682[] */

static pci_id_t const pci_vid_1688[] = {
{0x1688, 0xFFFF, 0xFFFF, 0xFFFF, "CastleNet Technology Inc.(0x1688)"},
{0x1688, 0x1170, 0xFFFF, 0xFFFF, "WLAN 802.11b card(0x1170)"},
}; /* pci_vid_1688[] */

static pci_id_t const pci_vid_168A[] = {
{0x168A, 0xFFFF, 0xFFFF, 0xFFFF, "Utimaco IS GmbH(0x168A)"},
{0x168A, 0x2086, 0xFFFF, 0xFFFF, "CryptoServer Se-Series Hardware Security Module(0x2086)"},
{0x168A, 0xC040, 0xFFFF, 0xFFFF, "CryptoServer CSe-Series Hardware Security Module(0xC040)"},
{0x168A, 0xC051, 0xFFFF, 0xFFFF, "CryptoServer Se-Series Gen2 Hardware Security Module(0xC051)"},
{0x168A, 0xC070, 0xFFFF, 0xFFFF, "u.trust Anchor Hardware Security Module cs7.2 Series(0xC070)"},
{0x168A, 0xC071, 0xFFFF, 0xFFFF, "u.trust Anchor Hardware Security Module cs7.3 Series(0xC071)"},
{0x168A, 0xC072, 0xFFFF, 0xFFFF, "u.trust Anchor Hardware Security Module cs7.3 Series Virtual Function(0xC072)"},
}; /* pci_vid_168A[] */

static pci_id_t const pci_vid_168C[] = {
{0x168C, 0xFFFF, 0xFFFF, 0xFFFF, "Qualcomm Atheros(0x168C)"},
{0x168C, 0x0007, 0xFFFF, 0xFFFF, "AR5210 Wireless Network Adapter [AR5000 802.11a](0x0007)"},
{0x168C, 0x0007, 0x1737, 0x0007, "WPC54A Wireless PC Card(0x1737-0x0007)"},
{0x168C, 0x0007, 0x1B47, 0x0100, "Harmony 8450CN Wireless CardBus Module(0x1B47-0x0100)"},
{0x168C, 0x0007, 0x1B47, 0x0110, "Skyline 4030 / Harmony 8450 802.11a Wireless CardBus Adapter(0x1B47-0x0110)"},
{0x168C, 0x0007, 0x8086, 0x2501, "PRO/Wireless 5000 LAN PCI Adapter Module(0x8086-0x2501)"},
{0x168C, 0x0011, 0xFFFF, 0xFFFF, "AR5211 Wireless Network Adapter [AR5001A 802.11a](0x0011)"},
{0x168C, 0x0012, 0xFFFF, 0xFFFF, "AR5211 Wireless Network Adapter [AR5001X 802.11ab](0x0012)"},
{0x168C, 0x0012, 0x1186, 0x3A03, "AirPro DWL-A650 Wireless Cardbus Adapter (rev.B)(0x1186-0x3A03)"},
{0x168C, 0x0012, 0x1186, 0x3A04, "AirPro DWL-AB650 Multimode Wireless Cardbus Adapter(0x1186-0x3A04)"},
{0x168C, 0x0012, 0x1186, 0x3A05, "AirPro DWL-AB520 Multimode Wireless PCI Adapter(0x1186-0x3A05)"},
{0x168C, 0x0012, 0x126C, 0x8031, "2201 Mobile Adapter(0x126C-0x8031)"},
{0x168C, 0x0012, 0x1385, 0x4400, "WAB501 802.11ab Wireless CardBus Card(0x1385-0x4400)"},
{0x168C, 0x0012, 0x1B47, 0xAA00, "8460 802.11ab Wireless CardBus Adapter(0x1B47-0xAA00)"},
{0x168C, 0x0013, 0xFFFF, 0xFFFF, "AR5212/5213/2414 Wireless Network Adapter(0x0013)"},
{0x168C, 0x0013, 0x0308, 0x3402, "AG-100 802.11ag Wireless Cardbus Adapter(0x0308-0x3402)"},
{0x168C, 0x0013, 0x0308, 0x3405, "G-102 v2 802.11g Wireless Cardbus Adapter(0x0308-0x3405)"},
{0x168C, 0x0013, 0x0308, 0x3408, "G-170S 802.11g Wireless CardBus Adapter(0x0308-0x3408)"},
{0x168C, 0x0013, 0x0E11, 0x00E5, "NC6000/NC8000 laptop(0x0E11-0x00E5)"},
{0x168C, 0x0013, 0x10B7, 0x6002, "3CRWE154A72 802.11abg Cardbus Adapter(0x10B7-0x6002)"},
{0x168C, 0x0013, 0x1113, 0xD301, "Philips CPWNA100 Wireless CardBus adapter(0x1113-0xD301)"},
{0x168C, 0x0013, 0x1113, 0xEE23, "SMCWPCIT-G 108Mbps Wireless PCI adapter(0x1113-0xEE23)"},
{0x168C, 0x0013, 0x1154, 0x033B, "Buffalo WLI-CB-AMG54(0x1154-0x033B)"},
{0x168C, 0x0013, 0x1154, 0x034E, "Buffalo WLI-CB-AG108HP 802.11abg Cardbus Adapter(0x1154-0x034E)"},
{0x168C, 0x0013, 0x1186, 0x3202, "DWL-G650 (Rev B3,B5) Wireless cardbus adapter(0x1186-0x3202)"},
{0x168C, 0x0013, 0x1186, 0x3203, "AirPlus DWL-G520 Wireless PCI Adapter (rev. A)(0x1186-0x3203)"},
{0x168C, 0x0013, 0x1186, 0x3A07, "AirXpert DWL-AG650 Wireless Cardbus Adapter(0x1186-0x3A07)"},
{0x168C, 0x0013, 0x1186, 0x3A08, "AirXpert DWL-AG520 Wireless PCI Adapter(0x1186-0x3A08)"},
{0x168C, 0x0013, 0x1186, 0x3A12, "D-Link AirPlus DWL-G650 Wireless Cardbus Adapter(rev.C)(0x1186-0x3A12)"},
{0x168C, 0x0013, 0x1186, 0x3A13, "AirPlus DWL-G520 Wireless PCI Adapter (rev. B)(0x1186-0x3A13)"},
{0x168C, 0x0013, 0x1186, 0x3A14, "AirPremier AG DWL-AG530 Wireless PCI Adapter (rev.A)(0x1186-0x3A14)"},
{0x168C, 0x0013, 0x1186, 0x3A17, "D-Link AirPremier DWL-G680 Wireless Cardbus Adapter(0x1186-0x3A17)"},
{0x168C, 0x0013, 0x1186, 0x3A18, "D-Link AirPremier DWL-G550 Wireless PCI Adapter(0x1186-0x3A18)"},
{0x168C, 0x0013, 0x1186, 0x3A1A, "WNA-2330 802.11bg Wireless CardBus Adapter(0x1186-0x3A1A)"},
{0x168C, 0x0013, 0x1186, 0x3A63, "D-Link AirPremier DWL-AG660 Wireless Cardbus Adapter(0x1186-0x3A63)"},
{0x168C, 0x0013, 0x1186, 0x3A93, "Conceptronic C54I Wireless 801.11g PCI card(0x1186-0x3A93)"},
{0x168C, 0x0013, 0x1186, 0x3A94, "Conceptronic C54C 802.11g Wireless Cardbus Adapter(0x1186-0x3A94)"},
{0x168C, 0x0013, 0x1186, 0x3AB0, "Allnet ALL0281 Wireless PCI Card(0x1186-0x3AB0)"},
{0x168C, 0x0013, 0x1385, 0x4600, "WAG511 802.11a/b/g Dual Band Wireless PC Card(0x1385-0x4600)"},
{0x168C, 0x0013, 0x1385, 0x4610, "WAG511 802.11a/b/g Dual Band Wireless PC Card(0x1385-0x4610)"},
{0x168C, 0x0013, 0x1385, 0x4900, "WG311v1 802.11g Wireless PCI Adapter(0x1385-0x4900)"},
{0x168C, 0x0013, 0x1385, 0x4A00, "WAG311 802.11a/g Wireless PCI Adapter(0x1385-0x4A00)"},
{0x168C, 0x0013, 0x1385, 0x4B00, "WG511T 108 Mbps Wireless PC Card (rev.A/B)(0x1385-0x4B00)"},
{0x168C, 0x0013, 0x1385, 0x4D00, "WG311T 108 Mbps Wireless PCI Adapter (rev.A2)(0x1385-0x4D00)"},
{0x168C, 0x0013, 0x1385, 0x4F00, "WG511U Double 108 Mbps Wireless PC Card(0x1385-0x4F00)"},
{0x168C, 0x0013, 0x1385, 0x5A00, "WG311T (rev.A3 v1h3/v1h4) 108 Mbps Wireless PCI Adapter [AR2412](0x1385-0x5A00)"},
{0x168C, 0x0013, 0x1385, 0x5B00, "WG511T 108 Mbps Wireless PC Card (rev.C)(0x1385-0x5B00)"},
{0x168C, 0x0013, 0x1385, 0x5D00, "WPN511 RangeMax Wireless PC Card(0x1385-0x5D00)"},
{0x168C, 0x0013, 0x1458, 0xE911, "GN-WIAG02(0x1458-0xE911)"},
{0x168C, 0x0013, 0x1468, 0x0403, "U10H014 802.11g Cardbus Adapter(0x1468-0x0403)"},
{0x168C, 0x0013, 0x1468, 0x0408, "ThinkPad 11b/g Wireless LAN Mini PCI Adapter(0x1468-0x0408)"},
{0x168C, 0x0013, 0x14B7, 0x0A10, "8480-WD 802.11abg Cardbus Adapter(0x14B7-0x0A10)"},
{0x168C, 0x0013, 0x14B7, 0x0A60, "8482-WD ORiNOCO 11a/b/g Wireless PCI Adapter(0x14B7-0x0A60)"},
{0x168C, 0x0013, 0x14B7, 0xAA30, "8800-FC 802.11bg Cardbus Adapter(0x14B7-0xAA30)"},
{0x168C, 0x0013, 0x14B7, 0xAA40, "8470-WD 802.11bg Cardbus Adapter(0x14B7-0xAA40)"},
{0x168C, 0x0013, 0x14B9, 0xCB21, "CB21 802.11a/b/g Cardbus Adapter(0x14B9-0xCB21)"},
{0x168C, 0x0013, 0x1668, 0x1026, "IBM HighRate 11 a/b/g Wireless CardBus Adapter(0x1668-0x1026)"},
{0x168C, 0x0013, 0x168C, 0x0013, "AirPlus XtremeG DWL-G650 Wireless PCMCIA Adapter(0x168C-0x0013)"},
{0x168C, 0x0013, 0x168C, 0x1025, "DWL-G650B2 Wireless CardBus Adapter(0x168C-0x1025)"},
{0x168C, 0x0013, 0x168C, 0x1027, "Engenius NL-3054CB ARIES b/g CardBus Adapter(0x168C-0x1027)"},
{0x168C, 0x0013, 0x168C, 0x1042, "Ubiquiti Networks SuperRange a/b/g Cardbus Adapter(0x168C-0x1042)"},
{0x168C, 0x0013, 0x168C, 0x1051, "EZ Connect g 802.11g 108Mbps Wireless PCI Adapter(0x168C-0x1051)"},
{0x168C, 0x0013, 0x168C, 0x2026, "Netgate 5354MP ARIES a(108Mb turbo)/b/g MiniPCI Adapter(0x168C-0x2026)"},
{0x168C, 0x0013, 0x168C, 0x2027, "D-Link AirPlus DWL-G520 Wireless PCI Adapter (rev. A)(0x168C-0x2027)"},
{0x168C, 0x0013, 0x168C, 0x2041, "Engenius 5354MP Plus ARIES2 b/g MiniPCI Adapter(0x168C-0x2041)"},
{0x168C, 0x0013, 0x168C, 0x2042, "Engenius 5354MP Plus ARIES2 a/b/g MiniPCI Adapter(0x168C-0x2042)"},
{0x168C, 0x0013, 0x168C, 0x2051, "TRENDnet TEW-443PI Wireless PCI Adapter(0x168C-0x2051)"},
{0x168C, 0x0013, 0x16A5, 0x160A, "BWP712 802.11bg Wireless CardBus Adapter(0x16A5-0x160A)"},
{0x168C, 0x0013, 0x16AB, 0x7302, "Trust Speedshare Turbo Pro Wireless PCI Adapter(0x16AB-0x7302)"},
{0x168C, 0x0013, 0x1737, 0x0017, "WPC55AG(0x1737-0x0017)"},
{0x168C, 0x0013, 0x1737, 0x0026, "WMP55AG v1.1(0x1737-0x0026)"},
{0x168C, 0x0013, 0x1737, 0x0035, "WPC55AG v1.2 802.11abg Cardbus Adapter(0x1737-0x0035)"},
{0x168C, 0x0013, 0x1737, 0x0036, "WMP55AG v1.2 802.11abg PCI Adapter(0x1737-0x0036)"},
{0x168C, 0x0013, 0x1799, 0x3000, "F6D3000 Dual-Band Wireless A+G Desktop Card(0x1799-0x3000)"},
{0x168C, 0x0013, 0x1799, 0x3010, "F6D3010 Dual-Band Wireless A+G Notebook Card(0x1799-0x3010)"},
{0x168C, 0x0013, 0x17CF, 0x0042, "Z-COMAX Highpower XG-622H (400mw) 802.11b/g mini-PCI Adapter(0x17CF-0x0042)"},
{0x168C, 0x0013, 0x185F, 0x1012, "CM9 Wireless a/b/g MiniPCI Adapter(0x185F-0x1012)"},
{0x168C, 0x0013, 0x185F, 0x2012, "Wistron NeWeb WLAN a+b+g model CB9(0x185F-0x2012)"},
{0x168C, 0x0013, 0xA727, 0x6801, "3CRXJK10075 OfficeConnect Wireless 108Mbps 11g XJACK PC Card(0xA727-0x6801)"},
{0x168C, 0x001A, 0xFFFF, 0xFFFF, "AR2413/AR2414 Wireless Network Adapter [AR5005G(S) 802.11bg](0x001A)"},
{0x168C, 0x001A, 0x1052, 0x168C, "Sweex Wireless Lan PC Card 54Mbps(0x1052-0x168C)"},
{0x168C, 0x001A, 0x1113, 0xEE20, "SMC Wireless CardBus Adapter 802.11g (SMCWCB-G EU)(0x1113-0xEE20)"},
{0x168C, 0x001A, 0x1113, 0xEE24, "SMC Wireless PCI Card WPCI-G(0x1113-0xEE24)"},
{0x168C, 0x001A, 0x1186, 0x3A15, "AirPlus G DWL-G630 Wireless Cardbus Adapter (rev.D1)(0x1186-0x3A15)"},
{0x168C, 0x001A, 0x1186, 0x3A16, "AirPlus G DWL-G510 Wireless PCI Adapter(rev.B)(0x1186-0x3A16)"},
{0x168C, 0x001A, 0x1186, 0x3A1C, "WNA-1330 Notebook Adapter(0x1186-0x3A1C)"},
{0x168C, 0x001A, 0x1186, 0x3A1D, "WDA-1320 Desktop Adapter(0x1186-0x3A1D)"},
{0x168C, 0x001A, 0x1186, 0x3A23, "AirPlus G DWL-G520+A Wireless PCI Adapter(0x1186-0x3A23)"},
{0x168C, 0x001A, 0x1186, 0x3A24, "AirPlus G DWL-G650+A Wireless Cardbus Adapter(0x1186-0x3A24)"},
{0x168C, 0x001A, 0x1186, 0x3B08, "AirPlus G DWL-G630 Wireless Cardbus Adapter (rev.C1)(0x1186-0x3B08)"},
{0x168C, 0x001A, 0x168C, 0x001A, "Belkin FD7000(0x168C-0x001A)"},
{0x168C, 0x001A, 0x168C, 0x1052, "TP-Link TL-WN510G Wireless CardBus Adapter(0x168C-0x1052)"},
{0x168C, 0x001A, 0x168C, 0x2052, "Compex Wireless 802.11 b/g  MiniPCI Adapter, Rev A1 [WLM54G](0x168C-0x2052)"},
{0x168C, 0x001A, 0x16EC, 0x0122, "Wireless PCI Adapter Model 5418(0x16EC-0x0122)"},
{0x168C, 0x001A, 0x1737, 0x0053, "WPC54G v7 802.11g Wireless-G Notebook Adapter(0x1737-0x0053)"},
{0x168C, 0x001A, 0x1799, 0x700C, "F5D7000 v5000 Wireless G Desktop Card(0x1799-0x700C)"},
{0x168C, 0x001A, 0x1799, 0x701D, "F5D7010 v5000 Wireless G Notebook Card(0x1799-0x701D)"},
{0x168C, 0x001A, 0x17F9, 0x0008, "DX-WGNBC 802.11bg Wireless CardBus Adapter(0x17F9-0x0008)"},
{0x168C, 0x001A, 0x17F9, 0x0018, "DX-WGDTC 802.11bg Wireless PCI Adapter(0x17F9-0x0018)"},
{0x168C, 0x001B, 0xFFFF, 0xFFFF, "AR5413/AR5414 Wireless Network Adapter [AR5006X(S) 802.11abg](0x001B)"},
{0x168C, 0x001B, 0x0777, 0x1107, "UB5 802.11a Wireless Mini PCI Adapter(0x0777-0x1107)"},
{0x168C, 0x001B, 0x0777, 0x3002, "XR2 802.11g Wireless Mini PCI Adapter(0x0777-0x3002)"},
{0x168C, 0x001B, 0x0777, 0x3005, "XR5 802.11a Wireless Mini PCI Adapter(0x0777-0x3005)"},
{0x168C, 0x001B, 0x0777, 0x3009, "XR9 900MHz Wireless Mini PCI Adapter(0x0777-0x3009)"},
{0x168C, 0x001B, 0x1154, 0x034E, "WLI-CB-AG108HP 802.11abg Wireless CardBus Adapter(0x1154-0x034E)"},
{0x168C, 0x001B, 0x1186, 0x3A19, "D-Link AirPremier AG DWL-AG660 Wireless Cardbus Adapter(0x1186-0x3A19)"},
{0x168C, 0x001B, 0x1186, 0x3A22, "AirPremier AG DWL-AG530 Wireless PCI Adapter (rev.B)(0x1186-0x3A22)"},
{0x168C, 0x001B, 0x11AD, 0x5001, "WN5301A 802.11bg Wireless PCI Adapter(0x11AD-0x5001)"},
{0x168C, 0x001B, 0x1458, 0xE901, "GN-WI01HT Wireless a/b/g MiniPCI Adapter(0x1458-0xE901)"},
{0x168C, 0x001B, 0x168C, 0x001B, "Wireless LAN PCI LiteOn(0x168C-0x001B)"},
{0x168C, 0x001B, 0x168C, 0x1062, "IPN-W100CB 802.11abg Wireless CardBus Adapter(0x168C-0x1062)"},
{0x168C, 0x001B, 0x168C, 0x2062, "EnGenius EMP-8602 (400mw) or Compex WLM54AG (SuperAG)(0x168C-0x2062)"},
{0x168C, 0x001B, 0x168C, 0x2063, "EnGenius EMP-8602 (400mw) or Compex WLM54AG(0x168C-0x2063)"},
{0x168C, 0x001B, 0x17F9, 0x000B, "WL-711A 802.11abg Wireless CardBus Adapter(0x17F9-0x000B)"},
{0x168C, 0x001B, 0x17F9, 0x000C, "WPIA-112AG 802.11abg Wireless PCI Adapter(0x17F9-0x000C)"},
{0x168C, 0x001B, 0x17F9, 0x000D, "PC-686X 802.11abg Wireless Mini PCI Adapter(0x17F9-0x000D)"},
{0x168C, 0x001B, 0x185F, 0x1600, "DCMA-82 High Power WLAN 802.11a/b/g mini-PCI Module (Super A/G, eXtended Range, 400mW)(0x185F-0x1600)"},
{0x168C, 0x001B, 0x1948, 0x3ABA, "RBTBJ-AW 802.11abg Wireless Cardbus Adapter(0x1948-0x3ABA)"},
{0x168C, 0x001B, 0xA727, 0x6804, "Wireless 11a/b/g PC Card with XJACK(r) Antenna(0xA727-0x6804)"},
{0x168C, 0x001C, 0xFFFF, 0xFFFF, "AR242x / AR542x Wireless Network Adapter (PCI-Express)(0x001C)"},
{0x168C, 0x001C, 0x0777, 0x3006, "SRX 802.11abg Wireless ExpressCard Adapter(0x0777-0x3006)"},
{0x168C, 0x001C, 0x103C, 0x137A, "AR5BXB63 (Foxconn) 802.11bg Mini PCIe NIC(0x103C-0x137A)"},
{0x168C, 0x001C, 0x106B, 0x0086, "AirPort Extreme(0x106B-0x0086)"},
{0x168C, 0x001C, 0x144F, 0x7106, "WLL3140 (Toshiba PA3501U-1MPC) 802.11bg Wireless Mini PCIe Card(0x144F-0x7106)"},
{0x168C, 0x001C, 0x144F, 0x7128, "WLL3141 (Toshiba PA3613U-1MPC) 802.11bg Wireless Mini PCIe Card(0x144F-0x7128)"},
{0x168C, 0x001C, 0x1468, 0x0428, "AR5BXB63 802.11bg NIC(0x1468-0x0428)"},
{0x168C, 0x001C, 0x1468, 0x042A, "AR5007EG 802.11bg NIC(0x1468-0x042A)"},
{0x168C, 0x001C, 0x147B, 0x1033, "AirPace Wi-Fi(0x147B-0x1033)"},
{0x168C, 0x001C, 0x168C, 0x001C, "AR242x 802.11abg NIC (PCI Express)(0x168C-0x001C)"},
{0x168C, 0x001C, 0x168C, 0x3061, "AR5006EGS 802.11bg NIC (2.4GHz, PCI Express)(0x168C-0x3061)"},
{0x168C, 0x001C, 0x168C, 0x3062, "AR5006EXS 802.11abg NIC (2.4/5.0GHz, PCI Express)(0x168C-0x3062)"},
{0x168C, 0x001C, 0x168C, 0x3063, "AR5006EX 802.11abg NIC (2.4/5.0GHz, PCI Express)(0x168C-0x3063)"},
{0x168C, 0x001C, 0x168C, 0x3065, "AR5006EG 802.11bg NIC (2.4GHz, PCI Express)(0x168C-0x3065)"},
{0x168C, 0x001C, 0x168C, 0x3067, "AR242x 802.11abg Wireless PCI Express Adapter (rev 01)(0x168C-0x3067)"},
{0x168C, 0x001C, 0x1A3B, 0x1026, "AW-GE780 802.11bg Wireless Mini PCIe Card(0x1A3B-0x1026)"},
{0x168C, 0x001D, 0xFFFF, 0xFFFF, "AR2417 Wireless Network Adapter [AR5007G 802.11bg](0x001D)"},
{0x168C, 0x001D, 0x1799, 0x720B, "F5D7000 v8000 Wireless G Desktop Card(0x1799-0x720B)"},
{0x168C, 0x001D, 0x1799, 0x721B, "F5D7010 v8000 Wireless G Notebook Card(0x1799-0x721B)"},
{0x168C, 0x0020, 0xFFFF, 0xFFFF, "AR5513 802.11abg Wireless NIC(0x0020)"},
{0x168C, 0x0020, 0x0308, 0x3407, "M-102 802.11g Wireless Cardbus Adapter(0x0308-0x3407)"},
{0x168C, 0x0020, 0x1186, 0x3A67, "DWL-G650M Super G MIMO Wireless Notebook Adapter(0x1186-0x3A67)"},
{0x168C, 0x0020, 0x1186, 0x3A68, "DWL-G520M Wireless 108G MIMO Desktop Adapter(0x1186-0x3A68)"},
{0x168C, 0x0020, 0x187E, 0x340E, "M-302 802.11g Wireless PCI Adapter(0x187E-0x340E)"},
{0x168C, 0x0020, 0x1976, 0x2003, "TEW-601PC 802.11g Wireless CardBus Adapter(0x1976-0x2003)"},
{0x168C, 0x0023, 0xFFFF, 0xFFFF, "AR5416 Wireless Network Adapter [AR5008 802.11(a)bgn](0x0023)"},
{0x168C, 0x0023, 0x0308, 0x340B, "NWD-170N 802.11bgn Wireless CardBus Adapter(0x0308-0x340B)"},
{0x168C, 0x0023, 0x1154, 0x0365, "Buffalo WLP-CB-AG300 802.11abgn Cardbus Adapter(0x1154-0x0365)"},
{0x168C, 0x0023, 0x1154, 0x0367, "WLI-CB-AG301N 802.11abgn Wireless CardBus Adapter(0x1154-0x0367)"},
{0x168C, 0x0023, 0x1186, 0x3A6A, "DWA-642 802.11n RangeBooster N CardBus Adapter(0x1186-0x3A6A)"},
{0x168C, 0x0023, 0x1186, 0x3A6B, "DWA-547 802.11n RangeBooster N 650 DeskTop Adapter(0x1186-0x3A6B)"},
{0x168C, 0x0023, 0x1186, 0x3A6D, "DWA-552 802.11n Xtreme N Desktop Adapter (rev A1)(0x1186-0x3A6D)"},
{0x168C, 0x0023, 0x1186, 0x3A76, "DWA-645 802.11n RangeBooster N 650 Notebook Adapter (rev A1)(0x1186-0x3A76)"},
{0x168C, 0x0023, 0x1737, 0x0059, "WPC300N v2 Wireless-N Notebook Adapter(0x1737-0x0059)"},
{0x168C, 0x0023, 0x1737, 0x0069, "WPC100 v1 802.11n RangePlus Wireless Notebook Adapter(0x1737-0x0069)"},
{0x168C, 0x0023, 0x1737, 0x0072, "WMP110 v1 802.11n RangePlus Wireless PCI Adapter(0x1737-0x0072)"},
{0x168C, 0x0023, 0x1799, 0x8011, "F5D8011 v1 802.11n N1 Wireless Notebook Card(0x1799-0x8011)"},
{0x168C, 0x0023, 0x187E, 0x3411, "NWD-370N 802.11n Wireless PCI Adapter(0x187E-0x3411)"},
{0x168C, 0x0023, 0x1976, 0x2008, "TEW-621PC 802.11bgn Wireless CardBus Adapter(0x1976-0x2008)"},
{0x168C, 0x0024, 0xFFFF, 0xFFFF, "AR5418 Wireless Network Adapter [AR5008E 802.11(a)bgn] (PCI-Express)(0x0024)"},
{0x168C, 0x0024, 0x106B, 0x0087, "AirPort Extreme(0x106B-0x0087)"},
{0x168C, 0x0024, 0x1186, 0x3A70, "DWA-556 Xtreme N PCI Express Desktop Adapter(0x1186-0x3A70)"},
{0x168C, 0x0027, 0xFFFF, 0xFFFF, "AR9160 Wireless Network Adapter [AR9001 802.11(a)bgn](0x0027)"},
{0x168C, 0x0027, 0x0777, 0x4082, "SR71-A 802.11abgn Wireless Mini PCI Adapter(0x0777-0x4082)"},
{0x168C, 0x0029, 0xFFFF, 0xFFFF, "AR922X Wireless Network Adapter(0x0029)"},
{0x168C, 0x0029, 0x0777, 0x4005, "SR71-15 802.11an Mini PCI Adapter(0x0777-0x4005)"},
{0x168C, 0x0029, 0x1186, 0x3A7A, "DWA-552 802.11n Xtreme N Desktop Adapter (rev A2)(0x1186-0x3A7A)"},
{0x168C, 0x0029, 0x1186, 0x3A7D, "DWA-552 802.11n Xtreme N Desktop Adapter (rev A3)(0x1186-0x3A7D)"},
{0x168C, 0x0029, 0x168C, 0x0029, "AR922X Wireless Network Adapter(0x168C-0x0029)"},
{0x168C, 0x0029, 0x168C, 0x2096, "Compex WLM200NX / Wistron DNMA-92(0x168C-0x2096)"},
{0x168C, 0x002A, 0xFFFF, 0xFFFF, "AR928X Wireless Network Adapter (PCI-Express)(0x002A)"},
{0x168C, 0x002A, 0x0777, 0x4F05, "SR71-X 802.11abgn Wireless ExpressCard Adapter [AR9280](0x0777-0x4F05)"},
{0x168C, 0x002A, 0x103C, 0x3041, "AR5BHB92-H 802.11abgn Wireless Half-size Mini PCIe Card [AR9280](0x103C-0x3041)"},
{0x168C, 0x002A, 0x103C, 0x3042, "AzureWave AW-NE773 802.11abgn Wireless Half-size Mini PCIe Card [AR9280](0x103C-0x3042)"},
{0x168C, 0x002A, 0x105B, 0xE006, "T77H053.00 802.11bgn Wireless Mini PCIe Card [AR9281](0x105B-0xE006)"},
{0x168C, 0x002A, 0x105B, 0xE01F, "T77H047.31 802.11bgn Wireless Half-size Mini PCIe Card [AR9283](0x105B-0xE01F)"},
{0x168C, 0x002A, 0x106B, 0x008F, "AirPort Extreme(0x106B-0x008F)"},
{0x168C, 0x002A, 0x11AD, 0x6600, "WN6600A 802.11bgn Wireless Mini PCIe Card [AR9281](0x11AD-0x6600)"},
{0x168C, 0x002A, 0x144F, 0x7141, "WLL6080 802.11bgn Wireless Mini PCIe Card [AR9281](0x144F-0x7141)"},
{0x168C, 0x002A, 0x168C, 0x0203, "DW1525 802.11abgn WLAN PCIe Card [AR9280](0x168C-0x0203)"},
{0x168C, 0x002A, 0x1A32, 0x0303, "EM303 802.11bgn Wireless Mini PCIe Card [AR9281](0x1A32-0x0303)"},
{0x168C, 0x002A, 0x1A32, 0x0306, "EM306 802.11bgn Wireless Half-size Mini PCIe Card [AR9283](0x1A32-0x0306)"},
{0x168C, 0x002A, 0x1A3B, 0x1067, "AW-NE771 802.11bgn Wireless Mini PCIe Card [AR9281](0x1A3B-0x1067)"},
{0x168C, 0x002A, 0x1A3B, 0x1071, "AW-NE772 802.11abgn Wireless Mini PCIe Card [AR9280](0x1A3B-0x1071)"},
{0x168C, 0x002A, 0x1A3B, 0x1081, "AW-NE773 802.11abgn Wireless Half-size Mini PCIe Card [AR9280](0x1A3B-0x1081)"},
{0x168C, 0x002B, 0xFFFF, 0xFFFF, "AR9285 Wireless Network Adapter (PCI-Express)(0x002B)"},
{0x168C, 0x002B, 0x1028, 0x0204, "Wireless 1502 802.11bgn Half-size Mini PCIe Card(0x1028-0x0204)"},
{0x168C, 0x002B, 0x1028, 0x0205, "Wireless 1702 802.11bgn Half-size Mini PCIe Card [AR9002WB-1NGCD](0x1028-0x0205)"},
{0x168C, 0x002B, 0x103C, 0x303F, "U98Z062.10 802.11bgn Wireless Half-size Mini PCIe Card(0x103C-0x303F)"},
{0x168C, 0x002B, 0x103C, 0x3040, "U98Z062.12 802.11bgn Wireless Half-size Mini PCIe Card(0x103C-0x3040)"},
{0x168C, 0x002B, 0x105B, 0xE017, "T77H126.00 802.11bgn Wireless Half-size Mini PCIe Card(0x105B-0xE017)"},
{0x168C, 0x002B, 0x105B, 0xE023, "T77H121.04 802.11bgn Wireless Half-size Mini PCIe Card(0x105B-0xE023)"},
{0x168C, 0x002B, 0x105B, 0xE025, "T77H121.05 802.11bgn Wireless Half-size Mini PCIe Card(0x105B-0xE025)"},
{0x168C, 0x002B, 0x1113, 0xE811, "WN7811A (Toshiba PA3722U-1MPC) 802.11bgn Wireless Half-size Mini PCIe Card(0x1113-0xE811)"},
{0x168C, 0x002B, 0x185F, 0x30AF, "DNXA-95 802.11bgn Wireless Half-size Mini PCIe Card(0x185F-0x30AF)"},
{0x168C, 0x002B, 0x1931, 0x0023, "Option GTM67x PCIe WiFi Adapter(0x1931-0x0023)"},
{0x168C, 0x002B, 0x1A3B, 0x1089, "AW-NE785 / AW-NE785H 802.11bgn Wireless Full or Half-size Mini PCIe Card(0x1A3B-0x1089)"},
{0x168C, 0x002B, 0x1A3B, 0x2C37, "AW-NB037H 802.11bgn Wireless Half-size Mini PCIe Card [AR9002WB-1NGCD](0x1A3B-0x2C37)"},
{0x168C, 0x002B, 0x1B9A, 0x0401, "XW204E 802.11bgn Wireless Half-size Mini PCIe Card(0x1B9A-0x0401)"},
{0x168C, 0x002B, 0x1B9A, 0x0C03, "WB214E 802.11bgn Wireless Half-size Mini PCIe Card [AR9002WB-1NGCD](0x1B9A-0x0C03)"},
{0x168C, 0x002C, 0xFFFF, 0xFFFF, "AR2427 802.11bg Wireless Network Adapter (PCI-Express)(0x002C)"},
{0x168C, 0x002D, 0xFFFF, 0xFFFF, "AR9227 Wireless Network Adapter(0x002D)"},
{0x168C, 0x002E, 0xFFFF, 0xFFFF, "AR9287 Wireless Network Adapter (PCI-Express)(0x002E)"},
{0x168C, 0x002E, 0x105B, 0xE034, "T77H167.00(0x105B-0xE034)"},
{0x168C, 0x0030, 0xFFFF, 0xFFFF, "AR93xx Wireless Network Adapter(0x0030)"},
{0x168C, 0x0030, 0x103C, 0x1627, "AR9380/HB112 802.11abgn 3x3 Wi-Fi Adapter(0x103C-0x1627)"},
{0x168C, 0x0030, 0x106B, 0x009A, "AirPort Extreme(0x106B-0x009A)"},
{0x168C, 0x0030, 0x1186, 0x3A7E, "DWA-566 Wireless N 300 Dual Band PCIe Desktop Adapter(0x1186-0x3A7E)"},
{0x168C, 0x0030, 0x1A56, 0x2000, "Killer Wireless-N 1102 Half-size Mini PCIe Card [AR9382](0x1A56-0x2000)"},
{0x168C, 0x0030, 0x1A56, 0x2001, "Killer Wireless-N 1103 Half-size Mini PCIe Card [AR9380](0x1A56-0x2001)"},
{0x168C, 0x0032, 0xFFFF, 0xFFFF, "AR9485 Wireless Network Adapter(0x0032)"},
{0x168C, 0x0032, 0x1028, 0x0208, "Wireless 1506 WLAN Half Mini-Card(0x1028-0x0208)"},
{0x168C, 0x0032, 0x103C, 0x1838, "AR9485/HB125 802.11bgn 1x1 Wi-Fi Adapter(0x103C-0x1838)"},
{0x168C, 0x0032, 0x105B, 0xE044, "Unex DHXA-225(0x105B-0xE044)"},
{0x168C, 0x0032, 0x144D, 0x410E, "AR9485WB-EG 802.11b/g/n mini-PCIe card on a series 3 laptop(0x144D-0x410E)"},
{0x168C, 0x0032, 0x1A3B, 0x1186, "AW-NE186H(0x1A3B-0x1186)"},
{0x168C, 0x0033, 0xFFFF, 0xFFFF, "AR958x 802.11abgn Wireless Network Adapter(0x0033)"},
{0x168C, 0x0033, 0x168C, 0xA120, "AR9582 802.11a/n WLAN Mini-PCIe Adapter(0x168C-0xA120)"},
{0x168C, 0x0034, 0xFFFF, 0xFFFF, "AR9462 Wireless Network Adapter(0x0034)"},
{0x168C, 0x0034, 0x1028, 0x020B, "Wireless 1601 802.11abgn Adapter(0x1028-0x020B)"},
{0x168C, 0x0034, 0x1028, 0x0300, "Wireless 1802 802.11abgn Adapter(0x1028-0x0300)"},
{0x168C, 0x0034, 0x1A56, 0x2003, "Killer Wireless-N 1202 Half-size Mini PCIe Card(0x1A56-0x2003)"},
{0x168C, 0x0036, 0xFFFF, 0xFFFF, "QCA9565 / AR9565 Wireless Network Adapter(0x0036)"},
{0x168C, 0x0036, 0x1028, 0x020E, "Vostro 3470(0x1028-0x020E)"},
{0x168C, 0x0037, 0xFFFF, 0xFFFF, "AR9485 Wireless Network Adapter(0x0037)"},
{0x168C, 0x0037, 0x1A3B, 0x2100, "AW-NB100H 802.11n Wireless Mini PCIe Card(0x1A3B-0x2100)"},
{0x168C, 0x003C, 0xFFFF, 0xFFFF, "QCA986x/988x 802.11ac Wireless Network Adapter(0x003C)"},
{0x168C, 0x003E, 0xFFFF, 0xFFFF, "QCA6174 802.11ac Wireless Network Adapter(0x003E)"},
{0x168C, 0x003E, 0x1A56, 0x143A, "Killer 1435 Wireless-AC(0x1A56-0x143A)"},
{0x168C, 0x003E, 0x1A56, 0x1525, "Killer N1525 Wireless-AC(0x1A56-0x1525)"},
{0x168C, 0x003E, 0x1A56, 0x1535, "Killer Wireless-n/a/ac 1535 Wireless Network Adapter(0x1A56-0x1535)"},
{0x168C, 0x0040, 0xFFFF, 0xFFFF, "QCA9980/9990 802.11ac Wireless Network Adapter(0x0040)"},
{0x168C, 0x0041, 0xFFFF, 0xFFFF, "QCA6164 802.11ac Wireless Network Adapter(0x0041)"},
{0x168C, 0x0042, 0xFFFF, 0xFFFF, "QCA9377 802.11ac Wireless Network Adapter(0x0042)"},
{0x168C, 0x0042, 0x11AD, 0x08A6, "Qualcomm Atheros QCA9377 802.11ac Wireless Network Adapter(0x11AD-0x08A6)"},
{0x168C, 0x0042, 0x17AA, 0x0901, "Qualcomm Atheros QCA9377 Wireless Network Adapter(0x17AA-0x0901)"},
{0x168C, 0x0046, 0xFFFF, 0xFFFF, "QCA9984 802.11ac Wave 2 Wireless Network Adapter(0x0046)"},
{0x168C, 0x0050, 0xFFFF, 0xFFFF, "QCA9887 802.11ac Wireless Network Adapter(0x0050)"},
{0x168C, 0x0207, 0xFFFF, 0xFFFF, "AR5210 Wireless Network Adapter [AR5000 802.11a](0x0207)"},
{0x168C, 0x1014, 0xFFFF, 0xFFFF, "AR5212 802.11abg NIC(0x1014)"},
{0x168C, 0x1014, 0x1014, 0x058A, "ThinkPad 11a/b/g Wireless LAN Mini Express Adapter (AR5BXB6)(0x1014-0x058A)"},
{0x168C, 0x9013, 0xFFFF, 0xFFFF, "AR5002X Wireless Network Adapter(0x9013)"},
{0x168C, 0xFF19, 0xFFFF, 0xFFFF, "AR5006X Wireless Network Adapter(0xFF19)"},
{0x168C, 0xFF1B, 0xFFFF, 0xFFFF, "AR2425 Wireless Network Adapter [AR5007EG 802.11bg](0xFF1B)"},
{0x168C, 0xFF1C, 0xFFFF, 0xFFFF, "AR5008 Wireless Network Adapter(0xFF1C)"},
{0x168C, 0xFF1D, 0xFFFF, 0xFFFF, "AR922x Wireless Network Adapter(0xFF1D)"},
{0x168C, 0xFF1D, 0x168C, 0xEE1C, "AR9220-AC1A [AVM Fritz!Box FON WLAN 7270 v3](0x168C-0xEE1C)"},
}; /* pci_vid_168C[] */

static pci_id_t const pci_vid_1695[] = {
{0x1695, 0xFFFF, 0xFFFF, 0xFFFF, "EPoX Computer Co., Ltd.(0x1695)"},
}; /* pci_vid_1695[] */

static pci_id_t const pci_vid_169C[] = {
{0x169C, 0xFFFF, 0xFFFF, 0xFFFF, "Netcell Corporation(0x169C)"},
{0x169C, 0x0044, 0xFFFF, 0xFFFF, "Revolution Storage Processing Card(0x0044)"},
}; /* pci_vid_169C[] */

static pci_id_t const pci_vid_169D[] = {
{0x169D, 0xFFFF, 0xFFFF, 0xFFFF, "Club-3D VB (Wrong ID)(0x169D)"},
}; /* pci_vid_169D[] */

static pci_id_t const pci_vid_16A5[] = {
{0x16A5, 0xFFFF, 0xFFFF, 0xFFFF, "Tekram Technology Co.,Ltd.(0x16A5)"},
}; /* pci_vid_16A5[] */

static pci_id_t const pci_vid_16AB[] = {
{0x16AB, 0xFFFF, 0xFFFF, 0xFFFF, "Global Sun Technology Inc(0x16AB)"},
{0x16AB, 0x1100, 0xFFFF, 0xFFFF, "GL24110P(0x1100)"},
{0x16AB, 0x1101, 0xFFFF, 0xFFFF, "PLX9052 PCMCIA-to-PCI Wireless LAN(0x1101)"},
{0x16AB, 0x1102, 0xFFFF, 0xFFFF, "PCMCIA-to-PCI Wireless Network Bridge(0x1102)"},
{0x16AB, 0x8501, 0xFFFF, 0xFFFF, "WL-8305 Wireless LAN PCI Adapter(0x8501)"},
}; /* pci_vid_16AB[] */

static pci_id_t const pci_vid_16AE[] = {
{0x16AE, 0xFFFF, 0xFFFF, 0xFFFF, "SafeNet Inc(0x16AE)"},
{0x16AE, 0x0001, 0xFFFF, 0xFFFF, "SafeXcel 1140(0x0001)"},
{0x16AE, 0x000A, 0xFFFF, 0xFFFF, "SafeXcel 1841(0x000A)"},
{0x16AE, 0x1141, 0xFFFF, 0xFFFF, "SafeXcel 1141(0x1141)"},
{0x16AE, 0x1141, 0x0001, 0x0001, "SafeXcel 1141 v. 1.1(0x0001-0x0001)"},
{0x16AE, 0x1841, 0xFFFF, 0xFFFF, "SafeXcel 1842(0x1841)"},
}; /* pci_vid_16AE[] */

static pci_id_t const pci_vid_16AF[] = {
{0x16AF, 0xFFFF, 0xFFFF, 0xFFFF, "SparkLAN Communications, Inc.(0x16AF)"},
}; /* pci_vid_16AF[] */

static pci_id_t const pci_vid_16B4[] = {
{0x16B4, 0xFFFF, 0xFFFF, 0xFFFF, "Aspex Semiconductor Ltd(0x16B4)"},
}; /* pci_vid_16B4[] */

static pci_id_t const pci_vid_16B8[] = {
{0x16B8, 0xFFFF, 0xFFFF, 0xFFFF, "Sonnet Technologies, Inc.(0x16B8)"},
}; /* pci_vid_16B8[] */

static pci_id_t const pci_vid_16BE[] = {
{0x16BE, 0xFFFF, 0xFFFF, 0xFFFF, "Creatix Polymedia GmbH(0x16BE)"},
}; /* pci_vid_16BE[] */

static pci_id_t const pci_vid_16C3[] = {
{0x16C3, 0xFFFF, 0xFFFF, 0xFFFF, "Synopsys, Inc.(0x16C3)"},
{0x16C3, 0xABCD, 0xFFFF, 0xFFFF, "DWC_usb3 / PCIe bridge(0xABCD)"},
{0x16C3, 0xABCE, 0xFFFF, 0xFFFF, "DWC_usb3(0xABCE)"},
{0x16C3, 0xABCF, 0xFFFF, 0xFFFF, "DWC_usb31(0xABCF)"},
{0x16C3, 0xEDDA, 0xFFFF, 0xFFFF, "EPMockUp(0xEDDA)"},
}; /* pci_vid_16C3[] */

static pci_id_t const pci_vid_16C6[] = {
{0x16C6, 0xFFFF, 0xFFFF, 0xFFFF, "Micrel-Kendin(0x16C6)"},
{0x16C6, 0x8695, 0xFFFF, 0xFFFF, "Centaur KS8695 ARM processor(0x8695)"},
{0x16C6, 0x8842, 0xFFFF, 0xFFFF, "KSZ8842-PMQL 2-Port Ethernet Switch(0x8842)"},
}; /* pci_vid_16C6[] */

static pci_id_t const pci_vid_16C8[] = {
{0x16C8, 0xFFFF, 0xFFFF, 0xFFFF, "Octasic Inc.(0x16C8)"},
}; /* pci_vid_16C8[] */

static pci_id_t const pci_vid_16C9[] = {
{0x16C9, 0xFFFF, 0xFFFF, 0xFFFF, "EONIC B.V. The Netherlands(0x16C9)"},
}; /* pci_vid_16C9[] */

static pci_id_t const pci_vid_16CA[] = {
{0x16CA, 0xFFFF, 0xFFFF, 0xFFFF, "CENATEK Inc(0x16CA)"},
{0x16CA, 0x0001, 0xFFFF, 0xFFFF, "Rocket Drive DL(0x0001)"},
}; /* pci_vid_16CA[] */

static pci_id_t const pci_vid_16CD[] = {
{0x16CD, 0xFFFF, 0xFFFF, 0xFFFF, "Advantech Co. Ltd(0x16CD)"},
{0x16CD, 0x0101, 0xFFFF, 0xFFFF, "DirectPCI SRAM for DPX-11x series(0x0101)"},
{0x16CD, 0x0102, 0xFFFF, 0xFFFF, "DirectPCI SRAM for DPX-S/C/E-series(0x0102)"},
{0x16CD, 0x0103, 0xFFFF, 0xFFFF, "DirectPCI ROM for DPX-11x series(0x0103)"},
{0x16CD, 0x0104, 0xFFFF, 0xFFFF, "DirectPCI ROM for DPX-S/C/E-series(0x0104)"},
{0x16CD, 0x0105, 0xFFFF, 0xFFFF, "DirectPCI I/O for DPX-114/DPX-115(0x0105)"},
{0x16CD, 0x0106, 0xFFFF, 0xFFFF, "DirectPCI I/O for DPX-116(0x0106)"},
{0x16CD, 0x0107, 0xFFFF, 0xFFFF, "DirectPCI I/O for DPX-116U(0x0107)"},
{0x16CD, 0x0108, 0xFFFF, 0xFFFF, "DirectPCI I/O for DPX-117(0x0108)"},
{0x16CD, 0x0109, 0xFFFF, 0xFFFF, "DirectPCI I/O for DPX-112(0x0109)"},
{0x16CD, 0x010A, 0xFFFF, 0xFFFF, "DirectPCI I/O for DPX-C/E-series(0x010A)"},
{0x16CD, 0x010B, 0xFFFF, 0xFFFF, "DirectPCI I/O for DPX-S series(0x010B)"},
}; /* pci_vid_16CD[] */

static pci_id_t const pci_vid_16CE[] = {
{0x16CE, 0xFFFF, 0xFFFF, 0xFFFF, "Roland Corp.(0x16CE)"},
}; /* pci_vid_16CE[] */

static pci_id_t const pci_vid_16D5[] = {
{0x16D5, 0xFFFF, 0xFFFF, 0xFFFF, "Acromag, Inc.(0x16D5)"},
{0x16D5, 0x0504, 0xFFFF, 0xFFFF, "PMC-DX504 Reconfigurable FPGA with LVDS I/O(0x0504)"},
{0x16D5, 0x0520, 0xFFFF, 0xFFFF, "PMC520 Serial Communication, 232 Octal(0x0520)"},
{0x16D5, 0x0521, 0xFFFF, 0xFFFF, "PMC521 Serial Communication, 422/485 Octal(0x0521)"},
{0x16D5, 0x1020, 0xFFFF, 0xFFFF, "PMC-AX1020 Reconfigurable FPGA with A/D & D/A(0x1020)"},
{0x16D5, 0x1065, 0xFFFF, 0xFFFF, "PMC-AX1065 Reconfigurable FPGA with A/D & D/A(0x1065)"},
{0x16D5, 0x2004, 0xFFFF, 0xFFFF, "PMC-DX2004 Reconfigurable FPGA with LVDS I/O(0x2004)"},
{0x16D5, 0x2020, 0xFFFF, 0xFFFF, "PMC-AX2020 Reconfigurable FPGA with A/D & D/A(0x2020)"},
{0x16D5, 0x2065, 0xFFFF, 0xFFFF, "PMC-AX2065 Reconfigurable FPGA with A/D & D/A(0x2065)"},
{0x16D5, 0x3020, 0xFFFF, 0xFFFF, "PMC-AX3020 Reconfigurable FPGA with A/D & D/A(0x3020)"},
{0x16D5, 0x3065, 0xFFFF, 0xFFFF, "PMC-AX3065 Reconfigurable FPGA with A/D & D/A(0x3065)"},
{0x16D5, 0x4243, 0xFFFF, 0xFFFF, "PMC424, APC424, AcPC424 Digital I/O and Counter Timer Module(0x4243)"},
{0x16D5, 0x4248, 0xFFFF, 0xFFFF, "PMC464, APC464, AcPC464 Digital I/O and Counter Timer Module(0x4248)"},
{0x16D5, 0x424B, 0xFFFF, 0xFFFF, "PMC-DX2002 Reconfigurable FPGA with Differential I/O(0x424B)"},
{0x16D5, 0x4253, 0xFFFF, 0xFFFF, "PMC-DX503 Reconfigurable FPGA with TTL and Differential I/O(0x4253)"},
{0x16D5, 0x4312, 0xFFFF, 0xFFFF, "PMC-CX1002 Reconfigurable Conduction-Cooled FPGA Virtex-II with Differential I/O(0x4312)"},
{0x16D5, 0x4313, 0xFFFF, 0xFFFF, "PMC-CX1003 Reconfigurable Conduction-Cooled FPGA Virtex-II with CMOS and Differential I/O(0x4313)"},
{0x16D5, 0x4322, 0xFFFF, 0xFFFF, "PMC-CX2002 Reconfigurable Conduction-Cooled FPGA Virtex-II with Differential I/O(0x4322)"},
{0x16D5, 0x4323, 0xFFFF, 0xFFFF, "PMC-CX2003 Reconfigurable Conduction-Cooled FPGA Virtex-II with CMOS and Differential I/O(0x4323)"},
{0x16D5, 0x4350, 0xFFFF, 0xFFFF, "PMC-DX501 Reconfigurable Digital I/O Module(0x4350)"},
{0x16D5, 0x4353, 0xFFFF, 0xFFFF, "PMC-DX2003 Reconfigurable FPGA with TTL and Differential I/O(0x4353)"},
{0x16D5, 0x4357, 0xFFFF, 0xFFFF, "PMC-DX502 Reconfigurable Differential I/O Module(0x4357)"},
{0x16D5, 0x4457, 0xFFFF, 0xFFFF, "PMC730, APC730, AcPC730 Multifunction Module(0x4457)"},
{0x16D5, 0x4471, 0xFFFF, 0xFFFF, "XMC730 Multi-function I/O module with front I/O(0x4471)"},
{0x16D5, 0x4473, 0xFFFF, 0xFFFF, "XMC730CC Multi-function I/O module with rear I/O Conduction-cooled(0x4473)"},
{0x16D5, 0x464D, 0xFFFF, 0xFFFF, "PMC408 32-Channel Digital Input/Output Module(0x464D)"},
{0x16D5, 0x4850, 0xFFFF, 0xFFFF, "PMC220-16 12-Bit Analog Output Module(0x4850)"},
{0x16D5, 0x4A42, 0xFFFF, 0xFFFF, "PMC483, APC483, AcPC483 Counter Timer Module(0x4A42)"},
{0x16D5, 0x4A50, 0xFFFF, 0xFFFF, "PMC484, APC484, AcPC484 Counter Timer Module(0x4A50)"},
{0x16D5, 0x4A56, 0xFFFF, 0xFFFF, "PMC230 16-Bit Analog Output Module(0x4A56)"},
{0x16D5, 0x4B47, 0xFFFF, 0xFFFF, "PMC330, APC330, AcPC330 Analog Input Module, 16-bit A/D(0x4B47)"},
{0x16D5, 0x4C40, 0xFFFF, 0xFFFF, "PMC-LX40 Reconfigurable Virtex-4 FPGA with plug-in I/O(0x4C40)"},
{0x16D5, 0x4C60, 0xFFFF, 0xFFFF, "PMC-LX60 Reconfigurable Virtex-4 FPGA with plug-in I/O(0x4C60)"},
{0x16D5, 0x4D4D, 0xFFFF, 0xFFFF, "PMC341, APC341, AcPC341 Analog Input Module, Simultaneous Sample & Hold(0x4D4D)"},
{0x16D5, 0x4D4E, 0xFFFF, 0xFFFF, "PMC482, APC482, AcPC482 Counter Timer Board(0x4D4E)"},
{0x16D5, 0x524D, 0xFFFF, 0xFFFF, "PMC-DX2001 Reconfigurable FPGA with TTL I/O(0x524D)"},
{0x16D5, 0x5335, 0xFFFF, 0xFFFF, "PMC-SX35 Reconfigurable Virtex-4 FPGA with plug-in I/O(0x5335)"},
{0x16D5, 0x5456, 0xFFFF, 0xFFFF, "PMC470 48-Channel Digital Input/Output Module(0x5456)"},
{0x16D5, 0x5601, 0xFFFF, 0xFFFF, "PMC-VLX85 Reconfigurable Virtex-5 FPGA with plug-in I/O(0x5601)"},
{0x16D5, 0x5602, 0xFFFF, 0xFFFF, "PMC-VLX110 Reconfigurable Virtex-5 FPGA with plug-in I/O(0x5602)"},
{0x16D5, 0x5603, 0xFFFF, 0xFFFF, "PMC-VSX95 Reconfigurable Virtex-5 FPGA with plug-in I/O(0x5603)"},
{0x16D5, 0x5604, 0xFFFF, 0xFFFF, "PMC-VLX155 Reconfigurable Virtex-5 FPGA with plug-in I/O(0x5604)"},
{0x16D5, 0x5605, 0xFFFF, 0xFFFF, "PMC-VFX70 Reconfigurable Virtex-5 FPGA with plug-in I/O(0x5605)"},
{0x16D5, 0x5606, 0xFFFF, 0xFFFF, "PMC-VLX155-1M Reconfigurable Virtex-5 FPGA with plug-in I/O(0x5606)"},
{0x16D5, 0x5701, 0xFFFF, 0xFFFF, "PMC-SLX150: Reconfigurable Spartan-6 FPGA with plug-in I/O(0x5701)"},
{0x16D5, 0x5702, 0xFFFF, 0xFFFF, "PMC-SLX150-1M: Reconfigurable Spartan-6 FPGA with plug-in I/O(0x5702)"},
{0x16D5, 0x5801, 0xFFFF, 0xFFFF, "XMC-VLX85 Reconfigurable Virtex-5 FPGA with plug-in I/O(0x5801)"},
{0x16D5, 0x5802, 0xFFFF, 0xFFFF, "XMC-VLX110 Reconfigurable Virtex-5 FPGA with plug-in I/O(0x5802)"},
{0x16D5, 0x5803, 0xFFFF, 0xFFFF, "XMC-VSX95 Reconfigurable Virtex-5 FPGA with plug-in I/O(0x5803)"},
{0x16D5, 0x5804, 0xFFFF, 0xFFFF, "XMC-VLX155 Reconfigurable Virtex-5 FPGA with plug-in I/O(0x5804)"},
{0x16D5, 0x5807, 0xFFFF, 0xFFFF, "XMC-SLX150: Reconfigurable Spartan-6 FPGA with plug-in I/O(0x5807)"},
{0x16D5, 0x5808, 0xFFFF, 0xFFFF, "XMC-SLX150-1M: Reconfigurable Spartan-6 FPGA with plug-in I/O(0x5808)"},
{0x16D5, 0x5901, 0xFFFF, 0xFFFF, "APCe8650 PCI Express IndustryPack Carrier Card(0x5901)"},
{0x16D5, 0x6301, 0xFFFF, 0xFFFF, "XMC Module with user-configurable Virtex-6 FPGA, 240k logic cells, SFP front I/O(0x6301)"},
{0x16D5, 0x6302, 0xFFFF, 0xFFFF, "XMC Module with user-configurable Virtex-6 FPGA, 365k logic cells, SFP front I/O(0x6302)"},
{0x16D5, 0x6303, 0xFFFF, 0xFFFF, "XMC Module with user-configurable Virtex-6 FPGA, 240k logic cells, no front I/O(0x6303)"},
{0x16D5, 0x6304, 0xFFFF, 0xFFFF, "XMC Module with user-configurable Virtex-6 FPGA, 365k logic cells, no front I/O(0x6304)"},
{0x16D5, 0x7000, 0xFFFF, 0xFFFF, "XMC-7K325F: User-configurable Kintex-7 FPGA, 325k logic cells plus SFP front I/O(0x7000)"},
{0x16D5, 0x7001, 0xFFFF, 0xFFFF, "XMC-7K410F: User-configurable Kintex-7 FPGA, 410k logic cells plus SFP front I/O(0x7001)"},
{0x16D5, 0x7002, 0xFFFF, 0xFFFF, "XMC-7K325AX: User-Configurable Kintex-7 FPGA, 325k logic cells with AXM Plug-In I/O(0x7002)"},
{0x16D5, 0x7003, 0xFFFF, 0xFFFF, "XMC-7K410AX: User-Configurable Kintex-7 FPGA, 410k logic cells with AXM Plug-In I/O(0x7003)"},
{0x16D5, 0x7004, 0xFFFF, 0xFFFF, "XMC-7K325CC: User-Configurable Kintex-7 FPGA, 325k logic cells, conduction-cooled(0x7004)"},
{0x16D5, 0x7005, 0xFFFF, 0xFFFF, "XMC-7K410CC: User-Configurable Kintex-7 FPGA, 410k logic cells, conduction-cooled(0x7005)"},
{0x16D5, 0x7006, 0xFFFF, 0xFFFF, "XMC-7A200: User-Configurable Artix-7 FPGA, 200k logic cells with Plug-In I/O(0x7006)"},
{0x16D5, 0x7007, 0xFFFF, 0xFFFF, "XMC-7A200CC: User-Configurable Conduction-Cooled Artix-7 FPGA, with 200k logic cells(0x7007)"},
{0x16D5, 0x7011, 0xFFFF, 0xFFFF, "AP440-1: 32-Channel Isolated Digital Input Module(0x7011)"},
{0x16D5, 0x7012, 0xFFFF, 0xFFFF, "AP440-2: 32-Channel Isolated Digital Input Module(0x7012)"},
{0x16D5, 0x7013, 0xFFFF, 0xFFFF, "AP440-3: 32-Channel Isolated Digital Input Module(0x7013)"},
{0x16D5, 0x7014, 0xFFFF, 0xFFFF, "AP445: 32-Channel Isolated Digital Output Module(0x7014)"},
{0x16D5, 0x7015, 0xFFFF, 0xFFFF, "AP471 48-Channel TTL Level Digital Input/Output Module(0x7015)"},
{0x16D5, 0x7016, 0xFFFF, 0xFFFF, "AP470 48-Channel TTL Level Digital Input/Output Module(0x7016)"},
{0x16D5, 0x7017, 0xFFFF, 0xFFFF, "AP323 16-bit, 20 or 40 Channel Analog Input Module(0x7017)"},
{0x16D5, 0x7018, 0xFFFF, 0xFFFF, "AP408: 32-Channel Digital I/O Module(0x7018)"},
{0x16D5, 0x7019, 0xFFFF, 0xFFFF, "AP341 14-bit, 16-Channel Simultaneous Conversion Analog Input Module(0x7019)"},
{0x16D5, 0x701A, 0xFFFF, 0xFFFF, "AP220-16 12-Bit, 16-Channel Analog Output Module(0x701A)"},
{0x16D5, 0x701B, 0xFFFF, 0xFFFF, "AP231-16 16-Bit, 16-Channel Analog Output Module(0x701B)"},
{0x16D5, 0x701C, 0xFFFF, 0xFFFF, "AP225 12-Bit, 16-Channel Analog Output Module with Waveform Memory(0x701C)"},
{0x16D5, 0x701D, 0xFFFF, 0xFFFF, "AP235 16-Bit, 16-Channel Analog Output Module with Waveform Memory(0x701D)"},
{0x16D5, 0x7021, 0xFFFF, 0xFFFF, "APA7-201 Reconfigurable Artix-7 FPGA module 48 TTL channels(0x7021)"},
{0x16D5, 0x7022, 0xFFFF, 0xFFFF, "APA7-202 Reconfigurable Artix-7 FPGA module 24 RS485 channels(0x7022)"},
{0x16D5, 0x7023, 0xFFFF, 0xFFFF, "APA7-203 Reconfigurable Artix-7 FPGA module 24 TTL & 12 RS485 channels(0x7023)"},
{0x16D5, 0x7024, 0xFFFF, 0xFFFF, "APA7-204 Reconfigurable Artix-7 FPGA module 24 LVDS channels(0x7024)"},
{0x16D5, 0x7027, 0xFFFF, 0xFFFF, "AP418 16-Channel High Voltage Digital Input/Output Module(0x7027)"},
{0x16D5, 0x7029, 0xFFFF, 0xFFFF, "AP342 14-bit, 12-Channel Isolated Simultaneous Conversion Analog Input Module(0x7029)"},
{0x16D5, 0x702A, 0xFFFF, 0xFFFF, "AP226 12-Bit, 8-Channel Isolated Analog Output Module(0x702A)"},
{0x16D5, 0x702B, 0xFFFF, 0xFFFF, "AP236 16-Bit, 8-Channel Isolated Analog Output Module(0x702B)"},
{0x16D5, 0x702C, 0xFFFF, 0xFFFF, "AP560A Module 4 Independent isolated CAN bus channels(0x702C)"},
{0x16D5, 0x7031, 0xFFFF, 0xFFFF, "AP441-1: 32-Channel Isolated Digital Input Module(0x7031)"},
{0x16D5, 0x7032, 0xFFFF, 0xFFFF, "AP441-2: 32-Channel Isolated Digital Input Module(0x7032)"},
{0x16D5, 0x7033, 0xFFFF, 0xFFFF, "AP441-3: 32-Channel Isolated Digital Input Module(0x7033)"},
{0x16D5, 0x7042, 0xFFFF, 0xFFFF, "AP482 Counter Timer Module with TTL Level Input/Output(0x7042)"},
{0x16D5, 0x7043, 0xFFFF, 0xFFFF, "AP483 Counter Timer Module with TTL Level and RS422 Input/Output(0x7043)"},
{0x16D5, 0x7044, 0xFFFF, 0xFFFF, "AP484 Counter Timer Module with RS422 Input/Output(0x7044)"},
{0x16D5, 0x7051, 0xFFFF, 0xFFFF, "APA7-501 Reconfigurable Artix-7 52,160 Cell FPGA module 48 TTL channels(0x7051)"},
{0x16D5, 0x7052, 0xFFFF, 0xFFFF, "APA7-502 Reconfigurable Artix-7 52,160 Cell FPGA module 24 RS485 channels(0x7052)"},
{0x16D5, 0x7053, 0xFFFF, 0xFFFF, "APA7-503 Reconfigurable Artix-7 52,160 Cell FPGA module 24 TTL & 12 RS485 channels(0x7053)"},
{0x16D5, 0x7054, 0xFFFF, 0xFFFF, "APA7-504 Reconfigurable Artix-7 52,160 Cell FPGA module 24 LVDS channels(0x7054)"},
{0x16D5, 0x7072, 0xFFFF, 0xFFFF, "AP731 Multi-function I/O Module with 12-bit DAC(0x7072)"},
{0x16D5, 0x7073, 0xFFFF, 0xFFFF, "AP730 Multi-function I/O Module 16 Digital I/O 8 Differential Analog In 4 Analog Out(0x7073)"},
{0x16D5, 0x7731, 0xFFFF, 0xFFFF, "APZU-301 Zynq Ultrascale+ Module 28 TTL channels(0x7731)"},
{0x16D5, 0x7733, 0xFFFF, 0xFFFF, "APZU-303 Zynq Ultrascale+ Module 20 TTL & 3 RS485/422 channels(0x7733)"},
{0x16D5, 0x7734, 0xFFFF, 0xFFFF, "APZU-304 Zynq Ultrascale+ Module 14 LVDS channels(0x7734)"},
}; /* pci_vid_16D5[] */

static pci_id_t const pci_vid_16DA[] = {
{0x16DA, 0xFFFF, 0xFFFF, 0xFFFF, "Advantech Co., Ltd.(0x16DA)"},
{0x16DA, 0x0011, 0xFFFF, 0xFFFF, "INES GPIB-PCI(0x0011)"},
}; /* pci_vid_16DA[] */

static pci_id_t const pci_vid_16DF[] = {
{0x16DF, 0xFFFF, 0xFFFF, 0xFFFF, "PIKA Technologies Inc.(0x16DF)"},
}; /* pci_vid_16DF[] */

static pci_id_t const pci_vid_16E2[] = {
{0x16E2, 0xFFFF, 0xFFFF, 0xFFFF, "Marvin Test Solutions(0x16E2)"},
{0x16E2, 0x1034, 0xFFFF, 0xFFFF, "GX1034 Certification and Verification Module PXI Board(0x1034)"},
{0x16E2, 0x1100, 0xFFFF, 0xFFFF, "GX1100 Arbitrary Waveform and Function Generator PXI Board(0x1100)"},
{0x16E2, 0x1120, 0xFFFF, 0xFFFF, "GX1120 Arbitrary Waveform and Function Generator PXI Board(0x1120)"},
{0x16E2, 0x1164, 0xFFFF, 0xFFFF, "GX1164 Multi-Channel Programmable Resistor PXI Board(0x1164)"},
{0x16E2, 0x1632, 0xFFFF, 0xFFFF, "GX1632e 32-Channel Arbitrary Analog Output PXIe Board(0x1632)"},
{0x16E2, 0x1648, 0xFFFF, 0xFFFF, "GX1648 64-Channel Analog Output PXI Board(0x1648)"},
{0x16E2, 0x1649, 0xFFFF, 0xFFFF, "GX1649 64-Channel Arbitrary Analog Output PXI Board(0x1649)"},
{0x16E2, 0x1838, 0xFFFF, 0xFFFF, "GX1838 Precision DC Source PXI Board(0x1838)"},
{0x16E2, 0x2065, 0xFFFF, 0xFFFF, "GX2065 Digital Multimeter PXI Board(0x2065)"},
{0x16E2, 0x2200, 0xFFFF, 0xFFFF, "GTX2200 High Resolution Universal Time Interval Counter PXI Board(0x2200)"},
{0x16E2, 0x2201, 0xFFFF, 0xFFFF, "GC2200 High Resolution Universal Time Interval Counter PCI Board(0x2201)"},
{0x16E2, 0x3104, 0xFFFF, 0xFFFF, "GX3104 4-Channel 20V, 250mA Per Channel SMU PXI Board(0x3104)"},
{0x16E2, 0x3108, 0xFFFF, 0xFFFF, "GX3108 4-Channel Source Measure Unit PXI Board(0x3108)"},
{0x16E2, 0x3116, 0xFFFF, 0xFFFF, "GX3116e 16-Channel DUT Power Supply PXIe Board(0x3116)"},
{0x16E2, 0x3348, 0xFFFF, 0xFFFF, "GX3348 Multi-Channel DC Source and Switch Matrix Board(0x3348)"},
{0x16E2, 0x3500, 0xFFFF, 0xFFFF, "GX3500 Digital I/O FLEX FPGA Board(0x3500)"},
{0x16E2, 0x3700, 0xFFFF, 0xFFFF, "GX3700e Digital I/O FLEX FPGA PXIe Board(0x3700)"},
{0x16E2, 0x3701, 0xFFFF, 0xFFFF, "GX3700 Digital I/O FLEX FPGA PXI Board(0x3701)"},
{0x16E2, 0x3800, 0xFFFF, 0xFFFF, "GX3800e Digital I/O FLEX FPGA PXIe Board(0x3800)"},
{0x16E2, 0x4943, 0xFFFF, 0xFFFF, "GX4943 HellFire/Longbow Serial Communication Board(0x4943)"},
{0x16E2, 0x5050, 0xFFFF, 0xFFFF, "GC5050 Dynamic Digital I/O with Algorithmic Sequencer PCI Board(0x5050)"},
{0x16E2, 0x5055, 0xFFFF, 0xFFFF, "GX5055 Dynamic Digital I/O with Pin Electronics PXI Board(0x5055)"},
{0x16E2, 0x5083, 0xFFFF, 0xFFFF, "GX5083 Dynamic Digital I/O with Algorithmic Sequencer PXI Board(0x5083)"},
{0x16E2, 0x5105, 0xFFFF, 0xFFFF, "GX5105 High-Speed Digital I/O Timing (Master) Module PXI Board(0x5105)"},
{0x16E2, 0x5106, 0xFFFF, 0xFFFF, "GX5106 High-Speed Digital I/O Cycle Timing (Master) Module PXI Board(0x5106)"},
{0x16E2, 0x5151, 0xFFFF, 0xFFFF, "GX5150/1 High Speed Digital I/O (50/100MHz) PXI Board(0x5151)"},
{0x16E2, 0x5152, 0xFFFF, 0xFFFF, "GX5152/3 DSR High Speed Digital Stimulus/Response PXI Board(0x5152)"},
{0x16E2, 0x5250, 0xFFFF, 0xFFFF, "GX5250 Digital I/O Streaming PXI Board(0x5250)"},
{0x16E2, 0x5280, 0xFFFF, 0xFFFF, "GX5280 High-Speed Digital I/O PXI Board(0x5280)"},
{0x16E2, 0x5290, 0xFFFF, 0xFFFF, "GX5290 High-Speed Dynamic Digital I/O PXI Board(0x5290)"},
{0x16E2, 0x5294, 0xFFFF, 0xFFFF, "GX5294 High-Speed Digital I/O PXI Board(0x5294)"},
{0x16E2, 0x5295, 0xFFFF, 0xFFFF, "GX5295 Digital I/O with Pin Electronics and PMU PXI Board(0x5295)"},
{0x16E2, 0x5296, 0xFFFF, 0xFFFF, "GX5296 Digital I/O with Pin Electronics and PMU PXI Board(0x5296)"},
{0x16E2, 0x5550, 0xFFFF, 0xFFFF, "GX5050 Dynamic Digital I/O with Algorithmic Sequencer PXI Board(0x5550)"},
{0x16E2, 0x5641, 0xFFFF, 0xFFFF, "GX5641/2 Bi-directional Differential-TTL I/O PXI Board(0x5641)"},
{0x16E2, 0x5731, 0xFFFF, 0xFFFF, "GX5731 Digital I/O with 128 TTL Channels and 3x32 Customizable Channels PXI Board(0x5731)"},
{0x16E2, 0x5732, 0xFFFF, 0xFFFF, "GX5732 224-Channel Static Digital I/O PXI Board(0x5732)"},
{0x16E2, 0x5733, 0xFFFF, 0xFFFF, "GX5733 Digital I/O with 96 TTL Channels and 32 Customizable Channels PXI Board(0x5733)"},
{0x16E2, 0x5960, 0xFFFF, 0xFFFF, "GX5961/4 Digital I/O Timing/Sync with Pin Electronics and PMU PXI Board(0x5960)"},
{0x16E2, 0x6021, 0xFFFF, 0xFFFF, "GX6021 20-Channel RF Multiplexer PXI Board(0x6021)"},
{0x16E2, 0x6062, 0xFFFF, 0xFFFF, "GX6062 60-Channel RF Multiplexer PXI Board(0x6062)"},
{0x16E2, 0x6115, 0xFFFF, 0xFFFF, "GX6115 15-Channel High Current SPDT Form-C Relay PXI Board(0x6115)"},
{0x16E2, 0x6125, 0xFFFF, 0xFFFF, "GX6125 25-Channel High-Density SPDT Form-C Relay PXI Board(0x6125)"},
{0x16E2, 0x6138, 0xFFFF, 0xFFFF, "GX6138 38-Channel SPST Form-A Relay PXI Board(0x6138)"},
{0x16E2, 0x6188, 0xFFFF, 0xFFFF, "GX6188 104-Channel 8x8 Multiplexer/Matrix PXI Board(0x6188)"},
{0x16E2, 0x6192, 0xFFFF, 0xFFFF, "GX6192 16, 16x2 High Frequency, High Density Multiplexer PXI Board(0x6192)"},
{0x16E2, 0x6196, 0xFFFF, 0xFFFF, "GX6196 96-Channel DPST Form-A Relay Carrier PXI Board(0x6196)"},
{0x16E2, 0x6256, 0xFFFF, 0xFFFF, "GX6256 16, 16x2 Low Frequency, High Density Multiplexer PXI Board(0x6256)"},
{0x16E2, 0x6264, 0xFFFF, 0xFFFF, "GX6264 128-Channel Scanner/Multiplexer Board(0x6264)"},
{0x16E2, 0x6315, 0xFFFF, 0xFFFF, "GX6315 45-Channel High Current SPDT Form-C Relay Board(0x6315)"},
{0x16E2, 0x6325, 0xFFFF, 0xFFFF, "GX6325 75-Channel High-Density SPDT Form-C Relay Board(0x6325)"},
{0x16E2, 0x6338, 0xFFFF, 0xFFFF, "GX6338 114-Channel SPST Form-A Relay PXI Board(0x6338)"},
{0x16E2, 0x6377, 0xFFFF, 0xFFFF, "GX6377 Multifunction Switching PXI Board(0x6377)"},
{0x16E2, 0x6384, 0xFFFF, 0xFFFF, "GX6384 Configurable High-Density Switch Matrix PXI Board(0x6384)"},
{0x16E2, 0x6616, 0xFFFF, 0xFFFF, "GX6616 6x2:16 Switch Matrix PXI Board(0x6616)"},
{0x16E2, 0x6864, 0xFFFF, 0xFFFF, "GX6864 Video Switching PXI Board(0x6864)"},
{0x16E2, 0x7400, 0xFFFF, 0xFFFF, "GX7400 Dual-Output Programmable Power Supply PXI Board(0x7400)"},
{0x16E2, 0x7404, 0xFFFF, 0xFFFF, "GX7404 Prototyping and Power Interface PXI Board(0x7404)"},
{0x16E2, 0x7777, 0xFFFF, 0xFFFF, "GX7777 Generic Interface PXI Board(0x7777)"},
{0x16E2, 0x7779, 0xFFFF, 0xFFFF, "GX7779 Backplane Tester PXI Board(0x7779)"},
}; /* pci_vid_16E2[] */

static pci_id_t const pci_vid_16E3[] = {
{0x16E3, 0xFFFF, 0xFFFF, 0xFFFF, "European Space Agency(0x16E3)"},
{0x16E3, 0x1E0F, 0xFFFF, 0xFFFF, "LEON2FT Processor(0x1E0F)"},
}; /* pci_vid_16E3[] */

static pci_id_t const pci_vid_16E5[] = {
{0x16E5, 0xFFFF, 0xFFFF, 0xFFFF, "Intellon Corp.(0x16E5)"},
{0x16E5, 0x6000, 0xFFFF, 0xFFFF, "INT6000 Ethernet-to-Powerline Bridge [HomePlug AV](0x6000)"},
{0x16E5, 0x6300, 0xFFFF, 0xFFFF, "INT6300 Ethernet-to-Powerline Bridge [HomePlug AV](0x6300)"},
}; /* pci_vid_16E5[] */

static pci_id_t const pci_vid_16EC[] = {
{0x16EC, 0xFFFF, 0xFFFF, 0xFFFF, "U.S. Robotics(0x16EC)"},
{0x16EC, 0x00ED, 0xFFFF, 0xFFFF, "USR997900(0x00ED)"},
{0x16EC, 0x0116, 0xFFFF, 0xFFFF, "USR997902 10/100/1000 Mbps PCI Network Card(0x0116)"},
{0x16EC, 0x2F00, 0xFFFF, 0xFFFF, "USR5660A (USR265660A, USR5660A-BP) 56K PCI Faxmodem(0x2F00)"},
{0x16EC, 0x3685, 0xFFFF, 0xFFFF, "Wireless Access PCI Adapter Model 022415(0x3685)"},
{0x16EC, 0x4320, 0xFFFF, 0xFFFF, "USR997904 10/100/1000 64-bit NIC (Marvell Yukon)(0x4320)"},
{0x16EC, 0xAB06, 0xFFFF, 0xFFFF, "USR997901A 10/100 Cardbus NIC(0xAB06)"},
}; /* pci_vid_16EC[] */

static pci_id_t const pci_vid_16ED[] = {
{0x16ED, 0xFFFF, 0xFFFF, 0xFFFF, "Sycron N. V.(0x16ED)"},
{0x16ED, 0x1001, 0xFFFF, 0xFFFF, "UMIO communication card(0x1001)"},
}; /* pci_vid_16ED[] */

static pci_id_t const pci_vid_16F2[] = {
{0x16F2, 0xFFFF, 0xFFFF, 0xFFFF, "ETAS GmbH(0x16F2)"},
{0x16F2, 0x0200, 0xFFFF, 0xFFFF, "I/O board(0x0200)"},
{0x16F2, 0x0200, 0x16F2, 0x0010, "ES53xx I/O board(0x16F2-0x0010)"},
}; /* pci_vid_16F2[] */

static pci_id_t const pci_vid_16F3[] = {
{0x16F3, 0xFFFF, 0xFFFF, 0xFFFF, "Jetway Information Co., Ltd.(0x16F3)"},
}; /* pci_vid_16F3[] */

static pci_id_t const pci_vid_16F4[] = {
{0x16F4, 0xFFFF, 0xFFFF, 0xFFFF, "Vweb Corp(0x16F4)"},
{0x16F4, 0x8000, 0xFFFF, 0xFFFF, "VW2010(0x8000)"},
}; /* pci_vid_16F4[] */

static pci_id_t const pci_vid_16F6[] = {
{0x16F6, 0xFFFF, 0xFFFF, 0xFFFF, "VideoTele.com, Inc.(0x16F6)"},
}; /* pci_vid_16F6[] */

static pci_id_t const pci_vid_1702[] = {
{0x1702, 0xFFFF, 0xFFFF, 0xFFFF, "Internet Machines Corporation (IMC)(0x1702)"},
}; /* pci_vid_1702[] */

static pci_id_t const pci_vid_1705[] = {
{0x1705, 0xFFFF, 0xFFFF, 0xFFFF, "Digital First, Inc.(0x1705)"},
}; /* pci_vid_1705[] */

static pci_id_t const pci_vid_170B[] = {
{0x170B, 0xFFFF, 0xFFFF, 0xFFFF, "NetOctave(0x170B)"},
{0x170B, 0x0100, 0xFFFF, 0xFFFF, "NSP2000-SSL crypto accelerator(0x0100)"},
}; /* pci_vid_170B[] */

static pci_id_t const pci_vid_170C[] = {
{0x170C, 0xFFFF, 0xFFFF, 0xFFFF, "YottaYotta Inc.(0x170C)"},
}; /* pci_vid_170C[] */

static pci_id_t const pci_vid_1719[] = {
{0x1719, 0xFFFF, 0xFFFF, 0xFFFF, "EZChip Technologies(0x1719)"},
{0x1719, 0x1000, 0xFFFF, 0xFFFF, "NPA Access Network Processor Family(0x1000)"},
}; /* pci_vid_1719[] */

static pci_id_t const pci_vid_1725[] = {
{0x1725, 0xFFFF, 0xFFFF, 0xFFFF, "Vitesse Semiconductor(0x1725)"},
{0x1725, 0x7174, 0xFFFF, 0xFFFF, "VSC7174 PCI/PCI-X Serial ATA Host Bus Controller(0x7174)"},
}; /* pci_vid_1725[] */

static pci_id_t const pci_vid_172A[] = {
{0x172A, 0xFFFF, 0xFFFF, 0xFFFF, "Accelerated Encryption(0x172A)"},
{0x172A, 0x13C8, 0xFFFF, 0xFFFF, "AEP SureWare Runner 1000V3(0x13C8)"},
}; /* pci_vid_172A[] */

static pci_id_t const pci_vid_1734[] = {
{0x1734, 0xFFFF, 0xFFFF, 0xFFFF, "Fujitsu Technology Solutions(0x1734)"},
{0x1734, 0x9602, 0xFFFF, 0xFFFF, "RS780/RS880 PCI to PCI bridge (int gfx)(0x9602)"},
}; /* pci_vid_1734[] */

static pci_id_t const pci_vid_1735[] = {
{0x1735, 0xFFFF, 0xFFFF, 0xFFFF, "Aten International Co. Ltd.(0x1735)"},
}; /* pci_vid_1735[] */

static pci_id_t const pci_vid_1737[] = {
{0x1737, 0xFFFF, 0xFFFF, 0xFFFF, "Linksys(0x1737)"},
{0x1737, 0x0029, 0xFFFF, 0xFFFF, "WPG54G ver. 4 PCI Card(0x0029)"},
{0x1737, 0x1032, 0xFFFF, 0xFFFF, "Gigabit Network Adapter(0x1032)"},
{0x1737, 0x1032, 0x1737, 0x0015, "EG1032 v2 Instant Gigabit Network Adapter(0x1737-0x0015)"},
{0x1737, 0x1032, 0x1737, 0x0024, "EG1032 v3 Instant Gigabit Network Adapter(0x1737-0x0024)"},
{0x1737, 0x1064, 0xFFFF, 0xFFFF, "Gigabit Network Adapter(0x1064)"},
{0x1737, 0x1064, 0x1737, 0x0016, "EG1064 v2 Instant Gigabit Network Adapter(0x1737-0x0016)"},
{0x1737, 0xAB08, 0xFFFF, 0xFFFF, "21x4x DEC-Tulip compatible 10/100 Ethernet(0xAB08)"},
{0x1737, 0xAB09, 0xFFFF, 0xFFFF, "21x4x DEC-Tulip compatible 10/100 Ethernet(0xAB09)"},
}; /* pci_vid_1737[] */

static pci_id_t const pci_vid_173B[] = {
{0x173B, 0xFFFF, 0xFFFF, 0xFFFF, "Altima (nee Broadcom)(0x173B)"},
{0x173B, 0x0001, 0xFFFF, 0xFFFF, "AC1002 PCI Gigabit Ethernet controller(0x0001)"},
{0x173B, 0x03E8, 0xFFFF, 0xFFFF, "AC1000 Gigabit Ethernet(0x03E8)"},
{0x173B, 0x03E9, 0xFFFF, 0xFFFF, "AC1001 Gigabit Ethernet(0x03E9)"},
{0x173B, 0x03EA, 0xFFFF, 0xFFFF, "AC9100 Gigabit Ethernet(0x03EA)"},
{0x173B, 0x03EA, 0x173B, 0x0001, "AC1002(0x173B-0x0001)"},
{0x173B, 0x03EB, 0xFFFF, 0xFFFF, "AC1003 Gigabit Ethernet(0x03EB)"},
}; /* pci_vid_173B[] */

static pci_id_t const pci_vid_1743[] = {
{0x1743, 0xFFFF, 0xFFFF, 0xFFFF, "Peppercon AG(0x1743)"},
{0x1743, 0x8139, 0xFFFF, 0xFFFF, "ROL/F-100 Fast Ethernet Adapter with ROL(0x8139)"},
}; /* pci_vid_1743[] */

static pci_id_t const pci_vid_1745[] = {
{0x1745, 0xFFFF, 0xFFFF, 0xFFFF, "ViXS Systems, Inc.(0x1745)"},
{0x1745, 0x2020, 0xFFFF, 0xFFFF, "XCode II Series(0x2020)"},
{0x1745, 0x2100, 0xFFFF, 0xFFFF, "XCode 2100 Series(0x2100)"},
{0x1745, 0x2100, 0x1043, 0x48C9, "My Cinema PE6200 Analoog(0x1043-0x48C9)"},
}; /* pci_vid_1745[] */

static pci_id_t const pci_vid_1749[] = {
{0x1749, 0xFFFF, 0xFFFF, 0xFFFF, "RLX Technologies(0x1749)"},
}; /* pci_vid_1749[] */

static pci_id_t const pci_vid_174B[] = {
{0x174B, 0xFFFF, 0xFFFF, 0xFFFF, "PC Partner Limited / Sapphire Technology(0x174B)"},
}; /* pci_vid_174B[] */

static pci_id_t const pci_vid_174D[] = {
{0x174D, 0xFFFF, 0xFFFF, 0xFFFF, "WellX Telecom SA(0x174D)"},
}; /* pci_vid_174D[] */

static pci_id_t const pci_vid_175C[] = {
{0x175C, 0xFFFF, 0xFFFF, 0xFFFF, "AudioScience Inc(0x175C)"},
}; /* pci_vid_175C[] */

static pci_id_t const pci_vid_175E[] = {
{0x175E, 0xFFFF, 0xFFFF, 0xFFFF, "Sanera Systems, Inc.(0x175E)"},
}; /* pci_vid_175E[] */

static pci_id_t const pci_vid_1760[] = {
{0x1760, 0xFFFF, 0xFFFF, 0xFFFF, "TEDIA spol. s r. o.(0x1760)"},
{0x1760, 0x0101, 0xFFFF, 0xFFFF, "PCD-7004 Digital Bi-Directional Ports PCI Card(0x0101)"},
{0x1760, 0x0102, 0xFFFF, 0xFFFF, "PCD-7104 Digital Input & Output PCI Card(0x0102)"},
{0x1760, 0x0121, 0xFFFF, 0xFFFF, "PCT-7303A PC card with IRC counters(0x0121)"},
{0x1760, 0x0122, 0xFFFF, 0xFFFF, "PCT-7408A PC card with counters and timers(0x0122)"},
{0x1760, 0x0123, 0xFFFF, 0xFFFF, "PCT-7424 PCI card with standard counters(0x0123)"},
{0x1760, 0x0141, 0xFFFF, 0xFFFF, "PCA7208AL - Analog Inputs/Outputs(0x0141)"},
{0x1760, 0x0142, 0xFFFF, 0xFFFF, "PCA7208AS - Analog inputs/Outputs(0x0142)"},
{0x1760, 0x0143, 0xFFFF, 0xFFFF, "PCA7408AL - Analog Inputs/Outputs(0x0143)"},
{0x1760, 0x0144, 0xFFFF, 0xFFFF, "PCA7408AS - Analog Inputs/Outputs(0x0144)"},
{0x1760, 0x0145, 0xFFFF, 0xFFFF, "PCA-7228AL Multifunction PCI IO card(0x0145)"},
{0x1760, 0x0146, 0xFFFF, 0xFFFF, "PCA-7228AS Multifunction PCI IO card(0x0146)"},
{0x1760, 0x0147, 0xFFFF, 0xFFFF, "PCA7428AL Multifunction PCI IO card(0x0147)"},
{0x1760, 0x0148, 0xFFFF, 0xFFFF, "PCA7428AS Multifunction PCI IO card(0x0148)"},
{0x1760, 0x0149, 0xFFFF, 0xFFFF, "PCA7228EL Multifunction PCI IO card with isolated analog inputs(0x0149)"},
{0x1760, 0x0150, 0xFFFF, 0xFFFF, "PCA7428EL Multifunction PCI IO card with isolated analog inputs(0x0150)"},
{0x1760, 0x0151, 0xFFFF, 0xFFFF, "PCA7628AL - PCI card with analog inputs, counters and DIO(0x0151)"},
{0x1760, 0x0152, 0xFFFF, 0xFFFF, "PCA7628AS PCI card with analog inputs, outputs, counters and DIO(0x0152)"},
{0x1760, 0x0161, 0xFFFF, 0xFFFF, "PCA7288A PCI card with analog outputs, counters and DIO(0x0161)"},
{0x1760, 0x0180, 0xFFFF, 0xFFFF, "PCI1052 Communication card for MicroUnit network(0x0180)"},
{0x1760, 0x0214, 0xFFFF, 0xFFFF, "PCT-7424C (F0) PC card with standard counters(0x0214)"},
{0x1760, 0x0215, 0xFFFF, 0xFFFF, "PCT-7424C (F1) PC card with standard counters(0x0215)"},
{0x1760, 0x0216, 0xFFFF, 0xFFFF, "PCT-7424E (F0) PC card with standard counters(0x0216)"},
{0x1760, 0x0217, 0xFFFF, 0xFFFF, "PCT-7424E (F1) PC card with standard counters(0x0217)"},
{0x1760, 0x0240, 0xFFFF, 0xFFFF, "PCA7428CL_F0 - analog Inputs(0x0240)"},
{0x1760, 0x0241, 0xFFFF, 0xFFFF, "PCA7428CL_F1 - analog Inputs(0x0241)"},
{0x1760, 0x0242, 0xFFFF, 0xFFFF, "PCA7428CS_F0 - Analog Inputs/Outputs non isolated(0x0242)"},
{0x1760, 0x0243, 0xFFFF, 0xFFFF, "PCA7428CS_F1 - Analog Inputs/Outputs non isolated(0x0243)"},
{0x1760, 0x0244, 0xFFFF, 0xFFFF, "PCA7428CE_F0 - Analog Inputs isolated(0x0244)"},
{0x1760, 0x0245, 0xFFFF, 0xFFFF, "PCA7428CE_F1 - Analog Inputs isolated(0x0245)"},
{0x1760, 0x0303, 0xFFFF, 0xFFFF, "PCD-7006C Digital Input & Output PCI Card(0x0303)"},
{0x1760, 0x0800, 0xFFFF, 0xFFFF, "PCD8006 - PCIe digital Inputs/Outputs(0x0800)"},
{0x1760, 0x0840, 0xFFFF, 0xFFFF, "PCA-8428 General-purpose multifunctional PCIe card with 8 analog inputs and 2 analog outputs(0x0840)"},
{0x1760, 0x0841, 0xFFFF, 0xFFFF, "PCA-8429 General-purpose multifunctional PCIe card with 8 analog inputs(0x0841)"},
{0x1760, 0x0842, 0xFFFF, 0xFFFF, "PCA-8438 General-purpose multifunctional PCIe card with 16 analog inputs and 2 analog outputs(0x0842)"},
{0x1760, 0x0843, 0xFFFF, 0xFFFF, "PCA-8439 General-purpose multifunctional PCIe card with 16 analog inputs(0x0843)"},
{0x1760, 0xFF00, 0xFFFF, 0xFFFF, "CTU CAN FD PCIe Card(0xFF00)"},
}; /* pci_vid_1760[] */

static pci_id_t const pci_vid_1761[] = {
{0x1761, 0xFFFF, 0xFFFF, 0xFFFF, "Pickering Interfaces Ltd(0x1761)"},
}; /* pci_vid_1761[] */

static pci_id_t const pci_vid_1771[] = {
{0x1771, 0xFFFF, 0xFFFF, 0xFFFF, "InnoVISION Multimedia Ltd.(0x1771)"},
}; /* pci_vid_1771[] */

static pci_id_t const pci_vid_1775[] = {
{0x1775, 0xFFFF, 0xFFFF, 0xFFFF, "General Electric(0x1775)"},
}; /* pci_vid_1775[] */

static pci_id_t const pci_vid_177D[] = {
{0x177D, 0xFFFF, 0xFFFF, 0xFFFF, "Cavium, Inc.(0x177D)"},
{0x177D, 0x0001, 0xFFFF, 0xFFFF, "Nitrox XL N1(0x0001)"},
{0x177D, 0x0003, 0xFFFF, 0xFFFF, "Nitrox XL N1 Lite(0x0003)"},
{0x177D, 0x0004, 0xFFFF, 0xFFFF, "Octeon (and older) FIPS(0x0004)"},
{0x177D, 0x0005, 0xFFFF, 0xFFFF, "Octeon CN38XX Network Processor Pass 3.x(0x0005)"},
{0x177D, 0x0006, 0xFFFF, 0xFFFF, "RoHS(0x0006)"},
{0x177D, 0x0010, 0xFFFF, 0xFFFF, "CN15XX/CN16XX [Nitrox PX](0x0010)"},
{0x177D, 0x0011, 0xFFFF, 0xFFFF, "CNN35XX [Nitrox III](0x0011)"},
{0x177D, 0x0012, 0xFFFF, 0xFFFF, "CNN55XX [Nitrox V](0x0012)"},
{0x177D, 0x0020, 0xFFFF, 0xFFFF, "Octeon CN31XX Network Processor(0x0020)"},
{0x177D, 0x0030, 0xFFFF, 0xFFFF, "Octeon CN30XX Network Processor(0x0030)"},
{0x177D, 0x0040, 0xFFFF, 0xFFFF, "Octeon CN58XX Network Processor(0x0040)"},
{0x177D, 0x0050, 0xFFFF, 0xFFFF, "Octeon CN57XX Network Processor (CN54XX/CN55XX/CN56XX)(0x0050)"},
{0x177D, 0x0070, 0xFFFF, 0xFFFF, "Octeon CN50XX Network Processor(0x0070)"},
{0x177D, 0x0080, 0xFFFF, 0xFFFF, "Octeon CN52XX Network Processor(0x0080)"},
{0x177D, 0x0090, 0xFFFF, 0xFFFF, "Octeon II CN63XX Network Processor(0x0090)"},
{0x177D, 0x0091, 0xFFFF, 0xFFFF, "Octeon II CN68XX Network Processor(0x0091)"},
{0x177D, 0x0092, 0xFFFF, 0xFFFF, "Octeon II CN65XX Network Processor(0x0092)"},
{0x177D, 0x0093, 0xFFFF, 0xFFFF, "Octeon II CN61XX Network Processor(0x0093)"},
{0x177D, 0x0094, 0xFFFF, 0xFFFF, "Octeon Fusion CNF71XX Cell processor(0x0094)"},
{0x177D, 0x0095, 0xFFFF, 0xFFFF, "Octeon III CN78XX Network Processor(0x0095)"},
{0x177D, 0x0096, 0xFFFF, 0xFFFF, "Octeon III CN70XX Network Processor(0x0096)"},
{0x177D, 0x9700, 0xFFFF, 0xFFFF, "Octeon III CN73XX Network Processor(0x9700)"},
{0x177D, 0x9702, 0xFFFF, 0xFFFF, "CN23XX [LiquidIO II] Intelligent Adapter(0x9702)"},
{0x177D, 0x9702, 0x177D, 0x0003, "CN2350 [LiquidIO II] 2-port 10GbE Intelligent adapter(0x177D-0x0003)"},
{0x177D, 0x9702, 0x177D, 0x0004, "CN2350 [LiquidIO II] 2-port 10GbE Intelligent adapter(0x177D-0x0004)"},
{0x177D, 0x9702, 0x177D, 0x0005, "CN2360 [LiquidIO II] 2-port 10GbE Intelligent adapter(0x177D-0x0005)"},
{0x177D, 0x9702, 0x177D, 0x0006, "CN2360 [LiquidIO II] 2-port 25GbE Intelligent adapter(0x177D-0x0006)"},
{0x177D, 0x9702, 0x177D, 0x0007, "CN2350 [LiquidIO II] 2-port 25GbE Intelligent adapter(0x177D-0x0007)"},
{0x177D, 0x9702, 0x177D, 0x0008, "CN2350 [LiquidIO II] 2-port 10GbE SFP+ Intelligent adapter(0x177D-0x0008)"},
{0x177D, 0x9702, 0x177D, 0x0009, "CN2360 [LiquidIO II] 2-port 10GbE SFP+ Intelligent adapter(0x177D-0x0009)"},
{0x177D, 0x9702, 0x177D, 0x000A, "CN2350 [LiquidIO II] 2-port 10GBASE-T Intelligent adapter(0x177D-0x000A)"},
{0x177D, 0x9702, 0x177D, 0x000B, "CN2360 [LiquidIO II] 2-port 10GBASE-T Intelligent adapter(0x177D-0x000B)"},
{0x177D, 0x9703, 0xFFFF, 0xFFFF, "CN23XX [LiquidIO II] NVMe Controller(0x9703)"},
{0x177D, 0x9712, 0xFFFF, 0xFFFF, "CN23XX [LiquidIO II] SRIOV Virtual Function(0x9712)"},
{0x177D, 0x9712, 0x177D, 0x0003, "CN2350 [LiquidIO II] 2-port 10GbE SRIOV Virtual Function(0x177D-0x0003)"},
{0x177D, 0x9712, 0x177D, 0x0004, "CN2350 [LiquidIO II] 2-port 10GbE SRIOV Virtual Function(0x177D-0x0004)"},
{0x177D, 0x9712, 0x177D, 0x0005, "CN2360 [LiquidIO II] 2-port 10GbE SRIOV Virtual Function(0x177D-0x0005)"},
{0x177D, 0x9712, 0x177D, 0x0006, "CN2360 [LiquidIO II] 2-port 25GbE SRIOV Virtual Function(0x177D-0x0006)"},
{0x177D, 0x9712, 0x177D, 0x0007, "CN2350 [LiquidIO II] 2-port 25GbE SRIOV Virtual Function(0x177D-0x0007)"},
{0x177D, 0x9713, 0xFFFF, 0xFFFF, "CN23XX [LiquidIO II] NVMe SRIOV Virtual Function(0x9713)"},
{0x177D, 0x9800, 0xFFFF, 0xFFFF, "Octeon Fusion CNF75XX Processor(0x9800)"},
{0x177D, 0xA001, 0xFFFF, 0xFFFF, "ThunderX MRML(Master RML Bridge to RSL devices)(0xA001)"},
{0x177D, 0xA002, 0xFFFF, 0xFFFF, "THUNDERX PCC Bridge(0xA002)"},
{0x177D, 0xA002, 0x177D, 0xA102, "CN88XX PCC Bridge(0x177D-0xA102)"},
{0x177D, 0xA008, 0xFFFF, 0xFFFF, "THUNDERX SMMU(0xA008)"},
{0x177D, 0xA008, 0x177D, 0xA108, "CN88XX SMMU(0x177D-0xA108)"},
{0x177D, 0xA009, 0xFFFF, 0xFFFF, "THUNDERX Generic Interrupt Controller(0xA009)"},
{0x177D, 0xA00A, 0xFFFF, 0xFFFF, "THUNDERX GPIO Controller(0xA00A)"},
{0x177D, 0xA00B, 0xFFFF, 0xFFFF, "THUNDERX MPI / SPI Controller(0xA00B)"},
{0x177D, 0xA00C, 0xFFFF, 0xFFFF, "THUNDERX MIO-PTP Controller(0xA00C)"},
{0x177D, 0xA00D, 0xFFFF, 0xFFFF, "THUNDERX MIX Network Controller(0xA00D)"},
{0x177D, 0xA00E, 0xFFFF, 0xFFFF, "THUNDERX Reset Controller(0xA00E)"},
{0x177D, 0xA00F, 0xFFFF, 0xFFFF, "THUNDERX UART Controller(0xA00F)"},
{0x177D, 0xA010, 0xFFFF, 0xFFFF, "THUNDERX eMMC/SD Controller(0xA010)"},
{0x177D, 0xA011, 0xFFFF, 0xFFFF, "THUNDERX MIO-BOOT Controller(0xA011)"},
{0x177D, 0xA012, 0xFFFF, 0xFFFF, "THUNDERX TWSI / I2C Controller(0xA012)"},
{0x177D, 0xA013, 0xFFFF, 0xFFFF, "THUNDERX CCPI (Multi-node connect)(0xA013)"},
{0x177D, 0xA014, 0xFFFF, 0xFFFF, "THUNDERX Voltage Regulator Module(0xA014)"},
{0x177D, 0xA015, 0xFFFF, 0xFFFF, "THUNDERX PCIe Switch Logic Interface(0xA015)"},
{0x177D, 0xA016, 0xFFFF, 0xFFFF, "THUNDERX Key Memory(0xA016)"},
{0x177D, 0xA017, 0xFFFF, 0xFFFF, "THUNDERX GTI (Global System Timers)(0xA017)"},
{0x177D, 0xA018, 0xFFFF, 0xFFFF, "THUNDERX Random Number Generator(0xA018)"},
{0x177D, 0xA019, 0xFFFF, 0xFFFF, "THUNDERX DFA(0xA019)"},
{0x177D, 0xA01A, 0xFFFF, 0xFFFF, "THUNDERX Zip Coprocessor(0xA01A)"},
{0x177D, 0xA01B, 0xFFFF, 0xFFFF, "THUNDERX xHCI USB Controller(0xA01B)"},
{0x177D, 0xA01C, 0xFFFF, 0xFFFF, "THUNDERX AHCI SATA Controller(0xA01C)"},
{0x177D, 0xA01C, 0x177D, 0xA11C, "CN88XX AHCI SATA Controller(0x177D-0xA11C)"},
{0x177D, 0xA01D, 0xFFFF, 0xFFFF, "THUNDERX RAID Coprocessor(0xA01D)"},
{0x177D, 0xA01E, 0xFFFF, 0xFFFF, "THUNDERX Network Interface Controller(0xA01E)"},
{0x177D, 0xA01F, 0xFFFF, 0xFFFF, "THUNDERX Traffic Network Switch(0xA01F)"},
{0x177D, 0xA020, 0xFFFF, 0xFFFF, "THUNDERX PEM (PCI Express Interface)(0xA020)"},
{0x177D, 0xA021, 0xFFFF, 0xFFFF, "THUNDERX L2C (Level-2 Cache Controller)(0xA021)"},
{0x177D, 0xA022, 0xFFFF, 0xFFFF, "THUNDERX LMC (DRAM Controller)(0xA022)"},
{0x177D, 0xA023, 0xFFFF, 0xFFFF, "THUNDERX OCLA (On-Chip Logic Analyzer)(0xA023)"},
{0x177D, 0xA024, 0xFFFF, 0xFFFF, "THUNDERX OSM(0xA024)"},
{0x177D, 0xA025, 0xFFFF, 0xFFFF, "THUNDERX GSER (General Serializer/Deserializer)(0xA025)"},
{0x177D, 0xA026, 0xFFFF, 0xFFFF, "THUNDERX BGX (Common Ethernet Interface)(0xA026)"},
{0x177D, 0xA027, 0xFFFF, 0xFFFF, "THUNDERX IOBN(0xA027)"},
{0x177D, 0xA029, 0xFFFF, 0xFFFF, "THUNDERX NCSI (Network Controller Sideband Interface)(0xA029)"},
{0x177D, 0xA02A, 0xFFFF, 0xFFFF, "ThunderX SGPIO (Serial GPIO controller for SATA disk lights)(0xA02A)"},
{0x177D, 0xA02B, 0xFFFF, 0xFFFF, "THUNDERX SMI / MDIO Controller(0xA02B)"},
{0x177D, 0xA02C, 0xFFFF, 0xFFFF, "THUNDERX DAP (Debug Access Port)(0xA02C)"},
{0x177D, 0xA02D, 0xFFFF, 0xFFFF, "THUNDERX PCIERC (PCIe Root Complex)(0xA02D)"},
{0x177D, 0xA02E, 0xFFFF, 0xFFFF, "ThunderX L2C-TAD (Level 2 cache tag and data)(0xA02E)"},
{0x177D, 0xA02F, 0xFFFF, 0xFFFF, "THUNDERX L2C-CBC(0xA02F)"},
{0x177D, 0xA030, 0xFFFF, 0xFFFF, "THUNDERX L2C-MCI(0xA030)"},
{0x177D, 0xA031, 0xFFFF, 0xFFFF, "THUNDERX MIO-FUS (Fuse Access Controller)(0xA031)"},
{0x177D, 0xA032, 0xFFFF, 0xFFFF, "THUNDERX FUSF (Fuse Controller)(0xA032)"},
{0x177D, 0xA033, 0xFFFF, 0xFFFF, "THUNDERX Random Number Generator virtual function(0xA033)"},
{0x177D, 0xA034, 0xFFFF, 0xFFFF, "THUNDERX Network Interface Controller virtual function(0xA034)"},
{0x177D, 0xA035, 0xFFFF, 0xFFFF, "THUNDERX Parallel Bus(0xA035)"},
{0x177D, 0xA036, 0xFFFF, 0xFFFF, "ThunderX RAD (RAID acceleration engine) virtual function(0xA036)"},
{0x177D, 0xA037, 0xFFFF, 0xFFFF, "THUNDERX ZIP virtual function(0xA037)"},
{0x177D, 0xA040, 0xFFFF, 0xFFFF, "THUNDERX CPT Cryptographic Accelerator(0xA040)"},
{0x177D, 0xA059, 0xFFFF, 0xFFFF, "Octeon TX2 CGX (MAC)(0xA059)"},
{0x177D, 0xA060, 0xFFFF, 0xFFFF, "Octeon 10 RPM (MAC)(0xA060)"},
{0x177D, 0xA061, 0xFFFF, 0xFFFF, "Octeon Tx2 Loopback Interface (LBK)(0xA061)"},
{0x177D, 0xA063, 0xFFFF, 0xFFFF, "Octeon Tx2 RVU Physical Function(0xA063)"},
{0x177D, 0xA064, 0xFFFF, 0xFFFF, "Octeon Tx2 RVU Virtual Function(0xA064)"},
{0x177D, 0xA065, 0xFFFF, 0xFFFF, "Octeon Tx2 RVU Admin Function(0xA065)"},
{0x177D, 0xA09E, 0xFFFF, 0xFFFF, "Octeon 10 PTP controller(0xA09E)"},
{0x177D, 0xA0F2, 0xFFFF, 0xFFFF, "Octeon 10 CPT Cryptographic Accelerator, Physical function(0xA0F2)"},
{0x177D, 0xA0F3, 0xFFFF, 0xFFFF, "Octeon 10 CPT Cryptographic Accelerator, Virtual function(0xA0F3)"},
{0x177D, 0xA0F6, 0xFFFF, 0xFFFF, "Octeon Tx2 SDP Physical Function(0xA0F6)"},
{0x177D, 0xA0F7, 0xFFFF, 0xFFFF, "Octeon Tx2 SDP Virtual Function(0xA0F7)"},
{0x177D, 0xA0F8, 0xFFFF, 0xFFFF, "Octeon Tx2 Loopback Interface Virtual Function (LBKVF)(0xA0F8)"},
{0x177D, 0xA0FD, 0xFFFF, 0xFFFF, "Octeon Tx2 CPT Cryptographic Accelerator, Physical function(0xA0FD)"},
{0x177D, 0xA0FE, 0xFFFF, 0xFFFF, "Octeon Tx2 CPT Cryptographic Accelerator, Virtual function(0xA0FE)"},
{0x177D, 0xA100, 0xFFFF, 0xFFFF, "THUNDERX CN88XX 48 core SoC(0xA100)"},
{0x177D, 0xA200, 0xFFFF, 0xFFFF, "OCTEON TX CN81XX/CN80XX(0xA200)"},
{0x177D, 0xA300, 0xFFFF, 0xFFFF, "OCTEON TX CN83XX(0xA300)"},
{0x177D, 0xAF00, 0xFFFF, 0xFFFF, "CN99xx [ThunderX2] Integrated PCI Host bridge(0xAF00)"},
{0x177D, 0xAF84, 0xFFFF, 0xFFFF, "CN99xx [ThunderX2] Integrated PCI Express RP Bridge(0xAF84)"},
}; /* pci_vid_177D[] */

static pci_id_t const pci_vid_1787[] = {
{0x1787, 0xFFFF, 0xFFFF, 0xFFFF, "Hightech Information System Ltd.(0x1787)"},
}; /* pci_vid_1787[] */

static pci_id_t const pci_vid_1789[] = {
{0x1789, 0xFFFF, 0xFFFF, 0xFFFF, "Ennyah Technologies Corp.(0x1789)"},
}; /* pci_vid_1789[] */

static pci_id_t const pci_vid_1796[] = {
{0x1796, 0xFFFF, 0xFFFF, 0xFFFF, "Research Centre Juelich(0x1796)"},
{0x1796, 0x0001, 0xFFFF, 0xFFFF, "SIS1100 [Gigabit link](0x0001)"},
{0x1796, 0x0002, 0xFFFF, 0xFFFF, "HOTlink(0x0002)"},
{0x1796, 0x0003, 0xFFFF, 0xFFFF, "Counter Timer(0x0003)"},
{0x1796, 0x0004, 0xFFFF, 0xFFFF, "CAMAC Controller(0x0004)"},
{0x1796, 0x0005, 0xFFFF, 0xFFFF, "PROFIBUS(0x0005)"},
{0x1796, 0x0006, 0xFFFF, 0xFFFF, "AMCC HOTlink(0x0006)"},
{0x1796, 0x0007, 0xFFFF, 0xFFFF, "LVD Cable Bus(0x0007)"},
{0x1796, 0x0008, 0xFFFF, 0xFFFF, "100MHz, 64bit Sequence Generator based on VirtexII(0x0008)"},
{0x1796, 0x0009, 0xFFFF, 0xFFFF, "double 14bit-ADC(0x0009)"},
{0x1796, 0x000A, 0xFFFF, 0xFFFF, "SIS1100 with N110 TDC(0x000A)"},
{0x1796, 0x000B, 0xFFFF, 0xFFFF, "double 14bit-ADC with memory(0x000B)"},
{0x1796, 0x000D, 0xFFFF, 0xFFFF, "Synchronisation Slave(0x000D)"},
{0x1796, 0x000E, 0xFFFF, 0xFFFF, "SIS1100-eCMC(0x000E)"},
{0x1796, 0x000F, 0xFFFF, 0xFFFF, "TDC (GPX)(0x000F)"},
{0x1796, 0x0010, 0xFFFF, 0xFFFF, "PCIe Counter Timer(0x0010)"},
{0x1796, 0x0011, 0xFFFF, 0xFFFF, "SIS1100-e single link(0x0011)"},
{0x1796, 0x0012, 0xFFFF, 0xFFFF, "SIS1100-e quad link(0x0012)"},
{0x1796, 0x0013, 0xFFFF, 0xFFFF, "4x2.5GHz SFP to 4 lane PCIe bridge(0x0013)"},
{0x1796, 0x0014, 0xFFFF, 0xFFFF, "SIS1100 with GPX piggy back(0x0014)"},
{0x1796, 0x0015, 0xFFFF, 0xFFFF, "SIS8100 [Gigabit link, MicroTCA](0x0015)"},
{0x1796, 0x0016, 0xFFFF, 0xFFFF, "SIS1100e with 4 lanes(0x0016)"},
{0x1796, 0x0017, 0xFFFF, 0xFFFF, "Quad 14bit, 50MHz ADC with 2.5GHz SFP(0x0017)"},
{0x1796, 0x0018, 0xFFFF, 0xFFFF, "SIS8300 4-lane PCI Express, Micro TCA for Physics ADC(0x0018)"},
{0x1796, 0x0019, 0xFFFF, 0xFFFF, "SIS SIS8300-Lx MTCA.4 Digitizer(0x0019)"},
{0x1796, 0x001A, 0xFFFF, 0xFFFF, "100MHz, 64bit Sequence Generator based on VirtexII(0x001A)"},
{0x1796, 0x001C, 0xFFFF, 0xFFFF, "Quad 16bit, 150MHz ADC with 2.5GHz SFP(0x001C)"},
{0x1796, 0x0030, 0xFFFF, 0xFFFF, "100MHz, 64bit Sequence Generator based on Spartan6(0x0030)"},
{0x1796, 0x0031, 0xFFFF, 0xFFFF, "200MHz 64bit Sequence Generator based on Spartan7(0x0031)"},
}; /* pci_vid_1796[] */

static pci_id_t const pci_vid_1797[] = {
{0x1797, 0xFFFF, 0xFFFF, 0xFFFF, "Intersil Techwell(0x1797)"},
{0x1797, 0x5864, 0xFFFF, 0xFFFF, "TW5864 multimedia video controller(0x5864)"},
{0x1797, 0x6801, 0xFFFF, 0xFFFF, "TW6802 multimedia video card(0x6801)"},
{0x1797, 0x6802, 0xFFFF, 0xFFFF, "TW6802 multimedia other device(0x6802)"},
{0x1797, 0x6810, 0xFFFF, 0xFFFF, "TW6816 multimedia video controller(0x6810)"},
{0x1797, 0x6811, 0xFFFF, 0xFFFF, "TW6816 multimedia video controller(0x6811)"},
{0x1797, 0x6812, 0xFFFF, 0xFFFF, "TW6816 multimedia video controller(0x6812)"},
{0x1797, 0x6813, 0xFFFF, 0xFFFF, "TW6816 multimedia video controller(0x6813)"},
{0x1797, 0x6814, 0xFFFF, 0xFFFF, "TW6816 multimedia video controller(0x6814)"},
{0x1797, 0x6815, 0xFFFF, 0xFFFF, "TW6816 multimedia video controller(0x6815)"},
{0x1797, 0x6816, 0xFFFF, 0xFFFF, "TW6816 multimedia video controller(0x6816)"},
{0x1797, 0x6817, 0xFFFF, 0xFFFF, "TW6816 multimedia video controller(0x6817)"},
{0x1797, 0x6864, 0xFFFF, 0xFFFF, "TW6864 multimedia video controller(0x6864)"},
}; /* pci_vid_1797[] */

static pci_id_t const pci_vid_1799[] = {
{0x1799, 0xFFFF, 0xFFFF, 0xFFFF, "Belkin(0x1799)"},
{0x1799, 0x6001, 0xFFFF, 0xFFFF, "F5D6001 Wireless PCI Card [Realtek RTL8180](0x6001)"},
{0x1799, 0x6020, 0xFFFF, 0xFFFF, "F5D6020 v3000 Wireless PCMCIA Card [Realtek RTL8180](0x6020)"},
{0x1799, 0x6060, 0xFFFF, 0xFFFF, "F5D6060 Wireless PDA Card(0x6060)"},
{0x1799, 0x700F, 0xFFFF, 0xFFFF, "F5D7000 v7000 Wireless G Desktop Card [Realtek RTL8185](0x700F)"},
{0x1799, 0x701F, 0xFFFF, 0xFFFF, "F5D7010 v7000 Wireless G Notebook Card [Realtek RTL8185](0x701F)"},
}; /* pci_vid_1799[] */

static pci_id_t const pci_vid_179A[] = {
{0x179A, 0xFFFF, 0xFFFF, 0xFFFF, "id Quantique(0x179A)"},
{0x179A, 0x0001, 0xFFFF, 0xFFFF, "Quantis PCI 16Mbps(0x0001)"},
}; /* pci_vid_179A[] */

static pci_id_t const pci_vid_179C[] = {
{0x179C, 0xFFFF, 0xFFFF, 0xFFFF, "Data Patterns(0x179C)"},
{0x179C, 0x0557, 0xFFFF, 0xFFFF, "DP-PCI-557 [PCI 1553B](0x0557)"},
{0x179C, 0x0566, 0xFFFF, 0xFFFF, "DP-PCI-566 [Intelligent PCI 1553B](0x0566)"},
{0x179C, 0x1152, 0xFFFF, 0xFFFF, "DP-cPCI-1152 (8-channel Isolated ADC Module)(0x1152)"},
{0x179C, 0x5031, 0xFFFF, 0xFFFF, "DP-CPCI-5031-Synchro Module(0x5031)"},
{0x179C, 0x5112, 0xFFFF, 0xFFFF, "DP-cPCI-5112 [MM-Carrier](0x5112)"},
{0x179C, 0x5121, 0xFFFF, 0xFFFF, "DP-CPCI-5121-IP Carrier(0x5121)"},
{0x179C, 0x5211, 0xFFFF, 0xFFFF, "DP-CPCI-5211-IP Carrier(0x5211)"},
{0x179C, 0x5679, 0xFFFF, 0xFFFF, "AGE Display Module(0x5679)"},
}; /* pci_vid_179C[] */

static pci_id_t const pci_vid_17A0[] = {
{0x17A0, 0xFFFF, 0xFFFF, 0xFFFF, "Genesys Logic, Inc(0x17A0)"},
{0x17A0, 0x7163, 0xFFFF, 0xFFFF, "GL9701 PCIe to PCI Bridge(0x7163)"},
{0x17A0, 0x8083, 0xFFFF, 0xFFFF, "GL880 USB 1.1 UHCI controller(0x8083)"},
{0x17A0, 0x8084, 0xFFFF, 0xFFFF, "GL880 USB 2.0 EHCI controller(0x8084)"},
{0x17A0, 0x9750, 0xFFFF, 0xFFFF, "GL9750 SD Host Controller(0x9750)"},
{0x17A0, 0x9755, 0xFFFF, 0xFFFF, "GL9755 SD Host Controller(0x9755)"},
{0x17A0, 0xE763, 0xFFFF, 0xFFFF, "GL9763E eMMC Controller(0xE763)"},
}; /* pci_vid_17A0[] */

static pci_id_t const pci_vid_17AA[] = {
{0x17AA, 0xFFFF, 0xFFFF, 0xFFFF, "Lenovo(0x17AA)"},
{0x17AA, 0x0003, 0xFFFF, 0xFFFF, "LENSE20256GMSP34MEAT2TA(0x0003)"},
{0x17AA, 0x0004, 0xFFFF, 0xFFFF, "LENSE20512GMSP34MEAT2TA(0x0004)"},
{0x17AA, 0x0005, 0xFFFF, 0xFFFF, "LENSE30256GMSP34MEAT3TA(0x0005)"},
{0x17AA, 0x0006, 0xFFFF, 0xFFFF, "LENSE30512GMSP34MEAT3TA(0x0006)"},
{0x17AA, 0x3181, 0xFFFF, 0xFFFF, "ThinkCentre M75n IoT(0x3181)"},
{0x17AA, 0x402B, 0xFFFF, 0xFFFF, "Intel 82599ES 10Gb 2-port Server Adapter X520-2(0x402B)"},
{0x17AA, 0x9602, 0xFFFF, 0xFFFF, "RS780/RS880 PCI to PCI bridge (int gfx)(0x9602)"},
}; /* pci_vid_17AA[] */

static pci_id_t const pci_vid_17AB[] = {
{0x17AB, 0xFFFF, 0xFFFF, 0xFFFF, "Phillips Components(0x17AB)"},
}; /* pci_vid_17AB[] */

static pci_id_t const pci_vid_17AF[] = {
{0x17AF, 0xFFFF, 0xFFFF, 0xFFFF, "Hightech Information System Ltd.(0x17AF)"},
}; /* pci_vid_17AF[] */

static pci_id_t const pci_vid_17B3[] = {
{0x17B3, 0xFFFF, 0xFFFF, 0xFFFF, "Hawking Technologies(0x17B3)"},
{0x17B3, 0xAB08, 0xFFFF, 0xFFFF, "PN672TX 10/100 Ethernet(0xAB08)"},
}; /* pci_vid_17B3[] */

static pci_id_t const pci_vid_17B4[] = {
{0x17B4, 0xFFFF, 0xFFFF, 0xFFFF, "Indra Networks, Inc.(0x17B4)"},
{0x17B4, 0x0011, 0xFFFF, 0xFFFF, "WebEnhance 100 GZIP Compression Card(0x0011)"},
{0x17B4, 0x0012, 0xFFFF, 0xFFFF, "WebEnhance 200 GZIP Compression Card(0x0012)"},
{0x17B4, 0x0015, 0xFFFF, 0xFFFF, "WebEnhance 300 GZIP Compression Card(0x0015)"},
{0x17B4, 0x0016, 0xFFFF, 0xFFFF, "StorCompress 300 GZIP Compression Card(0x0016)"},
{0x17B4, 0x0017, 0xFFFF, 0xFFFF, "StorSecure 300 GZIP Compression and AES Encryption Card(0x0017)"},
}; /* pci_vid_17B4[] */

static pci_id_t const pci_vid_17C0[] = {
{0x17C0, 0xFFFF, 0xFFFF, 0xFFFF, "Wistron Corp.(0x17C0)"},
}; /* pci_vid_17C0[] */

static pci_id_t const pci_vid_17C2[] = {
{0x17C2, 0xFFFF, 0xFFFF, 0xFFFF, "Newisys, Inc.(0x17C2)"},
}; /* pci_vid_17C2[] */

static pci_id_t const pci_vid_17C3[] = {
{0x17C3, 0xFFFF, 0xFFFF, 0xFFFF, "Protogate, Inc.(0x17C3)"},
}; /* pci_vid_17C3[] */

static pci_id_t const pci_vid_17CB[] = {
{0x17CB, 0xFFFF, 0xFFFF, 0xFFFF, "Qualcomm Technologies, Inc(0x17CB)"},
{0x17CB, 0x0001, 0xFFFF, 0xFFFF, "AGN100 802.11 a/b/g True MIMO Wireless Card(0x0001)"},
{0x17CB, 0x0001, 0x1385, 0x5C00, "WGM511 Pre-N 802.11g Wireless CardBus Adapter(0x1385-0x5C00)"},
{0x17CB, 0x0001, 0x1737, 0x0045, "WMP54GX v1 802.11g Wireless-G PCI Adapter with SRX(0x1737-0x0045)"},
{0x17CB, 0x0002, 0xFFFF, 0xFFFF, "AGN300 802.11 a/b/g True MIMO Wireless Card(0x0002)"},
{0x17CB, 0x0002, 0x1385, 0x6D00, "WPNT511 RangeMax 240 Mbps Wireless CardBus Adapter(0x1385-0x6D00)"},
{0x17CB, 0x0002, 0x1737, 0x0054, "WPC54GX4 v1 802.11g Wireless-G Notebook Adapter with SRX400(0x1737-0x0054)"},
{0x17CB, 0x0104, 0xFFFF, 0xFFFF, "APQ8096 PCIe Root Complex [Snapdragon 820](0x0104)"},
{0x17CB, 0x0105, 0xFFFF, 0xFFFF, "MSM8998 PCIe Root Complex(0x0105)"},
{0x17CB, 0x0106, 0xFFFF, 0xFFFF, "SDM850 PCIe Root Complex [Snapdragon 850](0x0106)"},
{0x17CB, 0x0107, 0xFFFF, 0xFFFF, "SDM850 PCIe Root Port [Snapdragon 850](0x0107)"},
{0x17CB, 0x0108, 0xFFFF, 0xFFFF, "SM8150 PCIe Root Complex(0x0108)"},
{0x17CB, 0x0109, 0xFFFF, 0xFFFF, "SA8195P PCIe Root Complex(0x0109)"},
{0x17CB, 0x010B, 0xFFFF, 0xFFFF, "SM8250 PCIe Root Complex [Snapdragon 865/870 5G](0x010B)"},
{0x17CB, 0x010C, 0xFFFF, 0xFFFF, "SM8350 PCIe Root Complex [Snapdragon 888](0x010C)"},
{0x17CB, 0x010E, 0xFFFF, 0xFFFF, "SC8280XP PCI Express Root Port(0x010E)"},
{0x17CB, 0x0110, 0xFFFF, 0xFFFF, "SM8475 PCIe Root Complex [Snapdragon 8+ Gen 1](0x0110)"},
{0x17CB, 0x0300, 0xFFFF, 0xFFFF, "MDM9x35 LTE Modem [Snapdragon X7](0x0300)"},
{0x17CB, 0x0301, 0xFFFF, 0xFFFF, "MDM9x45 LTE Modem [Snapdragon X12](0x0301)"},
{0x17CB, 0x0302, 0xFFFF, 0xFFFF, "MDM9x55 LTE Modem [Snapdragon X16](0x0302)"},
{0x17CB, 0x0304, 0xFFFF, 0xFFFF, "SDX24 [Snapdragon X24 4G](0x0304)"},
{0x17CB, 0x0306, 0xFFFF, 0xFFFF, "SDX55 [Snapdragon X55 5G](0x0306)"},
{0x17CB, 0x0400, 0xFFFF, 0xFFFF, "Datacenter Technologies QDF2432 PCI Express Root Port(0x0400)"},
{0x17CB, 0x0401, 0xFFFF, 0xFFFF, "Datacenter Technologies QDF2400 PCI Express Root Port(0x0401)"},
{0x17CB, 0x1000, 0xFFFF, 0xFFFF, "QCS405 PCIe Root Complex(0x1000)"},
{0x17CB, 0x1101, 0xFFFF, 0xFFFF, "QCA6390 Wireless Network Adapter(0x1101)"},
{0x17CB, 0x1103, 0xFFFF, 0xFFFF, "QCNFA765 Wireless Network Adapter(0x1103)"},
{0x17CB, 0x1104, 0xFFFF, 0xFFFF, "QCN6024/9024/9074 Wireless Network Adapter(0x1104)"},
{0x17CB, 0x1107, 0xFFFF, 0xFFFF, "WCN785x Wi-Fi 7(802.11be) 320MHz 2x2 [FastConnect 7800](0x1107)"},
{0x17CB, 0x1107, 0x105B, 0xE0F7, "High Band Simultaneous Wireless Network Adapter(0x105B-0xE0F7)"},
{0x17CB, 0x1108, 0xFFFF, 0xFFFF, "IPQ95xx/97xx PCIe Root Port(0x1108)"},
{0x17CB, 0x1109, 0xFFFF, 0xFFFF, "QCN62xx/92xx Wireless Network Adapter(0x1109)"},
}; /* pci_vid_17CB[] */

static pci_id_t const pci_vid_17CC[] = {
{0x17CC, 0xFFFF, 0xFFFF, 0xFFFF, "NetChip Technology, Inc(0x17CC)"},
{0x17CC, 0x2280, 0xFFFF, 0xFFFF, "NET2280 PCI to USB 2.0 Hi-Speed Peripheral Controller(0x2280)"},
{0x17CC, 0x2282, 0xFFFF, 0xFFFF, "NET2282 PCI to USB 2.0 Hi-Speed Peripheral Controller(0x2282)"},
}; /* pci_vid_17CC[] */

static pci_id_t const pci_vid_17CD[] = {
{0x17CD, 0xFFFF, 0xFFFF, 0xFFFF, "Cadence Design Systems, Inc.(0x17CD)"},
}; /* pci_vid_17CD[] */

static pci_id_t const pci_vid_17CF[] = {
{0x17CF, 0xFFFF, 0xFFFF, 0xFFFF, "Z-Com, Inc.(0x17CF)"},
}; /* pci_vid_17CF[] */

static pci_id_t const pci_vid_17D3[] = {
{0x17D3, 0xFFFF, 0xFFFF, 0xFFFF, "Areca Technology Corp.(0x17D3)"},
{0x17D3, 0x1110, 0xFFFF, 0xFFFF, "ARC-1110 4-Port PCI-X to SATA RAID Controller(0x1110)"},
{0x17D3, 0x1120, 0xFFFF, 0xFFFF, "ARC-1120 8-Port PCI-X to SATA RAID Controller(0x1120)"},
{0x17D3, 0x1130, 0xFFFF, 0xFFFF, "ARC-1130 12-Port PCI-X to SATA RAID Controller(0x1130)"},
{0x17D3, 0x1160, 0xFFFF, 0xFFFF, "ARC-1160 16-Port PCI-X to SATA RAID Controller(0x1160)"},
{0x17D3, 0x1170, 0xFFFF, 0xFFFF, "ARC-1170 24-Port PCI-X to SATA RAID Controller(0x1170)"},
{0x17D3, 0x1201, 0xFFFF, 0xFFFF, "ARC-1200 2-Port PCI-Express to SATA II RAID Controller(0x1201)"},
{0x17D3, 0x1203, 0xFFFF, 0xFFFF, "ARC-1203 2/4/8 Port PCIe 2.0 to SATA 6Gb RAID Controller(0x1203)"},
{0x17D3, 0x1210, 0xFFFF, 0xFFFF, "ARC-1210 4-Port PCI-Express to SATA RAID Controller(0x1210)"},
{0x17D3, 0x1214, 0xFFFF, 0xFFFF, "ARC-12x4 PCIe 2.0 to SAS/SATA 6Gb RAID Controller(0x1214)"},
{0x17D3, 0x1214, 0x17D3, 0x1214, "ARC-1214 4-Port PCIe 2.0 to SAS/SATA 6Gb RAID Controller(0x17D3-0x1214)"},
{0x17D3, 0x1214, 0x17D3, 0x1224, "ARC-1224 8-Port PCIe 2.0 to SAS/SATA 6Gb RAID Controller(0x17D3-0x1224)"},
{0x17D3, 0x1214, 0x17D3, 0x1264, "ARC-1264 12/16 Port PCIe 2.0 to SATA 6Gb RAID Controller(0x17D3-0x1264)"},
{0x17D3, 0x1214, 0x17D3, 0x1284, "ARC-1284 24 Port PCIe 2.0 to SATA 6Gb RAID Controller(0x17D3-0x1284)"},
{0x17D3, 0x1220, 0xFFFF, 0xFFFF, "ARC-1220 8-Port PCI-Express to SATA RAID Controller(0x1220)"},
{0x17D3, 0x1222, 0xFFFF, 0xFFFF, "ARC-1222 8-Port PCI-Express to SAS/SATA II RAID Controller(0x1222)"},
{0x17D3, 0x1230, 0xFFFF, 0xFFFF, "ARC-1230 12-Port PCI-Express to SATA RAID Controller(0x1230)"},
{0x17D3, 0x1260, 0xFFFF, 0xFFFF, "ARC-1260 16-Port PCI-Express to SATA RAID Controller(0x1260)"},
{0x17D3, 0x1280, 0xFFFF, 0xFFFF, "ARC-1280/1280ML 24-Port PCI-Express to SATA II RAID Controller(0x1280)"},
{0x17D3, 0x1280, 0x17D3, 0x1221, "ARC-1221 8-Port PCI-Express to SATA RAID Controller(0x17D3-0x1221)"},
{0x17D3, 0x1300, 0xFFFF, 0xFFFF, "ARC-1300ix-16 16-Port PCI-Express to SAS Non-RAID Host Adapter(0x1300)"},
{0x17D3, 0x1320, 0xFFFF, 0xFFFF, "ARC-1320 8/16 Port PCIe 2.0 to SAS/SATA 6Gb Non-RAID Host Adapter(0x1320)"},
{0x17D3, 0x1330, 0xFFFF, 0xFFFF, "ARC-1330 16 Port PCIe 3.0 to SAS/SATA 12Gb Non-RAID Host Adapter(0x1330)"},
{0x17D3, 0x1680, 0xFFFF, 0xFFFF, "ARC-1680 series PCIe to SAS/SATA 3Gb RAID Controller(0x1680)"},
{0x17D3, 0x1680, 0x17D3, 0x1212, "ARC-1212 4-Port PCIe to SAS/SATA II RAID Controller(0x17D3-0x1212)"},
{0x17D3, 0x1680, 0x17D3, 0x1222, "ARC-1222 8-Port PCIe to SAS/SATA 3Gb RAID Controller(0x17D3-0x1222)"},
{0x17D3, 0x1680, 0x17D3, 0x1680, "ARC-1680 8/12/16/24 Port PCIe to SAS/SATA 3Gb RAID Controller(0x17D3-0x1680)"},
{0x17D3, 0x1880, 0xFFFF, 0xFFFF, "ARC-188x series PCIe 2.0/3.0 to SAS/SATA 6/12Gb RAID Controller(0x1880)"},
{0x17D3, 0x1880, 0x17D3, 0x1213, "ARC-1213 4-Port PCIe 2.0 to SAS/SATA 6Gb RAID Controller(0x17D3-0x1213)"},
{0x17D3, 0x1880, 0x17D3, 0x1215, "ARC-1215 4-Port PCIe 3.0 to SAS/SATA 6Gb RAID Controller(0x17D3-0x1215)"},
{0x17D3, 0x1880, 0x17D3, 0x1216, "ARC-1216 4-Port PCIe 3.0 to SAS/SATA 12Gb RAID Controller(0x17D3-0x1216)"},
{0x17D3, 0x1880, 0x17D3, 0x1223, "ARC-1223 8-Port PCIe 2.0 to SAS/SATA 6Gb RAID Controller(0x17D3-0x1223)"},
{0x17D3, 0x1880, 0x17D3, 0x1225, "ARC-1225 8-Port PCIe 3.0 to SAS/SATA 6Gb RAID Controller(0x17D3-0x1225)"},
{0x17D3, 0x1880, 0x17D3, 0x1226, "ARC-1226 8-Port PCIe 3.0 to SAS/SATA 12Gb RAID Controller(0x17D3-0x1226)"},
{0x17D3, 0x1880, 0x17D3, 0x1880, "ARC-1880 8/12/16/24 Port PCIe 2.0 to SAS/SATA 6Gb RAID Controller(0x17D3-0x1880)"},
{0x17D3, 0x1880, 0x17D3, 0x1882, "ARC-1882 8/12/16/24 Port PCIe 3.0 to SAS/SATA 6Gb RAID Controller(0x17D3-0x1882)"},
{0x17D3, 0x1880, 0x17D3, 0x1883, "ARC-1883 8/12/16/24 Port PCIe 3.0 to SAS/SATA 12Gb RAID Controller(0x17D3-0x1883)"},
{0x17D3, 0x1884, 0xFFFF, 0xFFFF, "ARC-1884 series PCIe 3.0 to SAS/SATA 12/6Gb RAID Controller(0x1884)"},
{0x17D3, 0x1886, 0xFFFF, 0xFFFF, "ARC-1886 series PCIe 4.0 to NVMe/SAS/SATA 16/12/6Gb RAID Controller(0x1886)"},
{0x17D3, 0x1886, 0x17D3, 0x1686, "ARC-1686 PCIe 4.0 to NVMe/SAS/SATA 16/12/6Gb RAID Controller(0x17D3-0x1686)"},
{0x17D3, 0x1886, 0x17D3, 0x1886, "ARC-1886 PCIe 4.0 to NVMe/SAS/SATA 16/12/6Gb RAID Controller(0x17D3-0x1886)"},
{0x17D3, 0x188A, 0xFFFF, 0xFFFF, "ARC-1886 series PCIe 4.0 to NVMe/SAS/SATA 16/12/6Gb RAID Controller(0x188A)"},
{0x17D3, 0x188A, 0x17D3, 0x1217, "ARC-1217 4-Port PCIe 4.0 to SAS/SATA 12/6Gb RAID Controller(0x17D3-0x1217)"},
{0x17D3, 0x188A, 0x17D3, 0x1227, "ARC-1227 8-Port PCIe 4.0 to SAS/SATA 12/6Gb RAID Controller(0x17D3-0x1227)"},
{0x17D3, 0x188A, 0x17D3, 0x1686, "ARC-1686 PCIe 4.0 to NVMe/SAS/SATA 16/12/6Gb RAID Controller(0x17D3-0x1686)"},
{0x17D3, 0x188A, 0x17D3, 0x1688, "ARC-1688 PCIe 4.0 to NVMe/SAS/SATA 16/12/6Gb RAID Controller(0x17D3-0x1688)"},
{0x17D3, 0x188A, 0x17D3, 0x1886, "ARC-1886 PCIe 4.0 to NVMe/SAS/SATA 16/12/6Gb RAID Controller(0x17D3-0x1886)"},
}; /* pci_vid_17D3[] */

static pci_id_t const pci_vid_17D5[] = {
{0x17D5, 0xFFFF, 0xFFFF, 0xFFFF, "Exar Corp.(0x17D5)"},
{0x17D5, 0x5731, 0xFFFF, 0xFFFF, "Xframe 10-Gigabit Ethernet PCI-X(0x5731)"},
{0x17D5, 0x5732, 0xFFFF, 0xFFFF, "Xframe II 10-Gigabit Ethernet PCI-X 2.0(0x5732)"},
{0x17D5, 0x5831, 0xFFFF, 0xFFFF, "Xframe 10-Gigabit Ethernet PCI-X(0x5831)"},
{0x17D5, 0x5831, 0x103C, 0x12D5, "PCI-X 133MHz 10GbE SR Fiber(0x103C-0x12D5)"},
{0x17D5, 0x5831, 0x10A9, 0x8020, "Single Port 10-Gigabit Ethernet (PCI-X, Fiber)(0x10A9-0x8020)"},
{0x17D5, 0x5831, 0x10A9, 0x8024, "Single Port 10-Gigabit Ethernet (PCI-X, Fiber)(0x10A9-0x8024)"},
{0x17D5, 0x5832, 0xFFFF, 0xFFFF, "Xframe II 10-Gigabit Ethernet PCI-X 2.0(0x5832)"},
{0x17D5, 0x5832, 0x103C, 0x1337, "PCI-X 266MHz 10GigE SR [AD385A](0x103C-0x1337)"},
{0x17D5, 0x5832, 0x10A9, 0x8021, "Single Port 10-Gigabit Ethernet II (PCI-X, Fiber)(0x10A9-0x8021)"},
{0x17D5, 0x5832, 0x17D5, 0x6020, "Xframe II SR(0x17D5-0x6020)"},
{0x17D5, 0x5832, 0x17D5, 0x6021, "Xframe II SR, Low Profile(0x17D5-0x6021)"},
{0x17D5, 0x5832, 0x17D5, 0x6022, "Xframe E SR(0x17D5-0x6022)"},
{0x17D5, 0x5832, 0x17D5, 0x6420, "Xframe II LR(0x17D5-0x6420)"},
{0x17D5, 0x5832, 0x17D5, 0x6421, "Xframe II LR, Low Profile(0x17D5-0x6421)"},
{0x17D5, 0x5832, 0x17D5, 0x6422, "Xframe E LR(0x17D5-0x6422)"},
{0x17D5, 0x5832, 0x17D5, 0x6C20, "Xframe II CX4(0x17D5-0x6C20)"},
{0x17D5, 0x5832, 0x17D5, 0x6C21, "Xframe II CX4, Low Profile(0x17D5-0x6C21)"},
{0x17D5, 0x5832, 0x17D5, 0x6C22, "Xframe E CX4(0x17D5-0x6C22)"},
{0x17D5, 0x5833, 0xFFFF, 0xFFFF, "X3100 Series 10 Gigabit Ethernet PCIe(0x5833)"},
{0x17D5, 0x5833, 0x17D5, 0x6030, "X3110 Single Port SR(0x17D5-0x6030)"},
{0x17D5, 0x5833, 0x17D5, 0x6031, "X3120 Dual Port SR(0x17D5-0x6031)"},
{0x17D5, 0x5833, 0x17D5, 0x6430, "X3110 Single Port LR(0x17D5-0x6430)"},
{0x17D5, 0x5833, 0x17D5, 0x6431, "X3120 Dual Port LR(0x17D5-0x6431)"},
{0x17D5, 0x5833, 0x17D5, 0x7030, "X3110 Single Port LRM(0x17D5-0x7030)"},
{0x17D5, 0x5833, 0x17D5, 0x7031, "X3120 Dual Port LRM(0x17D5-0x7031)"},
{0x17D5, 0x5833, 0x17D5, 0x7430, "X3110 Single Port 10GBase-T(0x17D5-0x7430)"},
{0x17D5, 0x5833, 0x17D5, 0x7431, "X3120 Dual Port 10GBase-T(0x17D5-0x7431)"},
{0x17D5, 0x5833, 0x17D5, 0x7830, "X3110 Single Port 10GBase-CR(0x17D5-0x7830)"},
{0x17D5, 0x5833, 0x17D5, 0x7831, "X3120 Dual Port 10GBase-CR(0x17D5-0x7831)"},
}; /* pci_vid_17D5[] */

static pci_id_t const pci_vid_17DB[] = {
{0x17DB, 0xFFFF, 0xFFFF, 0xFFFF, "Cray Inc(0x17DB)"},
{0x17DB, 0x0101, 0xFFFF, 0xFFFF, "XT Series [Seastar] 3D Toroidal Router(0x0101)"},
{0x17DB, 0x0501, 0xFFFF, 0xFFFF, "Cassini 1 [Slingshot 200Gb](0x0501)"},
}; /* pci_vid_17DB[] */

static pci_id_t const pci_vid_17DE[] = {
{0x17DE, 0xFFFF, 0xFFFF, 0xFFFF, "KWorld Computer Co. Ltd.(0x17DE)"},
}; /* pci_vid_17DE[] */

static pci_id_t const pci_vid_17DF[] = {
{0x17DF, 0xFFFF, 0xFFFF, 0xFFFF, "Dini Group(0x17DF)"},
{0x17DF, 0x1864, 0xFFFF, 0xFFFF, "Virtex4 PCI Board w/ QL5064 Bridge [DN7000K10PCI/DN8000K10PCI/DN8000K10PSX/NOTUS](0x1864)"},
{0x17DF, 0x1865, 0xFFFF, 0xFFFF, "Virtex4 ASIC Emulator [DN8000K10PCIe](0x1865)"},
{0x17DF, 0x1866, 0xFFFF, 0xFFFF, "Virtex4 ASIC Emulator Cable Connection [DN8000K10PCI](0x1866)"},
{0x17DF, 0x1867, 0xFFFF, 0xFFFF, "Virtex4 ASIC Emulator Cable Connection [DN8000K10PCIe](0x1867)"},
{0x17DF, 0x1868, 0xFFFF, 0xFFFF, "Virtex4 ASIC Emulator [DN8000K10PCIe-8](0x1868)"},
{0x17DF, 0x1900, 0xFFFF, 0xFFFF, "Virtex5 PCIe ASIC Emulator [DN9000K10PCIe8T/DN9002K10PCIe8T/DN9200K10PCIe8T/DN7006K10PCIe8T/DN7406K10PCIe8T](0x1900)"},
{0x17DF, 0x1901, 0xFFFF, 0xFFFF, "Virtex5 PCIe ASIC Emulator Large BARs [DN9000K10PCIe8T/DN9002K10PCIe8T/DN9200K10PCIe8T/DN7006K10PCIe8T/DN7406K10PCIe8T](0x1901)"},
{0x17DF, 0x1902, 0xFFFF, 0xFFFF, "Virtex5 PCIe ASIC Emulator Low Power [Interceptor](0x1902)"},
{0x17DF, 0x1903, 0xFFFF, 0xFFFF, "Spartan6 PCIe FPGA Accelerator Board [DNBFCS12PCIe](0x1903)"},
{0x17DF, 0x1904, 0xFFFF, 0xFFFF, "Virtex6 PCIe ASIC Emulation Board [DNDUALV6_PCIe4](0x1904)"},
{0x17DF, 0x1905, 0xFFFF, 0xFFFF, "Virtex6 PCIe ASIC Emulation Board [DNV6F6PCIe](0x1905)"},
{0x17DF, 0x1906, 0xFFFF, 0xFFFF, "Virtex6 PCIe ASIC Emulation Board [DN2076K10](0x1906)"},
{0x17DF, 0x1907, 0xFFFF, 0xFFFF, "Virtex6 PCIe ASIC Emulation Board [DNV6F2PCIe](0x1907)"},
{0x17DF, 0x1908, 0xFFFF, 0xFFFF, "Virtex6 PCIe ASIC Emulation Board Large BARs[DNV6F2PCIe](0x1908)"},
{0x17DF, 0x1909, 0xFFFF, 0xFFFF, "Kintex7 PCIe FPGA Accelerator Board [DNK7F5PCIe](0x1909)"},
{0x17DF, 0x190A, 0xFFFF, 0xFFFF, "Virtex7 PCIe ASIC Emulation Board [DNV7F1A](0x190A)"},
{0x17DF, 0x190B, 0xFFFF, 0xFFFF, "Stratix5 PCIe ASIC Emulation Board [DNS5GXF2](0x190B)"},
{0x17DF, 0x190C, 0xFFFF, 0xFFFF, "Virtex7 PCIe ASIC Emulation Board [DNV7F2A](0x190C)"},
{0x17DF, 0x190D, 0xFFFF, 0xFFFF, "Virtex7 PCIe ASIC Emulation Board [DNV7F4A](0x190D)"},
{0x17DF, 0x190E, 0xFFFF, 0xFFFF, "Virtex7 PCIe ASIC Emulation Board [DNV7F2B](0x190E)"},
{0x17DF, 0x190F, 0xFFFF, 0xFFFF, "KintexUS PCIe MainRef Design [DNPCIE_40G_KU_LL](0x190F)"},
{0x17DF, 0x1910, 0xFFFF, 0xFFFF, "VirtexUS ASIC Emulation Board [DNVUF4A](0x1910)"},
{0x17DF, 0x1911, 0xFFFF, 0xFFFF, "VirtexUS PCIe ASIC Emulation Board [DNVU_F2PCIe](0x1911)"},
{0x17DF, 0x1912, 0xFFFF, 0xFFFF, "KintexUS PCIe MainRef Design [DNPCIe_40G_KU_LL_QSFP](0x1912)"},
{0x17DF, 0x1913, 0xFFFF, 0xFFFF, "VirtexUS ASIC Emulation Board [DNVUF1A](0x1913)"},
{0x17DF, 0x1914, 0xFFFF, 0xFFFF, "VirtexUS ASIC Emulation Board [DNVUF2A](0x1914)"},
{0x17DF, 0x1915, 0xFFFF, 0xFFFF, "Arria10 PCIe MainRef Design [DNPCIe_80G_A10_LL](0x1915)"},
{0x17DF, 0x1916, 0xFFFF, 0xFFFF, "VirtexUS PCIe Accelerator Board [DNVUF2_HPC_PCIe](0x1916)"},
{0x17DF, 0x1917, 0xFFFF, 0xFFFF, "UltrascalePlus PCIe Accelerator Board [DNPCIe_400G_VU_LL](0x1917)"},
{0x17DF, 0x1918, 0xFFFF, 0xFFFF, "VirtexUS+ ASIC Emulation Board [DNVUPF4A](0x1918)"},
{0x17DF, 0x1919, 0xFFFF, 0xFFFF, "UltrascalePlus PCIe Accelerator Board [DNPCIe_400G_VUP_HBM_LL](0x1919)"},
{0x17DF, 0x1A00, 0xFFFF, 0xFFFF, "Virtex6 PCIe DMA Netlist Design(0x1A00)"},
{0x17DF, 0x1A01, 0xFFFF, 0xFFFF, "Virtex6 PCIe Darklite Design [DNPCIe_HXT_10G_LL](0x1A01)"},
{0x17DF, 0x1A02, 0xFFFF, 0xFFFF, "Virtex7 PCIe DMA Netlist Design(0x1A02)"},
{0x17DF, 0x1A03, 0xFFFF, 0xFFFF, "Kintex7 PCIe Darklite Design [DNPCIe_K7_10G_LL](0x1A03)"},
{0x17DF, 0x1A05, 0xFFFF, 0xFFFF, "Stratix5 PCIe Darklite Design [DNS5GX_F2](0x1A05)"},
{0x17DF, 0x1A06, 0xFFFF, 0xFFFF, "VirtexUS PCIe DMA Netlist Design(0x1A06)"},
{0x17DF, 0x1A07, 0xFFFF, 0xFFFF, "KintexUS PCIe Darklite Design [DNPCIe_40G_KU_LL](0x1A07)"},
{0x17DF, 0x1A08, 0xFFFF, 0xFFFF, "KintexUS PCIe Darklite Design [DNPCIe_40G_KU_LL_QSFP](0x1A08)"},
{0x17DF, 0x1A09, 0xFFFF, 0xFFFF, "Arria10 PCIe Darklite Design [DNPCIe_80G_A10_LL](0x1A09)"},
{0x17DF, 0x1A0A, 0xFFFF, 0xFFFF, "VirtexUS PCIe Darklite Design [DNVUF2_HPC_PCIe](0x1A0A)"},
{0x17DF, 0x1A0B, 0xFFFF, 0xFFFF, "UltrascalePlus PCIe Darklite Design [DNPCIe_400G_VU_LL](0x1A0B)"},
{0x17DF, 0x1A0C, 0xFFFF, 0xFFFF, "KintexUS PCIe DRAM Packet Capture Design [DNPCIe_40G_KU_LL](0x1A0C)"},
{0x17DF, 0x1A0D, 0xFFFF, 0xFFFF, "KintexUS PCIe DRAM Packet Capture Design [DNPCIe_40G_KU_LL_2QSFP](0x1A0D)"},
{0x17DF, 0x1A0E, 0xFFFF, 0xFFFF, "UltrascalePlus PCIe Darklite Design [DNPCIe_400G_VUP_HBM_LL](0x1A0E)"},
}; /* pci_vid_17DF[] */

static pci_id_t const pci_vid_17E4[] = {
{0x17E4, 0xFFFF, 0xFFFF, 0xFFFF, "Sectra AB(0x17E4)"},
{0x17E4, 0x0001, 0xFFFF, 0xFFFF, "KK671 Cardbus encryption board(0x0001)"},
{0x17E4, 0x0002, 0xFFFF, 0xFFFF, "KK672 Cardbus encryption board(0x0002)"},
}; /* pci_vid_17E4[] */

static pci_id_t const pci_vid_17E6[] = {
{0x17E6, 0xFFFF, 0xFFFF, 0xFFFF, "MaxLinear(0x17E6)"},
{0x17E6, 0x0010, 0xFFFF, 0xFFFF, "EN2010 [c.Link] MoCA Network Controller (Coax, PCI interface)(0x0010)"},
{0x17E6, 0x0011, 0xFFFF, 0xFFFF, "EN2010 [c.Link] MoCA Network Controller (Coax, MPEG interface)(0x0011)"},
{0x17E6, 0x0021, 0xFFFF, 0xFFFF, "EN2210 [c.Link] MoCA Network Controller (Coax)(0x0021)"},
{0x17E6, 0x0025, 0xFFFF, 0xFFFF, "EN2510 [c.Link] MoCA Network Controller (Coax, PCIe interface)(0x0025)"},
{0x17E6, 0x0027, 0xFFFF, 0xFFFF, "EN2710 [c.Link] MoCA 2.0 Network Controller (Coax, PCIe interface)(0x0027)"},
{0x17E6, 0x3700, 0xFFFF, 0xFFFF, "MoCA 2.0 Network Controller (Coax, PCIe interface)(0x3700)"},
{0x17E6, 0x3710, 0xFFFF, 0xFFFF, "MoCA 2.5 Network Controller (Coax, PCIe interface)(0x3710)"},
}; /* pci_vid_17E6[] */

static pci_id_t const pci_vid_17EE[] = {
{0x17EE, 0xFFFF, 0xFFFF, 0xFFFF, "Connect Components Ltd(0x17EE)"},
}; /* pci_vid_17EE[] */

static pci_id_t const pci_vid_17F2[] = {
{0x17F2, 0xFFFF, 0xFFFF, 0xFFFF, "Albatron Corp.(0x17F2)"},
}; /* pci_vid_17F2[] */

static pci_id_t const pci_vid_17F3[] = {
{0x17F3, 0xFFFF, 0xFFFF, 0xFFFF, "RDC Semiconductor, Inc.(0x17F3)"},
{0x17F3, 0x1010, 0xFFFF, 0xFFFF, "R1010 IDE Controller(0x1010)"},
{0x17F3, 0x1011, 0xFFFF, 0xFFFF, "R1011 IDE Controller(0x1011)"},
{0x17F3, 0x1012, 0xFFFF, 0xFFFF, "R1012 IDE Controller(0x1012)"},
{0x17F3, 0x1031, 0xFFFF, 0xFFFF, "PCI/PCI-X to PCI-E Bridge(0x1031)"},
{0x17F3, 0x1070, 0xFFFF, 0xFFFF, "CAN Bus Controller(0x1070)"},
{0x17F3, 0x1331, 0xFFFF, 0xFFFF, "Motion Control Interface(0x1331)"},
{0x17F3, 0x1930, 0xFFFF, 0xFFFF, "Hybrid Function Control Register(0x1930)"},
{0x17F3, 0x2010, 0xFFFF, 0xFFFF, "RDC M2010 VGA-compatible graphics adapter(0x2010)"},
{0x17F3, 0x2012, 0xFFFF, 0xFFFF, "M2012/R3308 VGA-compatible graphics adapter(0x2012)"},
{0x17F3, 0x2015, 0xFFFF, 0xFFFF, "RDC M2015 VGA-compatible graphics adapter(0x2015)"},
{0x17F3, 0x3010, 0xFFFF, 0xFFFF, "R3010 HD Audio Controller(0x3010)"},
{0x17F3, 0x6011, 0xFFFF, 0xFFFF, "R6011 ISA Bridge(0x6011)"},
{0x17F3, 0x6013, 0xFFFF, 0xFFFF, "R6013 ISA Bridge(0x6013)"},
{0x17F3, 0x6020, 0xFFFF, 0xFFFF, "R6020 North Bridge(0x6020)"},
{0x17F3, 0x6021, 0xFFFF, 0xFFFF, "R6021 Host Bridge(0x6021)"},
{0x17F3, 0x6022, 0xFFFF, 0xFFFF, "R6022 Host Bridge(0x6022)"},
{0x17F3, 0x6023, 0xFFFF, 0xFFFF, "R6023 Host Bridge(0x6023)"},
{0x17F3, 0x6025, 0xFFFF, 0xFFFF, "R6025 Host Bridge(0x6025)"},
{0x17F3, 0x6026, 0xFFFF, 0xFFFF, "R6026 Host Bridge(0x6026)"},
{0x17F3, 0x6030, 0xFFFF, 0xFFFF, "R6030 ISA Bridge(0x6030)"},
{0x17F3, 0x6031, 0xFFFF, 0xFFFF, "R6031 ISA Bridge(0x6031)"},
{0x17F3, 0x6035, 0xFFFF, 0xFFFF, "R6035 ISA Bridge(0x6035)"},
{0x17F3, 0x6036, 0xFFFF, 0xFFFF, "R6036 ISA Bridge(0x6036)"},
{0x17F3, 0x6040, 0xFFFF, 0xFFFF, "R6040 MAC Controller(0x6040)"},
{0x17F3, 0x6060, 0xFFFF, 0xFFFF, "R6060 USB 1.1 Controller(0x6060)"},
{0x17F3, 0x6061, 0xFFFF, 0xFFFF, "R6061 USB 2.0 Controller(0x6061)"},
}; /* pci_vid_17F3[] */

static pci_id_t const pci_vid_17F7[] = {
{0x17F7, 0xFFFF, 0xFFFF, 0xFFFF, "Topdek Semiconductor Inc.(0x17F7)"},
}; /* pci_vid_17F7[] */

static pci_id_t const pci_vid_17F9[] = {
{0x17F9, 0xFFFF, 0xFFFF, 0xFFFF, "Gemtek Technology Co., Ltd(0x17F9)"},
}; /* pci_vid_17F9[] */

static pci_id_t const pci_vid_17FC[] = {
{0x17FC, 0xFFFF, 0xFFFF, 0xFFFF, "IOGEAR, Inc.(0x17FC)"},
}; /* pci_vid_17FC[] */

static pci_id_t const pci_vid_17FE[] = {
{0x17FE, 0xFFFF, 0xFFFF, 0xFFFF, "InProComm Inc.(0x17FE)"},
{0x17FE, 0x2120, 0xFFFF, 0xFFFF, "IPN 2120 802.11b(0x2120)"},
{0x17FE, 0x2120, 0x1737, 0x0020, "WMP11 v4 802.11b Wireless-B PCI Adapter(0x1737-0x0020)"},
{0x17FE, 0x2220, 0xFFFF, 0xFFFF, "IPN 2220 802.11g(0x2220)"},
{0x17FE, 0x2220, 0x1468, 0x0305, "T60N871 802.11g Mini PCI Wireless Adapter(0x1468-0x0305)"},
{0x17FE, 0x2220, 0x1737, 0x0029, "WPC54G v4 802.11g Wireless-G Notebook Adapter(0x1737-0x0029)"},
}; /* pci_vid_17FE[] */

static pci_id_t const pci_vid_17FF[] = {
{0x17FF, 0xFFFF, 0xFFFF, 0xFFFF, "Benq Corporation(0x17FF)"},
}; /* pci_vid_17FF[] */

static pci_id_t const pci_vid_1800[] = {
{0x1800, 0xFFFF, 0xFFFF, 0xFFFF, "Qualcore Logic Inc.(0x1800)"},
{0x1800, 0x1100, 0xFFFF, 0xFFFF, "Nanospeed Trading Gateway(0x1100)"},
}; /* pci_vid_1800[] */

static pci_id_t const pci_vid_1803[] = {
{0x1803, 0xFFFF, 0xFFFF, 0xFFFF, "ProdaSafe GmbH(0x1803)"},
}; /* pci_vid_1803[] */

static pci_id_t const pci_vid_1804[] = {
{0x1804, 0xFFFF, 0xFFFF, 0xFFFF, "Ralink corp. (wrong ID)(0x1804)"},
{0x1804, 0x3060, 0xFFFF, 0xFFFF, "RT3060 Wireless 802.11n 1T/1R(0x3060)"},
}; /* pci_vid_1804[] */

static pci_id_t const pci_vid_1805[] = {
{0x1805, 0xFFFF, 0xFFFF, 0xFFFF, "Euresys S.A.(0x1805)"},
{0x1805, 0x0201, 0xFFFF, 0xFFFF, "PICOLO Alert PCI(0x0201)"},
{0x1805, 0x0202, 0xFFFF, 0xFFFF, "PICOLO Diligent(0x0202)"},
{0x1805, 0x0204, 0xFFFF, 0xFFFF, "PICOLO Alert-RC(0x0204)"},
{0x1805, 0x0205, 0xFFFF, 0xFFFF, "PICOLO Alert PCIe(0x0205)"},
{0x1805, 0x0206, 0xFFFF, 0xFFFF, "PICOLO Diligent Plus PCIe(0x0206)"},
{0x1805, 0x0207, 0xFFFF, 0xFFFF, "PICOLO Alert-RC PCIe(0x0207)"},
{0x1805, 0x0300, 0xFFFF, 0xFFFF, "GRABLINK Expert 2(0x0300)"},
{0x1805, 0x0301, 0xFFFF, 0xFFFF, "GRABLINK Quickpack ColorScan(0x0301)"},
{0x1805, 0x0302, 0xFFFF, 0xFFFF, "GRABLINK Value cPCI(0x0302)"},
{0x1805, 0x0303, 0xFFFF, 0xFFFF, "GRABLINK Expert 2 cPCI(0x0303)"},
{0x1805, 0x0305, 0xFFFF, 0xFFFF, "GRABLINK Avenue(0x0305)"},
{0x1805, 0x0306, 0xFFFF, 0xFFFF, "GRABLINK Quickpack CFA(0x0306)"},
{0x1805, 0x0307, 0xFFFF, 0xFFFF, "GRABLINK Express(0x0307)"},
{0x1805, 0x0308, 0xFFFF, 0xFFFF, "GRABLINK Quickpack CFA PCIe(0x0308)"},
{0x1805, 0x0309, 0xFFFF, 0xFFFF, "GRABLINK Quickpack CFA PCIe (Recovery)(0x0309)"},
{0x1805, 0x030A, 0xFFFF, 0xFFFF, "GRABLINK Full(0x030A)"},
{0x1805, 0x030B, 0xFFFF, 0xFFFF, "GRABLINK Full (Recovery)(0x030B)"},
{0x1805, 0x030C, 0xFFFF, 0xFFFF, "GRABLINK DualBase(0x030C)"},
{0x1805, 0x030D, 0xFFFF, 0xFFFF, "GRABLINK DualBase (Recovery)(0x030D)"},
{0x1805, 0x030E, 0xFFFF, 0xFFFF, "GRABLINK Base(0x030E)"},
{0x1805, 0x030F, 0xFFFF, 0xFFFF, "GRABLINK Base (Recovery)(0x030F)"},
{0x1805, 0x0310, 0xFFFF, 0xFFFF, "GRABLINK Full XR(0x0310)"},
{0x1805, 0x0311, 0xFFFF, 0xFFFF, "GRABLINK Full XR (Recovery)(0x0311)"},
{0x1805, 0x0401, 0xFFFF, 0xFFFF, "DOMINO Iota(0x0401)"},
{0x1805, 0x0402, 0xFFFF, 0xFFFF, "DOMINO Alpha 2(0x0402)"},
{0x1805, 0x0403, 0xFFFF, 0xFFFF, "DOMINO Harmony(0x0403)"},
{0x1805, 0x0404, 0xFFFF, 0xFFFF, "DOMINO Melody(0x0404)"},
{0x1805, 0x0407, 0xFFFF, 0xFFFF, "DOMINO Symphony(0x0407)"},
{0x1805, 0x0408, 0xFFFF, 0xFFFF, "DOMINO Symphony PCIe(0x0408)"},
}; /* pci_vid_1805[] */

static pci_id_t const pci_vid_1809[] = {
{0x1809, 0xFFFF, 0xFFFF, 0xFFFF, "Lumanate, Inc.(0x1809)"},
}; /* pci_vid_1809[] */

static pci_id_t const pci_vid_180C[] = {
{0x180C, 0xFFFF, 0xFFFF, 0xFFFF, "IEI Integration Corp(0x180C)"},
}; /* pci_vid_180C[] */

static pci_id_t const pci_vid_1813[] = {
{0x1813, 0xFFFF, 0xFFFF, 0xFFFF, "Ambient Technologies Inc(0x1813)"},
{0x1813, 0x4000, 0xFFFF, 0xFFFF, "HaM controllerless modem(0x4000)"},
{0x1813, 0x4000, 0x16BE, 0x0001, "V9x HAM Data Fax Modem(0x16BE-0x0001)"},
{0x1813, 0x4100, 0xFFFF, 0xFFFF, "HaM plus Data Fax Modem(0x4100)"},
{0x1813, 0x4100, 0x16BE, 0x0002, "V9x HAM 1394(0x16BE-0x0002)"},
}; /* pci_vid_1813[] */

static pci_id_t const pci_vid_1814[] = {
{0x1814, 0xFFFF, 0xFFFF, 0xFFFF, "Ralink corp.(0x1814)"},
{0x1814, 0x0101, 0xFFFF, 0xFFFF, "Wireless PCI Adapter RT2400 / RT2460(0x0101)"},
{0x1814, 0x0101, 0x1043, 0x0127, "WiFi-b add-on Card(0x1043-0x0127)"},
{0x1814, 0x0101, 0x1371, 0x0010, "Minitar MNW2BPCI Wireless PCI Card(0x1371-0x0010)"},
{0x1814, 0x0101, 0x1462, 0x6828, "PC11B2 (MS-6828) Wireless 11b PCI Card(0x1462-0x6828)"},
{0x1814, 0x0200, 0xFFFF, 0xFFFF, "RT2500 802.11g PCI [PC54G2](0x0200)"},
{0x1814, 0x0201, 0xFFFF, 0xFFFF, "RT2500 Wireless 802.11bg(0x0201)"},
{0x1814, 0x0201, 0x1043, 0x130F, "WL-130g(0x1043-0x130F)"},
{0x1814, 0x0201, 0x1186, 0x3C00, "DWL-G650X Wireless 11g CardBus Adapter(0x1186-0x3C00)"},
{0x1814, 0x0201, 0x1371, 0x001E, "CWC-854 Wireless-G CardBus Adapter(0x1371-0x001E)"},
{0x1814, 0x0201, 0x1371, 0x001F, "CWM-854 Wireless-G Mini PCI Adapter(0x1371-0x001F)"},
{0x1814, 0x0201, 0x1371, 0x0020, "CWP-854 Wireless-G PCI Adapter(0x1371-0x0020)"},
{0x1814, 0x0201, 0x1458, 0xE381, "GN-WMKG 802.11b/g Wireless CardBus Adapter(0x1458-0xE381)"},
{0x1814, 0x0201, 0x1458, 0xE931, "GN-WIKG 802.11b/g mini-PCI Adapter(0x1458-0xE931)"},
{0x1814, 0x0201, 0x1462, 0x6833, "Unknown 802.11g mini-PCI Adapter(0x1462-0x6833)"},
{0x1814, 0x0201, 0x1462, 0x6835, "Wireless 11G CardBus CB54G2(0x1462-0x6835)"},
{0x1814, 0x0201, 0x1737, 0x0032, "WMP54G v4.0 PCI Adapter(0x1737-0x0032)"},
{0x1814, 0x0201, 0x1799, 0x700A, "F5D7000 v2000/v3000 Wireless G Desktop Card(0x1799-0x700A)"},
{0x1814, 0x0201, 0x1799, 0x701A, "F5D7010 v2000/v3000 Wireless G Notebook Card(0x1799-0x701A)"},
{0x1814, 0x0201, 0x1814, 0x2560, "RT2500 Wireless 802.11bg(0x1814-0x2560)"},
{0x1814, 0x0201, 0x182D, 0x9073, "WL-115 Wireless Network PCI Adapter(0x182D-0x9073)"},
{0x1814, 0x0201, 0x185F, 0x22A0, "CN-WF513 Wireless Cardbus Adapter(0x185F-0x22A0)"},
{0x1814, 0x0201, 0x18EB, 0x5312, "WL531P IEEE 802.11g PCI Card-EU(0x18EB-0x5312)"},
{0x1814, 0x0201, 0x1948, 0x3C00, "C54RC v1 Wireless 11g CardBus Adapter(0x1948-0x3C00)"},
{0x1814, 0x0201, 0x1948, 0x3C01, "C54Ri v1 Wireless 11g PCI Adapter(0x1948-0x3C01)"},
{0x1814, 0x0300, 0xFFFF, 0xFFFF, "Wireless Adapter Canyon CN-WF511(0x0300)"},
{0x1814, 0x0301, 0xFFFF, 0xFFFF, "RT2561/RT61 802.11g PCI(0x0301)"},
{0x1814, 0x0301, 0x1186, 0x3C08, "AirPlus G DWL-G630 Wireless Cardbus Adapter (rev.E1)(0x1186-0x3C08)"},
{0x1814, 0x0301, 0x1186, 0x3C09, "DWL-G510 Rev C(0x1186-0x3C09)"},
{0x1814, 0x0301, 0x13D1, 0xABE3, "miniPCI Pluscom 802.11 a/b/g(0x13D1-0xABE3)"},
{0x1814, 0x0301, 0x1458, 0xE933, "GN-WI01GS(0x1458-0xE933)"},
{0x1814, 0x0301, 0x1458, 0xE934, "GN-WP01GS(0x1458-0xE934)"},
{0x1814, 0x0301, 0x1462, 0xB833, "MP54G5 (MS-6833B)(0x1462-0xB833)"},
{0x1814, 0x0301, 0x1737, 0x0055, "WMP54G v4.1(0x1737-0x0055)"},
{0x1814, 0x0301, 0x1799, 0x700E, "F5D7000 v6000 Wireless G Desktop Card(0x1799-0x700E)"},
{0x1814, 0x0301, 0x1799, 0x701E, "F5D7010 v6000 Wireless G Notebook Card(0x1799-0x701E)"},
{0x1814, 0x0301, 0x17F9, 0x0012, "AWLC3026T 802.11g Wireless CardBus Adapter(0x17F9-0x0012)"},
{0x1814, 0x0301, 0x1814, 0x2561, "EW-7108PCg/EW-7128g(0x1814-0x2561)"},
{0x1814, 0x0302, 0xFFFF, 0xFFFF, "RT2561/RT61 rev B 802.11g(0x0302)"},
{0x1814, 0x0302, 0x1186, 0x3A71, "DWA-510 Wireless G Desktop Adapter(0x1186-0x3A71)"},
{0x1814, 0x0302, 0x1186, 0x3C08, "AirPlus G DWL-G630 Wireless Cardbus Adapter (rev.E2)(0x1186-0x3C08)"},
{0x1814, 0x0302, 0x1186, 0x3C09, "AirPlus G DWL-G510 Wireless Network Adapter (Rev.C)(0x1186-0x3C09)"},
{0x1814, 0x0302, 0x1462, 0xB834, "PC54G3 Wireless 11g PCI Card(0x1462-0xB834)"},
{0x1814, 0x0302, 0x1948, 0x3C23, "C54RC v2 Wireless 11g CardBus Adapter(0x1948-0x3C23)"},
{0x1814, 0x0302, 0x1948, 0x3C24, "C54Ri v2 Wireless 11g PCI Adapter(0x1948-0x3C24)"},
{0x1814, 0x0401, 0xFFFF, 0xFFFF, "RT2600 802.11 MIMO(0x0401)"},
{0x1814, 0x0401, 0x1737, 0x0052, "WPC54GR v1 802.11g Wireless-G Notebook Adapter with RangeBooster(0x1737-0x0052)"},
{0x1814, 0x0401, 0x17F9, 0x0011, "WPCR-137G 802.11bg Wireless CardBus Adapter(0x17F9-0x0011)"},
{0x1814, 0x0401, 0x17F9, 0x0016, "WPIR-119GH 802.11bg Wireless Desktop Adapter(0x17F9-0x0016)"},
{0x1814, 0x0601, 0xFFFF, 0xFFFF, "RT2800 802.11n PCI(0x0601)"},
{0x1814, 0x0601, 0x1799, 0x801C, "F5D8011 v3 802.11n N1 Wireless Notebook Card(0x1799-0x801C)"},
{0x1814, 0x0601, 0x187E, 0x3412, "NWD-310N 802.11n Wireless PCI Adapter(0x187E-0x3412)"},
{0x1814, 0x0681, 0xFFFF, 0xFFFF, "RT2890 Wireless 802.11n PCIe(0x0681)"},
{0x1814, 0x0681, 0x1458, 0xE939, "GN-WS30N-RH 802.11bgn Mini PCIe Card(0x1458-0xE939)"},
{0x1814, 0x0701, 0xFFFF, 0xFFFF, "RT2760 Wireless 802.11n 1T/2R(0x0701)"},
{0x1814, 0x0701, 0x1737, 0x0074, "WMP110 v2 802.11n RangePlus Wireless PCI Adapter(0x1737-0x0074)"},
{0x1814, 0x0781, 0xFFFF, 0xFFFF, "RT2790 Wireless 802.11n 1T/2R PCIe(0x0781)"},
{0x1814, 0x0781, 0x11AD, 0x7600, "HP WN7600R(0x11AD-0x7600)"},
{0x1814, 0x0781, 0x1814, 0x2790, "RT2790 Wireless 802.11n 1T/2R PCIe(0x1814-0x2790)"},
{0x1814, 0x3060, 0xFFFF, 0xFFFF, "RT3060 Wireless 802.11n 1T/1R(0x3060)"},
{0x1814, 0x3060, 0x1186, 0x3C04, "DWA-525 Wireless N 150 Desktop Adapter (rev.A1)(0x1186-0x3C04)"},
{0x1814, 0x3062, 0xFFFF, 0xFFFF, "RT3062 Wireless 802.11n 2T/2R(0x3062)"},
{0x1814, 0x3090, 0xFFFF, 0xFFFF, "RT3090 Wireless 802.11n 1T/1R PCIe(0x3090)"},
{0x1814, 0x3090, 0x13BD, 0x1057, "GN-WS32L-RH Half-size Mini PCIe Card(0x13BD-0x1057)"},
{0x1814, 0x3091, 0xFFFF, 0xFFFF, "RT3091 Wireless 802.11n 1T/2R PCIe(0x3091)"},
{0x1814, 0x3092, 0xFFFF, 0xFFFF, "RT3092 Wireless 802.11n 2T/2R PCIe(0x3092)"},
{0x1814, 0x3290, 0xFFFF, 0xFFFF, "RT3290 Wireless 802.11n 1T/1R PCIe(0x3290)"},
{0x1814, 0x3290, 0x103C, 0x18EC, "Ralink RT3290LE 802.11bgn 1x1 Wi-Fi and Bluetooth 4.0 Combo Adapter(0x103C-0x18EC)"},
{0x1814, 0x3298, 0xFFFF, 0xFFFF, "RT3290 Bluetooth(0x3298)"},
{0x1814, 0x3298, 0x103C, 0x18EC, "Ralink RT3290LE 802.11bgn 1x1 Wi-Fi and Bluetooth 4.0 Combo Adapter(0x103C-0x18EC)"},
{0x1814, 0x3592, 0xFFFF, 0xFFFF, "RT3592 Wireless 802.11abgn 2T/2R PCIe(0x3592)"},
{0x1814, 0x359F, 0xFFFF, 0xFFFF, "RT3592 PCIe Wireless Network Adapter(0x359F)"},
{0x1814, 0x5360, 0xFFFF, 0xFFFF, "RT5360 Wireless 802.11n 1T/1R(0x5360)"},
{0x1814, 0x5360, 0x1186, 0x3C05, "DWA-525 Wireless N 150 Desktop Adapter (rev.A2)(0x1186-0x3C05)"},
{0x1814, 0x5360, 0x20F4, 0x703A, "TEW-703PI N150 Wireless PCI Adapter(0x20F4-0x703A)"},
{0x1814, 0x5362, 0xFFFF, 0xFFFF, "RT5362 PCI 802.11n Wireless Network Adapter(0x5362)"},
{0x1814, 0x5390, 0xFFFF, 0xFFFF, "RT5390 Wireless 802.11n 1T/1R PCIe(0x5390)"},
{0x1814, 0x5390, 0x103C, 0x1636, "U98Z077.00 Half-size Mini PCIe Card(0x103C-0x1636)"},
{0x1814, 0x5392, 0xFFFF, 0xFFFF, "RT5392 PCIe Wireless Network Adapter(0x5392)"},
{0x1814, 0x539B, 0xFFFF, 0xFFFF, "RT5390R 802.11bgn PCIe Wireless Network Adapter(0x539B)"},
{0x1814, 0x539F, 0xFFFF, 0xFFFF, "RT5390 [802.11 b/g/n 1T1R G-band PCI Express Single Chip](0x539F)"},
{0x1814, 0x539F, 0x103C, 0x1637, "Pavilion DM1Z-3000 PCIe wireless card(0x103C-0x1637)"},
{0x1814, 0x5592, 0xFFFF, 0xFFFF, "RT5592 PCIe Wireless Network Adapter(0x5592)"},
{0x1814, 0xE932, 0xFFFF, 0xFFFF, "RT2560F 802.11 b/g PCI(0xE932)"},
}; /* pci_vid_1814[] */

static pci_id_t const pci_vid_1815[] = {
{0x1815, 0xFFFF, 0xFFFF, 0xFFFF, "Devolo AG(0x1815)"},
}; /* pci_vid_1815[] */

static pci_id_t const pci_vid_1820[] = {
{0x1820, 0xFFFF, 0xFFFF, 0xFFFF, "InfiniCon Systems Inc.(0x1820)"},
}; /* pci_vid_1820[] */

static pci_id_t const pci_vid_1822[] = {
{0x1822, 0xFFFF, 0xFFFF, 0xFFFF, "Twinhan Technology Co. Ltd(0x1822)"},
{0x1822, 0x4E35, 0xFFFF, 0xFFFF, "Mantis DTV PCI Bridge Controller [Ver 1.0](0x4E35)"},
}; /* pci_vid_1822[] */

static pci_id_t const pci_vid_182D[] = {
{0x182D, 0xFFFF, 0xFFFF, 0xFFFF, "SiteCom Europe BV(0x182D)"},
{0x182D, 0x3069, 0xFFFF, 0xFFFF, "ISDN PCI DC-105V2(0x3069)"},
{0x182D, 0x9790, 0xFFFF, 0xFFFF, "WL-121 Wireless Network Adapter 100g+ [Ver.3](0x9790)"},
}; /* pci_vid_182D[] */

static pci_id_t const pci_vid_182E[] = {
{0x182E, 0xFFFF, 0xFFFF, 0xFFFF, "Raza Microelectronics, Inc.(0x182E)"},
{0x182E, 0x0008, 0xFFFF, 0xFFFF, "XLR516 Processor(0x0008)"},
}; /* pci_vid_182E[] */

static pci_id_t const pci_vid_182F[] = {
{0x182F, 0xFFFF, 0xFFFF, 0xFFFF, "Broadcom(0x182F)"},
{0x182F, 0x000B, 0xFFFF, 0xFFFF, "BCM5785 [HT1000] SATA (RAID Mode)(0x000B)"},
}; /* pci_vid_182F[] */

static pci_id_t const pci_vid_1830[] = {
{0x1830, 0xFFFF, 0xFFFF, 0xFFFF, "Credence Systems Corporation(0x1830)"},
{0x1830, 0x8000, 0xFFFF, 0xFFFF, "CPIn(0x8000)"},
{0x1830, 0x8001, 0xFFFF, 0xFFFF, "CPId(0x8001)"},
{0x1830, 0x8002, 0xFFFF, 0xFFFF, "CPIx(0x8002)"},
{0x1830, 0x8003, 0xFFFF, 0xFFFF, "CPIq(0x8003)"},
}; /* pci_vid_1830[] */

static pci_id_t const pci_vid_183B[] = {
{0x183B, 0xFFFF, 0xFFFF, 0xFFFF, "MikroM GmbH(0x183B)"},
{0x183B, 0x08A7, 0xFFFF, 0xFFFF, "MVC100 DVI(0x08A7)"},
{0x183B, 0x08A8, 0xFFFF, 0xFFFF, "MVC101 SDI(0x08A8)"},
{0x183B, 0x08A9, 0xFFFF, 0xFFFF, "MVC102 DVI+Audio(0x08A9)"},
{0x183B, 0x08B0, 0xFFFF, 0xFFFF, "MVC200-DC(0x08B0)"},
}; /* pci_vid_183B[] */

static pci_id_t const pci_vid_1846[] = {
{0x1846, 0xFFFF, 0xFFFF, 0xFFFF, "Alcatel-Lucent(0x1846)"},
}; /* pci_vid_1846[] */

static pci_id_t const pci_vid_1849[] = {
{0x1849, 0xFFFF, 0xFFFF, 0xFFFF, "ASRock Incorporation(0x1849)"},
{0x1849, 0x9602, 0xFFFF, 0xFFFF, "RS780/RS880 PCI to PCI bridge (int gfx)(0x9602)"},
}; /* pci_vid_1849[] */

static pci_id_t const pci_vid_184A[] = {
{0x184A, 0xFFFF, 0xFFFF, 0xFFFF, "Thales Computers(0x184A)"},
{0x184A, 0x1100, 0xFFFF, 0xFFFF, "MAX II cPLD(0x1100)"},
}; /* pci_vid_184A[] */

static pci_id_t const pci_vid_1850[] = {
{0x1850, 0xFFFF, 0xFFFF, 0xFFFF, "Advantest Corporation(0x1850)"},
{0x1850, 0x0048, 0xFFFF, 0xFFFF, "EK220-66401 Computer Interface Card(0x0048)"},
}; /* pci_vid_1850[] */

static pci_id_t const pci_vid_1851[] = {
{0x1851, 0xFFFF, 0xFFFF, 0xFFFF, "Microtune, Inc.(0x1851)"},
}; /* pci_vid_1851[] */

static pci_id_t const pci_vid_1852[] = {
{0x1852, 0xFFFF, 0xFFFF, 0xFFFF, "Anritsu Corp.(0x1852)"},
}; /* pci_vid_1852[] */

static pci_id_t const pci_vid_1853[] = {
{0x1853, 0xFFFF, 0xFFFF, 0xFFFF, "SMSC Automotive Infotainment System Group(0x1853)"},
}; /* pci_vid_1853[] */

static pci_id_t const pci_vid_1854[] = {
{0x1854, 0xFFFF, 0xFFFF, 0xFFFF, "LG Electronics, Inc.(0x1854)"},
}; /* pci_vid_1854[] */

static pci_id_t const pci_vid_185B[] = {
{0x185B, 0xFFFF, 0xFFFF, 0xFFFF, "Compro Technology, Inc.(0x185B)"},
{0x185B, 0x1489, 0xFFFF, 0xFFFF, "VideoMate Vista T100(0x1489)"},
}; /* pci_vid_185B[] */

static pci_id_t const pci_vid_185F[] = {
{0x185F, 0xFFFF, 0xFFFF, 0xFFFF, "Wistron NeWeb Corp.(0x185F)"},
}; /* pci_vid_185F[] */

static pci_id_t const pci_vid_1864[] = {
{0x1864, 0xFFFF, 0xFFFF, 0xFFFF, "SilverBack(0x1864)"},
{0x1864, 0x2110, 0xFFFF, 0xFFFF, "ISNAP 2110(0x2110)"},
}; /* pci_vid_1864[] */

static pci_id_t const pci_vid_1867[] = {
{0x1867, 0xFFFF, 0xFFFF, 0xFFFF, "Topspin Communications(0x1867)"},
{0x1867, 0x5A44, 0xFFFF, 0xFFFF, "MT23108 InfiniHost HCA(0x5A44)"},
{0x1867, 0x5A45, 0xFFFF, 0xFFFF, "MT23108 InfiniHost HCA flash recovery(0x5A45)"},
{0x1867, 0x5A46, 0xFFFF, 0xFFFF, "MT23108 InfiniHost HCA bridge(0x5A46)"},
{0x1867, 0x6278, 0xFFFF, 0xFFFF, "MT25208 InfiniHost III Ex (Tavor compatibility mode)(0x6278)"},
{0x1867, 0x6282, 0xFFFF, 0xFFFF, "MT25208 InfiniHost III Ex(0x6282)"},
}; /* pci_vid_1867[] */

static pci_id_t const pci_vid_186C[] = {
{0x186C, 0xFFFF, 0xFFFF, 0xFFFF, "Humusoft, s.r.o.(0x186C)"},
{0x186C, 0x0612, 0xFFFF, 0xFFFF, "AD612 Data Acquisition Device(0x0612)"},
{0x186C, 0x0614, 0xFFFF, 0xFFFF, "MF614 Multifunction I/O Card(0x0614)"},
{0x186C, 0x0622, 0xFFFF, 0xFFFF, "AD622 Data Acquisition Device(0x0622)"},
{0x186C, 0x0624, 0xFFFF, 0xFFFF, "MF624 Multifunction I/O PCI Card(0x0624)"},
{0x186C, 0x0625, 0xFFFF, 0xFFFF, "MF625 3-phase Motor Driver(0x0625)"},
{0x186C, 0x0634, 0xFFFF, 0xFFFF, "MF634 Multifunction I/O PCIe Card(0x0634)"},
{0x186C, 0x0644, 0xFFFF, 0xFFFF, "MF644 Multifunction I/O Thb Card(0x0644)"},
}; /* pci_vid_186C[] */

static pci_id_t const pci_vid_186F[] = {
{0x186F, 0xFFFF, 0xFFFF, 0xFFFF, "WiNRADiO Communications(0x186F)"},
}; /* pci_vid_186F[] */

static pci_id_t const pci_vid_1876[] = {
{0x1876, 0xFFFF, 0xFFFF, 0xFFFF, "L-3 Communications(0x1876)"},
{0x1876, 0xA101, 0xFFFF, 0xFFFF, "VigraWATCH PCI(0xA101)"},
{0x1876, 0xA102, 0xFFFF, 0xFFFF, "VigraWATCH PMC(0xA102)"},
{0x1876, 0xA103, 0xFFFF, 0xFFFF, "Vigra I/O(0xA103)"},
}; /* pci_vid_1876[] */

static pci_id_t const pci_vid_187E[] = {
{0x187E, 0xFFFF, 0xFFFF, 0xFFFF, "ZyXEL Communications Corporation(0x187E)"},
{0x187E, 0x3403, 0xFFFF, 0xFFFF, "ZyAir G-110 802.11g(0x3403)"},
{0x187E, 0x340E, 0xFFFF, 0xFFFF, "M-302 802.11g XtremeMIMO(0x340E)"},
}; /* pci_vid_187E[] */

static pci_id_t const pci_vid_1885[] = {
{0x1885, 0xFFFF, 0xFFFF, 0xFFFF, "Avvida Systems Inc.(0x1885)"},
}; /* pci_vid_1885[] */

static pci_id_t const pci_vid_1888[] = {
{0x1888, 0xFFFF, 0xFFFF, 0xFFFF, "Varisys Ltd(0x1888)"},
{0x1888, 0x0301, 0xFFFF, 0xFFFF, "VMFX1 FPGA PMC module(0x0301)"},
{0x1888, 0x0601, 0xFFFF, 0xFFFF, "VSM2 dual PMC carrier(0x0601)"},
{0x1888, 0x0710, 0xFFFF, 0xFFFF, "VS14x series PowerPC PCI board(0x0710)"},
{0x1888, 0x0720, 0xFFFF, 0xFFFF, "VS24x series PowerPC PCI board(0x0720)"},
}; /* pci_vid_1888[] */

static pci_id_t const pci_vid_188A[] = {
{0x188A, 0xFFFF, 0xFFFF, 0xFFFF, "Ample Communications, Inc(0x188A)"},
}; /* pci_vid_188A[] */

static pci_id_t const pci_vid_1890[] = {
{0x1890, 0xFFFF, 0xFFFF, 0xFFFF, "Egenera, Inc.(0x1890)"},
}; /* pci_vid_1890[] */

static pci_id_t const pci_vid_1894[] = {
{0x1894, 0xFFFF, 0xFFFF, 0xFFFF, "KNC One(0x1894)"},
}; /* pci_vid_1894[] */

static pci_id_t const pci_vid_1896[] = {
{0x1896, 0xFFFF, 0xFFFF, 0xFFFF, "B&B Electronics Manufacturing Company, Inc.(0x1896)"},
{0x1896, 0x4202, 0xFFFF, 0xFFFF, "MIport 3PCIU2 2-port Serial(0x4202)"},
{0x1896, 0x4204, 0xFFFF, 0xFFFF, "MIport 3PCIU4 4-port Serial(0x4204)"},
{0x1896, 0x4208, 0xFFFF, 0xFFFF, "MIport 3PCIU8 8-port Serial(0x4208)"},
{0x1896, 0x4211, 0xFFFF, 0xFFFF, "MIport 3PCIOU1 1-port Isolated Serial(0x4211)"},
{0x1896, 0x4212, 0xFFFF, 0xFFFF, "MIport 3PCIOU2 2-port Isolated Serial(0x4212)"},
{0x1896, 0x4214, 0xFFFF, 0xFFFF, "MIport 3PCIOU4 4-port Isolated Serial(0x4214)"},
{0x1896, 0xBB10, 0xFFFF, 0xFFFF, "3PCI2 2-Port Serial(0xBB10)"},
{0x1896, 0xBB11, 0xFFFF, 0xFFFF, "3PCIO1 1-Port Isolated Serial(0xBB11)"},
}; /* pci_vid_1896[] */

static pci_id_t const pci_vid_1897[] = {
{0x1897, 0xFFFF, 0xFFFF, 0xFFFF, "AMtek(0x1897)"},
}; /* pci_vid_1897[] */

static pci_id_t const pci_vid_18A1[] = {
{0x18A1, 0xFFFF, 0xFFFF, 0xFFFF, "Astute Networks Inc.(0x18A1)"},
}; /* pci_vid_18A1[] */

static pci_id_t const pci_vid_18A2[] = {
{0x18A2, 0xFFFF, 0xFFFF, 0xFFFF, "Stretch Inc.(0x18A2)"},
{0x18A2, 0x0002, 0xFFFF, 0xFFFF, "VRC6016 16-Channel PCIe DVR Card(0x0002)"},
}; /* pci_vid_18A2[] */

static pci_id_t const pci_vid_18A3[] = {
{0x18A3, 0xFFFF, 0xFFFF, 0xFFFF, "AT&T(0x18A3)"},
}; /* pci_vid_18A3[] */

static pci_id_t const pci_vid_18AC[] = {
{0x18AC, 0xFFFF, 0xFFFF, 0xFFFF, "DViCO Corporation(0x18AC)"},
{0x18AC, 0xD500, 0xFFFF, 0xFFFF, "FusionHDTV 5(0xD500)"},
{0x18AC, 0xD800, 0xFFFF, 0xFFFF, "FusionHDTV 3 Gold(0xD800)"},
{0x18AC, 0xD810, 0xFFFF, 0xFFFF, "FusionHDTV 3 Gold-Q(0xD810)"},
{0x18AC, 0xD820, 0xFFFF, 0xFFFF, "FusionHDTV 3 Gold-T(0xD820)"},
{0x18AC, 0xDB30, 0xFFFF, 0xFFFF, "FusionHDTV DVB-T Pro(0xDB30)"},
{0x18AC, 0xDB40, 0xFFFF, 0xFFFF, "FusionHDTV DVB-T Hybrid(0xDB40)"},
{0x18AC, 0xDB78, 0xFFFF, 0xFFFF, "FusionHDTV DVB-T Dual Express(0xDB78)"},
}; /* pci_vid_18AC[] */

static pci_id_t const pci_vid_18B8[] = {
{0x18B8, 0xFFFF, 0xFFFF, 0xFFFF, "Ammasso(0x18B8)"},
{0x18B8, 0xB001, 0xFFFF, 0xFFFF, "AMSO 1100 iWARP/RDMA Gigabit Ethernet Coprocessor(0xB001)"},
}; /* pci_vid_18B8[] */

static pci_id_t const pci_vid_18BC[] = {
{0x18BC, 0xFFFF, 0xFFFF, 0xFFFF, "GeCube Technologies, Inc.(0x18BC)"},
}; /* pci_vid_18BC[] */

static pci_id_t const pci_vid_18C3[] = {
{0x18C3, 0xFFFF, 0xFFFF, 0xFFFF, "Micronas Semiconductor Holding AG(0x18C3)"},
{0x18C3, 0x0720, 0xFFFF, 0xFFFF, "nGene PCI-Express Multimedia Controller(0x0720)"},
{0x18C3, 0x0720, 0x1461, 0x032E, "Hybrid M779 PCI-E(0x1461-0x032E)"},
}; /* pci_vid_18C3[] */

static pci_id_t const pci_vid_18C8[] = {
{0x18C8, 0xFFFF, 0xFFFF, 0xFFFF, "Cray Inc(0x18C8)"},
}; /* pci_vid_18C8[] */

static pci_id_t const pci_vid_18C9[] = {
{0x18C9, 0xFFFF, 0xFFFF, 0xFFFF, "ARVOO Engineering BV(0x18C9)"},
}; /* pci_vid_18C9[] */

static pci_id_t const pci_vid_18CA[] = {
{0x18CA, 0xFFFF, 0xFFFF, 0xFFFF, "XGI Technology Inc. (eXtreme Graphics Innovation)(0x18CA)"},
{0x18CA, 0x0020, 0xFFFF, 0xFFFF, "Z7/Z9 (XG20 core)(0x0020)"},
{0x18CA, 0x0021, 0xFFFF, 0xFFFF, "Z9s/Z9m (XG21 core)(0x0021)"},
{0x18CA, 0x0027, 0xFFFF, 0xFFFF, "Z11/Z11M(0x0027)"},
{0x18CA, 0x0040, 0xFFFF, 0xFFFF, "Volari V3XT/V5/V8(0x0040)"},
{0x18CA, 0x0047, 0xFFFF, 0xFFFF, "Volari 8300 (chip: XP10, codename: XG47)(0x0047)"},
}; /* pci_vid_18CA[] */

static pci_id_t const pci_vid_18D2[] = {
{0x18D2, 0xFFFF, 0xFFFF, 0xFFFF, "Sitecom Europe BV (Wrong ID)(0x18D2)"},
{0x18D2, 0x3069, 0xFFFF, 0xFFFF, "DC-105v2 ISDN controller(0x3069)"},
}; /* pci_vid_18D2[] */

static pci_id_t const pci_vid_18D4[] = {
{0x18D4, 0xFFFF, 0xFFFF, 0xFFFF, "Celestica(0x18D4)"},
}; /* pci_vid_18D4[] */

static pci_id_t const pci_vid_18D8[] = {
{0x18D8, 0xFFFF, 0xFFFF, 0xFFFF, "Dialogue Technology Corp.(0x18D8)"},
}; /* pci_vid_18D8[] */

static pci_id_t const pci_vid_18DD[] = {
{0x18DD, 0xFFFF, 0xFFFF, 0xFFFF, "Artimi Inc(0x18DD)"},
{0x18DD, 0x4C6F, 0xFFFF, 0xFFFF, "Artimi RTMI-100 UWB adapter(0x4C6F)"},
}; /* pci_vid_18DD[] */

static pci_id_t const pci_vid_18DF[] = {
{0x18DF, 0xFFFF, 0xFFFF, 0xFFFF, "LeWiz Communications(0x18DF)"},
}; /* pci_vid_18DF[] */

static pci_id_t const pci_vid_18E6[] = {
{0x18E6, 0xFFFF, 0xFFFF, 0xFFFF, "MPL AG(0x18E6)"},
{0x18E6, 0x0001, 0xFFFF, 0xFFFF, "OSCI [Octal Serial Communication Interface](0x0001)"},
}; /* pci_vid_18E6[] */

static pci_id_t const pci_vid_18EB[] = {
{0x18EB, 0xFFFF, 0xFFFF, 0xFFFF, "Advance Multimedia Internet Technology, Inc.(0x18EB)"},
}; /* pci_vid_18EB[] */

static pci_id_t const pci_vid_18EC[] = {
{0x18EC, 0xFFFF, 0xFFFF, 0xFFFF, "Cesnet, z.s.p.o.(0x18EC)"},
{0x18EC, 0x6D05, 0xFFFF, 0xFFFF, "ML555(0x6D05)"},
{0x18EC, 0x6D05, 0x18EC, 0x0100, "NIC (ethernet interfaces)(0x18EC-0x0100)"},
{0x18EC, 0x6D05, 0x18EC, 0x0200, "NIC (szedata2) 4x1G(0x18EC-0x0200)"},
{0x18EC, 0x6D05, 0x18EC, 0x0201, "NIC (szedata2) 2x10G(0x18EC-0x0201)"},
{0x18EC, 0x6D05, 0x18EC, 0x0300, "NIFIC (szedata2) 4x1G(0x18EC-0x0300)"},
{0x18EC, 0x6D05, 0x18EC, 0x0302, "NIFIC (szedata2) 2x10G(0x18EC-0x0302)"},
{0x18EC, 0x6D05, 0x18EC, 0x4200, "Flexible FlowMon (szedata2) 1x10G(0x18EC-0x4200)"},
{0x18EC, 0x6D05, 0x18EC, 0xFF00, "Testing design(0x18EC-0xFF00)"},
{0x18EC, 0x6D05, 0x18EC, 0xFF01, "Boot design(0x18EC-0xFF01)"},
{0x18EC, 0xC006, 0xFFFF, 0xFFFF, "COMBO6(0xC006)"},
{0x18EC, 0xC006, 0x18EC, 0xD001, "COMBO-4MTX(0x18EC-0xD001)"},
{0x18EC, 0xC006, 0x18EC, 0xD002, "COMBO-4SFP(0x18EC-0xD002)"},
{0x18EC, 0xC006, 0x18EC, 0xD003, "COMBO-4SFPRO(0x18EC-0xD003)"},
{0x18EC, 0xC006, 0x18EC, 0xD004, "COMBO-2XFP(0x18EC-0xD004)"},
{0x18EC, 0xC032, 0xFFFF, 0xFFFF, "COMBO-LXT110(0xC032)"},
{0x18EC, 0xC032, 0x18EC, 0x0100, "NIC (ethernet interfaces)(0x18EC-0x0100)"},
{0x18EC, 0xC032, 0x18EC, 0x0200, "NIC (szedata2) 4x1G(0x18EC-0x0200)"},
{0x18EC, 0xC032, 0x18EC, 0x0201, "NIC (szedata2) 2x10G(0x18EC-0x0201)"},
{0x18EC, 0xC032, 0x18EC, 0x0300, "NIFIC (szedata2) 4x1G(0x18EC-0x0300)"},
{0x18EC, 0xC032, 0x18EC, 0x0302, "NIFIC (szedata2) 2x10G(0x18EC-0x0302)"},
{0x18EC, 0xC032, 0x18EC, 0x4200, "Flexible FlowMon (szedata2) 1x10G(0x18EC-0x4200)"},
{0x18EC, 0xC032, 0x18EC, 0xFF00, "Testing design(0x18EC-0xFF00)"},
{0x18EC, 0xC032, 0x18EC, 0xFF01, "Boot design(0x18EC-0xFF01)"},
{0x18EC, 0xC045, 0xFFFF, 0xFFFF, "COMBO6E(0xC045)"},
{0x18EC, 0xC050, 0xFFFF, 0xFFFF, "COMBO-PTM(0xC050)"},
{0x18EC, 0xC058, 0xFFFF, 0xFFFF, "COMBO6X(0xC058)"},
{0x18EC, 0xC058, 0x18EC, 0xD001, "COMBO-4MTX(0x18EC-0xD001)"},
{0x18EC, 0xC058, 0x18EC, 0xD002, "COMBO-4SFP(0x18EC-0xD002)"},
{0x18EC, 0xC058, 0x18EC, 0xD003, "COMBO-4SFPRO(0x18EC-0xD003)"},
{0x18EC, 0xC058, 0x18EC, 0xD004, "COMBO-2XFP(0x18EC-0xD004)"},
{0x18EC, 0xC132, 0xFFFF, 0xFFFF, "COMBO-LXT155(0xC132)"},
{0x18EC, 0xC132, 0x18EC, 0x0100, "NIC (ethernet interfaces)(0x18EC-0x0100)"},
{0x18EC, 0xC132, 0x18EC, 0x0200, "NIC (szedata2) 4x1G(0x18EC-0x0200)"},
{0x18EC, 0xC132, 0x18EC, 0x0201, "NIC (szedata2) 2x10G(0x18EC-0x0201)"},
{0x18EC, 0xC132, 0x18EC, 0x0300, "NIFIC (szedata2) 4x1G(0x18EC-0x0300)"},
{0x18EC, 0xC132, 0x18EC, 0x0302, "NIFIC (szedata2) 2x10G(0x18EC-0x0302)"},
{0x18EC, 0xC132, 0x18EC, 0x4200, "Flexible FlowMon (szedata2) 1x10G(0x18EC-0x4200)"},
{0x18EC, 0xC132, 0x18EC, 0xFF00, "Testing design(0x18EC-0xFF00)"},
{0x18EC, 0xC132, 0x18EC, 0xFF01, "Boot design(0x18EC-0xFF01)"},
{0x18EC, 0xC232, 0xFFFF, 0xFFFF, "COMBO-FXT100(0xC232)"},
{0x18EC, 0xC232, 0x18EC, 0x0100, "NIC (ethernet interfaces)(0x18EC-0x0100)"},
{0x18EC, 0xC232, 0x18EC, 0x0200, "NIC (szedata2) 4x1G(0x18EC-0x0200)"},
{0x18EC, 0xC232, 0x18EC, 0x0201, "NIC (szedata2) 2x10G(0x18EC-0x0201)"},
{0x18EC, 0xC232, 0x18EC, 0x0300, "NIFIC (szedata2) 4x1G(0x18EC-0x0300)"},
{0x18EC, 0xC232, 0x18EC, 0x0302, "NIFIC (szedata2) 2x10G(0x18EC-0x0302)"},
{0x18EC, 0xC232, 0x18EC, 0x4200, "Flexible FlowMon (szedata2) 1x10G(0x18EC-0x4200)"},
{0x18EC, 0xC232, 0x18EC, 0xFF00, "Testing design(0x18EC-0xFF00)"},
{0x18EC, 0xC232, 0x18EC, 0xFF01, "Boot design(0x18EC-0xFF01)"},
{0x18EC, 0xC400, 0xFFFF, 0xFFFF, "COMBO-400G1(0xC400)"},
}; /* pci_vid_18EC[] */

static pci_id_t const pci_vid_18EE[] = {
{0x18EE, 0xFFFF, 0xFFFF, 0xFFFF, "Chenming Mold Ind. Corp.(0x18EE)"},
}; /* pci_vid_18EE[] */

static pci_id_t const pci_vid_18F1[] = {
{0x18F1, 0xFFFF, 0xFFFF, 0xFFFF, "Spectrum GmbH(0x18F1)"},
}; /* pci_vid_18F1[] */

static pci_id_t const pci_vid_18F4[] = {
{0x18F4, 0xFFFF, 0xFFFF, 0xFFFF, "Napatech A/S(0x18F4)"},
{0x18F4, 0x0031, 0xFFFF, 0xFFFF, "NT20X Network Adapter(0x0031)"},
{0x18F4, 0x0051, 0xFFFF, 0xFFFF, "NT20X Capture Card(0x0051)"},
{0x18F4, 0x0061, 0xFFFF, 0xFFFF, "NT20E Capture Card(0x0061)"},
{0x18F4, 0x0064, 0xFFFF, 0xFFFF, "NT20E Inline Card(0x0064)"},
{0x18F4, 0x0071, 0xFFFF, 0xFFFF, "NT4E Capture Card(0x0071)"},
{0x18F4, 0x0074, 0xFFFF, 0xFFFF, "NT4E Inline Card(0x0074)"},
{0x18F4, 0x0081, 0xFFFF, 0xFFFF, "NT4E 4-port Expansion Card(0x0081)"},
{0x18F4, 0x0091, 0xFFFF, 0xFFFF, "NT20X Capture Card [New Rev](0x0091)"},
{0x18F4, 0x00A1, 0xFFFF, 0xFFFF, "NT4E-STD Capture Card(0x00A1)"},
{0x18F4, 0x00A4, 0xFFFF, 0xFFFF, "NT4E-STD Inline Card(0x00A4)"},
{0x18F4, 0x00B1, 0xFFFF, 0xFFFF, "NTBPE Optical Bypass Adapter(0x00B1)"},
{0x18F4, 0x00C5, 0xFFFF, 0xFFFF, "NT20E2 Network Adapter 2x10Gb(0x00C5)"},
{0x18F4, 0x00D5, 0xFFFF, 0xFFFF, "NT40E2-4 Network Adapter 4x10Gb(0x00D5)"},
{0x18F4, 0x00E5, 0xFFFF, 0xFFFF, "NT40E2-1 Network Adapter 1x40Gb(0x00E5)"},
{0x18F4, 0x00F5, 0xFFFF, 0xFFFF, "NT4E2-4T-BP Network Adapter 4x1Gb with Electrical Bypass(0x00F5)"},
{0x18F4, 0x0105, 0xFFFF, 0xFFFF, "NT4E2-4-PTP Network Adapter 4x1Gb(0x0105)"},
{0x18F4, 0x0115, 0xFFFF, 0xFFFF, "NT20E2-PTP Network Adapter 2x10Gb(0x0115)"},
{0x18F4, 0x0125, 0xFFFF, 0xFFFF, "NT4E2-4-PTP Network Adapter 4x1Gb(0x0125)"},
{0x18F4, 0x0135, 0xFFFF, 0xFFFF, "NT20E2-PTP Network Adapter 2x10Gb(0x0135)"},
{0x18F4, 0x0145, 0xFFFF, 0xFFFF, "NT40E3-4-PTP Network Adapter 4x10Gb(0x0145)"},
{0x18F4, 0x0155, 0xFFFF, 0xFFFF, "NT100E3-1-PTP Network Adapter 1x100Gb(0x0155)"},
{0x18F4, 0x0165, 0xFFFF, 0xFFFF, "NT80E3-2-PTP Network Adapter 2x40Gb(0x0165)"},
{0x18F4, 0x0175, 0xFFFF, 0xFFFF, "NT20E3-2-PTP Network Adapter 2x10Gb(0x0175)"},
{0x18F4, 0x0185, 0xFFFF, 0xFFFF, "NT40A01 Network Adapter(0x0185)"},
{0x18F4, 0x01A5, 0xFFFF, 0xFFFF, "NT200A01 Network Adapter(0x01A5)"},
{0x18F4, 0x01C5, 0xFFFF, 0xFFFF, "NT200A02 Network Adapter(0x01C5)"},
{0x18F4, 0x01D5, 0xFFFF, 0xFFFF, "NT50B01 Network Adapter(0x01D5)"},
{0x18F4, 0x01E5, 0xFFFF, 0xFFFF, "NT100A01 Network Adapter(0x01E5)"},
{0x18F4, 0x0215, 0xFFFF, 0xFFFF, "NT400D11 Network Adapter(0x0215)"},
{0x18F4, 0x0225, 0xFFFF, 0xFFFF, "NT40A11 Network Adapter(0x0225)"},
}; /* pci_vid_18F4[] */

static pci_id_t const pci_vid_18F6[] = {
{0x18F6, 0xFFFF, 0xFFFF, 0xFFFF, "NextIO(0x18F6)"},
{0x18F6, 0x1000, 0xFFFF, 0xFFFF, "[Nexsis] Switch Virtual P2P PCIe Bridge(0x1000)"},
{0x18F6, 0x1001, 0xFFFF, 0xFFFF, "[Texsis] Switch Virtual P2P PCIe Bridge(0x1001)"},
{0x18F6, 0x1050, 0xFFFF, 0xFFFF, "[Nexsis] Switch Virtual P2P PCI Bridge(0x1050)"},
{0x18F6, 0x1051, 0xFFFF, 0xFFFF, "[Texsis] Switch Virtual P2P PCI Bridge(0x1051)"},
{0x18F6, 0x2000, 0xFFFF, 0xFFFF, "[Nexsis] Switch Integrated Mgmt. Endpoint(0x2000)"},
{0x18F6, 0x2001, 0xFFFF, 0xFFFF, "[Texsis] Switch Integrated Mgmt. Endpoint(0x2001)"},
}; /* pci_vid_18F6[] */

static pci_id_t const pci_vid_18F7[] = {
{0x18F7, 0xFFFF, 0xFFFF, 0xFFFF, "Commtech, Inc.(0x18F7)"},
{0x18F7, 0x0001, 0xFFFF, 0xFFFF, "ESCC-PCI-335 Serial PCI Adapter [Fastcom](0x0001)"},
{0x18F7, 0x0002, 0xFFFF, 0xFFFF, "422/4-PCI-335 Serial PCI Adapter [Fastcom](0x0002)"},
{0x18F7, 0x0003, 0xFFFF, 0xFFFF, "232/4-1M-PCI Serial PCI Adapter [Fastcom](0x0003)"},
{0x18F7, 0x0004, 0xFFFF, 0xFFFF, "422/2-PCI-335 Serial PCI Adapter [Fastcom](0x0004)"},
{0x18F7, 0x0005, 0xFFFF, 0xFFFF, "IGESCC-PCI-ISO/1 Serial PCI Adapter [Fastcom](0x0005)"},
{0x18F7, 0x000A, 0xFFFF, 0xFFFF, "232/4-PCI-335 Serial PCI Adapter [Fastcom](0x000A)"},
{0x18F7, 0x000B, 0xFFFF, 0xFFFF, "232/8-PCI-335 Serial PCI Adapter [Fastcom](0x000B)"},
{0x18F7, 0x000F, 0xFFFF, 0xFFFF, "FSCC Serial PCI Adapter [Fastcom](0x000F)"},
{0x18F7, 0x0010, 0xFFFF, 0xFFFF, "GSCC Serial PCI Adapter [Fastcom](0x0010)"},
{0x18F7, 0x0011, 0xFFFF, 0xFFFF, "QSSB Serial PCI Adapter [Fastcom](0x0011)"},
{0x18F7, 0x0014, 0xFFFF, 0xFFFF, "SuperFSCC Serial PCI Adapter [Fastcom](0x0014)"},
{0x18F7, 0x0015, 0xFFFF, 0xFFFF, "SuperFSCC-104-LVDS Serial PC/104+ Adapter [Fastcom](0x0015)"},
{0x18F7, 0x0016, 0xFFFF, 0xFFFF, "FSCC-232 RS-232 Serial PCI Adapter [Fastcom](0x0016)"},
{0x18F7, 0x0017, 0xFFFF, 0xFFFF, "SuperFSCC-104 Serial PC/104+ Adapter [Fastcom](0x0017)"},
{0x18F7, 0x0018, 0xFFFF, 0xFFFF, "SuperFSCC/4 Serial PCI Adapter [Fastcom](0x0018)"},
{0x18F7, 0x0019, 0xFFFF, 0xFFFF, "SuperFSCC Serial PCI Adapter [Fastcom](0x0019)"},
{0x18F7, 0x001A, 0xFFFF, 0xFFFF, "SuperFSCC-LVDS Serial PCI Adapter [Fastcom](0x001A)"},
{0x18F7, 0x001B, 0xFFFF, 0xFFFF, "FSCC/4 Serial PCI Adapter [Fastcom](0x001B)"},
{0x18F7, 0x001C, 0xFFFF, 0xFFFF, "SuperFSCC/4-LVDS Serial PCI Adapter [Fastcom](0x001C)"},
{0x18F7, 0x001D, 0xFFFF, 0xFFFF, "FSCC Serial PCI Adapter [Fastcom](0x001D)"},
{0x18F7, 0x001E, 0xFFFF, 0xFFFF, "SuperFSCC/4 Serial PCIe Adapter [Fastcom](0x001E)"},
{0x18F7, 0x001F, 0xFFFF, 0xFFFF, "SuperFSCC/4 Serial cPCI Adapter [Fastcom](0x001F)"},
{0x18F7, 0x0020, 0xFFFF, 0xFFFF, "422/4-PCIe Serial PCIe Adapter [Fastcom](0x0020)"},
{0x18F7, 0x0021, 0xFFFF, 0xFFFF, "422/8-PCIe Serial PCIe Adapter [Fastcom](0x0021)"},
{0x18F7, 0x0022, 0xFFFF, 0xFFFF, "SuperFSCC/4-LVDS Serial PCIe Adapter [Fastcom](0x0022)"},
{0x18F7, 0x0023, 0xFFFF, 0xFFFF, "SuperFSCC/4 Serial cPCI Adapter [Fastcom](0x0023)"},
{0x18F7, 0x0025, 0xFFFF, 0xFFFF, "SuperFSCC/4-LVDS Serial PCI Adapter [Fastcom](0x0025)"},
{0x18F7, 0x0026, 0xFFFF, 0xFFFF, "SuperFSCC-LVDS Serial PCI Adapter [Fastcom](0x0026)"},
{0x18F7, 0x0027, 0xFFFF, 0xFFFF, "FSCC/4 Serial PCIe Adapter [Fastcom](0x0027)"},
}; /* pci_vid_18F7[] */

static pci_id_t const pci_vid_18FB[] = {
{0x18FB, 0xFFFF, 0xFFFF, 0xFFFF, "Resilience Corporation(0x18FB)"},
}; /* pci_vid_18FB[] */

static pci_id_t const pci_vid_1904[] = {
{0x1904, 0xFFFF, 0xFFFF, 0xFFFF, "Hangzhou Silan Microelectronics Co., Ltd.(0x1904)"},
{0x1904, 0x2031, 0xFFFF, 0xFFFF, "SC92031 PCI Fast Ethernet Adapter(0x2031)"},
{0x1904, 0x8139, 0xFFFF, 0xFFFF, "RTL8139D [Realtek] PCI 10/100BaseTX ethernet adaptor(0x8139)"},
}; /* pci_vid_1904[] */

static pci_id_t const pci_vid_1905[] = {
{0x1905, 0xFFFF, 0xFFFF, 0xFFFF, "Micronas USA, Inc.(0x1905)"},
}; /* pci_vid_1905[] */

static pci_id_t const pci_vid_1912[] = {
{0x1912, 0xFFFF, 0xFFFF, 0xFFFF, "Renesas Technology Corp.(0x1912)"},
{0x1912, 0x0002, 0xFFFF, 0xFFFF, "SH7780 PCI Controller (PCIC)(0x0002)"},
{0x1912, 0x0011, 0xFFFF, 0xFFFF, "SH7757 PCIe End-Point [PBI](0x0011)"},
{0x1912, 0x0012, 0xFFFF, 0xFFFF, "SH7757 PCIe-PCI Bridge [PPB](0x0012)"},
{0x1912, 0x0013, 0xFFFF, 0xFFFF, "SH7757 PCIe Switch [PS](0x0013)"},
{0x1912, 0x0014, 0xFFFF, 0xFFFF, "uPD720201 USB 3.0 Host Controller(0x0014)"},
{0x1912, 0x0015, 0xFFFF, 0xFFFF, "uPD720202 USB 3.0 Host Controller(0x0015)"},
{0x1912, 0x0015, 0x4C52, 0x9A72, "LRSU9A72 2-Port USB 3.0 Exchange Adapter(0x4C52-0x9A72)"},
{0x1912, 0x001A, 0xFFFF, 0xFFFF, "SH7758 PCIe-PCI Bridge [PPB](0x001A)"},
{0x1912, 0x001B, 0xFFFF, 0xFFFF, "SH7758 PCIe End-Point [PBI](0x001B)"},
{0x1912, 0x001D, 0xFFFF, 0xFFFF, "SH7758 PCIe Switch [PS](0x001D)"},
}; /* pci_vid_1912[] */

static pci_id_t const pci_vid_1919[] = {
{0x1919, 0xFFFF, 0xFFFF, 0xFFFF, "Soltek Computer Inc.(0x1919)"},
}; /* pci_vid_1919[] */

static pci_id_t const pci_vid_1923[] = {
{0x1923, 0xFFFF, 0xFFFF, 0xFFFF, "Sangoma Technologies Corp.(0x1923)"},
{0x1923, 0x0040, 0xFFFF, 0xFFFF, "A200/Remora FXO/FXS Analog AFT card(0x0040)"},
{0x1923, 0x0100, 0xFFFF, 0xFFFF, "A104d QUAD T1/E1 AFT card(0x0100)"},
{0x1923, 0x0300, 0xFFFF, 0xFFFF, "A101 single-port T1/E1(0x0300)"},
{0x1923, 0x0400, 0xFFFF, 0xFFFF, "A104u Quad T1/E1 AFT(0x0400)"},
}; /* pci_vid_1923[] */

static pci_id_t const pci_vid_1924[] = {
{0x1924, 0xFFFF, 0xFFFF, 0xFFFF, "AMD Solarflare(0x1924)"},
{0x1924, 0x0703, 0xFFFF, 0xFFFF, "SFC4000 rev A net [Solarstorm](0x0703)"},
{0x1924, 0x0703, 0x10B8, 0x0102, "SMC10GPCIe-10BT (A2) [TigerCard](0x10B8-0x0102)"},
{0x1924, 0x0703, 0x10B8, 0x0103, "SMC10GPCIe-10BT (A3) [TigerCard](0x10B8-0x0103)"},
{0x1924, 0x0703, 0x10B8, 0x0201, "SMC10GPCIe-XFP (A1) [TigerCard](0x10B8-0x0201)"},
{0x1924, 0x0703, 0x1924, 0x0101, "SFE4001-A1(0x1924-0x0101)"},
{0x1924, 0x0703, 0x1924, 0x0102, "SFE4001-A2(0x1924-0x0102)"},
{0x1924, 0x0703, 0x1924, 0x0103, "SFE4001-A3(0x1924-0x0103)"},
{0x1924, 0x0703, 0x1924, 0x0201, "SFE4002-A1(0x1924-0x0201)"},
{0x1924, 0x0703, 0x1924, 0x0301, "SFE4003-A1(0x1924-0x0301)"},
{0x1924, 0x0703, 0x1924, 0x0302, "SFE4003-A2(0x1924-0x0302)"},
{0x1924, 0x0703, 0x1924, 0x0303, "SFE4003-A3(0x1924-0x0303)"},
{0x1924, 0x0703, 0x1924, 0x0304, "SFE4003-A4(0x1924-0x0304)"},
{0x1924, 0x0703, 0x1924, 0x0500, "SFE4005-A0(0x1924-0x0500)"},
{0x1924, 0x0710, 0xFFFF, 0xFFFF, "SFC4000 rev B [Solarstorm](0x0710)"},
{0x1924, 0x0710, 0x10B8, 0x0103, "SMC10GPCIe-10BT (A3) [TigerCard](0x10B8-0x0103)"},
{0x1924, 0x0710, 0x10B8, 0x0201, "SMC10GPCIe-XFP (A1) [TigerCard](0x10B8-0x0201)"},
{0x1924, 0x0710, 0x1924, 0x0102, "SFE4001-A2(0x1924-0x0102)"},
{0x1924, 0x0710, 0x1924, 0x0103, "SFE4001-A3(0x1924-0x0103)"},
{0x1924, 0x0710, 0x1924, 0x0201, "SFE4002-A1(0x1924-0x0201)"},
{0x1924, 0x0710, 0x1924, 0x0302, "SFE4003-A2(0x1924-0x0302)"},
{0x1924, 0x0710, 0x1924, 0x0303, "SFE4003-A3(0x1924-0x0303)"},
{0x1924, 0x0710, 0x1924, 0x0304, "SFE4003-A4(0x1924-0x0304)"},
{0x1924, 0x0710, 0x1924, 0x0500, "SFE4005-A0(0x1924-0x0500)"},
{0x1924, 0x0710, 0x1924, 0x5102, "SFN4111T-A2(0x1924-0x5102)"},
{0x1924, 0x0710, 0x1924, 0x5103, "SFN4111T-R3(0x1924-0x5103)"},
{0x1924, 0x0710, 0x1924, 0x5104, "SFN4111T-R4(0x1924-0x5104)"},
{0x1924, 0x0710, 0x1924, 0x5105, "SFN4111T-R5(0x1924-0x5105)"},
{0x1924, 0x0710, 0x1924, 0x5201, "SFN4112F-R1(0x1924-0x5201)"},
{0x1924, 0x0710, 0x1924, 0x5202, "SFN4112F-R2(0x1924-0x5202)"},
{0x1924, 0x0803, 0xFFFF, 0xFFFF, "SFC9020 10G Ethernet Controller(0x0803)"},
{0x1924, 0x0803, 0x1014, 0x0478, "2-port 10GbE Low-Latency (R7)(0x1014-0x0478)"},
{0x1924, 0x0803, 0x1014, 0x0479, "2-port 10GbE OpenOnload (R7)(0x1014-0x0479)"},
{0x1924, 0x0803, 0x1014, 0x04A7, "Solarflare 10Gb Low-latency Dual-port HBA (R7)(0x1014-0x04A7)"},
{0x1924, 0x0803, 0x1014, 0x04A8, "Solarflare 10Gb Dual-port HBA (R7)(0x1014-0x04A8)"},
{0x1924, 0x0803, 0x103C, 0x2132, "Ethernet 10Gb 2-port 570FLR-SFP+ Adapter (R1)(0x103C-0x2132)"},
{0x1924, 0x0803, 0x103C, 0x2136, "Ethernet 10Gb 2-port 570SFP+ Adapter (R7)(0x103C-0x2136)"},
{0x1924, 0x0803, 0x1924, 0x1201, "SFA6902F-R1 SFP+ AOE Adapter(0x1924-0x1201)"},
{0x1924, 0x0803, 0x1924, 0x6200, "SFN5122F-R0 SFP+ Server Adapter(0x1924-0x6200)"},
{0x1924, 0x0803, 0x1924, 0x6201, "SFN5122F-R1 SFP+ Server Adapter(0x1924-0x6201)"},
{0x1924, 0x0803, 0x1924, 0x6202, "SFN5122F-R2 SFP+ Server Adapter(0x1924-0x6202)"},
{0x1924, 0x0803, 0x1924, 0x6204, "SFN5122F-R4 SFP+ Server Adapter(0x1924-0x6204)"},
{0x1924, 0x0803, 0x1924, 0x6205, "SFN5122F-R5 SFP+ Server Adapter(0x1924-0x6205)"},
{0x1924, 0x0803, 0x1924, 0x6206, "SFN5122F-R6 SFP+ Server Adapter(0x1924-0x6206)"},
{0x1924, 0x0803, 0x1924, 0x6207, "SFN5122F-R7 SFP+ Server Adapter(0x1924-0x6207)"},
{0x1924, 0x0803, 0x1924, 0x6210, "SFN5322F-R0 SFP+ Precision Time Synchronization Server Adapter(0x1924-0x6210)"},
{0x1924, 0x0803, 0x1924, 0x6211, "SFN5322F-R1 SFP+ Precision Time Synchronization Server Adapter(0x1924-0x6211)"},
{0x1924, 0x0803, 0x1924, 0x6217, "SFN5322F-R7 SFP+ Precision Time Synchronization Server Adapter(0x1924-0x6217)"},
{0x1924, 0x0803, 0x1924, 0x6227, "SFN6122F-R7 SFP+ Server Adapter(0x1924-0x6227)"},
{0x1924, 0x0803, 0x1924, 0x6237, "SFN6322F-R7 SFP+ Precision Time Synchronization Server Adapter(0x1924-0x6237)"},
{0x1924, 0x0803, 0x1924, 0x6501, "SFN5802K-R1 Mezzanine Adapter(0x1924-0x6501)"},
{0x1924, 0x0803, 0x1924, 0x6511, "SFN5814H-R1 Mezzanine Adapter(0x1924-0x6511)"},
{0x1924, 0x0803, 0x1924, 0x6521, "SFN5812H-R1 Mezzanine Adapter(0x1924-0x6521)"},
{0x1924, 0x0803, 0x1924, 0x6562, "SFN6832F-R2 SFP+ Mezzanine Adapter(0x1924-0x6562)"},
{0x1924, 0x0803, 0x1924, 0x6A05, "SFN5112F-R5 SFP+ Server Adapter(0x1924-0x6A05)"},
{0x1924, 0x0803, 0x1924, 0x6A06, "SFN5112F-R6 SFP+ Server Adapter(0x1924-0x6A06)"},
{0x1924, 0x0803, 0x1924, 0x7206, "SFN5162F-R6 SFP+ Server Adapter(0x1924-0x7206)"},
{0x1924, 0x0803, 0x1924, 0x7207, "SFN5162F-R7 SFP+ Server Adapter(0x1924-0x7207)"},
{0x1924, 0x0803, 0x1924, 0x7A06, "SFN5152F-R6 SFP+ Server Adapter(0x1924-0x7A06)"},
{0x1924, 0x0803, 0x1924, 0x7A07, "SFN5152F-R7 SFP+ Server Adapter(0x1924-0x7A07)"},
{0x1924, 0x0813, 0xFFFF, 0xFFFF, "SFL9021 10GBASE-T Ethernet Controller(0x0813)"},
{0x1924, 0x0813, 0x1924, 0x6100, "SFN5121T-R0 10GBASE-T Server Adapter(0x1924-0x6100)"},
{0x1924, 0x0813, 0x1924, 0x6102, "SFN5121T-R2 10GBASE-T Server Adapter(0x1924-0x6102)"},
{0x1924, 0x0813, 0x1924, 0x6103, "SFN5121T-R3 10GBASE-T Server Adapter(0x1924-0x6103)"},
{0x1924, 0x0813, 0x1924, 0x6104, "SFN5121T-R4 10GBASE-T Server Adapter(0x1924-0x6104)"},
{0x1924, 0x0813, 0x1924, 0x6902, "SFN5111T-R2 10GBASE-T Server Adapter(0x1924-0x6902)"},
{0x1924, 0x0813, 0x1924, 0x6904, "SFN5111T-R4 10GBASE-T Server Adapter(0x1924-0x6904)"},
{0x1924, 0x0813, 0x1924, 0x7104, "SFN5161T-R4 10GBASE-T Server Adapter(0x1924-0x7104)"},
{0x1924, 0x0813, 0x1924, 0x7904, "SFN5151T-R4 10GBASE-T Server Adapter(0x1924-0x7904)"},
{0x1924, 0x0903, 0xFFFF, 0xFFFF, "SFC9120 10G Ethernet Controller(0x0903)"},
{0x1924, 0x0903, 0x1014, 0x04CC, "SFN7122F-R2 2x10GbE SFP+ Flareon Ultra(0x1014-0x04CC)"},
{0x1924, 0x0903, 0x1924, 0x8002, "SFN7122F-R1 SFP+ Server Adapter(0x1924-0x8002)"},
{0x1924, 0x0903, 0x1924, 0x8003, "SFN7x41Q-R1 Flareon Ultra 7000 Series 10/40G Adapter(0x1924-0x8003)"},
{0x1924, 0x0903, 0x1924, 0x8006, "SFN7022F-R1 SFP+ Server Adapter(0x1924-0x8006)"},
{0x1924, 0x0903, 0x1924, 0x8007, "SFN7322F-R2 Precision Time SFP+ Server Adapter(0x1924-0x8007)"},
{0x1924, 0x0903, 0x1924, 0x8009, "SFN7x22F-R2 Flareon Ultra 7000 Series 10G Adapter(0x1924-0x8009)"},
{0x1924, 0x0903, 0x1924, 0x800A, "SFN7x02F-R2 Flareon 7000 Series 10G Adapter(0x1924-0x800A)"},
{0x1924, 0x0903, 0x1924, 0x800C, "SFN7x22F-R3 Flareon Ultra 7000 Series 10G Adapter(0x1924-0x800C)"},
{0x1924, 0x0903, 0x1924, 0x800D, "SFN7x02F-R3 Flareon 7000 Series 10G Adapter(0x1924-0x800D)"},
{0x1924, 0x0903, 0x1924, 0x8010, "SFA7942Q-R1 QSFP+ AOE Adapter(0x1924-0x8010)"},
{0x1924, 0x0903, 0x1924, 0x8015, "SFA7942Q-A5-0-R1 QSFP+ AOE Adapter(0x1924-0x8015)"},
{0x1924, 0x0923, 0xFFFF, 0xFFFF, "SFC9140 10/40G Ethernet Controller(0x0923)"},
{0x1924, 0x0923, 0x1924, 0x800B, "SFN7x42Q-R1 Flareon Ultra 7000 Series 10/40G Adapter(0x1924-0x800B)"},
{0x1924, 0x0923, 0x1924, 0x800E, "SFN7x42Q-R2 Flareon Ultra 7000 Series 10/40G Adapter(0x1924-0x800E)"},
{0x1924, 0x0923, 0x1924, 0x800F, "SFN7xx4F-R1 Flareon Ultra 7000 Series 10G Adapter(0x1924-0x800F)"},
{0x1924, 0x0A03, 0xFFFF, 0xFFFF, "SFC9220 10/40G Ethernet Controller(0x0A03)"},
{0x1924, 0x0A03, 0x1924, 0x8011, "SFN8022-R1 8000 Series 10G Adapter(0x1924-0x8011)"},
{0x1924, 0x0A03, 0x1924, 0x8012, "SFN8522-R1 8000 Series 10G Adapter(0x1924-0x8012)"},
{0x1924, 0x0A03, 0x1924, 0x8013, "SFN8042-R1 8000 Series 10/40G Adapter(0x1924-0x8013)"},
{0x1924, 0x0A03, 0x1924, 0x8014, "SFN8542-R1 8000 Series 10/40G Adapter(0x1924-0x8014)"},
{0x1924, 0x0A03, 0x1924, 0x8016, "SFN8022-R2 8000 Series 10G Adapter(0x1924-0x8016)"},
{0x1924, 0x0A03, 0x1924, 0x8017, "SFN8522-R2 8000 Series 10G Adapter(0x1924-0x8017)"},
{0x1924, 0x0A03, 0x1924, 0x8018, "SFN8042-R2 8000 Series 10/40G Adapter(0x1924-0x8018)"},
{0x1924, 0x0A03, 0x1924, 0x8019, "SFN8542-R2 8000 Series 10/40G Adapter(0x1924-0x8019)"},
{0x1924, 0x0A03, 0x1924, 0x801A, "SFN8722-R1 8000 Series OCP 10G Adapter(0x1924-0x801A)"},
{0x1924, 0x0A03, 0x1924, 0x801B, "SFN8522-R3 8000 Series 10G Adapter(0x1924-0x801B)"},
{0x1924, 0x0A03, 0x1924, 0x801C, "SFN8042-R3 8000 Series 10/40G Adapter(0x1924-0x801C)"},
{0x1924, 0x0A03, 0x1924, 0x8021, "SFN8041-R1 8000 Series 10/40G Adapter(0x1924-0x8021)"},
{0x1924, 0x0B03, 0xFFFF, 0xFFFF, "XtremeScale SFC9250 10/25/40/50/100G Ethernet Controller(0x0B03)"},
{0x1924, 0x0B03, 0x1924, 0x801D, "x2522-R1 2000 Series 10/25G Adapter(0x1924-0x801D)"},
{0x1924, 0x0B03, 0x1924, 0x801E, "x2542-R1 2000 Series 40/100G Adapter(0x1924-0x801E)"},
{0x1924, 0x0B03, 0x1924, 0x8022, "XtremeScale X2522 10G Network Adapter(0x1924-0x8022)"},
{0x1924, 0x0B03, 0x1924, 0x8024, "XtremeScale X2562 OCP 3.0 Dual Port SFP28(0x1924-0x8024)"},
{0x1924, 0x0B03, 0x1924, 0x8027, "XtremeScale X2541 PCIe Single Port QSFP28(0x1924-0x8027)"},
{0x1924, 0x0B03, 0x1924, 0x8028, "XtremeScale X2522-25G Network Adapter(0x1924-0x8028)"},
{0x1924, 0x0B03, 0x1924, 0x802A, "XtremeScale X2542 PCIe Dual Port QSFP28(0x1924-0x802A)"},
{0x1924, 0x0B03, 0x1924, 0x802B, "XtremeScale X2552 OCP 2.0 Dual Port SFP28(0x1924-0x802B)"},
{0x1924, 0x0B03, 0x1924, 0x802C, "XtremeScale X2522-25G PCIe Dual Port SFP28(0x1924-0x802C)"},
{0x1924, 0x0B03, 0x1924, 0x802D, "XtremeScale X2562 OCP 3.0 Dual Port SFP28(0x1924-0x802D)"},
{0x1924, 0x1803, 0xFFFF, 0xFFFF, "SFC9020 10G Ethernet Controller (Virtual Function)(0x1803)"},
{0x1924, 0x1813, 0xFFFF, 0xFFFF, "SFL9021 10GBASE-T Ethernet Controller (Virtual Function)(0x1813)"},
{0x1924, 0x1903, 0xFFFF, 0xFFFF, "SFC9120 10G Ethernet Controller (Virtual Function)(0x1903)"},
{0x1924, 0x1923, 0xFFFF, 0xFFFF, "SFC9140 10/40G Ethernet Controller (Virtual Function)(0x1923)"},
{0x1924, 0x1A03, 0xFFFF, 0xFFFF, "SFC9220 10/40G Ethernet Controller (Virtual Function)(0x1A03)"},
{0x1924, 0x1B03, 0xFFFF, 0xFFFF, "XtremeScale SFC9250 10/25/40/50/100G Ethernet Controller (Virtual Function)(0x1B03)"},
{0x1924, 0x6703, 0xFFFF, 0xFFFF, "SFC4000 rev A iSCSI/Onload [Solarstorm](0x6703)"},
{0x1924, 0x6703, 0x10B8, 0x0102, "SMC10GPCIe-10BT (A2) [TigerCard](0x10B8-0x0102)"},
{0x1924, 0x6703, 0x10B8, 0x0103, "SMC10GPCIe-10BT (A3) [TigerCard](0x10B8-0x0103)"},
{0x1924, 0x6703, 0x10B8, 0x0201, "SMC10GPCIe-XFP (A1) [TigerCard](0x10B8-0x0201)"},
{0x1924, 0x6703, 0x1924, 0x0101, "SFE4001-A1(0x1924-0x0101)"},
{0x1924, 0x6703, 0x1924, 0x0102, "SFE4001-A2(0x1924-0x0102)"},
{0x1924, 0x6703, 0x1924, 0x0103, "SFE4001-A3(0x1924-0x0103)"},
{0x1924, 0x6703, 0x1924, 0x0201, "SFE4002-A1(0x1924-0x0201)"},
{0x1924, 0x6703, 0x1924, 0x0301, "SFE4003-A1(0x1924-0x0301)"},
{0x1924, 0x6703, 0x1924, 0x0302, "SFE4003-A2(0x1924-0x0302)"},
{0x1924, 0x6703, 0x1924, 0x0303, "SFE4003-A3(0x1924-0x0303)"},
{0x1924, 0x6703, 0x1924, 0x0304, "SFE4003-A4(0x1924-0x0304)"},
{0x1924, 0x6703, 0x1924, 0x0500, "SFE4005-A0(0x1924-0x0500)"},
{0x1924, 0xC101, 0xFFFF, 0xFFFF, "EF1-21022T [EtherFabric](0xC101)"},
}; /* pci_vid_1924[] */

static pci_id_t const pci_vid_192A[] = {
{0x192A, 0xFFFF, 0xFFFF, 0xFFFF, "BiTMICRO Networks Inc.(0x192A)"},
{0x192A, 0x0008, 0xFFFF, 0xFFFF, "RAMPART(0x0008)"},
}; /* pci_vid_192A[] */

static pci_id_t const pci_vid_192E[] = {
{0x192E, 0xFFFF, 0xFFFF, 0xFFFF, "TransDimension(0x192E)"},
}; /* pci_vid_192E[] */

static pci_id_t const pci_vid_1931[] = {
{0x1931, 0xFFFF, 0xFFFF, 0xFFFF, "Option N.V.(0x1931)"},
{0x1931, 0x000C, 0xFFFF, 0xFFFF, "Qualcomm MSM6275 UMTS chip(0x000C)"},
}; /* pci_vid_1931[] */

static pci_id_t const pci_vid_1932[] = {
{0x1932, 0xFFFF, 0xFFFF, 0xFFFF, "DiBcom(0x1932)"},
}; /* pci_vid_1932[] */

static pci_id_t const pci_vid_193C[] = {
{0x193C, 0xFFFF, 0xFFFF, 0xFFFF, "MAXIM Integrated Products(0x193C)"},
}; /* pci_vid_193C[] */

static pci_id_t const pci_vid_193D[] = {
{0x193D, 0xFFFF, 0xFFFF, 0xFFFF, "New H3C Technologies Co., Ltd.(0x193D)"},
}; /* pci_vid_193D[] */

static pci_id_t const pci_vid_193F[] = {
{0x193F, 0xFFFF, 0xFFFF, 0xFFFF, "AHA Products Group(0x193F)"},
{0x193F, 0x0001, 0xFFFF, 0xFFFF, "AHA36x-PCIX(0x0001)"},
{0x193F, 0x0360, 0xFFFF, 0xFFFF, "AHA360-PCIe(0x0360)"},
{0x193F, 0x0363, 0xFFFF, 0xFFFF, "AHA363-PCIe(0x0363)"},
{0x193F, 0x0364, 0xFFFF, 0xFFFF, "AHA364-PCIe(0x0364)"},
{0x193F, 0x0367, 0xFFFF, 0xFFFF, "AHA367-PCIe(0x0367)"},
{0x193F, 0x0370, 0xFFFF, 0xFFFF, "AHA370-PCIe(0x0370)"},
{0x193F, 0x0604, 0xFFFF, 0xFFFF, "AHA604(0x0604)"},
{0x193F, 0x0605, 0xFFFF, 0xFFFF, "AHA605(0x0605)"},
{0x193F, 0x3641, 0xFFFF, 0xFFFF, "AHA3641(0x3641)"},
{0x193F, 0x3642, 0xFFFF, 0xFFFF, "AHA3642(0x3642)"},
{0x193F, 0x6101, 0xFFFF, 0xFFFF, "AHA6101(0x6101)"},
{0x193F, 0x6102, 0xFFFF, 0xFFFF, "AHA6102(0x6102)"},
}; /* pci_vid_193F[] */

static pci_id_t const pci_vid_1942[] = {
{0x1942, 0xFFFF, 0xFFFF, 0xFFFF, "ClearSpeed Technology plc(0x1942)"},
{0x1942, 0xE511, 0xFFFF, 0xFFFF, "Advance X620 accelerator card(0xE511)"},
{0x1942, 0xE521, 0xFFFF, 0xFFFF, "Advance e620 accelerator card(0xE521)"},
}; /* pci_vid_1942[] */

static pci_id_t const pci_vid_1945[] = {
{0x1945, 0xFFFF, 0xFFFF, 0xFFFF, "MERA(0x1945)"},
{0x1945, 0x6200, 0xFFFF, 0xFFFF, "PXI/PXIe measurement module(0x6200)"},
}; /* pci_vid_1945[] */

static pci_id_t const pci_vid_1947[] = {
{0x1947, 0xFFFF, 0xFFFF, 0xFFFF, "C-guys, Inc.(0x1947)"},
{0x1947, 0x4743, 0xFFFF, 0xFFFF, "CG200 Dual SD/SDIO Host controller device(0x4743)"},
}; /* pci_vid_1947[] */

static pci_id_t const pci_vid_1948[] = {
{0x1948, 0xFFFF, 0xFFFF, 0xFFFF, "Alpha Networks Inc.(0x1948)"},
}; /* pci_vid_1948[] */

static pci_id_t const pci_vid_194A[] = {
{0x194A, 0xFFFF, 0xFFFF, 0xFFFF, "DapTechnology B.V.(0x194A)"},
{0x194A, 0x1111, 0xFFFF, 0xFFFF, "FireSpy3850(0x1111)"},
{0x194A, 0x1112, 0xFFFF, 0xFFFF, "FireSpy450b(0x1112)"},
{0x194A, 0x1113, 0xFFFF, 0xFFFF, "FireSpy450bT(0x1113)"},
{0x194A, 0x1114, 0xFFFF, 0xFFFF, "FireSpy850(0x1114)"},
{0x194A, 0x1115, 0xFFFF, 0xFFFF, "FireSpy850bT(0x1115)"},
{0x194A, 0x1200, 0xFFFF, 0xFFFF, "FireTrac 3460bT(0x1200)"},
{0x194A, 0x1201, 0xFFFF, 0xFFFF, "FireTrac 3460bT (fallback firmware)(0x1201)"},
{0x194A, 0x1202, 0xFFFF, 0xFFFF, "FireTrac 3460bT(0x1202)"},
{0x194A, 0x1203, 0xFFFF, 0xFFFF, "FireTrac 3460bT (fallback firmware)(0x1203)"},
}; /* pci_vid_194A[] */

static pci_id_t const pci_vid_1954[] = {
{0x1954, 0xFFFF, 0xFFFF, 0xFFFF, "One Stop Systems, Inc.(0x1954)"},
}; /* pci_vid_1954[] */

static pci_id_t const pci_vid_1957[] = {
{0x1957, 0xFFFF, 0xFFFF, 0xFFFF, "Freescale Semiconductor Inc(0x1957)"},
{0x1957, 0x0012, 0xFFFF, 0xFFFF, "MPC8548E(0x0012)"},
{0x1957, 0x0013, 0xFFFF, 0xFFFF, "MPC8548(0x0013)"},
{0x1957, 0x0014, 0xFFFF, 0xFFFF, "MPC8543E(0x0014)"},
{0x1957, 0x0015, 0xFFFF, 0xFFFF, "MPC8543(0x0015)"},
{0x1957, 0x0018, 0xFFFF, 0xFFFF, "MPC8547E(0x0018)"},
{0x1957, 0x0019, 0xFFFF, 0xFFFF, "MPC8545E(0x0019)"},
{0x1957, 0x001A, 0xFFFF, 0xFFFF, "MPC8545(0x001A)"},
{0x1957, 0x0020, 0xFFFF, 0xFFFF, "MPC8568E(0x0020)"},
{0x1957, 0x0021, 0xFFFF, 0xFFFF, "MPC8568(0x0021)"},
{0x1957, 0x0022, 0xFFFF, 0xFFFF, "MPC8567E(0x0022)"},
{0x1957, 0x0023, 0xFFFF, 0xFFFF, "MPC8567(0x0023)"},
{0x1957, 0x0030, 0xFFFF, 0xFFFF, "MPC8533E(0x0030)"},
{0x1957, 0x0031, 0xFFFF, 0xFFFF, "MPC8533(0x0031)"},
{0x1957, 0x0032, 0xFFFF, 0xFFFF, "MPC8544E(0x0032)"},
{0x1957, 0x0033, 0xFFFF, 0xFFFF, "MPC8544(0x0033)"},
{0x1957, 0x0040, 0xFFFF, 0xFFFF, "MPC8572E(0x0040)"},
{0x1957, 0x0041, 0xFFFF, 0xFFFF, "MPC8572(0x0041)"},
{0x1957, 0x0050, 0xFFFF, 0xFFFF, "MPC8536E(0x0050)"},
{0x1957, 0x0051, 0xFFFF, 0xFFFF, "MPC8536(0x0051)"},
{0x1957, 0x0052, 0xFFFF, 0xFFFF, "MPC8535E(0x0052)"},
{0x1957, 0x0053, 0xFFFF, 0xFFFF, "MPC8535(0x0053)"},
{0x1957, 0x0060, 0xFFFF, 0xFFFF, "MPC8569(0x0060)"},
{0x1957, 0x0061, 0xFFFF, 0xFFFF, "MPC8569E(0x0061)"},
{0x1957, 0x0070, 0xFFFF, 0xFFFF, "P2020E(0x0070)"},
{0x1957, 0x0071, 0xFFFF, 0xFFFF, "P2020(0x0071)"},
{0x1957, 0x0078, 0xFFFF, 0xFFFF, "P2010E(0x0078)"},
{0x1957, 0x0079, 0xFFFF, 0xFFFF, "P2010(0x0079)"},
{0x1957, 0x0080, 0xFFFF, 0xFFFF, "MPC8349E(0x0080)"},
{0x1957, 0x0081, 0xFFFF, 0xFFFF, "MPC8349(0x0081)"},
{0x1957, 0x0082, 0xFFFF, 0xFFFF, "MPC8347E TBGA(0x0082)"},
{0x1957, 0x0083, 0xFFFF, 0xFFFF, "MPC8347 TBGA(0x0083)"},
{0x1957, 0x0084, 0xFFFF, 0xFFFF, "MPC8347E PBGA(0x0084)"},
{0x1957, 0x0084, 0x110A, 0x4074, "SIMATIC NET CP 1628(0x110A-0x4074)"},
{0x1957, 0x0085, 0xFFFF, 0xFFFF, "MPC8347 PBGA(0x0085)"},
{0x1957, 0x0085, 0x110A, 0x4046, "SIMATIC NET CP 1623(0x110A-0x4046)"},
{0x1957, 0x0086, 0xFFFF, 0xFFFF, "MPC8343E(0x0086)"},
{0x1957, 0x0087, 0xFFFF, 0xFFFF, "MPC8343(0x0087)"},
{0x1957, 0x00B4, 0xFFFF, 0xFFFF, "MPC8315E(0x00B4)"},
{0x1957, 0x00B6, 0xFFFF, 0xFFFF, "MPC8314E(0x00B6)"},
{0x1957, 0x00B6, 0x1A56, 0x1101, "Bigfoot Killer Xeno Pro Gigabit Ethernet Controller(0x1A56-0x1101)"},
{0x1957, 0x00C2, 0xFFFF, 0xFFFF, "MPC8379E(0x00C2)"},
{0x1957, 0x00C3, 0xFFFF, 0xFFFF, "MPC8379(0x00C3)"},
{0x1957, 0x00C4, 0xFFFF, 0xFFFF, "MPC8378E(0x00C4)"},
{0x1957, 0x00C5, 0xFFFF, 0xFFFF, "MPC8378(0x00C5)"},
{0x1957, 0x00C6, 0xFFFF, 0xFFFF, "MPC8377E(0x00C6)"},
{0x1957, 0x00C7, 0xFFFF, 0xFFFF, "MPC8377(0x00C7)"},
{0x1957, 0x0100, 0xFFFF, 0xFFFF, "P1020E(0x0100)"},
{0x1957, 0x0101, 0xFFFF, 0xFFFF, "P1020(0x0101)"},
{0x1957, 0x0102, 0xFFFF, 0xFFFF, "P1021E(0x0102)"},
{0x1957, 0x0103, 0xFFFF, 0xFFFF, "P1021(0x0103)"},
{0x1957, 0x0108, 0xFFFF, 0xFFFF, "P1011E(0x0108)"},
{0x1957, 0x0109, 0xFFFF, 0xFFFF, "P1011(0x0109)"},
{0x1957, 0x010A, 0xFFFF, 0xFFFF, "P1012E(0x010A)"},
{0x1957, 0x010B, 0xFFFF, 0xFFFF, "P1012(0x010B)"},
{0x1957, 0x0110, 0xFFFF, 0xFFFF, "P1022E(0x0110)"},
{0x1957, 0x0111, 0xFFFF, 0xFFFF, "P1022(0x0111)"},
{0x1957, 0x0111, 0x1C7F, 0x5200, "EB5200(0x1C7F-0x5200)"},
{0x1957, 0x0118, 0xFFFF, 0xFFFF, "P1013E(0x0118)"},
{0x1957, 0x0119, 0xFFFF, 0xFFFF, "P1013(0x0119)"},
{0x1957, 0x0128, 0xFFFF, 0xFFFF, "P1010(0x0128)"},
{0x1957, 0x0400, 0xFFFF, 0xFFFF, "P4080E(0x0400)"},
{0x1957, 0x0401, 0xFFFF, 0xFFFF, "P4080(0x0401)"},
{0x1957, 0x0408, 0xFFFF, 0xFFFF, "P4040E(0x0408)"},
{0x1957, 0x0409, 0xFFFF, 0xFFFF, "P4040(0x0409)"},
{0x1957, 0x041F, 0xFFFF, 0xFFFF, "P3041(0x041F)"},
{0x1957, 0x0420, 0xFFFF, 0xFFFF, "QorIQ P5020 Communications Processor with security engine(0x0420)"},
{0x1957, 0x0421, 0xFFFF, 0xFFFF, "QorIQ P5020 Communications Processor without security engine(0x0421)"},
{0x1957, 0x0428, 0xFFFF, 0xFFFF, "QorIQ P5010 Communications Processor with security engine(0x0428)"},
{0x1957, 0x0429, 0xFFFF, 0xFFFF, "QorIQ P5010 Communications Processor without security engine(0x0429)"},
{0x1957, 0x0440, 0xFFFF, 0xFFFF, "T4240 with security(0x0440)"},
{0x1957, 0x0441, 0xFFFF, 0xFFFF, "T4240 without security(0x0441)"},
{0x1957, 0x0446, 0xFFFF, 0xFFFF, "T4160 with security(0x0446)"},
{0x1957, 0x0447, 0xFFFF, 0xFFFF, "T4160 without security(0x0447)"},
{0x1957, 0x0830, 0xFFFF, 0xFFFF, "T2080 with security(0x0830)"},
{0x1957, 0x0831, 0xFFFF, 0xFFFF, "T2080 without security(0x0831)"},
{0x1957, 0x0838, 0xFFFF, 0xFFFF, "T2081 with security(0x0838)"},
{0x1957, 0x0839, 0xFFFF, 0xFFFF, "T2081 without security(0x0839)"},
{0x1957, 0x580C, 0xFFFF, 0xFFFF, "MPC5121e(0x580C)"},
{0x1957, 0x7010, 0xFFFF, 0xFFFF, "MPC8641 PCI Host Bridge(0x7010)"},
{0x1957, 0x7011, 0xFFFF, 0xFFFF, "MPC8641D PCI Host Bridge(0x7011)"},
{0x1957, 0x7018, 0xFFFF, 0xFFFF, "MPC8610(0x7018)"},
{0x1957, 0x81C0, 0xFFFF, 0xFFFF, "LS1046A PCI Express Bridge(0x81C0)"},
{0x1957, 0xC006, 0xFFFF, 0xFFFF, "MPC8308(0xC006)"},
{0x1957, 0xC006, 0x1A56, 0x1201, "Bigfoot Killer E2100 Gigabit Ethernet Controller(0x1A56-0x1201)"},
{0x1957, 0xFC02, 0xFFFF, 0xFFFF, "RedStone(0xFC02)"},
{0x1957, 0xFC03, 0xFFFF, 0xFFFF, "CFI(0xFC03)"},
}; /* pci_vid_1957[] */

static pci_id_t const pci_vid_1958[] = {
{0x1958, 0xFFFF, 0xFFFF, 0xFFFF, "Faster Technology, LLC.(0x1958)"},
}; /* pci_vid_1958[] */

static pci_id_t const pci_vid_1959[] = {
{0x1959, 0xFFFF, 0xFFFF, 0xFFFF, "PA Semi, Inc(0x1959)"},
{0x1959, 0xA000, 0xFFFF, 0xFFFF, "PA6T Core(0xA000)"},
{0x1959, 0xA001, 0xFFFF, 0xFFFF, "PWRficient Host Bridge(0xA001)"},
{0x1959, 0xA002, 0xFFFF, 0xFFFF, "PWRficient PCI-Express Port(0xA002)"},
{0x1959, 0xA003, 0xFFFF, 0xFFFF, "PWRficient SMBus Controller(0xA003)"},
{0x1959, 0xA004, 0xFFFF, 0xFFFF, "PWRficient 16550 UART(0xA004)"},
{0x1959, 0xA005, 0xFFFF, 0xFFFF, "PWRficient Gigabit Ethernet(0xA005)"},
{0x1959, 0xA006, 0xFFFF, 0xFFFF, "PWRficient 10-Gigabit Ethernet(0xA006)"},
{0x1959, 0xA007, 0xFFFF, 0xFFFF, "PWRficient DMA Controller(0xA007)"},
{0x1959, 0xA008, 0xFFFF, 0xFFFF, "PWRficient LPC/Localbus Interface(0xA008)"},
{0x1959, 0xA009, 0xFFFF, 0xFFFF, "PWRficient L2 Cache(0xA009)"},
{0x1959, 0xA00A, 0xFFFF, 0xFFFF, "PWRficient DDR2 Memory Controller(0xA00A)"},
{0x1959, 0xA00B, 0xFFFF, 0xFFFF, "PWRficient SERDES(0xA00B)"},
{0x1959, 0xA00C, 0xFFFF, 0xFFFF, "PWRficient System/Debug Controller(0xA00C)"},
{0x1959, 0xA00D, 0xFFFF, 0xFFFF, "PWRficient PCI-Express Internal Endpoint(0xA00D)"},
}; /* pci_vid_1959[] */

static pci_id_t const pci_vid_1966[] = {
{0x1966, 0xFFFF, 0xFFFF, 0xFFFF, "Orad Hi-Tec Systems(0x1966)"},
{0x1966, 0x1975, 0xFFFF, 0xFFFF, "DVG64 family(0x1975)"},
{0x1966, 0x1977, 0xFFFF, 0xFFFF, "DVG128 family(0x1977)"},
{0x1966, 0x1979, 0xFFFF, 0xFFFF, "3DVG/UHD3(0x1979)"},
{0x1966, 0x1980, 0xFFFF, 0xFFFF, "HDV2/UHD2(0x1980)"},
{0x1966, 0x1980, 0x1234, 0x3160, "UHD2LC(0x1234-0x3160)"},
{0x1966, 0x1980, 0x1234, 0x3300, "Legacy UHD2(0x1234-0x3300)"},
{0x1966, 0x1980, 0x1234, 0x3410, "UHD2(0x1234-0x3410)"},
}; /* pci_vid_1966[] */

static pci_id_t const pci_vid_1969[] = {
{0x1969, 0xFFFF, 0xFFFF, 0xFFFF, "Qualcomm Atheros(0x1969)"},
{0x1969, 0x1026, 0xFFFF, 0xFFFF, "AR8121/AR8113/AR8114 Gigabit or Fast Ethernet(0x1026)"},
{0x1969, 0x1026, 0x1043, 0x8304, "P5KPL-CM Motherboard(0x1043-0x8304)"},
{0x1969, 0x1048, 0xFFFF, 0xFFFF, "Attansic L1 Gigabit Ethernet(0x1048)"},
{0x1969, 0x1048, 0x1043, 0x8226, "P5B-MX/WiFi-AP, P5KPL-VM Motherboard(0x1043-0x8226)"},
{0x1969, 0x1062, 0xFFFF, 0xFFFF, "AR8132 Fast Ethernet(0x1062)"},
{0x1969, 0x1063, 0xFFFF, 0xFFFF, "AR8131 Gigabit Ethernet(0x1063)"},
{0x1969, 0x1063, 0x1458, 0xE000, "GA-G31M-ES2L Motherboard(0x1458-0xE000)"},
{0x1969, 0x1063, 0x17C0, 0x10D2, "Medion Akoya E7214 Notebook PC [MD98410](0x17C0-0x10D2)"},
{0x1969, 0x1066, 0xFFFF, 0xFFFF, "Attansic L2c Gigabit Ethernet(0x1066)"},
{0x1969, 0x1067, 0xFFFF, 0xFFFF, "Attansic L1c Gigabit Ethernet(0x1067)"},
{0x1969, 0x1073, 0xFFFF, 0xFFFF, "AR8151 v1.0 Gigabit Ethernet(0x1073)"},
{0x1969, 0x1083, 0xFFFF, 0xFFFF, "AR8151 v2.0 Gigabit Ethernet(0x1083)"},
{0x1969, 0x1090, 0xFFFF, 0xFFFF, "AR8162 Fast Ethernet(0x1090)"},
{0x1969, 0x1090, 0x1043, 0x108D, "VivoBook X202E, X202EV(0x1043-0x108D)"},
{0x1969, 0x1091, 0xFFFF, 0xFFFF, "AR8161 Gigabit Ethernet(0x1091)"},
{0x1969, 0x1091, 0x1043, 0x1477, "N56VZ(0x1043-0x1477)"},
{0x1969, 0x10A0, 0xFFFF, 0xFFFF, "QCA8172 Fast Ethernet(0x10A0)"},
{0x1969, 0x10A1, 0xFFFF, 0xFFFF, "QCA8171 Gigabit Ethernet(0x10A1)"},
{0x1969, 0x2010, 0xFFFF, 0xFFFF, "QCA8175 card reader controller(0x2010)"},
{0x1969, 0x2048, 0xFFFF, 0xFFFF, "Attansic L2 Fast Ethernet(0x2048)"},
{0x1969, 0x2060, 0xFFFF, 0xFFFF, "AR8152 v1.1 Fast Ethernet(0x2060)"},
{0x1969, 0x2062, 0xFFFF, 0xFFFF, "AR8152 v2.0 Fast Ethernet(0x2062)"},
{0x1969, 0x2062, 0x1043, 0x8468, "Eee PC 1015PX(0x1043-0x8468)"},
{0x1969, 0x3010, 0xFFFF, 0xFFFF, "QCA8175 SD controller(0x3010)"},
{0x1969, 0xE091, 0xFFFF, 0xFFFF, "Killer E220x Gigabit Ethernet Controller(0xE091)"},
{0x1969, 0xE0A1, 0xFFFF, 0xFFFF, "Killer E2400 Gigabit Ethernet Controller(0xE0A1)"},
{0x1969, 0xE0B1, 0xFFFF, 0xFFFF, "Killer E2500 Gigabit Ethernet Controller(0xE0B1)"},
}; /* pci_vid_1969[] */

static pci_id_t const pci_vid_196A[] = {
{0x196A, 0xFFFF, 0xFFFF, 0xFFFF, "Sensory Networks Inc.(0x196A)"},
{0x196A, 0x0101, 0xFFFF, 0xFFFF, "NodalCore C-1000 Content Classification Accelerator(0x0101)"},
{0x196A, 0x0102, 0xFFFF, 0xFFFF, "NodalCore C-2000 Content Classification Accelerator(0x0102)"},
{0x196A, 0x0105, 0xFFFF, 0xFFFF, "NodalCore C-3000 Content Classification Accelerator(0x0105)"},
}; /* pci_vid_196A[] */

static pci_id_t const pci_vid_196D[] = {
{0x196D, 0xFFFF, 0xFFFF, 0xFFFF, "Club-3D BV(0x196D)"},
}; /* pci_vid_196D[] */

static pci_id_t const pci_vid_196E[] = {
{0x196E, 0xFFFF, 0xFFFF, 0xFFFF, "PNY(0x196E)"},
}; /* pci_vid_196E[] */

static pci_id_t const pci_vid_1971[] = {
{0x1971, 0xFFFF, 0xFFFF, 0xFFFF, "AGEIA Technologies, Inc.(0x1971)"},
{0x1971, 0x0000, 0xFFFF, 0xFFFF, "Physics Processing Unit [PhysX] 100 Series PCI Express Card(0x0000)"},
{0x1971, 0x1011, 0xFFFF, 0xFFFF, "Physics Processing Unit [PhysX] 100 Series PCI Card(0x1011)"},
{0x1971, 0x1011, 0x1043, 0x0001, "PhysX P1(0x1043-0x0001)"},
{0x1971, 0x1021, 0xFFFF, 0xFFFF, "Physics Processing Unit [PhysX] 200 Series PCI Express Card(0x1021)"},
}; /* pci_vid_1971[] */

static pci_id_t const pci_vid_1974[] = {
{0x1974, 0xFFFF, 0xFFFF, 0xFFFF, "Star Electronics GmbH & Co. KG(0x1974)"},
{0x1974, 0x0009, 0xFFFF, 0xFFFF, "FlexCard PMC-II(0x0009)"},
{0x1974, 0x0011, 0xFFFF, 0xFFFF, "FlexCard PMC-II Ethernet(0x0011)"},
{0x1974, 0x0018, 0xFFFF, 0xFFFF, "FlexCard PXIe3(0x0018)"},
{0x1974, 0x0019, 0xFFFF, 0xFFFF, "FlexCard PCIe3(0x0019)"},
{0x1974, 0x001A, 0xFFFF, 0xFFFF, "FlexCard PXIe Ethernet(0x001A)"},
{0x1974, 0x001B, 0xFFFF, 0xFFFF, "FlexCard PCIe Ethernet(0x001B)"},
}; /* pci_vid_1974[] */

static pci_id_t const pci_vid_1976[] = {
{0x1976, 0xFFFF, 0xFFFF, 0xFFFF, "TRENDnet(0x1976)"},
}; /* pci_vid_1976[] */

static pci_id_t const pci_vid_1977[] = {
{0x1977, 0xFFFF, 0xFFFF, 0xFFFF, "Parsec(0x1977)"},
}; /* pci_vid_1977[] */

static pci_id_t const pci_vid_197B[] = {
{0x197B, 0xFFFF, 0xFFFF, 0xFFFF, "JMicron Technology Corp.(0x197B)"},
{0x197B, 0x0250, 0xFFFF, 0xFFFF, "JMC250 PCI Express Gigabit Ethernet Controller(0x0250)"},
{0x197B, 0x0260, 0xFFFF, 0xFFFF, "JMC260 PCI Express Fast Ethernet Controller(0x0260)"},
{0x197B, 0x0368, 0xFFFF, 0xFFFF, "JMB368 IDE controller(0x0368)"},
{0x197B, 0x0585, 0xFFFF, 0xFFFF, "JMB58x AHCI SATA controller(0x0585)"},
{0x197B, 0x2360, 0xFFFF, 0xFFFF, "JMB360 AHCI Controller(0x2360)"},
{0x197B, 0x2361, 0xFFFF, 0xFFFF, "JMB361 AHCI/IDE(0x2361)"},
{0x197B, 0x2361, 0x1462, 0x7235, "P965 Neo MS-7235 mainboard(0x1462-0x7235)"},
{0x197B, 0x2362, 0xFFFF, 0xFFFF, "JMB362 SATA Controller(0x2362)"},
{0x197B, 0x2362, 0x1043, 0x8460, "P8P67 Deluxe Motherboard(0x1043-0x8460)"},
{0x197B, 0x2363, 0xFFFF, 0xFFFF, "JMB363 SATA/IDE Controller(0x2363)"},
{0x197B, 0x2363, 0x1043, 0x81E4, "P5B [JMB363](0x1043-0x81E4)"},
{0x197B, 0x2363, 0x1458, 0xB000, "Motherboard(0x1458-0xB000)"},
{0x197B, 0x2363, 0x1849, 0x2363, "Motherboard (one of many)(0x1849-0x2363)"},
{0x197B, 0x2364, 0xFFFF, 0xFFFF, "JMB364 AHCI Controller(0x2364)"},
{0x197B, 0x2365, 0xFFFF, 0xFFFF, "JMB365 AHCI/IDE(0x2365)"},
{0x197B, 0x2366, 0xFFFF, 0xFFFF, "JMB366 AHCI/IDE(0x2366)"},
{0x197B, 0x2368, 0xFFFF, 0xFFFF, "JMB368 IDE controller(0x2368)"},
{0x197B, 0x2369, 0xFFFF, 0xFFFF, "JMB369 Serial ATA Controller(0x2369)"},
{0x197B, 0x2380, 0xFFFF, 0xFFFF, "IEEE 1394 Host Controller(0x2380)"},
{0x197B, 0x2381, 0xFFFF, 0xFFFF, "Standard SD Host Controller(0x2381)"},
{0x197B, 0x2382, 0xFFFF, 0xFFFF, "SD/MMC Host Controller(0x2382)"},
{0x197B, 0x2383, 0xFFFF, 0xFFFF, "MS Host Controller(0x2383)"},
{0x197B, 0x2384, 0xFFFF, 0xFFFF, "xD Host Controller(0x2384)"},
{0x197B, 0x2386, 0xFFFF, 0xFFFF, "Standard SD Host Controller(0x2386)"},
{0x197B, 0x2387, 0xFFFF, 0xFFFF, "SD/MMC Host Controller(0x2387)"},
{0x197B, 0x2388, 0xFFFF, 0xFFFF, "MS Host Controller(0x2388)"},
{0x197B, 0x2389, 0xFFFF, 0xFFFF, "xD Host Controller(0x2389)"},
{0x197B, 0x2391, 0xFFFF, 0xFFFF, "Standard SD Host Controller(0x2391)"},
{0x197B, 0x2392, 0xFFFF, 0xFFFF, "SD/MMC Host Controller(0x2392)"},
{0x197B, 0x2393, 0xFFFF, 0xFFFF, "MS Host Controller(0x2393)"},
{0x197B, 0x2394, 0xFFFF, 0xFFFF, "xD Host Controller(0x2394)"},
}; /* pci_vid_197B[] */

static pci_id_t const pci_vid_1982[] = {
{0x1982, 0xFFFF, 0xFFFF, 0xFFFF, "Distant Early Warning Communications Inc(0x1982)"},
{0x1982, 0x1600, 0xFFFF, 0xFFFF, "OX16C954 HOST-A(0x1600)"},
{0x1982, 0x16FF, 0xFFFF, 0xFFFF, "OX16C954 HOST-B(0x16FF)"},
}; /* pci_vid_1982[] */

static pci_id_t const pci_vid_1987[] = {
{0x1987, 0xFFFF, 0xFFFF, 0xFFFF, "Phison Electronics Corporation(0x1987)"},
{0x1987, 0x5007, 0xFFFF, 0xFFFF, "E7 NVMe Controller(0x5007)"},
{0x1987, 0x5008, 0xFFFF, 0xFFFF, "E8 PCIe3 x2 NVMe Controller(0x5008)"},
{0x1987, 0x5012, 0xFFFF, 0xFFFF, "E12 NVMe Controller(0x5012)"},
{0x1987, 0x5013, 0xFFFF, 0xFFFF, "PS5013-E13 PCIe3 NVMe Controller (DRAM-less)(0x5013)"},
{0x1987, 0x5015, 0xFFFF, 0xFFFF, "PS5015-E15 PCIe3 NVMe Controller (DRAM-less)(0x5015)"},
{0x1987, 0x5016, 0xFFFF, 0xFFFF, "E16 PCIe4 NVMe Controller(0x5016)"},
{0x1987, 0x5018, 0xFFFF, 0xFFFF, "E18 PCIe4 NVMe Controller(0x5018)"},
{0x1987, 0x5019, 0xFFFF, 0xFFFF, "PS5019-E19 PCIe4 NVMe Controller (DRAM-less)(0x5019)"},
{0x1987, 0x5021, 0xFFFF, 0xFFFF, "PS5021-E21 PCIe4 NVMe Controller (DRAM-less)(0x5021)"},
{0x1987, 0x5026, 0xFFFF, 0xFFFF, "PS5026-E26 PCIe5 NVMe Controller(0x5026)"},
{0x1987, 0x5027, 0xFFFF, 0xFFFF, "PS5027-E27T PCIe4 NVMe Controller (DRAM-less)(0x5027)"},
}; /* pci_vid_1987[] */

static pci_id_t const pci_vid_1989[] = {
{0x1989, 0xFFFF, 0xFFFF, 0xFFFF, "Montilio Inc.(0x1989)"},
{0x1989, 0x0001, 0xFFFF, 0xFFFF, "RapidFile Bridge(0x0001)"},
{0x1989, 0x8001, 0xFFFF, 0xFFFF, "RapidFile(0x8001)"},
}; /* pci_vid_1989[] */

static pci_id_t const pci_vid_198A[] = {
{0x198A, 0xFFFF, 0xFFFF, 0xFFFF, "Nallatech Ltd.(0x198A)"},
}; /* pci_vid_198A[] */

static pci_id_t const pci_vid_1993[] = {
{0x1993, 0xFFFF, 0xFFFF, 0xFFFF, "Innominate Security Technologies AG(0x1993)"},
}; /* pci_vid_1993[] */

static pci_id_t const pci_vid_1999[] = {
{0x1999, 0xFFFF, 0xFFFF, 0xFFFF, "A-Logics(0x1999)"},
{0x1999, 0xA900, 0xFFFF, 0xFFFF, "AM-7209 Video Processor(0xA900)"},
}; /* pci_vid_1999[] */

static pci_id_t const pci_vid_199A[] = {
{0x199A, 0xFFFF, 0xFFFF, 0xFFFF, "Pulse-LINK, Inc.(0x199A)"},
}; /* pci_vid_199A[] */

static pci_id_t const pci_vid_199D[] = {
{0x199D, 0xFFFF, 0xFFFF, 0xFFFF, "Xsigo Systems(0x199D)"},
{0x199D, 0x8209, 0xFFFF, 0xFFFF, "Virtual NIC Device(0x8209)"},
{0x199D, 0x890A, 0xFFFF, 0xFFFF, "Virtual HBA Device(0x890A)"},
}; /* pci_vid_199D[] */

static pci_id_t const pci_vid_199F[] = {
{0x199F, 0xFFFF, 0xFFFF, 0xFFFF, "Auvitek(0x199F)"},
{0x199F, 0x8501, 0xFFFF, 0xFFFF, "AU85X1 PCI REV1.1(0x8501)"},
{0x199F, 0x8521, 0xFFFF, 0xFFFF, "AU8521 TV card(0x8521)"},
}; /* pci_vid_199F[] */

static pci_id_t const pci_vid_19A2[] = {
{0x19A2, 0xFFFF, 0xFFFF, 0xFFFF, "Emulex Corporation(0x19A2)"},
{0x19A2, 0x0120, 0xFFFF, 0xFFFF, "x1 PCIe Gen2 Bridge[Pilot4](0x0120)"},
{0x19A2, 0x0200, 0xFFFF, 0xFFFF, "BladeEngine 10Gb PCI-E iSCSI adapter(0x0200)"},
{0x19A2, 0x0201, 0xFFFF, 0xFFFF, "BladeEngine 10Gb PCIe Network Adapter(0x0201)"},
{0x19A2, 0x0211, 0xFFFF, 0xFFFF, "BladeEngine2 10Gb Gen2 PCIe Network Adapter(0x0211)"},
{0x19A2, 0x0212, 0xFFFF, 0xFFFF, "BladeEngine2 10Gb Gen2 PCIe iSCSI Adapter(0x0212)"},
{0x19A2, 0x0221, 0xFFFF, 0xFFFF, "BladeEngine3 10Gb Gen2 PCIe Network Adapter(0x0221)"},
{0x19A2, 0x0222, 0xFFFF, 0xFFFF, "BladeEngine3 10Gb Gen2 PCIe iSCSI Adapter(0x0222)"},
{0x19A2, 0x0700, 0xFFFF, 0xFFFF, "OneConnect OCe10100/OCe10102 Series 10 GbE(0x0700)"},
{0x19A2, 0x0700, 0x103C, 0x1747, "NC550SFP DualPort 10GbE Server Adapter(0x103C-0x1747)"},
{0x19A2, 0x0700, 0x103C, 0x1749, "NC550SFP Dual Port Server Adapter(0x103C-0x1749)"},
{0x19A2, 0x0700, 0x103C, 0x174A, "NC551m Dual Port FlexFabric 10Gb Adapter(0x103C-0x174A)"},
{0x19A2, 0x0700, 0x103C, 0x174B, "StorageWorks NC550 DualPort Converged Network Adapter(0x103C-0x174B)"},
{0x19A2, 0x0700, 0x103C, 0x3314, "NC551i Dual Port FlexFabric 10Gb Adapter(0x103C-0x3314)"},
{0x19A2, 0x0702, 0xFFFF, 0xFFFF, "OneConnect 10Gb iSCSI Initiator(0x0702)"},
{0x19A2, 0x0704, 0xFFFF, 0xFFFF, "OneConnect OCe10100/OCe10102 Series 10 GbE CNA(0x0704)"},
{0x19A2, 0x0704, 0x10DF, 0xE602, "OneConnect OCe10100 10Gb CNA(0x10DF-0xE602)"},
{0x19A2, 0x0704, 0x10DF, 0xE630, "OneConnect OCe10102-FM-E / OCe10102-FX-E for EMC VNX Symmetrix(0x10DF-0xE630)"},
{0x19A2, 0x0710, 0xFFFF, 0xFFFF, "OneConnect 10Gb NIC (be3)(0x0710)"},
{0x19A2, 0x0710, 0x1014, 0x03D0, "PCIe2 2-port 10GbE SR Adapter for POWER(0x1014-0x03D0)"},
{0x19A2, 0x0710, 0x1014, 0x03D1, "PCIe2 2-port 10GbE SFP+ Copper Adapter for POWER(0x1014-0x03D1)"},
{0x19A2, 0x0710, 0x1014, 0x0409, "Integrated Multifunction Card with Dual 10GbE SR Optical + Dual 1GbE for Power 750/760(0x1014-0x0409)"},
{0x19A2, 0x0710, 0x1014, 0x040A, "Integrated Multifunction Card with Dual 10GbE SR Copper + Dual 1GbE for Power 750/760(0x1014-0x040A)"},
{0x19A2, 0x0710, 0x103C, 0x3315, "NC553i 10Gb 2-port FlexFabric Converged Network Adapter(0x103C-0x3315)"},
{0x19A2, 0x0710, 0x103C, 0x3340, "NC552SFP 2-port 10Gb Server Adapter(0x103C-0x3340)"},
{0x19A2, 0x0710, 0x103C, 0x3341, "NC552m 10Gb 2-port FlexFabric Converged Network Adapter(0x103C-0x3341)"},
{0x19A2, 0x0710, 0x103C, 0x3345, "NC553m 10Gb 2-port FlexFabric Converged Network Adapter(0x103C-0x3345)"},
{0x19A2, 0x0710, 0x103C, 0x337B, "NC554FLB 10Gb 2-port FlexFabric Converged Network Adapter(0x103C-0x337B)"},
{0x19A2, 0x0710, 0x10DF, 0xE733, "Flex System EN4054 4-port 10Gb Ethernet Mezzanine Adapter(0x10DF-0xE733)"},
{0x19A2, 0x0712, 0xFFFF, 0xFFFF, "OneConnect 10Gb iSCSI Initiator (be3)(0x0712)"},
{0x19A2, 0x0714, 0xFFFF, 0xFFFF, "OneConnect 10Gb FCoE Initiator (be3)(0x0714)"},
{0x19A2, 0x0714, 0x103C, 0x3315, "NC553i 10Gb 2-port FlexFabric Converged Network Adapter(0x103C-0x3315)"},
{0x19A2, 0x0714, 0x103C, 0x337B, "NC554FLB 10Gb 2-port FlexFabric Converged Network Adapter(0x103C-0x337B)"},
{0x19A2, 0x0800, 0xFFFF, 0xFFFF, "ServerView iRMC HTI(0x0800)"},
}; /* pci_vid_19A2[] */

static pci_id_t const pci_vid_19A4[] = {
{0x19A4, 0xFFFF, 0xFFFF, 0xFFFF, "Owl Cyber Defense Solutions(0x19A4)"},
}; /* pci_vid_19A4[] */

static pci_id_t const pci_vid_19A8[] = {
{0x19A8, 0xFFFF, 0xFFFF, 0xFFFF, "DAQDATA GmbH(0x19A8)"},
}; /* pci_vid_19A8[] */

static pci_id_t const pci_vid_19AC[] = {
{0x19AC, 0xFFFF, 0xFFFF, 0xFFFF, "Kasten Chase Applied Research(0x19AC)"},
{0x19AC, 0x0001, 0xFFFF, 0xFFFF, "ACA2400 Crypto Accelerator(0x0001)"},
}; /* pci_vid_19AC[] */

static pci_id_t const pci_vid_19AE[] = {
{0x19AE, 0xFFFF, 0xFFFF, 0xFFFF, "Progeny Systems Corporation(0x19AE)"},
{0x19AE, 0x0520, 0xFFFF, 0xFFFF, "4135 HFT Interface Controller(0x0520)"},
{0x19AE, 0x0521, 0xFFFF, 0xFFFF, "Decimator(0x0521)"},
}; /* pci_vid_19AE[] */

static pci_id_t const pci_vid_19BA[] = {
{0x19BA, 0xFFFF, 0xFFFF, 0xFFFF, "ZyXEL Communications Corp.(0x19BA)"},
{0x19BA, 0x2330, 0xFFFF, 0xFFFF, "ZyWALL Turbo Card(0x2330)"},
}; /* pci_vid_19BA[] */

static pci_id_t const pci_vid_19C1[] = {
{0x19C1, 0xFFFF, 0xFFFF, 0xFFFF, "Exegy Inc.(0x19C1)"},
}; /* pci_vid_19C1[] */

static pci_id_t const pci_vid_19D1[] = {
{0x19D1, 0xFFFF, 0xFFFF, 0xFFFF, "Motorola Expedience(0x19D1)"},
}; /* pci_vid_19D1[] */

static pci_id_t const pci_vid_19D4[] = {
{0x19D4, 0xFFFF, 0xFFFF, 0xFFFF, "Quixant Limited(0x19D4)"},
}; /* pci_vid_19D4[] */

static pci_id_t const pci_vid_19DA[] = {
{0x19DA, 0xFFFF, 0xFFFF, 0xFFFF, "ZOTAC International (MCO) Ltd.(0x19DA)"},
}; /* pci_vid_19DA[] */

static pci_id_t const pci_vid_19DE[] = {
{0x19DE, 0xFFFF, 0xFFFF, 0xFFFF, "Pico Computing(0x19DE)"},
}; /* pci_vid_19DE[] */

static pci_id_t const pci_vid_19E2[] = {
{0x19E2, 0xFFFF, 0xFFFF, 0xFFFF, "Vector Informatik GmbH(0x19E2)"},
}; /* pci_vid_19E2[] */

static pci_id_t const pci_vid_19E3[] = {
{0x19E3, 0xFFFF, 0xFFFF, 0xFFFF, "DDRdrive LLC(0x19E3)"},
{0x19E3, 0x5801, 0xFFFF, 0xFFFF, "DDRdrive X1(0x5801)"},
{0x19E3, 0x5808, 0xFFFF, 0xFFFF, "DDRdrive X8(0x5808)"},
{0x19E3, 0xDD52, 0xFFFF, 0xFFFF, "DDRdrive X1-30(0xDD52)"},
}; /* pci_vid_19E3[] */

static pci_id_t const pci_vid_19E5[] = {
{0x19E5, 0xFFFF, 0xFFFF, 0xFFFF, "Huawei Technologies Co., Ltd.(0x19E5)"},
{0x19E5, 0x0123, 0xFFFF, 0xFFFF, "ES3000 V3 NVMe PCIe SSD(0x0123)"},
{0x19E5, 0x0123, 0x19E5, 0x3022, "NVMe SSD ES3600P V3 800GB 2.5\" U.2(0x19E5-0x3022)"},
{0x19E5, 0x0123, 0x19E5, 0x3023, "NVMe SSD ES3600P V3 1200GB 2.5\" U.2(0x19E5-0x3023)"},
{0x19E5, 0x0123, 0x19E5, 0x3024, "NVMe SSD ES3600P V3 1600GB 2.5\" U.2(0x19E5-0x3024)"},
{0x19E5, 0x0123, 0x19E5, 0x3025, "NVMe SSD ES3600P V3 2000GB 2.5\" U.2(0x19E5-0x3025)"},
{0x19E5, 0x0123, 0x19E5, 0x3026, "NVMe SSD ES3600P V3 3200GB 2.5\" U.2(0x19E5-0x3026)"},
{0x19E5, 0x0123, 0x19E5, 0x3033, "NVMe SSD ES3600C V3 1200GB HHHL AIC(0x19E5-0x3033)"},
{0x19E5, 0x0123, 0x19E5, 0x3034, "NVMe SSD ES3600C V3 1600GB HHHL AIC(0x19E5-0x3034)"},
{0x19E5, 0x0123, 0x19E5, 0x3036, "NVMe SSD ES3600C V3 3200GB HHHL AIC(0x19E5-0x3036)"},
{0x19E5, 0x0200, 0xFFFF, 0xFFFF, "Hi1822 Family (2*100GE)(0x0200)"},
{0x19E5, 0x0200, 0x19E5, 0xD139, "Hi1822 SP572 (2*100GE)(0x19E5-0xD139)"},
{0x19E5, 0x0200, 0x19E5, 0xD13D, "Hi1822 SC371 (2*100GE)(0x19E5-0xD13D)"},
{0x19E5, 0x0200, 0x19E5, 0xD147, "Hi1822 SP573 (2*100GE)(0x19E5-0xD147)"},
{0x19E5, 0x0202, 0xFFFF, 0xFFFF, "Hi1822 Family (2*32G FC)(0x0202)"},
{0x19E5, 0x0202, 0x19E5, 0xD149, "Hi1822 SP528 (2*32G FC)(0x19E5-0xD149)"},
{0x19E5, 0x0202, 0x19E5, 0xD302, "Hi1822 SP521 (2*32G FC)(0x19E5-0xD302)"},
{0x19E5, 0x0202, 0x19E5, 0xD304, "Hi1822 SP526 (2*32G FC)(0x19E5-0xD304)"},
{0x19E5, 0x0203, 0xFFFF, 0xFFFF, "Hi1822 Family (2*16G FC)(0x0203)"},
{0x19E5, 0x0203, 0x19E5, 0xD148, "Hi1822 SP527 (2*16G FC)(0x19E5-0xD148)"},
{0x19E5, 0x0203, 0x19E5, 0xD301, "Hi1822 SP520 (2*16G FC)(0x19E5-0xD301)"},
{0x19E5, 0x0203, 0x19E5, 0xD305, "Hi1822 SP525 (2*16G FC)(0x19E5-0xD305)"},
{0x19E5, 0x0205, 0xFFFF, 0xFFFF, "Hi1822 Family (2*100GE)(0x0205)"},
{0x19E5, 0x0205, 0x19E5, 0xDF27, "Hi1822 MZ731 MEZZ (2*100GE)(0x19E5-0xDF27)"},
{0x19E5, 0x0206, 0xFFFF, 0xFFFF, "Hi1822 Family (2*25GE)(0x0206)"},
{0x19E5, 0x0206, 0x19E5, 0xD138, "Hi1822 SP582 (2*25GE)(0x19E5-0xD138)"},
{0x19E5, 0x0206, 0x19E5, 0xD13A, "Hi1822 SC381 (2*25GE)(0x19E5-0xD13A)"},
{0x19E5, 0x0206, 0x19E5, 0xD145, "Hi1822 SP586 (2*25GE)(0x19E5-0xD145)"},
{0x19E5, 0x0210, 0xFFFF, 0xFFFF, "Hi1822 Family (4*25GE)(0x0210)"},
{0x19E5, 0x0210, 0x19E5, 0xDF2E, "Hi1822 MZ532 MEZZ (4*25GE)(0x19E5-0xDF2E)"},
{0x19E5, 0x0211, 0xFFFF, 0xFFFF, "Hi1822 Family (4*25GE)(0x0211)"},
{0x19E5, 0x0211, 0x19E5, 0xD12F, "Hi1822 SP571 (4*25GE)(0x19E5-0xD12F)"},
{0x19E5, 0x0211, 0x19E5, 0xD137, "Hi1822 SP581 (4*25GE)(0x19E5-0xD137)"},
{0x19E5, 0x0211, 0x19E5, 0xD142, "Hi1822 SP583 (4*25GE)(0x19E5-0xD142)"},
{0x19E5, 0x0212, 0xFFFF, 0xFFFF, "Hi1822 Family (2*8G FC)(0x0212)"},
{0x19E5, 0x0212, 0x19E5, 0xD303, "Hi1822 SP522 (2*8G FC)(0x19E5-0xD303)"},
{0x19E5, 0x0212, 0x19E5, 0xD306, "Hi1822 SP523 (2*8G FC)(0x19E5-0xD306)"},
{0x19E5, 0x0222, 0xFFFF, 0xFFFF, "Hi1822 Family(0x0222)"},
{0x19E5, 0x0222, 0x19E5, 0x0051, "Hi1822 SP681 (2*25/10GE)(0x19E5-0x0051)"},
{0x19E5, 0x0222, 0x19E5, 0x0052, "Hi1822 SP680 (4*25/10GE)(0x19E5-0x0052)"},
{0x19E5, 0x0222, 0x19E5, 0x00A1, "Hi1822 SP670 (2*100GE)(0x19E5-0x00A1)"},
{0x19E5, 0x1710, 0xFFFF, 0xFFFF, "iBMA Virtual Network Adapter(0x1710)"},
{0x19E5, 0x1711, 0xFFFF, 0xFFFF, "Hi171x Series [iBMC Intelligent Management system chip w/VGA support](0x1711)"},
{0x19E5, 0x1822, 0xFFFF, 0xFFFF, "Hi1822 Family (4*25GE)(0x1822)"},
{0x19E5, 0x1822, 0x19E5, 0xD129, "Hi1822 SP570 (4*25GE)(0x19E5-0xD129)"},
{0x19E5, 0x1822, 0x19E5, 0xD136, "Hi1822 SP580 (4*25GE)(0x19E5-0xD136)"},
{0x19E5, 0x1822, 0x19E5, 0xD141, "Hi1822 SP583 (4*25GE)(0x19E5-0xD141)"},
{0x19E5, 0x1822, 0x19E5, 0xD146, "Hi1822 SP585 (4*25GE)(0x19E5-0xD146)"},
{0x19E5, 0x3714, 0xFFFF, 0xFFFF, "ES3000 V5 NVMe PCIe SSD(0x3714)"},
{0x19E5, 0x3714, 0x19E5, 0x5312, "NVMe SSD ES3500P V5 2000GB 2.5\" U.2(0x19E5-0x5312)"},
{0x19E5, 0x371E, 0xFFFF, 0xFFFF, "Hi1822 Family Virtual Bridge(0x371E)"},
{0x19E5, 0x3754, 0xFFFF, 0xFFFF, "ES3000 V6 NVMe PCIe SSD(0x3754)"},
{0x19E5, 0x3754, 0x19E5, 0x6122, "NVMe SSD ES3600P V6 1600GB 2.5\" U.2(0x19E5-0x6122)"},
{0x19E5, 0x3754, 0x19E5, 0x6123, "NVMe SSD ES3600P V6 3200GB 2.5\" U.2(0x19E5-0x6123)"},
{0x19E5, 0x3754, 0x19E5, 0x6124, "NVMe SSD ES3600P V6 6400GB 2.5\" U.2(0x19E5-0x6124)"},
{0x19E5, 0x3754, 0x19E5, 0x6141, "NVMe SSD ES3800P V6 800GB 2.5\" U.2(0x19E5-0x6141)"},
{0x19E5, 0x3754, 0x19E5, 0x6142, "NVMe SSD ES3800P V6 1600GB 2.5\" U.2(0x19E5-0x6142)"},
{0x19E5, 0x3754, 0x19E5, 0x6212, "NVMe SSD ES3500P V6 1920GB 2.5\" U.2(0x19E5-0x6212)"},
{0x19E5, 0x3754, 0x19E5, 0x6213, "NVMe SSD ES3500P V6 3840GB 2.5\" U.2(0x19E5-0x6213)"},
{0x19E5, 0x3754, 0x19E5, 0x6214, "NVMe SSD ES3500P V6 7680GB 2.5\" U.2(0x19E5-0x6214)"},
{0x19E5, 0x3754, 0x19E5, 0x6215, "NVMe SSD ES3500P V6 15360GB 2.5\" U.2(0x19E5-0x6215)"},
{0x19E5, 0x375E, 0xFFFF, 0xFFFF, "Hi1822 Family Virtual Function(0x375E)"},
{0x19E5, 0x375F, 0xFFFF, 0xFFFF, "Hi1822 Family Virtual Function(0x375F)"},
{0x19E5, 0x379E, 0xFFFF, 0xFFFF, "Hi1822 Family Virtual Function(0x379E)"},
{0x19E5, 0x379F, 0xFFFF, 0xFFFF, "Hi1822 Family Virtual Function(0x379F)"},
{0x19E5, 0xA120, 0xFFFF, 0xFFFF, "HiSilicon PCIe Root Port with Gen4(0xA120)"},
{0x19E5, 0xA121, 0xFFFF, 0xFFFF, "HiSilicon PCI-PCI Bridge(0xA121)"},
{0x19E5, 0xA122, 0xFFFF, 0xFFFF, "HiSilicon Embedded DMA Engine(0xA122)"},
{0x19E5, 0xA124, 0xFFFF, 0xFFFF, "HiSilicon Internal SDI Function Engine(0xA124)"},
{0x19E5, 0xA125, 0xFFFF, 0xFFFF, "HiSilicon SDI Network Controller(0xA125)"},
{0x19E5, 0xA126, 0xFFFF, 0xFFFF, "HiSilicon SDI NVMe Storage Controller(0xA126)"},
{0x19E5, 0xA127, 0xFFFF, 0xFFFF, "HiSilicon SDI Accelerator(0xA127)"},
{0x19E5, 0xA12A, 0xFFFF, 0xFFFF, "HiSilicon Add-on PCI-PCI Bridge(0xA12A)"},
{0x19E5, 0xA220, 0xFFFF, 0xFFFF, "HNS GE Network Controller(0xA220)"},
{0x19E5, 0xA221, 0xFFFF, 0xFFFF, "HNS GE/10GE/25GE Network Controller(0xA221)"},
{0x19E5, 0xA221, 0x19E5, 0x0454, "TM280(0x19E5-0x0454)"},
{0x19E5, 0xA221, 0x19E5, 0x04CC, "TM210(0x19E5-0x04CC)"},
{0x19E5, 0xA221, 0x19E5, 0xD14A, "TM280 4*25G(0x19E5-0xD14A)"},
{0x19E5, 0xA221, 0x19E5, 0xD14B, "TM210 4*GE(0x19E5-0xD14B)"},
{0x19E5, 0xA222, 0xFFFF, 0xFFFF, "HNS GE/10GE/25GE RDMA Network Controller(0xA222)"},
{0x19E5, 0xA224, 0xFFFF, 0xFFFF, "HNS GE/10GE/25GE/50GE RDMA Network Controller(0xA224)"},
{0x19E5, 0xA226, 0xFFFF, 0xFFFF, "HNS GE/10GE/25GE/50GE/100GE RDMA Network Controller(0xA226)"},
{0x19E5, 0xA22A, 0xFFFF, 0xFFFF, "HiSilicon Network For SDI(0xA22A)"},
{0x19E5, 0xA22E, 0xFFFF, 0xFFFF, "HNS Network Controller (Virtual Function)(0xA22E)"},
{0x19E5, 0xA22F, 0xFFFF, 0xFFFF, "HNS RDMA Network Controller (Virtual Function)(0xA22F)"},
{0x19E5, 0xA230, 0xFFFF, 0xFFFF, "HiSilicon SAS 3.0 HBA(0xA230)"},
{0x19E5, 0xA235, 0xFFFF, 0xFFFF, "HiSilicon AHCI HBA(0xA235)"},
{0x19E5, 0xA238, 0xFFFF, 0xFFFF, "HiSilicon USB 3.0 Host Controller(0xA238)"},
{0x19E5, 0xA239, 0xFFFF, 0xFFFF, "HiSilicon USB 2.0 2-port Host Controller(0xA239)"},
{0x19E5, 0xA23A, 0xFFFF, 0xFFFF, "HiSilicon USB 2.0 Host Controller(0xA23A)"},
{0x19E5, 0xA23B, 0xFFFF, 0xFFFF, "HiSilicon USB 1.1 Host Controller(0xA23B)"},
{0x19E5, 0xA250, 0xFFFF, 0xFFFF, "HiSilicon ZIP Engine(0xA250)"},
{0x19E5, 0xA251, 0xFFFF, 0xFFFF, "HiSilicon ZIP Engine(Virtual Function)(0xA251)"},
{0x19E5, 0xA255, 0xFFFF, 0xFFFF, "HiSilicon SEC Engine(0xA255)"},
{0x19E5, 0xA256, 0xFFFF, 0xFFFF, "HiSilicon SEC Engine(Virtual Function)(0xA256)"},
{0x19E5, 0xA258, 0xFFFF, 0xFFFF, "HiSilicon HPRE Engine(0xA258)"},
{0x19E5, 0xA259, 0xFFFF, 0xFFFF, "HiSilicon HPRE Engine(Virtual Function)(0xA259)"},
{0x19E5, 0xA25A, 0xFFFF, 0xFFFF, "HiSilicon RDE Engine(0xA25A)"},
{0x19E5, 0xA25B, 0xFFFF, 0xFFFF, "HiSilicon RDE Engine(Virtual Function)(0xA25B)"},
}; /* pci_vid_19E5[] */

static pci_id_t const pci_vid_19E7[] = {
{0x19E7, 0xFFFF, 0xFFFF, 0xFFFF, "NET (Network Equipment Technologies)(0x19E7)"},
{0x19E7, 0x1001, 0xFFFF, 0xFFFF, "STIX DSP Card(0x1001)"},
{0x19E7, 0x1002, 0xFFFF, 0xFFFF, "STIX - 1 Port T1/E1 Card(0x1002)"},
{0x19E7, 0x1003, 0xFFFF, 0xFFFF, "STIX - 2 Port T1/E1 Card(0x1003)"},
{0x19E7, 0x1004, 0xFFFF, 0xFFFF, "STIX - 4 Port T1/E1 Card(0x1004)"},
{0x19E7, 0x1005, 0xFFFF, 0xFFFF, "STIX - 4 Port FXS Card(0x1005)"},
}; /* pci_vid_19E7[] */

static pci_id_t const pci_vid_19EE[] = {
{0x19EE, 0xFFFF, 0xFFFF, 0xFFFF, "Netronome Systems, Inc.(0x19EE)"},
}; /* pci_vid_19EE[] */

static pci_id_t const pci_vid_19F1[] = {
{0x19F1, 0xFFFF, 0xFFFF, 0xFFFF, "BFG Tech(0x19F1)"},
}; /* pci_vid_19F1[] */

static pci_id_t const pci_vid_19FF[] = {
{0x19FF, 0xFFFF, 0xFFFF, 0xFFFF, "Eclipse Electronic Systems, Inc.(0x19FF)"},
}; /* pci_vid_19FF[] */

static pci_id_t const pci_vid_1A03[] = {
{0x1A03, 0xFFFF, 0xFFFF, 0xFFFF, "ASPEED Technology, Inc.(0x1A03)"},
{0x1A03, 0x1150, 0xFFFF, 0xFFFF, "AST1150 PCI-to-PCI Bridge(0x1150)"},
{0x1A03, 0x2000, 0xFFFF, 0xFFFF, "ASPEED Graphics Family(0x2000)"},
{0x1A03, 0x2000, 0x15D9, 0x0832, "X10SRL-F(0x15D9-0x0832)"},
{0x1A03, 0x2000, 0x15D9, 0x1B95, "H12SSL-i(0x15D9-0x1B95)"},
}; /* pci_vid_1A03[] */

static pci_id_t const pci_vid_1A05[] = {
{0x1A05, 0xFFFF, 0xFFFF, 0xFFFF, "deltaww(0x1A05)"},
}; /* pci_vid_1A05[] */

static pci_id_t const pci_vid_1A07[] = {
{0x1A07, 0xFFFF, 0xFFFF, 0xFFFF, "Kvaser AB(0x1A07)"},
{0x1A07, 0x0006, 0xFFFF, 0xFFFF, "CAN interface PC104+ HS/HS(0x0006)"},
{0x1A07, 0x0007, 0xFFFF, 0xFFFF, "CAN interface PCIcanx II HS or HS/HS(0x0007)"},
{0x1A07, 0x0008, 0xFFFF, 0xFFFF, "CAN interface PCIEcan HS or HS/HS(0x0008)"},
{0x1A07, 0x0009, 0xFFFF, 0xFFFF, "CAN interface PCI104 HS/HS(0x0009)"},
}; /* pci_vid_1A07[] */

static pci_id_t const pci_vid_1A08[] = {
{0x1A08, 0xFFFF, 0xFFFF, 0xFFFF, "Sierra semiconductor(0x1A08)"},
{0x1A08, 0x0000, 0xFFFF, 0xFFFF, "SC15064(0x0000)"},
}; /* pci_vid_1A08[] */

static pci_id_t const pci_vid_1A0D[] = {
{0x1A0D, 0xFFFF, 0xFFFF, 0xFFFF, "SEAKR Engineering(0x1A0D)"},
}; /* pci_vid_1A0D[] */

static pci_id_t const pci_vid_1A0E[] = {
{0x1A0E, 0xFFFF, 0xFFFF, 0xFFFF, "DekTec Digital Video B.V.(0x1A0E)"},
{0x1A0E, 0x083F, 0xFFFF, 0xFFFF, "DTA-2111 VHF/UHF Modulator(0x083F)"},
{0x1A0E, 0x0860, 0xFFFF, 0xFFFF, "DTA-2144(B) Quad ASI/SDI in+out(0x0860)"},
{0x1A0E, 0x0861, 0xFFFF, 0xFFFF, "DTA-2145 ASI/SDI in+out with bypass relay(0x0861)"},
{0x1A0E, 0x087C, 0xFFFF, 0xFFFF, "DTA-2172 Dual 3G-SDI/ASI ports(0x087C)"},
{0x1A0E, 0x087E, 0xFFFF, 0xFFFF, "DTA-2174 Quad 3G-SDI/ASI in+out(0x087E)"},
{0x1A0E, 0x087F, 0xFFFF, 0xFFFF, "DTA-2175 3G-SDI/ASI input+output with bypass relay(0x087F)"},
{0x1A0E, 0x0882, 0xFFFF, 0xFFFF, "DTA-2178 Octal 12G-SDI/ASI ports with genlock(0x0882)"},
{0x1A0E, 0xA882, 0xFFFF, 0xFFFF, "DTA-2178-ASI Octal ASI Ports(0xA882)"},
{0x1A0E, 0xB87E, 0xFFFF, 0xFFFF, "DTA-2174B Quad 3G-SDI/ASI ports (1x12G) with genlock(0xB87E)"},
}; /* pci_vid_1A0E[] */

static pci_id_t const pci_vid_1A17[] = {
{0x1A17, 0xFFFF, 0xFFFF, 0xFFFF, "Force10 Networks, Inc.(0x1A17)"},
{0x1A17, 0x8002, 0xFFFF, 0xFFFF, "PB-10GE-2P 10GbE Security Card(0x8002)"},
}; /* pci_vid_1A17[] */

static pci_id_t const pci_vid_1A1D[] = {
{0x1A1D, 0xFFFF, 0xFFFF, 0xFFFF, "GFaI e.V.(0x1A1D)"},
{0x1A1D, 0x1A17, 0xFFFF, 0xFFFF, "Meta Networks MTP-1G IDPS NIC(0x1A17)"},
}; /* pci_vid_1A1D[] */

static pci_id_t const pci_vid_1A1E[] = {
{0x1A1E, 0xFFFF, 0xFFFF, 0xFFFF, "3Leaf Systems, Inc.(0x1A1E)"},
}; /* pci_vid_1A1E[] */

static pci_id_t const pci_vid_1A22[] = {
{0x1A22, 0xFFFF, 0xFFFF, 0xFFFF, "Ambric Inc.(0x1A22)"},
}; /* pci_vid_1A22[] */

static pci_id_t const pci_vid_1A29[] = {
{0x1A29, 0xFFFF, 0xFFFF, 0xFFFF, "Fortinet, Inc.(0x1A29)"},
{0x1A29, 0x4338, 0xFFFF, 0xFFFF, "CP8 Content Processor ASIC(0x4338)"},
{0x1A29, 0x43A0, 0xFFFF, 0xFFFF, "CP9 Content Processor ASIC(0x43A0)"},
{0x1A29, 0x4E36, 0xFFFF, 0xFFFF, "NP6 Network Processor(0x4E36)"},
{0x1A29, 0x4E37, 0xFFFF, 0xFFFF, "NP7 Network Processor(0x4E37)"},
}; /* pci_vid_1A29[] */

static pci_id_t const pci_vid_1A2B[] = {
{0x1A2B, 0xFFFF, 0xFFFF, 0xFFFF, "Ascom AG(0x1A2B)"},
{0x1A2B, 0x0000, 0xFFFF, 0xFFFF, "GESP v1.2(0x0000)"},
{0x1A2B, 0x0001, 0xFFFF, 0xFFFF, "GESP v1.3(0x0001)"},
{0x1A2B, 0x0002, 0xFFFF, 0xFFFF, "ECOMP v1.3(0x0002)"},
{0x1A2B, 0x0005, 0xFFFF, 0xFFFF, "ETP v1.4(0x0005)"},
{0x1A2B, 0x000A, 0xFFFF, 0xFFFF, "ETP-104 v1.1(0x000A)"},
{0x1A2B, 0x000E, 0xFFFF, 0xFFFF, "DSLP-104 v1.1(0x000E)"},
}; /* pci_vid_1A2B[] */

static pci_id_t const pci_vid_1A30[] = {
{0x1A30, 0xFFFF, 0xFFFF, 0xFFFF, "Lantiq(0x1A30)"},
{0x1A30, 0x0680, 0xFFFF, 0xFFFF, "MtW8171 [Hyperion II](0x0680)"},
{0x1A30, 0x0700, 0xFFFF, 0xFFFF, "Wave300 PSB8224 [Hyperion III](0x0700)"},
{0x1A30, 0x0710, 0xFFFF, 0xFFFF, "Wave300 PSB8231 [Hyperion III](0x0710)"},
}; /* pci_vid_1A30[] */

static pci_id_t const pci_vid_1A32[] = {
{0x1A32, 0xFFFF, 0xFFFF, 0xFFFF, "Quanta Microsystems, Inc(0x1A32)"},
}; /* pci_vid_1A32[] */

static pci_id_t const pci_vid_1A3B[] = {
{0x1A3B, 0xFFFF, 0xFFFF, 0xFFFF, "AzureWave(0x1A3B)"},
{0x1A3B, 0x1112, 0xFFFF, 0xFFFF, "AR9285 Wireless Network Adapter (PCI-Express)(0x1112)"},
}; /* pci_vid_1A3B[] */

static pci_id_t const pci_vid_1A41[] = {
{0x1A41, 0xFFFF, 0xFFFF, 0xFFFF, "Tilera Corp.(0x1A41)"},
{0x1A41, 0x0001, 0xFFFF, 0xFFFF, "TILE64 processor(0x0001)"},
{0x1A41, 0x0002, 0xFFFF, 0xFFFF, "TILEPro processor(0x0002)"},
{0x1A41, 0x0200, 0xFFFF, 0xFFFF, "TILE-Gx processor(0x0200)"},
{0x1A41, 0x0201, 0xFFFF, 0xFFFF, "TILE-Gx Processor Virtual Function(0x0201)"},
{0x1A41, 0x2000, 0xFFFF, 0xFFFF, "TILE-Gx PCI Express Root Port(0x2000)"},
}; /* pci_vid_1A41[] */

static pci_id_t const pci_vid_1A4A[] = {
{0x1A4A, 0xFFFF, 0xFFFF, 0xFFFF, "SLAC National Accelerator Lab TID-AIR(0x1A4A)"},
{0x1A4A, 0x1000, 0xFFFF, 0xFFFF, "MCOR Power Supply Controller(0x1000)"},
{0x1A4A, 0x1010, 0xFFFF, 0xFFFF, "AMC EVR - Stockholm Timing Board(0x1010)"},
{0x1A4A, 0x1020, 0xFFFF, 0xFFFF, "PGPCard - Gen3 Cameralink Interface(0x1020)"},
{0x1A4A, 0x1030, 0xFFFF, 0xFFFF, "PGPCard - Gen3 GIGe Interface(0x1030)"},
{0x1A4A, 0x2000, 0xFFFF, 0xFFFF, "PGPCard - 4 Lane(0x2000)"},
{0x1A4A, 0x2001, 0xFFFF, 0xFFFF, "PGPCard - 8 Lane Plus EVR(0x2001)"},
{0x1A4A, 0x2010, 0xFFFF, 0xFFFF, "PCI-Express EVR(0x2010)"},
{0x1A4A, 0x2011, 0xFFFF, 0xFFFF, "PCI-Express EVR - TPR Version(0x2011)"},
{0x1A4A, 0x2020, 0xFFFF, 0xFFFF, "PGP-GEN3 PCIe - 8 Lane Plus EVR(0x2020)"},
{0x1A4A, 0x2030, 0xFFFF, 0xFFFF, "AXI Stream DAQ PCIe card(0x2030)"},
{0x1A4A, 0x2040, 0xFFFF, 0xFFFF, "EXO PCIe TEM(0x2040)"},
{0x1A4A, 0x3000, 0xFFFF, 0xFFFF, "COB DTM V1(0x3000)"},
{0x1A4A, 0x3001, 0xFFFF, 0xFFFF, "COB DTM V2(0x3001)"},
}; /* pci_vid_1A4A[] */

static pci_id_t const pci_vid_1A51[] = {
{0x1A51, 0xFFFF, 0xFFFF, 0xFFFF, "Hectronic AB(0x1A51)"},
}; /* pci_vid_1A51[] */

static pci_id_t const pci_vid_1A55[] = {
{0x1A55, 0xFFFF, 0xFFFF, 0xFFFF, "Rohde & Schwarz DVS GmbH(0x1A55)"},
{0x1A55, 0x0010, 0xFFFF, 0xFFFF, "SDStationOEM(0x0010)"},
{0x1A55, 0x0011, 0xFFFF, 0xFFFF, "SDStationOEM II(0x0011)"},
{0x1A55, 0x0020, 0xFFFF, 0xFFFF, "Centaurus(0x0020)"},
{0x1A55, 0x0021, 0xFFFF, 0xFFFF, "Centaurus II(0x0021)"},
{0x1A55, 0x0022, 0xFFFF, 0xFFFF, "Centaurus II LT(0x0022)"},
{0x1A55, 0x0030, 0xFFFF, 0xFFFF, "CLIPSTER-VPU 1.x (Hugo)(0x0030)"},
{0x1A55, 0x0040, 0xFFFF, 0xFFFF, "Hydra Cinema (JPEG)(0x0040)"},
{0x1A55, 0x0050, 0xFFFF, 0xFFFF, "CLIPSTER-VPU 2.x (DigiLab)(0x0050)"},
{0x1A55, 0x0060, 0xFFFF, 0xFFFF, "CLIPSTER-DCI 2.x (HydraX)(0x0060)"},
{0x1A55, 0x0061, 0xFFFF, 0xFFFF, "Atomix(0x0061)"},
{0x1A55, 0x0062, 0xFFFF, 0xFFFF, "Atomix LT(0x0062)"},
{0x1A55, 0x0063, 0xFFFF, 0xFFFF, "Atomix HDMI(0x0063)"},
{0x1A55, 0x0064, 0xFFFF, 0xFFFF, "Atomix STAN(0x0064)"},
{0x1A55, 0x0065, 0xFFFF, 0xFFFF, "Atomix HDMI STAN(0x0065)"},
{0x1A55, 0x0070, 0xFFFF, 0xFFFF, "RED Rocket(0x0070)"},
{0x1A55, 0x0090, 0xFFFF, 0xFFFF, "CinePlay(0x0090)"},
}; /* pci_vid_1A55[] */

static pci_id_t const pci_vid_1A56[] = {
{0x1A56, 0xFFFF, 0xFFFF, 0xFFFF, "Rivet Networks(0x1A56)"},
}; /* pci_vid_1A56[] */

static pci_id_t const pci_vid_1A57[] = {
{0x1A57, 0xFFFF, 0xFFFF, 0xFFFF, "Highly Reliable Systems(0x1A57)"},
}; /* pci_vid_1A57[] */

static pci_id_t const pci_vid_1A58[] = {
{0x1A58, 0xFFFF, 0xFFFF, 0xFFFF, "Razer USA Ltd.(0x1A58)"},
}; /* pci_vid_1A58[] */

static pci_id_t const pci_vid_1A5D[] = {
{0x1A5D, 0xFFFF, 0xFFFF, 0xFFFF, "Celoxica(0x1A5D)"},
}; /* pci_vid_1A5D[] */

static pci_id_t const pci_vid_1A5E[] = {
{0x1A5E, 0xFFFF, 0xFFFF, 0xFFFF, "Aprius Inc.(0x1A5E)"},
}; /* pci_vid_1A5E[] */

static pci_id_t const pci_vid_1A5F[] = {
{0x1A5F, 0xFFFF, 0xFFFF, 0xFFFF, "System TALKS Inc.(0x1A5F)"},
}; /* pci_vid_1A5F[] */

static pci_id_t const pci_vid_1A68[] = {
{0x1A68, 0xFFFF, 0xFFFF, 0xFFFF, "VirtenSys Limited(0x1A68)"},
}; /* pci_vid_1A68[] */

static pci_id_t const pci_vid_1A71[] = {
{0x1A71, 0xFFFF, 0xFFFF, 0xFFFF, "XenSource, Inc.(0x1A71)"},
}; /* pci_vid_1A71[] */

static pci_id_t const pci_vid_1A73[] = {
{0x1A73, 0xFFFF, 0xFFFF, 0xFFFF, "Violin Memory, Inc(0x1A73)"},
{0x1A73, 0x0001, 0xFFFF, 0xFFFF, "Mozart [Memory Appliance 1010](0x0001)"},
}; /* pci_vid_1A73[] */

static pci_id_t const pci_vid_1A76[] = {
{0x1A76, 0xFFFF, 0xFFFF, 0xFFFF, "Wavesat(0x1A76)"},
}; /* pci_vid_1A76[] */

static pci_id_t const pci_vid_1A77[] = {
{0x1A77, 0xFFFF, 0xFFFF, 0xFFFF, "Lightfleet Corporation(0x1A77)"},
}; /* pci_vid_1A77[] */

static pci_id_t const pci_vid_1A78[] = {
{0x1A78, 0xFFFF, 0xFFFF, 0xFFFF, "Virident Systems Inc.(0x1A78)"},
{0x1A78, 0x0031, 0xFFFF, 0xFFFF, "FlashMAX Drive(0x0031)"},
{0x1A78, 0x0031, 0x1A78, 0x0034, "FlashMAX PCIe SSD [rev 3](0x1A78-0x0034)"},
{0x1A78, 0x0031, 0x1A78, 0x0037, "FlashMAX PCIe SSD [rev 3D](0x1A78-0x0037)"},
{0x1A78, 0x0031, 0x1A78, 0x0038, "FlashMAX PCIe SSD [rev 4](0x1A78-0x0038)"},
{0x1A78, 0x0031, 0x1A78, 0x0039, "FlashMAX PCIe SSD [rev 4D](0x1A78-0x0039)"},
{0x1A78, 0x0040, 0xFFFF, 0xFFFF, "FlashMAX II(0x0040)"},
{0x1A78, 0x0041, 0xFFFF, 0xFFFF, "FlashMAX II(0x0041)"},
{0x1A78, 0x0042, 0xFFFF, 0xFFFF, "FlashMAX II(0x0042)"},
{0x1A78, 0x0050, 0xFFFF, 0xFFFF, "FlashMAX III(0x0050)"},
}; /* pci_vid_1A78[] */

static pci_id_t const pci_vid_1A84[] = {
{0x1A84, 0xFFFF, 0xFFFF, 0xFFFF, "Commex Technologies(0x1A84)"},
{0x1A84, 0x0001, 0xFFFF, 0xFFFF, "Vulcan SP HT6210 10-Gigabit Ethernet (rev 02)(0x0001)"},
}; /* pci_vid_1A84[] */

static pci_id_t const pci_vid_1A88[] = {
{0x1A88, 0xFFFF, 0xFFFF, 0xFFFF, "Duagon AG(0x1A88)"},
{0x1A88, 0x4D45, 0xFFFF, 0xFFFF, "Multifunction IP core(0x4D45)"},
}; /* pci_vid_1A88[] */

static pci_id_t const pci_vid_1A8A[] = {
{0x1A8A, 0xFFFF, 0xFFFF, 0xFFFF, "StarBridge, Inc.(0x1A8A)"},
}; /* pci_vid_1A8A[] */

static pci_id_t const pci_vid_1A8C[] = {
{0x1A8C, 0xFFFF, 0xFFFF, 0xFFFF, "Verigy Pte. Ltd.(0x1A8C)"},
{0x1A8C, 0x1100, 0xFFFF, 0xFFFF, "E8001-66443 PCI Express CIC(0x1100)"},
}; /* pci_vid_1A8C[] */

static pci_id_t const pci_vid_1A8E[] = {
{0x1A8E, 0xFFFF, 0xFFFF, 0xFFFF, "DRS Technologies(0x1A8E)"},
{0x1A8E, 0x2090, 0xFFFF, 0xFFFF, "Model 2090 PCI Express(0x2090)"},
}; /* pci_vid_1A8E[] */

static pci_id_t const pci_vid_1AA8[] = {
{0x1AA8, 0xFFFF, 0xFFFF, 0xFFFF, "Ciprico, Inc.(0x1AA8)"},
{0x1AA8, 0x0009, 0xFFFF, 0xFFFF, "RAIDCore Controller(0x0009)"},
{0x1AA8, 0x000A, 0xFFFF, 0xFFFF, "RAIDCore Controller(0x000A)"},
}; /* pci_vid_1AA8[] */

static pci_id_t const pci_vid_1AA9[] = {
{0x1AA9, 0xFFFF, 0xFFFF, 0xFFFF, "Schweitzer Engineering Laboratories(0x1AA9)"},
{0x1AA9, 0x000D, 0xFFFF, 0xFFFF, "SEL-3390S8 Serial Adapter(0x000D)"},
{0x1AA9, 0x000E, 0xFFFF, 0xFFFF, "SEL-3390E4 Ethernet Adapter(0x000E)"},
{0x1AA9, 0x0014, 0xFFFF, 0xFFFF, "SEL-3390T Time and Ethernet Adapter(0x0014)"},
{0x1AA9, 0x0015, 0xFFFF, 0xFFFF, "SEL-3350 Mainboard(0x0015)"},
{0x1AA9, 0x0016, 0xFFFF, 0xFFFF, "SEL-3350 Serial Expansion Board(0x0016)"},
{0x1AA9, 0x0017, 0xFFFF, 0xFFFF, "SEL-3350 GPIO Expansion Board(0x0017)"},
{0x1AA9, 0x0018, 0xFFFF, 0xFFFF, "SEL-3390E4 Ethernet Adapter(0x0018)"},
{0x1AA9, 0x001C, 0xFFFF, 0xFFFF, "SEL-3390E4 Ethernet Adapter(0x001C)"},
}; /* pci_vid_1AA9[] */

static pci_id_t const pci_vid_1AAB[] = {
{0x1AAB, 0xFFFF, 0xFFFF, 0xFFFF, "Silver Creations AG(0x1AAB)"},
{0x1AAB, 0x7750, 0xFFFF, 0xFFFF, "Sceye 10L(0x7750)"},
}; /* pci_vid_1AAB[] */

static pci_id_t const pci_vid_1AAE[] = {
{0x1AAE, 0xFFFF, 0xFFFF, 0xFFFF, "Global Velocity, Inc.(0x1AAE)"},
}; /* pci_vid_1AAE[] */

static pci_id_t const pci_vid_1AB4[] = {
{0x1AB4, 0xFFFF, 0xFFFF, 0xFFFF, "Distributed Management Task Force, Inc. (DMTF)(0x1AB4)"},
}; /* pci_vid_1AB4[] */

static pci_id_t const pci_vid_1AB6[] = {
{0x1AB6, 0xFFFF, 0xFFFF, 0xFFFF, "CalDigit, Inc.(0x1AB6)"},
{0x1AB6, 0x6201, 0xFFFF, 0xFFFF, "RAID Card(0x6201)"},
}; /* pci_vid_1AB6[] */

static pci_id_t const pci_vid_1AB8[] = {
{0x1AB8, 0xFFFF, 0xFFFF, 0xFFFF, "Parallels, Inc.(0x1AB8)"},
{0x1AB8, 0x4000, 0xFFFF, 0xFFFF, "Virtual Machine Communication Interface(0x4000)"},
{0x1AB8, 0x4005, 0xFFFF, 0xFFFF, "Accelerated Virtual Video Adapter(0x4005)"},
{0x1AB8, 0x4006, 0xFFFF, 0xFFFF, "Memory Ballooning Controller(0x4006)"},
}; /* pci_vid_1AB8[] */

static pci_id_t const pci_vid_1AB9[] = {
{0x1AB9, 0xFFFF, 0xFFFF, 0xFFFF, "Espia Srl(0x1AB9)"},
}; /* pci_vid_1AB9[] */

static pci_id_t const pci_vid_1AC1[] = {
{0x1AC1, 0xFFFF, 0xFFFF, 0xFFFF, "Global Unichip Corp.(0x1AC1)"},
{0x1AC1, 0x089A, 0xFFFF, 0xFFFF, "Coral Edge TPU(0x089A)"},
}; /* pci_vid_1AC1[] */

static pci_id_t const pci_vid_1AC8[] = {
{0x1AC8, 0xFFFF, 0xFFFF, 0xFFFF, "Aeroflex Gaisler(0x1AC8)"},
}; /* pci_vid_1AC8[] */

static pci_id_t const pci_vid_1ACC[] = {
{0x1ACC, 0xFFFF, 0xFFFF, 0xFFFF, "Point of View BV(0x1ACC)"},
}; /* pci_vid_1ACC[] */

static pci_id_t const pci_vid_1AD7[] = {
{0x1AD7, 0xFFFF, 0xFFFF, 0xFFFF, "Spectracom Corporation(0x1AD7)"},
{0x1AD7, 0x8000, 0xFFFF, 0xFFFF, "TSync-PCIe Time Code Processor(0x8000)"},
{0x1AD7, 0x9100, 0xFFFF, 0xFFFF, "TPRO-PCI-66U Timecode Reader/Generator(0x9100)"},
}; /* pci_vid_1AD7[] */

static pci_id_t const pci_vid_1ADE[] = {
{0x1ADE, 0xFFFF, 0xFFFF, 0xFFFF, "Spin Master Ltd.(0x1ADE)"},
{0x1ADE, 0x1501, 0xFFFF, 0xFFFF, "Swipetech barcode scanner(0x1501)"},
{0x1ADE, 0x3038, 0xFFFF, 0xFFFF, "PCIe Video Bridge(0x3038)"},
{0x1ADE, 0x3038, 0x13C2, 0x3016, "TT-budget S2-4200 Twin(0x13C2-0x3016)"},
{0x1ADE, 0x3038, 0x4254, 0x0552, "S952 v3(0x4254-0x0552)"},
}; /* pci_vid_1ADE[] */

static pci_id_t const pci_vid_1AE0[] = {
{0x1AE0, 0xFFFF, 0xFFFF, 0xFFFF, "Google, Inc.(0x1AE0)"},
{0x1AE0, 0x001F, 0xFFFF, 0xFFFF, "NVMe device(0x001F)"},
{0x1AE0, 0x0042, 0xFFFF, 0xFFFF, "Compute Engine Virtual Ethernet [gVNIC](0x0042)"},
{0x1AE0, 0xABCD, 0xFFFF, 0xFFFF, "Airbrush Combined Paintbox IPU/Oscar Edge TPU [Pixel Neural Core](0xABCD)"},
}; /* pci_vid_1AE0[] */

static pci_id_t const pci_vid_1AE3[] = {
{0x1AE3, 0xFFFF, 0xFFFF, 0xFFFF, "SANBlaze Technology, Inc.(0x1AE3)"},
}; /* pci_vid_1AE3[] */

static pci_id_t const pci_vid_1AE7[] = {
{0x1AE7, 0xFFFF, 0xFFFF, 0xFFFF, "First Wise Media GmbH(0x1AE7)"},
{0x1AE7, 0x0520, 0xFFFF, 0xFFFF, "HFC-S PCI A [X-TENSIONS XC-520](0x0520)"},
}; /* pci_vid_1AE7[] */

static pci_id_t const pci_vid_1AE8[] = {
{0x1AE8, 0xFFFF, 0xFFFF, 0xFFFF, "Basler AG(0x1AE8)"},
{0x1AE8, 0x0751, 0xFFFF, 0xFFFF, "mE5 marathon VCL(0x0751)"},
{0x1AE8, 0x0752, 0xFFFF, 0xFFFF, "mE5 marathon AF2(0x0752)"},
{0x1AE8, 0x0753, 0xFFFF, 0xFFFF, "mE5 marathon ACX QP(0x0753)"},
{0x1AE8, 0x0754, 0xFFFF, 0xFFFF, "mE5 marathon ACL(0x0754)"},
{0x1AE8, 0x0755, 0xFFFF, 0xFFFF, "mE5 marathon ACX SP(0x0755)"},
{0x1AE8, 0x0756, 0xFFFF, 0xFFFF, "mE5 marathon ACX DP(0x0756)"},
{0x1AE8, 0x0757, 0xFFFF, 0xFFFF, "mE5 marathon VCX QP(0x0757)"},
{0x1AE8, 0x0758, 0xFFFF, 0xFFFF, "mE5 marathon VF2(0x0758)"},
{0x1AE8, 0x0759, 0xFFFF, 0xFFFF, "mE5 marathon VCLx(0x0759)"},
{0x1AE8, 0x0A40, 0xFFFF, 0xFFFF, "microEnable IV AD1-CL(0x0A40)"},
{0x1AE8, 0x0A41, 0xFFFF, 0xFFFF, "microEnable IV VD1-CL(0x0A41)"},
{0x1AE8, 0x0A42, 0xFFFF, 0xFFFF, "microEnable IV AD4-CL(0x0A42)"},
{0x1AE8, 0x0A44, 0xFFFF, 0xFFFF, "microEnable IV VD4-CL(0x0A44)"},
{0x1AE8, 0x0A45, 0xFFFF, 0xFFFF, "microEnable IV AS1-CL(0x0A45)"},
{0x1AE8, 0x0A53, 0xFFFF, 0xFFFF, "microEnable 5 AQ8-CXP6B(0x0A53)"},
{0x1AE8, 0x0A54, 0xFFFF, 0xFFFF, "microEnable 5 VQ8-CXP6B(0x0A54)"},
{0x1AE8, 0x0A56, 0xFFFF, 0xFFFF, "microEnable 5 VQ8-CXP6D(0x0A56)"},
{0x1AE8, 0x0A57, 0xFFFF, 0xFFFF, "microEnable 5 AQ8-CXP6D(0x0A57)"},
{0x1AE8, 0x0A58, 0xFFFF, 0xFFFF, "microEnable 5 VD8-CL(0x0A58)"},
{0x1AE8, 0x0A5A, 0xFFFF, 0xFFFF, "microEnable 5 AD8-CL(0x0A5A)"},
{0x1AE8, 0x0A64, 0xFFFF, 0xFFFF, "imaWorx CXP-12 Quad(0x0A64)"},
{0x1AE8, 0x0B52, 0xFFFF, 0xFFFF, "mE5 Abacus 4G Base(0x0B52)"},
{0x1AE8, 0x0B53, 0xFFFF, 0xFFFF, "mE5 Abacus 4G Base II(0x0B53)"},
{0x1AE8, 0x0B61, 0xFFFF, 0xFFFF, "mE6 Abacus 4TG(0x0B61)"},
{0x1AE8, 0x0B63, 0xFFFF, 0xFFFF, "CXP-12 Interface Card 1C(0x0B63)"},
{0x1AE8, 0x0B64, 0xFFFF, 0xFFFF, "CXP-12 Interface Card 4C(0x0B64)"},
{0x1AE8, 0x0B65, 0xFFFF, 0xFFFF, "CXP-12 Interface Card 2C(0x0B65)"},
{0x1AE8, 0x0B66, 0xFFFF, 0xFFFF, "CXP-12 LightBridge 2C(0x0B66)"},
{0x1AE8, 0x0E42, 0xFFFF, 0xFFFF, "microEnable IV AQ4-GE(0x0E42)"},
{0x1AE8, 0x0E44, 0xFFFF, 0xFFFF, "microEnable IV VQ4-GE(0x0E44)"},
}; /* pci_vid_1AE8[] */

static pci_id_t const pci_vid_1AE9[] = {
{0x1AE9, 0xFFFF, 0xFFFF, 0xFFFF, "Wilocity Ltd.(0x1AE9)"},
{0x1AE9, 0x0101, 0xFFFF, 0xFFFF, "Wil6200 PCI Express Upstream Port(0x0101)"},
{0x1AE9, 0x0200, 0xFFFF, 0xFFFF, "Wil6200 PCI Express Port(0x0200)"},
{0x1AE9, 0x0201, 0xFFFF, 0xFFFF, "Wil6200 Wireless PCI Express Port(0x0201)"},
{0x1AE9, 0x0301, 0xFFFF, 0xFFFF, "Wil6200 802.11ad Wireless Network Adapter(0x0301)"},
{0x1AE9, 0x0302, 0xFFFF, 0xFFFF, "Wil6200 802.11ad Wireless Network Adapter(0x0302)"},
{0x1AE9, 0x0310, 0xFFFF, 0xFFFF, "Wil6200 802.11ad Wireless Network Adapter(0x0310)"},
}; /* pci_vid_1AE9[] */

static pci_id_t const pci_vid_1AEA[] = {
{0x1AEA, 0xFFFF, 0xFFFF, 0xFFFF, "Alcor Micro(0x1AEA)"},
{0x1AEA, 0x6601, 0xFFFF, 0xFFFF, "AU6601 PCI-E Flash card reader controller(0x6601)"},
{0x1AEA, 0x6621, 0xFFFF, 0xFFFF, "AU6621 PCI-E Flash card reader controller(0x6621)"},
{0x1AEA, 0x6625, 0xFFFF, 0xFFFF, "AU6625 PCI-E Flash card reader controller(0x6625)"},
}; /* pci_vid_1AEA[] */

static pci_id_t const pci_vid_1AEC[] = {
{0x1AEC, 0xFFFF, 0xFFFF, 0xFFFF, "Wolfson Microelectronics(0x1AEC)"},
}; /* pci_vid_1AEC[] */

static pci_id_t const pci_vid_1AED[] = {
{0x1AED, 0xFFFF, 0xFFFF, 0xFFFF, "SanDisk(0x1AED)"},
{0x1AED, 0x1003, 0xFFFF, 0xFFFF, "ioDimm3 (v1.2)(0x1003)"},
{0x1AED, 0x1005, 0xFFFF, 0xFFFF, "ioDimm3(0x1005)"},
{0x1AED, 0x1005, 0x1014, 0x03C3, "High IOPS SSD PCIe Adapter(0x1014-0x03C3)"},
{0x1AED, 0x1005, 0x103C, 0x176F, "1.28TB MLC PCIe ioDrive Duo(0x103C-0x176F)"},
{0x1AED, 0x1005, 0x103C, 0x1770, "5.2TB MLC PCIe ioDrive Octal(0x103C-0x1770)"},
{0x1AED, 0x1005, 0x103C, 0x178B, "160GB SLC PCIe ioDrive(0x103C-0x178B)"},
{0x1AED, 0x1005, 0x103C, 0x178C, "320GB MLC PCIe ioDrive(0x103C-0x178C)"},
{0x1AED, 0x1005, 0x103C, 0x178D, "320GB SLC PCIe ioDrive Duo(0x103C-0x178D)"},
{0x1AED, 0x1005, 0x103C, 0x178E, "640GB MLC PCIe ioDrive Duo(0x103C-0x178E)"},
{0x1AED, 0x1006, 0xFFFF, 0xFFFF, "ioXtreme(0x1006)"},
{0x1AED, 0x1007, 0xFFFF, 0xFFFF, "ioXtreme Pro(0x1007)"},
{0x1AED, 0x1008, 0xFFFF, 0xFFFF, "ioXtreme-2(0x1008)"},
{0x1AED, 0x2001, 0xFFFF, 0xFFFF, "ioDrive2(0x2001)"},
{0x1AED, 0x3001, 0xFFFF, 0xFFFF, "ioMemory FHHL(0x3001)"},
{0x1AED, 0x3002, 0xFFFF, 0xFFFF, "ioMemory HHHL(0x3002)"},
{0x1AED, 0x3003, 0xFFFF, 0xFFFF, "ioMemory Mezzanine(0x3003)"},
}; /* pci_vid_1AED[] */

static pci_id_t const pci_vid_1AEE[] = {
{0x1AEE, 0xFFFF, 0xFFFF, 0xFFFF, "Caustic Graphics Inc.(0x1AEE)"},
}; /* pci_vid_1AEE[] */

static pci_id_t const pci_vid_1AF4[] = {
{0x1AF4, 0xFFFF, 0xFFFF, 0xFFFF, "Red Hat, Inc.(0x1AF4)"},
{0x1AF4, 0x1000, 0xFFFF, 0xFFFF, "Virtio network device(0x1000)"},
{0x1AF4, 0x1000, 0x01DE, 0xFFFB, "Propolis Virtio network device(0x01DE-0xFFFB)"},
{0x1AF4, 0x1001, 0xFFFF, 0xFFFF, "Virtio block device(0x1001)"},
{0x1AF4, 0x1001, 0x01DE, 0xFFFA, "Propolis Virtio block device(0x01DE-0xFFFA)"},
{0x1AF4, 0x1002, 0xFFFF, 0xFFFF, "Virtio memory balloon(0x1002)"},
{0x1AF4, 0x1003, 0xFFFF, 0xFFFF, "Virtio console(0x1003)"},
{0x1AF4, 0x1004, 0xFFFF, 0xFFFF, "Virtio SCSI(0x1004)"},
{0x1AF4, 0x1005, 0xFFFF, 0xFFFF, "Virtio RNG(0x1005)"},
{0x1AF4, 0x1009, 0xFFFF, 0xFFFF, "Virtio filesystem(0x1009)"},
{0x1AF4, 0x1041, 0xFFFF, 0xFFFF, "Virtio 1.0 network device(0x1041)"},
{0x1AF4, 0x1042, 0xFFFF, 0xFFFF, "Virtio 1.0 block device(0x1042)"},
{0x1AF4, 0x1043, 0xFFFF, 0xFFFF, "Virtio 1.0 console(0x1043)"},
{0x1AF4, 0x1044, 0xFFFF, 0xFFFF, "Virtio 1.0 RNG(0x1044)"},
{0x1AF4, 0x1045, 0xFFFF, 0xFFFF, "Virtio 1.0 memory balloon(0x1045)"},
{0x1AF4, 0x1048, 0xFFFF, 0xFFFF, "Virtio 1.0 SCSI(0x1048)"},
{0x1AF4, 0x1049, 0xFFFF, 0xFFFF, "Virtio 1.0 filesystem(0x1049)"},
{0x1AF4, 0x1050, 0xFFFF, 0xFFFF, "Virtio 1.0 GPU(0x1050)"},
{0x1AF4, 0x1052, 0xFFFF, 0xFFFF, "Virtio 1.0 input(0x1052)"},
{0x1AF4, 0x1053, 0xFFFF, 0xFFFF, "Virtio 1.0 socket(0x1053)"},
{0x1AF4, 0x1058, 0xFFFF, 0xFFFF, "virtio-mem(0x1058)"},
{0x1AF4, 0x105A, 0xFFFF, 0xFFFF, "Virtio file system(0x105A)"},
{0x1AF4, 0x1110, 0xFFFF, 0xFFFF, "Inter-VM shared memory(0x1110)"},
{0x1AF4, 0x1110, 0x1AF4, 0x1100, "QEMU Virtual Machine(0x1AF4-0x1100)"},
}; /* pci_vid_1AF4[] */

static pci_id_t const pci_vid_1AF5[] = {
{0x1AF5, 0xFFFF, 0xFFFF, 0xFFFF, "Netezza Corp.(0x1AF5)"},
}; /* pci_vid_1AF5[] */

static pci_id_t const pci_vid_1AFA[] = {
{0x1AFA, 0xFFFF, 0xFFFF, 0xFFFF, "J & W Electronics Co., Ltd.(0x1AFA)"},
}; /* pci_vid_1AFA[] */

static pci_id_t const pci_vid_1B00[] = {
{0x1B00, 0xFFFF, 0xFFFF, 0xFFFF, "Montage Technology Co., Ltd.(0x1B00)"},
{0x1B00, 0xC001, 0xFFFF, 0xFFFF, "CXL Memory Expander Controller M88MX5891(0xC001)"},
{0x1B00, 0xC001, 0x1FF9, 0x00A2, "CXL Memory Expander(0x1FF9-0x00A2)"},
{0x1B00, 0xC001, 0x1FF9, 0x00A4, "CXL Memory Expander(0x1FF9-0x00A4)"},
}; /* pci_vid_1B00[] */

static pci_id_t const pci_vid_1B03[] = {
{0x1B03, 0xFFFF, 0xFFFF, 0xFFFF, "Magnum Semiconductor, Inc,(0x1B03)"},
{0x1B03, 0x6100, 0xFFFF, 0xFFFF, "DXT/DXTPro Multiformat Broadcast HD/SD Encoder/Decoder/Transcoder(0x6100)"},
{0x1B03, 0x7000, 0xFFFF, 0xFFFF, "D7 Multiformat Broadcast HD/SD Encoder/Decoder/Transcoder(0x7000)"},
}; /* pci_vid_1B03[] */

static pci_id_t const pci_vid_1B08[] = {
{0x1B08, 0xFFFF, 0xFFFF, 0xFFFF, "MSC Technologies GmbH(0x1B08)"},
}; /* pci_vid_1B08[] */

static pci_id_t const pci_vid_1B0A[] = {
{0x1B0A, 0xFFFF, 0xFFFF, 0xFFFF, "Pegatron(0x1B0A)"},
{0x1B0A, 0x9602, 0xFFFF, 0xFFFF, "RS780/RS880 PCI to PCI bridge (int gfx)(0x9602)"},
}; /* pci_vid_1B0A[] */

static pci_id_t const pci_vid_1B13[] = {
{0x1B13, 0xFFFF, 0xFFFF, 0xFFFF, "Jaton Corp(0x1B13)"},
}; /* pci_vid_1B13[] */

static pci_id_t const pci_vid_1B1A[] = {
{0x1B1A, 0xFFFF, 0xFFFF, 0xFFFF, "K&F Computing Research Co.(0x1B1A)"},
{0x1B1A, 0x0E70, 0xFFFF, 0xFFFF, "GRAPE(0x0E70)"},
}; /* pci_vid_1B1A[] */

static pci_id_t const pci_vid_1B1C[] = {
{0x1B1C, 0xFFFF, 0xFFFF, 0xFFFF, "Corsair(0x1B1C)"},
}; /* pci_vid_1B1C[] */

static pci_id_t const pci_vid_1B21[] = {
{0x1B21, 0xFFFF, 0xFFFF, 0xFFFF, "ASMedia Technology Inc.(0x1B21)"},
{0x1B21, 0x0611, 0xFFFF, 0xFFFF, "ASM1061 Serial ATA Controller(0x0611)"},
{0x1B21, 0x0612, 0xFFFF, 0xFFFF, "ASM1061/ASM1062 Serial ATA Controller(0x0612)"},
{0x1B21, 0x0612, 0x1849, 0x0612, "Motherboard(0x1849-0x0612)"},
{0x1B21, 0x0622, 0xFFFF, 0xFFFF, "ASM106x Serial ATA AHCI Controller(0x0622)"},
{0x1B21, 0x0622, 0x4C52, 0x9661, "LRST9661 2-port M.2 SATA3(6Gb/s) Raid Adapter(0x4C52-0x9661)"},
{0x1B21, 0x0624, 0xFFFF, 0xFFFF, "ASM106x SATA/RAID Controller(0x0624)"},
{0x1B21, 0x0625, 0xFFFF, 0xFFFF, "106x SATA/RAID Controller(0x0625)"},
{0x1B21, 0x1040, 0xFFFF, 0xFFFF, "ASM1040 SuperSpeed USB Host Controller(0x1040)"},
{0x1B21, 0x1041, 0xFFFF, 0xFFFF, "ASM1041 SuperSpeed USB Host Controller(0x1041)"},
{0x1B21, 0x1042, 0xFFFF, 0xFFFF, "ASM1042 SuperSpeed USB Host Controller(0x1042)"},
{0x1B21, 0x1042, 0x1043, 0x1059, "K53SM motherboard(0x1043-0x1059)"},
{0x1B21, 0x1042, 0x1043, 0x8488, "P8B WS Motherboard(0x1043-0x8488)"},
{0x1B21, 0x1042, 0x1849, 0x1042, "Motherboard(0x1849-0x1042)"},
{0x1B21, 0x1064, 0xFFFF, 0xFFFF, "ASM1064 Serial ATA Controller(0x1064)"},
{0x1B21, 0x1080, 0xFFFF, 0xFFFF, "ASM1083/1085 PCIe to PCI Bridge(0x1080)"},
{0x1B21, 0x1080, 0x1849, 0x1080, "Motherboard(0x1849-0x1080)"},
{0x1B21, 0x1142, 0xFFFF, 0xFFFF, "ASM1042A USB 3.0 Host Controller(0x1142)"},
{0x1B21, 0x1164, 0xFFFF, 0xFFFF, "ASM1164 Serial ATA AHCI Controller(0x1164)"},
{0x1B21, 0x1166, 0xFFFF, 0xFFFF, "ASM1166 Serial ATA Controller(0x1166)"},
{0x1B21, 0x1182, 0xFFFF, 0xFFFF, "ASM1182e 2-Port PCIe x1 Gen2 Packet Switch(0x1182)"},
{0x1B21, 0x1182, 0x1B21, 0x118F, "ASM1182e 2-Port PCIe x1 Gen2 Packet Switch(0x1B21-0x118F)"},
{0x1B21, 0x1184, 0xFFFF, 0xFFFF, "ASM1184e 4-Port PCIe x1 Gen2 Packet Switch(0x1184)"},
{0x1B21, 0x1184, 0x1849, 0x1184, "ASM1184e 4-Port PCIe x1 Gen2 Packet Switch(0x1849-0x1184)"},
{0x1B21, 0x1187, 0xFFFF, 0xFFFF, "ASM1187e 7-Port PCIe x1 Gen2 Packet Switch(0x1187)"},
{0x1B21, 0x118F, 0xFFFF, 0xFFFF, "ASM1187e 7-Port PCIe x1 Gen2 Packet Switch(0x118F)"},
{0x1B21, 0x1242, 0xFFFF, 0xFFFF, "ASM1142 USB 3.1 Host Controller(0x1242)"},
{0x1B21, 0x1242, 0x4C52, 0x9A42, "LRSU9A42 2-Port Type-A Exchange Adapter(0x4C52-0x9A42)"},
{0x1B21, 0x1343, 0xFFFF, 0xFFFF, "ASM1143 USB 3.1 Host Controller(0x1343)"},
{0x1B21, 0x1806, 0xFFFF, 0xFFFF, "ASM1806 4-Port PCIe x2 Gen2 Packet Switch(0x1806)"},
{0x1B21, 0x1812, 0xFFFF, 0xFFFF, "ASM1812 6-Port PCIe x4 Gen2 Packet Switch(0x1812)"},
{0x1B21, 0x1824, 0xFFFF, 0xFFFF, "ASM1824 12-Port PCIe x8 Gen2 Packet Switch(0x1824)"},
{0x1B21, 0x2142, 0xFFFF, 0xFFFF, "ASM2142/ASM3142 USB 3.1 Host Controller(0x2142)"},
{0x1B21, 0x2142, 0x1462, 0x7A72, "H270 PC MATE(0x1462-0x7A72)"},
{0x1B21, 0x2806, 0xFFFF, 0xFFFF, "ASM2806 4-Port PCIe x2 Gen3 Packet Switch(0x2806)"},
{0x1B21, 0x2812, 0xFFFF, 0xFFFF, "ASM2812 6-Port PCIe x4 Gen3 Packet Switch(0x2812)"},
{0x1B21, 0x2824, 0xFFFF, 0xFFFF, "ASM2824 PCIe Gen3 Packet Switch(0x2824)"},
{0x1B21, 0x3042, 0xFFFF, 0xFFFF, "ASM3042 USB 3.2 Gen 1 xHCI Controller(0x3042)"},
{0x1B21, 0x3142, 0xFFFF, 0xFFFF, "ASM3142 USB 3.2 Gen 2x1 xHCI Controller(0x3142)"},
{0x1B21, 0x3241, 0xFFFF, 0xFFFF, "ASM3241 USB 3.2 Gen 2 Host Controller(0x3241)"},
{0x1B21, 0x3242, 0xFFFF, 0xFFFF, "ASM3242 USB 3.2 Host Controller(0x3242)"},
}; /* pci_vid_1B21[] */

static pci_id_t const pci_vid_1B26[] = {
{0x1B26, 0xFFFF, 0xFFFF, 0xFFFF, "Netcope Technologies, a.s.(0x1B26)"},
{0x1B26, 0xC132, 0xFFFF, 0xFFFF, "COMBO-LXT155(0xC132)"},
{0x1B26, 0xC1C0, 0xFFFF, 0xFFFF, "NFB-100G1-e0(0xC1C0)"},
{0x1B26, 0xC1C1, 0xFFFF, 0xFFFF, "NFB-100G1-e1(0xC1C1)"},
{0x1B26, 0xC250, 0xFFFF, 0xFFFF, "NFB-200G2-master(0xC250)"},
{0x1B26, 0xC251, 0xFFFF, 0xFFFF, "NFB-200G2-slave(0xC251)"},
{0x1B26, 0xC2C0, 0xFFFF, 0xFFFF, "NFB-100G2-e0(0xC2C0)"},
{0x1B26, 0xC2C1, 0xFFFF, 0xFFFF, "NFB-100G2-e1(0xC2C1)"},
{0x1B26, 0xCB20, 0xFFFF, 0xFFFF, "COMBO-20G(0xCB20)"},
{0x1B26, 0xCB40, 0xFFFF, 0xFFFF, "COMBO-40G(0xCB40)"},
{0x1B26, 0xCB80, 0xFFFF, 0xFFFF, "NFB-40G2(0xCB80)"},
}; /* pci_vid_1B26[] */

static pci_id_t const pci_vid_1B2C[] = {
{0x1B2C, 0xFFFF, 0xFFFF, 0xFFFF, "Opal-RT Technologies Inc.(0x1B2C)"},
}; /* pci_vid_1B2C[] */

static pci_id_t const pci_vid_1B36[] = {
{0x1B36, 0xFFFF, 0xFFFF, 0xFFFF, "Red Hat, Inc.(0x1B36)"},
{0x1B36, 0x0001, 0xFFFF, 0xFFFF, "QEMU PCI-PCI bridge(0x0001)"},
{0x1B36, 0x0002, 0xFFFF, 0xFFFF, "QEMU PCI 16550A Adapter(0x0002)"},
{0x1B36, 0x0002, 0x1AF4, 0x1100, "QEMU Virtual Machine(0x1AF4-0x1100)"},
{0x1B36, 0x0003, 0xFFFF, 0xFFFF, "QEMU PCI Dual-port 16550A Adapter(0x0003)"},
{0x1B36, 0x0003, 0x1AF4, 0x1100, "QEMU Virtual Machine(0x1AF4-0x1100)"},
{0x1B36, 0x0004, 0xFFFF, 0xFFFF, "QEMU PCI Quad-port 16550A Adapter(0x0004)"},
{0x1B36, 0x0004, 0x1AF4, 0x1100, "QEMU Virtual Machine(0x1AF4-0x1100)"},
{0x1B36, 0x0005, 0xFFFF, 0xFFFF, "QEMU PCI Test Device(0x0005)"},
{0x1B36, 0x0005, 0x1AF4, 0x1100, "QEMU Virtual Machine(0x1AF4-0x1100)"},
{0x1B36, 0x0006, 0xFFFF, 0xFFFF, "PCI Rocker Ethernet switch device(0x0006)"},
{0x1B36, 0x0007, 0xFFFF, 0xFFFF, "PCI SD Card Host Controller Interface(0x0007)"},
{0x1B36, 0x0008, 0xFFFF, 0xFFFF, "QEMU PCIe Host bridge(0x0008)"},
{0x1B36, 0x0009, 0xFFFF, 0xFFFF, "QEMU PCI Expander bridge(0x0009)"},
{0x1B36, 0x000A, 0xFFFF, 0xFFFF, "PCI-PCI bridge (multiseat)(0x000A)"},
{0x1B36, 0x000B, 0xFFFF, 0xFFFF, "QEMU PCIe Expander bridge(0x000B)"},
{0x1B36, 0x000C, 0xFFFF, 0xFFFF, "QEMU PCIe Root port(0x000C)"},
{0x1B36, 0x000D, 0xFFFF, 0xFFFF, "QEMU XHCI Host Controller(0x000D)"},
{0x1B36, 0x0010, 0xFFFF, 0xFFFF, "QEMU NVM Express Controller(0x0010)"},
{0x1B36, 0x0011, 0xFFFF, 0xFFFF, "QEMU PVPanic device(0x0011)"},
{0x1B36, 0x0013, 0xFFFF, 0xFFFF, "QEMU UFS Host Controller(0x0013)"},
{0x1B36, 0x0100, 0xFFFF, 0xFFFF, "QXL paravirtual graphic card(0x0100)"},
{0x1B36, 0x0100, 0x1AF4, 0x1100, "QEMU Virtual Machine(0x1AF4-0x1100)"},
}; /* pci_vid_1B36[] */

static pci_id_t const pci_vid_1B37[] = {
{0x1B37, 0xFFFF, 0xFFFF, 0xFFFF, "Signal Processing Devices Sweden AB(0x1B37)"},
{0x1B37, 0x0001, 0xFFFF, 0xFFFF, "ADQ214(0x0001)"},
{0x1B37, 0x0003, 0xFFFF, 0xFFFF, "ADQ114(0x0003)"},
{0x1B37, 0x0005, 0xFFFF, 0xFFFF, "ADQ112(0x0005)"},
{0x1B37, 0x000E, 0xFFFF, 0xFFFF, "ADQ108(0x000E)"},
{0x1B37, 0x000F, 0xFFFF, 0xFFFF, "ADQDSP(0x000F)"},
{0x1B37, 0x0014, 0xFFFF, 0xFFFF, "ADQ412(0x0014)"},
{0x1B37, 0x0015, 0xFFFF, 0xFFFF, "ADQ212(0x0015)"},
{0x1B37, 0x001B, 0xFFFF, 0xFFFF, "SDR14(0x001B)"},
{0x1B37, 0x001C, 0xFFFF, 0xFFFF, "ADQ1600(0x001C)"},
{0x1B37, 0x001E, 0xFFFF, 0xFFFF, "ADQ208(0x001E)"},
{0x1B37, 0x001F, 0xFFFF, 0xFFFF, "DSU(0x001F)"},
{0x1B37, 0x0020, 0xFFFF, 0xFFFF, "ADQ14(0x0020)"},
{0x1B37, 0x0023, 0xFFFF, 0xFFFF, "ADQ7(0x0023)"},
{0x1B37, 0x0026, 0xFFFF, 0xFFFF, "ADQ8(0x0026)"},
{0x1B37, 0x0031, 0xFFFF, 0xFFFF, "ADQ3(0x0031)"},
{0x1B37, 0x2014, 0xFFFF, 0xFFFF, "TX320(0x2014)"},
{0x1B37, 0x2019, 0xFFFF, 0xFFFF, "S6000(0x2019)"},
}; /* pci_vid_1B37[] */

static pci_id_t const pci_vid_1B39[] = {
{0x1B39, 0xFFFF, 0xFFFF, 0xFFFF, "sTec, Inc.(0x1B39)"},
{0x1B39, 0x0001, 0xFFFF, 0xFFFF, "S1120 PCIe Accelerator SSD(0x0001)"},
}; /* pci_vid_1B39[] */

static pci_id_t const pci_vid_1B3A[] = {
{0x1B3A, 0xFFFF, 0xFFFF, 0xFFFF, "Westar Display Technologies(0x1B3A)"},
{0x1B3A, 0x7589, 0xFFFF, 0xFFFF, "HRED J2000 - JPEG 2000 Video Codec Device(0x7589)"},
}; /* pci_vid_1B3A[] */

static pci_id_t const pci_vid_1B3E[] = {
{0x1B3E, 0xFFFF, 0xFFFF, 0xFFFF, "Teradata Corp.(0x1B3E)"},
{0x1B3E, 0x1FA8, 0xFFFF, 0xFFFF, "BYNET BIC2SE/X(0x1FA8)"},
{0x1B3E, 0x1FA8, 0x1B3E, 0x00A3, "BYNET BIC2SX(0x1B3E-0x00A3)"},
{0x1B3E, 0x1FA8, 0x1B3E, 0x00C3, "BYNET BIC2SE(0x1B3E-0x00C3)"},
}; /* pci_vid_1B3E[] */

static pci_id_t const pci_vid_1B40[] = {
{0x1B40, 0xFFFF, 0xFFFF, 0xFFFF, "Schooner Information Technology, Inc.(0x1B40)"},
}; /* pci_vid_1B40[] */

static pci_id_t const pci_vid_1B47[] = {
{0x1B47, 0xFFFF, 0xFFFF, 0xFFFF, "Numascale AS(0x1B47)"},
{0x1B47, 0x0601, 0xFFFF, 0xFFFF, "NumaChip N601(0x0601)"},
{0x1B47, 0x0602, 0xFFFF, 0xFFFF, "NumaChip N602(0x0602)"},
}; /* pci_vid_1B47[] */

static pci_id_t const pci_vid_1B4B[] = {
{0x1B4B, 0xFFFF, 0xFFFF, 0xFFFF, "Marvell Technology Group Ltd.(0x1B4B)"},
{0x1B4B, 0x0100, 0xFFFF, 0xFFFF, "88F3700 [Armada 3700 Family] ARM SoC(0x0100)"},
{0x1B4B, 0x0640, 0xFFFF, 0xFFFF, "88SE9128 SATA III 6Gb/s RAID Controller(0x0640)"},
{0x1B4B, 0x2241, 0xFFFF, 0xFFFF, "88NR2241 Non-Volatile memory controller(0x2241)"},
{0x1B4B, 0x2241, 0x1028, 0x2112, "BOSS-N1 Monolithic(0x1028-0x2112)"},
{0x1B4B, 0x2241, 0x1028, 0x2113, "BOSS-N1 Modular(0x1028-0x2113)"},
{0x1B4B, 0x2241, 0x1028, 0x2151, "BOSS-N1 Modular ET(0x1028-0x2151)"},
{0x1B4B, 0x2241, 0x1028, 0x2196, "ROR-N1(0x1028-0x2196)"},
{0x1B4B, 0x2241, 0x1028, 0x2286, "BOSS-N1 DC-MHS(0x1028-0x2286)"},
{0x1B4B, 0x2241, 0x1028, 0x2287, "BOSS-N1 Modular(0x1028-0x2287)"},
{0x1B4B, 0x2241, 0x1B4B, 0x2241, "Santa Cruz NVMe Host Adapter(0x1B4B-0x2241)"},
{0x1B4B, 0x2241, 0x1B96, 0x4000, "WD_BLACK AN1500 NVMe SSD(0x1B96-0x4000)"},
{0x1B4B, 0x2241, 0x1D49, 0x0306, "ThinkSystem M.2 NVMe 2-Bay RAID Enablement Kit(0x1D49-0x0306)"},
{0x1B4B, 0x2241, 0x1D49, 0x0307, "ThinkSystem 7mm NVMe 2-Bay Rear RAID Enablement Kit(0x1D49-0x0307)"},
{0x1B4B, 0x2241, 0x4C52, 0x9541, "LRNV9541 2-port M.2 NVMe Raid Adapter(0x4C52-0x9541)"},
{0x1B4B, 0x2B42, 0xFFFF, 0xFFFF, "88W8997 2.4/5 GHz Dual-Band 2x2 Wi-Fi® 5 (802.11ac) + Bluetooth® 5.3 Solution(0x2B42)"},
{0x1B4B, 0x2B43, 0xFFFF, 0xFFFF, "NXP 88W9098 Wi-Fi 6 (ax) MAC #1(0x2B43)"},
{0x1B4B, 0x2B44, 0xFFFF, 0xFFFF, "NXP 88W9098 Wi-Fi 6 (ax) MAC #2(0x2B44)"},
{0x1B4B, 0x2B45, 0xFFFF, 0xFFFF, "NXP 88W9098 Bluetooth 5.3(0x2B45)"},
{0x1B4B, 0x9120, 0xFFFF, 0xFFFF, "88SE9120 SATA 6Gb/s Controller(0x9120)"},
{0x1B4B, 0x9123, 0xFFFF, 0xFFFF, "88SE9123 PCIe SATA 6.0 Gb/s controller(0x9123)"},
{0x1B4B, 0x9123, 0xDC93, 0x600E, "DC-6xxe series SATA 6G controller(0xDC93-0x600E)"},
{0x1B4B, 0x9125, 0xFFFF, 0xFFFF, "88SE9125 PCIe SATA 6.0 Gb/s controller(0x9125)"},
{0x1B4B, 0x9125, 0x4C52, 0x9615, "LRST9615 4-port SATA3(6Gb/s) Exchange Adapter(0x4C52-0x9615)"},
{0x1B4B, 0x9128, 0xFFFF, 0xFFFF, "88SE9128 PCIe SATA 6 Gb/s RAID controller(0x9128)"},
{0x1B4B, 0x9130, 0xFFFF, 0xFFFF, "88SE9128 PCIe SATA 6 Gb/s RAID controller with HyperDuo(0x9130)"},
{0x1B4B, 0x9130, 0x1043, 0x8438, "P8P67 Deluxe Motherboard(0x1043-0x8438)"},
{0x1B4B, 0x9170, 0xFFFF, 0xFFFF, "88SE9170 PCIe 2.0 x1 2-port SATA 6 Gb/s Controller(0x9170)"},
{0x1B4B, 0x9172, 0xFFFF, 0xFFFF, "88SE9172 SATA 6Gb/s Controller(0x9172)"},
{0x1B4B, 0x9178, 0xFFFF, 0xFFFF, "88SE9170 PCIe SATA 6Gb/s Controller(0x9178)"},
{0x1B4B, 0x917A, 0xFFFF, 0xFFFF, "88SE9172 SATA III 6Gb/s RAID Controller(0x917A)"},
{0x1B4B, 0x9182, 0xFFFF, 0xFFFF, "88SE9182 PCIe 2.0 x2 2-port SATA 6 Gb/s Controller(0x9182)"},
{0x1B4B, 0x9183, 0xFFFF, 0xFFFF, "88SS9183 PCIe SSD Controller(0x9183)"},
{0x1B4B, 0x9192, 0xFFFF, 0xFFFF, "88SE9172 SATA III 6Gb/s RAID Controller(0x9192)"},
{0x1B4B, 0x91A0, 0xFFFF, 0xFFFF, "88SE912x SATA 6Gb/s Controller [IDE mode](0x91A0)"},
{0x1B4B, 0x91A4, 0xFFFF, 0xFFFF, "88SE912x IDE Controller(0x91A4)"},
{0x1B4B, 0x9215, 0xFFFF, 0xFFFF, "88SE9215 PCIe 2.0 x1 4-port SATA 6 Gb/s Controller(0x9215)"},
{0x1B4B, 0x9220, 0xFFFF, 0xFFFF, "88SE9220 PCIe 2.0 x2 2-port SATA 6 Gb/s RAID Controller(0x9220)"},
{0x1B4B, 0x9230, 0xFFFF, 0xFFFF, "88SE9230 PCIe 2.0 x2 4-port SATA 6 Gb/s RAID Controller(0x9230)"},
{0x1B4B, 0x9230, 0x1028, 0x1FD6, "BOSS-S1 Adapter(0x1028-0x1FD6)"},
{0x1B4B, 0x9230, 0x1028, 0x1FDF, "BOSS-S1 Modular(0x1028-0x1FDF)"},
{0x1B4B, 0x9230, 0x1028, 0x1FE2, "BOSS-S1 Adapter(0x1028-0x1FE2)"},
{0x1B4B, 0x9230, 0x1028, 0x2010, "BOSS-S2 Adapter(0x1028-0x2010)"},
{0x1B4B, 0x9230, 0x1028, 0x2260, "BOSS-S1 Modular(0x1028-0x2260)"},
{0x1B4B, 0x9230, 0x1028, 0x2261, "BOSS-S2 Adapter(0x1028-0x2261)"},
{0x1B4B, 0x9230, 0x1BD4, 0x0073, "RS0200L6R2iM2(0x1BD4-0x0073)"},
{0x1B4B, 0x9230, 0x1D49, 0x0300, "ThinkSystem M.2 with Mirroring Enablement Kit(0x1D49-0x0300)"},
{0x1B4B, 0x9230, 0x1D49, 0x0301, "ThinkSystem SR630 x16 PCIE with 4 SATA ports Riser(0x1D49-0x0301)"},
{0x1B4B, 0x9230, 0x1D49, 0x0302, "ThinkSystem SE350 M.2 SATA 4-Bay Data RAID Mirroring Enablement Kit(0x1D49-0x0302)"},
{0x1B4B, 0x9230, 0x1D49, 0x0303, "ThinkSystem SE350 M.2 SATA 4-Bay Data RAID Mirroring Enablement Kit(0x1D49-0x0303)"},
{0x1B4B, 0x9230, 0x1D49, 0x0304, "ThinkSystem M.2 SATA 2-Bay RAID Enablement Kit(0x1D49-0x0304)"},
{0x1B4B, 0x9230, 0x1D49, 0x0305, "ThinkSystem 7mm SATA 2-Bay Rear RAID Enablement Kit(0x1D49-0x0305)"},
{0x1B4B, 0x9230, 0x4C52, 0x9630, "LRST9630 4-port SATA3(6Gb/s) Raid Adapter(0x4C52-0x9630)"},
{0x1B4B, 0x9235, 0xFFFF, 0xFFFF, "88SE9235 PCIe 2.0 x2 4-port SATA 6 Gb/s Controller(0x9235)"},
{0x1B4B, 0x9445, 0xFFFF, 0xFFFF, "88SE9445 PCIe 2.0 x4 4-Port SAS/SATA 6 Gbps RAID Controller(0x9445)"},
{0x1B4B, 0x9480, 0xFFFF, 0xFFFF, "88SE9480 SAS/SATA 6Gb/s RAID controller(0x9480)"},
{0x1B4B, 0x9485, 0xFFFF, 0xFFFF, "88SE9485 SAS/SATA 6Gb/s controller(0x9485)"},
}; /* pci_vid_1B4B[] */

static pci_id_t const pci_vid_1B4C[] = {
{0x1B4C, 0xFFFF, 0xFFFF, 0xFFFF, "GALAX(0x1B4C)"},
}; /* pci_vid_1B4C[] */

static pci_id_t const pci_vid_1B55[] = {
{0x1B55, 0xFFFF, 0xFFFF, 0xFFFF, "NetUP Inc.(0x1B55)"},
{0x1B55, 0x18F6, 0xFFFF, 0xFFFF, "Dual DVB Universal CI card(0x18F6)"},
{0x1B55, 0x18F7, 0xFFFF, 0xFFFF, "Dual DVB Universal CI card rev 1.4(0x18F7)"},
{0x1B55, 0x2A2C, 0xFFFF, 0xFFFF, "Dual DVB-S2-CI card(0x2A2C)"},
{0x1B55, 0xE2E4, 0xFFFF, 0xFFFF, "Dual DVB-T/C-CI RF card(0xE2E4)"},
{0x1B55, 0xE5F4, 0xFFFF, 0xFFFF, "MPEG2 and H264 Encoder-Transcoder(0xE5F4)"},
{0x1B55, 0xF1C4, 0xFFFF, 0xFFFF, "Dual ASI-RX/TX-CI card(0xF1C4)"},
}; /* pci_vid_1B55[] */

static pci_id_t const pci_vid_1B5E[] = {
{0x1B5E, 0xFFFF, 0xFFFF, 0xFFFF, "STAR-Dundee Ltd.(0x1B5E)"},
{0x1B5E, 0x0001, 0xFFFF, 0xFFFF, "SpaceWire PCI Mk2(0x0001)"},
{0x1B5E, 0x0002, 0xFFFF, 0xFFFF, "SpaceWire PCIe Mk1(0x0002)"},
{0x1B5E, 0x0003, 0xFFFF, 0xFFFF, "SpaceWire cPCI Mk2(0x0003)"},
{0x1B5E, 0x0004, 0xFFFF, 0xFFFF, "SpaceWire PXI Recorder Mk1(0x0004)"},
{0x1B5E, 0x0005, 0xFFFF, 0xFFFF, "SpaceWire PXI Interface Mk1(0x0005)"},
{0x1B5E, 0x0006, 0xFFFF, 0xFFFF, "SpaceWire PXI Interface Mk1 with RMAP Target(0x0006)"},
{0x1B5E, 0x0008, 0xFFFF, 0xFFFF, "SpaceWire PXI Router Mk1(0x0008)"},
{0x1B5E, 0x000B, 0xFFFF, 0xFFFF, "SpaceWire PXI Interface Mk2(0x000B)"},
{0x1B5E, 0x000C, 0xFFFF, 0xFFFF, "SpaceWire PXI Interface Mk2 with RMAP Target(0x000C)"},
{0x1B5E, 0x000D, 0xFFFF, 0xFFFF, "SpaceWire PXI Router Mk2(0x000D)"},
{0x1B5E, 0x000E, 0xFFFF, 0xFFFF, "SpaceWire PXI Recorder Mk2(0x000E)"},
{0x1B5E, 0x0100, 0xFFFF, 0xFFFF, "STAR-Ultra PCIe(0x0100)"},
{0x1B5E, 0x0102, 0xFFFF, 0xFFFF, "STAR-Ultra Single-Lane Router(0x0102)"},
{0x1B5E, 0x0200, 0xFFFF, 0xFFFF, "SpaceWire PCIe Mk2(0x0200)"},
}; /* pci_vid_1B5E[] */

static pci_id_t const pci_vid_1B61[] = {
{0x1B61, 0xFFFF, 0xFFFF, 0xFFFF, "Byd Precision Manufacture Co.,Ltd(0x1B61)"},
}; /* pci_vid_1B61[] */

static pci_id_t const pci_vid_1B66[] = {
{0x1B66, 0xFFFF, 0xFFFF, 0xFFFF, "DELTACAST(0x1B66)"},
{0x1B66, 0x0007, 0xFFFF, 0xFFFF, "DELTA-3G-elp-d(0x0007)"},
}; /* pci_vid_1B66[] */

static pci_id_t const pci_vid_1B6F[] = {
{0x1B6F, 0xFFFF, 0xFFFF, 0xFFFF, "Etron Technology, Inc.(0x1B6F)"},
{0x1B6F, 0x7023, 0xFFFF, 0xFFFF, "EJ168 USB 3.0 Host Controller(0x7023)"},
{0x1B6F, 0x7023, 0x1458, 0x5007, "GA-880GMA-USB3(0x1458-0x5007)"},
{0x1B6F, 0x7052, 0xFFFF, 0xFFFF, "EJ188/EJ198 USB 3.0 Host Controller(0x7052)"},
{0x1B6F, 0x7052, 0x1849, 0x7052, "QC5000-ITX/PH(0x1849-0x7052)"},
}; /* pci_vid_1B6F[] */

static pci_id_t const pci_vid_1B73[] = {
{0x1B73, 0xFFFF, 0xFFFF, 0xFFFF, "Fresco Logic(0x1B73)"},
{0x1B73, 0x1000, 0xFFFF, 0xFFFF, "FL1000G USB 3.0 Host Controller(0x1000)"},
{0x1B73, 0x1000, 0x1D5C, 0x1000, "Anker USB 3.0 Express Card(0x1D5C-0x1000)"},
{0x1B73, 0x1009, 0xFFFF, 0xFFFF, "FL1009 USB 3.0 Host Controller(0x1009)"},
{0x1B73, 0x1100, 0xFFFF, 0xFFFF, "FL1100 USB 3.0 Host Controller(0x1100)"},
{0x1B73, 0x1100, 0x16B8, 0x6E31, "Allegro Pro USB 3.0 PCIe(0x16B8-0x6E31)"},
}; /* pci_vid_1B73[] */

static pci_id_t const pci_vid_1B74[] = {
{0x1B74, 0xFFFF, 0xFFFF, 0xFFFF, "OpenVox Communication Co. Ltd.(0x1B74)"},
{0x1B74, 0x0115, 0xFFFF, 0xFFFF, "D115P/D115E Single-port E1/T1 card(0x0115)"},
{0x1B74, 0xD130, 0xFFFF, 0xFFFF, "D130P/D130E Single-port E1/T1 card (3rd GEN)(0xD130)"},
{0x1B74, 0xD210, 0xFFFF, 0xFFFF, "D210P/D210E Dual-port E1/T1 card(2nd generation)(0xD210)"},
{0x1B74, 0xD230, 0xFFFF, 0xFFFF, "D230 Dual-port E1/T1 card (2nd generation)(0xD230)"},
{0x1B74, 0xD410, 0xFFFF, 0xFFFF, "D410/430 Quad-port E1/T1 card(0xD410)"},
{0x1B74, 0xD430, 0xFFFF, 0xFFFF, "D410/430 Quad-port E1/T1 card(0xD430)"},
}; /* pci_vid_1B74[] */

static pci_id_t const pci_vid_1B79[] = {
{0x1B79, 0xFFFF, 0xFFFF, 0xFFFF, "Absolute Analysis(0x1B79)"},
}; /* pci_vid_1B79[] */

static pci_id_t const pci_vid_1B85[] = {
{0x1B85, 0xFFFF, 0xFFFF, 0xFFFF, "OCZ Technology Group, Inc.(0x1B85)"},
{0x1B85, 0x1021, 0xFFFF, 0xFFFF, "RevoDrive 3 X2 PCIe SSD 240 GB (Marvell SAS Controller)(0x1021)"},
{0x1B85, 0x1041, 0xFFFF, 0xFFFF, "RevoDrive 3 X2 PCIe SSD 240 GB (Marvell SAS Controller)(0x1041)"},
{0x1B85, 0x4018, 0xFFFF, 0xFFFF, "Z Drive 6000/6300 NVME SSD(0x4018)"},
{0x1B85, 0x6018, 0xFFFF, 0xFFFF, "RD400/400A SSD(0x6018)"},
{0x1B85, 0x8788, 0xFFFF, 0xFFFF, "RevoDrive Hybrid(0x8788)"},
}; /* pci_vid_1B85[] */

static pci_id_t const pci_vid_1B94[] = {
{0x1B94, 0xFFFF, 0xFFFF, 0xFFFF, "Signatec / Dynamic Signals Corp(0x1B94)"},
{0x1B94, 0xE400, 0xFFFF, 0xFFFF, "PX14400 Dual Xilinx Virtex5 based Digitizer(0xE400)"},
}; /* pci_vid_1B94[] */

static pci_id_t const pci_vid_1B96[] = {
{0x1B96, 0xFFFF, 0xFFFF, 0xFFFF, "Western Digital(0x1B96)"},
{0x1B96, 0x2200, 0xFFFF, 0xFFFF, "Ultrastar DC SN630 NVMe SSD(0x2200)"},
{0x1B96, 0x2201, 0xFFFF, 0xFFFF, "Ultrastar DC SN630 NVMe SSD(0x2201)"},
{0x1B96, 0x2300, 0xFFFF, 0xFFFF, "Ultrastar DC SN840 NVMe SSD(0x2300)"},
{0x1B96, 0x2400, 0xFFFF, 0xFFFF, "Ultrastar DC SN640 NVMe SSD(0x2400)"},
{0x1B96, 0x2401, 0xFFFF, 0xFFFF, "Ultrastar DC SN640 NVMe SSD(0x2401)"},
{0x1B96, 0x2402, 0xFFFF, 0xFFFF, "Ultrastar DC SN640 NVMe SSD(0x2402)"},
{0x1B96, 0x2404, 0xFFFF, 0xFFFF, "Ultrastar DC SN640 NVMe SSD(0x2404)"},
{0x1B96, 0x2500, 0xFFFF, 0xFFFF, "Ultrastar DC SN840 NVMe SSD(0x2500)"},
{0x1B96, 0x2600, 0xFFFF, 0xFFFF, "Ultrastar DC ZN540 ZNS NVMe SSD(0x2600)"},
{0x1B96, 0x2700, 0xFFFF, 0xFFFF, "Ultrastar DC SN650 NVMe SSD(0x2700)"},
{0x1B96, 0x2701, 0xFFFF, 0xFFFF, "Ultrastar DC SN650 NVMe SSD(0x2701)"},
{0x1B96, 0x2702, 0xFFFF, 0xFFFF, "Ultrastar DC SN650 NVMe SSD(0x2702)"},
{0x1B96, 0x2720, 0xFFFF, 0xFFFF, "Ultrastar DC SN650 NVMe SSD(0x2720)"},
{0x1B96, 0x2721, 0xFFFF, 0xFFFF, "Ultrastar DC SN650 NVMe SSD(0x2721)"},
{0x1B96, 0x2722, 0xFFFF, 0xFFFF, "Ultrastar DC SN655 NVMe SSD(0x2722)"},
{0x1B96, 0x3001, 0xFFFF, 0xFFFF, "RapidFlex C2000 NVMe Initiator(0x3001)"},
{0x1B96, 0x3714, 0xFFFF, 0xFFFF, "PC SN730 NVMe SSD(0x3714)"},
{0x1B96, 0x3734, 0xFFFF, 0xFFFF, "PC SN730 NVMe SSD(0x3734)"},
}; /* pci_vid_1B96[] */

static pci_id_t const pci_vid_1B9A[] = {
{0x1B9A, 0xFFFF, 0xFFFF, 0xFFFF, "XAVi Technologies Corp.(0x1B9A)"},
}; /* pci_vid_1B9A[] */

static pci_id_t const pci_vid_1BAA[] = {
{0x1BAA, 0xFFFF, 0xFFFF, 0xFFFF, "QNAP Systems, Inc.(0x1BAA)"},
}; /* pci_vid_1BAA[] */

static pci_id_t const pci_vid_1BAD[] = {
{0x1BAD, 0xFFFF, 0xFFFF, 0xFFFF, "ReFLEX CES(0x1BAD)"},
{0x1BAD, 0xC001, 0xFFFF, 0xFFFF, "XpressGXA10-LP1150(0xC001)"},
{0x1BAD, 0xC002, 0xFFFF, 0xFFFF, "XpressGXA10-LP1151(0xC002)"},
}; /* pci_vid_1BAD[] */

static pci_id_t const pci_vid_1BB0[] = {
{0x1BB0, 0xFFFF, 0xFFFF, 0xFFFF, "SimpliVity Corporation(0x1BB0)"},
{0x1BB0, 0x0002, 0xFFFF, 0xFFFF, "OmniCube Accelerator OA-3000(0x0002)"},
{0x1BB0, 0x0010, 0xFFFF, 0xFFFF, "OmniCube Accelerator OA-3000-2(0x0010)"},
}; /* pci_vid_1BB0[] */

static pci_id_t const pci_vid_1BB1[] = {
{0x1BB1, 0xFFFF, 0xFFFF, 0xFFFF, "Seagate Technology PLC(0x1BB1)"},
{0x1BB1, 0x005D, 0xFFFF, 0xFFFF, "Nytro PCIe Flash Storage(0x005D)"},
{0x1BB1, 0x005D, 0x1BB1, 0x6501, "Nytro XP6500-8A1536 1.5TB(0x1BB1-0x6501)"},
{0x1BB1, 0x005D, 0x1BB1, 0x6502, "Nytro XP6500-8A2048(0x1BB1-0x6502)"},
{0x1BB1, 0x005D, 0x1BB1, 0x6503, "Nytro XP6500-8A4096(0x1BB1-0x6503)"},
{0x1BB1, 0x005D, 0x1BB1, 0x6511, "Nytro XH6550-2GB DRAM(0x1BB1-0x6511)"},
{0x1BB1, 0x005D, 0x1BB1, 0x6512, "Nytro XH6550-8GB DRAM(0x1BB1-0x6512)"},
{0x1BB1, 0x005D, 0x1BB1, 0x6521, "Nytro XP6500-8A1536 1.5TB(0x1BB1-0x6521)"},
{0x1BB1, 0x005D, 0x1BB1, 0x6522, "Nytro XP6500-8A2048(0x1BB1-0x6522)"},
{0x1BB1, 0x005D, 0x1BB1, 0x6523, "Nytro XP6500-8A4096(0x1BB1-0x6523)"},
{0x1BB1, 0x0100, 0xFFFF, 0xFFFF, "Nytro Flash Storage(0x0100)"},
{0x1BB1, 0x0100, 0x1BB1, 0x0101, "Nytro XF1440(0x1BB1-0x0101)"},
{0x1BB1, 0x0100, 0x1BB1, 0x0103, "Nytro 5000(0x1BB1-0x0103)"},
{0x1BB1, 0x0100, 0x1BB1, 0x0105, "Nytro 5020(0x1BB1-0x0105)"},
{0x1BB1, 0x0100, 0x1BB1, 0x0106, "Nytro 5020 TCG(0x1BB1-0x0106)"},
{0x1BB1, 0x0100, 0x1BB1, 0x0107, "Nytro 5320(0x1BB1-0x0107)"},
{0x1BB1, 0x0100, 0x1BB1, 0x0108, "Nytro 5320 TCG(0x1BB1-0x0108)"},
{0x1BB1, 0x0100, 0x1BB1, 0x0121, "Nytro XM1440(0x1BB1-0x0121)"},
{0x1BB1, 0x0100, 0x1BB1, 0x0123, "Nytro 5000(0x1BB1-0x0123)"},
{0x1BB1, 0x0100, 0x1BB1, 0x0125, "Nytro 5020(0x1BB1-0x0125)"},
{0x1BB1, 0x0100, 0x1BB1, 0x0126, "Nytro 5020(0x1BB1-0x0126)"},
{0x1BB1, 0x0100, 0x1BB1, 0x0127, "Nytro 5320 M.2(0x1BB1-0x0127)"},
{0x1BB1, 0x0100, 0x1BB1, 0x0128, "Nytro 5320 M.2 TCG(0x1BB1-0x0128)"},
{0x1BB1, 0x0100, 0x1BB1, 0x0131, "Nytro 5320 M.2(0x1BB1-0x0131)"},
{0x1BB1, 0x0100, 0x1BB1, 0x0132, "Nytro 5320 M.2 TCG(0x1BB1-0x0132)"},
{0x1BB1, 0x0100, 0x1BB1, 0x0141, "Nytro 5320 E1.S(0x1BB1-0x0141)"},
{0x1BB1, 0x0100, 0x1BB1, 0x0142, "Nytro 5320 E1.S TCG(0x1BB1-0x0142)"},
{0x1BB1, 0x0100, 0x1BB1, 0x0151, "Nytro 5520(0x1BB1-0x0151)"},
{0x1BB1, 0x0100, 0x1BB1, 0x0152, "Nytro 5520 TCG(0x1BB1-0x0152)"},
{0x1BB1, 0x0100, 0x1BB1, 0x0153, "Nytro 5050H(0x1BB1-0x0153)"},
{0x1BB1, 0x0100, 0x1BB1, 0x0154, "Nytro 5050H TCG(0x1BB1-0x0154)"},
{0x1BB1, 0x0100, 0x1BB1, 0x0155, "Nytro 5050M(0x1BB1-0x0155)"},
{0x1BB1, 0x0100, 0x1BB1, 0x0156, "Nytro 5050M TCG(0x1BB1-0x0156)"},
{0x1BB1, 0x0100, 0x1BB1, 0x0157, "Nytro 5050M 7mm(0x1BB1-0x0157)"},
{0x1BB1, 0x0100, 0x1BB1, 0x0158, "Nytro 5050M TCG 7mm(0x1BB1-0x0158)"},
{0x1BB1, 0x0100, 0x1BB1, 0x0159, "Nytro 5060M(0x1BB1-0x0159)"},
{0x1BB1, 0x0100, 0x1BB1, 0x0160, "Nytro 5060M TCG(0x1BB1-0x0160)"},
{0x1BB1, 0x0100, 0x1BB1, 0x0161, "Nytro 5060M 7mm(0x1BB1-0x0161)"},
{0x1BB1, 0x0100, 0x1BB1, 0x0162, "Nytro 5060M TCG 7mm(0x1BB1-0x0162)"},
{0x1BB1, 0x0100, 0x1BB1, 0x0163, "Nytro 5060H(0x1BB1-0x0163)"},
{0x1BB1, 0x0100, 0x1BB1, 0x0164, "Nytro 5060H TCG(0x1BB1-0x0164)"},
{0x1BB1, 0x0100, 0x1BB1, 0x0165, "Nytro 5060H E3.S 1T(0x1BB1-0x0165)"},
{0x1BB1, 0x0100, 0x1BB1, 0x0166, "Nytro 5060H E3.S 1T TCG(0x1BB1-0x0166)"},
{0x1BB1, 0x0100, 0x1BB1, 0x0167, "Nytro 5060H E3.L 1T(0x1BB1-0x0167)"},
{0x1BB1, 0x0100, 0x1BB1, 0x0168, "Nytro 5060H E3.L 1T TCG(0x1BB1-0x0168)"},
{0x1BB1, 0x0100, 0x1BB1, 0x0169, "Nytro 5060M E3.S 1T(0x1BB1-0x0169)"},
{0x1BB1, 0x0100, 0x1BB1, 0x0170, "Nytro 5060M E3.S 1T TCG(0x1BB1-0x0170)"},
{0x1BB1, 0x0100, 0x1BB1, 0x0171, "Nytro 5060M E3.L 1T(0x1BB1-0x0171)"},
{0x1BB1, 0x0100, 0x1BB1, 0x0172, "Nytro 5060M E3.L 1T TCG(0x1BB1-0x0172)"},
{0x1BB1, 0x0100, 0x1BB1, 0x0173, "Nytro 5060M E1.S(0x1BB1-0x0173)"},
{0x1BB1, 0x0100, 0x1BB1, 0x0174, "Nytro 5060M E1.S TCG(0x1BB1-0x0174)"},
{0x1BB1, 0x0100, 0x1BB1, 0x0175, "Nytro 5350S - 15mm(0x1BB1-0x0175)"},
{0x1BB1, 0x0100, 0x1BB1, 0x0176, "Nytro 5350S TCG - 15mm(0x1BB1-0x0176)"},
{0x1BB1, 0x0100, 0x1BB1, 0x0177, "Nytro 5360S - 15mm(0x1BB1-0x0177)"},
{0x1BB1, 0x0100, 0x1BB1, 0x0178, "Nytro 5360S TCG - 15mm(0x1BB1-0x0178)"},
{0x1BB1, 0x0100, 0x1BB1, 0x0179, "Nytro 5360S - E3.S(0x1BB1-0x0179)"},
{0x1BB1, 0x0100, 0x1BB1, 0x0180, "Nytro 5360S TCG - E3.S(0x1BB1-0x0180)"},
{0x1BB1, 0x0100, 0x1BB1, 0x0181, "Nytro 5060H(0x1BB1-0x0181)"},
{0x1BB1, 0x0100, 0x1BB1, 0x01A1, "Nytro XP7102(0x1BB1-0x01A1)"},
{0x1BB1, 0x5012, 0xFFFF, 0xFFFF, "FireCuda/IronWolf 510 SSD(0x5012)"},
{0x1BB1, 0x5013, 0xFFFF, 0xFFFF, "BarraCuda Q5 NVMe SSD (DRAM-less)(0x5013)"},
{0x1BB1, 0x5016, 0xFFFF, 0xFFFF, "FireCuda 520/IronWolf 525 SSD(0x5016)"},
{0x1BB1, 0x5018, 0xFFFF, 0xFFFF, "FireCuda 530 SSD(0x5018)"},
{0x1BB1, 0x5019, 0xFFFF, 0xFFFF, "BarraCuda PCIe SSD (DRAM-less)(0x5019)"},
{0x1BB1, 0x5021, 0xFFFF, 0xFFFF, "FireCuda 520 SSD(0x5021)"},
{0x1BB1, 0x5026, 0xFFFF, 0xFFFF, "FireCuda 540 SSD(0x5026)"},
}; /* pci_vid_1BB1[] */

static pci_id_t const pci_vid_1BB3[] = {
{0x1BB3, 0xFFFF, 0xFFFF, 0xFFFF, "Bluecherry(0x1BB3)"},
{0x1BB3, 0x4304, 0xFFFF, 0xFFFF, "BC-04120A MPEG4 4 port video encoder / decoder(0x4304)"},
{0x1BB3, 0x4309, 0xFFFF, 0xFFFF, "BC-08240A MPEG4 4 port video encoder / decoder(0x4309)"},
{0x1BB3, 0x4310, 0xFFFF, 0xFFFF, "BC-16480A MPEG4 16 port video encoder / decoder(0x4310)"},
{0x1BB3, 0x4E04, 0xFFFF, 0xFFFF, "BC-04120A 4 port MPEG4 video encoder / decoder(0x4E04)"},
{0x1BB3, 0x4E09, 0xFFFF, 0xFFFF, "BC-08240A 8 port MPEG4 video encoder / decoder(0x4E09)"},
{0x1BB3, 0x4E10, 0xFFFF, 0xFFFF, "BC-16480A 16 port MPEG4 video encoder / decoder(0x4E10)"},
{0x1BB3, 0x5304, 0xFFFF, 0xFFFF, "BC-H04120A 4 port H.264 video and audio encoder / decoder(0x5304)"},
{0x1BB3, 0x5308, 0xFFFF, 0xFFFF, "BC-H08240A 8 port H.264 video and audio encoder / decoder(0x5308)"},
{0x1BB3, 0x5310, 0xFFFF, 0xFFFF, "BC-H16480A 16 port H.264 video and audio encoder / decoder(0x5310)"},
}; /* pci_vid_1BB3[] */

static pci_id_t const pci_vid_1BB5[] = {
{0x1BB5, 0xFFFF, 0xFFFF, 0xFFFF, "Quantenna Communications, Inc.(0x1BB5)"},
}; /* pci_vid_1BB5[] */

static pci_id_t const pci_vid_1BBF[] = {
{0x1BBF, 0xFFFF, 0xFFFF, 0xFFFF, "Maxeler Technologies Ltd.(0x1BBF)"},
{0x1BBF, 0x0003, 0xFFFF, 0xFFFF, "MAX3(0x0003)"},
{0x1BBF, 0x0004, 0xFFFF, 0xFFFF, "MAX4(0x0004)"},
}; /* pci_vid_1BBF[] */

static pci_id_t const pci_vid_1BC0[] = {
{0x1BC0, 0xFFFF, 0xFFFF, 0xFFFF, "Innodisk Corporation(0x1BC0)"},
{0x1BC0, 0x1001, 0xFFFF, 0xFFFF, "PCIe 3TG6-P Controller(0x1001)"},
{0x1BC0, 0x1002, 0xFFFF, 0xFFFF, "PCIe 3TE6 Controller (DRAM-less)(0x1002)"},
{0x1BC0, 0x1160, 0xFFFF, 0xFFFF, "PCIe 3TE2 Controller(0x1160)"},
{0x1BC0, 0x1321, 0xFFFF, 0xFFFF, "PCIe 4TG-P Controller(0x1321)"},
{0x1BC0, 0x1322, 0xFFFF, 0xFFFF, "PCIe 4TE Controller(0x1322)"},
{0x1BC0, 0x2262, 0xFFFF, 0xFFFF, "PCIe 3TG3-P Controller(0x2262)"},
{0x1BC0, 0x5208, 0xFFFF, 0xFFFF, "PCIe 3TE7 Controller(0x5208)"},
{0x1BC0, 0x5216, 0xFFFF, 0xFFFF, "PCIe 3TE8 Controller(0x5216)"},
{0x1BC0, 0x5236, 0xFFFF, 0xFFFF, "PCIe 4TG2-P Controller(0x5236)"},
}; /* pci_vid_1BC0[] */

static pci_id_t const pci_vid_1BCD[] = {
{0x1BCD, 0xFFFF, 0xFFFF, 0xFFFF, "Apacer Technology(0x1BCD)"},
{0x1BCD, 0x0120, 0xFFFF, 0xFFFF, "NVMe SSD Drive 960GB(0x0120)"},
}; /* pci_vid_1BCD[] */

static pci_id_t const pci_vid_1BCF[] = {
{0x1BCF, 0xFFFF, 0xFFFF, 0xFFFF, "NEC Corporation(0x1BCF)"},
{0x1BCF, 0x001C, 0xFFFF, 0xFFFF, "Vector Engine 1.0(0x001C)"},
}; /* pci_vid_1BCF[] */

static pci_id_t const pci_vid_1BD0[] = {
{0x1BD0, 0xFFFF, 0xFFFF, 0xFFFF, "Astronics Corporation(0x1BD0)"},
{0x1BD0, 0x1001, 0xFFFF, 0xFFFF, "Mx5 PMC/XMC Databus Interface Card(0x1001)"},
{0x1BD0, 0x1002, 0xFFFF, 0xFFFF, "PM1553-5 (PC/104+ MIL-STD-1553 Interface Card)(0x1002)"},
{0x1BD0, 0x1004, 0xFFFF, 0xFFFF, "AB3000 Series Rugged Computer(0x1004)"},
{0x1BD0, 0x1005, 0xFFFF, 0xFFFF, "PE1000 (Multi-Protocol PCIe/104 Interface Card)(0x1005)"},
{0x1BD0, 0x1006, 0xFFFF, 0xFFFF, "webCS Wireless Aircraft Communications Server(0x1006)"},
{0x1BD0, 0x1007, 0xFFFF, 0xFFFF, "AB3000 Series Rugged Computer (Series N)(0x1007)"},
{0x1BD0, 0x1008, 0xFFFF, 0xFFFF, "ME1000 mPCIe Avionics Interface Card(0x1008)"},
{0x1BD0, 0x100A, 0xFFFF, 0xFFFF, "NG1 Series Avionics Converter(0x100A)"},
{0x1BD0, 0x100B, 0xFFFF, 0xFFFF, "LE5 429 Databus Interface Card(0x100B)"},
{0x1BD0, 0x100C, 0xFFFF, 0xFFFF, "LE5 1553 Databus Interface Card(0x100C)"},
{0x1BD0, 0x1101, 0xFFFF, 0xFFFF, "OmniBus II PCIe Multi-Protocol Interface Card(0x1101)"},
{0x1BD0, 0x1102, 0xFFFF, 0xFFFF, "OmniBusBox II Multi-Protocol Interface Core(0x1102)"},
{0x1BD0, 0x1103, 0xFFFF, 0xFFFF, "OmniBus II cPCIe/PXIe Multi-Protocol Interface Card(0x1103)"},
{0x1BD0, 0x1200, 0xFFFF, 0xFFFF, "NG3 Series Mil-Std-1553 Interface(0x1200)"},
{0x1BD0, 0x1201, 0xFFFF, 0xFFFF, "NG3 Series ARINC 429 Interface(0x1201)"},
{0x1BD0, 0x1202, 0xFFFF, 0xFFFF, "NG3 Series Avionics Discrete & Serial Interface(0x1202)"},
{0x1BD0, 0x1203, 0xFFFF, 0xFFFF, "NG3 Series Avionics Discrete Interface(0x1203)"},
}; /* pci_vid_1BD0[] */

static pci_id_t const pci_vid_1BD4[] = {
{0x1BD4, 0xFFFF, 0xFFFF, 0xFFFF, "Inspur Electronic Information Industry Co., Ltd.(0x1BD4)"},
{0x1BD4, 0x0911, 0xFFFF, 0xFFFF, "Arria10_PCIe_F10A1150(0x0911)"},
{0x1BD4, 0x1000, 0xFFFF, 0xFFFF, "NS8600G1U160 NVME SSD(0x1000)"},
{0x1BD4, 0x1001, 0xFFFF, 0xFFFF, "NS8600G1U320 NVME SSD(0x1001)"},
{0x1BD4, 0x1002, 0xFFFF, 0xFFFF, "NS8600G1U640 NVME SSD(0x1002)"},
{0x1BD4, 0x1003, 0xFFFF, 0xFFFF, "NS8500G1U192 NVME SSD(0x1003)"},
{0x1BD4, 0x1004, 0xFFFF, 0xFFFF, "NS8500G1U384 NVME SSD(0x1004)"},
{0x1BD4, 0x1005, 0xFFFF, 0xFFFF, "NS8500G1U768 NVME SSD(0x1005)"},
{0x1BD4, 0x1006, 0xFFFF, 0xFFFF, "NS6610G1U160, NS6510G1U192 NVME SSD(0x1006)"},
{0x1BD4, 0x1007, 0xFFFF, 0xFFFF, "NS6610G1U320, NS6510G1U384 NVME SSD(0x1007)"},
{0x1BD4, 0x100C, 0xFFFF, 0xFFFF, "NS8510G1Uxxx, NS8610G1Uxxx NVME SSD(0x100C)"},
{0x1BD4, 0x100E, 0xFFFF, 0xFFFF, "NS8500G2Uxxxx, NS8600G2Uxxxx NVME SSD(0x100E)"},
}; /* pci_vid_1BD4[] */

static pci_id_t const pci_vid_1BEE[] = {
{0x1BEE, 0xFFFF, 0xFFFF, 0xFFFF, "IXXAT Automation GmbH(0x1BEE)"},
{0x1BEE, 0x0002, 0xFFFF, 0xFFFF, "CAN-IB100/PCIe(0x0002)"},
{0x1BEE, 0x0003, 0xFFFF, 0xFFFF, "CAN-IB200/PCIe(0x0003)"},
{0x1BEE, 0x0004, 0xFFFF, 0xFFFF, "CAN-IB120/PCIe Mini(0x0004)"},
{0x1BEE, 0x0005, 0xFFFF, 0xFFFF, "CAN-IB130/PCIe 104(0x0005)"},
{0x1BEE, 0x0006, 0xFFFF, 0xFFFF, "CAN-IB230/PCIe 104(0x0006)"},
{0x1BEE, 0x000E, 0xFFFF, 0xFFFF, "CAN-IB500/PCIe(0x000E)"},
{0x1BEE, 0x000F, 0xFFFF, 0xFFFF, "CAN-IB600/PCIe(0x000F)"},
{0x1BEE, 0x0010, 0xFFFF, 0xFFFF, "CAN-IB300/PCI(0x0010)"},
{0x1BEE, 0x0011, 0xFFFF, 0xFFFF, "CAN-IB400/PCI(0x0011)"},
{0x1BEE, 0x0012, 0xFFFF, 0xFFFF, "CAN-IB520/PCIe Mini(0x0012)"},
{0x1BEE, 0x0016, 0xFFFF, 0xFFFF, "CAN-IB410/PMC(0x0016)"},
{0x1BEE, 0x001C, 0xFFFF, 0xFFFF, "CAN-IB810/PMC(0x001C)"},
{0x1BEE, 0x001E, 0xFFFF, 0xFFFF, "INpact PCIe(0x001E)"},
{0x1BEE, 0x001F, 0xFFFF, 0xFFFF, "INpact PCIe Mini(0x001F)"},
{0x1BEE, 0x0029, 0xFFFF, 0xFFFF, "INpact M.2(0x0029)"},
{0x1BEE, 0x002D, 0xFFFF, 0xFFFF, "CAN-IB630/PCIe 104(0x002D)"},
{0x1BEE, 0x002E, 0xFFFF, 0xFFFF, "CAN-IB640/PCIe(0x002E)"},
}; /* pci_vid_1BEE[] */

static pci_id_t const pci_vid_1BEF[] = {
{0x1BEF, 0xFFFF, 0xFFFF, 0xFFFF, "Lantiq(0x1BEF)"},
{0x1BEF, 0x0011, 0xFFFF, 0xFFFF, "MIPS SoC PCI Express Port(0x0011)"},
}; /* pci_vid_1BEF[] */

static pci_id_t const pci_vid_1BF4[] = {
{0x1BF4, 0xFFFF, 0xFFFF, 0xFFFF, "VTI Instruments Corporation(0x1BF4)"},
{0x1BF4, 0x0001, 0xFFFF, 0xFFFF, "SentinelEX(0x0001)"},
{0x1BF4, 0x7011, 0xFFFF, 0xFFFF, "RX0xxx(0x7011)"},
}; /* pci_vid_1BF4[] */

static pci_id_t const pci_vid_1BF5[] = {
{0x1BF5, 0xFFFF, 0xFFFF, 0xFFFF, "Greenliant(0x1BF5)"},
{0x1BF5, 0x1000, 0xFFFF, 0xFFFF, "G7200 series U.2 NVMe SSD(0x1000)"},
}; /* pci_vid_1BF5[] */

static pci_id_t const pci_vid_1BFC[] = {
{0x1BFC, 0xFFFF, 0xFFFF, 0xFFFF, "Duagon AG(0x1BFC)"},
}; /* pci_vid_1BFC[] */

static pci_id_t const pci_vid_1BFD[] = {
{0x1BFD, 0xFFFF, 0xFFFF, 0xFFFF, "EeeTOP(0x1BFD)"},
}; /* pci_vid_1BFD[] */

static pci_id_t const pci_vid_1C00[] = {
{0x1C00, 0xFFFF, 0xFFFF, 0xFFFF, "Nanjing Qinheng Microelectronics Co., Ltd.(0x1C00)"},
{0x1C00, 0x2170, 0xFFFF, 0xFFFF, "CH351 PCIe Parallel Port Adapter(0x2170)"},
{0x1C00, 0x2273, 0xFFFF, 0xFFFF, "CH351 PCIe Dual Port Serial Adapter(0x2273)"},
{0x1C00, 0x3050, 0xFFFF, 0xFFFF, "CH382L PCIe Parallel Port Adapter(0x3050)"},
{0x1C00, 0x3250, 0xFFFF, 0xFFFF, "CH384 Dual Port Serial and Parallel Port Adapter(0x3250)"},
{0x1C00, 0x3252, 0xFFFF, 0xFFFF, "CH382 PCIe Dual Port Serial Adapter(0x3252)"},
{0x1C00, 0x3253, 0xFFFF, 0xFFFF, "CH352/CH382 PCI/PCIe Dual Port Serial Adapter(0x3253)"},
}; /* pci_vid_1C00[] */

static pci_id_t const pci_vid_1C09[] = {
{0x1C09, 0xFFFF, 0xFFFF, 0xFFFF, "CSP, Inc.(0x1C09)"},
{0x1C09, 0x4254, 0xFFFF, 0xFFFF, "10G-PCIE3-8D-2S(0x4254)"},
{0x1C09, 0x4255, 0xFFFF, 0xFFFF, "10G-PCIE3-8D-Q(0x4255)"},
{0x1C09, 0x4256, 0xFFFF, 0xFFFF, "10G-PCIE3-8D-2S(0x4256)"},
{0x1C09, 0x4258, 0xFFFF, 0xFFFF, "10G-PCIE3-8E-2S Network Adapter(0x4258)"},
{0x1C09, 0x4260, 0xFFFF, 0xFFFF, "10G-PCIE3-8E-4S Network Adapter(0x4260)"},
{0x1C09, 0x4261, 0xFFFF, 0xFFFF, "10G-PCIE3-8E-4S Network Adapter(0x4261)"},
{0x1C09, 0x4262, 0xFFFF, 0xFFFF, "10G-PCIE3-8E-4S Network Adapter(0x4262)"},
{0x1C09, 0x4263, 0xFFFF, 0xFFFF, "10G-PCIE3-8E-4S Network Adapter(0x4263)"},
{0x1C09, 0x4264, 0xFFFF, 0xFFFF, "10G-PCIE3-8E-2S Network Adapter(0x4264)"},
{0x1C09, 0x4265, 0xFFFF, 0xFFFF, "10G-PCIE3-8E-2S Network Adapter(0x4265)"},
{0x1C09, 0x5000, 0xFFFF, 0xFFFF, "25G-PCIE3-8A-2S Security Intelligent Adapter(0x5000)"},
{0x1C09, 0x5001, 0xFFFF, 0xFFFF, "25G-PCIE3-8B-2S Security Intelligent Adapter(0x5001)"},
}; /* pci_vid_1C09[] */

static pci_id_t const pci_vid_1C1C[] = {
{0x1C1C, 0xFFFF, 0xFFFF, 0xFFFF, "Symphony(0x1C1C)"},
{0x1C1C, 0x0001, 0xFFFF, 0xFFFF, "82C101(0x0001)"},
}; /* pci_vid_1C1C[] */

static pci_id_t const pci_vid_1C1F[] = {
{0x1C1F, 0xFFFF, 0xFFFF, 0xFFFF, "SoftLab-NSK(0x1C1F)"},
{0x1C1F, 0x0015, 0xFFFF, 0xFFFF, "FD842(0x0015)"},
{0x1C1F, 0x0019, 0xFFFF, 0xFFFF, "FD722(0x0019)"},
{0x1C1F, 0x001A, 0xFFFF, 0xFFFF, "FD788(0x001A)"},
{0x1C1F, 0x001B, 0xFFFF, 0xFFFF, "FD720(0x001B)"},
{0x1C1F, 0x001C, 0xFFFF, 0xFFFF, "FD922(0x001C)"},
{0x1C1F, 0x001D, 0xFFFF, 0xFFFF, "Vega(0x001D)"},
{0x1C1F, 0x001F, 0xFFFF, 0xFFFF, "FD940(0x001F)"},
{0x1C1F, 0x0020, 0xFFFF, 0xFFFF, "FD2110(0x0020)"},
{0x1C1F, 0x0021, 0xFFFF, 0xFFFF, "FD722(0x0021)"},
{0x1C1F, 0x0022, 0xFFFF, 0xFFFF, "FD788(0x0022)"},
{0x1C1F, 0x0023, 0xFFFF, 0xFFFF, "FD722-M2(0x0023)"},
}; /* pci_vid_1C1F[] */

static pci_id_t const pci_vid_1C28[] = {
{0x1C28, 0xFFFF, 0xFFFF, 0xFFFF, "Lite-On IT Corp. / Plextor(0x1C28)"},
{0x1C28, 0x0122, 0xFFFF, 0xFFFF, "M6e PCI Express SSD [Marvell 88SS9183](0x0122)"},
}; /* pci_vid_1C28[] */

static pci_id_t const pci_vid_1C2C[] = {
{0x1C2C, 0xFFFF, 0xFFFF, 0xFFFF, "Silicom Denmark(0x1C2C)"},
{0x1C2C, 0x000A, 0xFFFF, 0xFFFF, "Capture(0x000A)"},
{0x1C2C, 0x000F, 0xFFFF, 0xFFFF, "SmartNIC(0x000F)"},
{0x1C2C, 0x00A0, 0xFFFF, 0xFFFF, "FBC4G Capture 4x1Gb [Herculaneum](0x00A0)"},
{0x1C2C, 0x00A1, 0xFFFF, 0xFFFF, "FBC4XG Capture 4x10Gb [Ancona](0x00A1)"},
{0x1C2C, 0x00A2, 0xFFFF, 0xFFFF, "FBC8XG Capture 8x10Gb [Livorno](0x00A2)"},
{0x1C2C, 0x00A3, 0xFFFF, 0xFFFF, "FBC2XG Capture 2x10Gb [Genoa](0x00A3)"},
{0x1C2C, 0x00A4, 0xFFFF, 0xFFFF, "FBC4XGG3 Capture 4x10Gb [Livigno](0x00A4)"},
{0x1C2C, 0x00A5, 0xFFFF, 0xFFFF, "FBC2XLG Capture 2x40Gb [Livorno](0x00A5)"},
{0x1C2C, 0x00A6, 0xFFFF, 0xFFFF, "FBC1CG Capture 1x100Gb(0x00A6)"},
{0x1C2C, 0x00A9, 0xFFFF, 0xFFFF, "FBC2XGHH Capture 2x10Gb [Latina](0x00A9)"},
{0x1C2C, 0x00AD, 0xFFFF, 0xFFFF, "FBC2CGG3HL Capture 2x100Gb [Padua](0x00AD)"},
{0x1C2C, 0x00AF, 0xFFFF, 0xFFFF, "Capture slave device(0x00AF)"},
{0x1C2C, 0x00E0, 0xFFFF, 0xFFFF, "PacketMover 2x100Gb [Savona](0x00E0)"},
{0x1C2C, 0x00E1, 0xFFFF, 0xFFFF, "PacketMover 2x100Gb [Tivoli](0x00E1)"},
{0x1C2C, 0x00E2, 0xFFFF, 0xFFFF, "PacketMover 2x100Gb [Mango_04](0x00E2)"},
{0x1C2C, 0x00E3, 0xFFFF, 0xFFFF, "PacketMover 2x10Gb [Tivoli](0x00E3)"},
{0x1C2C, 0x00E5, 0xFFFF, 0xFFFF, "PacketMover 2x10Gb [Corfu](0x00E5)"},
{0x1C2C, 0x1000, 0xFFFF, 0xFFFF, "SmartNIC N5010 4x100Gb(0x1000)"},
{0x1C2C, 0x1001, 0xFFFF, 0xFFFF, "SmartNIC N5011 w/2xE810 4x100Gb(0x1001)"},
{0x1C2C, 0x1002, 0xFFFF, 0xFFFF, "SmartNIC N5013 4x100Gb(0x1002)"},
{0x1C2C, 0x1003, 0xFFFF, 0xFFFF, "SmartNIC N5014 w/2xE810 4x100Gb(0x1003)"},
{0x1C2C, 0xA000, 0xFFFF, 0xFFFF, "FBC2CGG3 Capture 2x40Gb [Mango_02](0xA000)"},
{0x1C2C, 0xA001, 0xFFFF, 0xFFFF, "FBC2CGG3 Capture 2x100Gb [Mango_02](0xA001)"},
{0x1C2C, 0xA003, 0xFFFF, 0xFFFF, "FBC2CGG3 Capture 16x10Gb [Mango](0xA003)"},
{0x1C2C, 0xA006, 0xFFFF, 0xFFFF, "FBC2CGG3 Capture 2x100Gb [Mango](0xA006)"},
{0x1C2C, 0xA007, 0xFFFF, 0xFFFF, "FBC2CGG3 Capture 2x40Gb [Mango](0xA007)"},
{0x1C2C, 0xA008, 0xFFFF, 0xFFFF, "FBC2CGG3 Capture 2x25Gb [Mango](0xA008)"},
{0x1C2C, 0xA009, 0xFFFF, 0xFFFF, "FBC2CGG3 Capture 16x10Gb [Mango](0xA009)"},
{0x1C2C, 0xA00A, 0xFFFF, 0xFFFF, "FBC2CGG3 Capture 8x10Gb [Mango](0xA00A)"},
{0x1C2C, 0xA00E, 0xFFFF, 0xFFFF, "FB2CG Capture 2x100Gb [Savona](0xA00E)"},
{0x1C2C, 0xA00F, 0xFFFF, 0xFFFF, "FB2CG Capture 2x40Gb [Savona](0xA00F)"},
{0x1C2C, 0xA010, 0xFFFF, 0xFFFF, "FB2CGHH Capture 2x40Gb [Tivoli](0xA010)"},
{0x1C2C, 0xA011, 0xFFFF, 0xFFFF, "FB2CG Capture 2x25Gb [Savona](0xA011)"},
{0x1C2C, 0xA012, 0xFFFF, 0xFFFF, "FB2CG Capture 8x10Gb [Savona](0xA012)"},
{0x1C2C, 0xA013, 0xFFFF, 0xFFFF, "FB2CGHH Capture 2x25Gb [Tivoli](0xA013)"},
{0x1C2C, 0xA014, 0xFFFF, 0xFFFF, "FB2CGHH Capture 8x10Gb [Tivoli](0xA014)"},
{0x1C2C, 0xA015, 0xFFFF, 0xFFFF, "FB2CGHH Capture 2x100Gb [Tivoli](0xA015)"},
{0x1C2C, 0xA016, 0xFFFF, 0xFFFF, "FB2CG Capture 8x25Gb [Savona](0xA016)"},
{0x1C2C, 0xA017, 0xFFFF, 0xFFFF, "FB2CGHH Capture 8x25Gb [Tivoli] a017(0xA017)"},
}; /* pci_vid_1C2C[] */

static pci_id_t const pci_vid_1C32[] = {
{0x1C32, 0xFFFF, 0xFFFF, 0xFFFF, "Highland Technology, Inc.(0x1C32)"},
}; /* pci_vid_1C32[] */

static pci_id_t const pci_vid_1C33[] = {
{0x1C33, 0xFFFF, 0xFFFF, 0xFFFF, "Daktronics, Inc(0x1C33)"},
}; /* pci_vid_1C33[] */

static pci_id_t const pci_vid_1C36[] = {
{0x1C36, 0xFFFF, 0xFFFF, 0xFFFF, "Annapurna Labs Ltd.(0x1C36)"},
{0x1C36, 0x0001, 0xFFFF, 0xFFFF, "Gigabit Ethernet Adapter(0x0001)"},
{0x1C36, 0x0002, 0xFFFF, 0xFFFF, "SFP+ 10G Ethernet Adapter(0x0002)"},
}; /* pci_vid_1C36[] */

static pci_id_t const pci_vid_1C3B[] = {
{0x1C3B, 0xFFFF, 0xFFFF, 0xFFFF, "Accensus, LLC(0x1C3B)"},
{0x1C3B, 0x0200, 0xFFFF, 0xFFFF, "Telas2(0x0200)"},
{0x1C3B, 0x0300, 0xFFFF, 0xFFFF, "Telas 2.V(0x0300)"},
}; /* pci_vid_1C3B[] */

static pci_id_t const pci_vid_1C44[] = {
{0x1C44, 0xFFFF, 0xFFFF, 0xFFFF, "Enmotus Inc(0x1C44)"},
{0x1C44, 0x1100, 0xFFFF, 0xFFFF, "Fuzedrive NVMe SSD(0x1100)"},
{0x1C44, 0x8000, 0xFFFF, 0xFFFF, "8000 Storage IO Controller(0x8000)"},
}; /* pci_vid_1C44[] */

static pci_id_t const pci_vid_1C58[] = {
{0x1C58, 0xFFFF, 0xFFFF, 0xFFFF, "HGST, Inc.(0x1C58)"},
{0x1C58, 0x0003, 0xFFFF, 0xFFFF, "Ultrastar SN100 Series NVMe SSD(0x0003)"},
{0x1C58, 0x0003, 0x1014, 0x04F5, "PCIe3 1.6TB NVMe Flash Adapter(0x1014-0x04F5)"},
{0x1C58, 0x0003, 0x1014, 0x04F6, "PCIe3 3.2TB NVMe Flash Adapter(0x1014-0x04F6)"},
{0x1C58, 0x0003, 0x1C58, 0x0003, "Ultrastar SN100/SN150 NVMe SSD(0x1C58-0x0003)"},
{0x1C58, 0x0023, 0xFFFF, 0xFFFF, "Ultrastar SN200 Series NVMe SSD(0x0023)"},
{0x1C58, 0x0023, 0x1C58, 0x8823, "Ultrastar Memory (ME200)(0x1C58-0x8823)"},
}; /* pci_vid_1C58[] */

static pci_id_t const pci_vid_1C5C[] = {
{0x1C5C, 0xFFFF, 0xFFFF, 0xFFFF, "SK hynix(0x1C5C)"},
{0x1C5C, 0x1069, 0xFFFF, 0xFFFF, "PCB01 NVMe Solid State Drive(0x1069)"},
{0x1C5C, 0x1282, 0xFFFF, 0xFFFF, "PC300 NVMe Solid State Drive 128GB(0x1282)"},
{0x1C5C, 0x1283, 0xFFFF, 0xFFFF, "PC300 NVMe Solid State Drive 256GB(0x1283)"},
{0x1C5C, 0x1284, 0xFFFF, 0xFFFF, "PC300 NVMe Solid State Drive 512GB(0x1284)"},
{0x1C5C, 0x1285, 0xFFFF, 0xFFFF, "PC300 NVMe Solid State Drive 1TB(0x1285)"},
{0x1C5C, 0x1327, 0xFFFF, 0xFFFF, "BC501 NVMe Solid State Drive(0x1327)"},
{0x1C5C, 0x1339, 0xFFFF, 0xFFFF, "BC511 NVMe SSD(0x1339)"},
{0x1C5C, 0x1504, 0xFFFF, 0xFFFF, "PC400 NVMe SSD(0x1504)"},
{0x1C5C, 0x1527, 0xFFFF, 0xFFFF, "PC401 NVMe Solid State Drive 256GB(0x1527)"},
{0x1C5C, 0x1627, 0xFFFF, 0xFFFF, "PC601 NVMe Solid State Drive(0x1627)"},
{0x1C5C, 0x1639, 0xFFFF, 0xFFFF, "PC611 NVMe Solid State Drive(0x1639)"},
{0x1C5C, 0x1739, 0xFFFF, 0xFFFF, "BC701 NVMe Solid State Drive(0x1739)"},
{0x1C5C, 0x174A, 0xFFFF, 0xFFFF, "Gold P31/BC711/PC711 NVMe Solid State Drive(0x174A)"},
{0x1C5C, 0x1959, 0xFFFF, 0xFFFF, "Platinum P41/PC801 NVMe Solid State Drive(0x1959)"},
{0x1C5C, 0x1D59, 0xFFFF, 0xFFFF, "BC901 NVMe Solid State Drive (DRAM-less)(0x1D59)"},
{0x1C5C, 0x2204, 0xFFFF, 0xFFFF, "960GB TLC PCIe Gen3 x4 NVMe M.2 22110(0x2204)"},
{0x1C5C, 0x2427, 0xFFFF, 0xFFFF, "PE6010 NVMe Solid State Drive(0x2427)"},
{0x1C5C, 0x2429, 0xFFFF, 0xFFFF, "PE6011 NVMe Solid State Drive(0x2429)"},
{0x1C5C, 0x243B, 0xFFFF, 0xFFFF, "PE6110 NVMe Solid State Drive(0x243B)"},
{0x1C5C, 0x243B, 0x1C5C, 0x0100, "PE6110 NVMe Solid State Drive(0x1C5C-0x0100)"},
{0x1C5C, 0x2527, 0xFFFF, 0xFFFF, "PE4010 NVMe Solid State Drive(0x2527)"},
{0x1C5C, 0x2839, 0xFFFF, 0xFFFF, "PE8000 Series NVMe Solid State Drive(0x2839)"},
{0x1C5C, 0x2839, 0x1028, 0x2143, "DC NVMe SED PE8010 RI U.2 960GB(0x1028-0x2143)"},
{0x1C5C, 0x2839, 0x1028, 0x2144, "DC NVMe PE8010 RI U.2 960GB(0x1028-0x2144)"},
{0x1C5C, 0x2839, 0x1028, 0x2145, "DC NVMe SED PE8010 RI U.2 1.92TB(0x1028-0x2145)"},
{0x1C5C, 0x2839, 0x1028, 0x2146, "DC NVMe PE8010 RI U.2 1.92TB(0x1028-0x2146)"},
{0x1C5C, 0x2839, 0x1028, 0x2147, "DC NVMe SED PE8010 RI U.2 3.84TB(0x1028-0x2147)"},
{0x1C5C, 0x2839, 0x1028, 0x2148, "DC NVMe PE8010 RI U.2 3.84TB(0x1028-0x2148)"},
{0x1C5C, 0x2839, 0x1028, 0x2149, "DC NVMe SED PE8010 RI U.2 7.68TB(0x1028-0x2149)"},
{0x1C5C, 0x2839, 0x1028, 0x214A, "DC NVMe PE8010 RI U.2 7.68TB(0x1028-0x214A)"},
{0x1C5C, 0x2839, 0x1C5C, 0x0100, "PE8000 Series NVMe Solid State Drive(0x1C5C-0x0100)"},
{0x1C5C, 0x2849, 0xFFFF, 0xFFFF, "PE81x0 U.2/3 NVMe Solid State Drive(0x2849)"},
{0x1C5C, 0x2849, 0x1028, 0x2262, "DC NVMe OPAL PE8110 RI U.2 960GB(0x1028-0x2262)"},
{0x1C5C, 0x2849, 0x1028, 0x2263, "DC NVMe OPAL PE8110 RI U.2 1920GB(0x1028-0x2263)"},
{0x1C5C, 0x2849, 0x1028, 0x2264, "DC NVMe OPAL PE8110 RI U.2 3840GB(0x1028-0x2264)"},
{0x1C5C, 0x2849, 0x1028, 0x2265, "DC NVMe OPAL PE8110 RI U.2 7680GB(0x1028-0x2265)"},
{0x1C5C, 0x2849, 0x1028, 0x2266, "DC NVMe ISE PE8110 RI U.2 960GB(0x1028-0x2266)"},
{0x1C5C, 0x2849, 0x1028, 0x2267, "DC NVMe ISE PE8110 RI U.2 1920GB(0x1028-0x2267)"},
{0x1C5C, 0x2849, 0x1028, 0x2268, "DC NVMe ISE PE8110 RI U.2 3840GB(0x1028-0x2268)"},
{0x1C5C, 0x2849, 0x1028, 0x2269, "DC NVMe ISE PE8110 RI U.2 7680GB(0x1028-0x2269)"},
{0x1C5C, 0x2849, 0x1C5C, 0x0101, "PE81x0 U.2/3 NVMe Solid State Drive(0x1C5C-0x0101)"},
{0x1C5C, 0x284A, 0xFFFF, 0xFFFF, "PE8110 Series NVMe Solid State Drive(0x284A)"},
{0x1C5C, 0x2A49, 0xFFFF, 0xFFFF, "PE9110 Series NVMe Solid State Drive(0x2A49)"},
{0x1C5C, 0x2A59, 0xFFFF, 0xFFFF, "PE9010 Series NVMe Solid State Drives(0x2A59)"},
{0x1C5C, 0x2B59, 0xFFFF, 0xFFFF, "PS10x0 Series NVMe Solid State Drives(0x2B59)"},
}; /* pci_vid_1C5C[] */

static pci_id_t const pci_vid_1C5F[] = {
{0x1C5F, 0xFFFF, 0xFFFF, 0xFFFF, "Beijing Memblaze Technology Co. Ltd.(0x1C5F)"},
{0x1C5F, 0x000D, 0xFFFF, 0xFFFF, "PBlaze5 520/526(0x000D)"},
{0x1C5F, 0x000D, 0x1C5F, 0x0220, "NVMe SSD PBlaze5 520 1920G AIC(0x1C5F-0x0220)"},
{0x1C5F, 0x000D, 0x1C5F, 0x0221, "NVMe SSD PBlaze5 520 1920G 2.5\" U.2(0x1C5F-0x0221)"},
{0x1C5F, 0x000D, 0x1C5F, 0x0230, "NVMe SSD PBlaze5 520 3840G AIC(0x1C5F-0x0230)"},
{0x1C5F, 0x000D, 0x1C5F, 0x0231, "NVMe SSD PBlaze5 520 3840G 2.5\" U.2(0x1C5F-0x0231)"},
{0x1C5F, 0x000D, 0x1C5F, 0x4220, "NVMe SSD PBlaze5 526 1600G AIC(0x1C5F-0x4220)"},
{0x1C5F, 0x000D, 0x1C5F, 0x4221, "NVMe SSD PBlaze5 526 1600G 2.5\" U.2(0x1C5F-0x4221)"},
{0x1C5F, 0x000D, 0x1C5F, 0x4230, "NVMe SSD PBlaze5 526 3200G AIC(0x1C5F-0x4230)"},
{0x1C5F, 0x000D, 0x1C5F, 0x4231, "NVMe SSD PBlaze5 526 3200G 2.5\" U.2(0x1C5F-0x4231)"},
{0x1C5F, 0x000E, 0xFFFF, 0xFFFF, "PBlaze6 6530/6531/6541/6630(0x000E)"},
{0x1C5F, 0x000E, 0x1C5F, 0x0B20, "NVMe SSD PBlaze6 6530 1920G AIC(0x1C5F-0x0B20)"},
{0x1C5F, 0x000E, 0x1C5F, 0x0B21, "NVMe SSD PBlaze6 6530 1920G 2.5\" U.2(0x1C5F-0x0B21)"},
{0x1C5F, 0x000E, 0x1C5F, 0x0B25, "NVMe SSD PBlaze6 6530 1920G E1.S(0x1C5F-0x0B25)"},
{0x1C5F, 0x000E, 0x1C5F, 0x0B27, "NVMe SSD PBlaze6 6630 1920G 2.5\" U.2(0x1C5F-0x0B27)"},
{0x1C5F, 0x000E, 0x1C5F, 0x0B30, "NVMe SSD PBlaze6 6530 3840G AIC(0x1C5F-0x0B30)"},
{0x1C5F, 0x000E, 0x1C5F, 0x0B31, "NVMe SSD PBlaze6 6530 3840G 2.5\" U.2(0x1C5F-0x0B31)"},
{0x1C5F, 0x000E, 0x1C5F, 0x0B35, "NVMe SSD PBlaze6 6530 3840G E1.S(0x1C5F-0x0B35)"},
{0x1C5F, 0x000E, 0x1C5F, 0x0B37, "NVMe SSD PBlaze6 6630 3840G 2.5\" U.2(0x1C5F-0x0B37)"},
{0x1C5F, 0x000E, 0x1C5F, 0x0B40, "NVMe SSD PBlaze6 6530 7680G AIC(0x1C5F-0x0B40)"},
{0x1C5F, 0x000E, 0x1C5F, 0x0B41, "NVMe SSD PBlaze6 6530 7680G 2.5\" U.2(0x1C5F-0x0B41)"},
{0x1C5F, 0x000E, 0x1C5F, 0x0B47, "NVMe SSD PBlaze6 6630 7680G 2.5\" U.2(0x1C5F-0x0B47)"},
{0x1C5F, 0x000E, 0x1C5F, 0x1320, "NVMe SSD PBlaze6 6531 1920G AIC(0x1C5F-0x1320)"},
{0x1C5F, 0x000E, 0x1C5F, 0x1321, "NVMe SSD PBlaze6 6531 1920G 2.5\" U.2(0x1C5F-0x1321)"},
{0x1C5F, 0x000E, 0x1C5F, 0x1330, "NVMe SSD PBlaze6 6531 3840G AIC(0x1C5F-0x1330)"},
{0x1C5F, 0x000E, 0x1C5F, 0x1331, "NVMe SSD PBlaze6 6531 3840G 2.5\" U.2(0x1C5F-0x1331)"},
{0x1C5F, 0x000E, 0x1C5F, 0x1340, "NVMe SSD PBlaze6 6531 7680G AIC(0x1C5F-0x1340)"},
{0x1C5F, 0x000E, 0x1C5F, 0x1341, "NVMe SSD PBlaze6 6531 7680G 2.5\" U.2(0x1C5F-0x1341)"},
{0x1C5F, 0x000E, 0x1C5F, 0x1421, "NVMe SSD PBlaze6 6541 1920G 2.5\" U.2(0x1C5F-0x1421)"},
{0x1C5F, 0x000E, 0x1C5F, 0x1427, "NVMe SSD PBlaze6 6641 1920G 2.5\" U.2(dual port)(0x1C5F-0x1427)"},
{0x1C5F, 0x000E, 0x1C5F, 0x1431, "NVMe SSD PBlaze6 6541 3840G 2.5\" U.2(0x1C5F-0x1431)"},
{0x1C5F, 0x000E, 0x1C5F, 0x1437, "NVMe SSD PBlaze6 6641 3840G 2.5\" U.2(dual port)(0x1C5F-0x1437)"},
{0x1C5F, 0x000E, 0x1C5F, 0x1441, "NVMe SSD PBlaze6 6541 7680G 2.5\" U.2(0x1C5F-0x1441)"},
{0x1C5F, 0x000E, 0x1C5F, 0x1447, "NVMe SSD PBlaze6 6641 7680G 2.5\" U.2(dual port)(0x1C5F-0x1447)"},
{0x1C5F, 0x000E, 0x1C5F, 0x4B20, "NVMe SSD PBlaze6 6536 1600G AIC(0x1C5F-0x4B20)"},
{0x1C5F, 0x000E, 0x1C5F, 0x4B21, "NVMe SSD PBlaze6 6536 1600G 2.5\" U.2(0x1C5F-0x4B21)"},
{0x1C5F, 0x000E, 0x1C5F, 0x4B25, "NVMe SSD PBlaze6 6536 1600G E1.S(0x1C5F-0x4B25)"},
{0x1C5F, 0x000E, 0x1C5F, 0x4B27, "NVMe SSD PBlaze6 6636 1600G 2.5\" U.2(0x1C5F-0x4B27)"},
{0x1C5F, 0x000E, 0x1C5F, 0x4B30, "NVMe SSD PBlaze6 6536 3200G AIC(0x1C5F-0x4B30)"},
{0x1C5F, 0x000E, 0x1C5F, 0x4B31, "NVMe SSD PBlaze6 6536 3200G 2.5\" U.2(0x1C5F-0x4B31)"},
{0x1C5F, 0x000E, 0x1C5F, 0x4B35, "NVMe SSD PBlaze6 6536 3200G E1.S(0x1C5F-0x4B35)"},
{0x1C5F, 0x000E, 0x1C5F, 0x4B37, "NVMe SSD PBlaze6 6636 3200G 2.5\" U.2(0x1C5F-0x4B37)"},
{0x1C5F, 0x000E, 0x1C5F, 0x4B40, "NVMe SSD PBlaze6 6536 6400G AIC(0x1C5F-0x4B40)"},
{0x1C5F, 0x000E, 0x1C5F, 0x4B41, "NVMe SSD PBlaze6 6536 6400G 2.5\" U.2(0x1C5F-0x4B41)"},
{0x1C5F, 0x000E, 0x1C5F, 0x4B47, "NVMe SSD PBlaze6 6636 6400G 2.5\" U.2(0x1C5F-0x4B47)"},
{0x1C5F, 0x000E, 0x1C5F, 0x5320, "NVMe SSD PBlaze6 6537 1600G AIC(0x1C5F-0x5320)"},
{0x1C5F, 0x000E, 0x1C5F, 0x5321, "NVMe SSD PBlaze6 6537 1600G 2.5\" U.2(0x1C5F-0x5321)"},
{0x1C5F, 0x000E, 0x1C5F, 0x5330, "NVMe SSD PBlaze6 6537 3200G AIC(0x1C5F-0x5330)"},
{0x1C5F, 0x000E, 0x1C5F, 0x5331, "NVMe SSD PBlaze6 6537 3200G 2.5\" U.2(0x1C5F-0x5331)"},
{0x1C5F, 0x000E, 0x1C5F, 0x5340, "NVMe SSD PBlaze6 6537 6400G AIC(0x1C5F-0x5340)"},
{0x1C5F, 0x000E, 0x1C5F, 0x5341, "NVMe SSD PBlaze6 6537 6400G 2.5\" U.2(0x1C5F-0x5341)"},
{0x1C5F, 0x000E, 0x1C5F, 0x5421, "NVMe SSD PBlaze6 6547 1600G 2.5\" U.2(0x1C5F-0x5421)"},
{0x1C5F, 0x000E, 0x1C5F, 0x5427, "NVMe SSD PBlaze6 6647 1600G 2.5\" U.2(dual port)(0x1C5F-0x5427)"},
{0x1C5F, 0x000E, 0x1C5F, 0x5431, "NVMe SSD PBlaze6 6547 3200G 2.5\" U.2(0x1C5F-0x5431)"},
{0x1C5F, 0x000E, 0x1C5F, 0x5437, "NVMe SSD PBlaze6 6647 3200G 2.5\" U.2(dual port)(0x1C5F-0x5437)"},
{0x1C5F, 0x000E, 0x1C5F, 0x5441, "NVMe SSD PBlaze6 6547 6400G 2.5\" U.2(0x1C5F-0x5441)"},
{0x1C5F, 0x000E, 0x1C5F, 0x5447, "NVMe SSD PBlaze6 6647 6400G 2.5\" U.2(dual port)(0x1C5F-0x5447)"},
{0x1C5F, 0x003D, 0xFFFF, 0xFFFF, "PBlaze5 920/926(0x003D)"},
{0x1C5F, 0x003D, 0x1C5F, 0x0A30, "NVMe SSD PBlaze5 920 3840G AIC(0x1C5F-0x0A30)"},
{0x1C5F, 0x003D, 0x1C5F, 0x0A31, "NVMe SSD PBlaze5 920 3840G 2.5\" U.2(0x1C5F-0x0A31)"},
{0x1C5F, 0x003D, 0x1C5F, 0x0A40, "NVMe SSD PBlaze5 920 7680G AIC(0x1C5F-0x0A40)"},
{0x1C5F, 0x003D, 0x1C5F, 0x0A41, "NVMe SSD PBlaze5 920 7680G 2.5\" U.2(0x1C5F-0x0A41)"},
{0x1C5F, 0x003D, 0x1C5F, 0x4A30, "NVMe SSD PBlaze5 926 3200G AIC(0x1C5F-0x4A30)"},
{0x1C5F, 0x003D, 0x1C5F, 0x4A31, "NVMe SSD PBlaze5 926 3200G 2.5\" U.2(0x1C5F-0x4A31)"},
{0x1C5F, 0x003D, 0x1C5F, 0x4A40, "NVMe SSD PBlaze5 926 6400G AIC(0x1C5F-0x4A40)"},
{0x1C5F, 0x003D, 0x1C5F, 0x4A41, "NVMe SSD PBlaze5 926 6400G 2.5\" U.2(0x1C5F-0x4A41)"},
{0x1C5F, 0x003E, 0xFFFF, 0xFFFF, "PBlaze6 6920/6930(0x003E)"},
{0x1C5F, 0x003E, 0x1C5F, 0x0A31, "NVMe SSD PBlaze6 6920 3840GB 2.5\" U.2(0x1C5F-0x0A31)"},
{0x1C5F, 0x003E, 0x1C5F, 0x0A41, "NVMe SSD PBlaze6 6920 7680GB 2.5\" U.2(0x1C5F-0x0A41)"},
{0x1C5F, 0x003E, 0x1C5F, 0x0B31, "NVMe SSD PBlaze6 6930 3840GB 2.5\" U.3(0x1C5F-0x0B31)"},
{0x1C5F, 0x003E, 0x1C5F, 0x0B41, "NVMe SSD PBlaze6 6930 7680GB 2.5\" U.3(0x1C5F-0x0B41)"},
{0x1C5F, 0x003E, 0x1C5F, 0x0B51, "NVMe SSD PBlaze6 6930 15360GB 2.5\" U.3(0x1C5F-0x0B51)"},
{0x1C5F, 0x003E, 0x1C5F, 0x0B61, "NVMe SSD PBlaze6 6930 30720GB 2.5\" U.3(0x1C5F-0x0B61)"},
{0x1C5F, 0x003E, 0x1C5F, 0x4A31, "NVMe SSD PBlaze6 6920 3200GB 2.5\" U.2(0x1C5F-0x4A31)"},
{0x1C5F, 0x003E, 0x1C5F, 0x4A41, "NVMe SSD PBlaze6 6920 6400GB 2.5\" U.2(0x1C5F-0x4A41)"},
{0x1C5F, 0x003E, 0x1C5F, 0x4B41, "NVMe SSD PBlaze6 6936 6400GB 2.5\" U.3(0x1C5F-0x4B41)"},
{0x1C5F, 0x003E, 0x1C5F, 0x4B51, "NVMe SSD PBlaze6 6936 12800GB 2.5\" U.3(0x1C5F-0x4B51)"},
{0x1C5F, 0x003E, 0x1C5F, 0x4B61, "NVMe SSD PBlaze6 6936 25600GB 2.5\" U.3(0x1C5F-0x4B61)"},
{0x1C5F, 0x003F, 0xFFFF, 0xFFFF, "PBlaze7 7940/7946 NVMe SSD(0x003F)"},
{0x1C5F, 0x003F, 0x1C5F, 0x0431, "NVMe SSD PBlaze7 7940 3840G 2.5\" U.2(0x1C5F-0x0431)"},
{0x1C5F, 0x003F, 0x1C5F, 0x0C31, "NVMe SSD PBlaze7 7940 3840G 2.5\" U.2(0x1C5F-0x0C31)"},
{0x1C5F, 0x003F, 0x1C5F, 0x0C41, "NVMe SSD PBlaze7 7940 7680G 2.5\" U.2(0x1C5F-0x0C41)"},
{0x1C5F, 0x003F, 0x1C5F, 0x0C51, "NVMe SSD PBlaze7 7940 15360G 2.5\" U.2(0x1C5F-0x0C51)"},
{0x1C5F, 0x003F, 0x1C5F, 0x1430, "NVMe SSD PBlaze7 7940 3840G AIC(0x1C5F-0x1430)"},
{0x1C5F, 0x003F, 0x1C5F, 0x1431, "NVMe SSD PBlaze7 7940 3840G 2.5\" U.2(0x1C5F-0x1431)"},
{0x1C5F, 0x003F, 0x1C5F, 0x1435, "NVMe SSD PBlaze7 7940 3840G E1.S(0x1C5F-0x1435)"},
{0x1C5F, 0x003F, 0x1C5F, 0x1440, "NVMe SSD PBlaze7 7940 7680G AIC(0x1C5F-0x1440)"},
{0x1C5F, 0x003F, 0x1C5F, 0x1441, "NVMe SSD PBlaze7 7940 7680G 2.5\" U.2(0x1C5F-0x1441)"},
{0x1C5F, 0x003F, 0x1C5F, 0x1445, "NVMe SSD PBlaze7 7940 7680G E1.S(0x1C5F-0x1445)"},
{0x1C5F, 0x003F, 0x1C5F, 0x1450, "NVMe SSD PBlaze7 7940 15360G AIC(0x1C5F-0x1450)"},
{0x1C5F, 0x003F, 0x1C5F, 0x1451, "NVMe SSD PBlaze7 7940 15360G 2.5\" U.2(0x1C5F-0x1451)"},
{0x1C5F, 0x003F, 0x1C5F, 0x4C31, "NVMe SSD PBlaze7 7946 3200G 2.5\" U.2(0x1C5F-0x4C31)"},
{0x1C5F, 0x003F, 0x1C5F, 0x4C41, "NVMe SSD PBlaze7 7946 6400G 2.5\" U.2(0x1C5F-0x4C41)"},
{0x1C5F, 0x003F, 0x1C5F, 0x4C51, "NVMe SSD PBlaze7 7946 12800G 2.5\" U.2(0x1C5F-0x4C51)"},
{0x1C5F, 0x003F, 0x1C5F, 0x5430, "NVMe SSD PBlaze7 7946 3200G AIC(0x1C5F-0x5430)"},
{0x1C5F, 0x003F, 0x1C5F, 0x5431, "NVMe SSD PBlaze7 7946 3200G 2.5\" U.2(0x1C5F-0x5431)"},
{0x1C5F, 0x003F, 0x1C5F, 0x5435, "NVMe SSD PBlaze7 7946 3200G E1.S(0x1C5F-0x5435)"},
{0x1C5F, 0x003F, 0x1C5F, 0x5440, "NVMe SSD PBlaze7 7946 6400G AIC(0x1C5F-0x5440)"},
{0x1C5F, 0x003F, 0x1C5F, 0x5441, "NVMe SSD PBlaze7 7946 6400G 2.5\" U.2(0x1C5F-0x5441)"},
{0x1C5F, 0x003F, 0x1C5F, 0x5445, "NVMe SSD PBlaze7 7946 6400G E1.S(0x1C5F-0x5445)"},
{0x1C5F, 0x003F, 0x1C5F, 0x5450, "NVMe SSD PBlaze7 7946 12800G AIC(0x1C5F-0x5450)"},
{0x1C5F, 0x003F, 0x1C5F, 0x5451, "NVMe SSD PBlaze7 7946 12800G 2.5\" U.2(0x1C5F-0x5451)"},
{0x1C5F, 0x003F, 0x1EA0, 0x2100, "TP2510 Series U.2 NVMe Datacenter SSD(3.84TB)(0x1EA0-0x2100)"},
{0x1C5F, 0x003F, 0x1EA0, 0x2101, "TP2511 Series U.2 NVMe Datacenter SSD(3.84TB)(0x1EA0-0x2101)"},
{0x1C5F, 0x003F, 0x1EA0, 0x2110, "TP2510 Series E3.S NVMe Datacenter SSD(3.84TB)(0x1EA0-0x2110)"},
{0x1C5F, 0x003F, 0x1EA0, 0x2111, "TP2511 Series E3.S NVMe Datacenter SSD(3.84TB)(0x1EA0-0x2111)"},
{0x1C5F, 0x003F, 0x1EA0, 0x2200, "TP2510 Series U.2 NVMe Datacenter SSD(7.68TB)(0x1EA0-0x2200)"},
{0x1C5F, 0x003F, 0x1EA0, 0x2201, "TP2511 Series U.2 NVMe Datacenter SSD(7.68TB)(0x1EA0-0x2201)"},
{0x1C5F, 0x003F, 0x1EA0, 0x2210, "TP2510 Series E3.S NVMe Datacenter SSD(7.68TB)(0x1EA0-0x2210)"},
{0x1C5F, 0x003F, 0x1EA0, 0x2211, "TP2511 Series E3.S NVMe Datacenter SSD(7.68TB)(0x1EA0-0x2211)"},
{0x1C5F, 0x0540, 0xFFFF, 0xFFFF, "PBlaze4 NVMe SSD(0x0540)"},
{0x1C5F, 0x0550, 0xFFFF, 0xFFFF, "PBlaze5 700/900(0x0550)"},
{0x1C5F, 0x0555, 0xFFFF, 0xFFFF, "PBlaze5 510/516(0x0555)"},
{0x1C5F, 0x0557, 0xFFFF, 0xFFFF, "PBlaze5 910/916(0x0557)"},
}; /* pci_vid_1C5F[] */

static pci_id_t const pci_vid_1C63[] = {
{0x1C63, 0xFFFF, 0xFFFF, 0xFFFF, "Science and Research Centre of Computer Technology (JSC \"NICEVT\")(0x1C63)"},
{0x1C63, 0x0008, 0xFFFF, 0xFFFF, "K1927BB1Ya [EC8430] Angara Interconnection Network Adapter(0x0008)"},
}; /* pci_vid_1C63[] */

static pci_id_t const pci_vid_1C7E[] = {
{0x1C7E, 0xFFFF, 0xFFFF, 0xFFFF, "TTTech Computertechnik AG(0x1C7E)"},
{0x1C7E, 0x0200, 0xFFFF, 0xFFFF, "zFAS Debug Port(0x0200)"},
}; /* pci_vid_1C7E[] */

static pci_id_t const pci_vid_1C7F[] = {
{0x1C7F, 0xFFFF, 0xFFFF, 0xFFFF, "Elektrobit Austria GmbH(0x1C7F)"},
{0x1C7F, 0x5100, 0xFFFF, 0xFFFF, "EB5100(0x5100)"},
}; /* pci_vid_1C7F[] */

static pci_id_t const pci_vid_1C8A[] = {
{0x1C8A, 0xFFFF, 0xFFFF, 0xFFFF, "TSF5 Corporation(0x1C8A)"},
{0x1C8A, 0x0001, 0xFFFF, 0xFFFF, "Hunter PCI Express(0x0001)"},
}; /* pci_vid_1C8A[] */

static pci_id_t const pci_vid_1C8C[] = {
{0x1C8C, 0xFFFF, 0xFFFF, 0xFFFF, "Mobiveil, Inc.(0x1C8C)"},
}; /* pci_vid_1C8C[] */

static pci_id_t const pci_vid_1CB0[] = {
{0x1CB0, 0xFFFF, 0xFFFF, 0xFFFF, "Shannon Systems(0x1CB0)"},
{0x1CB0, 0x8266, 0xFFFF, 0xFFFF, "SP4 Series SSD(0x8266)"},
{0x1CB0, 0x8266, 0x1CB0, 0x2021, "SP4 Series OCS U.2 SSD(0x1CB0-0x2021)"},
{0x1CB0, 0x8266, 0x1CB0, 0x2121, "SP4 Series ZNS U.2 SSD(0x1CB0-0x2121)"},
{0x1CB0, 0x8266, 0x1CB0, 0x2F21, "SP4E Series NVMe U.2 SSD(1920/3840/7680GB)(0x1CB0-0x2F21)"},
{0x1CB0, 0x8266, 0x1CB0, 0x2F22, "SP4X Series NVMe U.2 SSD(1600/3200/6400GB)(0x1CB0-0x2F22)"},
{0x1CB0, 0xD000, 0xFFFF, 0xFFFF, "Venice NVMe SSD(0xD000)"},
{0x1CB0, 0xD000, 0x1CB0, 0x2010, "Venice-E Series OCS U.2(0x1CB0-0x2010)"},
{0x1CB0, 0xD000, 0x1CB0, 0x2011, "Venice Series OCS U.2(0x1CB0-0x2011)"},
{0x1CB0, 0xD000, 0x1CB0, 0x2012, "Venice-X Series OCS U.2(0x1CB0-0x2012)"},
{0x1CB0, 0xD000, 0x1CB0, 0x2F10, "Venice-E Series NVMe U.2(0x1CB0-0x2F10)"},
{0x1CB0, 0xD000, 0x1CB0, 0x2F11, "Venice Series NVMe U.2(0x1CB0-0x2F11)"},
{0x1CB0, 0xD000, 0x1CB0, 0x2F12, "Venice-X Series NVMe U.2(0x1CB0-0x2F12)"},
{0x1CB0, 0xD000, 0x1CB0, 0xA010, "Venice-E Series OCS AIC(0x1CB0-0xA010)"},
{0x1CB0, 0xD000, 0x1CB0, 0xA012, "Venice-X Series OCS AIC(0x1CB0-0xA012)"},
{0x1CB0, 0xD000, 0x1CB0, 0xAF10, "Venice-E Series NVMe AIC(0x1CB0-0xAF10)"},
{0x1CB0, 0xD000, 0x1CB0, 0xAF12, "Venice-X Series NVMe AIC(0x1CB0-0xAF12)"},
}; /* pci_vid_1CB0[] */

static pci_id_t const pci_vid_1CB1[] = {
{0x1CB1, 0xFFFF, 0xFFFF, 0xFFFF, "Collion UG & Co.KG(0x1CB1)"},
}; /* pci_vid_1CB1[] */

static pci_id_t const pci_vid_1CB5[] = {
{0x1CB5, 0xFFFF, 0xFFFF, 0xFFFF, "Focusrite Audio Engineering Ltd(0x1CB5)"},
{0x1CB5, 0x0002, 0xFFFF, 0xFFFF, "Clarett(0x0002)"},
}; /* pci_vid_1CB5[] */

static pci_id_t const pci_vid_1CB8[] = {
{0x1CB8, 0xFFFF, 0xFFFF, 0xFFFF, "Dawning Information Industry Co., Ltd.(0x1CB8)"},
}; /* pci_vid_1CB8[] */

static pci_id_t const pci_vid_1CC1[] = {
{0x1CC1, 0xFFFF, 0xFFFF, 0xFFFF, "ADATA Technology Co., Ltd.(0x1CC1)"},
{0x1CC1, 0x1202, 0xFFFF, 0xFFFF, "IM2P32A8 NVMe SSD (DRAM-less)(0x1202)"},
{0x1CC1, 0x2263, 0xFFFF, 0xFFFF, "XPG SX6000 Lite NVMe SSD (DRAM-less)(0x2263)"},
{0x1CC1, 0x32A8, 0xFFFF, 0xFFFF, "SM2P32A8 NVMe SSD (DRAM-less)(0x32A8)"},
{0x1CC1, 0x33F3, 0xFFFF, 0xFFFF, "IM2P33F3 NVMe SSD (DRAM-less)(0x33F3)"},
{0x1CC1, 0x33F4, 0xFFFF, 0xFFFF, "IM2P33F4 NVMe SSD (DRAM-less)(0x33F4)"},
{0x1CC1, 0x33F8, 0xFFFF, 0xFFFF, "IM2P33F8 series NVMe SSD (DRAM-less)(0x33F8)"},
{0x1CC1, 0x41C3, 0xFFFF, 0xFFFF, "SM2P41C3 NVMe SSD (DRAM-less)(0x41C3)"},
{0x1CC1, 0x41C8, 0xFFFF, 0xFFFF, "SM2P41C8 NVMe SSD (DRAM-less)(0x41C8)"},
{0x1CC1, 0x5236, 0xFFFF, 0xFFFF, "XPG GAMMIX S70 BLADE NVMe SSD(0x5236)"},
{0x1CC1, 0x5350, 0xFFFF, 0xFFFF, "XPG GAMMIX S50, S50 Lite NVMe SSD(0x5350)"},
{0x1CC1, 0x5370, 0xFFFF, 0xFFFF, "GAMMIX S70 BLADE, PS5 PREMIUM NVMe SSD(0x5370)"},
{0x1CC1, 0x5762, 0xFFFF, 0xFFFF, "FALCON, GAMMIX S41, SPECTRIX S40G NVMe SSD (DRAM-less)(0x5762)"},
{0x1CC1, 0x5763, 0xFFFF, 0xFFFF, "XPG GAMMIX S5 NVMe SSD (DRAM-less)(0x5763)"},
{0x1CC1, 0x5766, 0xFFFF, 0xFFFF, "XPG GAMMIXS1 1L, XPG GAMMIX S5, LEGEND 710 / 740, SWORDFISH NVMe SSD (DRAM-less)(0x5766)"},
{0x1CC1, 0x5772, 0xFFFF, 0xFFFF, "LEGEND 850 LITE NVMe SSD (DRAM-less)(0x5772)"},
{0x1CC1, 0x612A, 0xFFFF, 0xFFFF, "LEGEND 750 NVMe SSD (DRAM-less)(0x612A)"},
{0x1CC1, 0x613A, 0xFFFF, 0xFFFF, "ATOM 50, LEGEND 840 NVMe SSD (DRAM-less)(0x613A)"},
{0x1CC1, 0x621A, 0xFFFF, 0xFFFF, "LEGEND 850 NVMe SSD (DRAM-less)(0x621A)"},
{0x1CC1, 0x622A, 0xFFFF, 0xFFFF, "LEGEND 960 NVMe SSD(0x622A)"},
{0x1CC1, 0x624A, 0xFFFF, 0xFFFF, "LEGEND 700, XPG GAMMIX S20 NVMe SSD (DRAM-less)(0x624A)"},
{0x1CC1, 0x627A, 0xFFFF, 0xFFFF, "LEGEND 800 NVMe SSD (DRAM-less)(0x627A)"},
{0x1CC1, 0x628A, 0xFFFF, 0xFFFF, "LEGEND 800 NVMe SSD (DRAM-less)(0x628A)"},
{0x1CC1, 0x8201, 0xFFFF, 0xFFFF, "XPG SX8200 Pro PCIe Gen3x4 M.2 2280 Solid State Drive(0x8201)"},
}; /* pci_vid_1CC1[] */

static pci_id_t const pci_vid_1CC4[] = {
{0x1CC4, 0xFFFF, 0xFFFF, 0xFFFF, "Shenzhen Unionmemory Information System Ltd.(0x1CC4)"},
{0x1CC4, 0x1203, 0xFFFF, 0xFFFF, "NVMe SSD Controller UHXXXa series(0x1203)"},
{0x1CC4, 0x1203, 0x1CC4, 0xA121, "NVMe SSD UHXXXa series U.2 960GB(0x1CC4-0xA121)"},
{0x1CC4, 0x1203, 0x1CC4, 0xA122, "NVMe SSD UHXXXa series U.2 1920GB(0x1CC4-0xA122)"},
{0x1CC4, 0x1203, 0x1CC4, 0xA123, "NVMe SSD UHXXXa series U.2 3840GB(0x1CC4-0xA123)"},
{0x1CC4, 0x1203, 0x1CC4, 0xA124, "NVMe SSD UHXXXa series U.2 7680GB(0x1CC4-0xA124)"},
{0x1CC4, 0x1203, 0x1CC4, 0xA125, "NVMe SSD UHXXXa series U.2 15360GB(0x1CC4-0xA125)"},
{0x1CC4, 0x1203, 0x1CC4, 0xA211, "NVMe SSD UHXXXa series U.2 800GB(0x1CC4-0xA211)"},
{0x1CC4, 0x1203, 0x1CC4, 0xA212, "NVMe SSD UHXXXa series U.2 1600GB(0x1CC4-0xA212)"},
{0x1CC4, 0x1203, 0x1CC4, 0xA213, "NVMe SSD UHXXXa series U.2 3200GB(0x1CC4-0xA213)"},
{0x1CC4, 0x1203, 0x1CC4, 0xA214, "NVMe SSD UHXXXa series U.2 6400GB(0x1CC4-0xA214)"},
{0x1CC4, 0x1203, 0x1CC4, 0xE122, "NVMe SSD UH711a series U.2 1920GB(0x1CC4-0xE122)"},
{0x1CC4, 0x1203, 0x1CC4, 0xE123, "NVMe SSD UH711a series U.2 3840GB(0x1CC4-0xE123)"},
{0x1CC4, 0x1203, 0x1CC4, 0xE124, "NVMe SSD UH711a series U.2 7680GB(0x1CC4-0xE124)"},
{0x1CC4, 0x17A9, 0xFFFF, 0xFFFF, "RPITJ1TBVME2HWD NVMe SSD 1024GB(0x17A9)"},
{0x1CC4, 0x17AA, 0xFFFF, 0xFFFF, "AH631 PCIe 3.0 NVMe SSD 512GB(0x17AA)"},
{0x1CC4, 0x17AB, 0xFFFF, 0xFFFF, "AH631 PCIe 3.0 NVMe SSD 256GB(0x17AB)"},
{0x1CC4, 0x2263, 0xFFFF, 0xFFFF, "AM611 PCIe 3.0 x2 NVMe SSD 256GB(0x2263)"},
{0x1CC4, 0x5008, 0xFFFF, 0xFFFF, "AM610 PCIe 3.0 x2 NVMe SSD 128GB, 256GB(0x5008)"},
{0x1CC4, 0x5012, 0xFFFF, 0xFFFF, "RPITJ512PED2OWX NVMe SSD 512GB(0x5012)"},
{0x1CC4, 0x5212, 0xFFFF, 0xFFFF, "AM521 PCIe 3.0 NVMe SSD 256GB(0x5212)"},
{0x1CC4, 0x6201, 0xFFFF, 0xFFFF, "AM620 PCIe 3.0 NVMe SSD 128GB(0x6201)"},
{0x1CC4, 0x6202, 0xFFFF, 0xFFFF, "AM620 PCIe 3.0 NVMe SSD 256GB(0x6202)"},
{0x1CC4, 0x6203, 0xFFFF, 0xFFFF, "AM620 PCIe 3.0 NVMe SSD 512GB(0x6203)"},
{0x1CC4, 0x6204, 0xFFFF, 0xFFFF, "AM620 PCIe 3.0 NVMe SSD 1024GB(0x6204)"},
{0x1CC4, 0x6302, 0xFFFF, 0xFFFF, "AM630 PCIe 4.0 NVMe SSD 256GB(0x6302)"},
{0x1CC4, 0x6303, 0xFFFF, 0xFFFF, "AM630 PCIe 4.0 x4 NVMe SSD Controller(0x6303)"},
{0x1CC4, 0x6304, 0xFFFF, 0xFFFF, "AM630 PCIe 4.0 NVMe SSD 1024GB(0x6304)"},
{0x1CC4, 0x6A02, 0xFFFF, 0xFFFF, "AM6A0 PCIe 4.0 NVMe SSD 256GB(0x6A02)"},
{0x1CC4, 0x6A03, 0xFFFF, 0xFFFF, "RPETJ512MKP1QDQ PCIe 4.0 NVMe SSD 512GB (DRAM-less)(0x6A03)"},
{0x1CC4, 0x6A13, 0xFFFF, 0xFFFF, "RPJYJ512MKN1QWQ PCIe 4.0 NVMe SSD 512GB (DRAM-less)(0x6A13)"},
{0x1CC4, 0x6A14, 0xFFFF, 0xFFFF, "RPEYJ1T24MKN2QWY PCIe 4.0 NVMe SSD 1024GB (DRAM-less)(0x6A14)"},
{0x1CC4, 0x8030, 0xFFFF, 0xFFFF, "NVMe SSD Controller UH8X2X/UH7X2X series(0x8030)"},
{0x1CC4, 0x8030, 0x1CC4, 0x1122, "NVMe SSD UH812a U.2 1.92TB(0x1CC4-0x1122)"},
{0x1CC4, 0x8030, 0x1CC4, 0x1123, "NVMe SSD UH812a U.2 3.84TB(0x1CC4-0x1123)"},
{0x1CC4, 0x8030, 0x1CC4, 0x1124, "NVMe SSD UH812a U.2 7.68TB(0x1CC4-0x1124)"},
{0x1CC4, 0x8030, 0x1CC4, 0x1125, "NVMe SSD UH812a U.2 15.36TB(0x1CC4-0x1125)"},
{0x1CC4, 0x8030, 0x1CC4, 0x1222, "NVMe SSD UH812a E3.S 1.92TB(0x1CC4-0x1222)"},
{0x1CC4, 0x8030, 0x1CC4, 0x1223, "NVMe SSD UH812a E3.S 3.84TB(0x1CC4-0x1223)"},
{0x1CC4, 0x8030, 0x1CC4, 0x1224, "NVMe SSD UH812a E3.S 7.68TB(0x1CC4-0x1224)"},
{0x1CC4, 0x8030, 0x1CC4, 0x1225, "NVMe SSD UH812a E3.S 15.36TB(0x1CC4-0x1225)"},
{0x1CC4, 0x8030, 0x1CC4, 0x2112, "NVMe SSD UH832a U.2 1.6TB(0x1CC4-0x2112)"},
{0x1CC4, 0x8030, 0x1CC4, 0x2113, "NVMe SSD UH832a U.2 3.2TB(0x1CC4-0x2113)"},
{0x1CC4, 0x8030, 0x1CC4, 0x2114, "NVMe SSD UH832a U.2 6.4TB(0x1CC4-0x2114)"},
{0x1CC4, 0x8030, 0x1CC4, 0x2115, "NVMe SSD UH832a U.2 12.8TB(0x1CC4-0x2115)"},
{0x1CC4, 0x8030, 0x1CC4, 0x2212, "NVMe SSD UH832a E3.S 1.6TB(0x1CC4-0x2212)"},
{0x1CC4, 0x8030, 0x1CC4, 0x2213, "NVMe SSD UH832a E3.S 3.2TB(0x1CC4-0x2213)"},
{0x1CC4, 0x8030, 0x1CC4, 0x2214, "NVMe SSD UH832a E3.S 6.4TB(0x1CC4-0x2214)"},
{0x1CC4, 0x8030, 0x1CC4, 0x2215, "NVMe SSD UH832a E3.S 12.8TB(0x1CC4-0x2215)"},
{0x1CC4, 0x8030, 0x1CC4, 0x3122, "NVMe SSD UH712a U.2 1.92TB(0x1CC4-0x3122)"},
{0x1CC4, 0x8030, 0x1CC4, 0x3123, "NVMe SSD UH712a U.2 3.84TB(0x1CC4-0x3123)"},
{0x1CC4, 0x8030, 0x1CC4, 0x3124, "NVMe SSD UH712a U.2 7.68TB(0x1CC4-0x3124)"},
{0x1CC4, 0x8030, 0x1CC4, 0x3125, "NVMe SSD UH712a U.2 15.36TB(0x1CC4-0x3125)"},
}; /* pci_vid_1CC4[] */

static pci_id_t const pci_vid_1CC5[] = {
{0x1CC5, 0xFFFF, 0xFFFF, 0xFFFF, "Embedded Intelligence, Inc.(0x1CC5)"},
{0x1CC5, 0x0100, 0xFFFF, 0xFFFF, "PCIe-CAN-02 Dual CAN bus (9-pin male). PCI Express x1.(0x0100)"},
{0x1CC5, 0x0101, 0xFFFF, 0xFFFF, "PCIe-CAN-01 Single CAN bus (9-pin male). PCI Express x1.(0x0101)"},
}; /* pci_vid_1CC5[] */

static pci_id_t const pci_vid_1CC7[] = {
{0x1CC7, 0xFFFF, 0xFFFF, 0xFFFF, "Radian Memory Systems Inc.(0x1CC7)"},
{0x1CC7, 0x0200, 0xFFFF, 0xFFFF, "RMS-200 PCIe NVMe SSD(0x0200)"},
{0x1CC7, 0x0250, 0xFFFF, 0xFFFF, "RMS-250 U.2 NVMe SSD(0x0250)"},
}; /* pci_vid_1CC7[] */

static pci_id_t const pci_vid_1CCF[] = {
{0x1CCF, 0xFFFF, 0xFFFF, 0xFFFF, "Zoom Corporation(0x1CCF)"},
{0x1CCF, 0x0001, 0xFFFF, 0xFFFF, "TAC-2 Thunderbolt Audio Converter(0x0001)"},
}; /* pci_vid_1CCF[] */

static pci_id_t const pci_vid_1CD2[] = {
{0x1CD2, 0xFFFF, 0xFFFF, 0xFFFF, "SesKion GmbH(0x1CD2)"},
{0x1CD2, 0x0301, 0xFFFF, 0xFFFF, "Simulyzer-RT CompactPCI Serial DIO-1 card(0x0301)"},
{0x1CD2, 0x0302, 0xFFFF, 0xFFFF, "Simulyzer-RT CompactPCI Serial PSI5-ECU-1 card(0x0302)"},
{0x1CD2, 0x0303, 0xFFFF, 0xFFFF, "Simulyzer-RT CompactPCI Serial PSI5-SIM-1 card(0x0303)"},
{0x1CD2, 0x0304, 0xFFFF, 0xFFFF, "Simulyzer-RT CompactPCI Serial PWR-ANA-1 card(0x0304)"},
{0x1CD2, 0x0305, 0xFFFF, 0xFFFF, "Simulyzer-RT CompactPCI Serial CAN-1 card(0x0305)"},
{0x1CD2, 0x0306, 0xFFFF, 0xFFFF, "Simulyzer-RT CompactPCI Serial CAN-2 card (CAN-FD)(0x0306)"},
{0x1CD2, 0x0307, 0xFFFF, 0xFFFF, "Simulyzer-RT CompactPCI Serial DIO-2 card [Xilinx Zynq UltraScale+](0x0307)"},
}; /* pci_vid_1CD2[] */

static pci_id_t const pci_vid_1CD7[] = {
{0x1CD7, 0xFFFF, 0xFFFF, 0xFFFF, "Nanjing Magewell Electronics Co., Ltd.(0x1CD7)"},
{0x1CD7, 0x0002, 0xFFFF, 0xFFFF, "Pro Capture AIO(0x0002)"},
{0x1CD7, 0x0010, 0xFFFF, 0xFFFF, "Pro Capture Endpoint(0x0010)"},
{0x1CD7, 0x0014, 0xFFFF, 0xFFFF, "PRO CAPTURE AIO 4K PLUS(0x0014)"},
{0x1CD7, 0x0017, 0xFFFF, 0xFFFF, "PRO CAPTURE AIO 4K(0x0017)"},
{0x1CD7, 0x0051, 0xFFFF, 0xFFFF, "Eco Capture Dual HDMI M.2(0x0051)"},
{0x1CD7, 0x0052, 0xFFFF, 0xFFFF, "Eco Capture HDMI 4K M.2(0x0052)"},
{0x1CD7, 0x0053, 0xFFFF, 0xFFFF, "Eco Capture Dual SDI M.2(0x0053)"},
{0x1CD7, 0x0054, 0xFFFF, 0xFFFF, "Eco Capture Quad SDI M.2(0x0054)"},
}; /* pci_vid_1CD7[] */

static pci_id_t const pci_vid_1CDD[] = {
{0x1CDD, 0xFFFF, 0xFFFF, 0xFFFF, "secunet Security Networks AG(0x1CDD)"},
}; /* pci_vid_1CDD[] */

static pci_id_t const pci_vid_1CE4[] = {
{0x1CE4, 0xFFFF, 0xFFFF, 0xFFFF, "Exablaze(0x1CE4)"},
{0x1CE4, 0x0001, 0xFFFF, 0xFFFF, "ExaNIC X4(0x0001)"},
{0x1CE4, 0x0002, 0xFFFF, 0xFFFF, "ExaNIC X2(0x0002)"},
{0x1CE4, 0x0003, 0xFFFF, 0xFFFF, "ExaNIC X10(0x0003)"},
{0x1CE4, 0x0004, 0xFFFF, 0xFFFF, "ExaNIC X10-GM(0x0004)"},
{0x1CE4, 0x0005, 0xFFFF, 0xFFFF, "ExaNIC X40(0x0005)"},
{0x1CE4, 0x0006, 0xFFFF, 0xFFFF, "ExaNIC X10-HPT(0x0006)"},
{0x1CE4, 0x0007, 0xFFFF, 0xFFFF, "ExaNIC X40(0x0007)"},
{0x1CE4, 0x0008, 0xFFFF, 0xFFFF, "ExaNIC V5P(0x0008)"},
{0x1CE4, 0x0009, 0xFFFF, 0xFFFF, "ExaNIC X25(0x0009)"},
{0x1CE4, 0x000A, 0xFFFF, 0xFFFF, "ExaNIC X100(0x000A)"},
{0x1CE4, 0x000B, 0xFFFF, 0xFFFF, "ExaNIC V9P(0x000B)"},
{0x1CE4, 0x000C, 0xFFFF, 0xFFFF, "ExaNIC V9P-3(0x000C)"},
{0x1CE4, 0x0100, 0xFFFF, 0xFFFF, "ExaDISK FX1(0x0100)"},
}; /* pci_vid_1CE4[] */

static pci_id_t const pci_vid_1CF0[] = {
{0x1CF0, 0xFFFF, 0xFFFF, 0xFFFF, "Akitio(0x1CF0)"},
}; /* pci_vid_1CF0[] */

static pci_id_t const pci_vid_1CF7[] = {
{0x1CF7, 0xFFFF, 0xFFFF, 0xFFFF, "Subspace Dynamics(0x1CF7)"},
}; /* pci_vid_1CF7[] */

static pci_id_t const pci_vid_1CFA[] = {
{0x1CFA, 0xFFFF, 0xFFFF, 0xFFFF, "Corsair Memory, Inc(0x1CFA)"},
}; /* pci_vid_1CFA[] */

static pci_id_t const pci_vid_1CFD[] = {
{0x1CFD, 0xFFFF, 0xFFFF, 0xFFFF, "Mangstor(0x1CFD)"},
{0x1CFD, 0x6300, 0xFFFF, 0xFFFF, "MX6300 series PCIe x8 NVMe SSD(0x6300)"},
}; /* pci_vid_1CFD[] */

static pci_id_t const pci_vid_1D00[] = {
{0x1D00, 0xFFFF, 0xFFFF, 0xFFFF, "Pure Storage(0x1D00)"},
}; /* pci_vid_1D00[] */

static pci_id_t const pci_vid_1D05[] = {
{0x1D05, 0xFFFF, 0xFFFF, 0xFFFF, "Tongfang Hongkong Limited(0x1D05)"},
}; /* pci_vid_1D05[] */

static pci_id_t const pci_vid_1D0F[] = {
{0x1D0F, 0xFFFF, 0xFFFF, 0xFFFF, "Amazon.com, Inc.(0x1D0F)"},
{0x1D0F, 0x7064, 0xFFFF, 0xFFFF, "NeuronDevice (Inferentia)(0x7064)"},
{0x1D0F, 0x7164, 0xFFFF, 0xFFFF, "NeuronDevice (Trainium)(0x7164)"},
{0x1D0F, 0x7164, 0x1D0F, 0x0000, "Trainium(0x1D0F-0x0000)"},
{0x1D0F, 0x7264, 0xFFFF, 0xFFFF, "NeuronDevice (Inferentia2)(0x7264)"},
{0x1D0F, 0x7364, 0xFFFF, 0xFFFF, "NeuronDevice (Trainium2)(0x7364)"},
{0x1D0F, 0x8061, 0xFFFF, 0xFFFF, "NVMe EBS Controller(0x8061)"},
{0x1D0F, 0xCD01, 0xFFFF, 0xFFFF, "NVMe SSD Controller(0xCD01)"},
{0x1D0F, 0xEC20, 0xFFFF, 0xFFFF, "Elastic Network Adapter (ENA)(0xEC20)"},
{0x1D0F, 0xEFA0, 0xFFFF, 0xFFFF, "Elastic Fabric Adapter (EFA)(0xEFA0)"},
{0x1D0F, 0xEFA1, 0xFFFF, 0xFFFF, "Elastic Fabric Adapter (EFA)(0xEFA1)"},
{0x1D0F, 0xEFA2, 0xFFFF, 0xFFFF, "Elastic Fabric Adapter (EFA)(0xEFA2)"},
}; /* pci_vid_1D0F[] */

static pci_id_t const pci_vid_1D17[] = {
{0x1D17, 0xFFFF, 0xFFFF, 0xFFFF, "Zhaoxin(0x1D17)"},
{0x1D17, 0x070F, 0xFFFF, 0xFFFF, "ZX-100 PCI Express Root Port(0x070F)"},
{0x1D17, 0x0710, 0xFFFF, 0xFFFF, "ZX-100/ZX-200 PCI Express Root Port(0x0710)"},
{0x1D17, 0x0711, 0xFFFF, 0xFFFF, "ZX-100/ZX-200 PCI Express Root Port(0x0711)"},
{0x1D17, 0x0712, 0xFFFF, 0xFFFF, "ZX-100/ZX-200 PCI Express Root Port(0x0712)"},
{0x1D17, 0x0713, 0xFFFF, 0xFFFF, "ZX-100/ZX-200 PCI Express Root Port(0x0713)"},
{0x1D17, 0x0714, 0xFFFF, 0xFFFF, "ZX-100/ZX-200 PCI Express Root Port(0x0714)"},
{0x1D17, 0x0715, 0xFFFF, 0xFFFF, "ZX-100/ZX-200 PCI Express Root Port(0x0715)"},
{0x1D17, 0x0716, 0xFFFF, 0xFFFF, "ZX-D PCI Express Root Port(0x0716)"},
{0x1D17, 0x0717, 0xFFFF, 0xFFFF, "KX-5000/KX-6000/KX-6000G/KH-40000/KX-7000 PCI Express Root Port(0x0717)"},
{0x1D17, 0x0718, 0xFFFF, 0xFFFF, "KX-5000/KX-6000/KX-6000G/KH-40000/KX-7000 PCI Express Root Port(0x0718)"},
{0x1D17, 0x0719, 0xFFFF, 0xFFFF, "KX-5000/KX-6000/KX-6000G/KH-40000/KX-7000 PCI Express Root Port(0x0719)"},
{0x1D17, 0x071A, 0xFFFF, 0xFFFF, "KX-5000/KX-6000/KX-6000G/KH-40000 PCI Express Root Port(0x071A)"},
{0x1D17, 0x071B, 0xFFFF, 0xFFFF, "KX-5000/KX-6000/KX-6000G/KH-40000/KX-7000 PCI Express Root Port(0x071B)"},
{0x1D17, 0x071C, 0xFFFF, 0xFFFF, "KX-5000/KX-6000/KX-6000G/KH-40000/KX-7000 PCI Express Root Port(0x071C)"},
{0x1D17, 0x071D, 0xFFFF, 0xFFFF, "KX-5000/KX-6000/KX-6000G/KH-40000/KX-7000 PCI Express Root Port(0x071D)"},
{0x1D17, 0x071E, 0xFFFF, 0xFFFF, "KX-5000/KX-6000/KX-6000G/KH-40000/KX-7000 PCI Express Root Port(0x071E)"},
{0x1D17, 0x071F, 0xFFFF, 0xFFFF, "ZX-200 Upstream Port of PCI Express Switch(0x071F)"},
{0x1D17, 0x0720, 0xFFFF, 0xFFFF, "ZX-200 PCIE RC6 controller(0x0720)"},
{0x1D17, 0x0721, 0xFFFF, 0xFFFF, "ZX-200 Downstream Port of PCI Express Switch(0x0721)"},
{0x1D17, 0x0722, 0xFFFF, 0xFFFF, "ZX-200 PCIE P2C bridge(0x0722)"},
{0x1D17, 0x0731, 0xFFFF, 0xFFFF, "KH-40000 PCI Express Root Port(0x0731)"},
{0x1D17, 0x0732, 0xFFFF, 0xFFFF, "KH-40000/KX-7000 PCI Express Root Port(0x0732)"},
{0x1D17, 0x0733, 0xFFFF, 0xFFFF, "KX-7000 PCIE Express Root Port(0x0733)"},
{0x1D17, 0x0734, 0xFFFF, 0xFFFF, "KX-7000 PCIE Express Root Port(0x0734)"},
{0x1D17, 0x0735, 0xFFFF, 0xFFFF, "KX-7000 PCIE Express Root Port(0x0735)"},
{0x1D17, 0x0736, 0xFFFF, 0xFFFF, "KX-7000 PCIE Express Root Port(0x0736)"},
{0x1D17, 0x0737, 0xFFFF, 0xFFFF, "KX-7000 PCIE Express Root Port(0x0737)"},
{0x1D17, 0x0738, 0xFFFF, 0xFFFF, "KX-7000 PCIE Express Root Port(0x0738)"},
{0x1D17, 0x0739, 0xFFFF, 0xFFFF, "KX-7000 PCIE Express Root Port(0x0739)"},
{0x1D17, 0x073A, 0xFFFF, 0xFFFF, "KX-7000 PCIE Express Root Port(0x073A)"},
{0x1D17, 0x073B, 0xFFFF, 0xFFFF, "KX-7000 PCIE Express Root Port(0x073B)"},
{0x1D17, 0x1000, 0xFFFF, 0xFFFF, "ZX-D Standard Host Bridge(0x1000)"},
{0x1D17, 0x1001, 0xFFFF, 0xFFFF, "ZX-D/ZX-E/KH-40000/KX-7000 Miscellaneous Bus(0x1001)"},
{0x1D17, 0x1003, 0xFFFF, 0xFFFF, "ZX-E Standard Host Bridge(0x1003)"},
{0x1D17, 0x1005, 0xFFFF, 0xFFFF, "KH-40000 Standard Host Bridge(0x1005)"},
{0x1D17, 0x1006, 0xFFFF, 0xFFFF, "KX-6000G Standard Host Bridge(0x1006)"},
{0x1D17, 0x1007, 0xFFFF, 0xFFFF, "KX-7000 Standard Host Bridge(0x1007)"},
{0x1D17, 0x3001, 0xFFFF, 0xFFFF, "ZX-100 Standard Host Bridge(0x3001)"},
{0x1D17, 0x300A, 0xFFFF, 0xFFFF, "ZX-100 Miscellaneous Bus(0x300A)"},
{0x1D17, 0x3038, 0xFFFF, 0xFFFF, "ZX-100/ZX-200/KX-6000/KX-6000G/KH-40000/KX-7000 Standard Universal PCI to USB Host Controller(0x3038)"},
{0x1D17, 0x3104, 0xFFFF, 0xFFFF, "ZX-100/ZX-200/KX-6000/KX-6000G/KH-40000/KX-7000 Standard Enhanced PCI to USB Host Controller(0x3104)"},
{0x1D17, 0x31B0, 0xFFFF, 0xFFFF, "ZX-100/KX-5000/KX-6000/KX-6000G/KH-40000/KX-7000 Standard Host Bridge(0x31B0)"},
{0x1D17, 0x31B1, 0xFFFF, 0xFFFF, "ZX-100/KX-5000/KX-6000/KX-6000G/KH-40000/KX-7000 Standard Host Bridge(0x31B1)"},
{0x1D17, 0x31B2, 0xFFFF, 0xFFFF, "ZX-100/KX-5000/KX-6000/KX-6000G/KH-40000/KX-7000 DRAM Controller(0x31B2)"},
{0x1D17, 0x31B3, 0xFFFF, 0xFFFF, "ZX-100/KX-5000/KX-6000/KX-6000G/KH-40000/KX-7000 Power Management Controller(0x31B3)"},
{0x1D17, 0x31B4, 0xFFFF, 0xFFFF, "ZX-100/KX-5000/KX-6000/KX-6000G/KH-40000/KX-7000 I/O APIC(0x31B4)"},
{0x1D17, 0x31B5, 0xFFFF, 0xFFFF, "ZX-100/KX-5000/KX-6000/KX-6000G/KH-40000/KX-7000 Scratch Device(0x31B5)"},
{0x1D17, 0x31B7, 0xFFFF, 0xFFFF, "ZX-100/KX-5000/KX-6000/KX-6000G/KH-40000/KX-7000 Standard Host Bridge(0x31B7)"},
{0x1D17, 0x31B8, 0xFFFF, 0xFFFF, "ZX-100/ZX-D PCI to PCI Bridge(0x31B8)"},
{0x1D17, 0x3200, 0xFFFF, 0xFFFF, "KX-7000 Host Bridge(0x3200)"},
{0x1D17, 0x3288, 0xFFFF, 0xFFFF, "ZX-100/KX-5000/KX-6000/KX-6000G/KH-40000/KX-7000 High Definition Audio Controller(0x3288)"},
{0x1D17, 0x345B, 0xFFFF, 0xFFFF, "ZX-100/KX-5000/KX-6000/KX-6000G/KH-40000 Miscellaneous Bus(0x345B)"},
{0x1D17, 0x3A02, 0xFFFF, 0xFFFF, "ZX-100 C-320 GPU(0x3A02)"},
{0x1D17, 0x3A03, 0xFFFF, 0xFFFF, "ZX-D C-860 GPU(0x3A03)"},
{0x1D17, 0x3A04, 0xFFFF, 0xFFFF, "KX-6000 C-960 GPU(0x3A04)"},
{0x1D17, 0x3A05, 0xFFFF, 0xFFFF, "KX-7000 C-1190 GPU(0x3A05)"},
{0x1D17, 0x3B01, 0xFFFF, 0xFFFF, "KH-40000 OPI Controller(0x3B01)"},
{0x1D17, 0x3B02, 0xFFFF, 0xFFFF, "KH-40000 OPI Controller(0x3B02)"},
{0x1D17, 0x3B03, 0xFFFF, 0xFFFF, "KH-40000 OPI Controller(0x3B03)"},
{0x1D17, 0x3B04, 0xFFFF, 0xFFFF, "KH-40000 OPI Controller(0x3B04)"},
{0x1D17, 0x3C00, 0xFFFF, 0xFFFF, "KH-40000/KX-7000 DRAM Controller(0x3C00)"},
{0x1D17, 0x3C02, 0xFFFF, 0xFFFF, "KX-6000G DRAM Controller(0x3C02)"},
{0x1D17, 0x3D01, 0xFFFF, 0xFFFF, "KX-6000G C-1080 GPU(0x3D01)"},
{0x1D17, 0x9002, 0xFFFF, 0xFFFF, "ZX-100/ZX-200/KH-40000/KX-7000 EIDE Controller(0x9002)"},
{0x1D17, 0x9003, 0xFFFF, 0xFFFF, "ZX-100/KX-6000/KX-6000G EIDE Controller(0x9003)"},
{0x1D17, 0x9043, 0xFFFF, 0xFFFF, "KX-6000G/KH-40000/KX-7000 RAID Controller(0x9043)"},
{0x1D17, 0x9045, 0xFFFF, 0xFFFF, "ZX-100/ZX-D/ZX-E RAID Accelerator 0(0x9045)"},
{0x1D17, 0x9046, 0xFFFF, 0xFFFF, "ZX-D/ZX-E RAID Accelerator 1(0x9046)"},
{0x1D17, 0x9083, 0xFFFF, 0xFFFF, "ZX-100/ZX-200/KX-6000/KX-6000G/KH-40000/KX-7000 StorX AHCI Controller(0x9083)"},
{0x1D17, 0x9084, 0xFFFF, 0xFFFF, "ZX-100 StorX AHCI Controller(0x9084)"},
{0x1D17, 0x9100, 0xFFFF, 0xFFFF, "ZX-200 Cross bus(0x9100)"},
{0x1D17, 0x9101, 0xFFFF, 0xFFFF, "ZX-200 Traffic Controller(0x9101)"},
{0x1D17, 0x9141, 0xFFFF, 0xFFFF, "ZX-100 High Definition Audio Controller(0x9141)"},
{0x1D17, 0x9142, 0xFFFF, 0xFFFF, "ZX-D High Definition Audio Controller(0x9142)"},
{0x1D17, 0x9144, 0xFFFF, 0xFFFF, "ZX-E High Definition Audio Controller(0x9144)"},
{0x1D17, 0x9145, 0xFFFF, 0xFFFF, "KX-6000G High Definition Audio Controller(0x9145)"},
{0x1D17, 0x9146, 0xFFFF, 0xFFFF, "KX-7000 High Definition Audio Controller(0x9146)"},
{0x1D17, 0x9180, 0xFFFF, 0xFFFF, "ZX-200 Networking Gigabit Ethernet Adapter(0x9180)"},
{0x1D17, 0x91C1, 0xFFFF, 0xFFFF, "KH-40000 ZPI Controller(0x91C1)"},
{0x1D17, 0x91C2, 0xFFFF, 0xFFFF, "KH-40000 ZPI Controller(0x91C2)"},
{0x1D17, 0x9202, 0xFFFF, 0xFFFF, "ZX-100 USB eXtensible Host Controller(0x9202)"},
{0x1D17, 0x9203, 0xFFFF, 0xFFFF, "ZX-200 USB eXtensible Host Controller(0x9203)"},
{0x1D17, 0x9204, 0xFFFF, 0xFFFF, "KX-6000/KX-6000G/KX-7000 USB3 xHCI Host Controller(0x9204)"},
{0x1D17, 0x9205, 0xFFFF, 0xFFFF, "KH-40000 USB eXtensible Host Controller(0x9205)"},
{0x1D17, 0x9206, 0xFFFF, 0xFFFF, "KX-7000 USB4 Contoller(0x9206)"},
{0x1D17, 0x9286, 0xFFFF, 0xFFFF, "ZX-D eMMC Host Controller(0x9286)"},
{0x1D17, 0x9300, 0xFFFF, 0xFFFF, "ZX-100/KX-5000/KX-6000/KX-6000G/KH-40000/KX-7000 eSPI Host Controller(0x9300)"},
{0x1D17, 0x9500, 0xFFFF, 0xFFFF, "KX-7000 I2S Controller(0x9500)"},
{0x1D17, 0x9501, 0xFFFF, 0xFFFF, "KX-7000 I2S Controller(0x9501)"},
{0x1D17, 0x95D0, 0xFFFF, 0xFFFF, "ZX-100 Universal SD Host Controller(0x95D0)"},
{0x1D17, 0xF410, 0xFFFF, 0xFFFF, "ZX-100/KX-5000/KX-6000/KX-6000G/KH-40000/KX-7000 PCI Com Port(0xF410)"},
}; /* pci_vid_1D17[] */

static pci_id_t const pci_vid_1D18[] = {
{0x1D18, 0xFFFF, 0xFFFF, 0xFFFF, "RME(0x1D18)"},
{0x1D18, 0x0001, 0xFFFF, 0xFFFF, "Fireface UFX+(0x0001)"},
}; /* pci_vid_1D18[] */

static pci_id_t const pci_vid_1D1C[] = {
{0x1D1C, 0xFFFF, 0xFFFF, 0xFFFF, "Barefoot Networks, Inc.(0x1D1C)"},
{0x1D1C, 0x0001, 0xFFFF, 0xFFFF, "Tofino 1(0x0001)"},
{0x1D1C, 0x0010, 0xFFFF, 0xFFFF, "Tofino 1(0x0010)"},
{0x1D1C, 0x0100, 0xFFFF, 0xFFFF, "Tofino 2(0x0100)"},
{0x1D1C, 0x0110, 0xFFFF, 0xFFFF, "Tofino 2(0x0110)"},
}; /* pci_vid_1D1C[] */

static pci_id_t const pci_vid_1D1D[] = {
{0x1D1D, 0xFFFF, 0xFFFF, 0xFFFF, "CNEX Labs(0x1D1D)"},
{0x1D1D, 0x1F1F, 0xFFFF, 0xFFFF, "QEMU NVM Express LightNVM Controller(0x1F1F)"},
{0x1D1D, 0x2807, 0xFFFF, 0xFFFF, "8800 series NVMe SSD(0x2807)"},
}; /* pci_vid_1D1D[] */

static pci_id_t const pci_vid_1D21[] = {
{0x1D21, 0xFFFF, 0xFFFF, 0xFFFF, "Allo(0x1D21)"},
}; /* pci_vid_1D21[] */

static pci_id_t const pci_vid_1D22[] = {
{0x1D22, 0xFFFF, 0xFFFF, 0xFFFF, "Baidu Technology(0x1D22)"},
{0x1D22, 0x1380, 0xFFFF, 0xFFFF, "Cloud Storage Device(0x1380)"},
{0x1D22, 0x3684, 0xFFFF, 0xFFFF, "Kunlun AI Accelerator(0x3684)"},
{0x1D22, 0x3685, 0xFFFF, 0xFFFF, "Kunlun2 AI Accelerator [VF](0x3685)"},
}; /* pci_vid_1D22[] */

static pci_id_t const pci_vid_1D26[] = {
{0x1D26, 0xFFFF, 0xFFFF, 0xFFFF, "Kalray Inc.(0x1D26)"},
{0x1D26, 0x0040, 0xFFFF, 0xFFFF, "Turbocard2 Accelerator(0x0040)"},
{0x1D26, 0x0080, 0xFFFF, 0xFFFF, "Open Network Interface Card 80G(0x0080)"},
{0x1D26, 0x00C0, 0xFFFF, 0xFFFF, "Turbocard3 Accelerator(0x00C0)"},
{0x1D26, 0x0140, 0xFFFF, 0xFFFF, "Open Network Interface Card 40G(0x0140)"},
{0x1D26, 0xE004, 0xFFFF, 0xFFFF, "AB01/EMB01 Development Board(0xE004)"},
}; /* pci_vid_1D26[] */

static pci_id_t const pci_vid_1D37[] = {
{0x1D37, 0xFFFF, 0xFFFF, 0xFFFF, "NovaSparks(0x1D37)"},
{0x1D37, 0x0013, 0xFFFF, 0xFFFF, "PM3(0x0013)"},
{0x1D37, 0x0014, 0xFFFF, 0xFFFF, "PM4(0x0014)"},
{0x1D37, 0x0015, 0xFFFF, 0xFFFF, "PM4edge(0x0015)"},
{0x1D37, 0x0016, 0xFFFF, 0xFFFF, "PM4edge User Device(0x0016)"},
}; /* pci_vid_1D37[] */

static pci_id_t const pci_vid_1D40[] = {
{0x1D40, 0xFFFF, 0xFFFF, 0xFFFF, "Techman Electronics (Changshu) Co., Ltd.(0x1D40)"},
{0x1D40, 0x5501, 0xFFFF, 0xFFFF, "XC100C55-xxxx NVME SSD(0x5501)"},
{0x1D40, 0x5C01, 0xFFFF, 0xFFFF, "XC100C5C-xxxx, XC100E5C-xxxx NVME SSD(0x5C01)"},
{0x1D40, 0xB100, 0xFFFF, 0xFFFF, "PV100C55-xxxx NVME SSD(0xB100)"},
}; /* pci_vid_1D40[] */

static pci_id_t const pci_vid_1D44[] = {
{0x1D44, 0xFFFF, 0xFFFF, 0xFFFF, "DPT(0x1D44)"},
{0x1D44, 0xA400, 0xFFFF, 0xFFFF, "PM2x24/PM3224(0xA400)"},
}; /* pci_vid_1D44[] */

static pci_id_t const pci_vid_1D49[] = {
{0x1D49, 0xFFFF, 0xFFFF, 0xFFFF, "Lenovo(0x1D49)"},
}; /* pci_vid_1D49[] */

static pci_id_t const pci_vid_1D4C[] = {
{0x1D4C, 0xFFFF, 0xFFFF, 0xFFFF, "Diamanti, Inc.(0x1D4C)"},
}; /* pci_vid_1D4C[] */

static pci_id_t const pci_vid_1D5C[] = {
{0x1D5C, 0xFFFF, 0xFFFF, 0xFFFF, "Fantasia Trading LLC(0x1D5C)"},
}; /* pci_vid_1D5C[] */

static pci_id_t const pci_vid_1D61[] = {
{0x1D61, 0xFFFF, 0xFFFF, 0xFFFF, "Technobox, Inc.(0x1D61)"},
}; /* pci_vid_1D61[] */

static pci_id_t const pci_vid_1D62[] = {
{0x1D62, 0xFFFF, 0xFFFF, 0xFFFF, "Nebbiolo Technologies(0x1D62)"},
}; /* pci_vid_1D62[] */

static pci_id_t const pci_vid_1D65[] = {
{0x1D65, 0xFFFF, 0xFFFF, 0xFFFF, "Imagine Communications Corp.(0x1D65)"},
{0x1D65, 0x04DE, 0xFFFF, 0xFFFF, "Taurus/McKinley(0x04DE)"},
}; /* pci_vid_1D65[] */

static pci_id_t const pci_vid_1D69[] = {
{0x1D69, 0xFFFF, 0xFFFF, 0xFFFF, "Celeno Communications(0x1D69)"},
{0x1D69, 0x2432, 0xFFFF, 0xFFFF, "CL2432(0x2432)"},
{0x1D69, 0x2440, 0xFFFF, 0xFFFF, "CL2440(0x2440)"},
}; /* pci_vid_1D69[] */

static pci_id_t const pci_vid_1D6A[] = {
{0x1D6A, 0xFFFF, 0xFFFF, 0xFFFF, "Aquantia Corp.(0x1D6A)"},
{0x1D6A, 0x0001, 0xFFFF, 0xFFFF, "AQC107 NBase-T/IEEE 802.3bz Ethernet Controller [AQtion](0x0001)"},
{0x1D6A, 0x0001, 0x4C52, 0x6880, "LREC6880BT Single-port 10Gb Ethernet Network Adapter(0x4C52-0x6880)"},
{0x1D6A, 0x00B1, 0xFFFF, 0xFFFF, "AQtion AQC100 NBase-T/IEEE 802.3an Ethernet Controller [Atlantic 10G](0x00B1)"},
{0x1D6A, 0x00C0, 0xFFFF, 0xFFFF, "Antigua NBase-T/IEEE 802.3an Ethernet Controller - Engineering Sample(0x00C0)"},
{0x1D6A, 0x04C0, 0xFFFF, 0xFFFF, "AQtion AQC113 NBase-T/IEEE 802.3an Ethernet Controller [Antigua 10G](0x04C0)"},
{0x1D6A, 0x04C0, 0x4C52, 0x1053, "LRES1053PT Quad-port 10Gb Ethernet Network Adapter(0x4C52-0x1053)"},
{0x1D6A, 0x04C0, 0x4C52, 0x2051, "LRES2051PT Single-port 10Gb Ethernet Network Adapter(0x4C52-0x2051)"},
{0x1D6A, 0x07B1, 0xFFFF, 0xFFFF, "AQtion AQC107 NBase-T/IEEE 802.3an Ethernet Controller [Atlantic 10G](0x07B1)"},
{0x1D6A, 0x07B1, 0x1BAA, 0x07B1, "QM2-2P10G1TA [QXG 10GbE Network Adapter](0x1BAA-0x07B1)"},
{0x1D6A, 0x07B1, 0x1BAA, 0x07B2, "QM2-2P10G1TA [QM2 Expansion Adapter](0x1BAA-0x07B2)"},
{0x1D6A, 0x07B1, 0x4C52, 0x6880, "LREC6880BT Single-port 10Gb Ethernet Network Adapter(0x4C52-0x6880)"},
{0x1D6A, 0x08B1, 0xFFFF, 0xFFFF, "AQC108 NBase-T/IEEE 802.3bz Ethernet Controller [AQtion](0x08B1)"},
{0x1D6A, 0x11B1, 0xFFFF, 0xFFFF, "AQC111 NBase-T/IEEE 802.3bz Ethernet Controller [AQtion](0x11B1)"},
{0x1D6A, 0x12B1, 0xFFFF, 0xFFFF, "AQC112 NBase-T/IEEE 802.3bz Ethernet Controller [AQtion](0x12B1)"},
{0x1D6A, 0x12C0, 0xFFFF, 0xFFFF, "AQtion AQC115C NBase-T/IEEE 802.3bz Ethernet Controller [Antigua 2.5G](0x12C0)"},
{0x1D6A, 0x14C0, 0xFFFF, 0xFFFF, "AQC113C NBase-T/IEEE 802.3an Ethernet Controller [Marvell Scalable mGig](0x14C0)"},
{0x1D6A, 0x80B1, 0xFFFF, 0xFFFF, "AQtion AQC100S NBase-T/IEEE 802.3an Ethernet Controller [Atlantic 10G](0x80B1)"},
{0x1D6A, 0x87B1, 0xFFFF, 0xFFFF, "AQtion AQC107S NBase-T/IEEE 802.3an Ethernet Controller [Atlantic 10G](0x87B1)"},
{0x1D6A, 0x93C0, 0xFFFF, 0xFFFF, "AQtion AQC114CS NBase-T/IEEE 802.3bz Ethernet Controller [Antigua 5G](0x93C0)"},
{0x1D6A, 0x94C0, 0xFFFF, 0xFFFF, "AQtion AQC113CS NBase-T/IEEE 802.3an Ethernet Controller [Antigua 10G](0x94C0)"},
{0x1D6A, 0x94C0, 0x1043, 0x87F5, "ProArt X570-CREATOR WIFI(0x1043-0x87F5)"},
{0x1D6A, 0xD107, 0xFFFF, 0xFFFF, "AQtion AQC107 NBase-T/IEEE 802.3an Ethernet Controller [Atlantic 10G](0xD107)"},
{0x1D6A, 0xD107, 0x1043, 0x8741, "XG-C100C(0x1043-0x8741)"},
{0x1D6A, 0xD108, 0xFFFF, 0xFFFF, "AQC108 NBase-T/IEEE 802.3bz Ethernet Controller [AQtion](0xD108)"},
}; /* pci_vid_1D6A[] */

static pci_id_t const pci_vid_1D6C[] = {
{0x1D6C, 0xFFFF, 0xFFFF, 0xFFFF, "Atomic Rules LLC(0x1D6C)"},
{0x1D6C, 0x1001, 0xFFFF, 0xFFFF, "A5PL-E1(0x1001)"},
{0x1D6C, 0x1002, 0xFFFF, 0xFFFF, "A5PL-E7(0x1002)"},
{0x1D6C, 0x1003, 0xFFFF, 0xFFFF, "S5PEDS-AB(0x1003)"},
{0x1D6C, 0x1004, 0xFFFF, 0xFFFF, "KC705-K325(0x1004)"},
{0x1D6C, 0x1005, 0xFFFF, 0xFFFF, "ZC706-Z045(0x1005)"},
{0x1D6C, 0x1006, 0xFFFF, 0xFFFF, "KCU105-KU040(0x1006)"},
{0x1D6C, 0x1007, 0xFFFF, 0xFFFF, "XUSP3S-VU095 [Jasper](0x1007)"},
{0x1D6C, 0x1008, 0xFFFF, 0xFFFF, "XUSPL4-VU065 [Mustang UltraScale](0x1008)"},
{0x1D6C, 0x1009, 0xFFFF, 0xFFFF, "XUSPL4-VU3P [Mustang UltraScale+](0x1009)"},
{0x1D6C, 0x100A, 0xFFFF, 0xFFFF, "A10PL4-A10GX115(0x100A)"},
{0x1D6C, 0x100B, 0xFFFF, 0xFFFF, "K35-2SFP(0x100B)"},
{0x1D6C, 0x100C, 0xFFFF, 0xFFFF, "K35-4SFP(0x100C)"},
{0x1D6C, 0x100D, 0xFFFF, 0xFFFF, "AR-ARKA-FX0 [Arkville 32B DPDK Data Mover](0x100D)"},
{0x1D6C, 0x100D, 0x1D6C, 0x2001, "DPDK-Aware Virtual Function [Arkville VF](0x1D6C-0x2001)"},
{0x1D6C, 0x100E, 0xFFFF, 0xFFFF, "AR-ARKA-FX1 [Arkville 64B DPDK Data Mover](0x100E)"},
{0x1D6C, 0x100E, 0x1D6C, 0x2001, "DPDK-Aware Virtual Function [Arkville VF](0x1D6C-0x2001)"},
{0x1D6C, 0x100F, 0xFFFF, 0xFFFF, "AR-ARKA-FX1 [Arkville 64B DPDK Data Mover for Versal](0x100F)"},
{0x1D6C, 0x1010, 0xFFFF, 0xFFFF, "AR-ARKA-FX1 [Arkville 64B DPDK Data Mover for Agilex](0x1010)"},
{0x1D6C, 0x1011, 0xFFFF, 0xFFFF, "AR-MAN-U50 [Manitou Class Accelerator for U50](0x1011)"},
{0x1D6C, 0x1012, 0xFFFF, 0xFFFF, "AR-MAN-U200 [Manitou Class Accelerator for U200](0x1012)"},
{0x1D6C, 0x1013, 0xFFFF, 0xFFFF, "AR-MAN-U250 [Manitou Class Accelerator for U250](0x1013)"},
{0x1D6C, 0x1014, 0xFFFF, 0xFFFF, "AR-MAN-U280 [Manitou Class Accelerator for U280](0x1014)"},
{0x1D6C, 0x1015, 0xFFFF, 0xFFFF, "AR-ARK-BBDEV-FX0 [Arkville 32B DPDK Baseband Device](0x1015)"},
{0x1D6C, 0x1016, 0xFFFF, 0xFFFF, "AR-ARK-BBDEV-FX1 [Arkville 64B DPDK Baseband Device](0x1016)"},
{0x1D6C, 0x1017, 0xFFFF, 0xFFFF, "AR-ARK-FX1 [Arkville 64B Multi-Homed Primary Endpoint](0x1017)"},
{0x1D6C, 0x1018, 0xFFFF, 0xFFFF, "AR-ARK-FX1 [Arkville 64B Multi-Homed Secondary Endpoint](0x1018)"},
{0x1D6C, 0x1019, 0xFFFF, 0xFFFF, "AR-ARK-FX1 [Arkville 64B Multi-Homed Tertiary Endpoint](0x1019)"},
{0x1D6C, 0x101A, 0xFFFF, 0xFFFF, "AR-ARK-SRIOV-FX0 [Arkville 32B Primary Physical Function](0x101A)"},
{0x1D6C, 0x101B, 0xFFFF, 0xFFFF, "AR-ARK-SRIOV-FX1 [Arkville 64B Primary Physical Function](0x101B)"},
{0x1D6C, 0x101C, 0xFFFF, 0xFFFF, "AR-ARK-SRIOV-VF [Arkville Virtual Function](0x101C)"},
{0x1D6C, 0x101D, 0xFFFF, 0xFFFF, "AR-ARK-NIC [Arkville ArkNIC Kernel Path Device](0x101D)"},
{0x1D6C, 0x101E, 0xFFFF, 0xFFFF, "AR-ARKA-FX1 [Arkville 64B DPDK Data Mover for Agilex R-Tile](0x101E)"},
{0x1D6C, 0x101F, 0xFFFF, 0xFFFF, "AR-TK242 [2x100GbE Packet Capture Device](0x101F)"},
{0x1D6C, 0x1020, 0xFFFF, 0xFFFF, "AR-GP-PF [General-Purpose Physical Function](0x1020)"},
{0x1D6C, 0x1021, 0xFFFF, 0xFFFF, "AR-MGMT-PF [Board-Generic Management Physical Function](0x1021)"},
{0x1D6C, 0x1022, 0xFFFF, 0xFFFF, "AR-ARKA-FX2 [Arkville 128B DPDK Data Mover for Agilex](0x1022)"},
{0x1D6C, 0x1023, 0xFFFF, 0xFFFF, "AR-BD-FX1 [BufferDirect Zero-Bounce Data Motion Endpoint](0x1023)"},
{0x1D6C, 0x1024, 0xFFFF, 0xFFFF, "AR-TK242 [2x10GbE Packet Capture Device](0x1024)"},
{0x1D6C, 0x1025, 0xFFFF, 0xFFFF, "AR-TK242-FX2 [2x100GbE Gen5 Packet Capture Device](0x1025)"},
{0x1D6C, 0x1026, 0xFFFF, 0xFFFF, "AR-TK242-FX2 [1x200GbE Gen5 Packet Capture Device](0x1026)"},
{0x1D6C, 0x1027, 0xFFFF, 0xFFFF, "AR-P2P-DBG [P2P Debug Function](0x1027)"},
{0x1D6C, 0x1028, 0xFFFF, 0xFFFF, "AR-P2P-ATR [P2P Actor Function](0x1028)"},
{0x1D6C, 0x1029, 0xFFFF, 0xFFFF, "AR-P2P-UTL [P2P Utility Function](0x1029)"},
{0x1D6C, 0x4200, 0xFFFF, 0xFFFF, "A5PL-E1-10GETI [10 GbE Ethernet Traffic Instrument](0x4200)"},
}; /* pci_vid_1D6C[] */

static pci_id_t const pci_vid_1D72[] = {
{0x1D72, 0xFFFF, 0xFFFF, 0xFFFF, "Xiaomi(0x1D72)"},
}; /* pci_vid_1D72[] */

static pci_id_t const pci_vid_1D78[] = {
{0x1D78, 0xFFFF, 0xFFFF, 0xFFFF, "DERA Storage(0x1D78)"},
{0x1D78, 0x1512, 0xFFFF, 0xFFFF, "TAI NVMe Controller(0x1512)"},
{0x1D78, 0x1512, 0x1D78, 0x2004, "D5437 HHHL 2TB NVMe SSD(0x1D78-0x2004)"},
{0x1D78, 0x1512, 0x1D78, 0x2006, "D5437 HHHL 4TB NVMe SSD(0x1D78-0x2006)"},
{0x1D78, 0x1512, 0x1D78, 0x2008, "D5437 HHHL 8TB NVMe SSD(0x1D78-0x2008)"},
{0x1D78, 0x1512, 0x1D78, 0x2104, "D5437 U.2 2TB NVMe SSD(0x1D78-0x2104)"},
{0x1D78, 0x1512, 0x1D78, 0x2106, "D5437 U.2 4TB NVMe SSD(0x1D78-0x2106)"},
{0x1D78, 0x1512, 0x1D78, 0x2108, "D5437 U.2 8TB NVMe SSD(0x1D78-0x2108)"},
{0x1D78, 0x1512, 0x1D78, 0x3003, "D5457 HHHL 1.6TB NVMe SSD(0x1D78-0x3003)"},
{0x1D78, 0x1512, 0x1D78, 0x3005, "D5457 HHHL 3.2TB NVMe SSD(0x1D78-0x3005)"},
{0x1D78, 0x1512, 0x1D78, 0x3007, "D5457 HHHL 6.4TB NVMe SSD(0x1D78-0x3007)"},
{0x1D78, 0x1512, 0x1D78, 0x3103, "D5457 U.2 1.6TB NVMe SSD(0x1D78-0x3103)"},
{0x1D78, 0x1512, 0x1D78, 0x3105, "D5457 U.2 3.2TB NVMe SSD(0x1D78-0x3105)"},
{0x1D78, 0x1512, 0x1D78, 0x3107, "D5457 U.2 6.4TB NVMe SSD(0x1D78-0x3107)"},
{0x1D78, 0x1512, 0x1D78, 0x3108, "D5437 U.2 7.68TB NVMe SSD(0x1D78-0x3108)"},
{0x1D78, 0x1512, 0x1D78, 0x5003, "D5447 HHHL 1.6TB NVMe SSD(0x1D78-0x5003)"},
{0x1D78, 0x1512, 0x1D78, 0x5004, "D5427 HHHL 1.92TB NVMe SSD(0x1D78-0x5004)"},
{0x1D78, 0x1512, 0x1D78, 0x5005, "D5447 HHHL 3.2TB NVMe SSD(0x1D78-0x5005)"},
{0x1D78, 0x1512, 0x1D78, 0x5006, "D5427 HHHL 3.84TB NVMe SSD(0x1D78-0x5006)"},
{0x1D78, 0x1512, 0x1D78, 0x5007, "D5447 HHHL 6.4TB NVMe SSD(0x1D78-0x5007)"},
{0x1D78, 0x1512, 0x1D78, 0x5008, "D5427 HHHL 7.68TB NVMe SSD(0x1D78-0x5008)"},
{0x1D78, 0x1512, 0x1D78, 0x5103, "D5447 U.2 1.6TB NVMe SSD(0x1D78-0x5103)"},
{0x1D78, 0x1512, 0x1D78, 0x5105, "D5447 U.2 3.2TB NVMe SSD(0x1D78-0x5105)"},
{0x1D78, 0x1512, 0x1D78, 0x5106, "AF3UP34DTCUN3T8B SSD(0x1D78-0x5106)"},
{0x1D78, 0x1512, 0x1D78, 0x5107, "D5447 U.2 6.4TB NVMe SSD(0x1D78-0x5107)"},
{0x1D78, 0x1512, 0x1D78, 0x5114, "D5427 U.2 1.92TB NVMe SSD(0x1D78-0x5114)"},
{0x1D78, 0x1512, 0x1D78, 0x5116, "D5427 U.2 3.84TB NVMe SSD(0x1D78-0x5116)"},
{0x1D78, 0x1512, 0x1D78, 0x5118, "D5427 U.2 7.68TB NVMe SSD(0x1D78-0x5118)"},
{0x1D78, 0x1512, 0x1D78, 0x8107, "D5457 U.2 6.4TB NVMe SSD(0x1D78-0x8107)"},
{0x1D78, 0x1513, 0xFFFF, 0xFFFF, "DERA MENG NVMe Controller(0x1513)"},
{0x1D78, 0x1513, 0x1D78, 0x6015, "D6456 HHHL 3.2TB NVMe SSD(0x1D78-0x6015)"},
{0x1D78, 0x1513, 0x1D78, 0x6016, "D6436 HHHL 3.84TB NVMe SSD(0x1D78-0x6016)"},
{0x1D78, 0x1513, 0x1D78, 0x6017, "D6456 HHHL 6.4TB NVMe SSD(0x1D78-0x6017)"},
{0x1D78, 0x1513, 0x1D78, 0x6018, "D6436 HHHL 7.68TB NVMe SSD(0x1D78-0x6018)"},
{0x1D78, 0x1513, 0x1D78, 0x6105, "D6457 U.2 3.2TB NVMe SSD(0x1D78-0x6105)"},
{0x1D78, 0x1513, 0x1D78, 0x6106, "D6437 U.2 3.84TB NVMe SSD(0x1D78-0x6106)"},
{0x1D78, 0x1513, 0x1D78, 0x6107, "D6457 U.2 6.4TB NVMe SSD(0x1D78-0x6107)"},
{0x1D78, 0x1513, 0x1D78, 0x6108, "D6437 U.2 7.68TB NVMe SSD(0x1D78-0x6108)"},
{0x1D78, 0x1513, 0x1D78, 0x6115, "D6456 U.2 3.2TB NVMe SSD(0x1D78-0x6115)"},
{0x1D78, 0x1513, 0x1D78, 0x6116, "D6436 U.2 3.84TB NVMe SSD(0x1D78-0x6116)"},
{0x1D78, 0x1513, 0x1D78, 0x6117, "D6456 U.2 6.4TB NVMe SSD(0x1D78-0x6117)"},
{0x1D78, 0x1513, 0x1D78, 0x6118, "D6436 U.2 7.68TB NVMe SSD(0x1D78-0x6118)"},
{0x1D78, 0x1515, 0xFFFF, 0xFFFF, "DERA EMEI NVMe Controller(0x1515)"},
{0x1D78, 0x1515, 0x1D78, 0x7002, "D7436 HHHL 1.92TB NVMe SSD(0x1D78-0x7002)"},
{0x1D78, 0x1515, 0x1D78, 0x7003, "D7456 HHHL 1.6TB NVMe SSD(0x1D78-0x7003)"},
{0x1D78, 0x1515, 0x1D78, 0x7004, "D7436 HHHL 3.84TB NVMe SSD(0x1D78-0x7004)"},
{0x1D78, 0x1515, 0x1D78, 0x7005, "D7456 HHHL 3.2TB NVMe SSD(0x1D78-0x7005)"},
{0x1D78, 0x1515, 0x1D78, 0x7007, "D7456 HHHL 6.4TB NVMe SSD(0x1D78-0x7007)"},
{0x1D78, 0x1515, 0x1D78, 0x7008, "D7436 HHHL 7.68TB NVMe SSD(0x1D78-0x7008)"},
{0x1D78, 0x1515, 0x1D78, 0x7009, "D7456 HHHL 12.8TB NVMe SSD(0x1D78-0x7009)"},
{0x1D78, 0x1515, 0x1D78, 0x700A, "D7436 HHHL 15.36TB NVMe SSD(0x1D78-0x700A)"},
{0x1D78, 0x1515, 0x1D78, 0x7102, "D7436 U.2 15mm 1.92TB NVMe SSD(0x1D78-0x7102)"},
{0x1D78, 0x1515, 0x1D78, 0x7103, "D7456 U.2 15mm 1.6TB NVMe SSD(0x1D78-0x7103)"},
{0x1D78, 0x1515, 0x1D78, 0x7104, "D7436 U.2 15mm 3.84TB NVMe SSD(0x1D78-0x7104)"},
{0x1D78, 0x1515, 0x1D78, 0x7105, "D7456 U.2 15mm 3.2TB NVMe SSD(0x1D78-0x7105)"},
{0x1D78, 0x1515, 0x1D78, 0x7107, "D7456 U.2 15mm 6.4TB NVMe SSD(0x1D78-0x7107)"},
{0x1D78, 0x1515, 0x1D78, 0x7108, "D7436 U.2 15mm 7.68TB NVMe SSD(0x1D78-0x7108)"},
{0x1D78, 0x1515, 0x1D78, 0x7109, "D7456 U.2 15mm 12.8TB NVMe SSD(0x1D78-0x7109)"},
{0x1D78, 0x1515, 0x1D78, 0x710A, "D7436 U.2 15mm 15.36TB NVMe SSD(0x1D78-0x710A)"},
{0x1D78, 0x1515, 0x1D78, 0x7202, "Aliflash V2 U.2 15mm 1.92TB NVMe SSD(0x1D78-0x7202)"},
{0x1D78, 0x1515, 0x1D78, 0x7204, "Aliflash V2 U.2 15mm 3.84TB NVMe SSD(0x1D78-0x7204)"},
{0x1D78, 0x1515, 0x1D78, 0x7208, "Aliflash V2 U.2 15mm 7.68TB NVMe SSD(0x1D78-0x7208)"},
}; /* pci_vid_1D78[] */

static pci_id_t const pci_vid_1D79[] = {
{0x1D79, 0xFFFF, 0xFFFF, 0xFFFF, "Transcend Information, Inc.(0x1D79)"},
{0x1D79, 0x2262, 0xFFFF, 0xFFFF, "NVMe PCIe SSD 220S/MTE662T2(0x2262)"},
{0x1D79, 0x2263, 0xFFFF, 0xFFFF, "NVMe PCIe SSD 110S/112S/120S/MTE300S/MTE400S/MTE652T2 (DRAM-less)(0x2263)"},
{0x1D79, 0x2264, 0xFFFF, 0xFFFF, "NVMe PCIe SSD 250H(0x2264)"},
{0x1D79, 0x2267, 0xFFFF, 0xFFFF, "NVMe PCIe SSD 220S/240S/MTE710T(0x2267)"},
{0x1D79, 0x5766, 0xFFFF, 0xFFFF, "NVMe PCIe SSD 110Q (DRAM-less)(0x5766)"},
}; /* pci_vid_1D79[] */

static pci_id_t const pci_vid_1D7C[] = {
{0x1D7C, 0xFFFF, 0xFFFF, 0xFFFF, "Aerotech, Inc.(0x1D7C)"},
{0x1D7C, 0x0001, 0xFFFF, 0xFFFF, "HyperWire Adapter(0x0001)"},
}; /* pci_vid_1D7C[] */

static pci_id_t const pci_vid_1D82[] = {
{0x1D82, 0xFFFF, 0xFFFF, 0xFFFF, "NETINT Technologies Inc.(0x1D82)"},
{0x1D82, 0x0101, 0xFFFF, 0xFFFF, "Codensity D400 SSD(0x0101)"},
{0x1D82, 0x0102, 0xFFFF, 0xFFFF, "Codensity D408 PCIe Gen4 NVMe SSD(0x0102)"},
{0x1D82, 0x0202, 0xFFFF, 0xFFFF, "Codensity T408 Video Encoding-Decoding Accelerator(0x0202)"},
{0x1D82, 0x0401, 0xFFFF, 0xFFFF, "Quadra Video Processing Unit (VPU)(0x0401)"},
}; /* pci_vid_1D82[] */

static pci_id_t const pci_vid_1D87[] = {
{0x1D87, 0xFFFF, 0xFFFF, 0xFFFF, "Rockchip Electronics Co., Ltd(0x1D87)"},
{0x1D87, 0x0100, 0xFFFF, 0xFFFF, "RK3399 PCI Express Root Port(0x0100)"},
{0x1D87, 0x1808, 0xFFFF, 0xFFFF, "RK1808 Neural Network Processor Card(0x1808)"},
{0x1D87, 0x3528, 0xFFFF, 0xFFFF, "RK3528 PCI Express Root Port(0x3528)"},
{0x1D87, 0x3562, 0xFFFF, 0xFFFF, "RK3562 PCI Express Root Port(0x3562)"},
{0x1D87, 0x3566, 0xFFFF, 0xFFFF, "RK3568 Remote Signal Processor(0x3566)"},
{0x1D87, 0x3588, 0xFFFF, 0xFFFF, "RK3588(0x3588)"},
}; /* pci_vid_1D87[] */

static pci_id_t const pci_vid_1D89[] = {
{0x1D89, 0xFFFF, 0xFFFF, 0xFFFF, "YEESTOR Microelectronics Co., Ltd(0x1D89)"},
{0x1D89, 0x0280, 0xFFFF, 0xFFFF, "PCIe NVMe SSD(0x0280)"},
}; /* pci_vid_1D89[] */

static pci_id_t const pci_vid_1D8F[] = {
{0x1D8F, 0xFFFF, 0xFFFF, 0xFFFF, "Enyx(0x1D8F)"},
}; /* pci_vid_1D8F[] */

static pci_id_t const pci_vid_1D92[] = {
{0x1D92, 0xFFFF, 0xFFFF, 0xFFFF, "Abaco Systems Inc.(0x1D92)"},
}; /* pci_vid_1D92[] */

static pci_id_t const pci_vid_1D93[] = {
{0x1D93, 0xFFFF, 0xFFFF, 0xFFFF, "YADRO(0x1D93)"},
}; /* pci_vid_1D93[] */

static pci_id_t const pci_vid_1D94[] = {
{0x1D94, 0xFFFF, 0xFFFF, 0xFFFF, "Chengdu Haiguang IC Design Co., Ltd.(0x1D94)"},
{0x1D94, 0x1450, 0xFFFF, 0xFFFF, "Root Complex(0x1450)"},
{0x1D94, 0x1451, 0xFFFF, 0xFFFF, "I/O Memory Management Unit(0x1451)"},
{0x1D94, 0x1452, 0xFFFF, 0xFFFF, "PCIe Dummy Host Bridge(0x1452)"},
{0x1D94, 0x1453, 0xFFFF, 0xFFFF, "PCIE GPP Bridge(0x1453)"},
{0x1D94, 0x1454, 0xFFFF, 0xFFFF, "Internal PCIe GPP Bridge 0 to Bus B(0x1454)"},
{0x1D94, 0x1455, 0xFFFF, 0xFFFF, "PCIe Dummy Function(0x1455)"},
{0x1D94, 0x1456, 0xFFFF, 0xFFFF, "PSPCCP Command DMA Processor(0x1456)"},
{0x1D94, 0x1458, 0xFFFF, 0xFFFF, "10 Gb Ethernet Controller Port 0/Port1(0x1458)"},
{0x1D94, 0x1459, 0xFFFF, 0xFFFF, "10 Gb Ethernet Controller Port 2/Port3(0x1459)"},
{0x1D94, 0x145A, 0xFFFF, 0xFFFF, "PCIe Dummy Function(0x145A)"},
{0x1D94, 0x145B, 0xFFFF, 0xFFFF, "PCIE Non-Transparent Bridge(0x145B)"},
{0x1D94, 0x145C, 0xFFFF, 0xFFFF, "USB3 XHCI(0x145C)"},
{0x1D94, 0x145D, 0xFFFF, 0xFFFF, "Switch upstream in PCIe(0x145D)"},
{0x1D94, 0x145E, 0xFFFF, 0xFFFF, "Switch downstream in PCIe(0x145E)"},
{0x1D94, 0x145F, 0xFFFF, 0xFFFF, "USB 3.0 Host controller(0x145F)"},
{0x1D94, 0x1460, 0xFFFF, 0xFFFF, "Data Fabric: Device 18h; Function 0(0x1460)"},
{0x1D94, 0x1461, 0xFFFF, 0xFFFF, "Data Fabric: Device 18h; Function 1(0x1461)"},
{0x1D94, 0x1462, 0xFFFF, 0xFFFF, "Data Fabric: Device 18h; Function 2(0x1462)"},
{0x1D94, 0x1463, 0xFFFF, 0xFFFF, "Data Fabric: Device 18h; Function 3(0x1463)"},
{0x1D94, 0x1464, 0xFFFF, 0xFFFF, "Data Fabric: Device 18h; Function 4(0x1464)"},
{0x1D94, 0x1465, 0xFFFF, 0xFFFF, "Data Fabric: Device 18h; Function 5(0x1465)"},
{0x1D94, 0x1466, 0xFFFF, 0xFFFF, "Data Fabric: Device 18h; Function 6(0x1466)"},
{0x1D94, 0x1467, 0xFFFF, 0xFFFF, "Data Fabric: Device 18h; Function 7(0x1467)"},
{0x1D94, 0x1468, 0xFFFF, 0xFFFF, "NTBCCP(0x1468)"},
{0x1D94, 0x7901, 0xFFFF, 0xFFFF, "FCH SATA Controller [AHCI mode](0x7901)"},
{0x1D94, 0x7904, 0xFFFF, 0xFFFF, "FCH SATA Controller [AHCI mode](0x7904)"},
{0x1D94, 0x7906, 0xFFFF, 0xFFFF, "FCH SD Flash Controller(0x7906)"},
{0x1D94, 0x790B, 0xFFFF, 0xFFFF, "FCH SMBus Controller(0x790B)"},
{0x1D94, 0x790E, 0xFFFF, 0xFFFF, "FCH LPC Bridge(0x790E)"},
}; /* pci_vid_1D94[] */

static pci_id_t const pci_vid_1D95[] = {
{0x1D95, 0xFFFF, 0xFFFF, 0xFFFF, "Graphcore Ltd(0x1D95)"},
{0x1D95, 0x0001, 0xFFFF, 0xFFFF, "Colossus GC2 [C2](0x0001)"},
{0x1D95, 0x0002, 0xFFFF, 0xFFFF, "Colossus GC1 [S1](0x0002)"},
}; /* pci_vid_1D95[] */

static pci_id_t const pci_vid_1D97[] = {
{0x1D97, 0xFFFF, 0xFFFF, 0xFFFF, "Shenzhen Longsys Electronics Co., Ltd.(0x1D97)"},
{0x1D97, 0x1062, 0xFFFF, 0xFFFF, "Lexar NM710 NVME SSD(0x1062)"},
{0x1D97, 0x1160, 0xFFFF, 0xFFFF, "FORESEE P900 BGA NVMe SSD (DRAM-less)(0x1160)"},
{0x1D97, 0x1202, 0xFFFF, 0xFFFF, "Lexar NM610 PRO NVME SSD (DRAM-less)(0x1202)"},
{0x1D97, 0x12E4, 0xFFFF, 0xFFFF, "ORCA 4836 Series eSSD(0x12E4)"},
{0x1D97, 0x1602, 0xFFFF, 0xFFFF, "Lexar NM790 NVME SSD (DRAM-less)(0x1602)"},
{0x1D97, 0x1D97, 0xFFFF, 0xFFFF, "Lexar NM620 NVME SSD (DRAM-less)(0x1D97)"},
{0x1D97, 0x2263, 0xFFFF, 0xFFFF, "SM2263EN/SM2263XT-based OEM NVME SSD (DRAM-less)(0x2263)"},
{0x1D97, 0x2269, 0xFFFF, 0xFFFF, "FORESEE XP2000, Lexar NM760 NVME SSD (DRAM-less)(0x2269)"},
{0x1D97, 0x5216, 0xFFFF, 0xFFFF, "FORESEE XP1000 / Lexar Professional CFexpress Type B Gold series, NM620 PCIe NVME SSD (DRAM-less)(0x5216)"},
{0x1D97, 0x5220, 0xFFFF, 0xFFFF, "FORESEE XP2100 NVMe SSD (DRAM-less)(0x5220)"},
{0x1D97, 0x5236, 0xFFFF, 0xFFFF, "Lexar NM800 PRO NVME SSD(0x5236)"},
}; /* pci_vid_1D97[] */

static pci_id_t const pci_vid_1D9B[] = {
{0x1D9B, 0xFFFF, 0xFFFF, 0xFFFF, "Meta Platforms, Inc.(0x1D9B)"},
{0x1D9B, 0x0010, 0xFFFF, 0xFFFF, "Networking DOM Engine(0x0010)"},
{0x1D9B, 0x0011, 0xFFFF, 0xFFFF, "IO Bridge(0x0011)"},
}; /* pci_vid_1D9B[] */

static pci_id_t const pci_vid_1DA1[] = {
{0x1DA1, 0xFFFF, 0xFFFF, 0xFFFF, "Teko Telecom S.r.l.(0x1DA1)"},
}; /* pci_vid_1DA1[] */

static pci_id_t const pci_vid_1DA2[] = {
{0x1DA2, 0xFFFF, 0xFFFF, 0xFFFF, "Sapphire Technology Limited(0x1DA2)"},
{0x1DA2, 0xE26A, 0xFFFF, 0xFFFF, "Radeon R7 250(0xE26A)"},
{0x1DA2, 0xE445, 0xFFFF, 0xFFFF, "Sapphire Radeon RX 6700(0xE445)"},
}; /* pci_vid_1DA2[] */

static pci_id_t const pci_vid_1DA3[] = {
{0x1DA3, 0xFFFF, 0xFFFF, 0xFFFF, "Habana Labs Ltd.(0x1DA3)"},
{0x1DA3, 0x0001, 0xFFFF, 0xFFFF, "HL-1000 AI Inference Accelerator [Goya](0x0001)"},
{0x1DA3, 0x0030, 0xFFFF, 0xFFFF, "Greco AI Inference Accelerator(0x0030)"},
{0x1DA3, 0x1000, 0xFFFF, 0xFFFF, "HL-2000 AI Training Accelerator [Gaudi](0x1000)"},
{0x1DA3, 0x1010, 0xFFFF, 0xFFFF, "HL-2000 AI Training Accelerator [Gaudi secured](0x1010)"},
{0x1DA3, 0x1020, 0xFFFF, 0xFFFF, "Gaudi2 AI Training Accelerator(0x1020)"},
}; /* pci_vid_1DA3[] */

static pci_id_t const pci_vid_1DA8[] = {
{0x1DA8, 0xFFFF, 0xFFFF, 0xFFFF, "Corigine, Inc.(0x1DA8)"},
{0x1DA8, 0x3800, 0xFFFF, 0xFFFF, "Network Flow Processor 3800(0x3800)"},
{0x1DA8, 0x3803, 0xFFFF, 0xFFFF, "Network Flow Processor 3800 Virtual Function(0x3803)"},
}; /* pci_vid_1DA8[] */

static pci_id_t const pci_vid_1DAD[] = {
{0x1DAD, 0xFFFF, 0xFFFF, 0xFFFF, "Fungible(0x1DAD)"},
{0x1DAD, 0x0108, 0xFFFF, 0xFFFF, "FC50, FC100, FC200 DPU NVMeoF Adapters(0x0108)"},
}; /* pci_vid_1DAD[] */

static pci_id_t const pci_vid_1DB2[] = {
{0x1DB2, 0xFFFF, 0xFFFF, 0xFFFF, "ATP ELECTRONICS INC(0x1DB2)"},
}; /* pci_vid_1DB2[] */

static pci_id_t const pci_vid_1DB7[] = {
{0x1DB7, 0xFFFF, 0xFFFF, 0xFFFF, "Phytium Technology Co., Ltd.(0x1DB7)"},
{0x1DB7, 0xDC20, 0xFFFF, 0xFFFF, "[X100 Series](0xDC20)"},
{0x1DB7, 0xDC21, 0xFFFF, 0xFFFF, "VPU Controller [X100 Series](0xDC21)"},
{0x1DB7, 0xDC22, 0xFFFF, 0xFFFF, "DC Controller [X100 Series](0xDC22)"},
{0x1DB7, 0xDC23, 0xFFFF, 0xFFFF, "I2S/DMA Controller [X100 Series](0xDC23)"},
{0x1DB7, 0xDC24, 0xFFFF, 0xFFFF, "NPU Controller [X100 Series](0xDC24)"},
{0x1DB7, 0xDC26, 0xFFFF, 0xFFFF, "SATA Controller [X100 Series](0xDC26)"},
{0x1DB7, 0xDC27, 0xFFFF, 0xFFFF, "USB Controller [X100 Series](0xDC27)"},
{0x1DB7, 0xDC29, 0xFFFF, 0xFFFF, "NANDFLASH Controller [X100 Series](0xDC29)"},
{0x1DB7, 0xDC2B, 0xFFFF, 0xFFFF, "I2S Controller [X100 Series](0xDC2B)"},
{0x1DB7, 0xDC2C, 0xFFFF, 0xFFFF, "SPIM Controller [X100 Series](0xDC2C)"},
{0x1DB7, 0xDC2D, 0xFFFF, 0xFFFF, "CAN Controller [X100 Series](0xDC2D)"},
{0x1DB7, 0xDC2E, 0xFFFF, 0xFFFF, "UART Controller [X100 Series](0xDC2E)"},
{0x1DB7, 0xDC2F, 0xFFFF, 0xFFFF, "PWM Controller [X100 Series](0xDC2F)"},
{0x1DB7, 0xDC30, 0xFFFF, 0xFFFF, "MIO Controller [X100 Series](0xDC30)"},
{0x1DB7, 0xDC31, 0xFFFF, 0xFFFF, "GPIO Controller [X100 Series](0xDC31)"},
{0x1DB7, 0xDC32, 0xFFFF, 0xFFFF, "SMBUS Controller [X100 Series](0xDC32)"},
{0x1DB7, 0xDC34, 0xFFFF, 0xFFFF, "PS2 Controller [X100 Series](0xDC34)"},
{0x1DB7, 0xDC35, 0xFFFF, 0xFFFF, "LPC Controller [X100 Series](0xDC35)"},
{0x1DB7, 0xDC36, 0xFFFF, 0xFFFF, "LDMA Controller [X100 Series](0xDC36)"},
{0x1DB7, 0xDC38, 0xFFFF, 0xFFFF, "LSD_CFG Controller [X100 Series](0xDC38)"},
{0x1DB7, 0xDC3A, 0xFFFF, 0xFFFF, "SWITCH Controller [X100 Series](0xDC3A)"},
{0x1DB7, 0xDC3C, 0xFFFF, 0xFFFF, "GPU_DMA Controller [X100 Series](0xDC3C)"},
}; /* pci_vid_1DB7[] */

static pci_id_t const pci_vid_1DBB[] = {
{0x1DBB, 0xFFFF, 0xFFFF, 0xFFFF, "NGD Systems, Inc.(0x1DBB)"},
}; /* pci_vid_1DBB[] */

static pci_id_t const pci_vid_1DBE[] = {
{0x1DBE, 0xFFFF, 0xFFFF, 0xFFFF, "INNOGRIT Corporation(0x1DBE)"},
{0x1DBE, 0x5216, 0xFFFF, 0xFFFF, "NVMe SSD Controller IG5216 (DRAM-less)(0x5216)"},
{0x1DBE, 0x5220, 0xFFFF, 0xFFFF, "NVMe SSD Controller IG5220 (DRAM-less)(0x5220)"},
{0x1DBE, 0x5236, 0xFFFF, 0xFFFF, "NVMe SSD Controller IG5236(0x5236)"},
{0x1DBE, 0x5236, 0x1DBE, 0x4001, "Dongting-B1 DC SSD M.2 480GB(0x1DBE-0x4001)"},
{0x1DBE, 0x5236, 0x1DBE, 0x4002, "Dongting-B1 DC SSD M.2 960GB(0x1DBE-0x4002)"},
{0x1DBE, 0x5636, 0xFFFF, 0xFFFF, "NVMe DC SSD IG5636(0x5636)"},
{0x1DBE, 0x5636, 0x1DBE, 0x0001, "Dongting-N1 DC SSD U.2 1600GB(0x1DBE-0x0001)"},
{0x1DBE, 0x5636, 0x1DBE, 0x0002, "Dongting-N1 DC SSD U.2 1920GB(0x1DBE-0x0002)"},
{0x1DBE, 0x5636, 0x1DBE, 0x0003, "Dongting-N1 DC SSD U.2 3200GB(0x1DBE-0x0003)"},
{0x1DBE, 0x5636, 0x1DBE, 0x0004, "Dongting-N1 DC SSD U.2 3840GB(0x1DBE-0x0004)"},
{0x1DBE, 0x5636, 0x1DBE, 0x0005, "Dongting-N1 DC SSD U.2 6400GB(0x1DBE-0x0005)"},
{0x1DBE, 0x5636, 0x1DBE, 0x0006, "Dongting-N1 DC SSD U.2 7680GB(0x1DBE-0x0006)"},
{0x1DBE, 0x5636, 0x1DBE, 0x1001, "Donghu-Z1 DC ZNS SSD U.2 4000GB(0x1DBE-0x1001)"},
{0x1DBE, 0x5636, 0x1DBE, 0x1002, "Donghu-Z1 DC ZNS SSD U.2 8000GB(0x1DBE-0x1002)"},
{0x1DBE, 0x5638, 0xFFFF, 0xFFFF, "NVMe DC SSD IG5638(0x5638)"},
{0x1DBE, 0x5638, 0x1DBE, 0x2001, "Dongting-N2 DC SSD U.2 1600GB(0x1DBE-0x2001)"},
{0x1DBE, 0x5638, 0x1DBE, 0x2002, "Dongting-N2 DC SSD U.2 1920GB(0x1DBE-0x2002)"},
{0x1DBE, 0x5638, 0x1DBE, 0x2003, "Dongting-N2 DC SSD U.2 3200GB(0x1DBE-0x2003)"},
{0x1DBE, 0x5638, 0x1DBE, 0x2004, "Dongting-N2 DC SSD U.2 3840GB(0x1DBE-0x2004)"},
{0x1DBE, 0x5638, 0x1DBE, 0x2005, "Dongting-N2 DC SSD U.2 6400GB(0x1DBE-0x2005)"},
{0x1DBE, 0x5638, 0x1DBE, 0x2006, "Dongting-N2 DC SSD U.2 7680GB(0x1DBE-0x2006)"},
{0x1DBE, 0x5638, 0x1DBE, 0x3001, "Donghu-Z2 DC ZNS SSD U.2 4000GB(0x1DBE-0x3001)"},
{0x1DBE, 0x5638, 0x1DBE, 0x3002, "Donghu-Z2 DC ZNS SSD U.2 8000GB(0x1DBE-0x3002)"},
{0x1DBE, 0x5666, 0xFFFF, 0xFFFF, "NVMe SSD Controller IG5666(0x5666)"},
{0x1DBE, 0x5668, 0xFFFF, 0xFFFF, "NVMe SSD Controller IG5668(0x5668)"},
{0x1DBE, 0x5669, 0xFFFF, 0xFFFF, "NVMe SSD Controller IG5669 [Tacoma](0x5669)"},
}; /* pci_vid_1DBE[] */

static pci_id_t const pci_vid_1DBF[] = {
{0x1DBF, 0xFFFF, 0xFFFF, 0xFFFF, "Guizhou Huaxintong Semiconductor Technology Co., Ltd(0x1DBF)"},
{0x1DBF, 0x0401, 0xFFFF, 0xFFFF, "StarDragon4800 PCI Express Root Port(0x0401)"},
}; /* pci_vid_1DBF[] */

static pci_id_t const pci_vid_1DC2[] = {
{0x1DC2, 0xFFFF, 0xFFFF, 0xFFFF, "Alco Digital Devices Limited(0x1DC2)"},
}; /* pci_vid_1DC2[] */

static pci_id_t const pci_vid_1DC5[] = {
{0x1DC5, 0xFFFF, 0xFFFF, 0xFFFF, "FADU Inc.(0x1DC5)"},
{0x1DC5, 0x4081, 0xFFFF, 0xFFFF, "FC4121 PCIe 4.0 NVMe controller [DELTA](0x4081)"},
{0x1DC5, 0x6150, 0xFFFF, 0xFFFF, "FC3081 PCIe 3.0 NVMe controller [BRAVO](0x6150)"},
}; /* pci_vid_1DC5[] */

static pci_id_t const pci_vid_1DCD[] = {
{0x1DCD, 0xFFFF, 0xFFFF, 0xFFFF, "Liqid Inc.(0x1DCD)"},
}; /* pci_vid_1DCD[] */

static pci_id_t const pci_vid_1DCF[] = {
{0x1DCF, 0xFFFF, 0xFFFF, 0xFFFF, "Beijing Sinead Technology Co., Ltd.(0x1DCF)"},
}; /* pci_vid_1DCF[] */

static pci_id_t const pci_vid_1DD3[] = {
{0x1DD3, 0xFFFF, 0xFFFF, 0xFFFF, "Sage Microelectronics Corp.(0x1DD3)"},
}; /* pci_vid_1DD3[] */

static pci_id_t const pci_vid_1DD4[] = {
{0x1DD4, 0xFFFF, 0xFFFF, 0xFFFF, "Swissbit AG(0x1DD4)"},
{0x1DD4, 0x0010, 0xFFFF, 0xFFFF, "N-10m2 NVMe SSD(0x0010)"},
{0x1DD4, 0x0016, 0xFFFF, 0xFFFF, "N-16(0x0016)"},
{0x1DD4, 0x0020, 0xFFFF, 0xFFFF, "EN-20 BGA NVMe SSD (DRAM-less)(0x0020)"},
}; /* pci_vid_1DD4[] */

static pci_id_t const pci_vid_1DD8[] = {
{0x1DD8, 0xFFFF, 0xFFFF, 0xFFFF, "AMD Pensando Systems(0x1DD8)"},
{0x1DD8, 0x0002, 0xFFFF, 0xFFFF, "DSC2 Elba Upstream Port(0x0002)"},
{0x1DD8, 0x0002, 0x1DD8, 0x100E, "Distributed Services Card(0x1DD8-0x100E)"},
{0x1DD8, 0x0002, 0x1DD8, 0x5001, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 Services Card(0x1DD8-0x5001)"},
{0x1DD8, 0x0002, 0x1DD8, 0x5003, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 Services Card(0x1DD8-0x5003)"},
{0x1DD8, 0x0002, 0x1DD8, 0x5008, "DSC25v2 10/25G 2p 32GB Spl Card(0x1DD8-0x5008)"},
{0x1DD8, 0x0002, 0x1DD8, 0x5009, "DSC2-25 10/25G 2p SFP56 DPU(0x1DD8-0x5009)"},
{0x1DD8, 0x0002, 0x1DD8, 0x500A, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R2(0x1DD8-0x500A)"},
{0x1DD8, 0x0002, 0x1DD8, 0x500B, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU(0x1DD8-0x500B)"},
{0x1DD8, 0x0002, 0x1DD8, 0x500C, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R3(0x1DD8-0x500C)"},
{0x1DD8, 0x0002, 0x1DD8, 0x500D, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R4(0x1DD8-0x500D)"},
{0x1DD8, 0x0002, 0x1DD8, 0x500E, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R5(0x1DD8-0x500E)"},
{0x1DD8, 0x0002, 0x1DD8, 0x500F, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R4-T(0x1DD8-0x500F)"},
{0x1DD8, 0x1000, 0xFFFF, 0xFFFF, "DSC Capri Upstream Port(0x1000)"},
{0x1DD8, 0x1000, 0x1DD8, 0x4000, "Naples 100Gb 2-port QSFP28 x16 8GB(0x1DD8-0x4000)"},
{0x1DD8, 0x1000, 0x1DD8, 0x4001, "Naples 100Gb 2-port QSFP28 x16 4GB(0x1DD8-0x4001)"},
{0x1DD8, 0x1000, 0x1DD8, 0x4002, "Naples 25Gb 2-port SFP28 x8 4GB(0x1DD8-0x4002)"},
{0x1DD8, 0x1000, 0x1DD8, 0x4007, "DSP DSC-25 Ent 10/25G OCP3 Card(0x1DD8-0x4007)"},
{0x1DD8, 0x1000, 0x1DD8, 0x4008, "DSP DSC-25 10/25G 2p SFP28 Card(0x1DD8-0x4008)"},
{0x1DD8, 0x1000, 0x1DD8, 0x400A, "DSC-100 40/100G 2-port 8G RAM 16G eMMC G1 Services Card(0x1DD8-0x400A)"},
{0x1DD8, 0x1000, 0x1DD8, 0x400C, "DSC-25 10/25G 2-port 4G RAM 8G eMMC G1 Services Card(0x1DD8-0x400C)"},
{0x1DD8, 0x1000, 0x1DD8, 0x400D, "DSP DSC-100 Ent 100Gb Card(0x1DD8-0x400D)"},
{0x1DD8, 0x1000, 0x1DD8, 0x400E, "DSC-25 10/25G 2-port 4G RAM 8G eMMC G1 Services Card(0x1DD8-0x400E)"},
{0x1DD8, 0x1000, 0x1DD8, 0x4014, "DSC-100 40/100G 2-port 8G RAM 16G eMMC G1 Services Card(0x1DD8-0x4014)"},
{0x1DD8, 0x1001, 0xFFFF, 0xFFFF, "DSC Virtual Downstream Port(0x1001)"},
{0x1DD8, 0x1001, 0x1DD8, 0x100E, "Distributed Services Card(0x1DD8-0x100E)"},
{0x1DD8, 0x1001, 0x1DD8, 0x4000, "Naples 100Gb 2-port QSFP28 x16 8GB(0x1DD8-0x4000)"},
{0x1DD8, 0x1001, 0x1DD8, 0x4001, "Naples 100Gb 2-port QSFP28 x16 4GB(0x1DD8-0x4001)"},
{0x1DD8, 0x1001, 0x1DD8, 0x4002, "Naples 25Gb 2-port SFP28 x8 4GB(0x1DD8-0x4002)"},
{0x1DD8, 0x1001, 0x1DD8, 0x4007, "DSP DSC-25 Ent 10/25G OCP3 Card(0x1DD8-0x4007)"},
{0x1DD8, 0x1001, 0x1DD8, 0x4008, "DSP DSC-25 10/25G 2p SFP28 Card(0x1DD8-0x4008)"},
{0x1DD8, 0x1001, 0x1DD8, 0x400A, "DSC-100 40/100G 2-port 8G RAM 16G eMMC G1 Services Card(0x1DD8-0x400A)"},
{0x1DD8, 0x1001, 0x1DD8, 0x400C, "DSC-25 10/25G 2-port 4G RAM 8G eMMC G1 Services Card(0x1DD8-0x400C)"},
{0x1DD8, 0x1001, 0x1DD8, 0x400D, "DSP DSC-100 Ent 100Gb Card(0x1DD8-0x400D)"},
{0x1DD8, 0x1001, 0x1DD8, 0x400E, "DSC-25 10/25G 2-port 4G RAM 8G eMMC G1 Services Card(0x1DD8-0x400E)"},
{0x1DD8, 0x1001, 0x1DD8, 0x4014, "DSC-100 40/100G 2-port 8G RAM 16G eMMC G1 Services Card(0x1DD8-0x4014)"},
{0x1DD8, 0x1001, 0x1DD8, 0x5001, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 Services Card(0x1DD8-0x5001)"},
{0x1DD8, 0x1001, 0x1DD8, 0x5003, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 Services Card(0x1DD8-0x5003)"},
{0x1DD8, 0x1001, 0x1DD8, 0x5008, "DSC25v2 10/25G 2p 32GB Spl Card(0x1DD8-0x5008)"},
{0x1DD8, 0x1001, 0x1DD8, 0x5009, "DSC2-25 10/25G 2p SFP56 DPU(0x1DD8-0x5009)"},
{0x1DD8, 0x1001, 0x1DD8, 0x500A, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R2(0x1DD8-0x500A)"},
{0x1DD8, 0x1001, 0x1DD8, 0x500B, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU(0x1DD8-0x500B)"},
{0x1DD8, 0x1001, 0x1DD8, 0x500C, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R3(0x1DD8-0x500C)"},
{0x1DD8, 0x1001, 0x1DD8, 0x500D, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R4(0x1DD8-0x500D)"},
{0x1DD8, 0x1001, 0x1DD8, 0x500E, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R5(0x1DD8-0x500E)"},
{0x1DD8, 0x1001, 0x1DD8, 0x500F, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R4-T(0x1DD8-0x500F)"},
{0x1DD8, 0x1002, 0xFFFF, 0xFFFF, "DSC Ethernet Controller(0x1002)"},
{0x1DD8, 0x1002, 0x1DD8, 0x100E, "Distributed Services Card(0x1DD8-0x100E)"},
{0x1DD8, 0x1002, 0x1DD8, 0x4000, "Naples 100Gb 2-port QSFP28 x16 8GB(0x1DD8-0x4000)"},
{0x1DD8, 0x1002, 0x1DD8, 0x4001, "Naples 100Gb 2-port QSFP28 x16 4GB(0x1DD8-0x4001)"},
{0x1DD8, 0x1002, 0x1DD8, 0x4002, "Naples 25Gb 2-port SFP28 x8 4GB(0x1DD8-0x4002)"},
{0x1DD8, 0x1002, 0x1DD8, 0x4007, "DSP DSC-25 Ent 10/25G OCP3 Card(0x1DD8-0x4007)"},
{0x1DD8, 0x1002, 0x1DD8, 0x4008, "DSP DSC-25 10/25G 2p SFP28 Card(0x1DD8-0x4008)"},
{0x1DD8, 0x1002, 0x1DD8, 0x400A, "DSC-100 40/100G 2-port 8G RAM 16G eMMC G1 Services Card(0x1DD8-0x400A)"},
{0x1DD8, 0x1002, 0x1DD8, 0x400C, "DSC-25 10/25G 2-port 4G RAM 8G eMMC G1 Services Card(0x1DD8-0x400C)"},
{0x1DD8, 0x1002, 0x1DD8, 0x400D, "DSP DSC-100 Ent 100Gb Card(0x1DD8-0x400D)"},
{0x1DD8, 0x1002, 0x1DD8, 0x400E, "DSC-25 10/25G 2-port 4G RAM 8G eMMC G1 Services Card(0x1DD8-0x400E)"},
{0x1DD8, 0x1002, 0x1DD8, 0x4014, "DSC-100 40/100G 2-port 8G RAM 16G eMMC G1 Services Card(0x1DD8-0x4014)"},
{0x1DD8, 0x1002, 0x1DD8, 0x5001, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 Services Card(0x1DD8-0x5001)"},
{0x1DD8, 0x1002, 0x1DD8, 0x5003, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 Services Card(0x1DD8-0x5003)"},
{0x1DD8, 0x1002, 0x1DD8, 0x5008, "DSC25v2 10/25G 2p 32GB Spl Card(0x1DD8-0x5008)"},
{0x1DD8, 0x1002, 0x1DD8, 0x5009, "DSC2-25 10/25G 2p SFP56 DPU(0x1DD8-0x5009)"},
{0x1DD8, 0x1002, 0x1DD8, 0x500A, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R2(0x1DD8-0x500A)"},
{0x1DD8, 0x1002, 0x1DD8, 0x500B, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU(0x1DD8-0x500B)"},
{0x1DD8, 0x1002, 0x1DD8, 0x500C, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R3(0x1DD8-0x500C)"},
{0x1DD8, 0x1002, 0x1DD8, 0x500D, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R4(0x1DD8-0x500D)"},
{0x1DD8, 0x1002, 0x1DD8, 0x500E, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R5(0x1DD8-0x500E)"},
{0x1DD8, 0x1002, 0x1DD8, 0x500F, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R4-T(0x1DD8-0x500F)"},
{0x1DD8, 0x1003, 0xFFFF, 0xFFFF, "DSC Ethernet Controller VF(0x1003)"},
{0x1DD8, 0x1003, 0x1DD8, 0x100E, "Distributed Services Card(0x1DD8-0x100E)"},
{0x1DD8, 0x1003, 0x1DD8, 0x4000, "Naples 100Gb 2-port QSFP28 x16 8GB(0x1DD8-0x4000)"},
{0x1DD8, 0x1003, 0x1DD8, 0x4001, "Naples 100Gb 2-port QSFP28 x16 4GB(0x1DD8-0x4001)"},
{0x1DD8, 0x1003, 0x1DD8, 0x4002, "Naples 25Gb 2-port SFP28 x8 4GB(0x1DD8-0x4002)"},
{0x1DD8, 0x1003, 0x1DD8, 0x4007, "DSP DSC-25 Ent 10/25G OCP3 Card(0x1DD8-0x4007)"},
{0x1DD8, 0x1003, 0x1DD8, 0x4008, "DSP DSC-25 10/25G 2p SFP28 Card(0x1DD8-0x4008)"},
{0x1DD8, 0x1003, 0x1DD8, 0x400A, "DSC-100 40/100G 2-port 8G RAM 16G eMMC G1 Services Card(0x1DD8-0x400A)"},
{0x1DD8, 0x1003, 0x1DD8, 0x400C, "DSC-25 10/25G 2-port 4G RAM 8G eMMC G1 Services Card(0x1DD8-0x400C)"},
{0x1DD8, 0x1003, 0x1DD8, 0x400D, "DSP DSC-100 Ent 100Gb Card(0x1DD8-0x400D)"},
{0x1DD8, 0x1003, 0x1DD8, 0x400E, "DSC-25 10/25G 2-port 4G RAM 8G eMMC G1 Services Card(0x1DD8-0x400E)"},
{0x1DD8, 0x1003, 0x1DD8, 0x4014, "DSC-100 40/100G 2-port 8G RAM 16G eMMC G1 Services Card(0x1DD8-0x4014)"},
{0x1DD8, 0x1003, 0x1DD8, 0x5001, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 Services Card(0x1DD8-0x5001)"},
{0x1DD8, 0x1003, 0x1DD8, 0x5003, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 Services Card(0x1DD8-0x5003)"},
{0x1DD8, 0x1003, 0x1DD8, 0x5008, "DSC25v2 10/25G 2p 32GB Spl Card(0x1DD8-0x5008)"},
{0x1DD8, 0x1003, 0x1DD8, 0x5009, "DSC2-25 10/25G 2p SFP56 DPU(0x1DD8-0x5009)"},
{0x1DD8, 0x1003, 0x1DD8, 0x500A, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R2(0x1DD8-0x500A)"},
{0x1DD8, 0x1003, 0x1DD8, 0x500B, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU(0x1DD8-0x500B)"},
{0x1DD8, 0x1003, 0x1DD8, 0x500C, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R3(0x1DD8-0x500C)"},
{0x1DD8, 0x1003, 0x1DD8, 0x500D, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R4(0x1DD8-0x500D)"},
{0x1DD8, 0x1003, 0x1DD8, 0x500E, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R5(0x1DD8-0x500E)"},
{0x1DD8, 0x1003, 0x1DD8, 0x500F, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R4-T(0x1DD8-0x500F)"},
{0x1DD8, 0x1004, 0xFFFF, 0xFFFF, "DSC Management Controller(0x1004)"},
{0x1DD8, 0x1004, 0x1DD8, 0x100E, "Distributed Services Card(0x1DD8-0x100E)"},
{0x1DD8, 0x1004, 0x1DD8, 0x4000, "Naples 100Gb 2-port QSFP28 x16 8GB(0x1DD8-0x4000)"},
{0x1DD8, 0x1004, 0x1DD8, 0x4001, "Naples 100Gb 2-port QSFP28 x16 4GB(0x1DD8-0x4001)"},
{0x1DD8, 0x1004, 0x1DD8, 0x4002, "Naples 25Gb 2-port SFP28 x8 4GB(0x1DD8-0x4002)"},
{0x1DD8, 0x1004, 0x1DD8, 0x4007, "DSP DSC-25 Ent 10/25G OCP3 Card(0x1DD8-0x4007)"},
{0x1DD8, 0x1004, 0x1DD8, 0x4008, "DSP DSC-25 10/25G 2p SFP28 Card(0x1DD8-0x4008)"},
{0x1DD8, 0x1004, 0x1DD8, 0x400A, "DSC-100 40/100G 2-port 8G RAM 16G eMMC G1 Services Card(0x1DD8-0x400A)"},
{0x1DD8, 0x1004, 0x1DD8, 0x400C, "DSC-25 10/25G 2-port 4G RAM 8G eMMC G1 Services Card(0x1DD8-0x400C)"},
{0x1DD8, 0x1004, 0x1DD8, 0x400D, "DSP DSC-100 Ent 100Gb Card(0x1DD8-0x400D)"},
{0x1DD8, 0x1004, 0x1DD8, 0x400E, "DSC-25 10/25G 2-port 4G RAM 8G eMMC G1 Services Card(0x1DD8-0x400E)"},
{0x1DD8, 0x1004, 0x1DD8, 0x4014, "DSC-100 40/100G 2-port 8G RAM 16G eMMC G1 Services Card(0x1DD8-0x4014)"},
{0x1DD8, 0x1004, 0x1DD8, 0x5001, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 Services Card(0x1DD8-0x5001)"},
{0x1DD8, 0x1004, 0x1DD8, 0x5003, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 Services Card(0x1DD8-0x5003)"},
{0x1DD8, 0x1004, 0x1DD8, 0x5008, "DSC25v2 10/25G 2p 32GB Spl Card(0x1DD8-0x5008)"},
{0x1DD8, 0x1004, 0x1DD8, 0x5009, "DSC2-25 10/25G 2p SFP56 DPU(0x1DD8-0x5009)"},
{0x1DD8, 0x1004, 0x1DD8, 0x500A, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R2(0x1DD8-0x500A)"},
{0x1DD8, 0x1004, 0x1DD8, 0x500B, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU(0x1DD8-0x500B)"},
{0x1DD8, 0x1004, 0x1DD8, 0x500C, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R3(0x1DD8-0x500C)"},
{0x1DD8, 0x1004, 0x1DD8, 0x500D, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R4(0x1DD8-0x500D)"},
{0x1DD8, 0x1004, 0x1DD8, 0x500E, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R5(0x1DD8-0x500E)"},
{0x1DD8, 0x1004, 0x1DD8, 0x500F, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R4-T(0x1DD8-0x500F)"},
{0x1DD8, 0x1005, 0xFFFF, 0xFFFF, "DSC NVMe Controller(0x1005)"},
{0x1DD8, 0x1005, 0x1DD8, 0x100E, "Distributed Services Card(0x1DD8-0x100E)"},
{0x1DD8, 0x1005, 0x1DD8, 0x5001, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 Services Card(0x1DD8-0x5001)"},
{0x1DD8, 0x1005, 0x1DD8, 0x5003, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 Services Card(0x1DD8-0x5003)"},
{0x1DD8, 0x1005, 0x1DD8, 0x5008, "DSC25v2 10/25G 2p 32GB Spl Card(0x1DD8-0x5008)"},
{0x1DD8, 0x1005, 0x1DD8, 0x5009, "DSC2-25 10/25G 2p SFP56 DPU(0x1DD8-0x5009)"},
{0x1DD8, 0x1005, 0x1DD8, 0x500A, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R2(0x1DD8-0x500A)"},
{0x1DD8, 0x1005, 0x1DD8, 0x500B, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU(0x1DD8-0x500B)"},
{0x1DD8, 0x1005, 0x1DD8, 0x500C, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R3(0x1DD8-0x500C)"},
{0x1DD8, 0x1005, 0x1DD8, 0x500D, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R4(0x1DD8-0x500D)"},
{0x1DD8, 0x1005, 0x1DD8, 0x500E, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R5(0x1DD8-0x500E)"},
{0x1DD8, 0x1005, 0x1DD8, 0x500F, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R4-T(0x1DD8-0x500F)"},
{0x1DD8, 0x1006, 0xFFFF, 0xFFFF, "DSC NVMe Controller VF(0x1006)"},
{0x1DD8, 0x1006, 0x1DD8, 0x100E, "Distributed Services Card(0x1DD8-0x100E)"},
{0x1DD8, 0x1006, 0x1DD8, 0x5001, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 Services Card(0x1DD8-0x5001)"},
{0x1DD8, 0x1006, 0x1DD8, 0x5003, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 Services Card(0x1DD8-0x5003)"},
{0x1DD8, 0x1006, 0x1DD8, 0x5008, "DSC25v2 10/25G 2p 32GB Spl Card(0x1DD8-0x5008)"},
{0x1DD8, 0x1006, 0x1DD8, 0x5009, "DSC2-25 10/25G 2p SFP56 DPU(0x1DD8-0x5009)"},
{0x1DD8, 0x1006, 0x1DD8, 0x500A, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R2(0x1DD8-0x500A)"},
{0x1DD8, 0x1006, 0x1DD8, 0x500B, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU(0x1DD8-0x500B)"},
{0x1DD8, 0x1006, 0x1DD8, 0x500C, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R3(0x1DD8-0x500C)"},
{0x1DD8, 0x1006, 0x1DD8, 0x500D, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R4(0x1DD8-0x500D)"},
{0x1DD8, 0x1006, 0x1DD8, 0x500E, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R5(0x1DD8-0x500E)"},
{0x1DD8, 0x1006, 0x1DD8, 0x500F, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R4-T(0x1DD8-0x500F)"},
{0x1DD8, 0x1007, 0xFFFF, 0xFFFF, "DSC Storage Accelerator(0x1007)"},
{0x1DD8, 0x1007, 0x1DD8, 0x100E, "Distributed Services Card(0x1DD8-0x100E)"},
{0x1DD8, 0x1007, 0x1DD8, 0x4000, "Naples 100Gb 2-port QSFP28 x16 8GB(0x1DD8-0x4000)"},
{0x1DD8, 0x1007, 0x1DD8, 0x4001, "Naples 100Gb 2-port QSFP28 x16 4GB(0x1DD8-0x4001)"},
{0x1DD8, 0x1007, 0x1DD8, 0x4002, "Naples 25Gb 2-port SFP28 x8 4GB(0x1DD8-0x4002)"},
{0x1DD8, 0x1007, 0x1DD8, 0x4007, "DSP DSC-25 Ent 10/25G OCP3 Card(0x1DD8-0x4007)"},
{0x1DD8, 0x1007, 0x1DD8, 0x4008, "DSP DSC-25 10/25G 2p SFP28 Card(0x1DD8-0x4008)"},
{0x1DD8, 0x1007, 0x1DD8, 0x400A, "DSC-100 40/100G 2-port 8G RAM 16G eMMC G1 Services Card(0x1DD8-0x400A)"},
{0x1DD8, 0x1007, 0x1DD8, 0x400C, "DSC-25 10/25G 2-port 4G RAM 8G eMMC G1 Services Card(0x1DD8-0x400C)"},
{0x1DD8, 0x1007, 0x1DD8, 0x400D, "DSP DSC-100 Ent 100Gb Card(0x1DD8-0x400D)"},
{0x1DD8, 0x1007, 0x1DD8, 0x400E, "DSC-25 10/25G 2-port 4G RAM 8G eMMC G1 Services Card(0x1DD8-0x400E)"},
{0x1DD8, 0x1007, 0x1DD8, 0x4014, "DSC-100 40/100G 2-port 8G RAM 16G eMMC G1 Services Card(0x1DD8-0x4014)"},
{0x1DD8, 0x1007, 0x1DD8, 0x5001, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 Services Card(0x1DD8-0x5001)"},
{0x1DD8, 0x1007, 0x1DD8, 0x5003, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 Services Card(0x1DD8-0x5003)"},
{0x1DD8, 0x1007, 0x1DD8, 0x5008, "DSC25v2 10/25G 2p 32GB Spl Card(0x1DD8-0x5008)"},
{0x1DD8, 0x1007, 0x1DD8, 0x5009, "DSC2-25 10/25G 2p SFP56 DPU(0x1DD8-0x5009)"},
{0x1DD8, 0x1007, 0x1DD8, 0x500A, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R2(0x1DD8-0x500A)"},
{0x1DD8, 0x1007, 0x1DD8, 0x500B, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU(0x1DD8-0x500B)"},
{0x1DD8, 0x1007, 0x1DD8, 0x500C, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R3(0x1DD8-0x500C)"},
{0x1DD8, 0x1007, 0x1DD8, 0x500D, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R4(0x1DD8-0x500D)"},
{0x1DD8, 0x1007, 0x1DD8, 0x500E, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R5(0x1DD8-0x500E)"},
{0x1DD8, 0x1007, 0x1DD8, 0x500F, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R4-T(0x1DD8-0x500F)"},
{0x1DD8, 0x1009, 0xFFFF, 0xFFFF, "DSC Ethernet Controller UPT(0x1009)"},
{0x1DD8, 0x1009, 0x1DD8, 0x100E, "Distributed Services Card(0x1DD8-0x100E)"},
{0x1DD8, 0x1009, 0x1DD8, 0x5001, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 Services Card(0x1DD8-0x5001)"},
{0x1DD8, 0x1009, 0x1DD8, 0x5003, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 Services Card(0x1DD8-0x5003)"},
{0x1DD8, 0x1009, 0x1DD8, 0x5008, "DSC25v2 10/25G 2p 32GB Spl Card(0x1DD8-0x5008)"},
{0x1DD8, 0x1009, 0x1DD8, 0x5009, "DSC2-25 10/25G 2p SFP56 DPU(0x1DD8-0x5009)"},
{0x1DD8, 0x1009, 0x1DD8, 0x500A, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R2(0x1DD8-0x500A)"},
{0x1DD8, 0x1009, 0x1DD8, 0x500B, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU(0x1DD8-0x500B)"},
{0x1DD8, 0x1009, 0x1DD8, 0x500C, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R3(0x1DD8-0x500C)"},
{0x1DD8, 0x1009, 0x1DD8, 0x500D, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R4(0x1DD8-0x500D)"},
{0x1DD8, 0x1009, 0x1DD8, 0x500E, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R5(0x1DD8-0x500E)"},
{0x1DD8, 0x1009, 0x1DD8, 0x500F, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R4-T(0x1DD8-0x500F)"},
{0x1DD8, 0x100A, 0xFFFF, 0xFFFF, "DSC Serial Port Controller(0x100A)"},
{0x1DD8, 0x100A, 0x1DD8, 0x100E, "Distributed Services Card(0x1DD8-0x100E)"},
{0x1DD8, 0x100A, 0x1DD8, 0x5001, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 Services Card(0x1DD8-0x5001)"},
{0x1DD8, 0x100A, 0x1DD8, 0x5003, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 Services Card(0x1DD8-0x5003)"},
{0x1DD8, 0x100A, 0x1DD8, 0x5008, "DSC25v2 10/25G 2p 32GB Spl Card(0x1DD8-0x5008)"},
{0x1DD8, 0x100A, 0x1DD8, 0x5009, "DSC2-25 10/25G 2p SFP56 DPU(0x1DD8-0x5009)"},
{0x1DD8, 0x100A, 0x1DD8, 0x500A, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R2(0x1DD8-0x500A)"},
{0x1DD8, 0x100A, 0x1DD8, 0x500B, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU(0x1DD8-0x500B)"},
{0x1DD8, 0x100A, 0x1DD8, 0x500C, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R3(0x1DD8-0x500C)"},
{0x1DD8, 0x100A, 0x1DD8, 0x500D, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R4(0x1DD8-0x500D)"},
{0x1DD8, 0x100A, 0x1DD8, 0x500E, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R5(0x1DD8-0x500E)"},
{0x1DD8, 0x100A, 0x1DD8, 0x500F, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R4-T(0x1DD8-0x500F)"},
{0x1DD8, 0x100B, 0xFFFF, 0xFFFF, "DSC vDPA Network Device VF(0x100B)"},
{0x1DD8, 0x100B, 0x1DD8, 0x100E, "Distributed Services Card(0x1DD8-0x100E)"},
{0x1DD8, 0x100B, 0x1DD8, 0x5001, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 Services Card(0x1DD8-0x5001)"},
{0x1DD8, 0x100B, 0x1DD8, 0x5003, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 Services Card(0x1DD8-0x5003)"},
{0x1DD8, 0x100B, 0x1DD8, 0x5008, "DSC25v2 10/25G 2p 32GB Spl Card(0x1DD8-0x5008)"},
{0x1DD8, 0x100B, 0x1DD8, 0x5009, "DSC2-25 10/25G 2p SFP56 DPU(0x1DD8-0x5009)"},
{0x1DD8, 0x100B, 0x1DD8, 0x500A, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R2(0x1DD8-0x500A)"},
{0x1DD8, 0x100B, 0x1DD8, 0x500B, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU(0x1DD8-0x500B)"},
{0x1DD8, 0x100B, 0x1DD8, 0x500C, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R3(0x1DD8-0x500C)"},
{0x1DD8, 0x100B, 0x1DD8, 0x500D, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R4(0x1DD8-0x500D)"},
{0x1DD8, 0x100B, 0x1DD8, 0x500E, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R5(0x1DD8-0x500E)"},
{0x1DD8, 0x100B, 0x1DD8, 0x500F, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R4-T(0x1DD8-0x500F)"},
{0x1DD8, 0x100C, 0xFFFF, 0xFFFF, "DSC PDS Core Management(0x100C)"},
{0x1DD8, 0x100C, 0x1DD8, 0x100E, "Distributed Services Card(0x1DD8-0x100E)"},
{0x1DD8, 0x100C, 0x1DD8, 0x5001, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 Services Card(0x1DD8-0x5001)"},
{0x1DD8, 0x100C, 0x1DD8, 0x5003, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 Services Card(0x1DD8-0x5003)"},
{0x1DD8, 0x100C, 0x1DD8, 0x5008, "DSC25v2 10/25G 2p 32GB Spl Card(0x1DD8-0x5008)"},
{0x1DD8, 0x100C, 0x1DD8, 0x5009, "DSC2-25 10/25G 2p SFP56 DPU(0x1DD8-0x5009)"},
{0x1DD8, 0x100C, 0x1DD8, 0x500A, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R2(0x1DD8-0x500A)"},
{0x1DD8, 0x100C, 0x1DD8, 0x500B, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU(0x1DD8-0x500B)"},
{0x1DD8, 0x100C, 0x1DD8, 0x500C, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R3(0x1DD8-0x500C)"},
{0x1DD8, 0x100C, 0x1DD8, 0x500D, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R4(0x1DD8-0x500D)"},
{0x1DD8, 0x100C, 0x1DD8, 0x500E, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R5(0x1DD8-0x500E)"},
{0x1DD8, 0x100C, 0x1DD8, 0x500F, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R4-T(0x1DD8-0x500F)"},
{0x1DD8, 0x100D, 0xFFFF, 0xFFFF, "DSC Virtio Network Device VF(0x100D)"},
{0x1DD8, 0x100D, 0x1DD8, 0x100E, "Distributed Services Card(0x1DD8-0x100E)"},
{0x1DD8, 0x100D, 0x1DD8, 0x5001, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 Services Card(0x1DD8-0x5001)"},
{0x1DD8, 0x100D, 0x1DD8, 0x5003, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 Services Card(0x1DD8-0x5003)"},
{0x1DD8, 0x100D, 0x1DD8, 0x5008, "DSC25v2 10/25G 2p 32GB Spl Card(0x1DD8-0x5008)"},
{0x1DD8, 0x100D, 0x1DD8, 0x5009, "DSC2-25 10/25G 2p SFP56 DPU(0x1DD8-0x5009)"},
{0x1DD8, 0x100D, 0x1DD8, 0x500A, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R2(0x1DD8-0x500A)"},
{0x1DD8, 0x100D, 0x1DD8, 0x500B, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU(0x1DD8-0x500B)"},
{0x1DD8, 0x100D, 0x1DD8, 0x500C, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R3(0x1DD8-0x500C)"},
{0x1DD8, 0x100D, 0x1DD8, 0x500D, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R4(0x1DD8-0x500D)"},
{0x1DD8, 0x100D, 0x1DD8, 0x500E, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R5(0x1DD8-0x500E)"},
{0x1DD8, 0x100D, 0x1DD8, 0x500F, "DSC2-200 50/100/200G 2-port 32G RAM 64G eMMC G2 DPU R4-T(0x1DD8-0x500F)"},
}; /* pci_vid_1DD8[] */

static pci_id_t const pci_vid_1DDD[] = {
{0x1DDD, 0xFFFF, 0xFFFF, 0xFFFF, "Thorlabs(0x1DDD)"},
}; /* pci_vid_1DDD[] */

static pci_id_t const pci_vid_1DE0[] = {
{0x1DE0, 0xFFFF, 0xFFFF, 0xFFFF, "Groq(0x1DE0)"},
{0x1DE0, 0x0000, 0xFFFF, 0xFFFF, "TSP [GroqChip](0x0000)"},
{0x1DE0, 0x0000, 0x1DE0, 0x0000, "GC1-010X-ES [GroqCard](0x1DE0-0x0000)"},
{0x1DE0, 0x0000, 0x1DE0, 0xC005, "GC1-010B [GroqCard](0x1DE0-0xC005)"},
{0x1DE0, 0x0000, 0x1DE0, 0xC006, "GC1-0109 [GroqCard](0x1DE0-0xC006)"},
{0x1DE0, 0x0000, 0x1DE0, 0xC007, "GC1-0100 [GroqCard](0x1DE0-0xC007)"},
}; /* pci_vid_1DE0[] */

static pci_id_t const pci_vid_1DE1[] = {
{0x1DE1, 0xFFFF, 0xFFFF, 0xFFFF, "Tekram Technology Co.,Ltd.(0x1DE1)"},
{0x1DE1, 0x0391, 0xFFFF, 0xFFFF, "TRM-S1040 [DC-315 / DC-395 series](0x0391)"},
{0x1DE1, 0x2020, 0xFFFF, 0xFFFF, "DC-390 Series SCSI Adapter [AMD Am53C974](0x2020)"},
{0x1DE1, 0x690C, 0xFFFF, 0xFFFF, "690c(0x690C)"},
{0x1DE1, 0xDC29, 0xFFFF, 0xFFFF, "DC290(0xDC29)"},
}; /* pci_vid_1DE1[] */

static pci_id_t const pci_vid_1DE4[] = {
{0x1DE4, 0xFFFF, 0xFFFF, 0xFFFF, "Raspberry Pi Ltd(0x1DE4)"},
{0x1DE4, 0x0001, 0xFFFF, 0xFFFF, "RP1 PCIe 2.0 South Bridge(0x0001)"},
}; /* pci_vid_1DE4[] */

static pci_id_t const pci_vid_1DE5[] = {
{0x1DE5, 0xFFFF, 0xFFFF, 0xFFFF, "Eideticom, Inc(0x1DE5)"},
{0x1DE5, 0x1000, 0xFFFF, 0xFFFF, "IO Memory Controller(0x1000)"},
{0x1DE5, 0x2000, 0xFFFF, 0xFFFF, "NoLoad Hardware Development Kit(0x2000)"},
{0x1DE5, 0x3000, 0xFFFF, 0xFFFF, "eBPF-based PCIe Accelerator(0x3000)"},
}; /* pci_vid_1DE5[] */

static pci_id_t const pci_vid_1DED[] = {
{0x1DED, 0xFFFF, 0xFFFF, 0xFFFF, "Alibaba (China) Co., Ltd.(0x1DED)"},
{0x1DED, 0x107F, 0xFFFF, 0xFFFF, "Elastic RDMA Adapter(0x107F)"},
{0x1DED, 0x5007, 0xFFFF, 0xFFFF, "Elastic RDMA Adapter(0x5007)"},
{0x1DED, 0x8000, 0xFFFF, 0xFFFF, "M1 Root Port(0x8000)"},
{0x1DED, 0x8001, 0xFFFF, 0xFFFF, "ACC-RCiEP(0x8001)"},
{0x1DED, 0x8002, 0xFFFF, 0xFFFF, "RCiEP VF(0x8002)"},
{0x1DED, 0x8003, 0xFFFF, 0xFFFF, "RCEC PF(0x8003)"},
{0x1DED, 0x8004, 0xFFFF, 0xFFFF, "RCEC VF(0x8004)"},
}; /* pci_vid_1DED[] */

static pci_id_t const pci_vid_1DEE[] = {
{0x1DEE, 0xFFFF, 0xFFFF, 0xFFFF, "Biwin Storage Technology Co., Ltd.(0x1DEE)"},
{0x1DEE, 0x2262, 0xFFFF, 0xFFFF, "HP EX950 NVMe SSD(0x2262)"},
{0x1DEE, 0x2263, 0xFFFF, 0xFFFF, "HP EX900 NVMe SSD (DRAM-less)(0x2263)"},
{0x1DEE, 0x5216, 0xFFFF, 0xFFFF, "KingSpec NX series NVMe SSD (DRAM-less)(0x5216)"},
}; /* pci_vid_1DEE[] */

static pci_id_t const pci_vid_1DEF[] = {
{0x1DEF, 0xFFFF, 0xFFFF, 0xFFFF, "Ampere Computing, LLC(0x1DEF)"},
{0x1DEF, 0xE005, 0xFFFF, 0xFFFF, "eMAG PCI Express Root Port 0(0xE005)"},
{0x1DEF, 0xE006, 0xFFFF, 0xFFFF, "eMAG PCI Express Root Port 1(0xE006)"},
{0x1DEF, 0xE007, 0xFFFF, 0xFFFF, "eMAG PCI Express Root Port 2(0xE007)"},
{0x1DEF, 0xE008, 0xFFFF, 0xFFFF, "eMAG PCI Express Root Port 3(0xE008)"},
{0x1DEF, 0xE009, 0xFFFF, 0xFFFF, "eMAG PCI Express Root Port 4(0xE009)"},
{0x1DEF, 0xE00A, 0xFFFF, 0xFFFF, "eMAG PCI Express Root Port 5(0xE00A)"},
{0x1DEF, 0xE00B, 0xFFFF, 0xFFFF, "eMAG PCI Express Root Port 6(0xE00B)"},
{0x1DEF, 0xE00C, 0xFFFF, 0xFFFF, "eMAG PCI Express Root Port 7(0xE00C)"},
{0x1DEF, 0xE100, 0xFFFF, 0xFFFF, "Altra PCI Express Root Complex A(0xE100)"},
{0x1DEF, 0xE101, 0xFFFF, 0xFFFF, "Altra PCI Express Root Port a0(0xE101)"},
{0x1DEF, 0xE102, 0xFFFF, 0xFFFF, "Altra PCI Express Root Port a1(0xE102)"},
{0x1DEF, 0xE103, 0xFFFF, 0xFFFF, "Altra PCI Express Root Port a2(0xE103)"},
{0x1DEF, 0xE104, 0xFFFF, 0xFFFF, "Altra PCI Express Root Port a3(0xE104)"},
{0x1DEF, 0xE105, 0xFFFF, 0xFFFF, "Altra PCI Express Root Port a4(0xE105)"},
{0x1DEF, 0xE106, 0xFFFF, 0xFFFF, "Altra PCI Express Root Port a5(0xE106)"},
{0x1DEF, 0xE107, 0xFFFF, 0xFFFF, "Altra PCI Express Root Port a6(0xE107)"},
{0x1DEF, 0xE108, 0xFFFF, 0xFFFF, "Altra PCI Express Root Port a7(0xE108)"},
{0x1DEF, 0xE110, 0xFFFF, 0xFFFF, "Altra PCI Express Root Complex B(0xE110)"},
{0x1DEF, 0xE111, 0xFFFF, 0xFFFF, "Altra PCI Express Root Port b0(0xE111)"},
{0x1DEF, 0xE112, 0xFFFF, 0xFFFF, "Altra PCI Express Root Port b1(0xE112)"},
{0x1DEF, 0xE113, 0xFFFF, 0xFFFF, "Altra PCI Express Root Port b2(0xE113)"},
{0x1DEF, 0xE114, 0xFFFF, 0xFFFF, "Altra PCI Express Root Port b3(0xE114)"},
{0x1DEF, 0xE115, 0xFFFF, 0xFFFF, "Altra PCI Express Root Port b4(0xE115)"},
{0x1DEF, 0xE116, 0xFFFF, 0xFFFF, "Altra PCI Express Root Port b5(0xE116)"},
{0x1DEF, 0xE117, 0xFFFF, 0xFFFF, "Altra PCI Express Root Port b6(0xE117)"},
{0x1DEF, 0xE118, 0xFFFF, 0xFFFF, "Altra PCI Express Root Port b7(0xE118)"},
}; /* pci_vid_1DEF[] */

static pci_id_t const pci_vid_1DF3[] = {
{0x1DF3, 0xFFFF, 0xFFFF, 0xFFFF, "Ethernity Networks(0x1DF3)"},
{0x1DF3, 0x0201, 0xFFFF, 0xFFFF, "ACE-NIC40 Programmable Network Accelerator(0x0201)"},
{0x1DF3, 0x0201, 0x1DF3, 0x0001, "ENA1040(0x1DF3-0x0001)"},
{0x1DF3, 0x0201, 0x1DF3, 0x0002, "ENA1044(0x1DF3-0x0002)"},
{0x1DF3, 0x0201, 0x1DF3, 0x0003, "ENA1044S(0x1DF3-0x0003)"},
{0x1DF3, 0x0202, 0xFFFF, 0xFFFF, "ACE-NIC50 Programmable Network Accelerator(0x0202)"},
{0x1DF3, 0x0202, 0x1DF3, 0x0001, "ENA2050F(0x1DF3-0x0001)"},
{0x1DF3, 0x0202, 0x1DF3, 0x0002, "ENA2050FS(0x1DF3-0x0002)"},
{0x1DF3, 0x0203, 0xFFFF, 0xFFFF, "ACE-NIC100 Programmable Network Accelerator(0x0203)"},
{0x1DF3, 0x0203, 0x1DF3, 0x0000, "Maintenance Mode(0x1DF3-0x0000)"},
{0x1DF3, 0x0203, 0x1DF3, 0x0001, "ENA2080F(0x1DF3-0x0001)"},
{0x1DF3, 0x0203, 0x1DF3, 0x0002, "ENA2080FS(0x1DF3-0x0002)"},
{0x1DF3, 0x0203, 0x1DF3, 0x0003, "ENA2100F(0x1DF3-0x0003)"},
{0x1DF3, 0x0203, 0x1DF3, 0x0004, "ENA2040F(0x1DF3-0x0004)"},
{0x1DF3, 0x0204, 0xFFFF, 0xFFFF, "ACE-NIC-NID Programmable Network Accelerator(0x0204)"},
{0x1DF3, 0x0204, 0x1DF3, 0x0001, "ENA1020Z(0x1DF3-0x0001)"},
{0x1DF3, 0x0204, 0x1DF3, 0x0002, "ENA1020ZS(0x1DF3-0x0002)"},
{0x1DF3, 0x0205, 0xFFFF, 0xFFFF, "ACE-NIC250 Programmable Network Accelerator(0x0205)"},
{0x1DF3, 0x0205, 0x1DF3, 0x0000, "Maintenance Mode(0x1DF3-0x0000)"},
{0x1DF3, 0x0205, 0x1DF3, 0x0001, "ENA2250F(0x1DF3-0x0001)"},
{0x1DF3, 0x0206, 0xFFFF, 0xFFFF, "ACE-NIC200 Programmable Network Accelerator(0x0206)"},
{0x1DF3, 0x0206, 0x1DF3, 0x0000, "Maintenance Mode(0x1DF3-0x0000)"},
{0x1DF3, 0x0206, 0x1DF3, 0x0001, "ENA2200F(0x1DF3-0x0001)"},
{0x1DF3, 0x0207, 0xFFFF, 0xFFFF, "ACE-NIC50RN Programmable Network Accelerator(0x0207)"},
{0x1DF3, 0x0207, 0x1DF3, 0x0000, "Maintenance Mode(0x1DF3-0x0000)"},
{0x1DF3, 0x0207, 0x1DF3, 0x0001, "ENA2050RN(0x1DF3-0x0001)"},
{0x1DF3, 0x0208, 0xFFFF, 0xFFFF, "ACE-NIC100RN Programmable Network Accelerator(0x0208)"},
{0x1DF3, 0x0208, 0x1DF3, 0x0000, "Maintenance Mode(0x1DF3-0x0000)"},
{0x1DF3, 0x0208, 0x1DF3, 0x0001, "ENA2100RN(0x1DF3-0x0001)"},
}; /* pci_vid_1DF3[] */

static pci_id_t const pci_vid_1DF5[] = {
{0x1DF5, 0xFFFF, 0xFFFF, 0xFFFF, "Shenzhen TIGO Semiconductor(0x1DF5)"},
{0x1DF5, 0x1202, 0xFFFF, 0xFFFF, "kimtigo NVMe SSD (DRAM-less)(0x1202)"},
{0x1DF5, 0x2263, 0xFFFF, 0xFFFF, "kimtigo MG931K NVMe SSD (DRAM-less)(0x2263)"},
}; /* pci_vid_1DF5[] */

static pci_id_t const pci_vid_1DF7[] = {
{0x1DF7, 0xFFFF, 0xFFFF, 0xFFFF, "opencpi.org(0x1DF7)"},
{0x1DF7, 0x0001, 0xFFFF, 0xFFFF, "ml605(0x0001)"},
{0x1DF7, 0x0002, 0xFFFF, 0xFFFF, "alst4(0x0002)"},
{0x1DF7, 0x0003, 0xFFFF, 0xFFFF, "alst4x(0x0003)"},
}; /* pci_vid_1DF7[] */

static pci_id_t const pci_vid_1DF8[] = {
{0x1DF8, 0xFFFF, 0xFFFF, 0xFFFF, "V&G Information System Co.,Ltd(0x1DF8)"},
{0x1DF8, 0x3000, 0xFFFF, 0xFFFF, "PC NVMe SSD(0x3000)"},
{0x1DF8, 0x3000, 0x1DF8, 0x3100, "M.2 NVMe Gen3*4 SSD(0x1DF8-0x3100)"},
{0x1DF8, 0xC000, 0xFFFF, 0xFFFF, "DC NVMe SSD(0xC000)"},
{0x1DF8, 0xC000, 0x1DF8, 0xC600, "Enterprise U.2 NVMe SSD(0x1DF8-0xC600)"},
{0x1DF8, 0xD000, 0xFFFF, 0xFFFF, "PC NVMe SSD(0xD000)"},
{0x1DF8, 0xD000, 0x1DF8, 0xD100, "M.2 NVMe SSD(0x1DF8-0xD100)"},
{0x1DF8, 0xD000, 0x1DF8, 0xD201, "M.2 NVMe SSD(0x1DF8-0xD201)"},
{0x1DF8, 0xD000, 0x1DF8, 0xD600, "M.2 NVMe SSD(0x1DF8-0xD600)"},
}; /* pci_vid_1DF8[] */

static pci_id_t const pci_vid_1DFA[] = {
{0x1DFA, 0xFFFF, 0xFFFF, 0xFFFF, "Astera Labs, Inc.(0x1DFA)"},
}; /* pci_vid_1DFA[] */

static pci_id_t const pci_vid_1DFC[] = {
{0x1DFC, 0xFFFF, 0xFFFF, 0xFFFF, "JSC NT-COM(0x1DFC)"},
{0x1DFC, 0x1181, 0xFFFF, 0xFFFF, "TDM 8 Port E1/T1/J1 Adapter(0x1181)"},
}; /* pci_vid_1DFC[] */

static pci_id_t const pci_vid_1E0D[] = {
{0x1E0D, 0xFFFF, 0xFFFF, 0xFFFF, "SambaNova Systems, Inc(0x1E0D)"},
}; /* pci_vid_1E0D[] */

static pci_id_t const pci_vid_1E0F[] = {
{0x1E0F, 0xFFFF, 0xFFFF, 0xFFFF, "KIOXIA Corporation(0x1E0F)"},
{0x1E0F, 0x0001, 0xFFFF, 0xFFFF, "NVMe SSD Controller BG4 (DRAM-less)(0x0001)"},
{0x1E0F, 0x0007, 0xFFFF, 0xFFFF, "NVMe SSD Controller Cx6(0x0007)"},
{0x1E0F, 0x0007, 0x1028, 0x2078, "DC NVMe CD6 RI 960GB(0x1028-0x2078)"},
{0x1E0F, 0x0007, 0x1028, 0x2079, "DC NVMe CD6 RI 1.92TB(0x1028-0x2079)"},
{0x1E0F, 0x0007, 0x1028, 0x207A, "DC NVMe CD6 RI 3.84TB(0x1028-0x207A)"},
{0x1E0F, 0x0007, 0x1028, 0x207B, "DC NVMe CD6 RI 7.68TB(0x1028-0x207B)"},
{0x1E0F, 0x0007, 0x1028, 0x207C, "DC NVMe CD6 RI 15.36TB(0x1028-0x207C)"},
{0x1E0F, 0x0007, 0x1028, 0x207E, "Dell Ent NVMe CM6 RI 1.92TB(0x1028-0x207E)"},
{0x1E0F, 0x0007, 0x1028, 0x207F, "Dell Ent NVMe CM6 RI 3.84TB(0x1028-0x207F)"},
{0x1E0F, 0x0007, 0x1028, 0x2080, "Dell Ent NVMe CM6 RI 7.68TB(0x1028-0x2080)"},
{0x1E0F, 0x0007, 0x1028, 0x2081, "Dell Ent NVMe CM6 RI 15.36TB(0x1028-0x2081)"},
{0x1E0F, 0x0007, 0x1028, 0x2084, "Dell Ent NVMe CM6 MU 1.6TB(0x1028-0x2084)"},
{0x1E0F, 0x0007, 0x1028, 0x2085, "Dell Ent NVMe CM6 MU 3.2TB(0x1028-0x2085)"},
{0x1E0F, 0x0007, 0x1028, 0x2086, "Dell Ent NVMe CM6 MU 6.4TB(0x1028-0x2086)"},
{0x1E0F, 0x0007, 0x1028, 0x210A, "Dell Ent NVMe FIPS CM6 RI 1.92TB(0x1028-0x210A)"},
{0x1E0F, 0x0007, 0x1028, 0x210B, "Dell Ent NVMe FIPS CM6 RI 3.84TB(0x1028-0x210B)"},
{0x1E0F, 0x0007, 0x1028, 0x210C, "Dell Ent NVMe FIPS CM6 RI 7.68TB(0x1028-0x210C)"},
{0x1E0F, 0x0007, 0x1028, 0x210D, "Dell Ent NVMe FIPS CM6 RI15.36TB(0x1028-0x210D)"},
{0x1E0F, 0x0007, 0x1028, 0x210E, "Dell Ent NVMe FIPS CM6 MU 1.6TB(0x1028-0x210E)"},
{0x1E0F, 0x0007, 0x1028, 0x210F, "Dell Ent NVMe FIPS CM6 MU 3.2TB(0x1028-0x210F)"},
{0x1E0F, 0x0007, 0x1028, 0x2110, "Dell Ent NVMe FIPS CM6 MU 6.4TB(0x1028-0x2110)"},
{0x1E0F, 0x0007, 0x1E0F, 0x0001, "Generic NVMe CM6(0x1E0F-0x0001)"},
{0x1E0F, 0x0008, 0xFFFF, 0xFFFF, "RD500/Exceria Plus/Exceria Plus G2 NVMe SSD(0x0008)"},
{0x1E0F, 0x0009, 0xFFFF, 0xFFFF, "NVMe SSD(0x0009)"},
{0x1E0F, 0x0009, 0x1E0F, 0x0001, "Toshiba RC500 Series NVMe SSD(0x1E0F-0x0001)"},
{0x1E0F, 0x0009, 0x1E0F, 0x0032, "KIOXIA EXCERIA RC10 Series NVMe SSD(0x1E0F-0x0032)"},
{0x1E0F, 0x000C, 0xFFFF, 0xFFFF, "NVMe SSD Controller BG5 (DRAM-less)(0x000C)"},
{0x1E0F, 0x000D, 0xFFFF, 0xFFFF, "NVMe SSD Controller XG7(0x000D)"},
{0x1E0F, 0x0010, 0xFFFF, 0xFFFF, "NVMe SSD Controller XG8(0x0010)"},
{0x1E0F, 0x0011, 0xFFFF, 0xFFFF, "NVMe SSD Controller CD7(0x0011)"},
{0x1E0F, 0x0011, 0x1028, 0x2189, "DC NVMe SED CD7 RI 960GB(0x1028-0x2189)"},
{0x1E0F, 0x0011, 0x1028, 0x218A, "DC NVMe CD7 RI 960GB(0x1028-0x218A)"},
{0x1E0F, 0x0011, 0x1028, 0x218B, "DC NVMe SED CD7 RI 1.92TB(0x1028-0x218B)"},
{0x1E0F, 0x0011, 0x1028, 0x218C, "DC NVMe CD7 RI 1.92TB(0x1028-0x218C)"},
{0x1E0F, 0x0011, 0x1028, 0x218D, "DC NVMe SED CD7 RI 3.84TB(0x1028-0x218D)"},
{0x1E0F, 0x0011, 0x1028, 0x218E, "DC NVMe CD7 RI 3.84TB(0x1028-0x218E)"},
{0x1E0F, 0x0011, 0x1028, 0x218F, "DC NVMe SED CD7 RI 7.68TB(0x1028-0x218F)"},
{0x1E0F, 0x0011, 0x1028, 0x2190, "DC NVMe CD7 RI 7.68TB(0x1028-0x2190)"},
{0x1E0F, 0x0011, 0x1028, 0x2191, "DC NVMe SED CD7 RI 15.36TB(0x1028-0x2191)"},
{0x1E0F, 0x0011, 0x1028, 0x2192, "DC NVMe CD7 RI 15.36TB(0x1028-0x2192)"},
{0x1E0F, 0x0011, 0x1028, 0x2193, "NVMe CD7 E3.S 1.92TB(0x1028-0x2193)"},
{0x1E0F, 0x0011, 0x1028, 0x2194, "NVMe CD7 E3.S 3.84TB(0x1028-0x2194)"},
{0x1E0F, 0x0011, 0x1028, 0x2195, "NVMe CD7 E3.S 7.68TB(0x1028-0x2195)"},
{0x1E0F, 0x0014, 0xFFFF, 0xFFFF, "NVMe SSD Controller CM7 EDSFF(0x0014)"},
{0x1E0F, 0x0014, 0x1028, 0x223F, "Ent NVMe CM7 FIPS E3.S RI 15.36TB(0x1028-0x223F)"},
{0x1E0F, 0x0014, 0x1028, 0x2240, "Ent NVMe CM7 FIPS E3.S RI 7.68TB(0x1028-0x2240)"},
{0x1E0F, 0x0014, 0x1028, 0x2241, "Ent NVMe CM7 FIPS E3.S RI 3.84TB(0x1028-0x2241)"},
{0x1E0F, 0x0014, 0x1028, 0x2242, "Ent NVMe CM7 E3.S RI 15.36TB(0x1028-0x2242)"},
{0x1E0F, 0x0014, 0x1028, 0x2243, "Ent NVMe CM7 E3.S RI 7.68TB(0x1028-0x2243)"},
{0x1E0F, 0x0014, 0x1028, 0x2244, "Ent NVMe CM7 E3.S RI 3.84TB(0x1028-0x2244)"},
{0x1E0F, 0x0014, 0x1028, 0x2245, "Ent NVMe CM7 E3.S RI 1.92TB(0x1028-0x2245)"},
{0x1E0F, 0x0014, 0x1028, 0x2246, "Ent NVMe CM7 E3.S MU 12.8TB(0x1028-0x2246)"},
{0x1E0F, 0x0014, 0x1028, 0x2247, "Ent NVMe CM7 E3.S MU 6.4TB(0x1028-0x2247)"},
{0x1E0F, 0x0014, 0x1028, 0x2248, "Ent NVMe CM7 E3.S MU 3.2TB(0x1028-0x2248)"},
{0x1E0F, 0x0014, 0x1028, 0x2249, "Ent NVMe CM7 E3.S MU 1.6TB(0x1028-0x2249)"},
{0x1E0F, 0x0014, 0x1028, 0x22B7, "Ent NVMe CM7 FIPS E3.S MU 1.6TB(0x1028-0x22B7)"},
{0x1E0F, 0x0014, 0x1028, 0x22B8, "Ent NVMe CM7 FIPS E3.S MU 3.2TB(0x1028-0x22B8)"},
{0x1E0F, 0x0014, 0x1028, 0x22B9, "Ent NVMe CM7 FIPS E3.S MU 6.4TB(0x1028-0x22B9)"},
{0x1E0F, 0x0014, 0x1028, 0x22BA, "Ent NVMe CM7 FIPS E3.S MU 12.8TB(0x1028-0x22BA)"},
{0x1E0F, 0x0018, 0xFFFF, 0xFFFF, "Exceria Pro NVMe SSD(0x0018)"},
{0x1E0F, 0x001A, 0xFFFF, 0xFFFF, "NVMe SSD Controller BG6 (DRAM-less)(0x001A)"},
{0x1E0F, 0x001F, 0xFFFF, 0xFFFF, "NVMe SSD Controller CD8(0x001F)"},
{0x1E0F, 0x001F, 0x1028, 0x2223, "DC NVMe CD8 U.2 SED 15.36TB(0x1028-0x2223)"},
{0x1E0F, 0x001F, 0x1028, 0x2224, "DC NVMe CD8 U.2 SED 7.68TB(0x1028-0x2224)"},
{0x1E0F, 0x001F, 0x1028, 0x2225, "DC NVMe CD8 U.2 SED 3.84TB(0x1028-0x2225)"},
{0x1E0F, 0x001F, 0x1028, 0x2226, "DC NVMe CD8 U.2 SED 1.92TB(0x1028-0x2226)"},
{0x1E0F, 0x001F, 0x1028, 0x2227, "DC NVMe CD8 U.2 SED 960GB(0x1028-0x2227)"},
{0x1E0F, 0x001F, 0x1028, 0x2228, "DC NVMe CD8 U.2 15.36TB(0x1028-0x2228)"},
{0x1E0F, 0x001F, 0x1028, 0x2229, "DC NVMe CD8 U.2 7.68TB(0x1028-0x2229)"},
{0x1E0F, 0x001F, 0x1028, 0x222A, "DC NVMe CD8 U.2 3.84TB(0x1028-0x222A)"},
{0x1E0F, 0x001F, 0x1028, 0x222B, "DC NVMe CD8 U.2 1.92TB(0x1028-0x222B)"},
{0x1E0F, 0x001F, 0x1028, 0x222C, "DC NVMe CD8 U.2 960GB(0x1028-0x222C)"},
{0x1E0F, 0x0025, 0xFFFF, 0xFFFF, "NVMe SSD Controller CM7 2.5\"(0x0025)"},
{0x1E0F, 0x0025, 0x1028, 0x222D, "Ent NVMe CM7 FIPS U.2 RI 30.72TB(0x1028-0x222D)"},
{0x1E0F, 0x0025, 0x1028, 0x222E, "Ent NVMe CM7 FIPS U.2 RI 15.36TB(0x1028-0x222E)"},
{0x1E0F, 0x0025, 0x1028, 0x222F, "Ent NVMe CM7 FIPS U.2 RI 7.68TB(0x1028-0x222F)"},
{0x1E0F, 0x0025, 0x1028, 0x2230, "Ent NVMe CM7 FIPS U.2 RI 3.84TB(0x1028-0x2230)"},
{0x1E0F, 0x0025, 0x1028, 0x2231, "Ent NVMe CM7 FIPS U.2 RI 1.92TB(0x1028-0x2231)"},
{0x1E0F, 0x0025, 0x1028, 0x2232, "Ent NVMe CM7 U.2 RI 30.72TB(0x1028-0x2232)"},
{0x1E0F, 0x0025, 0x1028, 0x2233, "Ent NVMe CM7 U.2 RI 15.36TB(0x1028-0x2233)"},
{0x1E0F, 0x0025, 0x1028, 0x2234, "Ent NVMe CM7 U.2 RI 7.68TB(0x1028-0x2234)"},
{0x1E0F, 0x0025, 0x1028, 0x2235, "Ent NVMe CM7 U.2 RI 3.84TB(0x1028-0x2235)"},
{0x1E0F, 0x0025, 0x1028, 0x2236, "Ent NVMe CM7 U.2 RI 1.92TB(0x1028-0x2236)"},
{0x1E0F, 0x0025, 0x1028, 0x2237, "Ent NVMe CM7 FIPS U.2 MU 12.8TB(0x1028-0x2237)"},
{0x1E0F, 0x0025, 0x1028, 0x2238, "Ent NVMe CM7 FIPS U.2 MU 6.4TB(0x1028-0x2238)"},
{0x1E0F, 0x0025, 0x1028, 0x2239, "Ent NVMe CM7 FIPS U.2 MU 3.2TB(0x1028-0x2239)"},
{0x1E0F, 0x0025, 0x1028, 0x223A, "Ent NVMe CM7 FIPS U.2 MU 1.6TB(0x1028-0x223A)"},
{0x1E0F, 0x0025, 0x1028, 0x223B, "Ent NVMe CM7 U.2 MU 12.8TB(0x1028-0x223B)"},
{0x1E0F, 0x0025, 0x1028, 0x223C, "Ent NVMe CM7 U.2 MU 6.4TB(0x1028-0x223C)"},
{0x1E0F, 0x0025, 0x1028, 0x223D, "Ent NVMe CM7 U.2 MU 3.2TB(0x1028-0x223D)"},
{0x1E0F, 0x0025, 0x1028, 0x223E, "Ent NVMe CM7 U.2 MU 1.6TB(0x1028-0x223E)"},
{0x1E0F, 0x002A, 0xFFFF, 0xFFFF, "Exceria Plus G3 NVMe SSD (DRAM-less)(0x002A)"},
{0x1E0F, 0x002C, 0xFFFF, 0xFFFF, "NVMe SSD Controller CD8P EDSFF(0x002C)"},
{0x1E0F, 0x002C, 0x1028, 0x22BF, "DC NVMe CD8P E3.S 15.36TB(0x1028-0x22BF)"},
{0x1E0F, 0x002C, 0x1028, 0x22C0, "DC NVMe CD8P E3.S 7.68TB(0x1028-0x22C0)"},
{0x1E0F, 0x002C, 0x1028, 0x22C1, "DC NVMe CD8P E3.S 3.84TB(0x1028-0x22C1)"},
{0x1E0F, 0x002C, 0x1028, 0x22C2, "DC NVMe CD8P E3.S 1.92TB(0x1028-0x22C2)"},
{0x1E0F, 0x002C, 0x1028, 0x22C7, "DC NVMe CD8P E3.S MU 12.8TB(0x1028-0x22C7)"},
{0x1E0F, 0x002C, 0x1028, 0x22C8, "DC NVMe CD8P E3.S MU 6.4TB(0x1028-0x22C8)"},
{0x1E0F, 0x002C, 0x1028, 0x22C9, "DC NVMe CD8P E3.S MU 3.2TB(0x1028-0x22C9)"},
{0x1E0F, 0x002C, 0x1028, 0x22CA, "DC NVMe CD8P E3.S MU 1.6TB(0x1028-0x22CA)"},
}; /* pci_vid_1E0F[] */

static pci_id_t const pci_vid_1E17[] = {
{0x1E17, 0xFFFF, 0xFFFF, 0xFFFF, "Arnold & Richter Cine Technik GmbH & Co. Betriebs KG(0x1E17)"},
}; /* pci_vid_1E17[] */

static pci_id_t const pci_vid_1E18[] = {
{0x1E18, 0xFFFF, 0xFFFF, 0xFFFF, "Beijing GuangRunTong Technology Development Co.,Ltd(0x1E18)"},
}; /* pci_vid_1E18[] */

static pci_id_t const pci_vid_1E24[] = {
{0x1E24, 0xFFFF, 0xFFFF, 0xFFFF, "Squirrels Research Labs(0x1E24)"},
{0x1E24, 0x0101, 0xFFFF, 0xFFFF, "Acorn CLE-101(0x0101)"},
{0x1E24, 0x0215, 0xFFFF, 0xFFFF, "Acorn CLE-215(0x0215)"},
{0x1E24, 0x021F, 0xFFFF, 0xFFFF, "Acorn CLE-215+(0x021F)"},
{0x1E24, 0x1525, 0xFFFF, 0xFFFF, "Xilinx BCU-1525(0x1525)"},
{0x1E24, 0x1533, 0xFFFF, 0xFFFF, "ForestKitten 33(0x1533)"},
{0x1E24, 0x1633, 0xFFFF, 0xFFFF, "JCM33(0x1633)"},
{0x1E24, 0x1635, 0xFFFF, 0xFFFF, "JCM35(0x1635)"},
}; /* pci_vid_1E24[] */

static pci_id_t const pci_vid_1E26[] = {
{0x1E26, 0xFFFF, 0xFFFF, 0xFFFF, "Fujitsu Client Computing Limited(0x1E26)"},
}; /* pci_vid_1E26[] */

static pci_id_t const pci_vid_1E36[] = {
{0x1E36, 0xFFFF, 0xFFFF, 0xFFFF, "Shanghai Enflame Technology Co. Ltd(0x1E36)"},
{0x1E36, 0x0001, 0xFFFF, 0xFFFF, "T10 [CloudBlazer](0x0001)"},
{0x1E36, 0x0002, 0xFFFF, 0xFFFF, "T11 [CloudBlazer](0x0002)"},
{0x1E36, 0x0003, 0xFFFF, 0xFFFF, "T10(QSFP-DD) [CloudBlazer](0x0003)"},
{0x1E36, 0x0021, 0xFFFF, 0xFFFF, "T20(32GB) [CloudBlazer](0x0021)"},
{0x1E36, 0x0022, 0xFFFF, 0xFFFF, "T20(64GB) [CloudBlazer](0x0022)"},
{0x1E36, 0x0023, 0xFFFF, 0xFFFF, "T21(32GB) [CloudBlazer](0x0023)"},
{0x1E36, 0x0024, 0xFFFF, 0xFFFF, "T21(64GB) [CloudBlazer](0x0024)"},
{0x1E36, 0x8001, 0xFFFF, 0xFFFF, "I20 [CloudBlazer](0x8001)"},
{0x1E36, 0x8011, 0xFFFF, 0xFFFF, "I10 [CloudBlazer](0x8011)"},
{0x1E36, 0x8012, 0xFFFF, 0xFFFF, "I10L [CloudBlazer](0x8012)"},
{0x1E36, 0x8031, 0xFFFF, 0xFFFF, "S6 [Enflame](0x8031)"},
{0x1E36, 0x8032, 0xFFFF, 0xFFFF, "S6 [Enflame](0x8032)"},
{0x1E36, 0xC031, 0xFFFF, 0xFFFF, "S30 [Enflame](0xC031)"},
{0x1E36, 0xC032, 0xFFFF, 0xFFFF, "S90 [Enflame](0xC032)"},
{0x1E36, 0xC033, 0xFFFF, 0xFFFF, "S60G [Enflame](0xC033)"},
{0x1E36, 0xC035, 0xFFFF, 0xFFFF, "S60 [Enflame](0xC035)"},
}; /* pci_vid_1E36[] */

static pci_id_t const pci_vid_1E38[] = {
{0x1E38, 0xFFFF, 0xFFFF, 0xFFFF, "Blaize, Inc(0x1E38)"},
{0x1E38, 0x0102, 0xFFFF, 0xFFFF, "Xplorer X1600(0x0102)"},
}; /* pci_vid_1E38[] */

static pci_id_t const pci_vid_1E39[] = {
{0x1E39, 0xFFFF, 0xFFFF, 0xFFFF, "MEDION AG(0x1E39)"},
}; /* pci_vid_1E39[] */

static pci_id_t const pci_vid_1E3A[] = {
{0x1E3A, 0xFFFF, 0xFFFF, 0xFFFF, "Cactus Technologies Limited(0x1E3A)"},
{0x1E3A, 0x2263, 0xFFFF, 0xFFFF, "270PM6, 270PM7 series NVMe SSD(0x2263)"},
}; /* pci_vid_1E3A[] */

static pci_id_t const pci_vid_1E3B[] = {
{0x1E3B, 0xFFFF, 0xFFFF, 0xFFFF, "DapuStor Corporation(0x1E3B)"},
{0x1E3B, 0x0600, 0xFFFF, 0xFFFF, "NVMe SSD Controller DP600(0x0600)"},
{0x1E3B, 0x0600, 0x1E3B, 0x0006, "Enterprise NVMe SSD U.2 ODP 7.68TB (J5001)(0x1E3B-0x0006)"},
{0x1E3B, 0x0600, 0x1E3B, 0x0010, "Enterprise NVMe SSD U.2 3.84TB (R5102)(0x1E3B-0x0010)"},
{0x1E3B, 0x0600, 0x1E3B, 0x0013, "Enterprise NVMe SSD U.2 3.20TB (R5302)(0x1E3B-0x0013)"},
{0x1E3B, 0x0600, 0x1E3B, 0x0030, "Enterprise NVMe SSD U.2 3.84TB (J5100)(0x1E3B-0x0030)"},
{0x1E3B, 0x0600, 0x1E3B, 0x0031, "Enterprise NVMe SSD U.2 7.68TB (J5100)(0x1E3B-0x0031)"},
{0x1E3B, 0x0600, 0x1E3B, 0x0032, "Enterprise NVMe SSD U.2 15.36TB (J5100)(0x1E3B-0x0032)"},
{0x1E3B, 0x0600, 0x1E3B, 0x0033, "Enterprise NVMe SSD U.2 3.20TB (J5300)(0x1E3B-0x0033)"},
{0x1E3B, 0x0600, 0x1E3B, 0x0034, "Enterprise NVMe SSD U.2 6.40TB (J5300)(0x1E3B-0x0034)"},
{0x1E3B, 0x0600, 0x1E3B, 0x0035, "Enterprise NVMe SSD U.2 12.80TB (J5300)(0x1E3B-0x0035)"},
{0x1E3B, 0x0600, 0x1E3B, 0x0036, "Enterprise NVMe SSD AIC 7.68TB (J5110)(0x1E3B-0x0036)"},
{0x1E3B, 0x0600, 0x1E3B, 0x0037, "Enterprise NVMe SSD AIC 6.40TB (J5310)(0x1E3B-0x0037)"},
{0x1E3B, 0x0600, 0x1E3B, 0x0038, "Enterprise NVMe SSD U.2 3.84TB (J5100D)(0x1E3B-0x0038)"},
{0x1E3B, 0x0600, 0x1E3B, 0x0039, "Enterprise NVMe SSD U.2 7.68TB (J5100D)(0x1E3B-0x0039)"},
{0x1E3B, 0x0600, 0x1E3B, 0x003B, "Enterprise NVMe SSD U.2 3.20TB (J5300D)(0x1E3B-0x003B)"},
{0x1E3B, 0x0600, 0x1E3B, 0x003C, "Enterprise NVMe SSD U.2 6.40TB (J5300D)(0x1E3B-0x003C)"},
{0x1E3B, 0x0600, 0x1E3B, 0x003E, "Enterprise NVMe SSD AIC 3.84TB (J5110)(0x1E3B-0x003E)"},
{0x1E3B, 0x0600, 0x1E3B, 0x003F, "Enterprise NVMe SSD AIC 3.20TB (J5310)(0x1E3B-0x003F)"},
{0x1E3B, 0x0600, 0x1E3B, 0x004C, "Enterprise NVMe SSD U.2 QDP 1.92TB (J5100)(0x1E3B-0x004C)"},
{0x1E3B, 0x0600, 0x1E3B, 0x004D, "Enterprise NVMe SSD U.2 QDP 1.60TB (J5300)(0x1E3B-0x004D)"},
{0x1E3B, 0x0600, 0x1E3B, 0x0050, "Enterprise NVMe SSD U.2 3.84TB (R5100)(0x1E3B-0x0050)"},
{0x1E3B, 0x0600, 0x1E3B, 0x0051, "Enterprise NVMe SSD U.2 7.68TB (R5100)(0x1E3B-0x0051)"},
{0x1E3B, 0x0600, 0x1E3B, 0x0052, "Enterprise NVMe SSD U.2 15.36TB (R5100)(0x1E3B-0x0052)"},
{0x1E3B, 0x0600, 0x1E3B, 0x0053, "Enterprise NVMe SSD U.2 3.20TB (R5300)(0x1E3B-0x0053)"},
{0x1E3B, 0x0600, 0x1E3B, 0x0054, "Enterprise NVMe SSD U.2 6.40TB (R5300)(0x1E3B-0x0054)"},
{0x1E3B, 0x0600, 0x1E3B, 0x0055, "Enterprise NVMe SSD U.2 12.80TB (R5300)(0x1E3B-0x0055)"},
{0x1E3B, 0x0600, 0x1E3B, 0x0056, "Enterprise NVMe SSD U.2 3.84TB (R5101)(0x1E3B-0x0056)"},
{0x1E3B, 0x0600, 0x1E3B, 0x0059, "Enterprise NVMe SSD U.2 3.20TB (R5301)(0x1E3B-0x0059)"},
{0x1E3B, 0x0600, 0x1E3B, 0x0060, "Enterprise NVMe SSD U.2 3.84TB (R5100D)(0x1E3B-0x0060)"},
{0x1E3B, 0x0600, 0x1E3B, 0x0061, "Enterprise NVMe SSD U.2 7.68TB (R5100D)(0x1E3B-0x0061)"},
{0x1E3B, 0x0600, 0x1E3B, 0x0063, "Enterprise NVMe SSD U.2 3.20TB (R5300D)(0x1E3B-0x0063)"},
{0x1E3B, 0x0600, 0x1E3B, 0x0064, "Enterprise NVMe SSD U.2 6.40TB (R5300D)(0x1E3B-0x0064)"},
{0x1E3B, 0x0600, 0x1E3B, 0x0066, "Enterprise NVMe SSD U.2 3.84TB (R5101D)(0x1E3B-0x0066)"},
{0x1E3B, 0x0600, 0x1E3B, 0x0069, "Enterprise NVMe SSD U.2 3.20TB (R5301D)(0x1E3B-0x0069)"},
{0x1E3B, 0x0600, 0x1E3B, 0x006C, "Enterprise NVMe SSD U.2 1.92TB (R5101)(0x1E3B-0x006C)"},
{0x1E3B, 0x0600, 0x1E3B, 0x006D, "Enterprise NVMe SSD U.2 1.60TB (J5301)(0x1E3B-0x006D)"},
{0x1E3B, 0x0600, 0x1E3B, 0x00B9, "Enterprise NVMe SSD U.2 ODP 25.60TB (R5301)/(J5301)(0x1E3B-0x00B9)"},
{0x1E3B, 0x0600, 0x1E3B, 0x00BE, "Enterprise NVMe SSD U.2 ODP 30.72TB (R5101)/(J5101)(0x1E3B-0x00BE)"},
{0x1E3B, 0x0600, 0x1E3B, 0x00C1, "Enterprise NVMe SSD U.2 ODP 25.60TB (R5301D)/(J5301D)(0x1E3B-0x00C1)"},
{0x1E3B, 0x0600, 0x1E3B, 0x00C4, "Enterprise NVMe SSD U.2 ODP 30.72TB (R5101D)/(J5101D)(0x1E3B-0x00C4)"},
{0x1E3B, 0x0600, 0x1E3B, 0x00C7, "Enterprise NVMe SSD U.2 ODP 25.60TB (J5300)(0x1E3B-0x00C7)"},
{0x1E3B, 0x0600, 0x1E3B, 0x00C8, "Enterprise NVMe SSD U.2 ODP 30.72TB (J5100)(0x1E3B-0x00C8)"},
{0x1E3B, 0x0600, 0x1E3B, 0x00C9, "Enterprise NVMe SSD U.2 ODP 15.36TB (J5001)(0x1E3B-0x00C9)"},
{0x1E3B, 0x0600, 0x1E3B, 0x00CA, "Enterprise NVMe SSD U.2 ODP 3.84TB (J5102)(0x1E3B-0x00CA)"},
{0x1E3B, 0x0600, 0x1E3B, 0x00CB, "Enterprise NVMe SSD U.2 ODP 7.68TB (J5102)(0x1E3B-0x00CB)"},
{0x1E3B, 0x0600, 0x1E3B, 0x00CC, "Enterprise NVMe SSD U.2 QDP 3.84TB (J5101)(0x1E3B-0x00CC)"},
{0x1E3B, 0x0600, 0x1E3B, 0x00CD, "Enterprise NVMe SSD U.2 ODP 7.68TB (J5101)(0x1E3B-0x00CD)"},
{0x1E3B, 0x0600, 0x1E3B, 0x00CE, "Enterprise NVMe SSD U.2 QDP 3.84TB (J5101D)(0x1E3B-0x00CE)"},
{0x1E3B, 0x0600, 0x1E3B, 0x00CF, "Enterprise NVMe SSD U.2 ODP 7.68TB (J5101D)(0x1E3B-0x00CF)"},
{0x1E3B, 0x0600, 0x1E3B, 0x00DC, "Enterprise NVMe SSD U.2 ODP 30.72TB with SAMSUNG 32GB DRAM (J5001)(0x1E3B-0x00DC)"},
{0x1E3B, 0x0600, 0x1E3B, 0x00DD, "Enterprise NVMe SSD U.2 ODP 30.72TB with MT 32GB DRAM(J5001)(0x1E3B-0x00DD)"},
{0x1E3B, 0x0600, 0x1E3B, 0x00DE, "Enterprise NVMe SSD U.2 ODP 15.36TB with SK 16GB DRAM(J5001D)(0x1E3B-0x00DE)"},
{0x1E3B, 0x0600, 0x1E3B, 0x00DF, "Enterprise NVMe SSD U.2 ODP 30.72TB with SAMSUNG 32GB DRAM(J5001)(0x1E3B-0x00DF)"},
{0x1E3B, 0x0600, 0x1E3B, 0x00E7, "Enterprise NVMe SSD U.2 ODP 30.72TB with MT 32GB DRAM(J5001D)(0x1E3B-0x00E7)"},
{0x1E3B, 0x0600, 0x1E3B, 0x00E8, "Enterprise NVMe SSD U.2 QDP 3.20TB (J5301)(0x1E3B-0x00E8)"},
{0x1E3B, 0x0600, 0x1E3B, 0x00E9, "Enterprise NVMe SSD U.2 ODP 6.40TB (J5301)(0x1E3B-0x00E9)"},
{0x1E3B, 0x0600, 0x1E3B, 0x00EA, "Enterprise NVMe SSD U.2 QDP 3.20TB (J5301D)(0x1E3B-0x00EA)"},
{0x1E3B, 0x0600, 0x1E3B, 0x00EB, "Enterprise NVMe SSD U.2 ODP 6.40TB (J5301D)(0x1E3B-0x00EB)"},
{0x1E3B, 0x0600, 0x1E3B, 0x00EC, "Enterprise NVMe SSD U.2 ODP 30.72TB with MT 32GB DRAM(J5101)(0x1E3B-0x00EC)"},
{0x1E3B, 0x0600, 0x1E3B, 0x00ED, "Enterprise NVMe SSD U.2 ODP 30.72TB with MT 32GB DRAM(R5101)(0x1E3B-0x00ED)"},
{0x1E3B, 0x0600, 0x1E3B, 0x00EE, "Enterprise NVMe SSD U.2 ODP 15.36B with SK 16GB DRAM(J5101)(0x1E3B-0x00EE)"},
{0x1E3B, 0x0600, 0x1E3B, 0x00EF, "Enterprise NVMe SSD U.2 ODP 12.80TB with SK 16GB DRAM(J5301)(0x1E3B-0x00EF)"},
{0x1E3B, 0x0600, 0x1E3B, 0x00F0, "Enterprise NVMe SSD U.2 0.40TB (X2900)(0x1E3B-0x00F0)"},
{0x1E3B, 0x0600, 0x1E3B, 0x00F1, "Enterprise NVMe SSD U.2 0.80TB (X2900)(0x1E3B-0x00F1)"},
{0x1E3B, 0x0600, 0x1E3B, 0x00F2, "Enterprise NVMe SSD U.2 1.60TB (X2900)(0x1E3B-0x00F2)"},
{0x1E3B, 0x0600, 0x1E3B, 0x00F3, "Enterprise NVMe SSD U.2 3.20TB (X2900)(0x1E3B-0x00F3)"},
{0x1E3B, 0x0600, 0x1E3B, 0x00F5, "Enterprise NVMe SSD U.2 0.40TB (X2900P)(0x1E3B-0x00F5)"},
{0x1E3B, 0x0600, 0x1E3B, 0x00F6, "Enterprise NVMe SSD U.2 0.80TB (X2900P)(0x1E3B-0x00F6)"},
{0x1E3B, 0x0800, 0xFFFF, 0xFFFF, "DP800(0x0800)"},
{0x1E3B, 0x0800, 0x1E3B, 0x0001, "Enterprise NVMe SSD U.2 QDP 3.84TB(R6100)(0x1E3B-0x0001)"},
{0x1E3B, 0x0800, 0x1E3B, 0x0007, "Enterprise NVMe SSD U.2 ODP 15.36TB (R6100)(0x1E3B-0x0007)"},
{0x1E3B, 0x0800, 0x1E3B, 0x000A, "Enterprise NVMe SSD U.2 3.20TB (R6300)(0x1E3B-0x000A)"},
{0x1E3B, 0x0800, 0x1E3B, 0x000D, "Enterprise NVMe SSD U.2 6.40TB (R6300)(0x1E3B-0x000D)"},
{0x1E3B, 0x0800, 0x1E3B, 0x0010, "Enterprise NVMe SSD U.2 12.80TB (R6300)(0x1E3B-0x0010)"},
{0x1E3B, 0x0800, 0x1E3B, 0x0018, "Enterprise NVMe SSD U.2 QDP 3.84TB (R6100C)(0x1E3B-0x0018)"},
{0x1E3B, 0x0800, 0x1E3B, 0x0019, "Enterprise NVMe SSD U.2 ODP 7.68TB (R6100C)(0x1E3B-0x0019)"},
{0x1E3B, 0x0800, 0x1E3B, 0x001A, "Enterprise NVMe SSD U.2 3.20TB (R6300C)(0x1E3B-0x001A)"},
{0x1E3B, 0x0800, 0x1E3B, 0x001B, "Enterprise NVMe SSD U.2 6.40TB (R6300C)(0x1E3B-0x001B)"},
{0x1E3B, 0x0800, 0x1E3B, 0x001C, "Enterprise NVMe SSD U.2 ODP 7.68TB (R6100)(0x1E3B-0x001C)"},
{0x1E3B, 0x1098, 0xFFFF, 0xFFFF, "Haishen3 NVMe SSD(0x1098)"},
{0x1E3B, 0x1098, 0x1E3B, 0x0001, "Enterprise NVMe SSD U.2 0.8TB (H2100)(0x1E3B-0x0001)"},
{0x1E3B, 0x1098, 0x1E3B, 0x0002, "Enterprise NVMe SSD U.2 0.96TB (H2200)(0x1E3B-0x0002)"},
{0x1E3B, 0x1098, 0x1E3B, 0x0004, "Enterprise NVMe SSD U.2 1.6TB (H2100)(0x1E3B-0x0004)"},
{0x1E3B, 0x1098, 0x1E3B, 0x0005, "Enterprise NVMe SSD U.2 1.92TB (H2200)(0x1E3B-0x0005)"},
{0x1E3B, 0x1098, 0x1E3B, 0x0009, "Enterprise NVMe SSD U.2 0.8TB (H3100)(0x1E3B-0x0009)"},
{0x1E3B, 0x1098, 0x1E3B, 0x000A, "Enterprise NVMe SSD U.2 0.96TB (H3200)(0x1E3B-0x000A)"},
{0x1E3B, 0x1098, 0x1E3B, 0x000C, "Enterprise NVMe SSD U.2 1.6TB (H3100)(0x1E3B-0x000C)"},
{0x1E3B, 0x1098, 0x1E3B, 0x000D, "Enterprise NVMe SSD U.2 1.92TB (H3200)(0x1E3B-0x000D)"},
{0x1E3B, 0x1098, 0x1E3B, 0x0014, "Enterprise NVMe SSD U.2 3.2TB (H3100)(0x1E3B-0x0014)"},
{0x1E3B, 0x1098, 0x1E3B, 0x0015, "Enterprise NVMe SSD U.2 3.84TB (H3200)(0x1E3B-0x0015)"},
{0x1E3B, 0x1098, 0x1E3B, 0x0021, "Enterprise NVMe SSD U.2 6.4TB (H3100)(0x1E3B-0x0021)"},
{0x1E3B, 0x1098, 0x1E3B, 0x0022, "Enterprise NVMe SSD U.2 7.68TB (H3200)(0x1E3B-0x0022)"},
{0x1E3B, 0x1098, 0x1E3B, 0x0052, "Enterprise NVMe SSD U.2 0.8TB (H3900)(0x1E3B-0x0052)"},
{0x1E3B, 0x1098, 0x1E3B, 0x0053, "Enterprise NVMe SSD U.2 1.6TB (H3900)(0x1E3B-0x0053)"},
{0x1E3B, 0x1098, 0x1E3B, 0x0059, "Enterprise NVMe SSD U.2 0.75TB (H3900)(0x1E3B-0x0059)"},
{0x1E3B, 0x1098, 0x1E3B, 0x0061, "Enterprise NVMe SSD HHHL 0.8TB (H2100)(0x1E3B-0x0061)"},
{0x1E3B, 0x1098, 0x1E3B, 0x0062, "Enterprise NVMe SSD HHHL 0.96TB (H2200)(0x1E3B-0x0062)"},
{0x1E3B, 0x1098, 0x1E3B, 0x0064, "Enterprise NVMe SSD HHHL 1.6TB (H2100)(0x1E3B-0x0064)"},
{0x1E3B, 0x1098, 0x1E3B, 0x0065, "Enterprise NVMe SSD HHHL 1.92TB (H2200)(0x1E3B-0x0065)"},
{0x1E3B, 0x1098, 0x1E3B, 0x006C, "Enterprise NVMe SSD HHHL 0.8TB (H3100)(0x1E3B-0x006C)"},
{0x1E3B, 0x1098, 0x1E3B, 0x006D, "Enterprise NVMe SSD HHHL 0.96TB (H3200)(0x1E3B-0x006D)"},
{0x1E3B, 0x1098, 0x1E3B, 0x006F, "Enterprise NVMe SSD HHHL 1.6TB (H3100)(0x1E3B-0x006F)"},
{0x1E3B, 0x1098, 0x1E3B, 0x0070, "Enterprise NVMe SSD HHHL 1.92TB (H3200)(0x1E3B-0x0070)"},
{0x1E3B, 0x1098, 0x1E3B, 0x007C, "Enterprise NVMe SSD HHHL 3.2TB (H3100)(0x1E3B-0x007C)"},
{0x1E3B, 0x1098, 0x1E3B, 0x007D, "Enterprise NVMe SSD HHHL 3.84TB (H3200)(0x1E3B-0x007D)"},
{0x1E3B, 0x1098, 0x1E3B, 0x007F, "Enterprise NVMe SSD HHHL 6.4TB (H3100)(0x1E3B-0x007F)"},
{0x1E3B, 0x1098, 0x1E3B, 0x0080, "Enterprise NVMe SSD HHHL 7.68TB (H3200)(0x1E3B-0x0080)"},
{0x1E3B, 0x1098, 0x1E3B, 0x008A, "Enterprise NVMe SSD HHHL 0.8TB (H3900)(0x1E3B-0x008A)"},
{0x1E3B, 0x1098, 0x1E3B, 0x008B, "Enterprise NVMe SSD HHHL 1.6TB (H3900)(0x1E3B-0x008B)"},
{0x1E3B, 0x1098, 0x1E3B, 0x0091, "Enterprise NVMe SSD HHHL 0.75TB (H3900)(0x1E3B-0x0091)"},
{0x1E3B, 0x1333, 0xFFFF, 0xFFFF, "Haishen5 NVMe SSD(0x1333)"},
{0x1E3B, 0x1333, 0x1E3B, 0x0081, "Enterprise NVMe SSD U.2 3.84TB (H5100)(0x1E3B-0x0081)"},
{0x1E3B, 0x1333, 0x1E3B, 0x0082, "Enterprise NVMe SSD U.2 7.68TB (H5100)(0x1E3B-0x0082)"},
{0x1E3B, 0x1333, 0x1E3B, 0x0084, "Enterprise NVMe SSD U.2 3.2TB (H5300)(0x1E3B-0x0084)"},
{0x1E3B, 0x1333, 0x1E3B, 0x0085, "Enterprise NVMe SSD U.2 6.4TB (H5300)(0x1E3B-0x0085)"},
}; /* pci_vid_1E3B[] */

static pci_id_t const pci_vid_1E3D[] = {
{0x1E3D, 0xFFFF, 0xFFFF, 0xFFFF, "Burlywood, Inc(0x1E3D)"},
}; /* pci_vid_1E3D[] */

static pci_id_t const pci_vid_1E43[] = {
{0x1E43, 0xFFFF, 0xFFFF, 0xFFFF, "MaxLinear Inc(0x1E43)"},
{0x1E43, 0x8904, 0xFFFF, 0xFFFF, "MxL8904(0x8904)"},
{0x1E43, 0x8906, 0xFFFF, 0xFFFF, "MxL8906(0x8906)"},
{0x1E43, 0x8908, 0xFFFF, 0xFFFF, "MxL8908(0x8908)"},
}; /* pci_vid_1E43[] */

static pci_id_t const pci_vid_1E44[] = {
{0x1E44, 0xFFFF, 0xFFFF, 0xFFFF, "Valve Software(0x1E44)"},
}; /* pci_vid_1E44[] */

static pci_id_t const pci_vid_1E49[] = {
{0x1E49, 0xFFFF, 0xFFFF, 0xFFFF, "Yangtze Memory Technologies Co.,Ltd(0x1E49)"},
{0x1E49, 0x0001, 0xFFFF, 0xFFFF, "ZHITAI PC005 NVMe SSD(0x0001)"},
{0x1E49, 0x0021, 0xFFFF, 0xFFFF, "ZHITAI TiPro5000 NVMe SSD(0x0021)"},
{0x1E49, 0x0041, 0xFFFF, 0xFFFF, "ZHITAI TiPro7000(0x0041)"},
{0x1E49, 0x0071, 0xFFFF, 0xFFFF, "ZHITAI TiPlus7100(0x0071)"},
{0x1E49, 0x1001, 0xFFFF, 0xFFFF, "PC005 NVMe SSD(0x1001)"},
{0x1E49, 0x1011, 0xFFFF, 0xFFFF, "PC210 NVMe SSD(0x1011)"},
{0x1E49, 0x1013, 0xFFFF, 0xFFFF, "PC210 NVMe SSD(0x1013)"},
{0x1E49, 0x1031, 0xFFFF, 0xFFFF, "PC300 NVMe SSD (DRAM-less)(0x1031)"},
{0x1E49, 0x1033, 0xFFFF, 0xFFFF, "PC300 NVMe SSD (DRAM-less)(0x1033)"},
{0x1E49, 0x1071, 0xFFFF, 0xFFFF, "PC411 NVMe SSD (DRAM-less)(0x1071)"},
}; /* pci_vid_1E49[] */

static pci_id_t const pci_vid_1E4B[] = {
{0x1E4B, 0xFFFF, 0xFFFF, 0xFFFF, "MAXIO Technology (Hangzhou) Ltd.(0x1E4B)"},
{0x1E4B, 0x1001, 0xFFFF, 0xFFFF, "NVMe SSD Controller MAP1001(0x1001)"},
{0x1E4B, 0x1002, 0xFFFF, 0xFFFF, "NVMe SSD Controller MAP1002 (DRAM-less)(0x1002)"},
{0x1E4B, 0x1003, 0xFFFF, 0xFFFF, "NVMe SSD Controller MAP1003(0x1003)"},
{0x1E4B, 0x1201, 0xFFFF, 0xFFFF, "NVMe SSD Controller MAP1201(0x1201)"},
{0x1E4B, 0x1202, 0xFFFF, 0xFFFF, "NVMe SSD Controller MAP1202 (DRAM-less)(0x1202)"},
{0x1E4B, 0x1601, 0xFFFF, 0xFFFF, "NVMe SSD Controller MAP1601(0x1601)"},
{0x1E4B, 0x1602, 0xFFFF, 0xFFFF, "NVMe SSD Controller MAP1602 (DRAM-less)(0x1602)"},
{0x1E4B, 0x1608, 0xFFFF, 0xFFFF, "NVMe SSD Controller MAP1608 (DRAM-less)(0x1608)"},
}; /* pci_vid_1E4B[] */

static pci_id_t const pci_vid_1E4C[] = {
{0x1E4C, 0xFFFF, 0xFFFF, 0xFFFF, "GSI Technology(0x1E4C)"},
{0x1E4C, 0x0010, 0xFFFF, 0xFFFF, "Associative Processing Unit [Leda](0x0010)"},
{0x1E4C, 0x0010, 0x1E4C, 0x0120, "SE120(0x1E4C-0x0120)"},
}; /* pci_vid_1E4C[] */

static pci_id_t const pci_vid_1E50[] = {
{0x1E50, 0xFFFF, 0xFFFF, 0xFFFF, "IP3 Tech (HK) Limited(0x1E50)"},
}; /* pci_vid_1E50[] */

static pci_id_t const pci_vid_1E52[] = {
{0x1E52, 0xFFFF, 0xFFFF, 0xFFFF, "Tenstorrent Inc(0x1E52)"},
{0x1E52, 0x401E, 0xFFFF, 0xFFFF, "Wormhole(0x401E)"},
{0x1E52, 0x401E, 0x1E52, 0x0014, "n300(0x1E52-0x0014)"},
{0x1E52, 0x401E, 0x1E52, 0x0018, "n150(0x1E52-0x0018)"},
{0x1E52, 0xB140, 0xFFFF, 0xFFFF, "Blackhole(0xB140)"},
{0x1E52, 0xFACA, 0xFFFF, 0xFFFF, "Grayskull(0xFACA)"},
{0x1E52, 0xFACA, 0x1E52, 0x0003, "e150(0x1E52-0x0003)"},
{0x1E52, 0xFACA, 0x1E52, 0x0007, "e75(0x1E52-0x0007)"},
{0x1E52, 0xFACA, 0x1E52, 0x000A, "e300(0x1E52-0x000A)"},
}; /* pci_vid_1E52[] */

static pci_id_t const pci_vid_1E57[] = {
{0x1E57, 0xFFFF, 0xFFFF, 0xFFFF, "Beijing Panyi Technology Co., Ltd(0x1E57)"},
{0x1E57, 0x0100, 0xFFFF, 0xFFFF, "The device has already been deleted.(0x0100)"},
{0x1E57, 0x0100, 0x0000, 0x0100, "PY8800 64GB Accelerator(0x0000-0x0100)"},
}; /* pci_vid_1E57[] */

static pci_id_t const pci_vid_1E59[] = {
{0x1E59, 0xFFFF, 0xFFFF, 0xFFFF, "Oxford Nanopore Technologies(0x1E59)"},
{0x1E59, 0x0001, 0xFFFF, 0xFFFF, "MinION Mk1C(0x0001)"},
}; /* pci_vid_1E59[] */

static pci_id_t const pci_vid_1E5D[] = {
{0x1E5D, 0xFFFF, 0xFFFF, 0xFFFF, "ASR Microelectronics(0x1E5D)"},
{0x1E5D, 0x7000, 0xFFFF, 0xFFFF, "AI controller A7000(0x7000)"},
{0x1E5D, 0x7010, 0xFFFF, 0xFFFF, "AI controller A7010(0x7010)"},
}; /* pci_vid_1E5D[] */

static pci_id_t const pci_vid_1E60[] = {
{0x1E60, 0xFFFF, 0xFFFF, 0xFFFF, "Hailo Technologies Ltd.(0x1E60)"},
{0x1E60, 0x2864, 0xFFFF, 0xFFFF, "Hailo-8 AI Processor(0x2864)"},
}; /* pci_vid_1E60[] */

static pci_id_t const pci_vid_1E67[] = {
{0x1E67, 0xFFFF, 0xFFFF, 0xFFFF, "Untether AI(0x1E67)"},
{0x1E67, 0x0002, 0xFFFF, 0xFFFF, "runAI200 AI Inference Accelerator(0x0002)"},
}; /* pci_vid_1E67[] */

static pci_id_t const pci_vid_1E68[] = {
{0x1E68, 0xFFFF, 0xFFFF, 0xFFFF, "Jiangsu Xinsheng Intelligent Technology Co., Ltd(0x1E68)"},
{0x1E68, 0x8111, 0xFFFF, 0xFFFF, "EP2000Pro PCIe 3 NVMe SSD (DRAM-less)(0x8111)"},
}; /* pci_vid_1E68[] */

static pci_id_t const pci_vid_1E6B[] = {
{0x1E6B, 0xFFFF, 0xFFFF, 0xFFFF, "Axiado Corp.(0x1E6B)"},
}; /* pci_vid_1E6B[] */

static pci_id_t const pci_vid_1E7B[] = {
{0x1E7B, 0xFFFF, 0xFFFF, 0xFFFF, "Dataland(0x1E7B)"},
}; /* pci_vid_1E7B[] */

static pci_id_t const pci_vid_1E7C[] = {
{0x1E7C, 0xFFFF, 0xFFFF, 0xFFFF, "Brainchip Inc(0x1E7C)"},
{0x1E7C, 0xBCA1, 0xFFFF, 0xFFFF, "AKD1000 Neural Network Coprocessor [Akida](0xBCA1)"},
}; /* pci_vid_1E7C[] */

static pci_id_t const pci_vid_1E7E[] = {
{0x1E7E, 0xFFFF, 0xFFFF, 0xFFFF, "Pliops(0x1E7E)"},
{0x1E7E, 0x9034, 0xFFFF, 0xFFFF, "Pliops Extreme Data Processor [XDP1.0](0x9034)"},
}; /* pci_vid_1E7E[] */

static pci_id_t const pci_vid_1E7F[] = {
{0x1E7F, 0xFFFF, 0xFFFF, 0xFFFF, "Jiangsu Huacun Elec. Tech. Co., Ltd.(0x1E7F)"},
{0x1E7F, 0x6002, 0xFFFF, 0xFFFF, "MMY MMSP350 PCIe 3 NVMe SSD (DRAM-less)(0x6002)"},
{0x1E7F, 0x6003, 0xFFFF, 0xFFFF, "MMY HC512GP3KH2T PCIe 3 NVMe SSD (DRAM-less)(0x6003)"},
}; /* pci_vid_1E7F[] */

static pci_id_t const pci_vid_1E81[] = {
{0x1E81, 0xFFFF, 0xFFFF, 0xFFFF, "Ramaxel Technology(Shenzhen) Limited(0x1E81)"},
{0x1E81, 0x1203, 0xFFFF, 0xFFFF, "NVMe SSD Controller UHXXXa series(0x1203)"},
{0x1E81, 0x1203, 0x1E81, 0xA121, "NVMe SSD UHXXXa series U.2 960GB(0x1E81-0xA121)"},
{0x1E81, 0x1203, 0x1E81, 0xA122, "NVMe SSD UHXXXa series U.2 1920GB(0x1E81-0xA122)"},
{0x1E81, 0x1203, 0x1E81, 0xA123, "NVMe SSD UHXXXa series U.2 3840GB(0x1E81-0xA123)"},
{0x1E81, 0x1203, 0x1E81, 0xA124, "NVMe SSD UHXXXa series U.2 7680GB(0x1E81-0xA124)"},
{0x1E81, 0x1203, 0x1E81, 0xA125, "NVMe SSD UHXXXa series U.2 15360GB(0x1E81-0xA125)"},
{0x1E81, 0x1203, 0x1E81, 0xA211, "NVMe SSD UHXXXa series U.2 800GB(0x1E81-0xA211)"},
{0x1E81, 0x1203, 0x1E81, 0xA212, "NVMe SSD UHXXXa series U.2 1600GB(0x1E81-0xA212)"},
{0x1E81, 0x1203, 0x1E81, 0xA213, "NVMe SSD UHXXXa series U.2 3200GB(0x1E81-0xA213)"},
{0x1E81, 0x1203, 0x1E81, 0xA214, "NVMe SSD UHXXXa series U.2 6400GB(0x1E81-0xA214)"},
{0x1E81, 0x1203, 0x1E81, 0xF123, "NVMe SSD TP6500 series U.2 3840GB(0x1E81-0xF123)"},
{0x1E81, 0x6206, 0xFFFF, 0xFFFF, "AM620 NVMe SSD(0x6206)"},
}; /* pci_vid_1E81[] */

static pci_id_t const pci_vid_1E83[] = {
{0x1E83, 0xFFFF, 0xFFFF, 0xFFFF, "Huaqin Technology Co.Ltd(0x1E83)"},
}; /* pci_vid_1E83[] */

static pci_id_t const pci_vid_1E85[] = {
{0x1E85, 0xFFFF, 0xFFFF, 0xFFFF, "Heitec AG(0x1E85)"},
}; /* pci_vid_1E85[] */

static pci_id_t const pci_vid_1E89[] = {
{0x1E89, 0xFFFF, 0xFFFF, 0xFFFF, "ID Quantique SA(0x1E89)"},
{0x1E89, 0x0002, 0xFFFF, 0xFFFF, "Quantis-PCIe-40M(0x0002)"},
{0x1E89, 0x0003, 0xFFFF, 0xFFFF, "Quantis-PCIe-240M(0x0003)"},
}; /* pci_vid_1E89[] */

static pci_id_t const pci_vid_1E93[] = {
{0x1E93, 0xFFFF, 0xFFFF, 0xFFFF, "Beijing Bytedance Network Technology Co., Ltd.(0x1E93)"},
}; /* pci_vid_1E93[] */

static pci_id_t const pci_vid_1E94[] = {
{0x1E94, 0xFFFF, 0xFFFF, 0xFFFF, "Calian SED(0x1E94)"},
}; /* pci_vid_1E94[] */

static pci_id_t const pci_vid_1E95[] = {
{0x1E95, 0xFFFF, 0xFFFF, 0xFFFF, "Solid State Storage Technology Corporation(0x1E95)"},
{0x1E95, 0x1000, 0xFFFF, 0xFFFF, "XA1-311024 NVMe SSD M.2(0x1000)"},
{0x1E95, 0x1001, 0xFFFF, 0xFFFF, "CA6-8D512 NVMe SSD M.2(0x1001)"},
{0x1E95, 0x1002, 0xFFFF, 0xFFFF, "NVMe SSD [3DNAND] 2.5\" U.2 (LJ1)(0x1002)"},
{0x1E95, 0x1002, 0x1E95, 0x1101, "NVMe SSD [3DNAND] 2.5\" U.2 (LJ1)(0x1E95-0x1101)"},
{0x1E95, 0x1002, 0x1EA0, 0x5636, "TP1500 Series U.2 NVMe Datacenter SSD(0x1EA0-0x5636)"},
{0x1E95, 0x1003, 0xFFFF, 0xFFFF, "CLR-8W512 NVMe SSD M.2 (DRAM-less)(0x1003)"},
{0x1E95, 0x1005, 0xFFFF, 0xFFFF, "PLEXTOR M10P(GN) NVMe SSD M.2(0x1005)"},
{0x1E95, 0x1007, 0xFFFF, 0xFFFF, "CL4-8D512 NVMe SSD M.2 (DRAM-less)(0x1007)"},
{0x1E95, 0x1008, 0xFFFF, 0xFFFF, "CL5-8D512 NVMe SSD M.2 (DRAM-less)(0x1008)"},
{0x1E95, 0x3500, 0xFFFF, 0xFFFF, "CA5-8D256 NVMe SSD M.2(0x3500)"},
{0x1E95, 0x35F1, 0xFFFF, 0xFFFF, "PLEXTOR M9PGN Plus NVMe SSD M.2(0x35F1)"},
{0x1E95, 0x9100, 0xFFFF, 0xFFFF, "CL1-3D256-Q11 NVMe SSD M.2(0x9100)"},
}; /* pci_vid_1E95[] */

static pci_id_t const pci_vid_1E96[] = {
{0x1E96, 0xFFFF, 0xFFFF, 0xFFFF, "Drut Technologies Inc.(0x1E96)"},
}; /* pci_vid_1E96[] */

static pci_id_t const pci_vid_1E9F[] = {
{0x1E9F, 0xFFFF, 0xFFFF, 0xFFFF, "Lynxi Technologies Co., Ltd.(0x1E9F)"},
}; /* pci_vid_1E9F[] */

static pci_id_t const pci_vid_1EA0[] = {
{0x1EA0, 0xFFFF, 0xFFFF, 0xFFFF, "Tencent Technology (Shenzhen) Company Limited(0x1EA0)"},
{0x1EA0, 0x2A16, 0xFFFF, 0xFFFF, "Cloud Intelligent Inference Controller(0x2A16)"},
{0x1EA0, 0x2A18, 0xFFFF, 0xFFFF, "Video Transcode Controller(0x2A18)"},
{0x1EA0, 0x2A20, 0xFFFF, 0xFFFF, "Cloud Intelligent Inference and Training Controller(0x2A20)"},
{0x1EA0, 0x2A22, 0xFFFF, 0xFFFF, "Cloud Intelligent Inference Controller(0x2A22)"},
}; /* pci_vid_1EA0[] */

static pci_id_t const pci_vid_1EA7[] = {
{0x1EA7, 0xFFFF, 0xFFFF, 0xFFFF, "Intelliprop, Inc(0x1EA7)"},
{0x1EA7, 0x223A, 0xFFFF, 0xFFFF, "Typhon+ PCIe to Gen-Z Bridge(0x223A)"},
{0x1EA7, 0x224A, 0xFFFF, 0xFFFF, "IPA-PE224A CXL to Gen-Z Bridge [Sphinx](0x224A)"},
}; /* pci_vid_1EA7[] */

static pci_id_t const pci_vid_1EAB[] = {
{0x1EAB, 0xFFFF, 0xFFFF, 0xFFFF, "Hefei DATANG Storage Technology Co.,LTD.(0x1EAB)"},
{0x1EAB, 0x300A, 0xFFFF, 0xFFFF, "NVMe SSD Controller 300A(0x300A)"},
{0x1EAB, 0x300B, 0xFFFF, 0xFFFF, "NVMe SSD Controller 300B (DRAM-less)(0x300B)"},
}; /* pci_vid_1EAB[] */

static pci_id_t const pci_vid_1EAC[] = {
{0x1EAC, 0xFFFF, 0xFFFF, 0xFFFF, "Quectel Wireless Solutions Co., Ltd.(0x1EAC)"},
{0x1EAC, 0x1001, 0xFFFF, 0xFFFF, "EM120R-GL LTE Modem(0x1001)"},
{0x1EAC, 0x1002, 0xFFFF, 0xFFFF, "EM160R-GL LTE Modem(0x1002)"},
}; /* pci_vid_1EAC[] */

static pci_id_t const pci_vid_1EAE[] = {
{0x1EAE, 0xFFFF, 0xFFFF, 0xFFFF, "XFX Limited(0x1EAE)"},
}; /* pci_vid_1EAE[] */

static pci_id_t const pci_vid_1EB1[] = {
{0x1EB1, 0xFFFF, 0xFFFF, 0xFFFF, "VeriSilicon Inc(0x1EB1)"},
{0x1EB1, 0x1001, 0xFFFF, 0xFFFF, "Video Accelerator(0x1001)"},
}; /* pci_vid_1EB1[] */

static pci_id_t const pci_vid_1EB4[] = {
{0x1EB4, 0xFFFF, 0xFFFF, 0xFFFF, "Quantum Nebula Microelectronics Technology Co.,Ltd.(0x1EB4)"},
{0x1EB4, 0x3401, 0xFFFF, 0xFFFF, "SSD Contoller(0x3401)"},
}; /* pci_vid_1EB4[] */

static pci_id_t const pci_vid_1EB6[] = {
{0x1EB6, 0xFFFF, 0xFFFF, 0xFFFF, "Wuxi Stars Microsystem Technology Co., Ltd(0x1EB6)"},
}; /* pci_vid_1EB6[] */

static pci_id_t const pci_vid_1EB9[] = {
{0x1EB9, 0xFFFF, 0xFFFF, 0xFFFF, "Senscomm Semiconductor, Inc(0x1EB9)"},
{0x1EB9, 0x2020, 0xFFFF, 0xFFFF, "SCM2625 Wi-Fi6 Network Adapter(0x2020)"},
}; /* pci_vid_1EB9[] */

static pci_id_t const pci_vid_1EBD[] = {
{0x1EBD, 0xFFFF, 0xFFFF, 0xFFFF, "EMERGETECH Company Ltd.(0x1EBD)"},
{0x1EBD, 0x0101, 0xFFFF, 0xFFFF, "Seirios 2063 Video Codec(0x0101)"},
}; /* pci_vid_1EBD[] */

static pci_id_t const pci_vid_1EC6[] = {
{0x1EC6, 0xFFFF, 0xFFFF, 0xFFFF, "Vastai Technologies(0x1EC6)"},
{0x1EC6, 0x0100, 0xFFFF, 0xFFFF, "SV100(0x0100)"},
{0x1EC6, 0x0100, 0x1EC6, 0x0010, "VA1V(0x1EC6-0x0010)"},
{0x1EC6, 0x0100, 0x1EC6, 0x0011, "VA1A(0x1EC6-0x0011)"},
{0x1EC6, 0x0100, 0x1EC6, 0x0012, "VA1(0x1EC6-0x0012)"},
{0x1EC6, 0x0100, 0x1EC6, 0x0013, "VA1E(0x1EC6-0x0013)"},
{0x1EC6, 0x0100, 0x1EC6, 0x0020, "VA10V(0x1EC6-0x0020)"},
{0x1EC6, 0x0100, 0x1EC6, 0x0021, "VA10A(0x1EC6-0x0021)"},
{0x1EC6, 0x0100, 0x1EC6, 0x0022, "VA10(0x1EC6-0x0022)"},
{0x1EC6, 0x0100, 0x1EC6, 0x0030, "VE1P(0x1EC6-0x0030)"},
{0x1EC6, 0x0100, 0x1EC6, 0x0031, "VE1S(0x1EC6-0x0031)"},
{0x1EC6, 0x0100, 0x1EC6, 0x0032, "VE1V(0x1EC6-0x0032)"},
{0x1EC6, 0x0100, 0x1EC6, 0x0033, "VE1M(0x1EC6-0x0033)"},
{0x1EC6, 0x0100, 0x1EC6, 0x0034, "VE1E(0x1EC6-0x0034)"},
{0x1EC6, 0x0100, 0x1EC6, 0x0040, "VV1U(0x1EC6-0x0040)"},
{0x1EC6, 0x0100, 0x1EC6, 0x0041, "VA1U(0x1EC6-0x0041)"},
{0x1EC6, 0x0200, 0xFFFF, 0xFFFF, "SG100(0x0200)"},
{0x1EC6, 0x0200, 0x1EC6, 0x0060, "VG1200(0x1EC6-0x0060)"},
{0x1EC6, 0x0200, 0x1EC6, 0x0061, "VG1600(0x1EC6-0x0061)"},
{0x1EC6, 0x0200, 0x1EC6, 0x0062, "VG1800(0x1EC6-0x0062)"},
{0x1EC6, 0x0200, 0x1EC6, 0x0063, "VG1000(0x1EC6-0x0063)"},
{0x1EC6, 0x020F, 0xFFFF, 0xFFFF, "SG100 vGPU(0x020F)"},
}; /* pci_vid_1EC6[] */

static pci_id_t const pci_vid_1EC8[] = {
{0x1EC8, 0xFFFF, 0xFFFF, 0xFFFF, "Innosilicon Co Ltd(0x1EC8)"},
{0x1EC8, 0x8800, 0xFFFF, 0xFFFF, "Fantasy I(0x8800)"},
{0x1EC8, 0x8800, 0x1EC8, 0x12A2, "Fantasy I Device(0x1EC8-0x12A2)"},
{0x1EC8, 0x8810, 0xFFFF, 0xFFFF, "Fantasy I(0x8810)"},
{0x1EC8, 0x8810, 0x1EC8, 0x12A2, "Fantasy I Device(0x1EC8-0x12A2)"},
{0x1EC8, 0x9800, 0xFFFF, 0xFFFF, "Fantasy II(0x9800)"},
{0x1EC8, 0x9800, 0x1EC8, 0x12A2, "Fantasy II Device(0x1EC8-0x12A2)"},
{0x1EC8, 0x9802, 0xFFFF, 0xFFFF, "Fantasy II(0x9802)"},
{0x1EC8, 0x9802, 0x1EC8, 0x12A2, "Fantasy II Device(0x1EC8-0x12A2)"},
{0x1EC8, 0x9804, 0xFFFF, 0xFFFF, "Fantasy II(0x9804)"},
{0x1EC8, 0x9804, 0x1EC8, 0x12A2, "Fantasy II Device(0x1EC8-0x12A2)"},
{0x1EC8, 0x9810, 0xFFFF, 0xFFFF, "Fantasy II-M(0x9810)"},
{0x1EC8, 0x9810, 0x1EC8, 0x12A2, "Fantasy II Device(0x1EC8-0x12A2)"},
}; /* pci_vid_1EC8[] */

static pci_id_t const pci_vid_1EC9[] = {
{0x1EC9, 0xFFFF, 0xFFFF, 0xFFFF, "Wingtech Group(HongKong)Limited(0x1EC9)"},
}; /* pci_vid_1EC9[] */

static pci_id_t const pci_vid_1ECA[] = {
{0x1ECA, 0xFFFF, 0xFFFF, 0xFFFF, "Lightmatter(0x1ECA)"},
{0x1ECA, 0x0000, 0xFFFF, 0xFFFF, "Envise-B(0x0000)"},
}; /* pci_vid_1ECA[] */

static pci_id_t const pci_vid_1ED0[] = {
{0x1ED0, 0xFFFF, 0xFFFF, 0xFFFF, "Hosin Global Electronics(0x1ED0)"},
{0x1ED0, 0x2283, 0xFFFF, 0xFFFF, "Patriot P300 NVMe SSD (DRAM-less)(0x2283)"},
}; /* pci_vid_1ED0[] */

static pci_id_t const pci_vid_1ED2[] = {
{0x1ED2, 0xFFFF, 0xFFFF, 0xFFFF, "FuriosaAI, Inc.(0x1ED2)"},
{0x1ED2, 0x0000, 0xFFFF, 0xFFFF, "Warboy(0x0000)"},
{0x1ED2, 0x1111, 0xFFFF, 0xFFFF, "RNGD(0x1111)"},
{0x1ED2, 0x1111, 0x0000, 0x1111, "RNGD-S(0x0000-0x1111)"},
{0x1ED2, 0x1111, 0x0000, 0x2222, "RNGD VF(0x0000-0x2222)"},
{0x1ED2, 0x1111, 0x0000, 0x3333, "RNGD-S VF(0x0000-0x3333)"},
{0x1ED2, 0x2222, 0xFFFF, 0xFFFF, "RNGD-S(0x2222)"},
}; /* pci_vid_1ED2[] */

static pci_id_t const pci_vid_1ED3[] = {
{0x1ED3, 0xFFFF, 0xFFFF, 0xFFFF, "Yeston(0x1ED3)"},
}; /* pci_vid_1ED3[] */

static pci_id_t const pci_vid_1ED5[] = {
{0x1ED5, 0xFFFF, 0xFFFF, 0xFFFF, "Moore Threads Technology Co.,Ltd(0x1ED5)"},
{0x1ED5, 0x0100, 0xFFFF, 0xFFFF, "MTT S10(0x0100)"},
{0x1ED5, 0x0101, 0xFFFF, 0xFFFF, "MTT S10(0x0101)"},
{0x1ED5, 0x0102, 0xFFFF, 0xFFFF, "MTT S30(0x0102)"},
{0x1ED5, 0x0105, 0xFFFF, 0xFFFF, "MTT S50(0x0105)"},
{0x1ED5, 0x0106, 0xFFFF, 0xFFFF, "MTT S60(0x0106)"},
{0x1ED5, 0x0111, 0xFFFF, 0xFFFF, "MTT S100(0x0111)"},
{0x1ED5, 0x0121, 0xFFFF, 0xFFFF, "MTT S1000M(0x0121)"},
{0x1ED5, 0x0122, 0xFFFF, 0xFFFF, "MTT S1000(0x0122)"},
{0x1ED5, 0x0123, 0xFFFF, 0xFFFF, "MTT S2000(0x0123)"},
{0x1ED5, 0x01FF, 0xFFFF, 0xFFFF, "MTT HDMI/DP Audio(0x01FF)"},
{0x1ED5, 0x0200, 0xFFFF, 0xFFFF, "MTT S80 Engineering Sample(0x0200)"},
{0x1ED5, 0x0201, 0xFFFF, 0xFFFF, "MTT S80(0x0201)"},
{0x1ED5, 0x0202, 0xFFFF, 0xFFFF, "MTT S70(0x0202)"},
{0x1ED5, 0x0203, 0xFFFF, 0xFFFF, "MTT S60(0x0203)"},
{0x1ED5, 0x0211, 0xFFFF, 0xFFFF, "MTT X300(0x0211)"},
{0x1ED5, 0x0221, 0xFFFF, 0xFFFF, "G2S80(0x0221)"},
{0x1ED5, 0x0222, 0xFFFF, 0xFFFF, "MTT S3000(0x0222)"},
{0x1ED5, 0x0222, 0x1ED5, 0x0001, "C3150(0x1ED5-0x0001)"},
{0x1ED5, 0x0223, 0xFFFF, 0xFFFF, "G2S4(0x0223)"},
{0x1ED5, 0x0251, 0xFFFF, 0xFFFF, "G2N10(0x0251)"},
{0x1ED5, 0x02FF, 0xFFFF, 0xFFFF, "MTT HDMI/DP Audio(0x02FF)"},
{0x1ED5, 0x0300, 0xFFFF, 0xFFFF, "MTT S90 Engineering Sample(0x0300)"},
{0x1ED5, 0x0301, 0xFFFF, 0xFFFF, "MTT S90(0x0301)"},
{0x1ED5, 0x0323, 0xFFFF, 0xFFFF, "MTT S4000(0x0323)"},
{0x1ED5, 0x0327, 0xFFFF, 0xFFFF, "MTT S4000(0x0327)"},
{0x1ED5, 0x03FF, 0xFFFF, 0xFFFF, "MTT HDMI/DP Audio(0x03FF)"},
}; /* pci_vid_1ED5[] */

static pci_id_t const pci_vid_1ED8[] = {
{0x1ED8, 0xFFFF, 0xFFFF, 0xFFFF, "Digiteq Automotive(0x1ED8)"},
{0x1ED8, 0x0101, 0xFFFF, 0xFFFF, "FG4 PCIe Frame Grabber (T100)(0x0101)"},
{0x1ED8, 0x0201, 0xFFFF, 0xFFFF, "FG4 PCIe Frame Grabber (T200)(0x0201)"},
}; /* pci_vid_1ED8[] */

static pci_id_t const pci_vid_1ED9[] = {
{0x1ED9, 0xFFFF, 0xFFFF, 0xFFFF, "Myrtle.ai(0x1ED9)"},
}; /* pci_vid_1ED9[] */

static pci_id_t const pci_vid_1EE1[] = {
{0x1EE1, 0xFFFF, 0xFFFF, 0xFFFF, "Suzhou Kuhan Information Technologies(0x1EE1)"},
{0x1EE1, 0x0050, 0xFFFF, 0xFFFF, "Aurora NVMe SSD Controller(0x0050)"},
{0x1EE1, 0x0050, 0x1EE1, 0x0009, "Airglow A430 NVMe SSD U.2 1.6TB(0x1EE1-0x0009)"},
{0x1EE1, 0x0050, 0x1EE1, 0x000A, "Airglow A430 NVMe SSD U.2 3.2TB(0x1EE1-0x000A)"},
{0x1EE1, 0x0050, 0x1EE1, 0x000B, "Airglow A430 NVMe SSD U.2 4.8TB(0x1EE1-0x000B)"},
{0x1EE1, 0x0050, 0x1EE1, 0x0012, "Airglow Z400 NVMe ZNS SSD U.2 5.76TB(0x1EE1-0x0012)"},
}; /* pci_vid_1EE1[] */

static pci_id_t const pci_vid_1EE4[] = {
{0x1EE4, 0xFFFF, 0xFFFF, 0xFFFF, "PETAIO INC(0x1EE4)"},
{0x1EE4, 0x1180, 0xFFFF, 0xFFFF, "P8118 U.2 Single Port SSD(0x1180)"},
}; /* pci_vid_1EE4[] */

static pci_id_t const pci_vid_1EE9[] = {
{0x1EE9, 0xFFFF, 0xFFFF, 0xFFFF, "SUSE LLC(0x1EE9)"},
}; /* pci_vid_1EE9[] */

static pci_id_t const pci_vid_1EEC[] = {
{0x1EEC, 0xFFFF, 0xFFFF, 0xFFFF, "Viscore Technologies Ltd(0x1EEC)"},
{0x1EEC, 0x0102, 0xFFFF, 0xFFFF, "VSE250231S Dual-port 10Gb/25Gb Ethernet PCIe(0x0102)"},
{0x1EEC, 0x1EEC, 0xFFFF, 0xFFFF, "VSE250231S Dual-port 10Gb/25Gb Ethernet PCIe(0x1EEC)"},
}; /* pci_vid_1EEC[] */

static pci_id_t const pci_vid_1EED[] = {
{0x1EED, 0xFFFF, 0xFFFF, 0xFFFF, "XDX Computing Technology Ltd.(0x1EED)"},
{0x1EED, 0x10A0, 0xFFFF, 0xFFFF, "XDX110 Graphic/VGA Controller(0x10A0)"},
{0x1EED, 0x10A1, 0xFFFF, 0xFFFF, "XDX110 Audio Controller(0x10A1)"},
{0x1EED, 0x10A2, 0xFFFF, 0xFFFF, "XDX110M(0x10A2)"},
{0x1EED, 0x10A4, 0xFFFF, 0xFFFF, "XDX E1100(0x10A4)"},
{0x1EED, 0x1140, 0xFFFF, 0xFFFF, "XDX120(0x1140)"},
{0x1EED, 0x1142, 0xFFFF, 0xFFFF, "XDX120M(0x1142)"},
{0x1EED, 0x1144, 0xFFFF, 0xFFFF, "XDX E1200(0x1144)"},
{0x1EED, 0x1150, 0xFFFF, 0xFFFF, "XDX120S(0x1150)"},
{0x1EED, 0x1160, 0xFFFF, 0xFFFF, "XDX121(0x1160)"},
{0x1EED, 0x1170, 0xFFFF, 0xFFFF, "XDX121S(0x1170)"},
{0x1EED, 0x11E0, 0xFFFF, 0xFFFF, "XDX130(0x11E0)"},
{0x1EED, 0x11E4, 0xFFFF, 0xFFFF, "XDX E1300(0x11E4)"},
{0x1EED, 0x1320, 0xFFFF, 0xFFFF, "XDX150(0x1320)"},
{0x1EED, 0x1323, 0xFFFF, 0xFFFF, "XDX R1500(0x1323)"},
{0x1EED, 0x1324, 0xFFFF, 0xFFFF, "XDX X1500(0x1324)"},
{0x1EED, 0x1330, 0xFFFF, 0xFFFF, "XDX150S(0x1330)"},
{0x1EED, 0x1333, 0xFFFF, 0xFFFF, "XDX R1510(0x1333)"},
{0x1EED, 0x1340, 0xFFFF, 0xFFFF, "XDX151(0x1340)"},
{0x1EED, 0x1350, 0xFFFF, 0xFFFF, "XDX151S(0x1350)"},
{0x1EED, 0x1360, 0xFFFF, 0xFFFF, "XDX151T(0x1360)"},
{0x1EED, 0x13C0, 0xFFFF, 0xFFFF, "XDX160T(0x13C0)"},
{0x1EED, 0x13D0, 0xFFFF, 0xFFFF, "XDX160S(0x13D0)"},
{0x1EED, 0x13D3, 0xFFFF, 0xFFFF, "XDX R1610(0x13D3)"},
{0x1EED, 0x1500, 0xFFFF, 0xFFFF, "XDX180(0x1500)"},
{0x1EED, 0x1503, 0xFFFF, 0xFFFF, "XDX R1800(0x1503)"},
{0x1EED, 0x1504, 0xFFFF, 0xFFFF, "XDX X1800(0x1504)"},
{0x1EED, 0x1510, 0xFFFF, 0xFFFF, "XDX180S(0x1510)"},
{0x1EED, 0x15A0, 0xFFFF, 0xFFFF, "XDX190(0x15A0)"},
{0x1EED, 0x15A3, 0xFFFF, 0xFFFF, "XDX R1900(0x15A3)"},
{0x1EED, 0x15A4, 0xFFFF, 0xFFFF, "XDX X1900(0x15A4)"},
{0x1EED, 0x15A5, 0xFFFF, 0xFFFF, "XDX X1900D(0x15A5)"},
{0x1EED, 0x15B0, 0xFFFF, 0xFFFF, "XDX190S(0x15B0)"},
{0x1EED, 0x1810, 0xFFFF, 0xFFFF, "XDX TJ01 Audio(0x1810)"},
{0x1EED, 0x1820, 0xFFFF, 0xFFFF, "XDX TJ02 Audio(0x1820)"},
{0x1EED, 0x1830, 0xFFFF, 0xFFFF, "XDX TJ03 Audio(0x1830)"},
}; /* pci_vid_1EED[] */

static pci_id_t const pci_vid_1EF6[] = {
{0x1EF6, 0xFFFF, 0xFFFF, 0xFFFF, "GrAI Matter Labs(0x1EF6)"},
}; /* pci_vid_1EF6[] */

static pci_id_t const pci_vid_1EF7[] = {
{0x1EF7, 0xFFFF, 0xFFFF, 0xFFFF, "Shenzhen Gunnir Technology Development Co., Ltd(0x1EF7)"},
}; /* pci_vid_1EF7[] */

static pci_id_t const pci_vid_1EFB[] = {
{0x1EFB, 0xFFFF, 0xFFFF, 0xFFFF, "Flexxon Pte Ltd(0x1EFB)"},
}; /* pci_vid_1EFB[] */

static pci_id_t const pci_vid_1EFF[] = {
{0x1EFF, 0xFFFF, 0xFFFF, 0xFFFF, "Rebellions Inc.(0x1EFF)"},
}; /* pci_vid_1EFF[] */

static pci_id_t const pci_vid_1F02[] = {
{0x1F02, 0xFFFF, 0xFFFF, 0xFFFF, "Beijing Dayu Technology(0x1F02)"},
}; /* pci_vid_1F02[] */

static pci_id_t const pci_vid_1F03[] = {
{0x1F03, 0xFFFF, 0xFFFF, 0xFFFF, "Shenzhen Shichuangyi Electronics Co., Ltd(0x1F03)"},
{0x1F03, 0x1202, 0xFFFF, 0xFFFF, "MAP1202-Based NVMe SSD (DRAM-less)(0x1202)"},
{0x1F03, 0x2262, 0xFFFF, 0xFFFF, "SM2262EN-based OEM SSD(0x2262)"},
{0x1F03, 0x2263, 0xFFFF, 0xFFFF, "SM2263XT-Base NVMe SSD(0x2263)"},
{0x1F03, 0x5216, 0xFFFF, 0xFFFF, "IG5216-based NVMe SSD (DRAM-less)(0x5216)"},
{0x1F03, 0x5220, 0xFFFF, 0xFFFF, "IG5220-Based NVMe SSD(0x5220)"},
{0x1F03, 0x5236, 0xFFFF, 0xFFFF, "IG5236-Based NVMe SSD(0x5236)"},
{0x1F03, 0x5636, 0xFFFF, 0xFFFF, "IG5636-Based NVMe SSD(0x5636)"},
}; /* pci_vid_1F03[] */

static pci_id_t const pci_vid_1F0A[] = {
{0x1F0A, 0xFFFF, 0xFFFF, 0xFFFF, "Motorcomm Microelectronics.(0x1F0A)"},
{0x1F0A, 0x6801, 0xFFFF, 0xFFFF, "YT6801 Gigabit Ethernet Controller(0x6801)"},
}; /* pci_vid_1F0A[] */

static pci_id_t const pci_vid_1F0F[] = {
{0x1F0F, 0xFFFF, 0xFFFF, 0xFFFF, "NebulaMatrix Technology(0x1F0F)"},
{0x1F0F, 0x1041, 0xFFFF, 0xFFFF, "D1055AS vDPA Ethernet Controller(0x1041)"},
{0x1F0F, 0x1041, 0x1F0F, 0x0001, "D1055AS vDPA Ethernet Controller(0x1F0F-0x0001)"},
{0x1F0F, 0x1042, 0xFFFF, 0xFFFF, "D1055AS vDPA Storage Controller(0x1042)"},
{0x1F0F, 0x1042, 0x1F0F, 0x0001, "D1055AS vDPA Storage Controller(0x1F0F-0x0001)"},
{0x1F0F, 0x1220, 0xFFFF, 0xFFFF, "D1055AS Ethernet Controller(0x1220)"},
{0x1F0F, 0x1221, 0xFFFF, 0xFFFF, "D1055AS Ethernet Controller(0x1221)"},
{0x1F0F, 0x1222, 0xFFFF, 0xFFFF, "D1055AS Ethernet Controller(0x1222)"},
{0x1F0F, 0x1223, 0xFFFF, 0xFFFF, "D1055AS Ethernet Controller(0x1223)"},
{0x1F0F, 0x1600, 0xFFFF, 0xFFFF, "M16104 Family(0x1600)"},
{0x1F0F, 0x1600, 0x1F0F, 0x0001, "M16104 Family(0x1F0F-0x0001)"},
{0x1F0F, 0x1601, 0xFFFF, 0xFFFF, "M16104 Family Virtual Function(0x1601)"},
{0x1F0F, 0x1601, 0x1F0F, 0x0001, "M16104 Family Virtual Function(0x1F0F-0x0001)"},
{0x1F0F, 0x1A00, 0xFFFF, 0xFFFF, "M16104 Family(0x1A00)"},
{0x1F0F, 0x1A00, 0x1F0F, 0x0001, "M16104 Family(0x1F0F-0x0001)"},
{0x1F0F, 0x1A01, 0xFFFF, 0xFFFF, "M16104 Family Virtual Function(0x1A01)"},
{0x1F0F, 0x1A01, 0x1F0F, 0x0001, "M16104 Family Virtual Function(0x1F0F-0x0001)"},
{0x1F0F, 0x2022, 0xFFFF, 0xFFFF, "D1055AS PCI Express Switch Upstream Port(0x2022)"},
{0x1F0F, 0x3403, 0xFFFF, 0xFFFF, "M18110 Family(0x3403)"},
{0x1F0F, 0x3404, 0xFFFF, 0xFFFF, "M18110 Lx Family(0x3404)"},
{0x1F0F, 0x3405, 0xFFFF, 0xFFFF, "M18110 Family BASE-T(0x3405)"},
{0x1F0F, 0x3406, 0xFFFF, 0xFFFF, "M18110 Lx Family BASE-T(0x3406)"},
{0x1F0F, 0x3407, 0xFFFF, 0xFFFF, "M18110 Family OCP(0x3407)"},
{0x1F0F, 0x3408, 0xFFFF, 0xFFFF, "M18110 Lx Family OCP(0x3408)"},
{0x1F0F, 0x3409, 0xFFFF, 0xFFFF, "M18110 Family BASE-T OCP(0x3409)"},
{0x1F0F, 0x340A, 0xFFFF, 0xFFFF, "M18110 Lx Family BASE-T OCP(0x340A)"},
{0x1F0F, 0x340B, 0xFFFF, 0xFFFF, "M18120 Family(0x340B)"},
{0x1F0F, 0x340C, 0xFFFF, 0xFFFF, "M18120 Lx Family(0x340C)"},
{0x1F0F, 0x340D, 0xFFFF, 0xFFFF, "M18120 Family BASE-T(0x340D)"},
{0x1F0F, 0x340E, 0xFFFF, 0xFFFF, "M18120 Lx Family BASE-T(0x340E)"},
{0x1F0F, 0x340F, 0xFFFF, 0xFFFF, "M18120 Family OCP(0x340F)"},
{0x1F0F, 0x3410, 0xFFFF, 0xFFFF, "M18120 Lx Family OCP(0x3410)"},
{0x1F0F, 0x3411, 0xFFFF, 0xFFFF, "M18120 Family BASE-T OCP(0x3411)"},
{0x1F0F, 0x3412, 0xFFFF, 0xFFFF, "M18120 Lx Family BASE-T OCP(0x3412)"},
{0x1F0F, 0x3413, 0xFFFF, 0xFFFF, "M18100 Family Virtual Function(0x3413)"},
{0x1F0F, 0x9088, 0xFFFF, 0xFFFF, "D1055AS PCI Express Switch Downstream Port(0x9088)"},
}; /* pci_vid_1F0F[] */

static pci_id_t const pci_vid_1F16[] = {
{0x1F16, 0xFFFF, 0xFFFF, 0xFFFF, "XConn Technologies(0x1F16)"},
{0x1F16, 0xC500, 0xFFFF, 0xFFFF, "XC50256(0xC500)"},
}; /* pci_vid_1F16[] */

static pci_id_t const pci_vid_1F17[] = {
{0x1F17, 0xFFFF, 0xFFFF, 0xFFFF, "Zettastone Technology(0x1F17)"},
}; /* pci_vid_1F17[] */

static pci_id_t const pci_vid_1F24[] = {
{0x1F24, 0xFFFF, 0xFFFF, 0xFFFF, "xFusion Digital Technologies Co., Ltd.(0x1F24)"},
{0x1F24, 0x1058, 0xFFFF, 0xFFFF, "EP500/EP600 NVMe SSD(0x1058)"},
{0x1F24, 0x1058, 0x1F24, 0x1114, "EP500 NVMe SSD(RI)(0x1F24-0x1114)"},
{0x1F24, 0x1058, 0x1F24, 0x1115, "EP600 NVMe SSD(MU)(0x1F24-0x1115)"},
}; /* pci_vid_1F24[] */

static pci_id_t const pci_vid_1F2F[] = {
{0x1F2F, 0xFFFF, 0xFFFF, 0xFFFF, "China Mobile (Hangzhou) Information Technology Co.Ltd.(0x1F2F)"},
{0x1F2F, 0x1513, 0xFFFF, 0xFFFF, "DERA MENG NVMe Controller(0x1513)"},
{0x1F2F, 0x1513, 0x1F2F, 0x6113, "KM660 U.2 1.6TB NVMe SSD(0x1F2F-0x6113)"},
{0x1F2F, 0x1513, 0x1F2F, 0x6114, "KM560 U.2 1.92TB NVMe SSD(0x1F2F-0x6114)"},
{0x1F2F, 0x1513, 0x1F2F, 0x6115, "KM660 U.2 3.2TB NVMe SSD(0x1F2F-0x6115)"},
{0x1F2F, 0x1513, 0x1F2F, 0x6116, "KM560 U.2 3.84TB NVMe SSD(0x1F2F-0x6116)"},
{0x1F2F, 0x1513, 0x1F2F, 0x6118, "KM560 U.2 7.68TB NVMe SSD(0x1F2F-0x6118)"},
}; /* pci_vid_1F2F[] */

static pci_id_t const pci_vid_1F31[] = {
{0x1F31, 0xFFFF, 0xFFFF, 0xFFFF, "Nextorage(0x1F31)"},
{0x1F31, 0x4512, 0xFFFF, 0xFFFF, "Nextorage NE1N NVMe SSD(0x4512)"},
}; /* pci_vid_1F31[] */

static pci_id_t const pci_vid_1F3F[] = {
{0x1F3F, 0xFFFF, 0xFFFF, 0xFFFF, "3SNIC Ltd(0x1F3F)"},
{0x1F3F, 0x2100, 0xFFFF, 0xFFFF, "SSSHBA SAS/SATA HBA(0x2100)"},
{0x1F3F, 0x2100, 0x1F3F, 0x0120, "HBA 32 Ports(0x1F3F-0x0120)"},
{0x1F3F, 0x2100, 0x1F3F, 0x0125, "HBA 40 Ports(0x1F3F-0x0125)"},
{0x1F3F, 0x2100, 0x1F3F, 0x0180, "HBA 16 Ports(0x1F3F-0x0180)"},
{0x1F3F, 0x2100, 0x1F3F, 0x0185, "HBA 8 Ports(0x1F3F-0x0185)"},
{0x1F3F, 0x2200, 0xFFFF, 0xFFFF, "SSSRAID RAID controller(0x2200)"},
{0x1F3F, 0x2200, 0x1F3F, 0x0185, "RAID Controller 16 Ports with 2G Cache(0x1F3F-0x0185)"},
{0x1F3F, 0x2200, 0x1F3F, 0x01A1, "RAID Controller 40 Ports with 2G Cache(0x1F3F-0x01A1)"},
{0x1F3F, 0x2200, 0x1F3F, 0x01A4, "RAID Controller 16 Ports with 4G Cache(0x1F3F-0x01A4)"},
{0x1F3F, 0x2200, 0x1F3F, 0x01A8, "RAID Controller 32 Ports with 4G Cache(0x1F3F-0x01A8)"},
{0x1F3F, 0x2200, 0x1F3F, 0x01AD, "RAID Controller 40 Ports with 4G Cache(0x1F3F-0x01AD)"},
{0x1F3F, 0x9001, 0xFFFF, 0xFFFF, "SSSNIC Ethernet VF(0x9001)"},
{0x1F3F, 0x9001, 0x1F3F, 0x1000, "Ethernet VF(0x1F3F-0x1000)"},
{0x1F3F, 0x9002, 0xFFFF, 0xFFFF, "SSSNIC Ethernet VF Hyper-V(0x9002)"},
{0x1F3F, 0x9002, 0x1F3F, 0x1000, "Ethernet VF Hyper-V(0x1F3F-0x1000)"},
{0x1F3F, 0x9003, 0xFFFF, 0xFFFF, "SSSNIC Ethernet SDI VF(0x9003)"},
{0x1F3F, 0x9003, 0x1F3F, 0x1000, "Ethernet SDI VF(0x1F3F-0x1000)"},
{0x1F3F, 0x9004, 0xFFFF, 0xFFFF, "SSSNIC Ethernet SDI VF Hyper-V(0x9004)"},
{0x1F3F, 0x9004, 0x1F3F, 0x1000, "Ethernet SDI VF Hyper-V(0x1F3F-0x1000)"},
{0x1F3F, 0x9008, 0xFFFF, 0xFFFF, "SSSFC VF(0x9008)"},
{0x1F3F, 0x9008, 0x1F3F, 0x1000, "3SFC VF(0x1F3F-0x1000)"},
{0x1F3F, 0x9009, 0xFFFF, 0xFFFF, "SSSFC VF Hyper-V(0x9009)"},
{0x1F3F, 0x9009, 0x1F3F, 0x1000, "3SFC VF Hyper-V(0x1F3F-0x1000)"},
{0x1F3F, 0x9010, 0xFFFF, 0xFFFF, "SSSFC FC Controller(0x9010)"},
{0x1F3F, 0x9010, 0x1F3F, 0x0041, "Dual Port 16GE FC to PCIe Gen4 x16 Adapter(0x1F3F-0x0041)"},
{0x1F3F, 0x9010, 0x1F3F, 0x0061, "Dual Port 32GE FC to PCIe Gen4 x16 Adapter(0x1F3F-0x0061)"},
{0x1F3F, 0x9020, 0xFFFF, 0xFFFF, "SSSNIC Ethernet Network Adapter(0x9020)"},
{0x1F3F, 0x9020, 0x1F3F, 0x0051, "Dual Port 25GE Ethernet Network Adapter(0x1F3F-0x0051)"},
{0x1F3F, 0x9020, 0x1F3F, 0x0052, "Quad Port 25GE Ethernet Network Adapter(0x1F3F-0x0052)"},
{0x1F3F, 0x9020, 0x1F3F, 0x00A1, "Dual Port 100GE Ethernet Network Adapter(0x1F3F-0x00A1)"},
{0x1F3F, 0x9030, 0xFFFF, 0xFFFF, "SSSNIC IPU(0x9030)"},
{0x1F3F, 0x9030, 0x1F3F, 0x0051, "Dual Port 25GE IPU(0x1F3F-0x0051)"},
{0x1F3F, 0x9031, 0xFFFF, 0xFFFF, "SSSNIC SDI5.0(0x9031)"},
{0x1F3F, 0x9031, 0x1F3F, 0x0051, "Dual Port 25GE SDI5.0lite(0x1F3F-0x0051)"},
{0x1F3F, 0x9031, 0x1F3F, 0x00A1, "Dual Port 100GE SDI5.0(0x1F3F-0x00A1)"},
{0x1F3F, 0x9032, 0xFFFF, 0xFFFF, "SSSNIC SDI5.1(0x9032)"},
{0x1F3F, 0x9032, 0x1F3F, 0x00A1, "Dual Port 100GE SDI5.1(0x1F3F-0x00A1)"},
}; /* pci_vid_1F3F[] */

static pci_id_t const pci_vid_1F40[] = {
{0x1F40, 0xFFFF, 0xFFFF, 0xFFFF, "Netac Technology Co.,Ltd(0x1F40)"},
{0x1F40, 0x0001, 0xFFFF, 0xFFFF, "PCIe 4 NVMe SSD (DRAM-less)(0x0001)"},
{0x1F40, 0x1202, 0xFFFF, 0xFFFF, "PCIe 3 NVMe SSD (DRAM-less)(0x1202)"},
{0x1F40, 0x1602, 0xFFFF, 0xFFFF, "PCIe 4 NVMe SSD (DRAM-less)(0x1602)"},
{0x1F40, 0x1F40, 0xFFFF, 0xFFFF, "PCIe 4 NVMe SSD (DRAM-less)(0x1F40)"},
{0x1F40, 0x2263, 0xFFFF, 0xFFFF, "PCIe 3 SM based NVMe SSD (DRAM-less)(0x2263)"},
{0x1F40, 0x5216, 0xFFFF, 0xFFFF, "PCIe 3 NVMe SSD (DRAM-less)(0x5216)"},
{0x1F40, 0x5236, 0xFFFF, 0xFFFF, "PCIe 4 INNOGRIT based NVMe SSD(0x5236)"},
{0x1F40, 0x5765, 0xFFFF, 0xFFFF, "PCIe 3 NVMe SSD (DRAM-less)(0x5765)"},
}; /* pci_vid_1F40[] */

static pci_id_t const pci_vid_1F44[] = {
{0x1F44, 0xFFFF, 0xFFFF, 0xFFFF, "VVDN Technologies Private Limited(0x1F44)"},
}; /* pci_vid_1F44[] */

static pci_id_t const pci_vid_1F47[] = {
{0x1F47, 0xFFFF, 0xFFFF, 0xFFFF, "YUSUR Tech(0x1F47)"},
{0x1F47, 0x2018, 0xFFFF, 0xFFFF, "DPU Card(0x2018)"},
{0x1F47, 0x2020, 0xFFFF, 0xFFFF, "DPU(0x2020)"},
}; /* pci_vid_1F47[] */

static pci_id_t const pci_vid_1F4B[] = {
{0x1F4B, 0xFFFF, 0xFFFF, 0xFFFF, "Axera Semiconductor Co., Ltd(0x1F4B)"},
}; /* pci_vid_1F4B[] */

static pci_id_t const pci_vid_1F52[] = {
{0x1F52, 0xFFFF, 0xFFFF, 0xFFFF, "MangoBoost Inc.(0x1F52)"},
}; /* pci_vid_1F52[] */

static pci_id_t const pci_vid_1F56[] = {
{0x1F56, 0xFFFF, 0xFFFF, 0xFFFF, "SAPEON Inc.(0x1F56)"},
}; /* pci_vid_1F56[] */

static pci_id_t const pci_vid_1F60[] = {
{0x1F60, 0xFFFF, 0xFFFF, 0xFFFF, "Accelecom(0x1F60)"},
{0x1F60, 0x0001, 0xFFFF, 0xFFFF, "XELE-NIC 25K5(0x0001)"},
{0x1F60, 0x0054, 0xFFFF, 0xFFFF, "XELE-NIC 25K5(0x0054)"},
}; /* pci_vid_1F60[] */

static pci_id_t const pci_vid_1F67[] = {
{0x1F67, 0xFFFF, 0xFFFF, 0xFFFF, "Yunsilicon Technology(0x1F67)"},
{0x1F67, 0x1011, 0xFFFF, 0xFFFF, "metaConnect SmartNIC Physical Function(0x1011)"},
{0x1F67, 0x1012, 0xFFFF, 0xFFFF, "metaConnect SmartNIC Virtual Function(0x1012)"},
{0x1F67, 0x1051, 0xFFFF, 0xFFFF, "metaFusion DPU Physical Function(0x1051)"},
{0x1F67, 0x1052, 0xFFFF, 0xFFFF, "metaFusion DPU Virtual Function(0x1052)"},
{0x1F67, 0x1059, 0xFFFF, 0xFFFF, "metaFusion DPU SoC Network Interface(0x1059)"},
{0x1F67, 0x1111, 0xFFFF, 0xFFFF, "metaScale SmartNIC Physical Function(0x1111)"},
{0x1F67, 0x1112, 0xFFFF, 0xFFFF, "metaScale SmartNIC Virtual Function(0x1112)"},
{0x1F67, 0x1151, 0xFFFF, 0xFFFF, "metaVisor DPU Physical Function(0x1151)"},
{0x1F67, 0x1152, 0xFFFF, 0xFFFF, "metaVisor DPU Virtual Function(0x1152)"},
}; /* pci_vid_1F67[] */

static pci_id_t const pci_vid_1FAA[] = {
{0x1FAA, 0xFFFF, 0xFFFF, 0xFFFF, "Hexaflake (Shanghai) Information Technology Co., Ltd.(0x1FAA)"},
{0x1FAA, 0x0C10, 0xFFFF, 0xFFFF, "Compass C10 PF(0x0C10)"},
{0x1FAA, 0x0C11, 0xFFFF, 0xFFFF, "Compass C10 VF(0x0C11)"},
}; /* pci_vid_1FAA[] */

static pci_id_t const pci_vid_1FAB[] = {
{0x1FAB, 0xFFFF, 0xFFFF, 0xFFFF, "Unifabrix Ltd.(0x1FAB)"},
{0x1FAB, 0x0000, 0xFFFF, 0xFFFF, "Nexus Alpha IVPU(0x0000)"},
{0x1FAB, 0x0100, 0xFFFF, 0xFFFF, "NoX Gamma(0x0100)"},
{0x1FAB, 0x01FD, 0xFFFF, 0xFFFF, "Smart Memory Node Generic CXL Port (T1)(0x01FD)"},
{0x1FAB, 0x01FE, 0xFFFF, 0xFFFF, "Smart Memory Node Generic CXL Port (T2)(0x01FE)"},
{0x1FAB, 0x01FF, 0xFFFF, 0xFFFF, "Smart Memory Node Generic CXL Port (T3)(0x01FF)"},
{0x1FAB, 0x1B00, 0xFFFF, 0xFFFF, "MAX Host Device(0x1B00)"},
}; /* pci_vid_1FAB[] */

static pci_id_t const pci_vid_1FB0[] = {
{0x1FB0, 0xFFFF, 0xFFFF, 0xFFFF, "ICube Corporation Limited(0x1FB0)"},
{0x1FB0, 0x1000, 0xFFFF, 0xFFFF, "NF1000 Series GPU(0x1000)"},
{0x1FB0, 0x1000, 0x1FB0, 0x1001, "NF1001(0x1FB0-0x1001)"},
{0x1FB0, 0x1000, 0x1FB0, 0x1002, "NF1002(0x1FB0-0x1002)"},
{0x1FB0, 0x1000, 0x1FB0, 0x1003, "NF1003(0x1FB0-0x1003)"},
{0x1FB0, 0x1001, 0xFFFF, 0xFFFF, "NF1001(0x1001)"},
{0x1FB0, 0x1001, 0x1FB0, 0x1001, "NF1001(0x1FB0-0x1001)"},
{0x1FB0, 0x1001, 0x1FB0, 0x1002, "NF1002(0x1FB0-0x1002)"},
{0x1FB0, 0x1001, 0x1FB0, 0x1003, "NF1003(0x1FB0-0x1003)"},
{0x1FB0, 0x2000, 0xFFFF, 0xFFFF, "NF2000 Series GPU(0x2000)"},
{0x1FB0, 0x2000, 0x1FB0, 0x2001, "NF2001(0x1FB0-0x2001)"},
{0x1FB0, 0x2000, 0x1FB0, 0x2002, "NF 2002(0x1FB0-0x2002)"},
{0x1FB0, 0x2000, 0x1FB0, 0x2003, "NF 2003(0x1FB0-0x2003)"},
{0x1FB0, 0x3000, 0xFFFF, 0xFFFF, "NF3000 Series GPU(0x3000)"},
{0x1FB0, 0x3000, 0x1FB0, 0x3001, "NF3001(0x1FB0-0x3001)"},
{0x1FB0, 0x3000, 0x1FB0, 0x3002, "NF3002(0x1FB0-0x3002)"},
{0x1FB0, 0x3000, 0x1FB0, 0x3003, "NF3003(0x1FB0-0x3003)"},
{0x1FB0, 0x4000, 0xFFFF, 0xFFFF, "NF4000 Series GPU(0x4000)"},
{0x1FB0, 0x4000, 0x1FB0, 0x4001, "NF4001(0x1FB0-0x4001)"},
{0x1FB0, 0x4000, 0x1FB0, 0x4002, "NF4002(0x1FB0-0x4002)"},
{0x1FB0, 0x4000, 0x1FB0, 0x4003, "NF4003(0x1FB0-0x4003)"},
{0x1FB0, 0x5000, 0xFFFF, 0xFFFF, "NF5000 Series GPU(0x5000)"},
{0x1FB0, 0x5000, 0x1FB0, 0x5001, "NF 5001(0x1FB0-0x5001)"},
{0x1FB0, 0x5000, 0x1FB0, 0x5002, "NF 5002(0x1FB0-0x5002)"},
{0x1FB0, 0x5000, 0x1FB0, 0x5003, "NF5003(0x1FB0-0x5003)"},
}; /* pci_vid_1FB0[] */

static pci_id_t const pci_vid_1FC0[] = {
{0x1FC0, 0xFFFF, 0xFFFF, 0xFFFF, "Ascom (Finland) Oy(0x1FC0)"},
{0x1FC0, 0x0300, 0xFFFF, 0xFFFF, "E2200 Dual E1/Rawpipe Card(0x0300)"},
{0x1FC0, 0x0301, 0xFFFF, 0xFFFF, "C5400 SHDSL/E1 Card(0x0301)"},
}; /* pci_vid_1FC0[] */

static pci_id_t const pci_vid_1FC1[] = {
{0x1FC1, 0xFFFF, 0xFFFF, 0xFFFF, "QLogic, Corp.(0x1FC1)"},
{0x1FC1, 0x000D, 0xFFFF, 0xFFFF, "IBA6110 InfiniBand HCA(0x000D)"},
{0x1FC1, 0x0010, 0xFFFF, 0xFFFF, "IBA6120 InfiniBand HCA(0x0010)"},
}; /* pci_vid_1FC1[] */

static pci_id_t const pci_vid_1FC9[] = {
{0x1FC9, 0xFFFF, 0xFFFF, 0xFFFF, "Tehuti Networks Ltd.(0x1FC9)"},
{0x1FC9, 0x3009, 0xFFFF, 0xFFFF, "10-Giga TOE SmartNIC(0x3009)"},
{0x1FC9, 0x3010, 0xFFFF, 0xFFFF, "10-Giga TOE SmartNIC(0x3010)"},
{0x1FC9, 0x3010, 0x0000, 0x3002, "10-Giga TOE Single Port XFP SmartNIC(0x0000-0x3002)"},
{0x1FC9, 0x3010, 0x0000, 0x3004, "10-Giga TOE Single Port SFP+ SmartNIC(0x0000-0x3004)"},
{0x1FC9, 0x3010, 0x0000, 0x3008, "10-Giga TOE Single Port CX4 SmartNIC(0x0000-0x3008)"},
{0x1FC9, 0x3014, 0xFFFF, 0xFFFF, "10-Giga TOE SmartNIC 2-Port(0x3014)"},
{0x1FC9, 0x3014, 0x0000, 0x3003, "10-Giga TOE Dual Port XFP Low Profile SmartNIC(0x0000-0x3003)"},
{0x1FC9, 0x3014, 0x0000, 0x3005, "10-Giga TOE Dual Port SFP+ Low Profile SmartNIC(0x0000-0x3005)"},
{0x1FC9, 0x3014, 0x0000, 0x3014, "10-Giga TOE Dual Port CX4 Low Profile SmartNIC(0x0000-0x3014)"},
{0x1FC9, 0x3110, 0xFFFF, 0xFFFF, "10-Giga TOE Single Port SmartNIC(0x3110)"},
{0x1FC9, 0x3110, 0x0000, 0x3004, "10-Giga TOE Single Port SFP+ SmartNIC(0x0000-0x3004)"},
{0x1FC9, 0x3114, 0xFFFF, 0xFFFF, "10-Giga TOE Dual Port Low Profile SmartNIC(0x3114)"},
{0x1FC9, 0x3114, 0x0000, 0x3005, "10-Giga TOE Dual Port SFP+ Low Profile SmartNIC(0x0000-0x3005)"},
{0x1FC9, 0x3114, 0x0000, 0x3011, "10-Giga TOE Dual Port SFP+/CX4 Low Profile SmartNIC(0x0000-0x3011)"},
{0x1FC9, 0x3114, 0x0000, 0x3012, "10-Giga TOE Dual Port CX4/SFP+ Low Profile SmartNIC(0x0000-0x3012)"},
{0x1FC9, 0x3114, 0x0000, 0x3014, "10-Giga TOE Dual Port CX4 Low Profile SmartNIC(0x0000-0x3014)"},
{0x1FC9, 0x3310, 0xFFFF, 0xFFFF, "10-Giga TOE SFP+ Single Port SmartNIC(0x3310)"},
{0x1FC9, 0x3310, 0x0000, 0x3004, "10-Giga TOE Single Port SFP+ SmartNIC(0x0000-0x3004)"},
{0x1FC9, 0x3314, 0xFFFF, 0xFFFF, "10-Giga TOE Dual Port Low Profile SmartNIC(0x3314)"},
{0x1FC9, 0x3314, 0x0000, 0x3005, "10-Giga TOE Dual Port SFP+ Low Profile SmartNIC(0x0000-0x3005)"},
{0x1FC9, 0x3314, 0x0000, 0x3011, "10-Giga TOE Dual Port SFP+/CX4 Low Profile SmartNIC(0x0000-0x3011)"},
{0x1FC9, 0x3314, 0x0000, 0x3012, "10-Giga TOE Dual Port CX4/SFP+ Low Profile SmartNIC(0x0000-0x3012)"},
{0x1FC9, 0x3314, 0x0000, 0x3014, "10-Giga TOE Dual Port CX4 Low Profile SmartNIC(0x0000-0x3014)"},
{0x1FC9, 0x4010, 0xFFFF, 0xFFFF, "TN4010 Clean SROM(0x4010)"},
{0x1FC9, 0x4020, 0xFFFF, 0xFFFF, "TN9030 10GbE CX4 Ethernet Adapter(0x4020)"},
{0x1FC9, 0x4020, 0x180C, 0x2040, "Mustang-200 10GbE Ethernet Adapter(0x180C-0x2040)"},
{0x1FC9, 0x4022, 0xFFFF, 0xFFFF, "TN9310 10GbE SFP+ Ethernet Adapter(0x4022)"},
{0x1FC9, 0x4022, 0x1043, 0x8709, "XG-C100F 10GbE SFP+ Ethernet Adapter(0x1043-0x8709)"},
{0x1FC9, 0x4022, 0x1186, 0x4D00, "DXE-810S 10GbE SFP+ Ethernet Adapter(0x1186-0x4D00)"},
{0x1FC9, 0x4022, 0x1432, 0x8103, "10 Gigabit Ethernet SFP+ PCI Express Adapter(0x1432-0x8103)"},
{0x1FC9, 0x4022, 0x1FC9, 0x3015, "Ethernet Adapter(0x1FC9-0x3015)"},
{0x1FC9, 0x4024, 0xFFFF, 0xFFFF, "TN9210 10GBase-T Ethernet Adapter(0x4024)"},
{0x1FC9, 0x4025, 0xFFFF, 0xFFFF, "TN9510 10GBase-T/NBASE-T Ethernet Adapter(0x4025)"},
{0x1FC9, 0x4025, 0x105A, 0x7203, "SANLink3 NBase-T1(0x105A-0x7203)"},
{0x1FC9, 0x4025, 0x1186, 0x2900, "DXE-810T 10GBase-T Ethernet Adapter(0x1186-0x2900)"},
{0x1FC9, 0x4025, 0x1432, 0x8102, "10 Gigabit Ethernet PCI Express Adapter(0x1432-0x8102)"},
{0x1FC9, 0x4025, 0x1FC9, 0x3015, "Ethernet Adapter(0x1FC9-0x3015)"},
{0x1FC9, 0x4026, 0xFFFF, 0xFFFF, "TN9610 10GbE SFP+ Ethernet Adapter(0x4026)"},
{0x1FC9, 0x4026, 0x4C52, 0x1000, "LREC6860AF 10 Gigabit Ethernet Adapter(0x4C52-0x1000)"},
{0x1FC9, 0x4027, 0xFFFF, 0xFFFF, "TN9710P 10GBase-T/NBASE-T Ethernet Adapter(0x4027)"},
{0x1FC9, 0x4027, 0x1154, 0x0368, "LGY-PCIE-MG(0x1154-0x0368)"},
{0x1FC9, 0x4027, 0x1432, 0x8104, "10 Gigabit Ethernet PCI Express Adapter(0x1432-0x8104)"},
{0x1FC9, 0x4027, 0x1546, 0x4027, "GE10-PCIE4XG202P 10Gbase-T/NBASE-T Ethernet Adapter(0x1546-0x4027)"},
{0x1FC9, 0x4027, 0x1BAA, 0x3310, "PCIe Expansion Card(0x1BAA-0x3310)"},
{0x1FC9, 0x4027, 0x1FC9, 0x3015, "Ethernet Adapter(0x1FC9-0x3015)"},
{0x1FC9, 0x4027, 0x4C52, 0x1001, "LREC6860BT 10 Gigabit Ethernet Adapter(0x4C52-0x1001)"},
{0x1FC9, 0x4527, 0xFFFF, 0xFFFF, "TN9710Q 5GBase-T/NBASE-T Ethernet Adapter(0x4527)"},
}; /* pci_vid_1FC9[] */

static pci_id_t const pci_vid_1FCC[] = {
{0x1FCC, 0xFFFF, 0xFFFF, 0xFFFF, "StreamLabs(0x1FCC)"},
{0x1FCC, 0xF416, 0xFFFF, 0xFFFF, "MS416(0xF416)"},
{0x1FCC, 0xFB01, 0xFFFF, 0xFFFF, "MH4LM(0xFB01)"},
}; /* pci_vid_1FCC[] */

static pci_id_t const pci_vid_1FCE[] = {
{0x1FCE, 0xFFFF, 0xFFFF, 0xFFFF, "Cognio Inc.(0x1FCE)"},
{0x1FCE, 0x0001, 0xFFFF, 0xFFFF, "Spectrum Analyzer PC Card (SAgE)(0x0001)"},
}; /* pci_vid_1FCE[] */

static pci_id_t const pci_vid_1FD4[] = {
{0x1FD4, 0xFFFF, 0xFFFF, 0xFFFF, "SUNIX Co., Ltd.(0x1FD4)"},
{0x1FD4, 0x0001, 0xFFFF, 0xFFFF, "Matrix multiport serial adapter(0x0001)"},
{0x1FD4, 0x1999, 0xFFFF, 0xFFFF, "Multiport serial controller(0x1999)"},
}; /* pci_vid_1FD4[] */

static pci_id_t const pci_vid_1FDE[] = {
{0x1FDE, 0xFFFF, 0xFFFF, 0xFFFF, "Kratos Defense & Security Solutions, Inc.(0x1FDE)"},
{0x1FDE, 0x1125, 0xFFFF, 0xFFFF, "OpenEdge 1125P(0x1125)"},
{0x1FDE, 0x2500, 0xFFFF, 0xFFFF, "OpenEdge 2500P(0x2500)"},
}; /* pci_vid_1FDE[] */

static pci_id_t const pci_vid_1FE0[] = {
{0x1FE0, 0xFFFF, 0xFFFF, 0xFFFF, "Allwinmeta Co., Ltd.(0x1FE0)"},
{0x1FE0, 0x1010, 0xFFFF, 0xFFFF, "AWM 1(0x1010)"},
{0x1FE0, 0x2000, 0xFFFF, 0xFFFF, "AWM 2(0x2000)"},
{0x1FE0, 0x2010, 0xFFFF, 0xFFFF, "AWM 2-M(0x2010)"},
}; /* pci_vid_1FE0[] */

static pci_id_t const pci_vid_1FE4[] = {
{0x1FE4, 0xFFFF, 0xFFFF, 0xFFFF, "HippStor Technology(0x1FE4)"},
{0x1FE4, 0x1600, 0xFFFF, 0xFFFF, "HP600 Series NVMe SSD(0x1600)"},
{0x1FE4, 0x1600, 0x1FE4, 0x0075, "Enterprise NVMe SSD U.2 3.84TB(HP610)(0x1FE4-0x0075)"},
{0x1FE4, 0x1600, 0x1FE4, 0x0076, "Enterprise NVMe SSD U.2 7.68TB(HP610)(0x1FE4-0x0076)"},
{0x1FE4, 0x1600, 0x1FE4, 0x0077, "Enterprise NVMe SSD U.2 6.40TB(HP630)(0x1FE4-0x0077)"},
{0x1FE4, 0x1600, 0x1FE4, 0x0078, "Enterprise NVMe SSD U.2 3.20TB(HP630)(0x1FE4-0x0078)"},
}; /* pci_vid_1FE4[] */

static pci_id_t const pci_vid_1FE9[] = {
{0x1FE9, 0xFFFF, 0xFFFF, 0xFFFF, "MemryX(0x1FE9)"},
}; /* pci_vid_1FE9[] */

static pci_id_t const pci_vid_1FF2[] = {
{0x1FF2, 0xFFFF, 0xFFFF, 0xFFFF, "Linkdata(0x1FF2)"},
{0x1FF2, 0x10A1, 0xFFFF, 0xFFFF, "NIC1160 Ethernet Controller Family(0x10A1)"},
{0x1FF2, 0x10A1, 0x1FF2, 0x0C11, "10GE Ethernet Adapter 1160-2X(0x1FF2-0x0C11)"},
{0x1FF2, 0x10A2, 0xFFFF, 0xFFFF, "NIC1160 Ethernet Controller Virtual Function Family(0x10A2)"},
{0x1FF2, 0x20A1, 0xFFFF, 0xFFFF, "IOC2110 Storage Controller(0x20A1)"},
{0x1FF2, 0x20A1, 0x1FF2, 0x0A11, "2120-16i SATA3/SAS3 HBA Adapter(0x1FF2-0x0A11)"},
{0x1FF2, 0x20A1, 0x1FF2, 0x0A12, "2120-8i SATA3/SAS3 HBA Adapter(0x1FF2-0x0A12)"},
{0x1FF2, 0x20A2, 0xFFFF, 0xFFFF, "IOC2250 Storage Controller(0x20A2)"},
{0x1FF2, 0x20A2, 0x1FF2, 0x0A21, "2230-18i Tri-mode HBA Adapter(0x1FF2-0x0A21)"},
{0x1FF2, 0x20A2, 0x1FF2, 0x0A22, "2230-10i Tri-mode HBA Adapter(0x1FF2-0x0A22)"},
{0x1FF2, 0x20A2, 0x1FF2, 0x0A23, "2230-16i Tri-mode HBA Adapter(0x1FF2-0x0A23)"},
{0x1FF2, 0x20A2, 0x1FF2, 0x0A24, "2230-8i Tri-mode HBA Adapter(0x1FF2-0x0A24)"},
{0x1FF2, 0x20A2, 0x1FF2, 0x0A28, "2233-16i Tri-mode HBA Adapter(0x1FF2-0x0A28)"},
{0x1FF2, 0x30A2, 0xFFFF, 0xFFFF, "ROC3250 Storage Controller(0x30A2)"},
{0x1FF2, 0x30A2, 0x1FF2, 0x0B21, "3260-18i Tri-mode RAID Adapter(0x1FF2-0x0B21)"},
{0x1FF2, 0x30A2, 0x1FF2, 0x0B22, "3260-10i Tri-mode RAID Adapter(0x1FF2-0x0B22)"},
{0x1FF2, 0x30A2, 0x1FF2, 0x0B23, "3260-16i Tri-mode RAID Adapter(0x1FF2-0x0B23)"},
{0x1FF2, 0x30A2, 0x1FF2, 0x0B24, "3260-8i Tri-mode RAID Adapter(0x1FF2-0x0B24)"},
}; /* pci_vid_1FF2[] */

static pci_id_t const pci_vid_1FF4[] = {
{0x1FF4, 0xFFFF, 0xFFFF, 0xFFFF, "DEEPX Co., Ltd.(0x1FF4)"},
{0x1FF4, 0x0000, 0xFFFF, 0xFFFF, "DX_M1(0x0000)"},
{0x1FF4, 0x0001, 0xFFFF, 0xFFFF, "DX_M1A(0x0001)"},
{0x1FF4, 0x1000, 0xFFFF, 0xFFFF, "DX_H1(0x1000)"},
}; /* pci_vid_1FF4[] */

static pci_id_t const pci_vid_1FF8[] = {
{0x1FF8, 0xFFFF, 0xFFFF, 0xFFFF, "Beijing Gengtu Technology Co.Ltd(0x1FF8)"},
{0x1FF8, 0x2000, 0xFFFF, 0xFFFF, "GT6910(0x2000)"},
{0x1FF8, 0x2010, 0xFFFF, 0xFFFF, "GT6908(0x2010)"},
}; /* pci_vid_1FF8[] */

static pci_id_t const pci_vid_1FF9[] = {
{0x1FF9, 0xFFFF, 0xFFFF, 0xFFFF, "Inagile Electronic Technology Co., LTD(0x1FF9)"},
}; /* pci_vid_1FF9[] */

static pci_id_t const pci_vid_2000[] = {
{0x2000, 0xFFFF, 0xFFFF, 0xFFFF, "Smart Link Ltd.(0x2000)"},
{0x2000, 0x2800, 0xFFFF, 0xFFFF, "SmartPCI2800 V.92 PCI Soft DFT(0x2800)"},
}; /* pci_vid_2000[] */

static pci_id_t const pci_vid_2001[] = {
{0x2001, 0xFFFF, 0xFFFF, 0xFFFF, "Temporal Research Ltd(0x2001)"},
}; /* pci_vid_2001[] */

static pci_id_t const pci_vid_2003[] = {
{0x2003, 0xFFFF, 0xFFFF, 0xFFFF, "Smart Link Ltd.(0x2003)"},
{0x2003, 0x8800, 0xFFFF, 0xFFFF, "LM-I56N(0x8800)"},
}; /* pci_vid_2003[] */

static pci_id_t const pci_vid_2004[] = {
{0x2004, 0xFFFF, 0xFFFF, 0xFFFF, "Smart Link Ltd.(0x2004)"},
}; /* pci_vid_2004[] */

static pci_id_t const pci_vid_202C[] = {
{0x202C, 0xFFFF, 0xFFFF, 0xFFFF, "CAEN S.p.A.(0x202C)"},
{0x202C, 0x5818, 0xFFFF, 0xFFFF, "A5818(0x5818)"},
}; /* pci_vid_202C[] */

static pci_id_t const pci_vid_2036[] = {
{0x2036, 0xFFFF, 0xFFFF, 0xFFFF, "Netforward Microelectronics Co., Ltd.(0x2036)"},
{0x2036, 0x1618, 0xFFFF, 0xFFFF, "NF1618 PCI Express Ethernet Controller(0x1618)"},
{0x2036, 0x1619, 0xFFFF, 0xFFFF, "NF1618 Family Virtual Function(0x1619)"},
}; /* pci_vid_2036[] */

static pci_id_t const pci_vid_2046[] = {
{0x2046, 0xFFFF, 0xFFFF, 0xFFFF, "GXMICRO Technology (Shanghai) Co., Ltd.(0x2046)"},
}; /* pci_vid_2046[] */

static pci_id_t const pci_vid_2048[] = {
{0x2048, 0xFFFF, 0xFFFF, 0xFFFF, "Beijing SpaceControl Technology Co.Ltd(0x2048)"},
}; /* pci_vid_2048[] */

static pci_id_t const pci_vid_20F4[] = {
{0x20F4, 0xFFFF, 0xFFFF, 0xFFFF, "TRENDnet(0x20F4)"},
}; /* pci_vid_20F4[] */

static pci_id_t const pci_vid_2116[] = {
{0x2116, 0xFFFF, 0xFFFF, 0xFFFF, "ZyDAS Technology Corp.(0x2116)"},
}; /* pci_vid_2116[] */

static pci_id_t const pci_vid_21B4[] = {
{0x21B4, 0xFFFF, 0xFFFF, 0xFFFF, "Hunan Goke Microelectronics Co., Ltd(0x21B4)"},
}; /* pci_vid_21B4[] */

static pci_id_t const pci_vid_21C3[] = {
{0x21C3, 0xFFFF, 0xFFFF, 0xFFFF, "21st Century Computer Corp.(0x21C3)"},
}; /* pci_vid_21C3[] */

static pci_id_t const pci_vid_22B8[] = {
{0x22B8, 0xFFFF, 0xFFFF, 0xFFFF, "Flex-Logix Technologies(0x22B8)"},
{0x22B8, 0x22A0, 0xFFFF, 0xFFFF, "Flex Logix InferX X1 Inference Accelerator(0x22A0)"},
}; /* pci_vid_22B8[] */

static pci_id_t const pci_vid_22DB[] = {
{0x22DB, 0xFFFF, 0xFFFF, 0xFFFF, "Missing Link Electronics, Inc.(0x22DB)"},
{0x22DB, 0x1200, 0xFFFF, 0xFFFF, "NVMe Streamer EP ERD(0x1200)"},
}; /* pci_vid_22DB[] */

static pci_id_t const pci_vid_2304[] = {
{0x2304, 0xFFFF, 0xFFFF, 0xFFFF, "Colorgraphic Communications Corp.(0x2304)"},
}; /* pci_vid_2304[] */

static pci_id_t const pci_vid_2321[] = {
{0x2321, 0xFFFF, 0xFFFF, 0xFFFF, "Bruker AXS Inc.(0x2321)"},
}; /* pci_vid_2321[] */

static pci_id_t const pci_vid_2348[] = {
{0x2348, 0xFFFF, 0xFFFF, 0xFFFF, "Racore(0x2348)"},
{0x2348, 0x2010, 0xFFFF, 0xFFFF, "8142 100VG/AnyLAN(0x2010)"},
}; /* pci_vid_2348[] */

static pci_id_t const pci_vid_256C[] = {
{0x256C, 0xFFFF, 0xFFFF, 0xFFFF, "Graphics Technology (HK) Co., Ltd.(0x256C)"},
{0x256C, 0x006D, 0xFFFF, 0xFFFF, "HS610(0x006D)"},
}; /* pci_vid_256C[] */

static pci_id_t const pci_vid_2646[] = {
{0x2646, 0xFFFF, 0xFFFF, 0xFFFF, "Kingston Technology Company, Inc.(0x2646)"},
{0x2646, 0x0010, 0xFFFF, 0xFFFF, "HyperX Predator PCIe AHCI SSD(0x0010)"},
{0x2646, 0x2262, 0xFFFF, 0xFFFF, "KC2000/KC2500 NVMe SSD SM2262EN(0x2262)"},
{0x2646, 0x2263, 0xFFFF, 0xFFFF, "A2000 NVMe SSD SM2263EN(0x2263)"},
{0x2646, 0x5008, 0xFFFF, 0xFFFF, "A1000/U-SNS8154P3 x2 NVMe SSD(0x5008)"},
{0x2646, 0x500A, 0xFFFF, 0xFFFF, "DC1000B NVMe SSD E12DC(0x500A)"},
{0x2646, 0x500B, 0xFFFF, 0xFFFF, "DC1000M NVMe SSD SM2270(0x500B)"},
{0x2646, 0x500C, 0xFFFF, 0xFFFF, "OM8PCP Design-In PCIe 3 NVMe SSD (DRAM-less)(0x500C)"},
{0x2646, 0x500D, 0xFFFF, 0xFFFF, "OM3PDP3 NVMe SSD(0x500D)"},
{0x2646, 0x500E, 0xFFFF, 0xFFFF, "NV1 NVMe SSD E13T (DRAM-less)(0x500E)"},
{0x2646, 0x500F, 0xFFFF, 0xFFFF, "NV1 NVMe SSD SM2263XT (DRAM-less)(0x500F)"},
{0x2646, 0x5010, 0xFFFF, 0xFFFF, "OM8SBP NVMe PCIe SSD (DRAM-less)(0x5010)"},
{0x2646, 0x5012, 0xFFFF, 0xFFFF, "DC1500M NVMe SSD SM2270(0x5012)"},
{0x2646, 0x5013, 0xFFFF, 0xFFFF, "KC3000/FURY Renegade NVMe SSD E18(0x5013)"},
{0x2646, 0x5014, 0xFFFF, 0xFFFF, "OM8SEP4 Design-In PCIe 4 NVMe SSD (TLC) (DRAM-less)(0x5014)"},
{0x2646, 0x5016, 0xFFFF, 0xFFFF, "OM3PGP4 NVMe SSD(0x5016)"},
{0x2646, 0x5017, 0xFFFF, 0xFFFF, "NV2 NVMe SSD SM2267XT (DRAM-less)(0x5017)"},
{0x2646, 0x5019, 0xFFFF, 0xFFFF, "NV2 NVMe SSD E21T (DRAM-less)(0x5019)"},
{0x2646, 0x501A, 0xFFFF, 0xFFFF, "OM8PGP4 Design-In PCIe 4 NVMe SSD (TLC) (DRAM-less)(0x501A)"},
{0x2646, 0x501B, 0xFFFF, 0xFFFF, "OM8PGP4 NVMe PCIe SSD (DRAM-less)(0x501B)"},
{0x2646, 0x501C, 0xFFFF, 0xFFFF, "NV2 NVMe SSD E19T (DRAM-less)(0x501C)"},
{0x2646, 0x501D, 0xFFFF, 0xFFFF, "NV2 NVMe SSD TC2200 (DRAM-less)(0x501D)"},
{0x2646, 0x501F, 0xFFFF, 0xFFFF, "FURY Renegade NVMe SSD with heatsink(0x501F)"},
{0x2646, 0x5021, 0xFFFF, 0xFFFF, "OM8SEP4 Design-In PCIe 4 NVMe SSD (QLC) (DRAM-less)(0x5021)"},
{0x2646, 0x5022, 0xFFFF, 0xFFFF, "OM8PGP4 Design-In PCIe 4 NVMe SSD (QLC) (DRAM-less)(0x5022)"},
{0x2646, 0x5023, 0xFFFF, 0xFFFF, "NV2 NVMe SSD SM2269XT (DRAM-less)(0x5023)"},
{0x2646, 0x5024, 0xFFFF, 0xFFFF, "DC2000B NVMe SSD E18DC(0x5024)"},
}; /* pci_vid_2646[] */

static pci_id_t const pci_vid_270B[] = {
{0x270B, 0xFFFF, 0xFFFF, 0xFFFF, "Xantel Corporation(0x270B)"},
}; /* pci_vid_270B[] */

static pci_id_t const pci_vid_270F[] = {
{0x270F, 0xFFFF, 0xFFFF, 0xFFFF, "Chaintech Computer Co. Ltd(0x270F)"},
}; /* pci_vid_270F[] */

static pci_id_t const pci_vid_2711[] = {
{0x2711, 0xFFFF, 0xFFFF, 0xFFFF, "AVID Technology Inc.(0x2711)"},
}; /* pci_vid_2711[] */

static pci_id_t const pci_vid_2782[] = {
{0x2782, 0xFFFF, 0xFFFF, 0xFFFF, "Emdoor Digital Technology Co., Ltd(0x2782)"},
}; /* pci_vid_2782[] */

static pci_id_t const pci_vid_2955[] = {
{0x2955, 0xFFFF, 0xFFFF, 0xFFFF, "Connectix Virtual PC(0x2955)"},
{0x2955, 0x6E61, 0xFFFF, 0xFFFF, "OHCI USB 1.1 controller(0x6E61)"},
}; /* pci_vid_2955[] */

static pci_id_t const pci_vid_2A15[] = {
{0x2A15, 0xFFFF, 0xFFFF, 0xFFFF, "3D Vision(?-?-?-)(0x2A15)"},
}; /* pci_vid_2A15[] */

static pci_id_t const pci_vid_2A18[] = {
{0x2A18, 0xFFFF, 0xFFFF, 0xFFFF, "Video Transcode Controller(0x2A18)"},
}; /* pci_vid_2A18[] */

static pci_id_t const pci_vid_2BD8[] = {
{0x2BD8, 0xFFFF, 0xFFFF, 0xFFFF, "ROPEX Industrie-Elektronik GmbH(0x2BD8)"},
}; /* pci_vid_2BD8[] */

static pci_id_t const pci_vid_3000[] = {
{0x3000, 0xFFFF, 0xFFFF, 0xFFFF, "Hansol Electronics Inc.(0x3000)"},
}; /* pci_vid_3000[] */

static pci_id_t const pci_vid_3100[] = {
{0x3100, 0xFFFF, 0xFFFF, 0xFFFF, "Dynabook Inc.(0x3100)"},
}; /* pci_vid_3100[] */

static pci_id_t const pci_vid_3112[] = {
{0x3112, 0xFFFF, 0xFFFF, 0xFFFF, "Satelco Ingenieria S.A.(0x3112)"},
}; /* pci_vid_3112[] */

static pci_id_t const pci_vid_3130[] = {
{0x3130, 0xFFFF, 0xFFFF, 0xFFFF, "AUDIOTRAK(0x3130)"},
}; /* pci_vid_3130[] */

static pci_id_t const pci_vid_3142[] = {
{0x3142, 0xFFFF, 0xFFFF, 0xFFFF, "Post Impression Systems.(0x3142)"},
}; /* pci_vid_3142[] */

static pci_id_t const pci_vid_31AB[] = {
{0x31AB, 0xFFFF, 0xFFFF, 0xFFFF, "Zonet(0x31AB)"},
{0x31AB, 0x1FAA, 0xFFFF, 0xFFFF, "ZEW1602 802.11b/g Wireless Adapter(0x1FAA)"},
}; /* pci_vid_31AB[] */

static pci_id_t const pci_vid_328F[] = {
{0x328F, 0xFFFF, 0xFFFF, 0xFFFF, "Shenzhen EMEET Technology Co., Ltd.(0x328F)"},
{0x328F, 0x004C, 0xFFFF, 0xFFFF, "OfficeCore M1A(0x004C)"},
{0x328F, 0x2019, 0xFFFF, 0xFFFF, "REC 600 HD Webcam(0x2019)"},
}; /* pci_vid_328F[] */

static pci_id_t const pci_vid_3388[] = {
{0x3388, 0xFFFF, 0xFFFF, 0xFFFF, "Hint Corp(0x3388)"},
{0x3388, 0x0013, 0xFFFF, 0xFFFF, "HiNT HC4 PCI to ISDN bridge, Multimedia audio controller(0x0013)"},
{0x3388, 0x0014, 0xFFFF, 0xFFFF, "HiNT HC4 PCI to ISDN bridge, Network controller(0x0014)"},
{0x3388, 0x0020, 0xFFFF, 0xFFFF, "HB6 Universal PCI-PCI bridge (transparent mode)(0x0020)"},
{0x3388, 0x0021, 0xFFFF, 0xFFFF, "HB6 Universal PCI-PCI bridge (non-transparent mode)(0x0021)"},
{0x3388, 0x0021, 0x1775, 0xC200, "C2K CompactPCI interface bridge(0x1775-0xC200)"},
{0x3388, 0x0021, 0x1775, 0xCE90, "CE9(0x1775-0xCE90)"},
{0x3388, 0x0021, 0x4C53, 0x1050, "CT7 mainboard(0x4C53-0x1050)"},
{0x3388, 0x0021, 0x4C53, 0x1080, "CT8 mainboard(0x4C53-0x1080)"},
{0x3388, 0x0021, 0x4C53, 0x1090, "Cx9 mainboard(0x4C53-0x1090)"},
{0x3388, 0x0021, 0x4C53, 0x10A0, "CA3/CR3 mainboard(0x4C53-0x10A0)"},
{0x3388, 0x0021, 0x4C53, 0x3010, "PPCI mezzanine (32-bit PMC)(0x4C53-0x3010)"},
{0x3388, 0x0021, 0x4C53, 0x3011, "PPCI mezzanine (64-bit PMC)(0x4C53-0x3011)"},
{0x3388, 0x0021, 0x4C53, 0x4000, "PMCCARR1 carrier board(0x4C53-0x4000)"},
{0x3388, 0x0022, 0xFFFF, 0xFFFF, "HiNT HB4 PCI-PCI Bridge (PCI6150)(0x0022)"},
{0x3388, 0x0026, 0xFFFF, 0xFFFF, "HB2 PCI-PCI Bridge(0x0026)"},
{0x3388, 0x1014, 0xFFFF, 0xFFFF, "AudioTrak Maya(0x1014)"},
{0x3388, 0x1018, 0xFFFF, 0xFFFF, "Audiotrak INCA88(0x1018)"},
{0x3388, 0x1019, 0xFFFF, 0xFFFF, "Miditrak 2120(0x1019)"},
{0x3388, 0x101A, 0xFFFF, 0xFFFF, "E.Band [AudioTrak Inca88](0x101A)"},
{0x3388, 0x101B, 0xFFFF, 0xFFFF, "E.Band [AudioTrak Inca88](0x101B)"},
{0x3388, 0x8011, 0xFFFF, 0xFFFF, "VXPro II Chipset(0x8011)"},
{0x3388, 0x8011, 0x3388, 0x8011, "VXPro II Chipset CPU to PCI Bridge(0x3388-0x8011)"},
{0x3388, 0x8012, 0xFFFF, 0xFFFF, "VXPro II Chipset(0x8012)"},
{0x3388, 0x8012, 0x3388, 0x8012, "VXPro II Chipset PCI to ISA Bridge(0x3388-0x8012)"},
{0x3388, 0x8013, 0xFFFF, 0xFFFF, "VXPro II IDE(0x8013)"},
{0x3388, 0x8013, 0x3388, 0x8013, "VXPro II Chipset EIDE Controller(0x3388-0x8013)"},
{0x3388, 0xA103, 0xFFFF, 0xFFFF, "Blackmagic Design DeckLink HD Pro(0xA103)"},
}; /* pci_vid_3388[] */

static pci_id_t const pci_vid_3411[] = {
{0x3411, 0xFFFF, 0xFFFF, 0xFFFF, "Quantum Designs (H.K.) Inc(0x3411)"},
}; /* pci_vid_3411[] */

static pci_id_t const pci_vid_3442[] = {
{0x3442, 0xFFFF, 0xFFFF, 0xFFFF, "Bihl+Wiedemann GmbH(0x3442)"},
{0x3442, 0x1783, 0xFFFF, 0xFFFF, "AS-i 3.0 cPCI Master(0x1783)"},
{0x3442, 0x1922, 0xFFFF, 0xFFFF, "AS-i 3.0 PCI Master(0x1922)"},
}; /* pci_vid_3442[] */

static pci_id_t const pci_vid_3475[] = {
{0x3475, 0xFFFF, 0xFFFF, 0xFFFF, "Arista Networks, Inc.(0x3475)"},
}; /* pci_vid_3475[] */

static pci_id_t const pci_vid_34BA[] = {
{0x34BA, 0xFFFF, 0xFFFF, 0xFFFF, "Ice Lake-LP PCI Express Root Port #3(0x34BA)"},
}; /* pci_vid_34BA[] */

static pci_id_t const pci_vid_3513[] = {
{0x3513, 0xFFFF, 0xFFFF, 0xFFFF, "ARCOM Control Systems Ltd(0x3513)"},
}; /* pci_vid_3513[] */

static pci_id_t const pci_vid_369A[] = {
{0x369A, 0xFFFF, 0xFFFF, 0xFFFF, "HighSecLabs, Ltd.(0x369A)"},
}; /* pci_vid_369A[] */

static pci_id_t const pci_vid_37D9[] = {
{0x37D9, 0xFFFF, 0xFFFF, 0xFFFF, "ITD Firm ltd.(0x37D9)"},
{0x37D9, 0x1138, 0xFFFF, 0xFFFF, "SCHD-PH-8 Phase detector(0x1138)"},
{0x37D9, 0x1140, 0xFFFF, 0xFFFF, "VR-12-PCI 12-ch Relay Actuator Card(0x1140)"},
{0x37D9, 0x1141, 0xFFFF, 0xFFFF, "PCI-485(422) Multi-port Serial Board(0x1141)"},
{0x37D9, 0x1142, 0xFFFF, 0xFFFF, "PCI-CAN2(0x1142)"},
}; /* pci_vid_37D9[] */

static pci_id_t const pci_vid_3842[] = {
{0x3842, 0xFFFF, 0xFFFF, 0xFFFF, "eVga.com. Corp.(0x3842)"},
}; /* pci_vid_3842[] */

static pci_id_t const pci_vid_38EF[] = {
{0x38EF, 0xFFFF, 0xFFFF, 0xFFFF, "4Links(0x38EF)"},
}; /* pci_vid_38EF[] */

static pci_id_t const pci_vid_393E[] = {
{0x393E, 0xFFFF, 0xFFFF, 0xFFFF, "Lenovo (wrong ID)(0x393E)"},
}; /* pci_vid_393E[] */

static pci_id_t const pci_vid_3D3D[] = {
{0x3D3D, 0xFFFF, 0xFFFF, 0xFFFF, "3DLabs(0x3D3D)"},
{0x3D3D, 0x0001, 0xFFFF, 0xFFFF, "GLINT 300SX(0x0001)"},
{0x3D3D, 0x0002, 0xFFFF, 0xFFFF, "GLINT 500TX(0x0002)"},
{0x3D3D, 0x0002, 0x0000, 0x0000, "GLoria L(0x0000-0x0000)"},
{0x3D3D, 0x0003, 0xFFFF, 0xFFFF, "GLINT Delta(0x0003)"},
{0x3D3D, 0x0003, 0x0000, 0x0000, "GLoria XL(0x0000-0x0000)"},
{0x3D3D, 0x0004, 0xFFFF, 0xFFFF, "Permedia(0x0004)"},
{0x3D3D, 0x0005, 0xFFFF, 0xFFFF, "Permedia(0x0005)"},
{0x3D3D, 0x0006, 0xFFFF, 0xFFFF, "GLINT MX(0x0006)"},
{0x3D3D, 0x0006, 0x0000, 0x0000, "GLoria XL(0x0000-0x0000)"},
{0x3D3D, 0x0006, 0x1048, 0x0A42, "GLoria XXL(0x1048-0x0A42)"},
{0x3D3D, 0x0007, 0xFFFF, 0xFFFF, "3D Extreme(0x0007)"},
{0x3D3D, 0x0008, 0xFFFF, 0xFFFF, "GLINT Gamma G1(0x0008)"},
{0x3D3D, 0x0008, 0x1048, 0x0A42, "GLoria XXL(0x1048-0x0A42)"},
{0x3D3D, 0x0009, 0xFFFF, 0xFFFF, "Permedia II 2D+3D(0x0009)"},
{0x3D3D, 0x0009, 0x1040, 0x0011, "AccelStar II(0x1040-0x0011)"},
{0x3D3D, 0x0009, 0x1048, 0x0A42, "GLoria XXL(0x1048-0x0A42)"},
{0x3D3D, 0x0009, 0x13E9, 0x1000, "6221L-4U(0x13E9-0x1000)"},
{0x3D3D, 0x0009, 0x3D3D, 0x0100, "AccelStar II 3D Accelerator(0x3D3D-0x0100)"},
{0x3D3D, 0x0009, 0x3D3D, 0x0111, "Permedia 3:16(0x3D3D-0x0111)"},
{0x3D3D, 0x0009, 0x3D3D, 0x0114, "Santa Ana(0x3D3D-0x0114)"},
{0x3D3D, 0x0009, 0x3D3D, 0x0116, "Oxygen GVX1(0x3D3D-0x0116)"},
{0x3D3D, 0x0009, 0x3D3D, 0x0119, "Scirocco(0x3D3D-0x0119)"},
{0x3D3D, 0x0009, 0x3D3D, 0x0120, "Santa Ana PCL(0x3D3D-0x0120)"},
{0x3D3D, 0x0009, 0x3D3D, 0x0125, "Oxygen VX1(0x3D3D-0x0125)"},
{0x3D3D, 0x0009, 0x3D3D, 0x0127, "Permedia3 Create!(0x3D3D-0x0127)"},
{0x3D3D, 0x000A, 0xFFFF, 0xFFFF, "GLINT R3(0x000A)"},
{0x3D3D, 0x000A, 0x3D3D, 0x0121, "Oxygen VX1(0x3D3D-0x0121)"},
{0x3D3D, 0x000C, 0xFFFF, 0xFFFF, "GLINT R3 [Oxygen VX1](0x000C)"},
{0x3D3D, 0x000C, 0x3D3D, 0x0144, "Oxygen VX1-4X AGP [Permedia 4](0x3D3D-0x0144)"},
{0x3D3D, 0x000D, 0xFFFF, 0xFFFF, "GLint R4 rev A(0x000D)"},
{0x3D3D, 0x000E, 0xFFFF, 0xFFFF, "GLINT Gamma G2(0x000E)"},
{0x3D3D, 0x0011, 0xFFFF, 0xFFFF, "GLint R4 rev B(0x0011)"},
{0x3D3D, 0x0012, 0xFFFF, 0xFFFF, "GLint R5 rev A(0x0012)"},
{0x3D3D, 0x0013, 0xFFFF, 0xFFFF, "GLint R5 rev B(0x0013)"},
{0x3D3D, 0x0020, 0xFFFF, 0xFFFF, "VP10 visual processor(0x0020)"},
{0x3D3D, 0x0022, 0xFFFF, 0xFFFF, "VP10 visual processor(0x0022)"},
{0x3D3D, 0x0024, 0xFFFF, 0xFFFF, "VP9 visual processor(0x0024)"},
{0x3D3D, 0x002C, 0xFFFF, 0xFFFF, "Wildcat Realizm 100/200(0x002C)"},
{0x3D3D, 0x0030, 0xFFFF, 0xFFFF, "Wildcat Realizm 800(0x0030)"},
{0x3D3D, 0x0032, 0xFFFF, 0xFFFF, "Wildcat Realizm 500(0x0032)"},
{0x3D3D, 0x0100, 0xFFFF, 0xFFFF, "Permedia II 2D+3D(0x0100)"},
{0x3D3D, 0x07A1, 0xFFFF, 0xFFFF, "Wildcat III 6210(0x07A1)"},
{0x3D3D, 0x07A2, 0xFFFF, 0xFFFF, "Sun XVR-500 Graphics Accelerator(0x07A2)"},
{0x3D3D, 0x07A2, 0x3D3D, 0x1047, "Sun XVR-600 Graphics Accelerator(0x3D3D-0x1047)"},
{0x3D3D, 0x07A3, 0xFFFF, 0xFFFF, "Wildcat IV 7210(0x07A3)"},
{0x3D3D, 0x1004, 0xFFFF, 0xFFFF, "Permedia(0x1004)"},
{0x3D3D, 0x3D04, 0xFFFF, 0xFFFF, "Permedia(0x3D04)"},
{0x3D3D, 0xFFFF, 0xFFFF, 0xFFFF, "Glint VGA(0xFFFF)"},
}; /* pci_vid_3D3D[] */

static pci_id_t const pci_vid_4005[] = {
{0x4005, 0xFFFF, 0xFFFF, 0xFFFF, "Avance Logic Inc.(0x4005)"},
{0x4005, 0x0300, 0xFFFF, 0xFFFF, "ALS300 PCI Audio Device(0x0300)"},
{0x4005, 0x0308, 0xFFFF, 0xFFFF, "ALS300+ PCI Audio Device(0x0308)"},
{0x4005, 0x0309, 0xFFFF, 0xFFFF, "PCI Input Controller(0x0309)"},
{0x4005, 0x1064, 0xFFFF, 0xFFFF, "ALG-2064(0x1064)"},
{0x4005, 0x2064, 0xFFFF, 0xFFFF, "ALG-2064i(0x2064)"},
{0x4005, 0x2128, 0xFFFF, 0xFFFF, "ALG-2364A GUI Accelerator(0x2128)"},
{0x4005, 0x2301, 0xFFFF, 0xFFFF, "ALG-2301(0x2301)"},
{0x4005, 0x2302, 0xFFFF, 0xFFFF, "ALG-2302(0x2302)"},
{0x4005, 0x2303, 0xFFFF, 0xFFFF, "AVG-2302 GUI Accelerator(0x2303)"},
{0x4005, 0x2364, 0xFFFF, 0xFFFF, "ALG-2364A(0x2364)"},
{0x4005, 0x2464, 0xFFFF, 0xFFFF, "ALG-2464(0x2464)"},
{0x4005, 0x2501, 0xFFFF, 0xFFFF, "ALG-2564A/25128A(0x2501)"},
{0x4005, 0x4000, 0xFFFF, 0xFFFF, "ALS4000 Audio Chipset(0x4000)"},
{0x4005, 0x4000, 0x4005, 0x4000, "ALS4000 Audio Chipset(0x4005-0x4000)"},
{0x4005, 0x4710, 0xFFFF, 0xFFFF, "ALC200/200P(0x4710)"},
}; /* pci_vid_4005[] */

static pci_id_t const pci_vid_4033[] = {
{0x4033, 0xFFFF, 0xFFFF, 0xFFFF, "Addtron Technology Co, Inc.(0x4033)"},
{0x4033, 0x1360, 0xFFFF, 0xFFFF, "RTL8139 Ethernet(0x1360)"},
}; /* pci_vid_4033[] */

static pci_id_t const pci_vid_4040[] = {
{0x4040, 0xFFFF, 0xFFFF, 0xFFFF, "NetXen Incorporated(0x4040)"},
{0x4040, 0x0001, 0xFFFF, 0xFFFF, "NXB-10GXSR 10-Gigabit Ethernet PCIe Adapter with SR-XFP optical interface(0x0001)"},
{0x4040, 0x0001, 0x103C, 0x7047, "NC510F PCIe 10-Gigabit Server Adapter(0x103C-0x7047)"},
{0x4040, 0x0002, 0xFFFF, 0xFFFF, "NXB-10GCX4 10-Gigabit Ethernet PCIe Adapter with CX4 copper interface(0x0002)"},
{0x4040, 0x0002, 0x103C, 0x7048, "NC510c PCIe 10-Gigabit Server Adapter(0x103C-0x7048)"},
{0x4040, 0x0003, 0xFFFF, 0xFFFF, "NXB-4GCU Quad Gigabit Ethernet PCIe Adapter with 1000-BASE-T interface(0x0003)"},
{0x4040, 0x0004, 0xFFFF, 0xFFFF, "BladeCenter-H 10-Gigabit Ethernet High Speed Daughter Card(0x0004)"},
{0x4040, 0x0005, 0xFFFF, 0xFFFF, "NetXen Dual Port 10GbE Multifunction Adapter for c-Class(0x0005)"},
{0x4040, 0x0005, 0x103C, 0x170E, "NC512m Dual Port 10GbE Multifunction BL-C Adapter(0x103C-0x170E)"},
{0x4040, 0x0024, 0xFFFF, 0xFFFF, "XG Mgmt(0x0024)"},
{0x4040, 0x0025, 0xFFFF, 0xFFFF, "XG Mgmt(0x0025)"},
{0x4040, 0x0100, 0xFFFF, 0xFFFF, "NX3031 Multifunction 1/10-Gigabit Server Adapter(0x0100)"},
{0x4040, 0x0100, 0x103C, 0x171B, "NC522m Dual Port 10GbE Multifunction BL-c Adapter(0x103C-0x171B)"},
{0x4040, 0x0100, 0x103C, 0x1740, "NC375T PCI Express Quad Port Gigabit Server Adapter(0x103C-0x1740)"},
{0x4040, 0x0100, 0x103C, 0x3251, "NC375i 1G w/NC524SFP 10G Module(0x103C-0x3251)"},
{0x4040, 0x0100, 0x103C, 0x705A, "NC375i Integrated Quad Port Multifunction Gigabit Server Adapter(0x103C-0x705A)"},
{0x4040, 0x0100, 0x103C, 0x705B, "NC522SFP Dual Port 10GbE Server Adapter(0x103C-0x705B)"},
{0x4040, 0x0100, 0x152D, 0x896B, "TG20 Dual Port 10GbE Server/Storage Adapter(0x152D-0x896B)"},
{0x4040, 0x0100, 0x4040, 0x0124, "NX3031 Quad Port Gigabit Server Adapter(0x4040-0x0124)"},
{0x4040, 0x0100, 0x4040, 0x0126, "Dual Port SFP+ 10GbE Server Adapter(0x4040-0x0126)"},
}; /* pci_vid_4040[] */

static pci_id_t const pci_vid_4143[] = {
{0x4143, 0xFFFF, 0xFFFF, 0xFFFF, "Digital Equipment Corp(0x4143)"},
}; /* pci_vid_4143[] */

static pci_id_t const pci_vid_4144[] = {
{0x4144, 0xFFFF, 0xFFFF, 0xFFFF, "Alpha Data(0x4144)"},
{0x4144, 0x0044, 0xFFFF, 0xFFFF, "ADM-XRCIIPro(0x0044)"},
}; /* pci_vid_4144[] */

static pci_id_t const pci_vid_4150[] = {
{0x4150, 0xFFFF, 0xFFFF, 0xFFFF, "ONA Electroerosion(0x4150)"},
{0x4150, 0x0001, 0xFFFF, 0xFFFF, "PCI32TLITE FILSTRUP1 PCI to VME Bridge Controller(0x0001)"},
{0x4150, 0x0006, 0xFFFF, 0xFFFF, "PCI32TLITE UART 16550 Opencores(0x0006)"},
{0x4150, 0x0007, 0xFFFF, 0xFFFF, "PCI32TLITE CAN Controller Opencores(0x0007)"},
}; /* pci_vid_4150[] */

static pci_id_t const pci_vid_415A[] = {
{0x415A, 0xFFFF, 0xFFFF, 0xFFFF, "Auzentech, Inc.(0x415A)"},
}; /* pci_vid_415A[] */

static pci_id_t const pci_vid_416C[] = {
{0x416C, 0xFFFF, 0xFFFF, 0xFFFF, "Aladdin Knowledge Systems(0x416C)"},
{0x416C, 0x0100, 0xFFFF, 0xFFFF, "AladdinCARD(0x0100)"},
{0x416C, 0x0200, 0xFFFF, 0xFFFF, "CPC(0x0200)"},
}; /* pci_vid_416C[] */

static pci_id_t const pci_vid_4242[] = {
{0x4242, 0xFFFF, 0xFFFF, 0xFFFF, "Universall Answer Generators(0x4242)"},
}; /* pci_vid_4242[] */

static pci_id_t const pci_vid_4254[] = {
{0x4254, 0xFFFF, 0xFFFF, 0xFFFF, "DVBSky(0x4254)"},
}; /* pci_vid_4254[] */

static pci_id_t const pci_vid_4321[] = {
{0x4321, 0xFFFF, 0xFFFF, 0xFFFF, "Tata Power Strategic Electronics Division(0x4321)"},
}; /* pci_vid_4321[] */

static pci_id_t const pci_vid_4348[] = {
{0x4348, 0xFFFF, 0xFFFF, 0xFFFF, "WCH.CN(0x4348)"},
{0x4348, 0x2273, 0xFFFF, 0xFFFF, "CH351 PCI Dual Serial Port Controller(0x2273)"},
{0x4348, 0x3253, 0xFFFF, 0xFFFF, "CH352 PCI Dual Serial Port Controller(0x3253)"},
{0x4348, 0x3453, 0xFFFF, 0xFFFF, "CH353 PCI Quad Serial Port Controller(0x3453)"},
{0x4348, 0x5053, 0xFFFF, 0xFFFF, "CH352 PCI Serial and Parallel Port Controller(0x5053)"},
{0x4348, 0x7053, 0xFFFF, 0xFFFF, "CH353 PCI Dual Serial and Parallel Ports Controller(0x7053)"},
{0x4348, 0x7073, 0xFFFF, 0xFFFF, "CH356 PCI Quad Serial and Parallel Ports Controller(0x7073)"},
{0x4348, 0x7173, 0xFFFF, 0xFFFF, "CH355 PCI Quad Serial Port Controller(0x7173)"},
}; /* pci_vid_4348[] */

static pci_id_t const pci_vid_434E[] = {
{0x434E, 0xFFFF, 0xFFFF, 0xFFFF, "Cornelis Networks(0x434E)"},
}; /* pci_vid_434E[] */

static pci_id_t const pci_vid_4444[] = {
{0x4444, 0xFFFF, 0xFFFF, 0xFFFF, "Internext Compression Inc(0x4444)"},
{0x4444, 0x0016, 0xFFFF, 0xFFFF, "iTVC16 (CX23416) Video Decoder(0x0016)"},
{0x4444, 0x0016, 0x0070, 0x0003, "WinTV PVR 250(0x0070-0x0003)"},
{0x4444, 0x0016, 0x0070, 0x0009, "WinTV PVR 150(0x0070-0x0009)"},
{0x4444, 0x0016, 0x0070, 0x0801, "WinTV PVR 150(0x0070-0x0801)"},
{0x4444, 0x0016, 0x0070, 0x0807, "WinTV PVR 150(0x0070-0x0807)"},
{0x4444, 0x0016, 0x0070, 0x4001, "WinTV PVR 250(0x0070-0x4001)"},
{0x4444, 0x0016, 0x0070, 0x4009, "WinTV PVR 250(0x0070-0x4009)"},
{0x4444, 0x0016, 0x0070, 0x4801, "WinTV PVR 250(0x0070-0x4801)"},
{0x4444, 0x0016, 0x0070, 0x4803, "WinTV PVR 250(0x0070-0x4803)"},
{0x4444, 0x0016, 0x0070, 0x8003, "WinTV PVR 150(0x0070-0x8003)"},
{0x4444, 0x0016, 0x0070, 0x8801, "WinTV PVR 150(0x0070-0x8801)"},
{0x4444, 0x0016, 0x0070, 0xC801, "WinTV PVR 150(0x0070-0xC801)"},
{0x4444, 0x0016, 0x0070, 0xE807, "WinTV PVR 500 (1st unit)(0x0070-0xE807)"},
{0x4444, 0x0016, 0x0070, 0xE817, "WinTV PVR 500 (2nd unit)(0x0070-0xE817)"},
{0x4444, 0x0016, 0x0070, 0xFF92, "WiNTV PVR-550(0x0070-0xFF92)"},
{0x4444, 0x0016, 0x0270, 0x0801, "WinTV PVR 150(0x0270-0x0801)"},
{0x4444, 0x0016, 0x104D, 0x013D, "ENX-26 TV Encoder(0x104D-0x013D)"},
{0x4444, 0x0016, 0x10FC, 0xD038, "GV-MVP/RX2W (1st unit)(0x10FC-0xD038)"},
{0x4444, 0x0016, 0x10FC, 0xD039, "GV-MVP/RX2W (2nd unit)(0x10FC-0xD039)"},
{0x4444, 0x0016, 0x12AB, 0xFFF3, "MPG600(0x12AB-0xFFF3)"},
{0x4444, 0x0016, 0x12AB, 0xFFFF, "MPG600(0x12AB-0xFFFF)"},
{0x4444, 0x0016, 0x1461, 0xC00A, "M113 PCI Analog TV (PAL/SECAM, Philips FQ1216MK3 tuner)(0x1461-0xC00A)"},
{0x4444, 0x0016, 0x1461, 0xC00B, "M113 PCI Analog TV (PAL/SECAM+FM, Philips FM1216MK3 tuner)(0x1461-0xC00B)"},
{0x4444, 0x0016, 0x1461, 0xC00C, "M113 PCI Analog TV (NTSC, JAPAN version, Philips FI1286MK2 tuner)(0x1461-0xC00C)"},
{0x4444, 0x0016, 0x1461, 0xC010, "M113 PCI Analog TV (NTSC, Philips FI1236MK3 tuner)(0x1461-0xC010)"},
{0x4444, 0x0016, 0x1461, 0xC011, "M113 PCI Analog TV (NTSC+FM, Philips FM1236MK3 tuner)(0x1461-0xC011)"},
{0x4444, 0x0016, 0x1461, 0xC018, "M113 PCI Analog TV (NTSC, Philips FQ1236MK5 tuner)(0x1461-0xC018)"},
{0x4444, 0x0016, 0x1461, 0xC019, "UltraTV 1500 MCE, a.k.a. M113 PCI Analog TV (NTSC+FM, Philips FQ1236MK5 tuner)(0x1461-0xC019)"},
{0x4444, 0x0016, 0x1461, 0xC01A, "M113 PCI Analog TV (PAL/SECAM, Philips FQ1216MK5 tuner)(0x1461-0xC01A)"},
{0x4444, 0x0016, 0x1461, 0xC01B, "M113 PCI Analog TV (PAL/SECAM+FM, Philips FM1216MK5 tuner)(0x1461-0xC01B)"},
{0x4444, 0x0016, 0x1461, 0xC030, "M113 PCI Analog TV (NTSC-J, Partsnic tuner)(0x1461-0xC030)"},
{0x4444, 0x0016, 0x1461, 0xC031, "M113 PCI Analog TV (NTSC-J+FM, Partsnic tuner)(0x1461-0xC031)"},
{0x4444, 0x0016, 0x1461, 0xC032, "M113 PCI Analog TV (PAL/SECAM, Partsnic tuner)(0x1461-0xC032)"},
{0x4444, 0x0016, 0x1461, 0xC033, "M113 PCI Analog TV (PAL/SECAM+FM, Partsnic tuner)(0x1461-0xC033)"},
{0x4444, 0x0016, 0x1461, 0xC034, "M113 PCI Analog TV (NTSC, Partsnic tuner)(0x1461-0xC034)"},
{0x4444, 0x0016, 0x1461, 0xC035, "M113 PCI Analog TV (NTSC+FM, Partsnic tuner)(0x1461-0xC035)"},
{0x4444, 0x0016, 0x1461, 0xC03F, "C115 PCI video capture card (no tuner)(0x1461-0xC03F)"},
{0x4444, 0x0016, 0x1461, 0xC136, "M104 mini-PCI Analog TV(0x1461-0xC136)"},
{0x4444, 0x0016, 0x1461, 0xC20A, "M755 AVerTV Video Capture (PAL/SECAM, Philips FQ1216MK3 tuner)(0x1461-0xC20A)"},
{0x4444, 0x0016, 0x1461, 0xC218, "M755 AVerTV Video Capture (NTSC, Philips FQ1236MK5 tuner)(0x1461-0xC218)"},
{0x4444, 0x0016, 0x1461, 0xC219, "M755 AVerTV Video Capture (NTSC+FM, Philips FQ1236MK5 tuner)(0x1461-0xC219)"},
{0x4444, 0x0016, 0x1461, 0xC21A, "M755 AVerTV Video Capture (PAL/SECAM, Philips FQ1216MK5 tuner)(0x1461-0xC21A)"},
{0x4444, 0x0016, 0x1461, 0xC21B, "M755 AVerTV Video Capture (PAL/SECAM+FM, Philips FM1216MK5 tuner)(0x1461-0xC21B)"},
{0x4444, 0x0016, 0x1461, 0xC230, "M755 AVerTV Video Capture (NTSC-J, Partsnic tuner)(0x1461-0xC230)"},
{0x4444, 0x0016, 0x1461, 0xC231, "M755 AVerTV Video Capture (NTSC-J+FM, Partsnic tuner)(0x1461-0xC231)"},
{0x4444, 0x0016, 0x1461, 0xC232, "M755 AVerTV Video Capture (PAL/SECAM, Partsnic tuner)(0x1461-0xC232)"},
{0x4444, 0x0016, 0x1461, 0xC233, "M755 AVerTV Video Capture (PAL/SECAM+FM, Partsnic tuner)(0x1461-0xC233)"},
{0x4444, 0x0016, 0x1461, 0xC234, "M755 AVerTV Video Capture (NTSC, Partsnic tuner)(0x1461-0xC234)"},
{0x4444, 0x0016, 0x1461, 0xC235, "M755 AVerTV Video Capture (NTSC+FM, Partsnic tuner)(0x1461-0xC235)"},
{0x4444, 0x0016, 0x1461, 0xC337, "E106 AVerMedia AVerTV Video Capture(0x1461-0xC337)"},
{0x4444, 0x0016, 0x1461, 0xC439, "M116 AVerMedia AVerTV MCE 116 Plus (NTSC/PAL/SECAM+FM+REMOTE, Xceive 2028 tuner)(0x1461-0xC439)"},
{0x4444, 0x0016, 0x1461, 0xC5FF, "C755 AVerTV Video Capture card (no tuner)(0x1461-0xC5FF)"},
{0x4444, 0x0016, 0x1461, 0xC6FF, "C115 PCI video capture card (no tuner)(0x1461-0xC6FF)"},
{0x4444, 0x0016, 0x1461, 0xC739, "M785 AVerMedia PCI Analog TV (NTSC/PAL/SECAM+FM, Xceive 2028 tuner)(0x1461-0xC739)"},
{0x4444, 0x0016, 0x9005, 0x0092, "VideOh! AVC-2010(0x9005-0x0092)"},
{0x4444, 0x0016, 0x9005, 0x0093, "VideOh! AVC-2410(0x9005-0x0093)"},
{0x4444, 0x0803, 0xFFFF, 0xFFFF, "iTVC15 (CX23415) Video Decoder(0x0803)"},
{0x4444, 0x0803, 0x0070, 0x4000, "WinTV PVR-350(0x0070-0x4000)"},
{0x4444, 0x0803, 0x0070, 0x4001, "WinTV PVR-250(0x0070-0x4001)"},
{0x4444, 0x0803, 0x0070, 0x4800, "WinTV PVR-350 (V1)(0x0070-0x4800)"},
{0x4444, 0x0803, 0x12AB, 0x0000, "MPG160(0x12AB-0x0000)"},
{0x4444, 0x0803, 0x1461, 0xA3CE, "M179(0x1461-0xA3CE)"},
{0x4444, 0x0803, 0x1461, 0xA3CF, "M179(0x1461-0xA3CF)"},
}; /* pci_vid_4444[] */

static pci_id_t const pci_vid_4468[] = {
{0x4468, 0xFFFF, 0xFFFF, 0xFFFF, "Bridgeport machines(0x4468)"},
}; /* pci_vid_4468[] */

static pci_id_t const pci_vid_4594[] = {
{0x4594, 0xFFFF, 0xFFFF, 0xFFFF, "Cogetec Informatique Inc(0x4594)"},
}; /* pci_vid_4594[] */

static pci_id_t const pci_vid_45FB[] = {
{0x45FB, 0xFFFF, 0xFFFF, 0xFFFF, "Baldor Electric Company(0x45FB)"},
}; /* pci_vid_45FB[] */

static pci_id_t const pci_vid_4624[] = {
{0x4624, 0xFFFF, 0xFFFF, 0xFFFF, "Budker Institute of Nuclear Physics(0x4624)"},
{0x4624, 0xADC1, 0xFFFF, 0xFFFF, "ADC200ME High speed ADC(0xADC1)"},
{0x4624, 0xDE01, 0xFFFF, 0xFFFF, "DL200ME High resolution delay line PCI based card(0xDE01)"},
{0x4624, 0xDE02, 0xFFFF, 0xFFFF, "DL200ME Middle resolution delay line PCI based card(0xDE02)"},
}; /* pci_vid_4624[] */

static pci_id_t const pci_vid_4651[] = {
{0x4651, 0xFFFF, 0xFFFF, 0xFFFF, "TXIC(0x4651)"},
}; /* pci_vid_4651[] */

static pci_id_t const pci_vid_4680[] = {
{0x4680, 0xFFFF, 0xFFFF, 0xFFFF, "Umax Computer Corp(0x4680)"},
}; /* pci_vid_4680[] */

static pci_id_t const pci_vid_4843[] = {
{0x4843, 0xFFFF, 0xFFFF, 0xFFFF, "Hercules Computer Technology Inc(0x4843)"},
}; /* pci_vid_4843[] */

static pci_id_t const pci_vid_4916[] = {
{0x4916, 0xFFFF, 0xFFFF, 0xFFFF, "RedCreek Communications Inc(0x4916)"},
{0x4916, 0x1960, 0xFFFF, 0xFFFF, "RedCreek PCI adapter(0x1960)"},
}; /* pci_vid_4916[] */

static pci_id_t const pci_vid_4943[] = {
{0x4943, 0xFFFF, 0xFFFF, 0xFFFF, "Growth Networks(0x4943)"},
}; /* pci_vid_4943[] */

static pci_id_t const pci_vid_494F[] = {
{0x494F, 0xFFFF, 0xFFFF, 0xFFFF, "ACCES I/O Products, Inc.(0x494F)"},
{0x494F, 0x0508, 0xFFFF, 0xFFFF, "PCI-IDO-16A FET Output Card(0x0508)"},
{0x494F, 0x0518, 0xFFFF, 0xFFFF, "PCI-IDO-32A FET Output Card(0x0518)"},
{0x494F, 0x0520, 0xFFFF, 0xFFFF, "PCI-IDO-48 FET Output Card(0x0520)"},
{0x494F, 0x0521, 0xFFFF, 0xFFFF, "PCI-IDO-48A FET Output Card(0x0521)"},
{0x494F, 0x0703, 0xFFFF, 0xFFFF, "PCIe-RO-4 Electromechanical Relay Output Card(0x0703)"},
{0x494F, 0x07D0, 0xFFFF, 0xFFFF, "PCIe-IDO-24 FET Output Card(0x07D0)"},
{0x494F, 0x0920, 0xFFFF, 0xFFFF, "PCI-IDI-48 Isolated Digital Input Card(0x0920)"},
{0x494F, 0x0BD0, 0xFFFF, 0xFFFF, "PCIe-IDI-24 Isolated Digital Input Card(0x0BD0)"},
{0x494F, 0x0C50, 0xFFFF, 0xFFFF, "PCI-DIO-24H 1x 8255 Digital Input / Output Card(0x0C50)"},
{0x494F, 0x0C51, 0xFFFF, 0xFFFF, "PCI-DIO-24D 1x 8255 Digital Input / Output Card(0x0C51)"},
{0x494F, 0x0C52, 0xFFFF, 0xFFFF, "PCIe-DIO-24 1x 8255 Digital Input / Output Card(0x0C52)"},
{0x494F, 0x0C53, 0xFFFF, 0xFFFF, "PCIe-DIO-24H 8255 Digital Input / Output Card(0x0C53)"},
{0x494F, 0x0C57, 0xFFFF, 0xFFFF, "mPCIe-DIO-24 8255 Digital Input / Output Card(0x0C57)"},
{0x494F, 0x0C60, 0xFFFF, 0xFFFF, "PCI-DIO-48H 8255 Digital Input / Output Card(0x0C60)"},
{0x494F, 0x0C61, 0xFFFF, 0xFFFF, "PCIe-DIO-48 8255 Digital Input / Output Card(0x0C61)"},
{0x494F, 0x0C62, 0xFFFF, 0xFFFF, "P104-DIO-48 8255 Digital Input / Output Card(0x0C62)"},
{0x494F, 0x0C68, 0xFFFF, 0xFFFF, "PCI-DIO-72 8255 Digital Input / Output Card(0x0C68)"},
{0x494F, 0x0C69, 0xFFFF, 0xFFFF, "P104-DIO-96 8255 Digital Input / Output Card(0x0C69)"},
{0x494F, 0x0C70, 0xFFFF, 0xFFFF, "PCI-DIO-96 8255 Digital Input / Output Card(0x0C70)"},
{0x494F, 0x0C78, 0xFFFF, 0xFFFF, "PCI-DIO-120 8255 Digital Input / Output Card(0x0C78)"},
{0x494F, 0x0DC8, 0xFFFF, 0xFFFF, "PCI-IDIO-16 Isolated Digital Input / FET Output Card(0x0DC8)"},
{0x494F, 0x0E50, 0xFFFF, 0xFFFF, "PCI-DIO-24S 8255 Digital Input / Output Card(0x0E50)"},
{0x494F, 0x0E51, 0xFFFF, 0xFFFF, "PCI-DIO-24H(C) 8255 Digital Input / Output Card(0x0E51)"},
{0x494F, 0x0E52, 0xFFFF, 0xFFFF, "PCI-DIO-24D(C) 8255 Digital Input / Output Card(0x0E52)"},
{0x494F, 0x0E53, 0xFFFF, 0xFFFF, "PCIe-DIO-24S 8255 Digital Input / Output Card(0x0E53)"},
{0x494F, 0x0E54, 0xFFFF, 0xFFFF, "PCIe-DIO-24HS 8255 Digital Input / Output Card(0x0E54)"},
{0x494F, 0x0E55, 0xFFFF, 0xFFFF, "PCIe-DIO-24DC 8255 Digital Input / Output Card(0x0E55)"},
{0x494F, 0x0E56, 0xFFFF, 0xFFFF, "PCIe-DIO-24DCS 8255 Digital Input / Output Card(0x0E56)"},
{0x494F, 0x0E57, 0xFFFF, 0xFFFF, "mPCIe-DIO-24S 8255 Digital Input / Output Card(0x0E57)"},
{0x494F, 0x0E60, 0xFFFF, 0xFFFF, "PCI-DIO-48S 2x 8255 Digital Input / Output Card(0x0E60)"},
{0x494F, 0x0E61, 0xFFFF, 0xFFFF, "PCIe-DIO-48S 2x 8255 Digital Input / Output Card(0x0E61)"},
{0x494F, 0x0E62, 0xFFFF, 0xFFFF, "P104-DIO-48S 2x 8255 Digital Input / Output Card(0x0E62)"},
{0x494F, 0x0F00, 0xFFFF, 0xFFFF, "PCI-IIRO-8 Isolated Digital / Relay Output Card(0x0F00)"},
{0x494F, 0x0F01, 0xFFFF, 0xFFFF, "LPCI-IIRO-8 Isolated Digital / Relay Output Card(0x0F01)"},
{0x494F, 0x0F02, 0xFFFF, 0xFFFF, "PCIe-IIRO-8 Isolated Digital / Relay Output Card(0x0F02)"},
{0x494F, 0x0F08, 0xFFFF, 0xFFFF, "PCI-IIRO-16 Isolated Digital / Relay Output Card(0x0F08)"},
{0x494F, 0x0F09, 0xFFFF, 0xFFFF, "PCIe-IIRO-16 Isolated Digital / Relay Output Card(0x0F09)"},
{0x494F, 0x0FC0, 0xFFFF, 0xFFFF, "PCIe-IDIO-12 Isolated Digital Input / FET Output Card(0x0FC0)"},
{0x494F, 0x0FC1, 0xFFFF, 0xFFFF, "PCIe-IDI-12 Isolated Digital Input Card(0x0FC1)"},
{0x494F, 0x0FC2, 0xFFFF, 0xFFFF, "PCIe-IDO-12 FET Output Card(0x0FC2)"},
{0x494F, 0x0FD0, 0xFFFF, 0xFFFF, "PCIe-IDIO-24 Isolated Digital Input / FET Output Card(0x0FD0)"},
{0x494F, 0x1050, 0xFFFF, 0xFFFF, "PCI-422/485-2 2x RS422/RS484 Card(0x1050)"},
{0x494F, 0x1051, 0xFFFF, 0xFFFF, "PCIe-COM-2SRJ 2x RS422/RS484 Card w/RJ45 Connectors(0x1051)"},
{0x494F, 0x1052, 0xFFFF, 0xFFFF, "104I-COM-2S 2x RS422/RS484 PCI/104 Board(0x1052)"},
{0x494F, 0x1053, 0xFFFF, 0xFFFF, "mPCIe-COM-2S 2x RS422/RS484 PCI Express Mini Card(0x1053)"},
{0x494F, 0x1058, 0xFFFF, 0xFFFF, "PCI-COM422/4 4x RS422 Card(0x1058)"},
{0x494F, 0x1059, 0xFFFF, 0xFFFF, "PCI-COM485/4 4x RS485 Card(0x1059)"},
{0x494F, 0x105A, 0xFFFF, 0xFFFF, "PCIe-COM422-4 4x RS422 Card(0x105A)"},
{0x494F, 0x105B, 0xFFFF, 0xFFFF, "PCIe-COM485-4 4x RS485 Card(0x105B)"},
{0x494F, 0x105C, 0xFFFF, 0xFFFF, "PCIe-COM-4SRJ 4x RS422/RS485 Card w/RJ45 Connectors(0x105C)"},
{0x494F, 0x105D, 0xFFFF, 0xFFFF, "104I-COM-4S 4x RS422/RS484 PCI/104 Board(0x105D)"},
{0x494F, 0x105E, 0xFFFF, 0xFFFF, "mPCIe-COM-4S 4x RS422/RS484 PCI Express Mini Card(0x105E)"},
{0x494F, 0x1068, 0xFFFF, 0xFFFF, "PCI-COM422/8 8x RS422 Card(0x1068)"},
{0x494F, 0x1069, 0xFFFF, 0xFFFF, "PCI-COM485/8 8x RS485 Card(0x1069)"},
{0x494F, 0x106A, 0xFFFF, 0xFFFF, "PCIe-COM422-8 8x RS422 Card(0x106A)"},
{0x494F, 0x106B, 0xFFFF, 0xFFFF, "PCIe-COM485-8 8x RS485 Card(0x106B)"},
{0x494F, 0x106C, 0xFFFF, 0xFFFF, "104I-COM-8S 8x RS422/RS485 PCI/104 Board(0x106C)"},
{0x494F, 0x1088, 0xFFFF, 0xFFFF, "PCI-COM232/1 1x RS232 Card(0x1088)"},
{0x494F, 0x1090, 0xFFFF, 0xFFFF, "PCI-COM232/2 2x RS232 Card(0x1090)"},
{0x494F, 0x1091, 0xFFFF, 0xFFFF, "PCIe-COM232-2RJ 2x RS232 Card w/RJ45 Connectors(0x1091)"},
{0x494F, 0x1093, 0xFFFF, 0xFFFF, "mPCIe-COM232-2 2x RS232 PCI Express Mini Card(0x1093)"},
{0x494F, 0x1098, 0xFFFF, 0xFFFF, "PCIe-COM232-4 4x RS232 Card(0x1098)"},
{0x494F, 0x1099, 0xFFFF, 0xFFFF, "PCIe-COM232-4RJ 4x RS232 Card w/RJ45 Connectors(0x1099)"},
{0x494F, 0x109B, 0xFFFF, 0xFFFF, "mPCIe-COM232-4 4x RS232 PCI Express Mini Card(0x109B)"},
{0x494F, 0x10A8, 0xFFFF, 0xFFFF, "P104-COM232-8 8x RS232 PC-104+ Board(0x10A8)"},
{0x494F, 0x10A9, 0xFFFF, 0xFFFF, "PCIe-COM232-8 8x RS232 Card(0x10A9)"},
{0x494F, 0x10C9, 0xFFFF, 0xFFFF, "PCI-COM-1S 1x RS422/RS485 Card(0x10C9)"},
{0x494F, 0x10D0, 0xFFFF, 0xFFFF, "PCI-COM2S 2x RS422/RS485 Card(0x10D0)"},
{0x494F, 0x10D1, 0xFFFF, 0xFFFF, "PCIe-COM-2SMRJ 2x RS232/RS422/RS485 Card w/RJ45 Connectors(0x10D1)"},
{0x494F, 0x10D2, 0xFFFF, 0xFFFF, "104I-COM-2SM 2x RS232/RS422/RS485 PCI/104 Board(0x10D2)"},
{0x494F, 0x10D3, 0xFFFF, 0xFFFF, "mPCIe-COM-2SM 2x RS232/RS422/RS485 PCI Express Mini Card(0x10D3)"},
{0x494F, 0x10D8, 0xFFFF, 0xFFFF, "PCI-COM-4SM 4x RS232/RS422/RS485 Card(0x10D8)"},
{0x494F, 0x10D9, 0xFFFF, 0xFFFF, "PCIe-COM-4SM 4x RS232/RS422/RS485 Card(0x10D9)"},
{0x494F, 0x10DA, 0xFFFF, 0xFFFF, "PCIe-COM-4SMRJ 4x RS232/RS422/RS485 Card w/RJ45 Connectors(0x10DA)"},
{0x494F, 0x10DB, 0xFFFF, 0xFFFF, "104I-COM-4SM 4x RS232/RS422/RS485 PCI/104 Board(0x10DB)"},
{0x494F, 0x10DC, 0xFFFF, 0xFFFF, "mPCIe-COM-4SM 4x RS232/RS422/RS485 PCI Express Mini Card(0x10DC)"},
{0x494F, 0x10E8, 0xFFFF, 0xFFFF, "PCI-COM-8SM 8x RS232/RS422/RS485 Card(0x10E8)"},
{0x494F, 0x10E9, 0xFFFF, 0xFFFF, "PCIe-COM-8SM 8x RS232/RS422/RS485 Card(0x10E9)"},
{0x494F, 0x10EA, 0xFFFF, 0xFFFF, "104I-COM-8SM 8x RS232/RS422/RS485 PCI-104 Board(0x10EA)"},
{0x494F, 0x1108, 0xFFFF, 0xFFFF, "mPCIe-ICM485-1 1x Isolated RS485 PCI Express Mini Card(0x1108)"},
{0x494F, 0x1110, 0xFFFF, 0xFFFF, "mPCIe-ICM422-2 2x Isolated RS422 PCI Express Mini Card(0x1110)"},
{0x494F, 0x1111, 0xFFFF, 0xFFFF, "mPCIe-ICM485-2 2x Isolated RS485 PCI Express Mini Card(0x1111)"},
{0x494F, 0x1118, 0xFFFF, 0xFFFF, "mPCIe-ICM422-4 4x Isolated RS422 PCI Express Mini Card(0x1118)"},
{0x494F, 0x1119, 0xFFFF, 0xFFFF, "mPCIe-ICM485-4 4x Isolated RS485 PCI Express Mini Card(0x1119)"},
{0x494F, 0x1148, 0xFFFF, 0xFFFF, "PCI-ICM-1S 1x Isolated RS422/RS485 Card(0x1148)"},
{0x494F, 0x1150, 0xFFFF, 0xFFFF, "PCI-ICM-2S 2x Isolated RS422/RS485 Card(0x1150)"},
{0x494F, 0x1152, 0xFFFF, 0xFFFF, "PCIe-ICM-2S 2x Isolated RS422/RS485 Card(0x1152)"},
{0x494F, 0x1158, 0xFFFF, 0xFFFF, "PCI-ICM422/4 4x Isolated RS422 Card(0x1158)"},
{0x494F, 0x1159, 0xFFFF, 0xFFFF, "PCI-ICM485/4 4x Isolated RS485 Card(0x1159)"},
{0x494F, 0x115A, 0xFFFF, 0xFFFF, "PCIe-ICM-4S 4x Isolated RS422/RS485 Card(0x115A)"},
{0x494F, 0x1190, 0xFFFF, 0xFFFF, "PCIe-ICM232-2 2x Isolated RS232 Card(0x1190)"},
{0x494F, 0x1191, 0xFFFF, 0xFFFF, "mPCIe-ICM232-2 2x Isolated RS232 PCI Express Mini Card(0x1191)"},
{0x494F, 0x1198, 0xFFFF, 0xFFFF, "PCIe-ICM232-4 4x Isolated RS232 Card(0x1198)"},
{0x494F, 0x1199, 0xFFFF, 0xFFFF, "mPCIe-ICM232-4 4x Isolated RS422 PCI Express Mini Card(0x1199)"},
{0x494F, 0x11D0, 0xFFFF, 0xFFFF, "PCIe-ICM-2SM 2x Isolated RS232/RS422/RS485 Card(0x11D0)"},
{0x494F, 0x11D8, 0xFFFF, 0xFFFF, "PCIe-ICM-4SM 4x Isolated RS232/RS422/RS485 Card(0x11D8)"},
{0x494F, 0x1250, 0xFFFF, 0xFFFF, "PCI-WDG-2S Watchdog and 2x Serial Card(0x1250)"},
{0x494F, 0x12D0, 0xFFFF, 0xFFFF, "PCI-WDG-IMPAC(0x12D0)"},
{0x494F, 0x2230, 0xFFFF, 0xFFFF, "PCI-QUAD-8 8x Quadrature Input Card(0x2230)"},
{0x494F, 0x2231, 0xFFFF, 0xFFFF, "PCI-QUAD-4 4x Quadrature Input Card(0x2231)"},
{0x494F, 0x22C0, 0xFFFF, 0xFFFF, "PCI-WDG-CSM Watchdog Card(0x22C0)"},
{0x494F, 0x25C0, 0xFFFF, 0xFFFF, "P104-WDG-E Watchdog PC/104+ Board(0x25C0)"},
{0x494F, 0x2C50, 0xFFFF, 0xFFFF, "PCI-DIO-96CT 96x Digital Input / Output Card(0x2C50)"},
{0x494F, 0x2C58, 0xFFFF, 0xFFFF, "PCI-DIO-96C3 96x Digital Input / Output Card w/3x 8254 Counter Card(0x2C58)"},
{0x494F, 0x2EE0, 0xFFFF, 0xFFFF, "PCIe-DIO24S-CTR12 24x Digital Input / Output Card w/4x 8254 Counter Card(0x2EE0)"},
{0x494F, 0x2FC0, 0xFFFF, 0xFFFF, "P104-WDG-CSM Watchdog PC/104+ Board(0x2FC0)"},
{0x494F, 0x2FC1, 0xFFFF, 0xFFFF, "P104-WDG-CSMA Advanced Watchdog PC/104+ Board(0x2FC1)"},
{0x494F, 0x5ED0, 0xFFFF, 0xFFFF, "PCI-DAC(0x5ED0)"},
{0x494F, 0x6C90, 0xFFFF, 0xFFFF, "PCI-DA12-2 2x 12-bit Analog Output Card(0x6C90)"},
{0x494F, 0x6C98, 0xFFFF, 0xFFFF, "PCI-DA12-4 4x 12-bit Analog Output Card(0x6C98)"},
{0x494F, 0x6CA0, 0xFFFF, 0xFFFF, "PCI-DA12-6 6x 12-bit Analog Output Card(0x6CA0)"},
{0x494F, 0x6CA8, 0xFFFF, 0xFFFF, "PCI-DA12-8 8x 12-bit Analog Output Card(0x6CA8)"},
{0x494F, 0x6CA9, 0xFFFF, 0xFFFF, "PCI-DA12-8V(0x6CA9)"},
{0x494F, 0x6CB0, 0xFFFF, 0xFFFF, "PCI-DA12-16 16x 12-bit Analog Output Card(0x6CB0)"},
{0x494F, 0x6CB1, 0xFFFF, 0xFFFF, "PCI-DA12-16V(0x6CB1)"},
{0x494F, 0x8EF0, 0xFFFF, 0xFFFF, "P104-FAS16-16(0x8EF0)"},
{0x494F, 0xACA8, 0xFFFF, 0xFFFF, "PCI-AI12-16 12-bit 100kHz Analog Input Card(0xACA8)"},
{0x494F, 0xACA9, 0xFFFF, 0xFFFF, "PCI-AI12-16A 12-bit 100kHz Analog Input w/FIFO Card(0xACA9)"},
{0x494F, 0xECA8, 0xFFFF, 0xFFFF, "PCI-AIO12-16 12-bit 100kHz Analog Input w/2x Analog Output and FIFO Card(0xECA8)"},
{0x494F, 0xECAA, 0xFFFF, 0xFFFF, "PCI-A12-16A 12-bit 100kHz Analog Input w/2x Analog Output and FIFO Card(0xECAA)"},
{0x494F, 0xECE8, 0xFFFF, 0xFFFF, "LPCI-A16-16A 16-bit 500kHz Analog Input low-profile Card(0xECE8)"},
{0x494F, 0xECE9, 0xFFFF, 0xFFFF, "LPCI-AIO16A 16-bit 500kHz Analog Input low-profile Card(0xECE9)"},
}; /* pci_vid_494F[] */

static pci_id_t const pci_vid_4978[] = {
{0x4978, 0xFFFF, 0xFFFF, 0xFFFF, "Axil Computer Inc(0x4978)"},
}; /* pci_vid_4978[] */

static pci_id_t const pci_vid_4A14[] = {
{0x4A14, 0xFFFF, 0xFFFF, 0xFFFF, "NetVin(0x4A14)"},
{0x4A14, 0x5000, 0xFFFF, 0xFFFF, "NV5000SC(0x5000)"},
{0x4A14, 0x5000, 0x4A14, 0x5000, "RT8029-Based Ethernet Adapter(0x4A14-0x5000)"},
}; /* pci_vid_4A14[] */

static pci_id_t const pci_vid_4B10[] = {
{0x4B10, 0xFFFF, 0xFFFF, 0xFFFF, "Buslogic Inc.(0x4B10)"},
}; /* pci_vid_4B10[] */

static pci_id_t const pci_vid_4B43[] = {
{0x4B43, 0xFFFF, 0xFFFF, 0xFFFF, "KonteX Inc.(0x4B43)"},
}; /* pci_vid_4B43[] */

static pci_id_t const pci_vid_4C48[] = {
{0x4C48, 0xFFFF, 0xFFFF, 0xFFFF, "LUNG HWA Electronics(0x4C48)"},
}; /* pci_vid_4C48[] */

static pci_id_t const pci_vid_4C4D[] = {
{0x4C4D, 0xFFFF, 0xFFFF, 0xFFFF, "Liquid-Markets GmbH(0x4C4D)"},
{0x4C4D, 0x9998, 0xFFFF, 0xFFFF, "TaSR(0x9998)"},
{0x4C4D, 0x9999, 0xFFFF, 0xFFFF, "UberNIC PoC/testing/dev(0x9999)"},
}; /* pci_vid_4C4D[] */

static pci_id_t const pci_vid_4C52[] = {
{0x4C52, 0xFFFF, 0xFFFF, 0xFFFF, "LR-LINK(0x4C52)"},
{0x4C52, 0x1001, 0xFFFF, 0xFFFF, "Smart Network Adapter(0x1001)"},
{0x4C52, 0x1001, 0x4C52, 0xA008, "LREG1008PT Single-port 1Gb Smart Ethernet Network Adapter(0x4C52-0xA008)"},
{0x4C52, 0x1002, 0xFFFF, 0xFFFF, "Smart Network Adapter(0x1002)"},
{0x4C52, 0x1002, 0x4C52, 0xA006, "LREG1006PT Single-port 1.2Gb Network Security Isolation Adapter(0x4C52-0xA006)"},
{0x4C52, 0x1003, 0xFFFF, 0xFFFF, "Smart Network Adapter(0x1003)"},
{0x4C52, 0x1004, 0xFFFF, 0xFFFF, "Smart Network Adapter(0x1004)"},
{0x4C52, 0x1004, 0x4C52, 0xB010, "LREG1010PF Single-port 10Gb FPGA Network Security Isolation Adapter(0x4C52-0xB010)"},
{0x4C52, 0x1004, 0x4C52, 0xB011, "LREG1011PF Dual-port 10Gb FPGA Network Security Isolation Adapter(0x4C52-0xB011)"},
}; /* pci_vid_4C52[] */

static pci_id_t const pci_vid_4C53[] = {
{0x4C53, 0xFFFF, 0xFFFF, 0xFFFF, "SBS Technologies(0x4C53)"},
{0x4C53, 0x0000, 0xFFFF, 0xFFFF, "PLUSTEST device(0x0000)"},
{0x4C53, 0x0000, 0x4C53, 0x3000, "PLUSTEST card (PC104+)(0x4C53-0x3000)"},
{0x4C53, 0x0000, 0x4C53, 0x3001, "PLUSTEST card (PMC)(0x4C53-0x3001)"},
{0x4C53, 0x0001, 0xFFFF, 0xFFFF, "PLUSTEST-MM device(0x0001)"},
{0x4C53, 0x0001, 0x4C53, 0x3002, "PLUSTEST-MM card (PMC)(0x4C53-0x3002)"},
}; /* pci_vid_4C53[] */

static pci_id_t const pci_vid_4CA1[] = {
{0x4CA1, 0xFFFF, 0xFFFF, 0xFFFF, "Seanix Technology Inc(0x4CA1)"},
}; /* pci_vid_4CA1[] */

static pci_id_t const pci_vid_4D51[] = {
{0x4D51, 0xFFFF, 0xFFFF, 0xFFFF, "MediaQ Inc.(0x4D51)"},
{0x4D51, 0x0200, 0xFFFF, 0xFFFF, "MQ-200(0x0200)"},
}; /* pci_vid_4D51[] */

static pci_id_t const pci_vid_4D54[] = {
{0x4D54, 0xFFFF, 0xFFFF, 0xFFFF, "Microtechnica Co Ltd(0x4D54)"},
}; /* pci_vid_4D54[] */

static pci_id_t const pci_vid_4D56[] = {
{0x4D56, 0xFFFF, 0xFFFF, 0xFFFF, "Balluff MV GmbH(0x4D56)"},
{0x4D56, 0x0000, 0xFFFF, 0xFFFF, "[mvHYPERION-CLe/CLb] CameraLink PCI Express x1 Frame Grabber(0x0000)"},
{0x4D56, 0x0001, 0xFFFF, 0xFFFF, "[mvHYPERION-CLf/CLm] CameraLink PCI Express x4 Frame Grabber(0x0001)"},
{0x4D56, 0x0010, 0xFFFF, 0xFFFF, "[mvHYPERION-16R16/-32R16] 16 Video Channel PCI Express x4 Frame Grabber(0x0010)"},
{0x4D56, 0x0020, 0xFFFF, 0xFFFF, "[mvHYPERION-HD-SDI] HD-SDI PCI Express x4 Frame Grabber(0x0020)"},
{0x4D56, 0x0030, 0xFFFF, 0xFFFF, "[mvHYPERION-HD-SDI-Merger] HD-SDI PCI Express x4 Frame Grabber(0x0030)"},
{0x4D56, 0x7012, 0xFFFF, 0xFFFF, "[mvBlueNAOS BVS CA-BN] PCIe Gen1 x2 Camera(0x7012)"},
{0x4D56, 0x7014, 0xFFFF, 0xFFFF, "[mvBlueNAOS BVS CA-BN] PCIe Gen1 x4 Camera(0x7014)"},
{0x4D56, 0x7022, 0xFFFF, 0xFFFF, "[mvBlueNAOS BVS CA-BN] PCIe Gen2 x2 Camera(0x7022)"},
{0x4D56, 0x7024, 0xFFFF, 0xFFFF, "[mvBlueNAOS BVS CA-BN] PCIe Gen2 x4 Camera(0x7024)"},
}; /* pci_vid_4D56[] */

static pci_id_t const pci_vid_4DDC[] = {
{0x4DDC, 0xFFFF, 0xFFFF, 0xFFFF, "ILC Data Device Corp(0x4DDC)"},
{0x4DDC, 0x0100, 0xFFFF, 0xFFFF, "DD-42924I5-300 (ARINC 429 Data Bus)(0x0100)"},
{0x4DDC, 0x0300, 0xFFFF, 0xFFFF, "SB-3620 Motion Feedback Device(0x0300)"},
{0x4DDC, 0x0340, 0xFFFF, 0xFFFF, "SB-3623 Motion Feedback Device(0x0340)"},
{0x4DDC, 0x0400, 0xFFFF, 0xFFFF, "SB-3622 Motion Feedback Device(0x0400)"},
{0x4DDC, 0x0500, 0xFFFF, 0xFFFF, "SB-3621 Motion Feedback Device(0x0500)"},
{0x4DDC, 0x0510, 0xFFFF, 0xFFFF, "SB-3624 Motion Feedback Device(0x0510)"},
{0x4DDC, 0x0801, 0xFFFF, 0xFFFF, "BU-65570I1 MIL-STD-1553 Test and Simulation(0x0801)"},
{0x4DDC, 0x0802, 0xFFFF, 0xFFFF, "BU-65570I2 MIL-STD-1553 Test and Simulation(0x0802)"},
{0x4DDC, 0x0811, 0xFFFF, 0xFFFF, "BU-65572I1 MIL-STD-1553 Test and Simulation(0x0811)"},
{0x4DDC, 0x0812, 0xFFFF, 0xFFFF, "BU-65572I2 MIL-STD-1553 Test and Simulation(0x0812)"},
{0x4DDC, 0x0881, 0xFFFF, 0xFFFF, "BU-65570T1 MIL-STD-1553 Test and Simulation(0x0881)"},
{0x4DDC, 0x0882, 0xFFFF, 0xFFFF, "BU-65570T2 MIL-STD-1553 Test and Simulation(0x0882)"},
{0x4DDC, 0x0891, 0xFFFF, 0xFFFF, "BU-65572T1 MIL-STD-1553 Test and Simulation(0x0891)"},
{0x4DDC, 0x0892, 0xFFFF, 0xFFFF, "BU-65572T2 MIL-STD-1553 Test and Simulation(0x0892)"},
{0x4DDC, 0x0901, 0xFFFF, 0xFFFF, "BU-65565C1 MIL-STD-1553 Data Bus(0x0901)"},
{0x4DDC, 0x0902, 0xFFFF, 0xFFFF, "BU-65565C2 MIL-STD-1553 Data Bus(0x0902)"},
{0x4DDC, 0x0903, 0xFFFF, 0xFFFF, "BU-65565C3 MIL-STD-1553 Data Bus(0x0903)"},
{0x4DDC, 0x0904, 0xFFFF, 0xFFFF, "BU-65565C4 MIL-STD-1553 Data Bus(0x0904)"},
{0x4DDC, 0x0B01, 0xFFFF, 0xFFFF, "BU-65569I1 MIL-STD-1553 Data Bus(0x0B01)"},
{0x4DDC, 0x0B02, 0xFFFF, 0xFFFF, "BU-65569I2 MIL-STD-1553 Data Bus(0x0B02)"},
{0x4DDC, 0x0B03, 0xFFFF, 0xFFFF, "BU-65569I3 MIL-STD-1553 Data Bus(0x0B03)"},
{0x4DDC, 0x0B04, 0xFFFF, 0xFFFF, "BU-65569I4 MIL-STD-1553 Data Bus(0x0B04)"},
{0x4DDC, 0x0D01, 0xFFFF, 0xFFFF, "SB-3641 Motion Feedback Device(0x0D01)"},
{0x4DDC, 0x0D10, 0xFFFF, 0xFFFF, "SB-365x Motion Feedback Device(0x0D10)"},
{0x4DDC, 0x2F00, 0xFFFF, 0xFFFF, "SB-3642 Motion Feedback Device(0x2F00)"},
{0x4DDC, 0x3000, 0xFFFF, 0xFFFF, "SB-3644 Motion Feedback Device(0x3000)"},
}; /* pci_vid_4DDC[] */

static pci_id_t const pci_vid_4E4C[] = {
{0x4E4C, 0xFFFF, 0xFFFF, 0xFFFF, "NieL TechSolution(0x4E4C)"},
}; /* pci_vid_4E4C[] */

static pci_id_t const pci_vid_4E58[] = {
{0x4E58, 0xFFFF, 0xFFFF, 0xFFFF, "Nutanix, Inc.(0x4E58)"},
{0x4E58, 0x0001, 0xFFFF, 0xFFFF, "Virtual NVMe Controller(0x0001)"},
}; /* pci_vid_4E58[] */

static pci_id_t const pci_vid_5045[] = {
{0x5045, 0xFFFF, 0xFFFF, 0xFFFF, "University of Toronto(0x5045)"},
{0x5045, 0x4243, 0xFFFF, 0xFFFF, "BLASTbus PCI Interface Card v1(0x4243)"},
}; /* pci_vid_5045[] */

static pci_id_t const pci_vid_5046[] = {
{0x5046, 0xFFFF, 0xFFFF, 0xFFFF, "GemTek Technology Corporation(0x5046)"},
{0x5046, 0x1001, 0xFFFF, 0xFFFF, "PCI Radio(0x1001)"},
}; /* pci_vid_5046[] */

static pci_id_t const pci_vid_5053[] = {
{0x5053, 0xFFFF, 0xFFFF, 0xFFFF, "Voyetra Technologies(0x5053)"},
{0x5053, 0x2010, 0xFFFF, 0xFFFF, "Daytona Audio Adapter(0x2010)"},
}; /* pci_vid_5053[] */

static pci_id_t const pci_vid_50B2[] = {
{0x50B2, 0xFFFF, 0xFFFF, 0xFFFF, "TerraTec Electronic GmbH(0x50B2)"},
}; /* pci_vid_50B2[] */

static pci_id_t const pci_vid_50CE[] = {
{0x50CE, 0xFFFF, 0xFFFF, 0xFFFF, "System-on-Chip Engineering S.L.(0x50CE)"},
{0x50CE, 0x0001, 0xFFFF, 0xFFFF, "RELY-MIL-XMC-TSN-SWITCH(0x0001)"},
{0x50CE, 0x0100, 0xFFFF, 0xFFFF, "XMC_AV-Dual-ETH(0x0100)"},
{0x50CE, 0x0101, 0xFFFF, 0xFFFF, "XMC_AV-ETSN(0x0101)"},
{0x50CE, 0x0102, 0xFFFF, 0xFFFF, "XMC_AV-AFDX(0x0102)"},
}; /* pci_vid_50CE[] */

static pci_id_t const pci_vid_5136[] = {
{0x5136, 0xFFFF, 0xFFFF, 0xFFFF, "S S Technologies(0x5136)"},
}; /* pci_vid_5136[] */

static pci_id_t const pci_vid_5143[] = {
{0x5143, 0xFFFF, 0xFFFF, 0xFFFF, "Qualcomm Inc(0x5143)"},
}; /* pci_vid_5143[] */

static pci_id_t const pci_vid_5145[] = {
{0x5145, 0xFFFF, 0xFFFF, 0xFFFF, "Ensoniq (Old)(0x5145)"},
{0x5145, 0x3031, 0xFFFF, 0xFFFF, "Concert AudioPCI(0x3031)"},
}; /* pci_vid_5145[] */

static pci_id_t const pci_vid_5168[] = {
{0x5168, 0xFFFF, 0xFFFF, 0xFFFF, "Animation Technologies Inc.(0x5168)"},
{0x5168, 0x0300, 0xFFFF, 0xFFFF, "FlyDVB-S(0x0300)"},
{0x5168, 0x0301, 0xFFFF, 0xFFFF, "FlyDVB-T(0x0301)"},
}; /* pci_vid_5168[] */

static pci_id_t const pci_vid_5301[] = {
{0x5301, 0xFFFF, 0xFFFF, 0xFFFF, "Alliance Semiconductor Corp.(0x5301)"},
{0x5301, 0x0001, 0xFFFF, 0xFFFF, "ProMotion aT3D(0x0001)"},
}; /* pci_vid_5301[] */

static pci_id_t const pci_vid_5333[] = {
{0x5333, 0xFFFF, 0xFFFF, 0xFFFF, "S3 Graphics Ltd.(0x5333)"},
{0x5333, 0x0551, 0xFFFF, 0xFFFF, "Plato/PX (system)(0x0551)"},
{0x5333, 0x5631, 0xFFFF, 0xFFFF, "86c325 [ViRGE](0x5631)"},
{0x5333, 0x8800, 0xFFFF, 0xFFFF, "86c866 [Vision 866](0x8800)"},
{0x5333, 0x8801, 0xFFFF, 0xFFFF, "86c964 [Vision 964](0x8801)"},
{0x5333, 0x8810, 0xFFFF, 0xFFFF, "86c764_0 [Trio 32 vers 0](0x8810)"},
{0x5333, 0x8811, 0xFFFF, 0xFFFF, "86c764/765 [Trio32/64/64V+](0x8811)"},
{0x5333, 0x8812, 0xFFFF, 0xFFFF, "86cM65 [Aurora64V+](0x8812)"},
{0x5333, 0x8813, 0xFFFF, 0xFFFF, "86c764_3 [Trio 32/64 vers 3](0x8813)"},
{0x5333, 0x8814, 0xFFFF, 0xFFFF, "86c767 [Trio 64UV+](0x8814)"},
{0x5333, 0x8815, 0xFFFF, 0xFFFF, "86cM65 [Aurora 128](0x8815)"},
{0x5333, 0x883D, 0xFFFF, 0xFFFF, "86c988 [ViRGE/VX](0x883D)"},
{0x5333, 0x8870, 0xFFFF, 0xFFFF, "FireGL(0x8870)"},
{0x5333, 0x8880, 0xFFFF, 0xFFFF, "86c868 [Vision 868 VRAM] vers 0(0x8880)"},
{0x5333, 0x8881, 0xFFFF, 0xFFFF, "86c868 [Vision 868 VRAM] vers 1(0x8881)"},
{0x5333, 0x8882, 0xFFFF, 0xFFFF, "86c868 [Vision 868 VRAM] vers 2(0x8882)"},
{0x5333, 0x8883, 0xFFFF, 0xFFFF, "86c868 [Vision 868 VRAM] vers 3(0x8883)"},
{0x5333, 0x88B0, 0xFFFF, 0xFFFF, "86c928 [Vision 928 VRAM] vers 0(0x88B0)"},
{0x5333, 0x88B1, 0xFFFF, 0xFFFF, "86c928 [Vision 928 VRAM] vers 1(0x88B1)"},
{0x5333, 0x88B2, 0xFFFF, 0xFFFF, "86c928 [Vision 928 VRAM] vers 2(0x88B2)"},
{0x5333, 0x88B3, 0xFFFF, 0xFFFF, "86c928 [Vision 928 VRAM] vers 3(0x88B3)"},
{0x5333, 0x88C0, 0xFFFF, 0xFFFF, "86c864 [Vision 864 DRAM] vers 0(0x88C0)"},
{0x5333, 0x88C1, 0xFFFF, 0xFFFF, "86c864 [Vision 864 DRAM] vers 1(0x88C1)"},
{0x5333, 0x88C2, 0xFFFF, 0xFFFF, "86c864 [Vision 864-P DRAM] vers 2(0x88C2)"},
{0x5333, 0x88C3, 0xFFFF, 0xFFFF, "86c864 [Vision 864-P DRAM] vers 3(0x88C3)"},
{0x5333, 0x88D0, 0xFFFF, 0xFFFF, "86c964 [Vision 964 VRAM] vers 0(0x88D0)"},
{0x5333, 0x88D1, 0xFFFF, 0xFFFF, "86c964 [Vision 964 VRAM] vers 1(0x88D1)"},
{0x5333, 0x88D2, 0xFFFF, 0xFFFF, "86c964 [Vision 964-P VRAM] vers 2(0x88D2)"},
{0x5333, 0x88D3, 0xFFFF, 0xFFFF, "86c964 [Vision 964-P VRAM] vers 3(0x88D3)"},
{0x5333, 0x88F0, 0xFFFF, 0xFFFF, "86c968 [Vision 968 VRAM] rev 0(0x88F0)"},
{0x5333, 0x88F1, 0xFFFF, 0xFFFF, "86c968 [Vision 968 VRAM] rev 1(0x88F1)"},
{0x5333, 0x88F2, 0xFFFF, 0xFFFF, "86c968 [Vision 968 VRAM] rev 2(0x88F2)"},
{0x5333, 0x88F3, 0xFFFF, 0xFFFF, "86c968 [Vision 968 VRAM] rev 3(0x88F3)"},
{0x5333, 0x8900, 0xFFFF, 0xFFFF, "86c755 [Trio 64V2/DX](0x8900)"},
{0x5333, 0x8900, 0x5333, 0x8900, "86C775 Trio64V2/DX(0x5333-0x8900)"},
{0x5333, 0x8901, 0xFFFF, 0xFFFF, "86c775/86c785 [Trio 64V2/DX or /GX](0x8901)"},
{0x5333, 0x8901, 0x5333, 0x8901, "86C775 Trio64V2/DX, 86C785 Trio64V2/GX(0x5333-0x8901)"},
{0x5333, 0x8902, 0xFFFF, 0xFFFF, "Plato/PX(0x8902)"},
{0x5333, 0x8903, 0xFFFF, 0xFFFF, "Trio 3D business multimedia(0x8903)"},
{0x5333, 0x8904, 0xFFFF, 0xFFFF, "86c365, 86c366 [Trio 3D](0x8904)"},
{0x5333, 0x8904, 0x1014, 0x00DB, "Integrated Trio3D(0x1014-0x00DB)"},
{0x5333, 0x8904, 0x4843, 0x314A, "Terminator 128/3D GLH(0x4843-0x314A)"},
{0x5333, 0x8904, 0x5333, 0x8904, "86C365 Trio3D AGP(0x5333-0x8904)"},
{0x5333, 0x8905, 0xFFFF, 0xFFFF, "Trio 64V+ family(0x8905)"},
{0x5333, 0x8906, 0xFFFF, 0xFFFF, "Trio 64V+ family(0x8906)"},
{0x5333, 0x8907, 0xFFFF, 0xFFFF, "Trio 64V+ family(0x8907)"},
{0x5333, 0x8908, 0xFFFF, 0xFFFF, "Trio 64V+ family(0x8908)"},
{0x5333, 0x8909, 0xFFFF, 0xFFFF, "Trio 64V+ family(0x8909)"},
{0x5333, 0x890A, 0xFFFF, 0xFFFF, "Trio 64V+ family(0x890A)"},
{0x5333, 0x890B, 0xFFFF, 0xFFFF, "Trio 64V+ family(0x890B)"},
{0x5333, 0x890C, 0xFFFF, 0xFFFF, "Trio 64V+ family(0x890C)"},
{0x5333, 0x890D, 0xFFFF, 0xFFFF, "Trio 64V+ family(0x890D)"},
{0x5333, 0x890E, 0xFFFF, 0xFFFF, "Trio 64V+ family(0x890E)"},
{0x5333, 0x890F, 0xFFFF, 0xFFFF, "Trio 64V+ family(0x890F)"},
{0x5333, 0x8A01, 0xFFFF, 0xFFFF, "86c375 [ViRGE/DX] or 86c385 [ViRGE/GX](0x8A01)"},
{0x5333, 0x8A01, 0x0E11, 0xB032, "ViRGE/GX(0x0E11-0xB032)"},
{0x5333, 0x8A01, 0x10B4, 0x1617, "Nitro 3D(0x10B4-0x1617)"},
{0x5333, 0x8A01, 0x10B4, 0x1717, "Nitro 3D(0x10B4-0x1717)"},
{0x5333, 0x8A01, 0x5333, 0x8A01, "ViRGE/DX(0x5333-0x8A01)"},
{0x5333, 0x8A10, 0xFFFF, 0xFFFF, "ViRGE/GX2(0x8A10)"},
{0x5333, 0x8A10, 0x1092, 0x8A10, "Stealth 3D 4000(0x1092-0x8A10)"},
{0x5333, 0x8A13, 0xFFFF, 0xFFFF, "86c360 [Trio 3D/1X], 86c362, 86c368 [Trio 3D/2X](0x8A13)"},
{0x5333, 0x8A13, 0x5333, 0x8A13, "Trio3D/2X(0x5333-0x8A13)"},
{0x5333, 0x8A20, 0xFFFF, 0xFFFF, "86c794 [Savage 3D](0x8A20)"},
{0x5333, 0x8A20, 0x5333, 0x8A20, "86C391 Savage3D(0x5333-0x8A20)"},
{0x5333, 0x8A21, 0xFFFF, 0xFFFF, "86c390 [Savage 3D/MV](0x8A21)"},
{0x5333, 0x8A21, 0x5333, 0x8A21, "86C390 Savage3D/MV(0x5333-0x8A21)"},
{0x5333, 0x8A22, 0xFFFF, 0xFFFF, "Savage 4(0x8A22)"},
{0x5333, 0x8A22, 0x1033, 0x8068, "Savage 4(0x1033-0x8068)"},
{0x5333, 0x8A22, 0x1033, 0x8069, "Savage 4(0x1033-0x8069)"},
{0x5333, 0x8A22, 0x1033, 0x8110, "Savage 4 LT(0x1033-0x8110)"},
{0x5333, 0x8A22, 0x105D, 0x0018, "SR9 8Mb SDRAM(0x105D-0x0018)"},
{0x5333, 0x8A22, 0x105D, 0x002A, "SR9 Pro 16Mb SDRAM(0x105D-0x002A)"},
{0x5333, 0x8A22, 0x105D, 0x003A, "SR9 Pro 32Mb SDRAM(0x105D-0x003A)"},
{0x5333, 0x8A22, 0x105D, 0x092F, "SR9 Pro+ 16Mb SGRAM(0x105D-0x092F)"},
{0x5333, 0x8A22, 0x1092, 0x4207, "Stealth III S540(0x1092-0x4207)"},
{0x5333, 0x8A22, 0x1092, 0x4800, "Stealth III S540(0x1092-0x4800)"},
{0x5333, 0x8A22, 0x1092, 0x4807, "SpeedStar A90(0x1092-0x4807)"},
{0x5333, 0x8A22, 0x1092, 0x4808, "Stealth III S540(0x1092-0x4808)"},
{0x5333, 0x8A22, 0x1092, 0x4809, "Stealth III S540(0x1092-0x4809)"},
{0x5333, 0x8A22, 0x1092, 0x480E, "Stealth III S540(0x1092-0x480E)"},
{0x5333, 0x8A22, 0x1092, 0x4904, "Stealth III S520(0x1092-0x4904)"},
{0x5333, 0x8A22, 0x1092, 0x4905, "SpeedStar A200(0x1092-0x4905)"},
{0x5333, 0x8A22, 0x1092, 0x4A09, "Stealth III S540(0x1092-0x4A09)"},
{0x5333, 0x8A22, 0x1092, 0x4A0B, "Stealth III S540 Xtreme(0x1092-0x4A0B)"},
{0x5333, 0x8A22, 0x1092, 0x4A0F, "Stealth III S540(0x1092-0x4A0F)"},
{0x5333, 0x8A22, 0x1092, 0x4E01, "Stealth III S540(0x1092-0x4E01)"},
{0x5333, 0x8A22, 0x1102, 0x101D, "3d Blaster Savage 4(0x1102-0x101D)"},
{0x5333, 0x8A22, 0x1102, 0x101E, "3d Blaster Savage 4(0x1102-0x101E)"},
{0x5333, 0x8A22, 0x5333, 0x8100, "86C394-397 Savage4 SDRAM 100(0x5333-0x8100)"},
{0x5333, 0x8A22, 0x5333, 0x8110, "86C394-397 Savage4 SDRAM 110(0x5333-0x8110)"},
{0x5333, 0x8A22, 0x5333, 0x8125, "86C394-397 Savage4 SDRAM 125(0x5333-0x8125)"},
{0x5333, 0x8A22, 0x5333, 0x8143, "86C394-397 Savage4 SDRAM 143(0x5333-0x8143)"},
{0x5333, 0x8A22, 0x5333, 0x8A22, "86C394-397 Savage4(0x5333-0x8A22)"},
{0x5333, 0x8A22, 0x5333, 0x8A2E, "86C394-397 Savage4 32bit(0x5333-0x8A2E)"},
{0x5333, 0x8A22, 0x5333, 0x9125, "86C394-397 Savage4 SGRAM 125(0x5333-0x9125)"},
{0x5333, 0x8A22, 0x5333, 0x9143, "86C394-397 Savage4 SGRAM 143(0x5333-0x9143)"},
{0x5333, 0x8A23, 0xFFFF, 0xFFFF, "Savage 4(0x8A23)"},
{0x5333, 0x8A25, 0xFFFF, 0xFFFF, "ProSavage PM133(0x8A25)"},
{0x5333, 0x8A25, 0x0303, 0x0303, "D9840-60001 [Brio BA410 Motherboard](0x0303-0x0303)"},
{0x5333, 0x8A26, 0xFFFF, 0xFFFF, "ProSavage KM133(0x8A26)"},
{0x5333, 0x8C00, 0xFFFF, 0xFFFF, "ViRGE/M3(0x8C00)"},
{0x5333, 0x8C01, 0xFFFF, 0xFFFF, "ViRGE/MX(0x8C01)"},
{0x5333, 0x8C01, 0x1179, 0x0001, "ViRGE/MX(0x1179-0x0001)"},
{0x5333, 0x8C02, 0xFFFF, 0xFFFF, "ViRGE/MX+(0x8C02)"},
{0x5333, 0x8C03, 0xFFFF, 0xFFFF, "ViRGE/MX+MV(0x8C03)"},
{0x5333, 0x8C10, 0xFFFF, 0xFFFF, "86C270-294 [SavageMX-MV](0x8C10)"},
{0x5333, 0x8C11, 0xFFFF, 0xFFFF, "82C270-294 [SavageMX](0x8C11)"},
{0x5333, 0x8C12, 0xFFFF, 0xFFFF, "86C270-294 [SavageIX-MV](0x8C12)"},
{0x5333, 0x8C12, 0x1014, 0x017F, "ThinkPad T20/T22(0x1014-0x017F)"},
{0x5333, 0x8C12, 0x1179, 0x0001, "86C584 SuperSavage/IXC Toshiba(0x1179-0x0001)"},
{0x5333, 0x8C13, 0xFFFF, 0xFFFF, "86C270-294 [SavageIX](0x8C13)"},
{0x5333, 0x8C13, 0x1179, 0x0001, "Magnia Z310(0x1179-0x0001)"},
{0x5333, 0x8C22, 0xFFFF, 0xFFFF, "SuperSavage MX/128(0x8C22)"},
{0x5333, 0x8C24, 0xFFFF, 0xFFFF, "SuperSavage MX/64(0x8C24)"},
{0x5333, 0x8C26, 0xFFFF, 0xFFFF, "SuperSavage MX/64C(0x8C26)"},
{0x5333, 0x8C2A, 0xFFFF, 0xFFFF, "SuperSavage IX/128 SDR(0x8C2A)"},
{0x5333, 0x8C2B, 0xFFFF, 0xFFFF, "SuperSavage IX/128 DDR(0x8C2B)"},
{0x5333, 0x8C2C, 0xFFFF, 0xFFFF, "SuperSavage IX/64 SDR(0x8C2C)"},
{0x5333, 0x8C2D, 0xFFFF, 0xFFFF, "SuperSavage IX/64 DDR(0x8C2D)"},
{0x5333, 0x8C2E, 0xFFFF, 0xFFFF, "SuperSavage IX/C SDR(0x8C2E)"},
{0x5333, 0x8C2E, 0x1014, 0x01FC, "ThinkPad T23(0x1014-0x01FC)"},
{0x5333, 0x8C2F, 0xFFFF, 0xFFFF, "SuperSavage IX/C DDR(0x8C2F)"},
{0x5333, 0x8D01, 0xFFFF, 0xFFFF, "86C380 [ProSavageDDR K4M266](0x8D01)"},
{0x5333, 0x8D02, 0xFFFF, 0xFFFF, "VT8636A [ProSavage KN133] AGP4X VGA Controller (TwisterK)(0x8D02)"},
{0x5333, 0x8D03, 0xFFFF, 0xFFFF, "VT8751 [ProSavageDDR P4M266](0x8D03)"},
{0x5333, 0x8D04, 0xFFFF, 0xFFFF, "VT8375 [ProSavage8 KM266/KL266](0x8D04)"},
{0x5333, 0x8E00, 0xFFFF, 0xFFFF, "DeltaChrome(0x8E00)"},
{0x5333, 0x8E26, 0xFFFF, 0xFFFF, "ProSavage(0x8E26)"},
{0x5333, 0x8E40, 0xFFFF, 0xFFFF, "2300E Graphics Processor(0x8E40)"},
{0x5333, 0x8E48, 0xFFFF, 0xFFFF, "Matrix [Chrome S25 / S27](0x8E48)"},
{0x5333, 0x8E48, 0x5333, 0x0130, "Chrome S27 256M DDR2(0x5333-0x0130)"},
{0x5333, 0x9043, 0xFFFF, 0xFFFF, "Chrome 430 GT(0x9043)"},
{0x5333, 0x9045, 0xFFFF, 0xFFFF, "Chrome 430 ULP / 435 ULP / 440 GTX(0x9045)"},
{0x5333, 0x9060, 0xFFFF, 0xFFFF, "Chrome 530 GT(0x9060)"},
{0x5333, 0x9070, 0xFFFF, 0xFFFF, "Chrome 5400EW(0x9070)"},
{0x5333, 0x9102, 0xFFFF, 0xFFFF, "86C410 [Savage 2000](0x9102)"},
{0x5333, 0x9102, 0x1092, 0x5932, "Viper II Z200(0x1092-0x5932)"},
{0x5333, 0x9102, 0x1092, 0x5934, "Viper II Z200(0x1092-0x5934)"},
{0x5333, 0x9102, 0x1092, 0x5952, "Viper II Z200(0x1092-0x5952)"},
{0x5333, 0x9102, 0x1092, 0x5954, "Viper II Z200(0x1092-0x5954)"},
{0x5333, 0x9102, 0x1092, 0x5A35, "Viper II Z200(0x1092-0x5A35)"},
{0x5333, 0x9102, 0x1092, 0x5A37, "Viper II Z200(0x1092-0x5A37)"},
{0x5333, 0x9102, 0x1092, 0x5A55, "Viper II Z200(0x1092-0x5A55)"},
{0x5333, 0x9102, 0x1092, 0x5A57, "Viper II Z200(0x1092-0x5A57)"},
{0x5333, 0xCA00, 0xFFFF, 0xFFFF, "SonicVibes(0xCA00)"},
}; /* pci_vid_5333[] */

static pci_id_t const pci_vid_5431[] = {
{0x5431, 0xFFFF, 0xFFFF, 0xFFFF, "AuzenTech, Inc.(0x5431)"},
}; /* pci_vid_5431[] */

static pci_id_t const pci_vid_544C[] = {
{0x544C, 0xFFFF, 0xFFFF, 0xFFFF, "Teralogic Inc(0x544C)"},
{0x544C, 0x0350, 0xFFFF, 0xFFFF, "TL880-based HDTV/ATSC tuner(0x0350)"},
}; /* pci_vid_544C[] */

static pci_id_t const pci_vid_544D[] = {
{0x544D, 0xFFFF, 0xFFFF, 0xFFFF, "TBS Technologies(0x544D)"},
{0x544D, 0x6178, 0xFFFF, 0xFFFF, "DVB Tuner PCIe Card(0x6178)"},
{0x544D, 0x6178, 0x544D, 0x6904, "TBS6904 DVB-S2 Quad Tuner PCIe Card(0x544D-0x6904)"},
{0x544D, 0x6178, 0x544D, 0x6905, "TBS6905 DVB-S2 Quad Tuner PCIe Card(0x544D-0x6905)"},
{0x544D, 0x6178, 0x6205, 0x0001, "TBS6205 DVB-T2/T/C Quad TV Tuner PCIe Card(0x6205-0x0001)"},
{0x544D, 0x6178, 0x6209, 0x0001, "TBS6209 DVB-T2/C2/T/C/ISDB-T OctaTV Tuner(0x6209-0x0001)"},
{0x544D, 0x6178, 0x6590, 0x0001, "TBS6590 DVB-S/S2/S2X/T/T2/C/C2/ISDB-T + 2xCI(0x6590-0x0001)"},
{0x544D, 0x6178, 0x6590, 0x0002, "TBS6590SE DVB-S/S2/S2X/T/T2/C/C2 + 2xCI(0x6590-0x0002)"},
{0x544D, 0x6178, 0x6704, 0xFFFF, "TBS6704 (Quad ATSC/QAMB)(0x6704-0xFFFF)"},
{0x544D, 0x6178, 0x6903, 0x0020, "TBS6903x (Dual DVB-S/S2/S2X)(0x6903-0x0020)"},
{0x544D, 0x6178, 0x6903, 0x0021, "TBS6903x (Dual DVB-S/S2/S2X)(0x6903-0x0021)"},
{0x544D, 0x6178, 0x6903, 0x8888, "TBS6903x (Dual DVB-S/S2/S2X)(0x6903-0x8888)"},
{0x544D, 0x6178, 0x6909, 0x0009, "TBS6909x (Octa DVB-S/S2/S2X)(0x6909-0x0009)"},
{0x544D, 0x6178, 0x6909, 0x0010, "TBS6909x (Octa DVB-S/S2/S2X)(0x6909-0x0010)"},
{0x544D, 0x6178, 0x6909, 0x0019, "TBS6909x (Octa DVB-S/S2/S2X)(0x6909-0x0019)"},
{0x544D, 0x6178, 0x6910, 0x0001, "TBS6910 DVB-S/S2 + 2xCI(0x6910-0x0001)"},
{0x544D, 0x6178, 0x6910, 0x0002, "TBS6910SE DVB-S/S2/S2x + 2xCI(0x6910-0x0002)"},
}; /* pci_vid_544D[] */

static pci_id_t const pci_vid_5452[] = {
{0x5452, 0xFFFF, 0xFFFF, 0xFFFF, "SCANLAB AG(0x5452)"},
{0x5452, 0x3443, 0xFFFF, 0xFFFF, "RTC4(0x3443)"},
}; /* pci_vid_5452[] */

static pci_id_t const pci_vid_5455[] = {
{0x5455, 0xFFFF, 0xFFFF, 0xFFFF, "Technische Universitaet Berlin(0x5455)"},
{0x5455, 0x4458, 0xFFFF, 0xFFFF, "S5933(0x4458)"},
}; /* pci_vid_5455[] */

static pci_id_t const pci_vid_5456[] = {
{0x5456, 0xFFFF, 0xFFFF, 0xFFFF, "GoTView(0x5456)"},
}; /* pci_vid_5456[] */

static pci_id_t const pci_vid_5519[] = {
{0x5519, 0xFFFF, 0xFFFF, 0xFFFF, "Cnet Technologies, Inc.(0x5519)"},
}; /* pci_vid_5519[] */

static pci_id_t const pci_vid_5544[] = {
{0x5544, 0xFFFF, 0xFFFF, 0xFFFF, "Dunord Technologies(0x5544)"},
{0x5544, 0x0001, 0xFFFF, 0xFFFF, "I-30xx Scanner Interface(0x0001)"},
}; /* pci_vid_5544[] */

static pci_id_t const pci_vid_5555[] = {
{0x5555, 0xFFFF, 0xFFFF, 0xFFFF, "Genroco, Inc(0x5555)"},
{0x5555, 0x0003, 0xFFFF, 0xFFFF, "TURBOstor HFP-832 [HiPPI NIC](0x0003)"},
{0x5555, 0x0004, 0xFFFF, 0xFFFF, "Torrent QN16e [16-128 Channel MPEG QAM Modulator for DVB-C](0x0004)"},
{0x5555, 0x3B00, 0xFFFF, 0xFFFF, "Epiphan DVI2PCIe video capture card(0x3B00)"},
}; /* pci_vid_5555[] */

static pci_id_t const pci_vid_5646[] = {
{0x5646, 0xFFFF, 0xFFFF, 0xFFFF, "Vector Fabrics BV(0x5646)"},
}; /* pci_vid_5646[] */

static pci_id_t const pci_vid_5654[] = {
{0x5654, 0xFFFF, 0xFFFF, 0xFFFF, "VoiceTronix Pty Ltd(0x5654)"},
}; /* pci_vid_5654[] */

static pci_id_t const pci_vid_5678[] = {
{0x5678, 0xFFFF, 0xFFFF, 0xFFFF, "Dawicontrol Computersysteme GmbH(0x5678)"},
}; /* pci_vid_5678[] */

static pci_id_t const pci_vid_5700[] = {
{0x5700, 0xFFFF, 0xFFFF, 0xFFFF, "Netpower(0x5700)"},
}; /* pci_vid_5700[] */

static pci_id_t const pci_vid_5845[] = {
{0x5845, 0xFFFF, 0xFFFF, 0xFFFF, "X-ES, Inc.(0x5845)"},
}; /* pci_vid_5845[] */

static pci_id_t const pci_vid_584D[] = {
{0x584D, 0xFFFF, 0xFFFF, 0xFFFF, "AuzenTech Co., Ltd.(0x584D)"},
}; /* pci_vid_584D[] */

static pci_id_t const pci_vid_5851[] = {
{0x5851, 0xFFFF, 0xFFFF, 0xFFFF, "Exacq Technologies(0x5851)"},
{0x5851, 0x8008, 0xFFFF, 0xFFFF, "tDVR8008 8-port video capture card(0x8008)"},
{0x5851, 0x8016, 0xFFFF, 0xFFFF, "tDVR8016 16-chan video capture card(0x8016)"},
{0x5851, 0x8032, 0xFFFF, 0xFFFF, "tDVR8032 32-chan video capture card(0x8032)"},
}; /* pci_vid_5851[] */

static pci_id_t const pci_vid_5853[] = {
{0x5853, 0xFFFF, 0xFFFF, 0xFFFF, "XenSource, Inc.(0x5853)"},
{0x5853, 0x0001, 0xFFFF, 0xFFFF, "Xen Platform Device(0x0001)"},
{0x5853, 0xC000, 0xFFFF, 0xFFFF, "Citrix XenServer PCI Device for Windows Update(0xC000)"},
{0x5853, 0xC110, 0xFFFF, 0xFFFF, "Virtualized HID(0xC110)"},
{0x5853, 0xC147, 0xFFFF, 0xFFFF, "Virtualized Graphics Device(0xC147)"},
{0x5853, 0xC200, 0xFFFF, 0xFFFF, "XCP-ng Project PCI Device for Windows Update(0xC200)"},
}; /* pci_vid_5853[] */

static pci_id_t const pci_vid_5854[] = {
{0x5854, 0xFFFF, 0xFFFF, 0xFFFF, "GoTView(0x5854)"},
}; /* pci_vid_5854[] */

static pci_id_t const pci_vid_5ACE[] = {
{0x5ACE, 0xFFFF, 0xFFFF, 0xFFFF, "Beholder International Ltd.(0x5ACE)"},
}; /* pci_vid_5ACE[] */

static pci_id_t const pci_vid_6205[] = {
{0x6205, 0xFFFF, 0xFFFF, 0xFFFF, "TBS Technologies (wrong ID)(0x6205)"},
}; /* pci_vid_6205[] */

static pci_id_t const pci_vid_6209[] = {
{0x6209, 0xFFFF, 0xFFFF, 0xFFFF, "TBS Technologies (wrong ID)(0x6209)"},
}; /* pci_vid_6209[] */

static pci_id_t const pci_vid_631C[] = {
{0x631C, 0xFFFF, 0xFFFF, 0xFFFF, "SmartInfra Ltd(0x631C)"},
{0x631C, 0x1652, 0xFFFF, 0xFFFF, "PXI-1652 Signal Generator(0x1652)"},
{0x631C, 0x2504, 0xFFFF, 0xFFFF, "PXI-2504 Signal Interrogator(0x2504)"},
}; /* pci_vid_631C[] */

static pci_id_t const pci_vid_6356[] = {
{0x6356, 0xFFFF, 0xFFFF, 0xFFFF, "UltraStor(0x6356)"},
}; /* pci_vid_6356[] */

static pci_id_t const pci_vid_6374[] = {
{0x6374, 0xFFFF, 0xFFFF, 0xFFFF, "c't Magazin fuer Computertechnik(0x6374)"},
{0x6374, 0x6773, 0xFFFF, 0xFFFF, "GPPCI(0x6773)"},
}; /* pci_vid_6374[] */

static pci_id_t const pci_vid_6409[] = {
{0x6409, 0xFFFF, 0xFFFF, 0xFFFF, "Logitec Corp.(0x6409)"},
}; /* pci_vid_6409[] */

static pci_id_t const pci_vid_6549[] = {
{0x6549, 0xFFFF, 0xFFFF, 0xFFFF, "Teradici Corp.(0x6549)"},
{0x6549, 0x1200, 0xFFFF, 0xFFFF, "TERA1200 PC-over-IP Host(0x1200)"},
}; /* pci_vid_6549[] */

static pci_id_t const pci_vid_6590[] = {
{0x6590, 0xFFFF, 0xFFFF, 0xFFFF, "TBS Technologies (wrong ID)(0x6590)"},
}; /* pci_vid_6590[] */

static pci_id_t const pci_vid_6666[] = {
{0x6666, 0xFFFF, 0xFFFF, 0xFFFF, "Decision Computer International Co.(0x6666)"},
{0x6666, 0x0001, 0xFFFF, 0xFFFF, "PCCOM4(0x0001)"},
{0x6666, 0x0002, 0xFFFF, 0xFFFF, "PCCOM8(0x0002)"},
{0x6666, 0x0004, 0xFFFF, 0xFFFF, "PCCOM2(0x0004)"},
{0x6666, 0x0101, 0xFFFF, 0xFFFF, "PCI 8255/8254 I/O Card(0x0101)"},
{0x6666, 0x0200, 0xFFFF, 0xFFFF, "12-bit AD/DA Card(0x0200)"},
{0x6666, 0x0201, 0xFFFF, 0xFFFF, "14-bit AD/DA Card(0x0201)"},
{0x6666, 0x1011, 0xFFFF, 0xFFFF, "Industrial Card(0x1011)"},
{0x6666, 0x1021, 0xFFFF, 0xFFFF, "8 photo couple 8 relay Card(0x1021)"},
{0x6666, 0x1022, 0xFFFF, 0xFFFF, "4 photo couple 4 relay Card(0x1022)"},
{0x6666, 0x1025, 0xFFFF, 0xFFFF, "16 photo couple 16 relay Card(0x1025)"},
{0x6666, 0x4000, 0xFFFF, 0xFFFF, "WatchDog Card(0x4000)"},
}; /* pci_vid_6666[] */

static pci_id_t const pci_vid_6688[] = {
{0x6688, 0xFFFF, 0xFFFF, 0xFFFF, "Zycoo Co., Ltd(0x6688)"},
{0x6688, 0x1200, 0xFFFF, 0xFFFF, "CooVox TDM Analog Module(0x1200)"},
{0x6688, 0x1400, 0xFFFF, 0xFFFF, "CooVOX TDM GSM Module(0x1400)"},
{0x6688, 0x1600, 0xFFFF, 0xFFFF, "CooVOX TDM E1/T1 Module(0x1600)"},
{0x6688, 0x1800, 0xFFFF, 0xFFFF, "CooVOX TDM BRI Module(0x1800)"},
}; /* pci_vid_6688[] */

static pci_id_t const pci_vid_6704[] = {
{0x6704, 0xFFFF, 0xFFFF, 0xFFFF, "TBS Technologies (wrong ID)(0x6704)"},
}; /* pci_vid_6704[] */

static pci_id_t const pci_vid_6766[] = {
{0x6766, 0xFFFF, 0xFFFF, 0xFFFF, "Glenfly Tech Co., Ltd.(0x6766)"},
{0x6766, 0x3D00, 0xFFFF, 0xFFFF, "Arise-GT-10C0(0x3D00)"},
{0x6766, 0x3D02, 0xFFFF, 0xFFFF, "Arise1020(0x3D02)"},
{0x6766, 0x3D03, 0xFFFF, 0xFFFF, "Arise-GT-1040(0x3D03)"},
{0x6766, 0x3D04, 0xFFFF, 0xFFFF, "Arise1010(0x3D04)"},
{0x6766, 0x3D06, 0xFFFF, 0xFFFF, "Arise-GT-10C0t(0x3D06)"},
{0x6766, 0x3D07, 0xFFFF, 0xFFFF, "Arise2030(0x3D07)"},
{0x6766, 0x3D08, 0xFFFF, 0xFFFF, "Arise2020(0x3D08)"},
{0x6766, 0x3D40, 0xFFFF, 0xFFFF, "GLF HDMI/DP Audio(0x3D40)"},
{0x6766, 0x3D41, 0xFFFF, 0xFFFF, "GLF HDMI/DP Audio(0x3D41)"},
{0x6766, 0x3D43, 0xFFFF, 0xFFFF, "GLF HDMI/DP Audio(0x3D43)"},
}; /* pci_vid_6766[] */

static pci_id_t const pci_vid_6899[] = {
{0x6899, 0xFFFF, 0xFFFF, 0xFFFF, "ZT Systems(0x6899)"},
}; /* pci_vid_6899[] */

static pci_id_t const pci_vid_6900[] = {
{0x6900, 0xFFFF, 0xFFFF, 0xFFFF, "Red Hat, Inc.(0x6900)"},
}; /* pci_vid_6900[] */

static pci_id_t const pci_vid_6903[] = {
{0x6903, 0xFFFF, 0xFFFF, 0xFFFF, "TBS Technologies (wrong ID)(0x6903)"},
}; /* pci_vid_6903[] */

static pci_id_t const pci_vid_6909[] = {
{0x6909, 0xFFFF, 0xFFFF, 0xFFFF, "TBS Technologies (wrong ID)(0x6909)"},
}; /* pci_vid_6909[] */

static pci_id_t const pci_vid_6910[] = {
{0x6910, 0xFFFF, 0xFFFF, 0xFFFF, "TBS Technologies (wrong ID)(0x6910)"},
}; /* pci_vid_6910[] */

static pci_id_t const pci_vid_6F67[] = {
{0x6F67, 0xFFFF, 0xFFFF, 0xFFFF, "NOVAIUM Technology(0x6F67)"},
}; /* pci_vid_6F67[] */

static pci_id_t const pci_vid_7063[] = {
{0x7063, 0xFFFF, 0xFFFF, 0xFFFF, "pcHDTV(0x7063)"},
{0x7063, 0x2000, 0xFFFF, 0xFFFF, "HD-2000(0x2000)"},
{0x7063, 0x3000, 0xFFFF, 0xFFFF, "HD-3000(0x3000)"},
{0x7063, 0x5500, 0xFFFF, 0xFFFF, "HD5500 HDTV(0x5500)"},
}; /* pci_vid_7063[] */

static pci_id_t const pci_vid_7284[] = {
{0x7284, 0xFFFF, 0xFFFF, 0xFFFF, "HT OMEGA Inc.(0x7284)"},
}; /* pci_vid_7284[] */

static pci_id_t const pci_vid_7357[] = {
{0x7357, 0xFFFF, 0xFFFF, 0xFFFF, "IOxOS Technologies SA(0x7357)"},
{0x7357, 0x7910, 0xFFFF, 0xFFFF, "7910 [Althea](0x7910)"},
}; /* pci_vid_7357[] */

static pci_id_t const pci_vid_7377[] = {
{0x7377, 0xFFFF, 0xFFFF, 0xFFFF, "Shenzhen Colorful Yugong Technology and Development Co.(0x7377)"},
}; /* pci_vid_7377[] */

static pci_id_t const pci_vid_7401[] = {
{0x7401, 0xFFFF, 0xFFFF, 0xFFFF, "EndRun Technologies(0x7401)"},
{0x7401, 0xE100, 0xFFFF, 0xFFFF, "PTP3100 PCIe PTP Slave Clock(0xE100)"},
}; /* pci_vid_7401[] */

static pci_id_t const pci_vid_7470[] = {
{0x7470, 0xFFFF, 0xFFFF, 0xFFFF, "TP-LINK Technologies Co., Ltd.(0x7470)"},
}; /* pci_vid_7470[] */

static pci_id_t const pci_vid_7526[] = {
{0x7526, 0xFFFF, 0xFFFF, 0xFFFF, "HongQin (Beijing) Technology Co., Ltd.(0x7526)"},
{0x7526, 0x0082, 0xFFFF, 0xFFFF, "HQ SSD M.2(0x0082)"},
{0x7526, 0x0083, 0xFFFF, 0xFFFF, "HQ SSD 2TB M.2 NVMe(0x0083)"},
}; /* pci_vid_7526[] */

static pci_id_t const pci_vid_7604[] = {
{0x7604, 0xFFFF, 0xFFFF, 0xFFFF, "O.N. Electronic Co Ltd.(0x7604)"},
}; /* pci_vid_7604[] */

static pci_id_t const pci_vid_78C0[] = {
{0x78C0, 0xFFFF, 0xFFFF, 0xFFFF, "Herrick Technology Laboratories, Inc. [HTL](0x78C0)"},
{0x78C0, 0x0000, 0xFFFF, 0xFFFF, "HTLv-1 / HTLv-2 / HTLv-13 / HTLv-23(0x0000)"},
{0x78C0, 0x0011, 0xFFFF, 0xFFFF, "HTLv-53(0x0011)"},
}; /* pci_vid_78C0[] */

static pci_id_t const pci_vid_7BDE[] = {
{0x7BDE, 0xFFFF, 0xFFFF, 0xFFFF, "MIDAC Corporation(0x7BDE)"},
}; /* pci_vid_7BDE[] */

static pci_id_t const pci_vid_7FED[] = {
{0x7FED, 0xFFFF, 0xFFFF, 0xFFFF, "PowerTV(0x7FED)"},
}; /* pci_vid_7FED[] */

static pci_id_t const pci_vid_8008[] = {
{0x8008, 0xFFFF, 0xFFFF, 0xFFFF, "Quancom Electronic GmbH(0x8008)"},
{0x8008, 0x0010, 0xFFFF, 0xFFFF, "WDOG1 [PCI-Watchdog 1](0x0010)"},
{0x8008, 0x0011, 0xFFFF, 0xFFFF, "PWDOG2 [PCI-Watchdog 2](0x0011)"},
{0x8008, 0x0015, 0xFFFF, 0xFFFF, "Clock77/PCI & Clock77/PCIe (DCF-77 receiver)(0x0015)"},
}; /* pci_vid_8008[] */

static pci_id_t const pci_vid_807D[] = {
{0x807D, 0xFFFF, 0xFFFF, 0xFFFF, "Asustek Computer, Inc.(0x807D)"},
}; /* pci_vid_807D[] */

static pci_id_t const pci_vid_8086[] = {
{0x8086, 0xFFFF, 0xFFFF, 0xFFFF, "Intel Corporation(0x8086)"},
{0x8086, 0x0007, 0xFFFF, 0xFFFF, "82379AB(0x0007)"},
{0x8086, 0x0008, 0xFFFF, 0xFFFF, "Extended Express System Support Controller(0x0008)"},
{0x8086, 0x0039, 0xFFFF, 0xFFFF, "21145 Fast Ethernet(0x0039)"},
{0x8086, 0x0040, 0xFFFF, 0xFFFF, "Core Processor DRAM Controller(0x0040)"},
{0x8086, 0x0041, 0xFFFF, 0xFFFF, "Core Processor PCI Express x16 Root Port(0x0041)"},
{0x8086, 0x0042, 0xFFFF, 0xFFFF, "Core Processor Integrated Graphics Controller(0x0042)"},
{0x8086, 0x0043, 0xFFFF, 0xFFFF, "Core Processor Secondary PCI Express Root Port(0x0043)"},
{0x8086, 0x0044, 0xFFFF, 0xFFFF, "Core Processor DRAM Controller(0x0044)"},
{0x8086, 0x0044, 0x1025, 0x0347, "Aspire 7740G(0x1025-0x0347)"},
{0x8086, 0x0044, 0x1025, 0x0487, "TravelMate 5742(0x1025-0x0487)"},
{0x8086, 0x0044, 0x1028, 0x040A, "Latitude E6410(0x1028-0x040A)"},
{0x8086, 0x0044, 0x144D, 0xC06A, "R730 Laptop(0x144D-0xC06A)"},
{0x8086, 0x0044, 0x17C0, 0x10D2, "Medion Akoya E7214 Notebook PC [MD98410](0x17C0-0x10D2)"},
{0x8086, 0x0044, 0xE4BF, 0x50C1, "PC1-GROOVE(0xE4BF-0x50C1)"},
{0x8086, 0x0045, 0xFFFF, 0xFFFF, "Core Processor PCI Express x16 Root Port(0x0045)"},
{0x8086, 0x0045, 0x17C0, 0x10D2, "Medion Akoya E7214 Notebook PC [MD98410](0x17C0-0x10D2)"},
{0x8086, 0x0046, 0xFFFF, 0xFFFF, "Core Processor Integrated Graphics Controller(0x0046)"},
{0x8086, 0x0046, 0x1028, 0x040A, "Latitude E6410(0x1028-0x040A)"},
{0x8086, 0x0046, 0x144D, 0xC06A, "R730 Laptop(0x144D-0xC06A)"},
{0x8086, 0x0046, 0x17C0, 0x10D9, "Medion Akoya E7214 Notebook PC [MD98410](0x17C0-0x10D9)"},
{0x8086, 0x0046, 0xE4BF, 0x50C1, "PC1-GROOVE(0xE4BF-0x50C1)"},
{0x8086, 0x0047, 0xFFFF, 0xFFFF, "Core Processor Secondary PCI Express Root Port(0x0047)"},
{0x8086, 0x0048, 0xFFFF, 0xFFFF, "Core Processor DRAM Controller(0x0048)"},
{0x8086, 0x0049, 0xFFFF, 0xFFFF, "Core Processor PCI Express x16 Root Port(0x0049)"},
{0x8086, 0x004A, 0xFFFF, 0xFFFF, "Core Processor Integrated Graphics Controller(0x004A)"},
{0x8086, 0x004B, 0xFFFF, 0xFFFF, "Core Processor Secondary PCI Express Root Port(0x004B)"},
{0x8086, 0x0050, 0xFFFF, 0xFFFF, "Core Processor Thermal Management Controller(0x0050)"},
{0x8086, 0x0069, 0xFFFF, 0xFFFF, "Core Processor DRAM Controller(0x0069)"},
{0x8086, 0x0082, 0xFFFF, 0xFFFF, "Centrino Advanced-N 6205 [Taylor Peak](0x0082)"},
{0x8086, 0x0082, 0x8086, 0x1301, "Centrino Advanced-N 6205 AGN(0x8086-0x1301)"},
{0x8086, 0x0082, 0x8086, 0x1306, "Centrino Advanced-N 6205 ABG(0x8086-0x1306)"},
{0x8086, 0x0082, 0x8086, 0x1307, "Centrino Advanced-N 6205 BG(0x8086-0x1307)"},
{0x8086, 0x0082, 0x8086, 0x1321, "Centrino Advanced-N 6205 AGN(0x8086-0x1321)"},
{0x8086, 0x0082, 0x8086, 0x1326, "Centrino Advanced-N 6205 ABG(0x8086-0x1326)"},
{0x8086, 0x0083, 0xFFFF, 0xFFFF, "Centrino Wireless-N 1000 [Condor Peak](0x0083)"},
{0x8086, 0x0083, 0x8086, 0x1205, "Centrino Wireless-N 1000 BGN(0x8086-0x1205)"},
{0x8086, 0x0083, 0x8086, 0x1206, "Centrino Wireless-N 1000 BG(0x8086-0x1206)"},
{0x8086, 0x0083, 0x8086, 0x1225, "Centrino Wireless-N 1000 BGN(0x8086-0x1225)"},
{0x8086, 0x0083, 0x8086, 0x1226, "Centrino Wireless-N 1000 BG(0x8086-0x1226)"},
{0x8086, 0x0083, 0x8086, 0x1305, "Centrino Wireless-N 1000 BGN(0x8086-0x1305)"},
{0x8086, 0x0083, 0x8086, 0x1306, "Centrino Wireless-N 1000 BG(0x8086-0x1306)"},
{0x8086, 0x0083, 0x8086, 0x1325, "Centrino Wireless-N 1000 BGN(0x8086-0x1325)"},
{0x8086, 0x0083, 0x8086, 0x1326, "Centrino Wireless-N 1000 BG(0x8086-0x1326)"},
{0x8086, 0x0084, 0xFFFF, 0xFFFF, "Centrino Wireless-N 1000 [Condor Peak](0x0084)"},
{0x8086, 0x0084, 0x8086, 0x1215, "Centrino Wireless-N 1000 BGN(0x8086-0x1215)"},
{0x8086, 0x0084, 0x8086, 0x1216, "Centrino Wireless-N 1000 BG(0x8086-0x1216)"},
{0x8086, 0x0084, 0x8086, 0x1315, "Centrino Wireless-N 1000 BGN(0x8086-0x1315)"},
{0x8086, 0x0084, 0x8086, 0x1316, "Centrino Wireless-N 1000 BG(0x8086-0x1316)"},
{0x8086, 0x0085, 0xFFFF, 0xFFFF, "Centrino Advanced-N 6205 [Taylor Peak](0x0085)"},
{0x8086, 0x0085, 0x8086, 0x1311, "Centrino Advanced-N 6205 (802.11a/b/g/n)(0x8086-0x1311)"},
{0x8086, 0x0085, 0x8086, 0x1316, "Centrino Advanced-N 6205 ABG(0x8086-0x1316)"},
{0x8086, 0x0087, 0xFFFF, 0xFFFF, "Centrino Advanced-N + WiMAX 6250 [Kilmer Peak](0x0087)"},
{0x8086, 0x0087, 0x8086, 0x1301, "Centrino Advanced-N + WiMAX 6250 2x2 AGN(0x8086-0x1301)"},
{0x8086, 0x0087, 0x8086, 0x1306, "Centrino Advanced-N + WiMAX 6250 2x2 ABG(0x8086-0x1306)"},
{0x8086, 0x0087, 0x8086, 0x1321, "Centrino Advanced-N + WiMAX 6250 2x2 AGN(0x8086-0x1321)"},
{0x8086, 0x0087, 0x8086, 0x1326, "Centrino Advanced-N + WiMAX 6250 2x2 ABG(0x8086-0x1326)"},
{0x8086, 0x0089, 0xFFFF, 0xFFFF, "Centrino Advanced-N + WiMAX 6250 [Kilmer Peak](0x0089)"},
{0x8086, 0x0089, 0x8086, 0x1311, "Centrino Advanced-N + WiMAX 6250 2x2 AGN(0x8086-0x1311)"},
{0x8086, 0x0089, 0x8086, 0x1316, "Centrino Advanced-N + WiMAX 6250 2x2 ABG(0x8086-0x1316)"},
{0x8086, 0x008A, 0xFFFF, 0xFFFF, "Centrino Wireless-N 1030 [Rainbow Peak](0x008A)"},
{0x8086, 0x008A, 0x8086, 0x5305, "Centrino Wireless-N 1030 BGN(0x8086-0x5305)"},
{0x8086, 0x008A, 0x8086, 0x5307, "Centrino Wireless-N 1030 BG(0x8086-0x5307)"},
{0x8086, 0x008A, 0x8086, 0x5325, "Centrino Wireless-N 1030 BGN(0x8086-0x5325)"},
{0x8086, 0x008A, 0x8086, 0x5327, "Centrino Wireless-N 1030 BG(0x8086-0x5327)"},
{0x8086, 0x008B, 0xFFFF, 0xFFFF, "Centrino Wireless-N 1030 [Rainbow Peak](0x008B)"},
{0x8086, 0x008B, 0x8086, 0x5315, "Centrino Wireless-N 1030 BGN(0x8086-0x5315)"},
{0x8086, 0x008B, 0x8086, 0x5317, "Centrino Wireless-N 1030 BG(0x8086-0x5317)"},
{0x8086, 0x0090, 0xFFFF, 0xFFFF, "Centrino Advanced-N 6230 [Rainbow Peak](0x0090)"},
{0x8086, 0x0090, 0x8086, 0x5211, "Centrino Advanced-N 6230 AGN(0x8086-0x5211)"},
{0x8086, 0x0090, 0x8086, 0x5215, "Centrino Advanced-N 6230 BGN(0x8086-0x5215)"},
{0x8086, 0x0090, 0x8086, 0x5216, "Centrino Advanced-N 6230 ABG(0x8086-0x5216)"},
{0x8086, 0x0091, 0xFFFF, 0xFFFF, "Centrino Advanced-N 6230 [Rainbow Peak](0x0091)"},
{0x8086, 0x0091, 0x8086, 0x5201, "Centrino Advanced-N 6230 AGN(0x8086-0x5201)"},
{0x8086, 0x0091, 0x8086, 0x5205, "Centrino Advanced-N 6230 BGN(0x8086-0x5205)"},
{0x8086, 0x0091, 0x8086, 0x5206, "Centrino Advanced-N 6230 ABG(0x8086-0x5206)"},
{0x8086, 0x0091, 0x8086, 0x5207, "Centrino Advanced-N 6230 BG(0x8086-0x5207)"},
{0x8086, 0x0091, 0x8086, 0x5221, "Centrino Advanced-N 6230 AGN(0x8086-0x5221)"},
{0x8086, 0x0091, 0x8086, 0x5225, "Centrino Advanced-N 6230 BGN(0x8086-0x5225)"},
{0x8086, 0x0091, 0x8086, 0x5226, "Centrino Advanced-N 6230 ABG(0x8086-0x5226)"},
{0x8086, 0x0100, 0xFFFF, 0xFFFF, "2nd Generation Core Processor Family DRAM Controller(0x0100)"},
{0x8086, 0x0100, 0x1028, 0x04AA, "XPS 8300(0x1028-0x04AA)"},
{0x8086, 0x0100, 0x1043, 0x844D, "P8P67/P8H67 Series Motherboard(0x1043-0x844D)"},
{0x8086, 0x0100, 0x1734, 0x11B9, "Esprimo P510 D3171 motherboard(0x1734-0x11B9)"},
{0x8086, 0x0100, 0x17AA, 0x3070, "ThinkCentre M91p(0x17AA-0x3070)"},
{0x8086, 0x0100, 0x8086, 0x200D, "DH61CR motherboard(0x8086-0x200D)"},
{0x8086, 0x0101, 0xFFFF, 0xFFFF, "Xeon E3-1200/2nd Generation Core Processor Family PCI Express Root Port(0x0101)"},
{0x8086, 0x0101, 0x1028, 0x04B2, "Vostro 3350(0x1028-0x04B2)"},
{0x8086, 0x0101, 0x106B, 0x00DC, "MacBookPro8,2 [Core i7, 15\", 2011](0x106B-0x00DC)"},
{0x8086, 0x0101, 0x144D, 0xC652, "NP300E5C series laptop(0x144D-0xC652)"},
{0x8086, 0x0102, 0xFFFF, 0xFFFF, "2nd Generation Core Processor Family Integrated Graphics Controller(0x0102)"},
{0x8086, 0x0102, 0x1028, 0x04AA, "XPS 8300(0x1028-0x04AA)"},
{0x8086, 0x0102, 0x1043, 0x0102, "P8H67 Series Motherboard(0x1043-0x0102)"},
{0x8086, 0x0102, 0x1734, 0x11B9, "G640 [Sandy Bridge, HD Graphics] on Esprimo P510 D3171 motherboard(0x1734-0x11B9)"},
{0x8086, 0x0102, 0x17AA, 0x3070, "ThinkCentre M91p(0x17AA-0x3070)"},
{0x8086, 0x0104, 0xFFFF, 0xFFFF, "2nd Generation Core Processor Family DRAM Controller(0x0104)"},
{0x8086, 0x0104, 0x1028, 0x04A3, "Precision M4600(0x1028-0x04A3)"},
{0x8086, 0x0104, 0x1028, 0x04B2, "Vostro 3350(0x1028-0x04B2)"},
{0x8086, 0x0104, 0x1028, 0x04DA, "Vostro 3750(0x1028-0x04DA)"},
{0x8086, 0x0104, 0x106B, 0x00DC, "MacBookPro8,2 [Core i7, 15\", 2011](0x106B-0x00DC)"},
{0x8086, 0x0104, 0x144D, 0xC652, "NP300E5C series laptop(0x144D-0xC652)"},
{0x8086, 0x0104, 0x17AA, 0x21CF, "ThinkPad T520(0x17AA-0x21CF)"},
{0x8086, 0x0105, 0xFFFF, 0xFFFF, "Xeon E3-1200/2nd Generation Core Processor Family PCI Express Root Port(0x0105)"},
{0x8086, 0x0105, 0x106B, 0x00DC, "MacBookPro8,2 [Core i7, 15\", 2011](0x106B-0x00DC)"},
{0x8086, 0x0106, 0xFFFF, 0xFFFF, "2nd Generation Core Processor Family Integrated Graphics Controller(0x0106)"},
{0x8086, 0x0108, 0xFFFF, 0xFFFF, "Xeon E3-1200 Processor Family DRAM Controller(0x0108)"},
{0x8086, 0x0109, 0xFFFF, 0xFFFF, "Xeon E3-1200/2nd Generation Core Processor Family PCI Express Root Port(0x0109)"},
{0x8086, 0x010A, 0xFFFF, 0xFFFF, "Xeon E3-1200 Processor Family Integrated Graphics Controller(0x010A)"},
{0x8086, 0x010B, 0xFFFF, 0xFFFF, "Xeon E3-1200/2nd Generation Core Processor Family Integrated Graphics Controller(0x010B)"},
{0x8086, 0x010C, 0xFFFF, 0xFFFF, "Xeon E3-1200/2nd Generation Core Processor Family DRAM Controller(0x010C)"},
{0x8086, 0x010D, 0xFFFF, 0xFFFF, "Xeon E3-1200/2nd Generation Core Processor Family PCI Express Root Port(0x010D)"},
{0x8086, 0x010E, 0xFFFF, 0xFFFF, "Xeon E3-1200/2nd Generation Core Processor Family Integrated Graphics Controller(0x010E)"},
{0x8086, 0x0112, 0xFFFF, 0xFFFF, "2nd Generation Core Processor Family Integrated Graphics Controller(0x0112)"},
{0x8086, 0x0116, 0xFFFF, 0xFFFF, "2nd Generation Core Processor Family Integrated Graphics Controller(0x0116)"},
{0x8086, 0x0116, 0x1028, 0x04DA, "Vostro 3750(0x1028-0x04DA)"},
{0x8086, 0x0116, 0x144D, 0xC652, "integrated HD 3000 graphics controller on NP300E5C series laptop(0x144D-0xC652)"},
{0x8086, 0x0122, 0xFFFF, 0xFFFF, "2nd Generation Core Processor Family Integrated Graphics Controller(0x0122)"},
{0x8086, 0x0126, 0xFFFF, 0xFFFF, "2nd Generation Core Processor Family Integrated Graphics Controller(0x0126)"},
{0x8086, 0x0126, 0x1028, 0x04CC, "Vostro 3350(0x1028-0x04CC)"},
{0x8086, 0x0126, 0x17AA, 0x21CE, "ThinkPad T420(0x17AA-0x21CE)"},
{0x8086, 0x0126, 0x17AA, 0x21CF, "ThinkPad T520(0x17AA-0x21CF)"},
{0x8086, 0x0150, 0xFFFF, 0xFFFF, "Xeon E3-1200 v2/3rd Gen Core processor DRAM Controller(0x0150)"},
{0x8086, 0x0150, 0x1043, 0x84CA, "P8 series motherboard(0x1043-0x84CA)"},
{0x8086, 0x0150, 0x1458, 0xD000, "Ivy Bridge GT1 [HD Graphics](0x1458-0xD000)"},
{0x8086, 0x0150, 0x15D9, 0x0624, "X9SCM-F Motherboard(0x15D9-0x0624)"},
{0x8086, 0x0150, 0x1849, 0x0150, "Motherboard(0x1849-0x0150)"},
{0x8086, 0x0151, 0xFFFF, 0xFFFF, "Xeon E3-1200 v2/3rd Gen Core processor PCI Express Root Port(0x0151)"},
{0x8086, 0x0151, 0x1043, 0x1477, "N56VZ(0x1043-0x1477)"},
{0x8086, 0x0151, 0x1043, 0x844D, "P8 series motherboard(0x1043-0x844D)"},
{0x8086, 0x0151, 0x1043, 0x84CA, "P8H77-I Motherboard(0x1043-0x84CA)"},
{0x8086, 0x0151, 0x8086, 0x2010, "Server Board S1200BTS(0x8086-0x2010)"},
{0x8086, 0x0152, 0xFFFF, 0xFFFF, "Xeon E3-1200 v2/3rd Gen Core processor Graphics Controller(0x0152)"},
{0x8086, 0x0152, 0x1043, 0x84CA, "P8H77-I Motherboard(0x1043-0x84CA)"},
{0x8086, 0x0153, 0xFFFF, 0xFFFF, "3rd Gen Core Processor Thermal Subsystem(0x0153)"},
{0x8086, 0x0153, 0x1043, 0x1517, "Zenbook Prime UX31A(0x1043-0x1517)"},
{0x8086, 0x0154, 0xFFFF, 0xFFFF, "3rd Gen Core processor DRAM Controller(0x0154)"},
{0x8086, 0x0154, 0x1025, 0x0806, "Aspire E1-470G(0x1025-0x0806)"},
{0x8086, 0x0154, 0x1025, 0x0813, "Aspire R7-571(0x1025-0x0813)"},
{0x8086, 0x0154, 0x103C, 0x17F6, "ProBook 4540s(0x103C-0x17F6)"},
{0x8086, 0x0154, 0x1043, 0x108D, "VivoBook X202EV(0x1043-0x108D)"},
{0x8086, 0x0154, 0x1043, 0x1477, "N56VZ(0x1043-0x1477)"},
{0x8086, 0x0154, 0x1043, 0x1517, "Zenbook Prime UX31A(0x1043-0x1517)"},
{0x8086, 0x0154, 0x10CF, 0x16BF, "LIFEBOOK E752(0x10CF-0x16BF)"},
{0x8086, 0x0155, 0xFFFF, 0xFFFF, "Xeon E3-1200 v2/3rd Gen Core processor PCI Express Root Port(0x0155)"},
{0x8086, 0x0155, 0x8086, 0x2010, "Server Board S1200BTS(0x8086-0x2010)"},
{0x8086, 0x0156, 0xFFFF, 0xFFFF, "3rd Gen Core processor Graphics Controller(0x0156)"},
{0x8086, 0x0156, 0x1043, 0x108D, "VivoBook X202EV(0x1043-0x108D)"},
{0x8086, 0x0158, 0xFFFF, 0xFFFF, "Xeon E3-1200 v2/Ivy Bridge DRAM Controller(0x0158)"},
{0x8086, 0x0158, 0x1043, 0x844D, "P8 series motherboard(0x1043-0x844D)"},
{0x8086, 0x0158, 0x8086, 0x2010, "Server Board S1200BT Family(0x8086-0x2010)"},
{0x8086, 0x0159, 0xFFFF, 0xFFFF, "Xeon E3-1200 v2/3rd Gen Core processor PCI Express Root Port(0x0159)"},
{0x8086, 0x015A, 0xFFFF, 0xFFFF, "Xeon E3-1200 v2/Ivy Bridge Graphics Controller(0x015A)"},
{0x8086, 0x015C, 0xFFFF, 0xFFFF, "Xeon E3-1200 v2/3rd Gen Core processor DRAM Controller(0x015C)"},
{0x8086, 0x015D, 0xFFFF, 0xFFFF, "Xeon E3-1200 v2/3rd Gen Core processor PCI Express Root Port(0x015D)"},
{0x8086, 0x015D, 0x1043, 0x844D, "P8 series motherboard(0x1043-0x844D)"},
{0x8086, 0x015E, 0xFFFF, 0xFFFF, "Xeon E3-1200 v2/3rd Gen Core processor Graphics Controller(0x015E)"},
{0x8086, 0x0162, 0xFFFF, 0xFFFF, "IvyBridge GT2 [HD Graphics 4000](0x0162)"},
{0x8086, 0x0162, 0x1043, 0x84CA, "P8 series motherboard(0x1043-0x84CA)"},
{0x8086, 0x0162, 0x1849, 0x0162, "Motherboard(0x1849-0x0162)"},
{0x8086, 0x0166, 0xFFFF, 0xFFFF, "3rd Gen Core processor Graphics Controller(0x0166)"},
{0x8086, 0x0166, 0x1043, 0x1517, "Zenbook Prime UX31A(0x1043-0x1517)"},
{0x8086, 0x0166, 0x1043, 0x2103, "N56VZ(0x1043-0x2103)"},
{0x8086, 0x0166, 0x10CF, 0x16C1, "LIFEBOOK E752(0x10CF-0x16C1)"},
{0x8086, 0x016A, 0xFFFF, 0xFFFF, "Xeon E3-1200 v2/3rd Gen Core processor Graphics Controller(0x016A)"},
{0x8086, 0x016A, 0x1043, 0x844D, "P8B WS Motherboard(0x1043-0x844D)"},
{0x8086, 0x0172, 0xFFFF, 0xFFFF, "Xeon E3-1200 v2/3rd Gen Core processor Graphics Controller(0x0172)"},
{0x8086, 0x0176, 0xFFFF, 0xFFFF, "3rd Gen Core processor Graphics Controller(0x0176)"},
{0x8086, 0x0201, 0xFFFF, 0xFFFF, "Arctic Sound(0x0201)"},
{0x8086, 0x0284, 0xFFFF, 0xFFFF, "Comet Lake PCH-LP LPC Premium Controller/eSPI Controller(0x0284)"},
{0x8086, 0x0284, 0x1028, 0x09BE, "Latitude 7410(0x1028-0x09BE)"},
{0x8086, 0x02A3, 0xFFFF, 0xFFFF, "Comet Lake PCH-LP SMBus Host Controller(0x02A3)"},
{0x8086, 0x02A3, 0x1028, 0x09BE, "Latitude 7410(0x1028-0x09BE)"},
{0x8086, 0x02A4, 0xFFFF, 0xFFFF, "Comet Lake SPI (flash) Controller(0x02A4)"},
{0x8086, 0x02A4, 0x1028, 0x09BE, "Latitude 7410(0x1028-0x09BE)"},
{0x8086, 0x02A6, 0xFFFF, 0xFFFF, "Comet Lake North Peak(0x02A6)"},
{0x8086, 0x02B0, 0xFFFF, 0xFFFF, "Comet Lake PCI Express Root Port #9(0x02B0)"},
{0x8086, 0x02B1, 0xFFFF, 0xFFFF, "Comet Lake PCI Express Root Port #10(0x02B1)"},
{0x8086, 0x02B3, 0xFFFF, 0xFFFF, "Comet Lake PCI Express Root Port #12(0x02B3)"},
{0x8086, 0x02B4, 0xFFFF, 0xFFFF, "Comet Lake PCI Express Root Port #13(0x02B4)"},
{0x8086, 0x02B5, 0xFFFF, 0xFFFF, "Comet Lake PCI Express Root Port #14(0x02B5)"},
{0x8086, 0x02B8, 0xFFFF, 0xFFFF, "Comet Lake PCI Express Root Port #1(0x02B8)"},
{0x8086, 0x02BC, 0xFFFF, 0xFFFF, "Comet Lake PCI Express Root Port #5(0x02BC)"},
{0x8086, 0x02BF, 0xFFFF, 0xFFFF, "Comet Lake PCI Express Root Port #8(0x02BF)"},
{0x8086, 0x02C5, 0xFFFF, 0xFFFF, "Comet Lake Serial IO I2C Host Controller(0x02C5)"},
{0x8086, 0x02C5, 0x1028, 0x09BE, "Latitude 7410(0x1028-0x09BE)"},
{0x8086, 0x02C8, 0xFFFF, 0xFFFF, "Comet Lake PCH-LP cAVS(0x02C8)"},
{0x8086, 0x02C8, 0x1028, 0x09BE, "Latitude 7410(0x1028-0x09BE)"},
{0x8086, 0x02D3, 0xFFFF, 0xFFFF, "Comet Lake SATA AHCI Controller(0x02D3)"},
{0x8086, 0x02D7, 0xFFFF, 0xFFFF, "Comet Lake RAID Controller(0x02D7)"},
{0x8086, 0x02E0, 0xFFFF, 0xFFFF, "Comet Lake Management Engine Interface(0x02E0)"},
{0x8086, 0x02E0, 0x1028, 0x09BE, "Latitude 7410(0x1028-0x09BE)"},
{0x8086, 0x02E3, 0xFFFF, 0xFFFF, "Comet Lake AMT SOL Redirection(0x02E3)"},
{0x8086, 0x02E8, 0xFFFF, 0xFFFF, "Serial IO I2C Host Controller(0x02E8)"},
{0x8086, 0x02E8, 0x1028, 0x09BE, "Latitude 7410(0x1028-0x09BE)"},
{0x8086, 0x02E9, 0xFFFF, 0xFFFF, "Comet Lake Serial IO I2C Host Controller(0x02E9)"},
{0x8086, 0x02E9, 0x1028, 0x09BE, "Latitude 7410(0x1028-0x09BE)"},
{0x8086, 0x02EA, 0xFFFF, 0xFFFF, "Comet Lake PCH-LP LPSS: I2C Controller #2(0x02EA)"},
{0x8086, 0x02ED, 0xFFFF, 0xFFFF, "Comet Lake PCH-LP USB 3.1 xHCI Host Controller(0x02ED)"},
{0x8086, 0x02ED, 0x1028, 0x09BE, "Latitude 7410(0x1028-0x09BE)"},
{0x8086, 0x02EF, 0xFFFF, 0xFFFF, "Comet Lake PCH-LP Shared SRAM(0x02EF)"},
{0x8086, 0x02EF, 0x1028, 0x09BE, "Latitude 7410(0x1028-0x09BE)"},
{0x8086, 0x02F0, 0xFFFF, 0xFFFF, "Comet Lake PCH-LP CNVi WiFi(0x02F0)"},
{0x8086, 0x02F0, 0x8086, 0x0034, "Dual Band Wi-Fi 5(802.11ac) Wireless-AC 9560 160MHz 2x2 [Jefferson Peak](0x8086-0x0034)"},
{0x8086, 0x02F0, 0x8086, 0x0070, "Dual Band Wi-Fi 6(802.11ax) AX201 160MHz 2x2 [Harrison Peak](0x8086-0x0070)"},
{0x8086, 0x02F0, 0x8086, 0x0074, "Dual Band Wi-Fi 6(802.11ax) AX201 160MHz 2x2 [Harrison Peak](0x8086-0x0074)"},
{0x8086, 0x02F0, 0x8086, 0x0234, "Dual Band Wi-Fi 5(802.11ac) Wireless-AC 9560 80MHz 2x2 [Jefferson Peak](0x8086-0x0234)"},
{0x8086, 0x02F0, 0x8086, 0x0264, "Dual Band Wi-Fi 5(802.11ac) Wireless-AC 9461 80MHz 1x1 [Jefferson Peak](0x8086-0x0264)"},
{0x8086, 0x02F0, 0x8086, 0x02A4, "Dual Band Wi-Fi 5(802.11ac) Wireless-AC 9462 80MHz 1x1 [Jefferson Peak](0x8086-0x02A4)"},
{0x8086, 0x02F0, 0x8086, 0x4070, "Dual Band Wi-Fi 6(802.11ax) AX201 160MHz 2x2 [Harrison Peak](0x8086-0x4070)"},
{0x8086, 0x02F5, 0xFFFF, 0xFFFF, "Comet Lake PCH-LP SCS3(0x02F5)"},
{0x8086, 0x02F9, 0xFFFF, 0xFFFF, "Comet Lake Thermal Subsytem(0x02F9)"},
{0x8086, 0x02F9, 0x1028, 0x09BE, "Latitude 7410(0x1028-0x09BE)"},
{0x8086, 0x02FC, 0xFFFF, 0xFFFF, "Comet Lake Integrated Sensor Solution(0x02FC)"},
{0x8086, 0x02FC, 0x1028, 0x09BE, "Latitude 7410(0x1028-0x09BE)"},
{0x8086, 0x0309, 0xFFFF, 0xFFFF, "80303 I/O Processor PCI-to-PCI Bridge(0x0309)"},
{0x8086, 0x030D, 0xFFFF, 0xFFFF, "80312 I/O Companion Chip PCI-to-PCI Bridge(0x030D)"},
{0x8086, 0x0326, 0xFFFF, 0xFFFF, "6700/6702PXH I/OxAPIC Interrupt Controller A(0x0326)"},
{0x8086, 0x0326, 0x103C, 0x3208, "ProLiant DL140 G2(0x103C-0x3208)"},
{0x8086, 0x0326, 0x1775, 0x1100, "CR11/VR11 Single Board Computer(0x1775-0x1100)"},
{0x8086, 0x0327, 0xFFFF, 0xFFFF, "6700PXH I/OxAPIC Interrupt Controller B(0x0327)"},
{0x8086, 0x0327, 0x103C, 0x3208, "ProLiant DL140 G2(0x103C-0x3208)"},
{0x8086, 0x0327, 0x1775, 0x1100, "CR11/VR11 Single Board Computer(0x1775-0x1100)"},
{0x8086, 0x0329, 0xFFFF, 0xFFFF, "6700PXH PCI Express-to-PCI Bridge A(0x0329)"},
{0x8086, 0x032A, 0xFFFF, 0xFFFF, "6700PXH PCI Express-to-PCI Bridge B(0x032A)"},
{0x8086, 0x032C, 0xFFFF, 0xFFFF, "6702PXH PCI Express-to-PCI Bridge A(0x032C)"},
{0x8086, 0x0330, 0xFFFF, 0xFFFF, "80332 [Dobson] I/O processor (A-Segment Bridge)(0x0330)"},
{0x8086, 0x0331, 0xFFFF, 0xFFFF, "80332 [Dobson] I/O processor (A-Segment IOAPIC)(0x0331)"},
{0x8086, 0x0332, 0xFFFF, 0xFFFF, "80332 [Dobson] I/O processor (B-Segment Bridge)(0x0332)"},
{0x8086, 0x0333, 0xFFFF, 0xFFFF, "80332 [Dobson] I/O processor (B-Segment IOAPIC)(0x0333)"},
{0x8086, 0x0334, 0xFFFF, 0xFFFF, "80332 [Dobson] I/O processor (ATU)(0x0334)"},
{0x8086, 0x0335, 0xFFFF, 0xFFFF, "80331 [Lindsay] I/O processor (PCI-X Bridge)(0x0335)"},
{0x8086, 0x0336, 0xFFFF, 0xFFFF, "80331 [Lindsay] I/O processor (ATU)(0x0336)"},
{0x8086, 0x0340, 0xFFFF, 0xFFFF, "41210 [Lanai] Serial to Parallel PCI Bridge (A-Segment Bridge)(0x0340)"},
{0x8086, 0x0341, 0xFFFF, 0xFFFF, "41210 [Lanai] Serial to Parallel PCI Bridge (B-Segment Bridge)(0x0341)"},
{0x8086, 0x0370, 0xFFFF, 0xFFFF, "80333 Segment-A PCIe Express to PCI-X bridge(0x0370)"},
{0x8086, 0x0371, 0xFFFF, 0xFFFF, "80333 A-Bus IOAPIC(0x0371)"},
{0x8086, 0x0372, 0xFFFF, 0xFFFF, "80333 Segment-B PCIe Express to PCI-X bridge(0x0372)"},
{0x8086, 0x0373, 0xFFFF, 0xFFFF, "80333 B-Bus IOAPIC(0x0373)"},
{0x8086, 0x0374, 0xFFFF, 0xFFFF, "80333 Address Translation Unit(0x0374)"},
{0x8086, 0x0402, 0xFFFF, 0xFFFF, "Xeon E3-1200 v3/4th Gen Core Processor Integrated Graphics Controller(0x0402)"},
{0x8086, 0x0406, 0xFFFF, 0xFFFF, "Haswell Integrated Graphics Controller(0x0406)"},
{0x8086, 0x040A, 0xFFFF, 0xFFFF, "Xeon E3-1200 v3 Processor Integrated Graphics Controller(0x040A)"},
{0x8086, 0x0412, 0xFFFF, 0xFFFF, "Xeon E3-1200 v3/4th Gen Core Processor Integrated Graphics Controller(0x0412)"},
{0x8086, 0x0412, 0x1028, 0x05D7, "Alienware X51 R2(0x1028-0x05D7)"},
{0x8086, 0x0412, 0x103C, 0x1998, "EliteDesk 800 G1(0x103C-0x1998)"},
{0x8086, 0x0412, 0x17AA, 0x3098, "ThinkCentre E73(0x17AA-0x3098)"},
{0x8086, 0x0412, 0x17AA, 0x309F, "ThinkCentre M83(0x17AA-0x309F)"},
{0x8086, 0x0416, 0xFFFF, 0xFFFF, "4th Gen Core Processor Integrated Graphics Controller(0x0416)"},
{0x8086, 0x0416, 0x17AA, 0x220E, "ThinkPad T440p(0x17AA-0x220E)"},
{0x8086, 0x041A, 0xFFFF, 0xFFFF, "Xeon E3-1200 v3 Processor Integrated Graphics Controller(0x041A)"},
{0x8086, 0x041E, 0xFFFF, 0xFFFF, "4th Generation Core Processor Family Integrated Graphics Controller(0x041E)"},
{0x8086, 0x0434, 0xFFFF, 0xFFFF, "DH89XXCC Series QAT(0x0434)"},
{0x8086, 0x0435, 0xFFFF, 0xFFFF, "DH895XCC Series QAT(0x0435)"},
{0x8086, 0x0436, 0xFFFF, 0xFFFF, "DH8900CC Null Device(0x0436)"},
{0x8086, 0x0438, 0xFFFF, 0xFFFF, "DH8900CC Series Gigabit Network Connection(0x0438)"},
{0x8086, 0x043A, 0xFFFF, 0xFFFF, "DH8900CC Series Gigabit Fiber Network Connection(0x043A)"},
{0x8086, 0x043C, 0xFFFF, 0xFFFF, "DH8900CC Series Gigabit Backplane Network Connection(0x043C)"},
{0x8086, 0x0440, 0xFFFF, 0xFFFF, "DH8900CC Series Gigabit SFP Network Connection(0x0440)"},
{0x8086, 0x0442, 0xFFFF, 0xFFFF, "DH89XXCC Series QAT Virtual Function(0x0442)"},
{0x8086, 0x0443, 0xFFFF, 0xFFFF, "DH895XCC Series QAT Virtual Function(0x0443)"},
{0x8086, 0x0482, 0xFFFF, 0xFFFF, "82375EB/SB PCI to EISA Bridge(0x0482)"},
{0x8086, 0x0483, 0xFFFF, 0xFFFF, "82424TX/ZX [Saturn] CPU to PCI bridge(0x0483)"},
{0x8086, 0x0484, 0xFFFF, 0xFFFF, "82378ZB/IB, 82379AB (SIO, SIO.A) PCI to ISA Bridge(0x0484)"},
{0x8086, 0x0486, 0xFFFF, 0xFFFF, "82425EX/ZX [Aries] PCIset with ISA bridge(0x0486)"},
{0x8086, 0x04A3, 0xFFFF, 0xFFFF, "82434LX/NX [Mercury/Neptune] Processor to PCI bridge(0x04A3)"},
{0x8086, 0x04D0, 0xFFFF, 0xFFFF, "82437FX [Triton FX](0x04D0)"},
{0x8086, 0x0500, 0xFFFF, 0xFFFF, "E8870 Processor bus control(0x0500)"},
{0x8086, 0x0501, 0xFFFF, 0xFFFF, "E8870 Memory controller(0x0501)"},
{0x8086, 0x0502, 0xFFFF, 0xFFFF, "E8870 Scalability Port 0(0x0502)"},
{0x8086, 0x0503, 0xFFFF, 0xFFFF, "E8870 Scalability Port 1(0x0503)"},
{0x8086, 0x0510, 0xFFFF, 0xFFFF, "E8870IO Hub Interface Port 0 registers (8-bit compatibility port)(0x0510)"},
{0x8086, 0x0511, 0xFFFF, 0xFFFF, "E8870IO Hub Interface Port 1 registers(0x0511)"},
{0x8086, 0x0512, 0xFFFF, 0xFFFF, "E8870IO Hub Interface Port 2 registers(0x0512)"},
{0x8086, 0x0513, 0xFFFF, 0xFFFF, "E8870IO Hub Interface Port 3 registers(0x0513)"},
{0x8086, 0x0514, 0xFFFF, 0xFFFF, "E8870IO Hub Interface Port 4 registers(0x0514)"},
{0x8086, 0x0515, 0xFFFF, 0xFFFF, "E8870IO General SIOH registers(0x0515)"},
{0x8086, 0x0516, 0xFFFF, 0xFFFF, "E8870IO RAS registers(0x0516)"},
{0x8086, 0x0530, 0xFFFF, 0xFFFF, "E8870SP Scalability Port 0 registers(0x0530)"},
{0x8086, 0x0531, 0xFFFF, 0xFFFF, "E8870SP Scalability Port 1 registers(0x0531)"},
{0x8086, 0x0532, 0xFFFF, 0xFFFF, "E8870SP Scalability Port 2 registers(0x0532)"},
{0x8086, 0x0533, 0xFFFF, 0xFFFF, "E8870SP Scalability Port 3 registers(0x0533)"},
{0x8086, 0x0534, 0xFFFF, 0xFFFF, "E8870SP Scalability Port 4 registers(0x0534)"},
{0x8086, 0x0535, 0xFFFF, 0xFFFF, "E8870SP Scalability Port 5 registers(0x0535)"},
{0x8086, 0x0536, 0xFFFF, 0xFFFF, "E8870SP Interleave registers 0 and 1(0x0536)"},
{0x8086, 0x0537, 0xFFFF, 0xFFFF, "E8870SP Interleave registers 2 and 3(0x0537)"},
{0x8086, 0x0600, 0xFFFF, 0xFFFF, "RAID Controller(0x0600)"},
{0x8086, 0x0600, 0x8086, 0x0136, "SRCU31L(0x8086-0x0136)"},
{0x8086, 0x0600, 0x8086, 0x01AF, "SRCZCR(0x8086-0x01AF)"},
{0x8086, 0x0600, 0x8086, 0x01C1, "ICP Vortex GDT8546RZ(0x8086-0x01C1)"},
{0x8086, 0x0600, 0x8086, 0x01F7, "SCRU32(0x8086-0x01F7)"},
{0x8086, 0x061F, 0xFFFF, 0xFFFF, "80303 I/O Processor(0x061F)"},
{0x8086, 0x0684, 0xFFFF, 0xFFFF, "H470 Chipset LPC/eSPI Controller(0x0684)"},
{0x8086, 0x0685, 0xFFFF, 0xFFFF, "Z490 Chipset LPC/eSPI Controller(0x0685)"},
{0x8086, 0x0687, 0xFFFF, 0xFFFF, "Q470 Chipset LPC/eSPI Controller(0x0687)"},
{0x8086, 0x068D, 0xFFFF, 0xFFFF, "Comet Lake LPC Controller(0x068D)"},
{0x8086, 0x06A3, 0xFFFF, 0xFFFF, "Comet Lake PCH SMBus Controller(0x06A3)"},
{0x8086, 0x06A4, 0xFFFF, 0xFFFF, "Comet Lake PCH SPI Controller(0x06A4)"},
{0x8086, 0x06A8, 0xFFFF, 0xFFFF, "Comet Lake PCH Serial IO UART Host Controller #0(0x06A8)"},
{0x8086, 0x06A9, 0xFFFF, 0xFFFF, "Comet Lake PCH Serial IO UART Host Controller #1(0x06A9)"},
{0x8086, 0x06AA, 0xFFFF, 0xFFFF, "Comet Lake PCH Serial IO SPI Controller #0(0x06AA)"},
{0x8086, 0x06AB, 0xFFFF, 0xFFFF, "Comet Lake PCH Serial IO SPI Controller #1(0x06AB)"},
{0x8086, 0x06AC, 0xFFFF, 0xFFFF, "Comet Lake PCI Express Root Port #21(0x06AC)"},
{0x8086, 0x06B0, 0xFFFF, 0xFFFF, "Comet Lake PCI Express Root Port #9(0x06B0)"},
{0x8086, 0x06BA, 0xFFFF, 0xFFFF, "Comet Lake PCI Express Root Port #1(0x06BA)"},
{0x8086, 0x06BB, 0xFFFF, 0xFFFF, "Comet Lake PCI Express Root Port #4(0x06BB)"},
{0x8086, 0x06BD, 0xFFFF, 0xFFFF, "Comet Lake PCIe Port #6(0x06BD)"},
{0x8086, 0x06BF, 0xFFFF, 0xFFFF, "Comet Lake PCIe Port #8(0x06BF)"},
{0x8086, 0x06C0, 0xFFFF, 0xFFFF, "Comet Lake PCI Express Root Port #17(0x06C0)"},
{0x8086, 0x06C8, 0xFFFF, 0xFFFF, "Comet Lake PCH cAVS(0x06C8)"},
{0x8086, 0x06D2, 0xFFFF, 0xFFFF, "Comet Lake SATA AHCI Controller(0x06D2)"},
{0x8086, 0x06D6, 0xFFFF, 0xFFFF, "Comet Lake PCH-H RAID(0x06D6)"},
{0x8086, 0x06D7, 0xFFFF, 0xFFFF, "Comet Lake PCH-H RAID(0x06D7)"},
{0x8086, 0x06E0, 0xFFFF, 0xFFFF, "Comet Lake HECI Controller(0x06E0)"},
{0x8086, 0x06E3, 0xFFFF, 0xFFFF, "Comet Lake Keyboard and Text (KT) Redirection(0x06E3)"},
{0x8086, 0x06E8, 0xFFFF, 0xFFFF, "Comet Lake PCH Serial IO I2C Controller #0(0x06E8)"},
{0x8086, 0x06E9, 0xFFFF, 0xFFFF, "Comet Lake PCH Serial IO I2C Controller #1(0x06E9)"},
{0x8086, 0x06EA, 0xFFFF, 0xFFFF, "Comet Lake PCH Serial IO I2C Controller #2(0x06EA)"},
{0x8086, 0x06EB, 0xFFFF, 0xFFFF, "Comet Lake PCH Serial IO I2C Controller #3(0x06EB)"},
{0x8086, 0x06ED, 0xFFFF, 0xFFFF, "Comet Lake USB 3.1 xHCI Host Controller(0x06ED)"},
{0x8086, 0x06EF, 0xFFFF, 0xFFFF, "Comet Lake PCH Shared SRAM(0x06EF)"},
{0x8086, 0x06F0, 0xFFFF, 0xFFFF, "Comet Lake PCH CNVi WiFi(0x06F0)"},
{0x8086, 0x06F0, 0x1A56, 0x1651, "Dual Band Wi-Fi 6(802.11ax) Killer AX1650s 160MHz 2x2 [Cyclone Peak](0x1A56-0x1651)"},
{0x8086, 0x06F0, 0x1A56, 0x1652, "Dual Band Wi-Fi 6(802.11ax) Killer AX1650i 160MHz 2x2 [Cyclone Peak](0x1A56-0x1652)"},
{0x8086, 0x06F0, 0x8086, 0x0034, "Dual Band Wi-Fi 5(802.11ac) Wireless-AC 9560 160MHz 2x2 [Jefferson Peak](0x8086-0x0034)"},
{0x8086, 0x06F0, 0x8086, 0x0074, "Dual Band Wi-Fi 6(802.11ax) AX201 160MHz 2x2 [Harrison Peak](0x8086-0x0074)"},
{0x8086, 0x06F0, 0x8086, 0x02A4, "Dual Band Wi-Fi 5(802.11ac) Wireless-AC 9462 80MHz 1x1 [Jefferson Peak](0x8086-0x02A4)"},
{0x8086, 0x06F0, 0x8086, 0x42A4, "Dual Band Wi-Fi 5(802.11ac) Wireless-AC 9462 80MHz 1x1 [Jefferson Peak](0x8086-0x42A4)"},
{0x8086, 0x06F9, 0xFFFF, 0xFFFF, "Comet Lake PCH Thermal Controller(0x06F9)"},
{0x8086, 0x06FB, 0xFFFF, 0xFFFF, "Comet Lake PCH Serial IO SPI Controller #2(0x06FB)"},
{0x8086, 0x0700, 0xFFFF, 0xFFFF, "CE Media Processor A/V Bridge(0x0700)"},
{0x8086, 0x0701, 0xFFFF, 0xFFFF, "CE Media Processor NAND Flash Controller(0x0701)"},
{0x8086, 0x0703, 0xFFFF, 0xFFFF, "CE Media Processor Media Control Unit 1(0x0703)"},
{0x8086, 0x0704, 0xFFFF, 0xFFFF, "CE Media Processor Video Capture Interface(0x0704)"},
{0x8086, 0x0707, 0xFFFF, 0xFFFF, "CE Media Processor SPI Slave(0x0707)"},
{0x8086, 0x0708, 0xFFFF, 0xFFFF, "Atom Processor CE 4100(0x0708)"},
{0x8086, 0x0709, 0xFFFF, 0xFFFF, "Atom Processor CE 4200(0x0709)"},
{0x8086, 0x0800, 0xFFFF, 0xFFFF, "Moorestown SPI Ctrl 0(0x0800)"},
{0x8086, 0x0801, 0xFFFF, 0xFFFF, "Moorestown SPI Ctrl 1(0x0801)"},
{0x8086, 0x0802, 0xFFFF, 0xFFFF, "Moorestown I2C 0(0x0802)"},
{0x8086, 0x0803, 0xFFFF, 0xFFFF, "Moorestown I2C 1(0x0803)"},
{0x8086, 0x0804, 0xFFFF, 0xFFFF, "Moorestown I2C 2(0x0804)"},
{0x8086, 0x0805, 0xFFFF, 0xFFFF, "Moorestown Keyboard Ctrl(0x0805)"},
{0x8086, 0x0806, 0xFFFF, 0xFFFF, "Moorestown USB Ctrl(0x0806)"},
{0x8086, 0x0807, 0xFFFF, 0xFFFF, "Moorestown SD Host Ctrl 0(0x0807)"},
{0x8086, 0x0808, 0xFFFF, 0xFFFF, "Moorestown SD Host Ctrl 1(0x0808)"},
{0x8086, 0x0809, 0xFFFF, 0xFFFF, "Moorestown NAND Ctrl(0x0809)"},
{0x8086, 0x080A, 0xFFFF, 0xFFFF, "Moorestown Audio Ctrl(0x080A)"},
{0x8086, 0x080B, 0xFFFF, 0xFFFF, "Moorestown ISP(0x080B)"},
{0x8086, 0x080C, 0xFFFF, 0xFFFF, "Moorestown Security Controller(0x080C)"},
{0x8086, 0x080D, 0xFFFF, 0xFFFF, "Moorestown External Displays(0x080D)"},
{0x8086, 0x080E, 0xFFFF, 0xFFFF, "Moorestown SCU IPC(0x080E)"},
{0x8086, 0x080F, 0xFFFF, 0xFFFF, "Moorestown GPIO Controller(0x080F)"},
{0x8086, 0x0810, 0xFFFF, 0xFFFF, "Moorestown Power Management Unit(0x0810)"},
{0x8086, 0x0811, 0xFFFF, 0xFFFF, "Moorestown OTG Ctrl(0x0811)"},
{0x8086, 0x0812, 0xFFFF, 0xFFFF, "Moorestown SPI Ctrl 2(0x0812)"},
{0x8086, 0x0813, 0xFFFF, 0xFFFF, "Moorestown SC DMA(0x0813)"},
{0x8086, 0x0814, 0xFFFF, 0xFFFF, "Moorestown LPE DMA(0x0814)"},
{0x8086, 0x0815, 0xFFFF, 0xFFFF, "Moorestown SSP0(0x0815)"},
{0x8086, 0x0817, 0xFFFF, 0xFFFF, "Medfield Serial IO I2C Controller #3(0x0817)"},
{0x8086, 0x0818, 0xFFFF, 0xFFFF, "Medfield Serial IO I2C Controller #4(0x0818)"},
{0x8086, 0x0819, 0xFFFF, 0xFFFF, "Medfield Serial IO I2C Controller #5(0x0819)"},
{0x8086, 0x081A, 0xFFFF, 0xFFFF, "Medfield GPIO Controller [Core](0x081A)"},
{0x8086, 0x081B, 0xFFFF, 0xFFFF, "Medfield Serial IO HSUART Controller #1(0x081B)"},
{0x8086, 0x081C, 0xFFFF, 0xFFFF, "Medfield Serial IO HSUART Controller #2(0x081C)"},
{0x8086, 0x081D, 0xFFFF, 0xFFFF, "Medfield Serial IO HSUART Controller #3(0x081D)"},
{0x8086, 0x081E, 0xFFFF, 0xFFFF, "Medfield Serial IO HSUART DMA Controller(0x081E)"},
{0x8086, 0x081F, 0xFFFF, 0xFFFF, "Medfield GPIO Controller [AON](0x081F)"},
{0x8086, 0x0820, 0xFFFF, 0xFFFF, "Medfield SD Host Controller(0x0820)"},
{0x8086, 0x0821, 0xFFFF, 0xFFFF, "Medfield SDIO Controller #1(0x0821)"},
{0x8086, 0x0822, 0xFFFF, 0xFFFF, "Medfield SDIO Controller #2(0x0822)"},
{0x8086, 0x0823, 0xFFFF, 0xFFFF, "Medfield eMMC Controller #0(0x0823)"},
{0x8086, 0x0824, 0xFFFF, 0xFFFF, "Medfield eMMC Controller #1(0x0824)"},
{0x8086, 0x0827, 0xFFFF, 0xFFFF, "Medfield Serial IO DMA Controller(0x0827)"},
{0x8086, 0x0828, 0xFFFF, 0xFFFF, "Medfield Power Management Unit(0x0828)"},
{0x8086, 0x0829, 0xFFFF, 0xFFFF, "Medfield USB Device Controller (OTG)(0x0829)"},
{0x8086, 0x082A, 0xFFFF, 0xFFFF, "Medfield SCU IPC(0x082A)"},
{0x8086, 0x082C, 0xFFFF, 0xFFFF, "Medfield Serial IO I2C Controller #0(0x082C)"},
{0x8086, 0x082D, 0xFFFF, 0xFFFF, "Medfield Serial IO I2C Controller #1(0x082D)"},
{0x8086, 0x082E, 0xFFFF, 0xFFFF, "Medfield Serial IO I2C Controller #2(0x082E)"},
{0x8086, 0x0885, 0xFFFF, 0xFFFF, "Centrino Wireless-N + WiMAX 6150(0x0885)"},
{0x8086, 0x0885, 0x8086, 0x1305, "Centrino Wireless-N + WiMAX 6150 BGN(0x8086-0x1305)"},
{0x8086, 0x0885, 0x8086, 0x1307, "Centrino Wireless-N + WiMAX 6150 BG(0x8086-0x1307)"},
{0x8086, 0x0885, 0x8086, 0x1325, "Centrino Wireless-N + WiMAX 6150 BGN(0x8086-0x1325)"},
{0x8086, 0x0885, 0x8086, 0x1327, "Centrino Wireless-N + WiMAX 6150 BG(0x8086-0x1327)"},
{0x8086, 0x0886, 0xFFFF, 0xFFFF, "Centrino Wireless-N + WiMAX 6150(0x0886)"},
{0x8086, 0x0886, 0x8086, 0x1315, "Centrino Wireless-N + WiMAX 6150 BGN(0x8086-0x1315)"},
{0x8086, 0x0886, 0x8086, 0x1317, "Centrino Wireless-N + WiMAX 6150 BG(0x8086-0x1317)"},
{0x8086, 0x0887, 0xFFFF, 0xFFFF, "Centrino Wireless-N 2230(0x0887)"},
{0x8086, 0x0887, 0x8086, 0x4062, "Centrino Wireless-N 2230 BGN(0x8086-0x4062)"},
{0x8086, 0x0887, 0x8086, 0x4462, "Centrino Wireless-N 2230 BGN(0x8086-0x4462)"},
{0x8086, 0x0888, 0xFFFF, 0xFFFF, "Centrino Wireless-N 2230(0x0888)"},
{0x8086, 0x0888, 0x8086, 0x4262, "Centrino Wireless-N 2230 BGN(0x8086-0x4262)"},
{0x8086, 0x088E, 0xFFFF, 0xFFFF, "Centrino Advanced-N 6235(0x088E)"},
{0x8086, 0x088E, 0x8086, 0x4060, "Centrino Advanced-N 6235 AGN(0x8086-0x4060)"},
{0x8086, 0x088E, 0x8086, 0x4460, "Centrino Advanced-N 6235 AGN(0x8086-0x4460)"},
{0x8086, 0x088F, 0xFFFF, 0xFFFF, "Centrino Advanced-N 6235(0x088F)"},
{0x8086, 0x088F, 0x8086, 0x4260, "Centrino Advanced-N 6235 AGN(0x8086-0x4260)"},
{0x8086, 0x0890, 0xFFFF, 0xFFFF, "Centrino Wireless-N 2200(0x0890)"},
{0x8086, 0x0890, 0x8086, 0x4022, "Centrino Wireless-N 2200 BGN(0x8086-0x4022)"},
{0x8086, 0x0890, 0x8086, 0x4422, "Centrino Wireless-N 2200 BGN(0x8086-0x4422)"},
{0x8086, 0x0890, 0x8086, 0x4822, "Centrino Wireless-N 2200 BGN(0x8086-0x4822)"},
{0x8086, 0x0891, 0xFFFF, 0xFFFF, "Centrino Wireless-N 2200(0x0891)"},
{0x8086, 0x0891, 0x8086, 0x4222, "Centrino Wireless-N 2200 BGN(0x8086-0x4222)"},
{0x8086, 0x0892, 0xFFFF, 0xFFFF, "Centrino Wireless-N 135(0x0892)"},
{0x8086, 0x0892, 0x8086, 0x0062, "Centrino Wireless-N 135 BGN(0x8086-0x0062)"},
{0x8086, 0x0892, 0x8086, 0x0462, "Centrino Wireless-N 135 BGN(0x8086-0x0462)"},
{0x8086, 0x0893, 0xFFFF, 0xFFFF, "Centrino Wireless-N 135(0x0893)"},
{0x8086, 0x0893, 0x8086, 0x0262, "Centrino Wireless-N 135 BGN(0x8086-0x0262)"},
{0x8086, 0x0894, 0xFFFF, 0xFFFF, "Centrino Wireless-N 105(0x0894)"},
{0x8086, 0x0894, 0x8086, 0x0022, "Centrino Wireless-N 105 BGN(0x8086-0x0022)"},
{0x8086, 0x0894, 0x8086, 0x0422, "Centrino Wireless-N 105 BGN(0x8086-0x0422)"},
{0x8086, 0x0894, 0x8086, 0x0822, "Centrino Wireless-N 105 BGN(0x8086-0x0822)"},
{0x8086, 0x0895, 0xFFFF, 0xFFFF, "Centrino Wireless-N 105(0x0895)"},
{0x8086, 0x0895, 0x8086, 0x0222, "Centrino Wireless-N 105 BGN(0x8086-0x0222)"},
{0x8086, 0x0896, 0xFFFF, 0xFFFF, "Centrino Wireless-N 130(0x0896)"},
{0x8086, 0x0896, 0x8086, 0x5005, "Centrino Wireless-N 130 BGN(0x8086-0x5005)"},
{0x8086, 0x0896, 0x8086, 0x5007, "Centrino Wireless-N 130 BG(0x8086-0x5007)"},
{0x8086, 0x0896, 0x8086, 0x5025, "Centrino Wireless-N 130 BGN(0x8086-0x5025)"},
{0x8086, 0x0896, 0x8086, 0x5027, "Centrino Wireless-N 130 BG(0x8086-0x5027)"},
{0x8086, 0x0897, 0xFFFF, 0xFFFF, "Centrino Wireless-N 130(0x0897)"},
{0x8086, 0x0897, 0x8086, 0x5015, "Centrino Wireless-N 130 BGN(0x8086-0x5015)"},
{0x8086, 0x0897, 0x8086, 0x5017, "Centrino Wireless-N 130 BG(0x8086-0x5017)"},
{0x8086, 0x08A7, 0xFFFF, 0xFFFF, "Quark SoC X1000 SDIO / eMMC Controller(0x08A7)"},
{0x8086, 0x08AE, 0xFFFF, 0xFFFF, "Centrino Wireless-N 100(0x08AE)"},
{0x8086, 0x08AE, 0x8086, 0x1005, "Centrino Wireless-N 100 BGN(0x8086-0x1005)"},
{0x8086, 0x08AE, 0x8086, 0x1007, "Centrino Wireless-N 100 BG(0x8086-0x1007)"},
{0x8086, 0x08AE, 0x8086, 0x1025, "Centrino Wireless-N 100 BGN(0x8086-0x1025)"},
{0x8086, 0x08AE, 0x8086, 0x1027, "Centrino Wireless-N 100 BG(0x8086-0x1027)"},
{0x8086, 0x08AF, 0xFFFF, 0xFFFF, "Centrino Wireless-N 100(0x08AF)"},
{0x8086, 0x08AF, 0x8086, 0x1015, "Centrino Wireless-N 100 BGN(0x8086-0x1015)"},
{0x8086, 0x08AF, 0x8086, 0x1017, "Centrino Wireless-N 100 BG(0x8086-0x1017)"},
{0x8086, 0x08B1, 0xFFFF, 0xFFFF, "Wireless 7260(0x08B1)"},
{0x8086, 0x08B1, 0x8086, 0x4020, "Dual Band Wireless-N 7260 [Wilkins Peak 2](0x8086-0x4020)"},
{0x8086, 0x08B1, 0x8086, 0x402A, "Dual Band Wireless-N 7260 [Wilkins Peak 2](0x8086-0x402A)"},
{0x8086, 0x08B1, 0x8086, 0x4060, "Dual Band Wireless-N 7260 [Wilkins Peak 2](0x8086-0x4060)"},
{0x8086, 0x08B1, 0x8086, 0x4062, "Wireless-N 7260 [Wilkins Peak 2](0x8086-0x4062)"},
{0x8086, 0x08B1, 0x8086, 0x406A, "Dual Band Wireless-N 7260 [Wilkins Peak 2](0x8086-0x406A)"},
{0x8086, 0x08B1, 0x8086, 0x4070, "Dual Band Wireless-AC 7260 [Wilkins Peak 2](0x8086-0x4070)"},
{0x8086, 0x08B1, 0x8086, 0x4072, "Dual Band Wireless-AC 7260 [Wilkins Peak 2](0x8086-0x4072)"},
{0x8086, 0x08B1, 0x8086, 0x4160, "Dual Band Wireless-N 7260 [Wilkins Peak 2](0x8086-0x4160)"},
{0x8086, 0x08B1, 0x8086, 0x4162, "Wireless-N 7260 [Wilkins Peak 2](0x8086-0x4162)"},
{0x8086, 0x08B1, 0x8086, 0x4170, "Dual Band Wireless-AC 7260 [Wilkins Peak 2](0x8086-0x4170)"},
{0x8086, 0x08B1, 0x8086, 0x4420, "Dual Band Wireless-N 7260 [Wilkins Peak 2](0x8086-0x4420)"},
{0x8086, 0x08B1, 0x8086, 0x4460, "Dual Band Wireless-N 7260 [Wilkins Peak 2](0x8086-0x4460)"},
{0x8086, 0x08B1, 0x8086, 0x4462, "Wireless-N 7260 [Wilkins Peak 2](0x8086-0x4462)"},
{0x8086, 0x08B1, 0x8086, 0x446A, "Dual Band Wireless-N 7260 [Wilkins Peak 2](0x8086-0x446A)"},
{0x8086, 0x08B1, 0x8086, 0x4470, "Dual Band Wireless-AC 7260 [Wilkins Peak 2](0x8086-0x4470)"},
{0x8086, 0x08B1, 0x8086, 0x4472, "Dual Band Wireless-AC 7260 [Wilkins Peak 2](0x8086-0x4472)"},
{0x8086, 0x08B1, 0x8086, 0x4560, "Dual Band Wireless-N 7260 [Wilkins Peak 2](0x8086-0x4560)"},
{0x8086, 0x08B1, 0x8086, 0x4570, "Dual Band Wireless-AC 7260 [Wilkins Peak 2](0x8086-0x4570)"},
{0x8086, 0x08B1, 0x8086, 0x486E, "Dual Band Wireless-AC 7260 [Wilkins Peak 2](0x8086-0x486E)"},
{0x8086, 0x08B1, 0x8086, 0x4870, "Dual Band Wireless-AC 7260 [Wilkins Peak 2](0x8086-0x4870)"},
{0x8086, 0x08B1, 0x8086, 0x4A6C, "Dual Band Wireless-AC 7260 [Wilkins Peak 2](0x8086-0x4A6C)"},
{0x8086, 0x08B1, 0x8086, 0x4A6E, "Dual Band Wireless-AC 7260 [Wilkins Peak 2](0x8086-0x4A6E)"},
{0x8086, 0x08B1, 0x8086, 0x4A70, "Dual Band Wireless-AC 7260 [Wilkins Peak 2](0x8086-0x4A70)"},
{0x8086, 0x08B1, 0x8086, 0x4C60, "Dual Band Wireless-AC 7260 [Wilkins Peak 2](0x8086-0x4C60)"},
{0x8086, 0x08B1, 0x8086, 0x4C70, "Dual Band Wireless-AC 7260 [Wilkins Peak 2](0x8086-0x4C70)"},
{0x8086, 0x08B1, 0x8086, 0x5070, "Dual Band Wireless-AC 7260 [Wilkins Peak 2](0x8086-0x5070)"},
{0x8086, 0x08B1, 0x8086, 0x5072, "Dual Band Wireless-AC 7260 [Wilkins Peak 2](0x8086-0x5072)"},
{0x8086, 0x08B1, 0x8086, 0x5170, "Dual Band Wireless-AC 7260 [Wilkins Peak 2](0x8086-0x5170)"},
{0x8086, 0x08B1, 0x8086, 0x5770, "Dual Band Wireless-AC 7260 [Wilkins Peak 2](0x8086-0x5770)"},
{0x8086, 0x08B1, 0x8086, 0xC020, "Dual Band Wireless-N 7260 [Wilkins Peak 2](0x8086-0xC020)"},
{0x8086, 0x08B1, 0x8086, 0xC02A, "Dual Band Wireless-N 7260 [Wilkins Peak 2](0x8086-0xC02A)"},
{0x8086, 0x08B1, 0x8086, 0xC060, "Dual Band Wireless-N 7260 [Wilkins Peak 2](0x8086-0xC060)"},
{0x8086, 0x08B1, 0x8086, 0xC062, "Wireless-N 7260 [Wilkins Peak 2](0x8086-0xC062)"},
{0x8086, 0x08B1, 0x8086, 0xC06A, "Dual Band Wireless-N 7260 [Wilkins Peak 2](0x8086-0xC06A)"},
{0x8086, 0x08B1, 0x8086, 0xC070, "Dual Band Wireless-AC 7260 [Wilkins Peak 2](0x8086-0xC070)"},
{0x8086, 0x08B1, 0x8086, 0xC072, "Dual Band Wireless-AC 7260 [Wilkins Peak 2](0x8086-0xC072)"},
{0x8086, 0x08B1, 0x8086, 0xC160, "Dual Band Wireless-N 7260 [Wilkins Peak 2](0x8086-0xC160)"},
{0x8086, 0x08B1, 0x8086, 0xC162, "Wireless-N 7260 [Wilkins Peak 2](0x8086-0xC162)"},
{0x8086, 0x08B1, 0x8086, 0xC170, "Dual Band Wireless-AC 7260 [Wilkins Peak 2](0x8086-0xC170)"},
{0x8086, 0x08B1, 0x8086, 0xC360, "Dual Band Wireless-N 7260 [Wilkins Peak 2](0x8086-0xC360)"},
{0x8086, 0x08B1, 0x8086, 0xC420, "Dual Band Wireless-N 7260 [Wilkins Peak 2](0x8086-0xC420)"},
{0x8086, 0x08B1, 0x8086, 0xC460, "Dual Band Wireless-N 7260 [Wilkins Peak 2](0x8086-0xC460)"},
{0x8086, 0x08B1, 0x8086, 0xC462, "Wireless-N 7260 [Wilkins Peak 2](0x8086-0xC462)"},
{0x8086, 0x08B1, 0x8086, 0xC470, "Dual Band Wireless-AC 7260 [Wilkins Peak 2](0x8086-0xC470)"},
{0x8086, 0x08B1, 0x8086, 0xC472, "Dual Band Wireless-AC 7260 [Wilkins Peak 2](0x8086-0xC472)"},
{0x8086, 0x08B1, 0x8086, 0xC560, "Dual Band Wireless-N 7260 [Wilkins Peak 2](0x8086-0xC560)"},
{0x8086, 0x08B1, 0x8086, 0xC570, "Dual Band Wireless-AC 7260 [Wilkins Peak 2](0x8086-0xC570)"},
{0x8086, 0x08B1, 0x8086, 0xC760, "Dual Band Wireless-N 7260 [Wilkins Peak 2](0x8086-0xC760)"},
{0x8086, 0x08B1, 0x8086, 0xC770, "Dual Band Wireless-AC 7260 [Wilkins Peak 2](0x8086-0xC770)"},
{0x8086, 0x08B1, 0x8086, 0xCC60, "Dual Band Wireless-AC 7260 [Wilkins Peak 2](0x8086-0xCC60)"},
{0x8086, 0x08B1, 0x8086, 0xCC70, "Dual Band Wireless-AC 7260 [Wilkins Peak 2](0x8086-0xCC70)"},
{0x8086, 0x08B2, 0xFFFF, 0xFFFF, "Wireless 7260(0x08B2)"},
{0x8086, 0x08B2, 0x8086, 0x4220, "Dual Band Wireless-N 7260 [Wilkins Peak 2](0x8086-0x4220)"},
{0x8086, 0x08B2, 0x8086, 0x4260, "Dual Band Wireless-N 7260 [Wilkins Peak 2](0x8086-0x4260)"},
{0x8086, 0x08B2, 0x8086, 0x4262, "Wireless-N 7260 [Wilkins Peak 2](0x8086-0x4262)"},
{0x8086, 0x08B2, 0x8086, 0x426A, "Dual Band Wireless-N 7260 [Wilkins Peak 2](0x8086-0x426A)"},
{0x8086, 0x08B2, 0x8086, 0x4270, "Wireless-N 7260 [Wilkins Peak 2](0x8086-0x4270)"},
{0x8086, 0x08B2, 0x8086, 0x4272, "Dual Band Wireless-AC 7260 [Wilkins Peak 2](0x8086-0x4272)"},
{0x8086, 0x08B2, 0x8086, 0x4360, "Dual Band Wireless-N 7260 [Wilkins Peak 2](0x8086-0x4360)"},
{0x8086, 0x08B2, 0x8086, 0x4370, "Dual Band Wireless-AC 7260 [Wilkins Peak 2](0x8086-0x4370)"},
{0x8086, 0x08B2, 0x8086, 0xC220, "Dual Band Wireless-N 7260 [Wilkins Peak 2](0x8086-0xC220)"},
{0x8086, 0x08B2, 0x8086, 0xC260, "Dual Band Wireless-N 7260 [Wilkins Peak 2](0x8086-0xC260)"},
{0x8086, 0x08B2, 0x8086, 0xC262, "Wireless-N 7260 [Wilkins Peak 2](0x8086-0xC262)"},
{0x8086, 0x08B2, 0x8086, 0xC26A, "Dual Band Wireless-N 7260 [Wilkins Peak 2](0x8086-0xC26A)"},
{0x8086, 0x08B2, 0x8086, 0xC270, "Dual Band Wireless-AC 7260 [Wilkins Peak 2](0x8086-0xC270)"},
{0x8086, 0x08B2, 0x8086, 0xC272, "Dual Band Wireless-AC 7260 [Wilkins Peak 2](0x8086-0xC272)"},
{0x8086, 0x08B2, 0x8086, 0xC370, "Dual Band Wireless-AC 7260 [Wilkins Peak 2](0x8086-0xC370)"},
{0x8086, 0x08B3, 0xFFFF, 0xFFFF, "Wireless 3160(0x08B3)"},
{0x8086, 0x08B3, 0x8086, 0x0060, "Dual Band Wireless-N 3160 [Wilkins Peak 1](0x8086-0x0060)"},
{0x8086, 0x08B3, 0x8086, 0x0062, "Wireless-N 3160 [Wilkins Peak 1](0x8086-0x0062)"},
{0x8086, 0x08B3, 0x8086, 0x0070, "Dual Band Wireless-AC 3160 [Wilkins Peak 1](0x8086-0x0070)"},
{0x8086, 0x08B3, 0x8086, 0x0072, "Dual Band Wireless-AC 3160 [Wilkins Peak 1](0x8086-0x0072)"},
{0x8086, 0x08B3, 0x8086, 0x0170, "Dual Band Wireless-AC 3160 [Wilkins Peak 1](0x8086-0x0170)"},
{0x8086, 0x08B3, 0x8086, 0x0172, "Dual Band Wireless-AC 3160 [Wilkins Peak 1](0x8086-0x0172)"},
{0x8086, 0x08B3, 0x8086, 0x0260, "Dual Band Wireless-N 3160 [Wilkins Peak 1](0x8086-0x0260)"},
{0x8086, 0x08B3, 0x8086, 0x0470, "Dual Band Wireless-AC 3160 [Wilkins Peak 1](0x8086-0x0470)"},
{0x8086, 0x08B3, 0x8086, 0x0472, "Dual Band Wireless-AC 3160 [Wilkins Peak 1](0x8086-0x0472)"},
{0x8086, 0x08B3, 0x8086, 0x1070, "Dual Band Wireless-AC 3160 [Wilkins Peak 1](0x8086-0x1070)"},
{0x8086, 0x08B3, 0x8086, 0x1170, "Dual Band Wireless-AC 3160 [Wilkins Peak 1](0x8086-0x1170)"},
{0x8086, 0x08B3, 0x8086, 0x8060, "Dual Band Wireless N-3160 [Wilkins Peak 1](0x8086-0x8060)"},
{0x8086, 0x08B3, 0x8086, 0x8062, "Wireless N-3160 [Wilkins Peak 1](0x8086-0x8062)"},
{0x8086, 0x08B3, 0x8086, 0x8070, "Dual Band Wireless AC 3160 [Wilkins Peak 1](0x8086-0x8070)"},
{0x8086, 0x08B3, 0x8086, 0x8072, "Dual Band Wireless AC 3160 [Wilkins Peak 1](0x8086-0x8072)"},
{0x8086, 0x08B3, 0x8086, 0x8170, "Dual Band Wireless AC 3160 [Wilkins Peak 1](0x8086-0x8170)"},
{0x8086, 0x08B3, 0x8086, 0x8172, "Dual Band Wireless AC 3160 [Wilkins Peak 1](0x8086-0x8172)"},
{0x8086, 0x08B3, 0x8086, 0x8470, "Dual Band Wireless AC 3160 [Wilkins Peak 1](0x8086-0x8470)"},
{0x8086, 0x08B3, 0x8086, 0x8570, "Dual Band Wireless AC 3160 [Wilkins Peak 1](0x8086-0x8570)"},
{0x8086, 0x08B4, 0xFFFF, 0xFFFF, "Wireless 3160(0x08B4)"},
{0x8086, 0x08B4, 0x8086, 0x0270, "Dual Band Wireless-AC 3160 [Wilkins Peak 1](0x8086-0x0270)"},
{0x8086, 0x08B4, 0x8086, 0x0272, "Dual Band Wireless-AC 3160 [Wilkins Peak 1](0x8086-0x0272)"},
{0x8086, 0x08B4, 0x8086, 0x0370, "Dual Band Wireless-AC 3160 [Wilkins Peak 1](0x8086-0x0370)"},
{0x8086, 0x08B4, 0x8086, 0x8260, "Dual Band Wireless AC 3160 [Wilkins Peak 1](0x8086-0x8260)"},
{0x8086, 0x08B4, 0x8086, 0x8270, "Dual Band Wireless AC 3160 [Wilkins Peak 1](0x8086-0x8270)"},
{0x8086, 0x08B4, 0x8086, 0x8272, "Dual Band Wireless AC 3160 [Wilkins Peak 1](0x8086-0x8272)"},
{0x8086, 0x08B4, 0x8086, 0x8370, "Dual Band Wireless AC 3160 [Wilkins Peak 1](0x8086-0x8370)"},
{0x8086, 0x08CF, 0xFFFF, 0xFFFF, "Atom Processor Z2760 Integrated Graphics Controller(0x08CF)"},
{0x8086, 0x0931, 0xFFFF, 0xFFFF, "Atom Processor CE 2600 [Puma 6](0x0931)"},
{0x8086, 0x0934, 0xFFFF, 0xFFFF, "Quark SoC X1000 I2C Controller and GPIO Controller(0x0934)"},
{0x8086, 0x0935, 0xFFFF, 0xFFFF, "Quark SoC X1000 SPI Controller(0x0935)"},
{0x8086, 0x0936, 0xFFFF, 0xFFFF, "Quark SoC X1000 HS-UART(0x0936)"},
{0x8086, 0x0937, 0xFFFF, 0xFFFF, "Quark SoC X1000 10/100 Ethernet MAC(0x0937)"},
{0x8086, 0x0939, 0xFFFF, 0xFFFF, "Quark SoC X1000 USB EHCI Host Controller / USB 2.0 Device(0x0939)"},
{0x8086, 0x093A, 0xFFFF, 0xFFFF, "Quark SoC X1000 USB OHCI Host Controller(0x093A)"},
{0x8086, 0x0953, 0xFFFF, 0xFFFF, "PCIe Data Center SSD(0x0953)"},
{0x8086, 0x0953, 0x8086, 0x3702, "DC P3700 SSD(0x8086-0x3702)"},
{0x8086, 0x0953, 0x8086, 0x3703, "DC P3700 SSD [2.5\" SFF](0x8086-0x3703)"},
{0x8086, 0x0953, 0x8086, 0x3704, "DC P3500 SSD [Add-in Card](0x8086-0x3704)"},
{0x8086, 0x0953, 0x8086, 0x3705, "DC P3500 SSD [2.5\" SFF](0x8086-0x3705)"},
{0x8086, 0x0953, 0x8086, 0x3709, "DC P3600 SSD [Add-in Card](0x8086-0x3709)"},
{0x8086, 0x0953, 0x8086, 0x370A, "DC P3600 SSD [2.5\" SFF](0x8086-0x370A)"},
{0x8086, 0x0953, 0x8086, 0x370D, "SSD 750 Series [Add-in Card](0x8086-0x370D)"},
{0x8086, 0x0953, 0x8086, 0x370E, "SSD 750 Series [2.5\" SFF](0x8086-0x370E)"},
{0x8086, 0x0958, 0xFFFF, 0xFFFF, "Quark SoC X1000 Host Bridge(0x0958)"},
{0x8086, 0x095A, 0xFFFF, 0xFFFF, "Wireless 7265(0x095A)"},
{0x8086, 0x095A, 0x8086, 0x1010, "Dual Band Wireless-AC 7265 [Stone Peak 2 AC](0x8086-0x1010)"},
{0x8086, 0x095A, 0x8086, 0x5000, "Dual Band Wireless-N 7265 [Stone Peak 2 AGN](0x8086-0x5000)"},
{0x8086, 0x095A, 0x8086, 0x5002, "Wireless-N 7265 [Stone Peak 2 BGN](0x8086-0x5002)"},
{0x8086, 0x095A, 0x8086, 0x500A, "Dual Band Wireless-N 7265 [Stone Peak 2 AGN](0x8086-0x500A)"},
{0x8086, 0x095A, 0x8086, 0x5010, "Dual Band Wireless-AC 7265 [Stone Peak 2 AC](0x8086-0x5010)"},
{0x8086, 0x095A, 0x8086, 0x5012, "Dual Band Wireless-AC 7265 [Stone Peak 2 AC](0x8086-0x5012)"},
{0x8086, 0x095A, 0x8086, 0x5020, "Dual Band Wireless-N 7265 [Stone Peak 2 AGN](0x8086-0x5020)"},
{0x8086, 0x095A, 0x8086, 0x502A, "Dual Band Wireless-N 7265 [Stone Peak 2 AGN](0x8086-0x502A)"},
{0x8086, 0x095A, 0x8086, 0x5090, "Dual Band Wireless-AC 7265 [Maple Peak AC](0x8086-0x5090)"},
{0x8086, 0x095A, 0x8086, 0x5100, "Dual Band Wireless-AC 7265 [Stone Peak 2 AGN](0x8086-0x5100)"},
{0x8086, 0x095A, 0x8086, 0x5102, "Wireless-N 7265 [Stone Peak 2 BGN](0x8086-0x5102)"},
{0x8086, 0x095A, 0x8086, 0x510A, "Dual Band Wireless-AC 7265 [Stone Peak 2 AGN](0x8086-0x510A)"},
{0x8086, 0x095A, 0x8086, 0x5110, "Dual Band Wireless-AC 7265 [Stone Peak 2 AC](0x8086-0x5110)"},
{0x8086, 0x095A, 0x8086, 0x5112, "Dual Band Wireless-AC 7265 [Stone Peak 2 AC](0x8086-0x5112)"},
{0x8086, 0x095A, 0x8086, 0x5190, "Dual Band Wireless-AC 7265 [Maple Peak AC](0x8086-0x5190)"},
{0x8086, 0x095A, 0x8086, 0x5400, "Dual Band Wireless-AC 7265 [Stone Peak 2 AGN](0x8086-0x5400)"},
{0x8086, 0x095A, 0x8086, 0x5410, "Dual Band Wireless-AC 7265 [Stone Peak 2 AC](0x8086-0x5410)"},
{0x8086, 0x095A, 0x8086, 0x5412, "Dual Band Wireless-AC 7265 [Stone Peak 2 AC](0x8086-0x5412)"},
{0x8086, 0x095A, 0x8086, 0x5420, "Dual Band Wireless-N 7265 [Stone Peak 2 AGN](0x8086-0x5420)"},
{0x8086, 0x095A, 0x8086, 0x5490, "Dual Band Wireless-AC 7265 [Maple Peak AC](0x8086-0x5490)"},
{0x8086, 0x095A, 0x8086, 0x5510, "Dual Band Wireless-AC 7265 [Stone Peak 2 AC](0x8086-0x5510)"},
{0x8086, 0x095A, 0x8086, 0x5590, "Dual Band Wireless-AC 7265 [Maple Peak AC](0x8086-0x5590)"},
{0x8086, 0x095A, 0x8086, 0x9000, "Dual Band Wireless-AC 7265 [Stone Peak 2 AGN](0x8086-0x9000)"},
{0x8086, 0x095A, 0x8086, 0x900A, "Dual Band Wireless-AC 7265 [Stone Peak 2 AGN](0x8086-0x900A)"},
{0x8086, 0x095A, 0x8086, 0x9010, "Dual Band Wireless-AC 7265 [Stone Peak 2 AC](0x8086-0x9010)"},
{0x8086, 0x095A, 0x8086, 0x9012, "Dual Band Wireless-AC 7265 [Stone Peak 2 AC](0x8086-0x9012)"},
{0x8086, 0x095A, 0x8086, 0x9110, "Dual Band Wireless-AC 7265 [Stone Peak 2 AC](0x8086-0x9110)"},
{0x8086, 0x095A, 0x8086, 0x9112, "Dual Band Wireless-AC 7265 [Stone Peak 2 AC](0x8086-0x9112)"},
{0x8086, 0x095A, 0x8086, 0x9210, "Dual Band Wireless-AC 7265 [Stone Peak 2 AC](0x8086-0x9210)"},
{0x8086, 0x095A, 0x8086, 0x9310, "Dual Band Wireless-AC 7265 [Stone Peak 2 AC](0x8086-0x9310)"},
{0x8086, 0x095A, 0x8086, 0x9400, "Dual Band Wireless-AC 7265 [Stone Peak 2 AGN](0x8086-0x9400)"},
{0x8086, 0x095A, 0x8086, 0x9410, "Dual Band Wireless-AC 7265 [Stone Peak 2 AC](0x8086-0x9410)"},
{0x8086, 0x095A, 0x8086, 0x9510, "Dual Band Wireless-AC 7265 [Stone Peak 2 AC](0x8086-0x9510)"},
{0x8086, 0x095B, 0xFFFF, 0xFFFF, "Wireless 7265(0x095B)"},
{0x8086, 0x095B, 0x8086, 0x5200, "Dual Band Wireless-N 7265 [Stone Peak 2 AGN](0x8086-0x5200)"},
{0x8086, 0x095B, 0x8086, 0x5202, "Wireless-N 7265 [Stone Peak 2 BGN](0x8086-0x5202)"},
{0x8086, 0x095B, 0x8086, 0x520A, "Dual Band Wireless-N 7265 [Stone Peak 2 AGN](0x8086-0x520A)"},
{0x8086, 0x095B, 0x8086, 0x5210, "Dual Band Wireless-AC 7265 [Stone Peak 2 AC](0x8086-0x5210)"},
{0x8086, 0x095B, 0x8086, 0x5212, "Dual Band Wireless-AC 7265 [Stone Peak 2 AC](0x8086-0x5212)"},
{0x8086, 0x095B, 0x8086, 0x5290, "Dual Band Wireless-AC 7265 [Maple Peak AC](0x8086-0x5290)"},
{0x8086, 0x095B, 0x8086, 0x5302, "Wireless-N 7265 [Stone Peak 2 BGN](0x8086-0x5302)"},
{0x8086, 0x095B, 0x8086, 0x5310, "Dual Band Wireless-AC 7265 [Stone Peak 2 AC](0x8086-0x5310)"},
{0x8086, 0x095B, 0x8086, 0x9200, "Dual Band Wireless-AC 7265 [Stone Peak 2 AGN](0x8086-0x9200)"},
{0x8086, 0x095E, 0xFFFF, 0xFFFF, "Quark SoC X1000 Legacy Bridge(0x095E)"},
{0x8086, 0x0960, 0xFFFF, 0xFFFF, "80960RP (i960RP) Microprocessor/Bridge(0x0960)"},
{0x8086, 0x0962, 0xFFFF, 0xFFFF, "80960RM (i960RM) Bridge(0x0962)"},
{0x8086, 0x0964, 0xFFFF, 0xFFFF, "80960RP (i960RP) Microprocessor/Bridge(0x0964)"},
{0x8086, 0x0975, 0xFFFF, 0xFFFF, "Optane NVME SSD H10 with Solid State Storage [Teton Glacier](0x0975)"},
{0x8086, 0x0998, 0xFFFF, 0xFFFF, "Ice Lake IEH(0x0998)"},
{0x8086, 0x09A2, 0xFFFF, 0xFFFF, "Ice Lake Memory Map/VT-d(0x09A2)"},
{0x8086, 0x09A3, 0xFFFF, 0xFFFF, "Ice Lake RAS(0x09A3)"},
{0x8086, 0x09A4, 0xFFFF, 0xFFFF, "Ice Lake Mesh 2 PCIe(0x09A4)"},
{0x8086, 0x09A6, 0xFFFF, 0xFFFF, "Ice Lake MSM(0x09A6)"},
{0x8086, 0x09A7, 0xFFFF, 0xFFFF, "Ice Lake PMON MSM(0x09A7)"},
{0x8086, 0x09AB, 0xFFFF, 0xFFFF, "RST VMD Managed Controller(0x09AB)"},
{0x8086, 0x09AD, 0xFFFF, 0xFFFF, "Optane NVME SSD H20 with Solid State Storage [Pyramid Glacier](0x09AD)"},
{0x8086, 0x09C4, 0xFFFF, 0xFFFF, "PAC with Intel Arria 10 GX FPGA(0x09C4)"},
{0x8086, 0x0A03, 0xFFFF, 0xFFFF, "Haswell-ULT Thermal Subsystem(0x0A03)"},
{0x8086, 0x0A04, 0xFFFF, 0xFFFF, "Haswell-ULT DRAM Controller(0x0A04)"},
{0x8086, 0x0A04, 0x17AA, 0x2214, "ThinkPad X240(0x17AA-0x2214)"},
{0x8086, 0x0A06, 0xFFFF, 0xFFFF, "Haswell-ULT Integrated Graphics Controller(0x0A06)"},
{0x8086, 0x0A0C, 0xFFFF, 0xFFFF, "Haswell-ULT HD Audio Controller(0x0A0C)"},
{0x8086, 0x0A0C, 0x17AA, 0x2214, "ThinkPad X240(0x17AA-0x2214)"},
{0x8086, 0x0A16, 0xFFFF, 0xFFFF, "Haswell-ULT Integrated Graphics Controller(0x0A16)"},
{0x8086, 0x0A16, 0x17AA, 0x2214, "ThinkPad X240(0x17AA-0x2214)"},
{0x8086, 0x0A22, 0xFFFF, 0xFFFF, "Haswell-ULT Integrated Graphics Controller(0x0A22)"},
{0x8086, 0x0A26, 0xFFFF, 0xFFFF, "Haswell-ULT Integrated Graphics Controller(0x0A26)"},
{0x8086, 0x0A2A, 0xFFFF, 0xFFFF, "Haswell-ULT Integrated Graphics Controller(0x0A2A)"},
{0x8086, 0x0A2E, 0xFFFF, 0xFFFF, "Haswell-ULT Integrated Graphics Controller(0x0A2E)"},
{0x8086, 0x0A53, 0xFFFF, 0xFFFF, "DC P3520 SSD(0x0A53)"},
{0x8086, 0x0A54, 0xFFFF, 0xFFFF, "NVMe Datacenter SSD [3DNAND, Beta Rock Controller](0x0A54)"},
{0x8086, 0x0A54, 0x1028, 0x1FE1, "Express Flash NVMe 1TB 2.5\" U.2 (P4500)(0x1028-0x1FE1)"},
{0x8086, 0x0A54, 0x1028, 0x1FE2, "Express Flash NVMe 2TB 2.5\" U.2 (P4500)(0x1028-0x1FE2)"},
{0x8086, 0x0A54, 0x1028, 0x1FE3, "Express Flash NVMe 4TB 2.5\" U.2 (P4500)(0x1028-0x1FE3)"},
{0x8086, 0x0A54, 0x1028, 0x1FE4, "Express Flash NVMe 4TB HHHL AIC (P4500)(0x1028-0x1FE4)"},
{0x8086, 0x0A54, 0x1028, 0x1FEE, "Express Flash NVMe 1.6TB 2.5\" U.2 (P4610)(0x1028-0x1FEE)"},
{0x8086, 0x0A54, 0x1028, 0x1FEF, "Express Flash NVMe 3.2TB 2.5\" U.2 (P4610)(0x1028-0x1FEF)"},
{0x8086, 0x0A54, 0x1028, 0x1FF0, "Express Flash NVMe 6.4TB 2.5\" U.2 (P4610)(0x1028-0x1FF0)"},
{0x8086, 0x0A54, 0x1028, 0x1FFF, "Express Flash NVMe 8.0TB 2.5\" U.2 (P4510)(0x1028-0x1FFF)"},
{0x8086, 0x0A54, 0x1028, 0x2003, "Express Flash NVMe 1.0 TB 2.5\" U.2 (P4510)(0x1028-0x2003)"},
{0x8086, 0x0A54, 0x1028, 0x2004, "Express Flash NVMe 2.0TB 2.5\" U.2 (P4510)(0x1028-0x2004)"},
{0x8086, 0x0A54, 0x1028, 0x2005, "Express Flash NVMe 4.0TB 2.5\" U.2 (P4510)(0x1028-0x2005)"},
{0x8086, 0x0A54, 0x108E, 0x4870, "NVMe PCIe 3.0 SSD 6.4TB AIC (P4608)(0x108E-0x4870)"},
{0x8086, 0x0A54, 0x108E, 0x4871, "NVMe PCIe 3.0 SSD 6.4TB 2.5-inch (P4600)(0x108E-0x4871)"},
{0x8086, 0x0A54, 0x108E, 0x4879, "NVMe PCIe 3.0 SSD v2 6.4TB AIC (P4618)(0x108E-0x4879)"},
{0x8086, 0x0A54, 0x108E, 0x487A, "NVMe PCIe 3.0 SSD v2 6.4TB 2.5-inch (P4610)(0x108E-0x487A)"},
{0x8086, 0x0A54, 0x1137, 0x0227, "NVMe Datacenter SSD [3DNAND] 1.6TB 2.5\" U.2 (P4600)(0x1137-0x0227)"},
{0x8086, 0x0A54, 0x1137, 0x0228, "NVMe Datacenter SSD [3DNAND] 2.0TB 2.5\" U.2 (P4600)(0x1137-0x0228)"},
{0x8086, 0x0A54, 0x1137, 0x0229, "NVMe Datacenter SSD [3DNAND] 3.2TB 2.5\" U.2 (P4600)(0x1137-0x0229)"},
{0x8086, 0x0A54, 0x1137, 0x022B, "NVMe Datacenter SSD [3DNAND] 1.0TB 2.5\" U.2 (P4500)(0x1137-0x022B)"},
{0x8086, 0x0A54, 0x1137, 0x022C, "NVMe Datacenter SSD [3DNAND] 2.0TB 2.5\" U.2 (P4500)(0x1137-0x022C)"},
{0x8086, 0x0A54, 0x1137, 0x022D, "NVMe Datacenter SSD [3DNAND] 4.0TB 2.5\" U.2 (P4500)(0x1137-0x022D)"},
{0x8086, 0x0A54, 0x1137, 0x0231, "NVMe Datacenter SSD [3DNAND] 0.5TB 2.5\" U.2 (P4501)(0x1137-0x0231)"},
{0x8086, 0x0A54, 0x1137, 0x0232, "NVMe Datacenter SSD [3DNAND] 1.0TB 2.5\" U.2 (P4501)(0x1137-0x0232)"},
{0x8086, 0x0A54, 0x1137, 0x0233, "NVMe Datacenter SSD [3DNAND] 2.0TB 2.5\" U.2 (P4501)(0x1137-0x0233)"},
{0x8086, 0x0A54, 0x1137, 0x0258, "NVMe Datacenter SSD [3DNAND] 1.6TB 2.5\" U.2 (P4610)(0x1137-0x0258)"},
{0x8086, 0x0A54, 0x1137, 0x025A, "NVMe Datacenter SSD [3DNAND] 3.2TB 2.5\" U.2 (P4610)(0x1137-0x025A)"},
{0x8086, 0x0A54, 0x1137, 0x025B, "NVMe Datacenter SSD [3DNAND] 1.0TB 2.5\" U.2 (P4510)(0x1137-0x025B)"},
{0x8086, 0x0A54, 0x1137, 0x025C, "NVMe Datacenter SSD [3DNAND] 2.0TB 2.5\" U.2 (P4510)(0x1137-0x025C)"},
{0x8086, 0x0A54, 0x1137, 0x025D, "NVMe Datacenter SSD [3DNAND] 4.0TB 2.5\" U.2 (P4510)(0x1137-0x025D)"},
{0x8086, 0x0A54, 0x1137, 0x025E, "NVMe Datacenter SSD [3DNAND] 8.0TB 2.5\" U.2 (P4510)(0x1137-0x025E)"},
{0x8086, 0x0A54, 0x1590, 0x025D, "NVMe Datacenter SSD [3DNAND] 1.0TB 2.5\" U.2 (P4500)(0x1590-0x025D)"},
{0x8086, 0x0A54, 0x1590, 0x025E, "NVMe Datacenter SSD [3DNAND] 2.0TB 2.5\" U.2 (P4500)(0x1590-0x025E)"},
{0x8086, 0x0A54, 0x1590, 0x025F, "NVMe Datacenter SSD [3DNAND] 4.0TB 2.5\" U.2 (P4500)(0x1590-0x025F)"},
{0x8086, 0x0A54, 0x1590, 0x0262, "NVMe Datacenter SSD [3DNAND] 1.6TB 2.5\" U.2 (P4600)(0x1590-0x0262)"},
{0x8086, 0x0A54, 0x1590, 0x0264, "NVMe Datacenter SSD [3DNAND] 3.2TB 2.5\" U.2 (P4600)(0x1590-0x0264)"},
{0x8086, 0x0A54, 0x1590, 0x0265, "NVMe Datacenter SSD [3DNAND] 6.4TB 2.5\" U.2 (P4600)(0x1590-0x0265)"},
{0x8086, 0x0A54, 0x1590, 0x026C, "NVMe Datacenter SSD [3DNAND] 4.0TB AIC (P4500)(0x1590-0x026C)"},
{0x8086, 0x0A54, 0x1D49, 0x4702, "Thinksystem Intel P4500 NVMe U.2(0x1D49-0x4702)"},
{0x8086, 0x0A54, 0x1D49, 0x4704, "Thinksystem Intel P4500 NVMe AIC(0x1D49-0x4704)"},
{0x8086, 0x0A54, 0x1D49, 0x4712, "Thinksystem Intel P4600 NVMe U.2(0x1D49-0x4712)"},
{0x8086, 0x0A54, 0x1D49, 0x4714, "Thinksystem Intel P4600 NVMe AIC(0x1D49-0x4714)"},
{0x8086, 0x0A54, 0x1D49, 0x4802, "Thinksystem U.2 P4510 NVMe SSD(0x1D49-0x4802)"},
{0x8086, 0x0A54, 0x1D49, 0x4812, "Thinksystem U.2 P4610 NVMe SSD(0x1D49-0x4812)"},
{0x8086, 0x0A54, 0x8086, 0x4308, "SSD D5-P4320 and D5-P4326(0x8086-0x4308)"},
{0x8086, 0x0A54, 0x8086, 0x4702, "NVMe Datacenter SSD [3DNAND] SE 2.5\" U.2 (P4500)(0x8086-0x4702)"},
{0x8086, 0x0A54, 0x8086, 0x4704, "NVMe Datacenter SSD [3DNAND] SE AIC (P4500)(0x8086-0x4704)"},
{0x8086, 0x0A54, 0x8086, 0x4712, "NVMe Datacenter SSD [3DNAND] ME 2.5\" U.2 (P4600)(0x8086-0x4712)"},
{0x8086, 0x0A54, 0x8086, 0x4714, "NVMe Datacenter SSD [3DNAND] ME AIC (P4600)(0x8086-0x4714)"},
{0x8086, 0x0A54, 0x8086, 0x4802, "NVMe Datacenter SSD [3DNAND] SE 2.5\" U.2 (P4510)(0x8086-0x4802)"},
{0x8086, 0x0A54, 0x8086, 0x4804, "NVMe Datacenter SSD [3DNAND] SE AIC (P4510)(0x8086-0x4804)"},
{0x8086, 0x0A54, 0x8086, 0x4805, "NVMe Datacenter SSD [3DNAND] SE M.2 (P4511)(0x8086-0x4805)"},
{0x8086, 0x0A54, 0x8086, 0x4812, "NVMe Datacenter SSD [3DNAND] ME 2.5\" U.2 (P4610)(0x8086-0x4812)"},
{0x8086, 0x0A54, 0x8086, 0x4814, "NVMe Datacenter SSD [3DNAND] ME AIC (P4610)(0x8086-0x4814)"},
{0x8086, 0x0A55, 0xFFFF, 0xFFFF, "NVMe DC SSD [3DNAND, Beta Rock Controller](0x0A55)"},
{0x8086, 0x0A55, 0x1028, 0x1FE5, "Express Flash NVMe 1.6TB 2.5\" U.2 (P4600)(0x1028-0x1FE5)"},
{0x8086, 0x0A55, 0x1028, 0x1FE6, "Express Flash NVMe 2TB 2.5\" U.2 (P4600)(0x1028-0x1FE6)"},
{0x8086, 0x0A55, 0x1028, 0x1FE7, "Express Flash NVMe 3.2TB 2.5\" U.2 (P4600)(0x1028-0x1FE7)"},
{0x8086, 0x0A55, 0x1028, 0x1FE8, "Express Flash NVMe 2.0TB HHHL AIC (P4600)(0x1028-0x1FE8)"},
{0x8086, 0x0A55, 0x1028, 0x1FE9, "Express Flash NVMe 4.0TB HHHL AIC (P4600)(0x1028-0x1FE9)"},
{0x8086, 0x0B00, 0xFFFF, 0xFFFF, "Ice Lake CBDMA [QuickData Technology](0x0B00)"},
{0x8086, 0x0B26, 0xFFFF, 0xFFFF, "Thunderbolt 4 Bridge [Goshen Ridge 2020](0x0B26)"},
{0x8086, 0x0B27, 0xFFFF, 0xFFFF, "Thunderbolt 4 USB Controller [Goshen Ridge 2020](0x0B27)"},
{0x8086, 0x0B2B, 0xFFFF, 0xFFFF, "PAC with Intel Stratix 10 SX FPGA [FPGA PAC D5005](0x0B2B)"},
{0x8086, 0x0B60, 0xFFFF, 0xFFFF, "NVMe DC SSD [3DNAND, Sentinel Rock Controller](0x0B60)"},
{0x8086, 0x0B60, 0x1028, 0x2060, "NVMe SED MU U.2 1.6TB (P5600)(0x1028-0x2060)"},
{0x8086, 0x0B60, 0x1028, 0x2061, "NVMe SED MU U.2 3.2TB (P5600)(0x1028-0x2061)"},
{0x8086, 0x0B60, 0x1028, 0x2062, "NVMe SED MU U.2 6.4TB (P5600)(0x1028-0x2062)"},
{0x8086, 0x0B60, 0x1028, 0x2064, "NVMe SED RI U.2 1.92TB (P5500)(0x1028-0x2064)"},
{0x8086, 0x0B60, 0x1028, 0x2065, "NVMe SED RI U.2 3.84TB (P5500)(0x1028-0x2065)"},
{0x8086, 0x0B60, 0x1028, 0x2066, "NVMe SED RI U.2 7.68TB (P5500)(0x1028-0x2066)"},
{0x8086, 0x0B60, 0x1028, 0x209E, "NVMe MU U.2 1.6TB (P5600)(0x1028-0x209E)"},
{0x8086, 0x0B60, 0x1028, 0x209F, "NVMe MU U.2 3.2TB (P5600)(0x1028-0x209F)"},
{0x8086, 0x0B60, 0x1028, 0x2100, "NVMe MU U.2 6.4TB (P5600)(0x1028-0x2100)"},
{0x8086, 0x0B60, 0x1028, 0x2102, "NVMe RI U.2 1.92TB (P5500)(0x1028-0x2102)"},
{0x8086, 0x0B60, 0x1028, 0x2103, "NVMe RI U.2 3.84TB (P5500)(0x1028-0x2103)"},
{0x8086, 0x0B60, 0x1028, 0x2104, "NVMe RI U.2 7.68TB (P5500)(0x1028-0x2104)"},
{0x8086, 0x0B60, 0x1028, 0x219A, "NVMe P5316 RI 15.36TB(0x1028-0x219A)"},
{0x8086, 0x0B60, 0x1028, 0x219B, "NVMe P5316 RI 30.72TB(0x1028-0x219B)"},
{0x8086, 0x0B60, 0x1028, 0x219C, "NVMe SED P5316 RI 15.36(0x1028-0x219C)"},
{0x8086, 0x0B60, 0x1028, 0x219D, "NVMe SED P5316 RI 30.72(0x1028-0x219D)"},
{0x8086, 0x0B60, 0x1028, 0x219E, "NVMe FIPS P5316 RI 15.36TB(0x1028-0x219E)"},
{0x8086, 0x0B60, 0x1028, 0x219F, "NVMe FIPS P5316 RI 30.72(0x1028-0x219F)"},
{0x8086, 0x0B60, 0x8086, 0x8008, "NVMe Datacenter SSD [3DNAND] SE 2.5\" U.2 (P5510)(0x8086-0x8008)"},
{0x8086, 0x0B60, 0x8086, 0x8D08, "NVMe Datacenter SSD [3DNAND] VE 2.5\" U.2 (P5316)(0x8086-0x8D08)"},
{0x8086, 0x0B60, 0x8086, 0x8D1D, "NVMe Datacenter SSD [3DNAND] VE E1.L 9.5/18mm (P5316)(0x8086-0x8D1D)"},
{0x8086, 0x0B60, 0x8086, 0xC008, "NVMe Datacenter SSD [3DNAND] SE U.2 15mm (P5530)(0x8086-0xC008)"},
{0x8086, 0x0B69, 0xFFFF, 0xFFFF, "Ponte Vecchio XT (2 Tile) [Data Center GPU Max 1450](0x0B69)"},
{0x8086, 0x0B6E, 0xFFFF, 0xFFFF, "Ponte Vecchio XT (1 Tile) [Data Center GPU Max 1100C](0x0B6E)"},
{0x8086, 0x0BD0, 0xFFFF, 0xFFFF, "Ponte Vecchio XL (2 Tile)(0x0BD0)"},
{0x8086, 0x0BD4, 0xFFFF, 0xFFFF, "Ponte Vecchio XT (2 Tile) [Data Center GPU Max 1550VG](0x0BD4)"},
{0x8086, 0x0BD5, 0xFFFF, 0xFFFF, "Ponte Vecchio XT (2 Tile) [Data Center GPU Max 1550](0x0BD5)"},
{0x8086, 0x0BD6, 0xFFFF, 0xFFFF, "Ponte Vecchio XT (2 Tile) [Data Center GPU Max 1550](0x0BD6)"},
{0x8086, 0x0BD7, 0xFFFF, 0xFFFF, "Ponte Vecchio XT (2 Tile) [Data Center GPU Max 1350](0x0BD7)"},
{0x8086, 0x0BD8, 0xFFFF, 0xFFFF, "Ponte Vecchio XT (2 Tile) [Data Center GPU Max 1350](0x0BD8)"},
{0x8086, 0x0BD9, 0xFFFF, 0xFFFF, "Ponte Vecchio XT (1 Tile) [Data Center GPU Max 1100](0x0BD9)"},
{0x8086, 0x0BDA, 0xFFFF, 0xFFFF, "Ponte Vecchio XT (1 Tile) [Data Center GPU Max 1100](0x0BDA)"},
{0x8086, 0x0BDB, 0xFFFF, 0xFFFF, "Ponte Vecchio XT (1 Tile) [Data Center GPU Max 1100](0x0BDB)"},
{0x8086, 0x0BE0, 0xFFFF, 0xFFFF, "Atom Processor D2xxx/N2xxx Integrated Graphics Controller(0x0BE0)"},
{0x8086, 0x0BE1, 0xFFFF, 0xFFFF, "Atom Processor D2xxx/N2xxx Integrated Graphics Controller(0x0BE1)"},
{0x8086, 0x0BE1, 0x105B, 0x0D7C, "D270S/D250S Motherboard(0x105B-0x0D7C)"},
{0x8086, 0x0BE2, 0xFFFF, 0xFFFF, "Atom Processor D2xxx/N2xxx Integrated Graphics Controller(0x0BE2)"},
{0x8086, 0x0BE3, 0xFFFF, 0xFFFF, "Atom Processor D2xxx/N2xxx Integrated Graphics Controller(0x0BE3)"},
{0x8086, 0x0BE4, 0xFFFF, 0xFFFF, "Atom Processor D2xxx/N2xxx Integrated Graphics Controller(0x0BE4)"},
{0x8086, 0x0BE5, 0xFFFF, 0xFFFF, "Atom Processor D2xxx/N2xxx Integrated Graphics Controller(0x0BE5)"},
{0x8086, 0x0BE6, 0xFFFF, 0xFFFF, "Atom Processor D2xxx/N2xxx Integrated Graphics Controller(0x0BE6)"},
{0x8086, 0x0BE7, 0xFFFF, 0xFFFF, "Atom Processor D2xxx/N2xxx Integrated Graphics Controller(0x0BE7)"},
{0x8086, 0x0BE8, 0xFFFF, 0xFFFF, "Atom Processor D2xxx/N2xxx Integrated Graphics Controller(0x0BE8)"},
{0x8086, 0x0BE9, 0xFFFF, 0xFFFF, "Atom Processor D2xxx/N2xxx Integrated Graphics Controller(0x0BE9)"},
{0x8086, 0x0BEA, 0xFFFF, 0xFFFF, "Atom Processor D2xxx/N2xxx Integrated Graphics Controller(0x0BEA)"},
{0x8086, 0x0BEB, 0xFFFF, 0xFFFF, "Atom Processor D2xxx/N2xxx Integrated Graphics Controller(0x0BEB)"},
{0x8086, 0x0BEC, 0xFFFF, 0xFFFF, "Atom Processor D2xxx/N2xxx Integrated Graphics Controller(0x0BEC)"},
{0x8086, 0x0BED, 0xFFFF, 0xFFFF, "Atom Processor D2xxx/N2xxx Integrated Graphics Controller(0x0BED)"},
{0x8086, 0x0BEE, 0xFFFF, 0xFFFF, "Atom Processor D2xxx/N2xxx Integrated Graphics Controller(0x0BEE)"},
{0x8086, 0x0BEF, 0xFFFF, 0xFFFF, "Atom Processor D2xxx/N2xxx Integrated Graphics Controller(0x0BEF)"},
{0x8086, 0x0BF0, 0xFFFF, 0xFFFF, "Atom Processor D2xxx/N2xxx DRAM Controller(0x0BF0)"},
{0x8086, 0x0BF1, 0xFFFF, 0xFFFF, "Atom Processor D2xxx/N2xxx DRAM Controller(0x0BF1)"},
{0x8086, 0x0BF2, 0xFFFF, 0xFFFF, "Atom Processor D2xxx/N2xxx DRAM Controller(0x0BF2)"},
{0x8086, 0x0BF3, 0xFFFF, 0xFFFF, "Atom Processor D2xxx/N2xxx DRAM Controller(0x0BF3)"},
{0x8086, 0x0BF4, 0xFFFF, 0xFFFF, "Atom Processor D2xxx/N2xxx DRAM Controller(0x0BF4)"},
{0x8086, 0x0BF5, 0xFFFF, 0xFFFF, "Atom Processor D2xxx/N2xxx DRAM Controller(0x0BF5)"},
{0x8086, 0x0BF5, 0x105B, 0x0D7C, "D270S/D250S Motherboard(0x105B-0x0D7C)"},
{0x8086, 0x0BF6, 0xFFFF, 0xFFFF, "Atom Processor D2xxx/N2xxx DRAM Controller(0x0BF6)"},
{0x8086, 0x0BF7, 0xFFFF, 0xFFFF, "Atom Processor D2xxx/N2xxx DRAM Controller(0x0BF7)"},
{0x8086, 0x0C00, 0xFFFF, 0xFFFF, "4th Gen Core Processor DRAM Controller(0x0C00)"},
{0x8086, 0x0C00, 0x1028, 0x05D7, "Alienware X51 R2(0x1028-0x05D7)"},
{0x8086, 0x0C00, 0x103C, 0x1998, "EliteDesk 800 G1(0x103C-0x1998)"},
{0x8086, 0x0C00, 0x17AA, 0x3098, "ThinkCentre E73(0x17AA-0x3098)"},
{0x8086, 0x0C00, 0x17AA, 0x309F, "ThinkCentre M83(0x17AA-0x309F)"},
{0x8086, 0x0C01, 0xFFFF, 0xFFFF, "Xeon E3-1200 v3/4th Gen Core Processor PCI Express x16 Controller(0x0C01)"},
{0x8086, 0x0C04, 0xFFFF, 0xFFFF, "Xeon E3-1200 v3/4th Gen Core Processor DRAM Controller(0x0C04)"},
{0x8086, 0x0C04, 0x103C, 0x1909, "ZBook 15(0x103C-0x1909)"},
{0x8086, 0x0C04, 0x17AA, 0x220E, "ThinkPad T440p(0x17AA-0x220E)"},
{0x8086, 0x0C05, 0xFFFF, 0xFFFF, "Xeon E3-1200 v3/4th Gen Core Processor PCI Express x8 Controller(0x0C05)"},
{0x8086, 0x0C08, 0xFFFF, 0xFFFF, "Xeon E3-1200 v3 Processor DRAM Controller(0x0C08)"},
{0x8086, 0x0C09, 0xFFFF, 0xFFFF, "Xeon E3-1200 v3/4th Gen Core Processor PCI Express x4 Controller(0x0C09)"},
{0x8086, 0x0C0C, 0xFFFF, 0xFFFF, "Xeon E3-1200 v3/4th Gen Core Processor HD Audio Controller(0x0C0C)"},
{0x8086, 0x0C0C, 0x103C, 0x1998, "EliteDesk 800 G1(0x103C-0x1998)"},
{0x8086, 0x0C0C, 0x17AA, 0x220E, "ThinkPad T440p(0x17AA-0x220E)"},
{0x8086, 0x0C0C, 0x17AA, 0x309F, "ThinkCentre M83(0x17AA-0x309F)"},
{0x8086, 0x0C40, 0xFFFF, 0xFFFF, "Atom Processor CE 5300(0x0C40)"},
{0x8086, 0x0C46, 0xFFFF, 0xFFFF, "Atom Processor S1200 PCI Express Root Port 1(0x0C46)"},
{0x8086, 0x0C47, 0xFFFF, 0xFFFF, "Atom Processor S1200 PCI Express Root Port 2(0x0C47)"},
{0x8086, 0x0C48, 0xFFFF, 0xFFFF, "Atom Processor S1200 PCI Express Root Port 3(0x0C48)"},
{0x8086, 0x0C49, 0xFFFF, 0xFFFF, "Atom Processor S1200 PCI Express Root Port 4(0x0C49)"},
{0x8086, 0x0C4E, 0xFFFF, 0xFFFF, "Atom Processor S1200 NTB Primary(0x0C4E)"},
{0x8086, 0x0C50, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D QuickData Technology Device(0x0C50)"},
{0x8086, 0x0C51, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D QuickData Technology Device(0x0C51)"},
{0x8086, 0x0C52, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D QuickData Technology Device(0x0C52)"},
{0x8086, 0x0C53, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D QuickData Technology Device(0x0C53)"},
{0x8086, 0x0C54, 0xFFFF, 0xFFFF, "Atom Processor S1200 Internal(0x0C54)"},
{0x8086, 0x0C55, 0xFFFF, 0xFFFF, "Atom Processor S1200 DFX 1(0x0C55)"},
{0x8086, 0x0C56, 0xFFFF, 0xFFFF, "Atom Processor S1200 DFX 2(0x0C56)"},
{0x8086, 0x0C59, 0xFFFF, 0xFFFF, "Atom Processor S1200 SMBus 2.0 Controller 0(0x0C59)"},
{0x8086, 0x0C5A, 0xFFFF, 0xFFFF, "Atom Processor S1200 SMBus 2.0 Controller 1(0x0C5A)"},
{0x8086, 0x0C5B, 0xFFFF, 0xFFFF, "Atom Processor S1200 SMBus Controller 2(0x0C5B)"},
{0x8086, 0x0C5C, 0xFFFF, 0xFFFF, "Atom Processor S1200 SMBus Controller 3(0x0C5C)"},
{0x8086, 0x0C5D, 0xFFFF, 0xFFFF, "Atom Processor S1200 SMBus Controller 4(0x0C5D)"},
{0x8086, 0x0C5E, 0xFFFF, 0xFFFF, "Atom Processor S1200 SMBus Controller 5(0x0C5E)"},
{0x8086, 0x0C5F, 0xFFFF, 0xFFFF, "Atom Processor S1200 UART(0x0C5F)"},
{0x8086, 0x0C60, 0xFFFF, 0xFFFF, "Atom Processor S1200 Integrated Legacy Bus(0x0C60)"},
{0x8086, 0x0C70, 0xFFFF, 0xFFFF, "Atom Processor S1200 Internal(0x0C70)"},
{0x8086, 0x0C71, 0xFFFF, 0xFFFF, "Atom Processor S1200 Internal(0x0C71)"},
{0x8086, 0x0C72, 0xFFFF, 0xFFFF, "Atom Processor S1200 Internal(0x0C72)"},
{0x8086, 0x0C73, 0xFFFF, 0xFFFF, "Atom Processor S1200 Internal(0x0C73)"},
{0x8086, 0x0C74, 0xFFFF, 0xFFFF, "Atom Processor S1200 Internal(0x0C74)"},
{0x8086, 0x0C75, 0xFFFF, 0xFFFF, "Atom Processor S1200 Internal(0x0C75)"},
{0x8086, 0x0C76, 0xFFFF, 0xFFFF, "Atom Processor S1200 Internal(0x0C76)"},
{0x8086, 0x0C77, 0xFFFF, 0xFFFF, "Atom Processor S1200 Internal(0x0C77)"},
{0x8086, 0x0C78, 0xFFFF, 0xFFFF, "Atom Processor S1200 Internal(0x0C78)"},
{0x8086, 0x0C79, 0xFFFF, 0xFFFF, "Atom Processor S1200 Internal(0x0C79)"},
{0x8086, 0x0C7A, 0xFFFF, 0xFFFF, "Atom Processor S1200 Internal(0x0C7A)"},
{0x8086, 0x0C7B, 0xFFFF, 0xFFFF, "Atom Processor S1200 Internal(0x0C7B)"},
{0x8086, 0x0C7C, 0xFFFF, 0xFFFF, "Atom Processor S1200 Internal(0x0C7C)"},
{0x8086, 0x0C7D, 0xFFFF, 0xFFFF, "Atom Processor S1200 Internal(0x0C7D)"},
{0x8086, 0x0C7E, 0xFFFF, 0xFFFF, "Atom Processor S1200 Internal(0x0C7E)"},
{0x8086, 0x0C7F, 0xFFFF, 0xFFFF, "Atom Processor S1200 Internal(0x0C7F)"},
{0x8086, 0x0CF8, 0xFFFF, 0xFFFF, "Ethernet Controller X710 Intel(R) FPGA Programmable Acceleration Card N3000 for Networking(0x0CF8)"},
{0x8086, 0x0CF8, 0x8086, 0x0000, "Ethernet Controller X710 Intel(R) FPGA Programmable Acceleration Card N3000 for Networking(0x8086-0x0000)"},
{0x8086, 0x0CF8, 0x8086, 0x0001, "Ethernet Controller X710 Intel(R) FPGA Programmable Acceleration Card N3000 for Networking(0x8086-0x0001)"},
{0x8086, 0x0D00, 0xFFFF, 0xFFFF, "Crystal Well DRAM Controller(0x0D00)"},
{0x8086, 0x0D01, 0xFFFF, 0xFFFF, "Crystal Well PCI Express x16 Controller(0x0D01)"},
{0x8086, 0x0D04, 0xFFFF, 0xFFFF, "Crystal Well DRAM Controller(0x0D04)"},
{0x8086, 0x0D05, 0xFFFF, 0xFFFF, "Crystal Well PCI Express x8 Controller(0x0D05)"},
{0x8086, 0x0D09, 0xFFFF, 0xFFFF, "Crystal Well PCI Express x4 Controller(0x0D09)"},
{0x8086, 0x0D0C, 0xFFFF, 0xFFFF, "Crystal Well HD Audio Controller(0x0D0C)"},
{0x8086, 0x0D16, 0xFFFF, 0xFFFF, "Crystal Well Integrated Graphics Controller(0x0D16)"},
{0x8086, 0x0D26, 0xFFFF, 0xFFFF, "Crystal Well Integrated Graphics Controller(0x0D26)"},
{0x8086, 0x0D36, 0xFFFF, 0xFFFF, "Crystal Well Integrated Graphics Controller(0x0D36)"},
{0x8086, 0x0D4C, 0xFFFF, 0xFFFF, "Ethernet Connection (11) I219-LM(0x0D4C)"},
{0x8086, 0x0D4D, 0xFFFF, 0xFFFF, "Ethernet Connection (11) I219-V(0x0D4D)"},
{0x8086, 0x0D4D, 0x8086, 0x0D4D, "Ethernet Connection (11) I219-V(0x8086-0x0D4D)"},
{0x8086, 0x0D4E, 0xFFFF, 0xFFFF, "Ethernet Connection (10) I219-LM(0x0D4E)"},
{0x8086, 0x0D4F, 0xFFFF, 0xFFFF, "Ethernet Connection (10) I219-V(0x0D4F)"},
{0x8086, 0x0D53, 0xFFFF, 0xFFFF, "Ethernet Connection (12) I219-LM(0x0D53)"},
{0x8086, 0x0D55, 0xFFFF, 0xFFFF, "Ethernet Connection (12) I219-V(0x0D55)"},
{0x8086, 0x0D58, 0xFFFF, 0xFFFF, "Ethernet Controller XXV710 Intel(R) FPGA Programmable Acceleration Card N3000 for Networking(0x0D58)"},
{0x8086, 0x0D58, 0x8086, 0x0000, "Ethernet Controller XXV710 Intel(R) FPGA Programmable Acceleration Card N3000 for Networking(0x8086-0x0000)"},
{0x8086, 0x0D58, 0x8086, 0x0001, "Ethernet Controller XXV710 Intel(R) FPGA Programmable Acceleration Card N3000 for Networking(0x8086-0x0001)"},
{0x8086, 0x0D9F, 0xFFFF, 0xFFFF, "Ethernet Controller I225-IT(0x0D9F)"},
{0x8086, 0x0DC5, 0xFFFF, 0xFFFF, "Ethernet Connection (23) I219-LM(0x0DC5)"},
{0x8086, 0x0DC5, 0x1028, 0x0C06, "Precision 3580(0x1028-0x0C06)"},
{0x8086, 0x0DC6, 0xFFFF, 0xFFFF, "Ethernet Connection (23) I219-V(0x0DC6)"},
{0x8086, 0x0DCD, 0xFFFF, 0xFFFF, "Ethernet Connection C825-X(0x0DCD)"},
{0x8086, 0x0DD2, 0xFFFF, 0xFFFF, "Ethernet Network Adapter I710(0x0DD2)"},
{0x8086, 0x0DD2, 0x1137, 0x0000, "I710T4LG 4x1 GbE RJ45 PCIe NIC(0x1137-0x0000)"},
{0x8086, 0x0DD2, 0x1137, 0x02E3, "I710T4LG 4x1 GbE RJ45 PCIe NIC(0x1137-0x02E3)"},
{0x8086, 0x0DD2, 0x8086, 0x0000, "Ethernet Network Adapter I710-T4L(0x8086-0x0000)"},
{0x8086, 0x0DD2, 0x8086, 0x000D, "Ethernet Network Adapter I710-T4L(0x8086-0x000D)"},
{0x8086, 0x0DD2, 0x8086, 0x0010, "Ethernet Network Adapter I710-T4L for OCP 3.0(0x8086-0x0010)"},
{0x8086, 0x0DD2, 0x8086, 0x401A, "Ethernet Network Adapter I710-T4L(0x8086-0x401A)"},
{0x8086, 0x0DD2, 0x8086, 0x401B, "Ethernet Network Adapter I710-T4L for OCP 3.0(0x8086-0x401B)"},
{0x8086, 0x0DD5, 0xFFFF, 0xFFFF, "Ethernet Adaptive Virtual Function(0x0DD5)"},
{0x8086, 0x0DDA, 0xFFFF, 0xFFFF, "Ethernet Connection X722 for 10GbE SFP+(0x0DDA)"},
{0x8086, 0x0DDA, 0x1BD4, 0x0076, "Ethernet Connection F102IX722 for 10GbE SFP(0x1BD4-0x0076)"},
{0x8086, 0x0DDA, 0x1BD4, 0x0082, "Ethernet Connection F102IX722 for 10GbE SFP(0x1BD4-0x0082)"},
{0x8086, 0x0E00, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 DMI2(0x0E00)"},
{0x8086, 0x0E00, 0x1028, 0x04F7, "Xeon E5 v2 on PowerEdge R320 server(0x1028-0x04F7)"},
{0x8086, 0x0E00, 0x15D9, 0x066B, "X9SRL-F(0x15D9-0x066B)"},
{0x8086, 0x0E01, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 PCI Express Root Port in DMI2 Mode(0x0E01)"},
{0x8086, 0x0E02, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 PCI Express Root Port 1a(0x0E02)"},
{0x8086, 0x0E02, 0x1028, 0x04F7, "Xeon E5 v2 on PowerEdge R320 server(0x1028-0x04F7)"},
{0x8086, 0x0E03, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 PCI Express Root Port 1b(0x0E03)"},
{0x8086, 0x0E04, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 PCI Express Root Port 2a(0x0E04)"},
{0x8086, 0x0E05, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 PCI Express Root Port 2b(0x0E05)"},
{0x8086, 0x0E06, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 PCI Express Root Port 2c(0x0E06)"},
{0x8086, 0x0E07, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 PCI Express Root Port 2d(0x0E07)"},
{0x8086, 0x0E08, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 PCI Express Root Port 3a(0x0E08)"},
{0x8086, 0x0E08, 0x1028, 0x04F7, "Xeon E5 v2 on PowerEdge R320 server(0x1028-0x04F7)"},
{0x8086, 0x0E09, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 PCI Express Root Port 3b(0x0E09)"},
{0x8086, 0x0E0A, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 PCI Express Root Port 3c(0x0E0A)"},
{0x8086, 0x0E0B, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 PCI Express Root Port 3d(0x0E0B)"},
{0x8086, 0x0E10, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 IIO Configuration Registers(0x0E10)"},
{0x8086, 0x0E13, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 IIO Configuration Registers(0x0E13)"},
{0x8086, 0x0E17, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 IIO Configuration Registers(0x0E17)"},
{0x8086, 0x0E18, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 IIO Configuration Registers(0x0E18)"},
{0x8086, 0x0E1C, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 IIO Configuration Registers(0x0E1C)"},
{0x8086, 0x0E1D, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 R2PCIe(0x0E1D)"},
{0x8086, 0x0E1E, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 UBOX Registers(0x0E1E)"},
{0x8086, 0x0E1F, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 UBOX Registers(0x0E1F)"},
{0x8086, 0x0E20, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Crystal Beach DMA Channel 0(0x0E20)"},
{0x8086, 0x0E20, 0x1028, 0x04F7, "Xeon E5 v2 on PowerEdge R320 server(0x1028-0x04F7)"},
{0x8086, 0x0E20, 0x15D9, 0x066B, "X9SRL-F(0x15D9-0x066B)"},
{0x8086, 0x0E21, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Crystal Beach DMA Channel 1(0x0E21)"},
{0x8086, 0x0E21, 0x1028, 0x04F7, "Xeon E5 v2 on PowerEdge R320 server(0x1028-0x04F7)"},
{0x8086, 0x0E21, 0x15D9, 0x066B, "X9SRL-F(0x15D9-0x066B)"},
{0x8086, 0x0E22, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Crystal Beach DMA Channel 2(0x0E22)"},
{0x8086, 0x0E22, 0x1028, 0x04F7, "Xeon E5 v2 on PowerEdge R320 server(0x1028-0x04F7)"},
{0x8086, 0x0E22, 0x15D9, 0x066B, "X9SRL-F(0x15D9-0x066B)"},
{0x8086, 0x0E23, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Crystal Beach DMA Channel 3(0x0E23)"},
{0x8086, 0x0E23, 0x1028, 0x04F7, "Xeon E5 v2 on PowerEdge R320 server(0x1028-0x04F7)"},
{0x8086, 0x0E23, 0x15D9, 0x066B, "X9SRL-F(0x15D9-0x066B)"},
{0x8086, 0x0E24, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Crystal Beach DMA Channel 4(0x0E24)"},
{0x8086, 0x0E24, 0x1028, 0x04F7, "Xeon E5 v2 on PowerEdge R320 server(0x1028-0x04F7)"},
{0x8086, 0x0E24, 0x15D9, 0x066B, "X9SRL-F(0x15D9-0x066B)"},
{0x8086, 0x0E25, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Crystal Beach DMA Channel 5(0x0E25)"},
{0x8086, 0x0E25, 0x1028, 0x04F7, "Xeon E5 v2 on PowerEdge R320 server(0x1028-0x04F7)"},
{0x8086, 0x0E25, 0x15D9, 0x066B, "X9SRL-F(0x15D9-0x066B)"},
{0x8086, 0x0E26, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Crystal Beach DMA Channel 6(0x0E26)"},
{0x8086, 0x0E26, 0x1028, 0x04F7, "Xeon E5 v2 on PowerEdge R320 server(0x1028-0x04F7)"},
{0x8086, 0x0E26, 0x15D9, 0x066B, "X9SRL-F(0x15D9-0x066B)"},
{0x8086, 0x0E27, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Crystal Beach DMA Channel 7(0x0E27)"},
{0x8086, 0x0E27, 0x1028, 0x04F7, "Xeon E5 v2 on PowerEdge R320 server(0x1028-0x04F7)"},
{0x8086, 0x0E27, 0x15D9, 0x066B, "X9SRL-F(0x15D9-0x066B)"},
{0x8086, 0x0E28, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 VTd/Memory Map/Misc(0x0E28)"},
{0x8086, 0x0E28, 0x1028, 0x04F7, "Xeon E5 v2 on PowerEdge R320 server(0x1028-0x04F7)"},
{0x8086, 0x0E28, 0x15D9, 0x066B, "X9SRL-F(0x15D9-0x066B)"},
{0x8086, 0x0E29, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Memory Hotplug(0x0E29)"},
{0x8086, 0x0E2A, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 IIO RAS(0x0E2A)"},
{0x8086, 0x0E2A, 0x1028, 0x04F7, "Xeon E5 v2 on PowerEdge R320 server(0x1028-0x04F7)"},
{0x8086, 0x0E2A, 0x15D9, 0x066B, "X9SRL-F(0x15D9-0x066B)"},
{0x8086, 0x0E2C, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 IOAPIC(0x0E2C)"},
{0x8086, 0x0E2C, 0x15D9, 0x066B, "X9SRL-F(0x15D9-0x066B)"},
{0x8086, 0x0E2E, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 CBDMA(0x0E2E)"},
{0x8086, 0x0E2F, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 CBDMA(0x0E2F)"},
{0x8086, 0x0E30, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Home Agent 0(0x0E30)"},
{0x8086, 0x0E30, 0x1028, 0x04F7, "Xeon E5 v2 on PowerEdge R320 server(0x1028-0x04F7)"},
{0x8086, 0x0E32, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 QPI Link 0(0x0E32)"},
{0x8086, 0x0E33, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 QPI Link 1(0x0E33)"},
{0x8086, 0x0E34, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 R2PCIe(0x0E34)"},
{0x8086, 0x0E34, 0x1028, 0x04F7, "Xeon E5 v2 on PowerEdge R320 server(0x1028-0x04F7)"},
{0x8086, 0x0E36, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 QPI Ring Performance Ring Monitoring(0x0E36)"},
{0x8086, 0x0E36, 0x1028, 0x04F7, "Xeon E5 v2 on PowerEdge R320 server(0x1028-0x04F7)"},
{0x8086, 0x0E37, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 QPI Ring Performance Ring Monitoring(0x0E37)"},
{0x8086, 0x0E38, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Home Agent 1(0x0E38)"},
{0x8086, 0x0E3A, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 QPI Link 2(0x0E3A)"},
{0x8086, 0x0E3E, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 QPI Ring Performance Ring Monitoring(0x0E3E)"},
{0x8086, 0x0E3F, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 QPI Ring Performance Ring Monitoring(0x0E3F)"},
{0x8086, 0x0E40, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 QPI Link 2(0x0E40)"},
{0x8086, 0x0E41, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 QPI Ring Registers(0x0E41)"},
{0x8086, 0x0E43, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 QPI Link Reut 2(0x0E43)"},
{0x8086, 0x0E44, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 QPI Link Reut 2(0x0E44)"},
{0x8086, 0x0E45, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 QPI Link Agent Register(0x0E45)"},
{0x8086, 0x0E47, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 QPI Link Agent Register(0x0E47)"},
{0x8086, 0x0E60, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Home Agent 1(0x0E60)"},
{0x8086, 0x0E68, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Integrated Memory Controller 1 Target Address/Thermal Registers(0x0E68)"},
{0x8086, 0x0E6A, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Integrated Memory Controller 1 Channel Target Address Decoder Registers(0x0E6A)"},
{0x8086, 0x0E6B, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Integrated Memory Controller 1 Channel Target Address Decoder Registers(0x0E6B)"},
{0x8086, 0x0E6C, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Integrated Memory Controller 1 Channel Target Address Decoder Registers(0x0E6C)"},
{0x8086, 0x0E6D, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Integrated Memory Controller 1 Channel Target Address Decoder Registers(0x0E6D)"},
{0x8086, 0x0E71, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Integrated Memory Controller 0 RAS Registers(0x0E71)"},
{0x8086, 0x0E74, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 R2PCIe(0x0E74)"},
{0x8086, 0x0E75, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 R2PCIe(0x0E75)"},
{0x8086, 0x0E77, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 QPI Ring Registers(0x0E77)"},
{0x8086, 0x0E79, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Integrated Memory Controller 1 RAS Registers(0x0E79)"},
{0x8086, 0x0E7D, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 UBOX Registers(0x0E7D)"},
{0x8086, 0x0E7F, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 QPI Ring Registers(0x0E7F)"},
{0x8086, 0x0E80, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 QPI Link 0(0x0E80)"},
{0x8086, 0x0E81, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 QPI Ring Registers(0x0E81)"},
{0x8086, 0x0E81, 0x1028, 0x04F7, "Xeon E5 v2 on PowerEdge R320 server(0x1028-0x04F7)"},
{0x8086, 0x0E83, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 QPI Link Reut 0(0x0E83)"},
{0x8086, 0x0E84, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 QPI Link Reut 0(0x0E84)"},
{0x8086, 0x0E85, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 QPI Link Agent Register(0x0E85)"},
{0x8086, 0x0E87, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 QPI Registers(0x0E87)"},
{0x8086, 0x0E90, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 QPI Link 1(0x0E90)"},
{0x8086, 0x0E93, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 QPI Link 1(0x0E93)"},
{0x8086, 0x0E94, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 QPI Link Reut 1(0x0E94)"},
{0x8086, 0x0E95, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 QPI Link Agent Register(0x0E95)"},
{0x8086, 0x0EA0, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Home Agent 0(0x0EA0)"},
{0x8086, 0x0EA0, 0x1028, 0x04F7, "Xeon E5 v2 on PowerEdge R320 server(0x1028-0x04F7)"},
{0x8086, 0x0EA8, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Integrated Memory Controller 0 Target Address/Thermal Registers(0x0EA8)"},
{0x8086, 0x0EAA, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Integrated Memory Controller 0 Channel Target Address Decoder Registers(0x0EAA)"},
{0x8086, 0x0EAB, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Integrated Memory Controller 0 Channel Target Address Decoder Registers(0x0EAB)"},
{0x8086, 0x0EAC, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Integrated Memory Controller 0 Channel Target Address Decoder Registers(0x0EAC)"},
{0x8086, 0x0EAD, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Integrated Memory Controller 0 Channel Target Address Decoder Registers(0x0EAD)"},
{0x8086, 0x0EAE, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 DDRIO Registers(0x0EAE)"},
{0x8086, 0x0EAF, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 DDRIO Registers(0x0EAF)"},
{0x8086, 0x0EB0, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Integrated Memory Controller 1 Channel 0-3 Thermal Control 0(0x0EB0)"},
{0x8086, 0x0EB1, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Integrated Memory Controller 1 Channel 0-3 Thermal Control 1(0x0EB1)"},
{0x8086, 0x0EB2, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Integrated Memory Controller 1 Channel 0-3 ERROR Registers 0(0x0EB2)"},
{0x8086, 0x0EB3, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Integrated Memory Controller 1 Channel 0-3 ERROR Registers 1(0x0EB3)"},
{0x8086, 0x0EB4, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Integrated Memory Controller 1 Channel 0-3 Thermal Control 2(0x0EB4)"},
{0x8086, 0x0EB5, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Integrated Memory Controller 1 Channel 0-3 Thermal Control 3(0x0EB5)"},
{0x8086, 0x0EB6, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Integrated Memory Controller 1 Channel 0-3 ERROR Registers 2(0x0EB6)"},
{0x8086, 0x0EB7, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Integrated Memory Controller 1 Channel 0-3 ERROR Registers 3(0x0EB7)"},
{0x8086, 0x0EBC, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 DDRIO Registers(0x0EBC)"},
{0x8086, 0x0EBE, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 DDRIO Registers(0x0EBE)"},
{0x8086, 0x0EBF, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 DDRIO Registers(0x0EBF)"},
{0x8086, 0x0EC0, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Power Control Unit 0(0x0EC0)"},
{0x8086, 0x0EC1, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Power Control Unit 1(0x0EC1)"},
{0x8086, 0x0EC2, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Power Control Unit 2(0x0EC2)"},
{0x8086, 0x0EC3, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Power Control Unit 3(0x0EC3)"},
{0x8086, 0x0EC4, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Power Control Unit 4(0x0EC4)"},
{0x8086, 0x0EC8, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 System Address Decoder(0x0EC8)"},
{0x8086, 0x0EC9, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Broadcast Registers(0x0EC9)"},
{0x8086, 0x0ECA, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Broadcast Registers(0x0ECA)"},
{0x8086, 0x0ED8, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 DDRIO(0x0ED8)"},
{0x8086, 0x0ED9, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 DDRIO(0x0ED9)"},
{0x8086, 0x0EDC, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 DDRIO(0x0EDC)"},
{0x8086, 0x0EDD, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 DDRIO(0x0EDD)"},
{0x8086, 0x0EDE, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 DDRIO(0x0EDE)"},
{0x8086, 0x0EDF, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 DDRIO(0x0EDF)"},
{0x8086, 0x0EE0, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Unicast Registers(0x0EE0)"},
{0x8086, 0x0EE1, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Unicast Registers(0x0EE1)"},
{0x8086, 0x0EE2, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Unicast Registers(0x0EE2)"},
{0x8086, 0x0EE3, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Unicast Registers(0x0EE3)"},
{0x8086, 0x0EE4, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Unicast Registers(0x0EE4)"},
{0x8086, 0x0EE5, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Unicast Registers(0x0EE5)"},
{0x8086, 0x0EE6, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Unicast Registers(0x0EE6)"},
{0x8086, 0x0EE7, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Unicast Registers(0x0EE7)"},
{0x8086, 0x0EE8, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Unicast Registers(0x0EE8)"},
{0x8086, 0x0EE9, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Unicast Registers(0x0EE9)"},
{0x8086, 0x0EEA, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Unicast Registers(0x0EEA)"},
{0x8086, 0x0EEB, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Unicast Registers(0x0EEB)"},
{0x8086, 0x0EEC, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Unicast Registers(0x0EEC)"},
{0x8086, 0x0EED, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Unicast Registers(0x0EED)"},
{0x8086, 0x0EEE, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Unicast Registers(0x0EEE)"},
{0x8086, 0x0EF0, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Integrated Memory Controller 0 Channel 0-3 Thermal Control 0(0x0EF0)"},
{0x8086, 0x0EF1, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Integrated Memory Controller 0 Channel 0-3 Thermal Control 1(0x0EF1)"},
{0x8086, 0x0EF2, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Integrated Memory Controller 0 Channel 0-3 ERROR Registers 0(0x0EF2)"},
{0x8086, 0x0EF3, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Integrated Memory Controller 0 Channel 0-3 ERROR Registers 1(0x0EF3)"},
{0x8086, 0x0EF4, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Integrated Memory Controller 0 Channel 0-3 Thermal Control 2(0x0EF4)"},
{0x8086, 0x0EF5, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Integrated Memory Controller 0 Channel 0-3 Thermal Control 3(0x0EF5)"},
{0x8086, 0x0EF6, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Integrated Memory Controller 0 Channel 0-3 ERROR Registers 2(0x0EF6)"},
{0x8086, 0x0EF7, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 Integrated Memory Controller 0 Channel 0-3 ERROR Registers 3(0x0EF7)"},
{0x8086, 0x0EF8, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 DDRIO(0x0EF8)"},
{0x8086, 0x0EF9, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 DDRIO(0x0EF9)"},
{0x8086, 0x0EFA, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 DDRIO(0x0EFA)"},
{0x8086, 0x0EFB, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 DDRIO(0x0EFB)"},
{0x8086, 0x0EFC, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 DDRIO(0x0EFC)"},
{0x8086, 0x0EFD, 0xFFFF, 0xFFFF, "Xeon E7 v2/Xeon E5 v2/Core i7 DDRIO(0x0EFD)"},
{0x8086, 0x0F00, 0xFFFF, 0xFFFF, "Atom Processor Z36xxx/Z37xxx Series SoC Transaction Register(0x0F00)"},
{0x8086, 0x0F04, 0xFFFF, 0xFFFF, "Atom Processor Z36xxx/Z37xxx Series High Definition Audio Controller(0x0F04)"},
{0x8086, 0x0F06, 0xFFFF, 0xFFFF, "Atom Processor Z36xxx/Z37xxx Series LPIO1 DMA Controller(0x0F06)"},
{0x8086, 0x0F08, 0xFFFF, 0xFFFF, "Atom Processor Z36xxx/Z37xxx Series LPIO1 PWM Controller(0x0F08)"},
{0x8086, 0x0F09, 0xFFFF, 0xFFFF, "Atom Processor Z36xxx/Z37xxx Series LPIO1 PWM Controller(0x0F09)"},
{0x8086, 0x0F0A, 0xFFFF, 0xFFFF, "Atom Processor Z36xxx/Z37xxx Series LPIO1 HSUART Controller #1(0x0F0A)"},
{0x8086, 0x0F0C, 0xFFFF, 0xFFFF, "Atom Processor Z36xxx/Z37xxx Series LPIO1 HSUART Controller #2(0x0F0C)"},
{0x8086, 0x0F0E, 0xFFFF, 0xFFFF, "Atom Processor Z36xxx/Z37xxx Series LPIO1 SPI Controller(0x0F0E)"},
{0x8086, 0x0F12, 0xFFFF, 0xFFFF, "Atom Processor E3800/CE2700 Series SMBus Controller(0x0F12)"},
{0x8086, 0x0F14, 0xFFFF, 0xFFFF, "Atom Processor Z36xxx/Z37xxx Series SDIO Controller(0x0F14)"},
{0x8086, 0x0F15, 0xFFFF, 0xFFFF, "Atom Processor Z36xxx/Z37xxx Series SDIO Controller(0x0F15)"},
{0x8086, 0x0F16, 0xFFFF, 0xFFFF, "Atom Processor Z36xxx/Z37xxx Series SDIO Controller(0x0F16)"},
{0x8086, 0x0F18, 0xFFFF, 0xFFFF, "Atom Processor Z36xxx/Z37xxx Series Trusted Execution Engine(0x0F18)"},
{0x8086, 0x0F1C, 0xFFFF, 0xFFFF, "Atom Processor Z36xxx/Z37xxx Series Power Control Unit(0x0F1C)"},
{0x8086, 0x0F20, 0xFFFF, 0xFFFF, "Atom Processor E3800 Series SATA IDE Controller(0x0F20)"},
{0x8086, 0x0F21, 0xFFFF, 0xFFFF, "Atom Processor E3800 Series SATA IDE Controller(0x0F21)"},
{0x8086, 0x0F22, 0xFFFF, 0xFFFF, "Atom Processor E3800 Series SATA AHCI Controller(0x0F22)"},
{0x8086, 0x0F23, 0xFFFF, 0xFFFF, "Atom Processor E3800 Series SATA AHCI Controller(0x0F23)"},
{0x8086, 0x0F28, 0xFFFF, 0xFFFF, "Atom Processor Z36xxx/Z37xxx Series LPE Audio Controller(0x0F28)"},
{0x8086, 0x0F31, 0xFFFF, 0xFFFF, "Atom Processor Z36xxx/Z37xxx Series Graphics & Display(0x0F31)"},
{0x8086, 0x0F34, 0xFFFF, 0xFFFF, "Atom Processor Z36xxx/Z37xxx Series USB EHCI(0x0F34)"},
{0x8086, 0x0F35, 0xFFFF, 0xFFFF, "Atom Processor Z36xxx/Z37xxx, Celeron N2000 Series USB xHCI(0x0F35)"},
{0x8086, 0x0F35, 0x1025, 0x0936, "Aspire ES1(0x1025-0x0936)"},
{0x8086, 0x0F37, 0xFFFF, 0xFFFF, "Atom Processor Z36xxx/Z37xxx Series OTG USB Device(0x0F37)"},
{0x8086, 0x0F38, 0xFFFF, 0xFFFF, "Atom Processor Z36xxx/Z37xxx Series Camera ISP(0x0F38)"},
{0x8086, 0x0F40, 0xFFFF, 0xFFFF, "Atom Processor Z36xxx/Z37xxx Series LPIO2 DMA Controller(0x0F40)"},
{0x8086, 0x0F41, 0xFFFF, 0xFFFF, "Atom Processor Z36xxx/Z37xxx Series LPIO2 I2C Controller #1(0x0F41)"},
{0x8086, 0x0F42, 0xFFFF, 0xFFFF, "Atom Processor Z36xxx/Z37xxx Series LPIO2 I2C Controller #2(0x0F42)"},
{0x8086, 0x0F43, 0xFFFF, 0xFFFF, "Atom Processor Z36xxx/Z37xxx Series LPIO2 I2C Controller #3(0x0F43)"},
{0x8086, 0x0F44, 0xFFFF, 0xFFFF, "Atom Processor Z36xxx/Z37xxx Series LPIO2 I2C Controller #4(0x0F44)"},
{0x8086, 0x0F45, 0xFFFF, 0xFFFF, "Atom Processor Z36xxx/Z37xxx Series LPIO2 I2C Controller #5(0x0F45)"},
{0x8086, 0x0F46, 0xFFFF, 0xFFFF, "Atom Processor Z36xxx/Z37xxx Series LPIO2 I2C Controller #6(0x0F46)"},
{0x8086, 0x0F47, 0xFFFF, 0xFFFF, "Atom Processor Z36xxx/Z37xxx Series LPIO2 I2C Controller #7(0x0F47)"},
{0x8086, 0x0F48, 0xFFFF, 0xFFFF, "Atom Processor E3800 Series PCI Express Root Port 1(0x0F48)"},
{0x8086, 0x0F4A, 0xFFFF, 0xFFFF, "Atom Processor E3800 Series PCI Express Root Port 2(0x0F4A)"},
{0x8086, 0x0F4C, 0xFFFF, 0xFFFF, "Atom Processor E3800 Series PCI Express Root Port 3(0x0F4C)"},
{0x8086, 0x0F4E, 0xFFFF, 0xFFFF, "Atom Processor E3800 Series PCI Express Root Port 4(0x0F4E)"},
{0x8086, 0x0F50, 0xFFFF, 0xFFFF, "Atom Processor E3800 Series eMMC 4.5 Controller(0x0F50)"},
{0x8086, 0x1000, 0xFFFF, 0xFFFF, "82542 Gigabit Ethernet Controller (Fiber)(0x1000)"},
{0x8086, 0x1000, 0x0E11, 0xB0DF, "NC6132 Gigabit Ethernet Adapter (1000-SX)(0x0E11-0xB0DF)"},
{0x8086, 0x1000, 0x0E11, 0xB0E0, "NC6133 Gigabit Ethernet Adapter (1000-LX)(0x0E11-0xB0E0)"},
{0x8086, 0x1000, 0x0E11, 0xB123, "NC6134 Gigabit Ethernet Adapter (1000-LX)(0x0E11-0xB123)"},
{0x8086, 0x1000, 0x1014, 0x0119, "Netfinity Gigabit Ethernet SX Adapter(0x1014-0x0119)"},
{0x8086, 0x1000, 0x8086, 0x1000, "PRO/1000 Gigabit Server Adapter(0x8086-0x1000)"},
{0x8086, 0x1001, 0xFFFF, 0xFFFF, "82543GC Gigabit Ethernet Controller (Fiber)(0x1001)"},
{0x8086, 0x1001, 0x0E11, 0x004A, "NC6136 Gigabit Server Adapter(0x0E11-0x004A)"},
{0x8086, 0x1001, 0x1014, 0x01EA, "Netfinity Gigabit Ethernet SX Adapter(0x1014-0x01EA)"},
{0x8086, 0x1001, 0x8086, 0x1002, "PRO/1000 F Server Adapter(0x8086-0x1002)"},
{0x8086, 0x1001, 0x8086, 0x1003, "PRO/1000 F Server Adapter(0x8086-0x1003)"},
{0x8086, 0x1002, 0xFFFF, 0xFFFF, "Pro 100 LAN+Modem 56 Cardbus II(0x1002)"},
{0x8086, 0x1002, 0x8086, 0x200E, "Pro 100 LAN+Modem 56 Cardbus II(0x8086-0x200E)"},
{0x8086, 0x1002, 0x8086, 0x2013, "Pro 100 SR Mobile Combo Adapter(0x8086-0x2013)"},
{0x8086, 0x1002, 0x8086, 0x2017, "Pro 100 S Combo Mobile Adapter(0x8086-0x2017)"},
{0x8086, 0x1004, 0xFFFF, 0xFFFF, "82543GC Gigabit Ethernet Controller (Copper)(0x1004)"},
{0x8086, 0x1004, 0x0E11, 0x0049, "NC7132 Gigabit Upgrade Module(0x0E11-0x0049)"},
{0x8086, 0x1004, 0x0E11, 0xB1A4, "NC7131 Gigabit Server Adapter(0x0E11-0xB1A4)"},
{0x8086, 0x1004, 0x1014, 0x10F2, "Gigabit Ethernet Server Adapter(0x1014-0x10F2)"},
{0x8086, 0x1004, 0x8086, 0x1004, "PRO/1000 T Server Adapter(0x8086-0x1004)"},
{0x8086, 0x1004, 0x8086, 0x2004, "PRO/1000 T Server Adapter(0x8086-0x2004)"},
{0x8086, 0x1008, 0xFFFF, 0xFFFF, "82544EI Gigabit Ethernet Controller (Copper)(0x1008)"},
{0x8086, 0x1008, 0x1014, 0x0269, "iSeries 1000/100/10 Ethernet Adapter(0x1014-0x0269)"},
{0x8086, 0x1008, 0x1028, 0x011B, "PowerEdge 1650/2550(0x1028-0x011B)"},
{0x8086, 0x1008, 0x1028, 0x011C, "PRO/1000 XT Network Connection(0x1028-0x011C)"},
{0x8086, 0x1008, 0x8086, 0x1107, "PRO/1000 XT Server Adapter(0x8086-0x1107)"},
{0x8086, 0x1008, 0x8086, 0x2107, "PRO/1000 XT Server Adapter(0x8086-0x2107)"},
{0x8086, 0x1008, 0x8086, 0x2110, "PRO/1000 XT Desktop Adapter(0x8086-0x2110)"},
{0x8086, 0x1008, 0x8086, 0x3108, "PRO/1000 XT Network Connection(0x8086-0x3108)"},
{0x8086, 0x1009, 0xFFFF, 0xFFFF, "82544EI Gigabit Ethernet Controller (Fiber)(0x1009)"},
{0x8086, 0x1009, 0x1014, 0x0268, "iSeries Gigabit Ethernet Adapter(0x1014-0x0268)"},
{0x8086, 0x1009, 0x8086, 0x1109, "PRO/1000 XF Server Adapter(0x8086-0x1109)"},
{0x8086, 0x1009, 0x8086, 0x2109, "PRO/1000 XF Server Adapter(0x8086-0x2109)"},
{0x8086, 0x100A, 0xFFFF, 0xFFFF, "82540EM Gigabit Ethernet Controller(0x100A)"},
{0x8086, 0x100C, 0xFFFF, 0xFFFF, "82544GC Gigabit Ethernet Controller (Copper)(0x100C)"},
{0x8086, 0x100C, 0x8086, 0x1112, "PRO/1000 T Desktop Adapter(0x8086-0x1112)"},
{0x8086, 0x100C, 0x8086, 0x2112, "PRO/1000 T Desktop Adapter(0x8086-0x2112)"},
{0x8086, 0x100D, 0xFFFF, 0xFFFF, "82544GC Gigabit Ethernet Controller (LOM)(0x100D)"},
{0x8086, 0x100D, 0x1028, 0x0123, "PRO/1000 XT Network Connection(0x1028-0x0123)"},
{0x8086, 0x100D, 0x1079, 0x891F, "82544GC Based Network Connection(0x1079-0x891F)"},
{0x8086, 0x100D, 0x4C53, 0x1080, "CT8 mainboard(0x4C53-0x1080)"},
{0x8086, 0x100D, 0x8086, 0x110D, "82544GC Based Network Connection(0x8086-0x110D)"},
{0x8086, 0x100E, 0xFFFF, 0xFFFF, "82540EM Gigabit Ethernet Controller(0x100E)"},
{0x8086, 0x100E, 0x1014, 0x0265, "PRO/1000 MT Network Connection(0x1014-0x0265)"},
{0x8086, 0x100E, 0x1014, 0x0267, "PRO/1000 MT Network Connection(0x1014-0x0267)"},
{0x8086, 0x100E, 0x1014, 0x026A, "PRO/1000 MT Network Connection(0x1014-0x026A)"},
{0x8086, 0x100E, 0x1028, 0x002E, "Optiplex GX260(0x1028-0x002E)"},
{0x8086, 0x100E, 0x1028, 0x0134, "PowerEdge 600SC(0x1028-0x0134)"},
{0x8086, 0x100E, 0x1028, 0x0151, "Optiplex GX270(0x1028-0x0151)"},
{0x8086, 0x100E, 0x107B, 0x8920, "PRO/1000 MT Desktop Adapter(0x107B-0x8920)"},
{0x8086, 0x100E, 0x1AF4, 0x1100, "QEMU Virtual Machine(0x1AF4-0x1100)"},
{0x8086, 0x100E, 0x8086, 0x001E, "PRO/1000 MT Desktop Adapter(0x8086-0x001E)"},
{0x8086, 0x100E, 0x8086, 0x002E, "PRO/1000 MT Desktop Adapter(0x8086-0x002E)"},
{0x8086, 0x100E, 0x8086, 0x1376, "PRO/1000 GT Desktop Adapter(0x8086-0x1376)"},
{0x8086, 0x100E, 0x8086, 0x1476, "PRO/1000 GT Desktop Adapter(0x8086-0x1476)"},
{0x8086, 0x100F, 0xFFFF, 0xFFFF, "82545EM Gigabit Ethernet Controller (Copper)(0x100F)"},
{0x8086, 0x100F, 0x1014, 0x0269, "iSeries 1000/100/10 Ethernet Adapter(0x1014-0x0269)"},
{0x8086, 0x100F, 0x1014, 0x028E, "PRO/1000 MT Network Connection(0x1014-0x028E)"},
{0x8086, 0x100F, 0x15AD, 0x0750, "PRO/1000 MT Single Port Adapter(0x15AD-0x0750)"},
{0x8086, 0x100F, 0x8086, 0x1000, "PRO/1000 MT Network Connection(0x8086-0x1000)"},
{0x8086, 0x100F, 0x8086, 0x1001, "PRO/1000 MT Server Adapter(0x8086-0x1001)"},
{0x8086, 0x1010, 0xFFFF, 0xFFFF, "82546EB Gigabit Ethernet Controller (Copper)(0x1010)"},
{0x8086, 0x1010, 0x0E11, 0x00DB, "NC7170 Gigabit Server Adapter(0x0E11-0x00DB)"},
{0x8086, 0x1010, 0x1014, 0x027C, "PRO/1000 MT Dual Port Network Adapter(0x1014-0x027C)"},
{0x8086, 0x1010, 0x15AD, 0x0760, "PRO/1000 MT Dual Port Adapter(0x15AD-0x0760)"},
{0x8086, 0x1010, 0x18FB, 0x7872, "RESlink-X(0x18FB-0x7872)"},
{0x8086, 0x1010, 0x1FC1, 0x0026, "Niagara 2260 Bypass Card(0x1FC1-0x0026)"},
{0x8086, 0x1010, 0x4C53, 0x1080, "CT8 mainboard(0x4C53-0x1080)"},
{0x8086, 0x1010, 0x4C53, 0x10A0, "CA3/CR3 mainboard(0x4C53-0x10A0)"},
{0x8086, 0x1010, 0x8086, 0x1011, "PRO/1000 MT Dual Port Server Adapter(0x8086-0x1011)"},
{0x8086, 0x1010, 0x8086, 0x1012, "PRO/1000 MT Dual Port Server Adapter(0x8086-0x1012)"},
{0x8086, 0x1010, 0x8086, 0x101A, "PRO/1000 MT Dual Port Network Connection(0x8086-0x101A)"},
{0x8086, 0x1010, 0x8086, 0x3424, "SE7501HG2 Mainboard(0x8086-0x3424)"},
{0x8086, 0x1011, 0xFFFF, 0xFFFF, "82545EM Gigabit Ethernet Controller (Fiber)(0x1011)"},
{0x8086, 0x1011, 0x1014, 0x0268, "iSeries Gigabit Ethernet Adapter(0x1014-0x0268)"},
{0x8086, 0x1011, 0x8086, 0x1002, "PRO/1000 MF Server Adapter(0x8086-0x1002)"},
{0x8086, 0x1011, 0x8086, 0x1003, "PRO/1000 MF Server Adapter (LX)(0x8086-0x1003)"},
{0x8086, 0x1012, 0xFFFF, 0xFFFF, "82546EB Gigabit Ethernet Controller (Fiber)(0x1012)"},
{0x8086, 0x1012, 0x0E11, 0x00DC, "NC6170 Gigabit Server Adapter(0x0E11-0x00DC)"},
{0x8086, 0x1012, 0x8086, 0x1012, "PRO/1000 MF Dual Port Server Adapter(0x8086-0x1012)"},
{0x8086, 0x1013, 0xFFFF, 0xFFFF, "82541EI Gigabit Ethernet Controller(0x1013)"},
{0x8086, 0x1013, 0x8086, 0x0013, "PRO/1000 MT Network Connection(0x8086-0x0013)"},
{0x8086, 0x1013, 0x8086, 0x1013, "PRO/1000 MT Network Connection(0x8086-0x1013)"},
{0x8086, 0x1013, 0x8086, 0x1113, "PRO/1000 MT Desktop Adapter(0x8086-0x1113)"},
{0x8086, 0x1014, 0xFFFF, 0xFFFF, "82541ER Gigabit Ethernet Controller(0x1014)"},
{0x8086, 0x1014, 0x8086, 0x0014, "PRO/1000 MT Desktop Connection(0x8086-0x0014)"},
{0x8086, 0x1014, 0x8086, 0x1014, "PRO/1000 MT Network Connection(0x8086-0x1014)"},
{0x8086, 0x1015, 0xFFFF, 0xFFFF, "82540EM Gigabit Ethernet Controller (LOM)(0x1015)"},
{0x8086, 0x1015, 0x8086, 0x1015, "PRO/1000 MT Mobile Connection(0x8086-0x1015)"},
{0x8086, 0x1016, 0xFFFF, 0xFFFF, "82540EP Gigabit Ethernet Controller (Mobile)(0x1016)"},
{0x8086, 0x1016, 0x1014, 0x052C, "PRO/1000 MT Mobile Connection(0x1014-0x052C)"},
{0x8086, 0x1016, 0x1179, 0x0001, "PRO/1000 MT Mobile Connection(0x1179-0x0001)"},
{0x8086, 0x1016, 0x8086, 0x1016, "PRO/1000 MT Mobile Connection(0x8086-0x1016)"},
{0x8086, 0x1017, 0xFFFF, 0xFFFF, "82540EP Gigabit Ethernet Controller(0x1017)"},
{0x8086, 0x1017, 0x8086, 0x1017, "PR0/1000 MT Desktop Connection(0x8086-0x1017)"},
{0x8086, 0x1018, 0xFFFF, 0xFFFF, "82541EI Gigabit Ethernet Controller(0x1018)"},
{0x8086, 0x1018, 0x8086, 0x1018, "PRO/1000 MT Mobile Connection(0x8086-0x1018)"},
{0x8086, 0x1019, 0xFFFF, 0xFFFF, "82547EI Gigabit Ethernet Controller(0x1019)"},
{0x8086, 0x1019, 0x1458, 0x1019, "GA-8IPE1000 Pro2 motherboard (865PE)(0x1458-0x1019)"},
{0x8086, 0x1019, 0x1458, 0xE000, "Intel Gigabit Ethernet (Kenai II)(0x1458-0xE000)"},
{0x8086, 0x1019, 0x8086, 0x1019, "PRO/1000 CT Desktop Connection(0x8086-0x1019)"},
{0x8086, 0x1019, 0x8086, 0x301F, "D865PERL mainboard(0x8086-0x301F)"},
{0x8086, 0x1019, 0x8086, 0x3025, "D875PBZ motherboard(0x8086-0x3025)"},
{0x8086, 0x1019, 0x8086, 0x302C, "D865GBF Mainboard(0x8086-0x302C)"},
{0x8086, 0x1019, 0x8086, 0x3427, "S875WP1-E mainboard(0x8086-0x3427)"},
{0x8086, 0x101A, 0xFFFF, 0xFFFF, "82547EI Gigabit Ethernet Controller (Mobile)(0x101A)"},
{0x8086, 0x101A, 0x8086, 0x101A, "PRO/1000 CT Mobile Connection(0x8086-0x101A)"},
{0x8086, 0x101D, 0xFFFF, 0xFFFF, "82546EB Gigabit Ethernet Controller(0x101D)"},
{0x8086, 0x101D, 0x8086, 0x1000, "PRO/1000 MT Quad Port Server Adapter(0x8086-0x1000)"},
{0x8086, 0x101E, 0xFFFF, 0xFFFF, "82540EP Gigabit Ethernet Controller (Mobile)(0x101E)"},
{0x8086, 0x101E, 0x1014, 0x0549, "Thinkpad(0x1014-0x0549)"},
{0x8086, 0x101E, 0x1179, 0x0001, "PRO/1000 MT Mobile Connection(0x1179-0x0001)"},
{0x8086, 0x101E, 0x8086, 0x101E, "PRO/1000 MT Mobile Connection(0x8086-0x101E)"},
{0x8086, 0x101F, 0xFFFF, 0xFFFF, "Ethernet Controller V710 for 5GBASE-T(0x101F)"},
{0x8086, 0x1026, 0xFFFF, 0xFFFF, "82545GM Gigabit Ethernet Controller(0x1026)"},
{0x8086, 0x1026, 0x1028, 0x0168, "Precision Workstation 670 Mainboard(0x1028-0x0168)"},
{0x8086, 0x1026, 0x1028, 0x0169, "Precision 470(0x1028-0x0169)"},
{0x8086, 0x1026, 0x8086, 0x1000, "PRO/1000 MT Server Connection(0x8086-0x1000)"},
{0x8086, 0x1026, 0x8086, 0x1001, "PRO/1000 MT Server Adapter(0x8086-0x1001)"},
{0x8086, 0x1026, 0x8086, 0x1002, "PRO/1000 MT Server Adapter(0x8086-0x1002)"},
{0x8086, 0x1026, 0x8086, 0x1003, "PRO/1000 GT Server Adapter(0x8086-0x1003)"},
{0x8086, 0x1026, 0x8086, 0x1026, "PRO/1000 MT Server Connection(0x8086-0x1026)"},
{0x8086, 0x1027, 0xFFFF, 0xFFFF, "82545GM Gigabit Ethernet Controller(0x1027)"},
{0x8086, 0x1027, 0x103C, 0x3103, "NC310F PCI-X Gigabit Server Adapter(0x103C-0x3103)"},
{0x8086, 0x1027, 0x8086, 0x1001, "PRO/1000 MF Server Adapter(LX)(0x8086-0x1001)"},
{0x8086, 0x1027, 0x8086, 0x1002, "PRO/1000 MF Server Adapter(LX)(0x8086-0x1002)"},
{0x8086, 0x1027, 0x8086, 0x1003, "PRO/1000 MF Server Adapter(LX)(0x8086-0x1003)"},
{0x8086, 0x1027, 0x8086, 0x1027, "PRO/1000 MF Server Adapter(0x8086-0x1027)"},
{0x8086, 0x1028, 0xFFFF, 0xFFFF, "82545GM Gigabit Ethernet Controller(0x1028)"},
{0x8086, 0x1028, 0x8086, 0x1028, "PRO/1000 MB Server Connection(0x8086-0x1028)"},
{0x8086, 0x1029, 0xFFFF, 0xFFFF, "82559 Ethernet Controller(0x1029)"},
{0x8086, 0x1030, 0xFFFF, 0xFFFF, "82559 InBusiness 10/100(0x1030)"},
{0x8086, 0x1031, 0xFFFF, 0xFFFF, "82801CAM (ICH3) PRO/100 VE (LOM) Ethernet Controller(0x1031)"},
{0x8086, 0x1031, 0x1014, 0x0209, "ThinkPad A/T/X Series(0x1014-0x0209)"},
{0x8086, 0x1031, 0x104D, 0x80E7, "Vaio PCG-GR214EP/GR214MP/GR215MP/GR314MP/GR315MP(0x104D-0x80E7)"},
{0x8086, 0x1031, 0x104D, 0x813C, "Vaio PCG-GRV616G(0x104D-0x813C)"},
{0x8086, 0x1031, 0x107B, 0x5350, "EtherExpress PRO/100 VE(0x107B-0x5350)"},
{0x8086, 0x1031, 0x1179, 0x0001, "EtherExpress PRO/100 VE(0x1179-0x0001)"},
{0x8086, 0x1031, 0x144D, 0xC000, "EtherExpress PRO/100 VE(0x144D-0xC000)"},
{0x8086, 0x1031, 0x144D, 0xC001, "EtherExpress PRO/100 VE(0x144D-0xC001)"},
{0x8086, 0x1031, 0x144D, 0xC003, "EtherExpress PRO/100 VE(0x144D-0xC003)"},
{0x8086, 0x1031, 0x144D, 0xC006, "vpr Matrix 170B4(0x144D-0xC006)"},
{0x8086, 0x1032, 0xFFFF, 0xFFFF, "82801CAM (ICH3) PRO/100 VE Ethernet Controller(0x1032)"},
{0x8086, 0x1033, 0xFFFF, 0xFFFF, "82801CAM (ICH3) PRO/100 VM (LOM) Ethernet Controller(0x1033)"},
{0x8086, 0x1034, 0xFFFF, 0xFFFF, "82801CAM (ICH3) PRO/100 VM Ethernet Controller(0x1034)"},
{0x8086, 0x1035, 0xFFFF, 0xFFFF, "82801CAM (ICH3)/82562EH (LOM) Ethernet Controller(0x1035)"},
{0x8086, 0x1036, 0xFFFF, 0xFFFF, "82801CAM (ICH3) 82562EH Ethernet Controller(0x1036)"},
{0x8086, 0x1037, 0xFFFF, 0xFFFF, "82801CAM (ICH3) Chipset Ethernet Controller(0x1037)"},
{0x8086, 0x1038, 0xFFFF, 0xFFFF, "82801CAM (ICH3) PRO/100 VM (KM) Ethernet Controller(0x1038)"},
{0x8086, 0x1038, 0x0E11, 0x0098, "Evo N600c(0x0E11-0x0098)"},
{0x8086, 0x1039, 0xFFFF, 0xFFFF, "82801DB PRO/100 VE (LOM) Ethernet Controller(0x1039)"},
{0x8086, 0x1039, 0x1014, 0x0267, "NetVista A30p(0x1014-0x0267)"},
{0x8086, 0x1039, 0x114A, 0x0582, "PC8 onboard ethernet ETH1(0x114A-0x0582)"},
{0x8086, 0x103A, 0xFFFF, 0xFFFF, "82801DB PRO/100 VE (CNR) Ethernet Controller(0x103A)"},
{0x8086, 0x103B, 0xFFFF, 0xFFFF, "82801DB PRO/100 VM (LOM) Ethernet Controller(0x103B)"},
{0x8086, 0x103C, 0xFFFF, 0xFFFF, "82801DB PRO/100 VM (CNR) Ethernet Controller(0x103C)"},
{0x8086, 0x103D, 0xFFFF, 0xFFFF, "82801DB PRO/100 VE (MOB) Ethernet Controller(0x103D)"},
{0x8086, 0x103D, 0x1014, 0x0522, "ThinkPad R40(0x1014-0x0522)"},
{0x8086, 0x103D, 0x1028, 0x2002, "Latitude D500(0x1028-0x2002)"},
{0x8086, 0x103D, 0x8086, 0x103D, "82562EZ 10/100 Ethernet Controller(0x8086-0x103D)"},
{0x8086, 0x103E, 0xFFFF, 0xFFFF, "82801DB PRO/100 VM (MOB) Ethernet Controller(0x103E)"},
{0x8086, 0x1040, 0xFFFF, 0xFFFF, "536EP Data Fax Modem(0x1040)"},
{0x8086, 0x1040, 0x16BE, 0x1040, "V.9X DSP Data Fax Modem(0x16BE-0x1040)"},
{0x8086, 0x1043, 0xFFFF, 0xFFFF, "PRO/Wireless LAN 2100 3B Mini PCI Adapter(0x1043)"},
{0x8086, 0x1043, 0x103C, 0x08B0, "tc1100 tablet(0x103C-0x08B0)"},
{0x8086, 0x1043, 0x8086, 0x2522, "Samsung X10/P30 integrated WLAN(0x8086-0x2522)"},
{0x8086, 0x1043, 0x8086, 0x2527, "MIM2000/Centrino(0x8086-0x2527)"},
{0x8086, 0x1043, 0x8086, 0x2561, "Dell Latitude D800(0x8086-0x2561)"},
{0x8086, 0x1043, 0x8086, 0x2581, "Toshiba Satellite M10(0x8086-0x2581)"},
{0x8086, 0x1048, 0xFFFF, 0xFFFF, "82597EX 10GbE Ethernet Controller(0x1048)"},
{0x8086, 0x1048, 0x8086, 0xA01F, "PRO/10GbE LR Server Adapter(0x8086-0xA01F)"},
{0x8086, 0x1048, 0x8086, 0xA11F, "PRO/10GbE LR Server Adapter(0x8086-0xA11F)"},
{0x8086, 0x1049, 0xFFFF, 0xFFFF, "82566MM Gigabit Network Connection(0x1049)"},
{0x8086, 0x1049, 0x103C, 0x30C1, "Compaq 6910p(0x103C-0x30C1)"},
{0x8086, 0x1049, 0x17AA, 0x20B9, "ThinkPad T61/R61(0x17AA-0x20B9)"},
{0x8086, 0x104A, 0xFFFF, 0xFFFF, "82566DM Gigabit Network Connection(0x104A)"},
{0x8086, 0x104B, 0xFFFF, 0xFFFF, "82566DC Gigabit Network Connection(0x104B)"},
{0x8086, 0x104C, 0xFFFF, 0xFFFF, "82562V 10/100 Network Connection(0x104C)"},
{0x8086, 0x104D, 0xFFFF, 0xFFFF, "82566MC Gigabit Network Connection(0x104D)"},
{0x8086, 0x104E, 0xFFFF, 0xFFFF, "Ethernet Controller X710 for 10 Gigabit SFP+(0x104E)"},
{0x8086, 0x104F, 0xFFFF, 0xFFFF, "Ethernet Controller X710 for 10 Gigabit backplane(0x104F)"},
{0x8086, 0x1050, 0xFFFF, 0xFFFF, "82562EZ 10/100 Ethernet Controller(0x1050)"},
{0x8086, 0x1050, 0x1014, 0x0287, "ThinkCentre S50(0x1014-0x0287)"},
{0x8086, 0x1050, 0x1028, 0x019D, "Dimension 3000(0x1028-0x019D)"},
{0x8086, 0x1050, 0x1462, 0x728C, "865PE Neo2 (MS-6728)(0x1462-0x728C)"},
{0x8086, 0x1050, 0x1462, 0x758C, "MS-6758 (875P Neo)(0x1462-0x758C)"},
{0x8086, 0x1050, 0x8086, 0x3020, "D865PERL mainboard(0x8086-0x3020)"},
{0x8086, 0x1050, 0x8086, 0x302F, "Desktop Board D865GBF(0x8086-0x302F)"},
{0x8086, 0x1050, 0x8086, 0x3427, "S875WP1-E mainboard(0x8086-0x3427)"},
{0x8086, 0x1051, 0xFFFF, 0xFFFF, "82801EB/ER (ICH5/ICH5R) integrated LAN Controller(0x1051)"},
{0x8086, 0x1052, 0xFFFF, 0xFFFF, "PRO/100 VM Network Connection(0x1052)"},
{0x8086, 0x1053, 0xFFFF, 0xFFFF, "PRO/100 VM Network Connection(0x1053)"},
{0x8086, 0x1054, 0xFFFF, 0xFFFF, "PRO/100 VE Network Connection(0x1054)"},
{0x8086, 0x1055, 0xFFFF, 0xFFFF, "PRO/100 VM Network Connection(0x1055)"},
{0x8086, 0x1056, 0xFFFF, 0xFFFF, "PRO/100 VE Network Connection(0x1056)"},
{0x8086, 0x1057, 0xFFFF, 0xFFFF, "PRO/100 VE Network Connection(0x1057)"},
{0x8086, 0x1059, 0xFFFF, 0xFFFF, "82551QM Ethernet Controller(0x1059)"},
{0x8086, 0x105B, 0xFFFF, 0xFFFF, "82546GB Gigabit Ethernet Controller (Copper)(0x105B)"},
{0x8086, 0x105E, 0xFFFF, 0xFFFF, "82571EB/82571GB Gigabit Ethernet Controller D0/D1 (copper applications)(0x105E)"},
{0x8086, 0x105E, 0x103C, 0x7044, "NC360T PCI Express Dual Port Gigabit Server Adapter(0x103C-0x7044)"},
{0x8086, 0x105E, 0x103C, 0x704E, "Dual Port 1000Base-T (PCIe) [AD337A](0x103C-0x704E)"},
{0x8086, 0x105E, 0x1775, 0x1100, "CR11/VR11 Single Board Computer(0x1775-0x1100)"},
{0x8086, 0x105E, 0x1775, 0x6003, "Telum GE-QT(0x1775-0x6003)"},
{0x8086, 0x105E, 0x18DF, 0x1214, "2x 1GbE, PCIe x1, dual Intel 82571EB chips(0x18DF-0x1214)"},
{0x8086, 0x105E, 0x8086, 0x005E, "PRO/1000 PT Dual Port Server Connection(0x8086-0x005E)"},
{0x8086, 0x105E, 0x8086, 0x105E, "PRO/1000 PT Dual Port Network Connection(0x8086-0x105E)"},
{0x8086, 0x105E, 0x8086, 0x10D5, "82571PT Gigabit PT Quad Port Server ExpressModule(0x8086-0x10D5)"},
{0x8086, 0x105E, 0x8086, 0x115E, "PRO/1000 PT Dual Port Server Adapter(0x8086-0x115E)"},
{0x8086, 0x105E, 0x8086, 0x125E, "PRO/1000 PT Dual Port Server Adapter(0x8086-0x125E)"},
{0x8086, 0x105E, 0x8086, 0x135E, "PRO/1000 PT Dual Port Server Adapter(0x8086-0x135E)"},
{0x8086, 0x105F, 0xFFFF, 0xFFFF, "82571EB Gigabit Ethernet Controller(0x105F)"},
{0x8086, 0x105F, 0x103C, 0x704F, "Dual Port 1000Base-SX (PCIe) [AD338A](0x103C-0x704F)"},
{0x8086, 0x105F, 0x8086, 0x005A, "PRO/1000 PF Dual Port Server Adapter(0x8086-0x005A)"},
{0x8086, 0x105F, 0x8086, 0x115F, "PRO/1000 PF Dual Port Server Adapter(0x8086-0x115F)"},
{0x8086, 0x105F, 0x8086, 0x125F, "PRO/1000 PF Dual Port Server Adapter(0x8086-0x125F)"},
{0x8086, 0x105F, 0x8086, 0x135F, "PRO/1000 PF Dual Port Server Adapter(0x8086-0x135F)"},
{0x8086, 0x1060, 0xFFFF, 0xFFFF, "82571EB Gigabit Ethernet Controller(0x1060)"},
{0x8086, 0x1060, 0x8086, 0x0060, "PRO/1000 PB Dual Port Server Connection(0x8086-0x0060)"},
{0x8086, 0x1060, 0x8086, 0x1060, "PRO/1000 PB Dual Port Server Connection(0x8086-0x1060)"},
{0x8086, 0x1064, 0xFFFF, 0xFFFF, "82562ET/EZ/GT/GZ - PRO/100 VE (LOM) Ethernet Controller(0x1064)"},
{0x8086, 0x1064, 0x1043, 0x80F8, "P5GD1-VW Mainboard(0x1043-0x80F8)"},
{0x8086, 0x1065, 0xFFFF, 0xFFFF, "82562ET/EZ/GT/GZ - PRO/100 VE Ethernet Controller(0x1065)"},
{0x8086, 0x1066, 0xFFFF, 0xFFFF, "82562 EM/EX/GX - PRO/100 VM (LOM) Ethernet Controller(0x1066)"},
{0x8086, 0x1067, 0xFFFF, 0xFFFF, "82562 EM/EX/GX - PRO/100 VM Ethernet Controller(0x1067)"},
{0x8086, 0x1068, 0xFFFF, 0xFFFF, "82562ET/EZ/GT/GZ - PRO/100 VE (LOM) Ethernet Controller Mobile(0x1068)"},
{0x8086, 0x1068, 0x103C, 0x30D5, "530 Laptop(0x103C-0x30D5)"},
{0x8086, 0x1069, 0xFFFF, 0xFFFF, "82562EM/EX/GX - PRO/100 VM (LOM) Ethernet Controller Mobile(0x1069)"},
{0x8086, 0x106A, 0xFFFF, 0xFFFF, "82562G - PRO/100 VE (LOM) Ethernet Controller(0x106A)"},
{0x8086, 0x106B, 0xFFFF, 0xFFFF, "82562G - PRO/100 VE Ethernet Controller Mobile(0x106B)"},
{0x8086, 0x1075, 0xFFFF, 0xFFFF, "82547GI Gigabit Ethernet Controller(0x1075)"},
{0x8086, 0x1075, 0x1028, 0x0165, "PowerEdge 750(0x1028-0x0165)"},
{0x8086, 0x1075, 0x8086, 0x0075, "PRO/1000 CT Network Connection(0x8086-0x0075)"},
{0x8086, 0x1075, 0x8086, 0x1075, "PRO/1000 CT Network Connection(0x8086-0x1075)"},
{0x8086, 0x1076, 0xFFFF, 0xFFFF, "82541GI Gigabit Ethernet Controller(0x1076)"},
{0x8086, 0x1076, 0x1028, 0x0165, "PRO/1000 MT Network Connection(0x1028-0x0165)"},
{0x8086, 0x1076, 0x1028, 0x016D, "PRO/1000 MT Network Connection(0x1028-0x016D)"},
{0x8086, 0x1076, 0x1028, 0x019A, "PRO/1000 MT Network Connection(0x1028-0x019A)"},
{0x8086, 0x1076, 0x1028, 0x106D, "PRO/1000 MT Network Connection(0x1028-0x106D)"},
{0x8086, 0x1076, 0x8086, 0x0076, "PRO/1000 MT Network Connection(0x8086-0x0076)"},
{0x8086, 0x1076, 0x8086, 0x1076, "PRO/1000 MT Network Connection(0x8086-0x1076)"},
{0x8086, 0x1076, 0x8086, 0x1176, "PRO/1000 MT Desktop Adapter(0x8086-0x1176)"},
{0x8086, 0x1076, 0x8086, 0x1276, "PRO/1000 MT Network Adapter(0x8086-0x1276)"},
{0x8086, 0x1077, 0xFFFF, 0xFFFF, "82541GI Gigabit Ethernet Controller(0x1077)"},
{0x8086, 0x1077, 0x1179, 0x0001, "PRO/1000 MT Mobile Connection(0x1179-0x0001)"},
{0x8086, 0x1077, 0x8086, 0x0077, "PRO/1000 MT Mobile Connection(0x8086-0x0077)"},
{0x8086, 0x1077, 0x8086, 0x1077, "PRO/1000 MT Mobile Connection(0x8086-0x1077)"},
{0x8086, 0x1078, 0xFFFF, 0xFFFF, "82541ER Gigabit Ethernet Controller(0x1078)"},
{0x8086, 0x1078, 0x8086, 0x1078, "82541ER-based Network Connection(0x8086-0x1078)"},
{0x8086, 0x1079, 0xFFFF, 0xFFFF, "82546GB Gigabit Ethernet Controller(0x1079)"},
{0x8086, 0x1079, 0x103C, 0x12A6, "Dual Port 1000Base-T [A9900A](0x103C-0x12A6)"},
{0x8086, 0x1079, 0x103C, 0x12CF, "Core Dual Port 1000Base-T [AB352A](0x103C-0x12CF)"},
{0x8086, 0x1079, 0x1775, 0x10D0, "V5D Single Board Computer Gigabit Ethernet(0x1775-0x10D0)"},
{0x8086, 0x1079, 0x1775, 0xCE90, "CE9(0x1775-0xCE90)"},
{0x8086, 0x1079, 0x1FC1, 0x0027, "Niagara 2261 Failover NIC(0x1FC1-0x0027)"},
{0x8086, 0x1079, 0x4C53, 0x1090, "Cx9 / Vx9 mainboard(0x4C53-0x1090)"},
{0x8086, 0x1079, 0x4C53, 0x10B0, "CL9 mainboard(0x4C53-0x10B0)"},
{0x8086, 0x1079, 0x8086, 0x0079, "PRO/1000 MT Dual Port Network Connection(0x8086-0x0079)"},
{0x8086, 0x1079, 0x8086, 0x1079, "PRO/1000 MT Dual Port Network Connection(0x8086-0x1079)"},
{0x8086, 0x1079, 0x8086, 0x1179, "PRO/1000 MT Dual Port Server Adapter(0x8086-0x1179)"},
{0x8086, 0x1079, 0x8086, 0x117A, "PRO/1000 MT Dual Port Server Adapter(0x8086-0x117A)"},
{0x8086, 0x107A, 0xFFFF, 0xFFFF, "82546GB Gigabit Ethernet Controller(0x107A)"},
{0x8086, 0x107A, 0x103C, 0x12A8, "Dual Port 1000base-SX [A9899A](0x103C-0x12A8)"},
{0x8086, 0x107A, 0x8086, 0x107A, "PRO/1000 MF Dual Port Server Adapter(0x8086-0x107A)"},
{0x8086, 0x107A, 0x8086, 0x127A, "PRO/1000 MF Dual Port Server Adapter(0x8086-0x127A)"},
{0x8086, 0x107B, 0xFFFF, 0xFFFF, "82546GB Gigabit Ethernet Controller(0x107B)"},
{0x8086, 0x107B, 0x8086, 0x007B, "PRO/1000 MB Dual Port Server Connection(0x8086-0x007B)"},
{0x8086, 0x107B, 0x8086, 0x107B, "PRO/1000 MB Dual Port Server Connection(0x8086-0x107B)"},
{0x8086, 0x107C, 0xFFFF, 0xFFFF, "82541PI Gigabit Ethernet Controller(0x107C)"},
{0x8086, 0x107C, 0x8086, 0x1376, "PRO/1000 GT Desktop Adapter(0x8086-0x1376)"},
{0x8086, 0x107C, 0x8086, 0x1476, "PRO/1000 GT Desktop Adapter(0x8086-0x1476)"},
{0x8086, 0x107D, 0xFFFF, 0xFFFF, "82572EI Gigabit Ethernet Controller (Copper)(0x107D)"},
{0x8086, 0x107D, 0x8086, 0x1082, "PRO/1000 PT Server Adapter(0x8086-0x1082)"},
{0x8086, 0x107D, 0x8086, 0x1084, "PRO/1000 PT Server Adapter(0x8086-0x1084)"},
{0x8086, 0x107D, 0x8086, 0x1092, "PRO/1000 PT Server Adapter(0x8086-0x1092)"},
{0x8086, 0x107E, 0xFFFF, 0xFFFF, "82572EI Gigabit Ethernet Controller (Fiber)(0x107E)"},
{0x8086, 0x107E, 0x8086, 0x1084, "PRO/1000 PF Server Adapter(0x8086-0x1084)"},
{0x8086, 0x107E, 0x8086, 0x1085, "PRO/1000 PF Server Adapter(0x8086-0x1085)"},
{0x8086, 0x107E, 0x8086, 0x1094, "PRO/1000 PF Server Adapter(0x8086-0x1094)"},
{0x8086, 0x107F, 0xFFFF, 0xFFFF, "82572EI Gigabit Ethernet Controller(0x107F)"},
{0x8086, 0x1080, 0xFFFF, 0xFFFF, "FA82537EP 56K V.92 Data/Fax Modem PCI(0x1080)"},
{0x8086, 0x1081, 0xFFFF, 0xFFFF, "631xESB/632xESB LAN Controller Copper(0x1081)"},
{0x8086, 0x1082, 0xFFFF, 0xFFFF, "631xESB/632xESB LAN Controller fiber(0x1082)"},
{0x8086, 0x1083, 0xFFFF, 0xFFFF, "631xESB/632xESB LAN Controller SERDES(0x1083)"},
{0x8086, 0x1084, 0xFFFF, 0xFFFF, "631xESB/632xESB IDE Redirection(0x1084)"},
{0x8086, 0x1085, 0xFFFF, 0xFFFF, "631xESB/632xESB Serial Port Redirection(0x1085)"},
{0x8086, 0x1086, 0xFFFF, 0xFFFF, "631xESB/632xESB IPMI/KCS0(0x1086)"},
{0x8086, 0x1087, 0xFFFF, 0xFFFF, "631xESB/632xESB UHCI Redirection(0x1087)"},
{0x8086, 0x1089, 0xFFFF, 0xFFFF, "631xESB/632xESB BT(0x1089)"},
{0x8086, 0x108A, 0xFFFF, 0xFFFF, "82546GB Gigabit Ethernet Controller(0x108A)"},
{0x8086, 0x108A, 0x8086, 0x108A, "PRO/1000 P Dual Port Server Adapter(0x8086-0x108A)"},
{0x8086, 0x108A, 0x8086, 0x118A, "PRO/1000 P Dual Port Server Adapter(0x8086-0x118A)"},
{0x8086, 0x108B, 0xFFFF, 0xFFFF, "82573V Gigabit Ethernet Controller (Copper)(0x108B)"},
{0x8086, 0x108B, 0x1462, 0x176C, "on board on MSI 945P - NEO (MS-7176)(0x1462-0x176C)"},
{0x8086, 0x108C, 0xFFFF, 0xFFFF, "82573E Gigabit Ethernet Controller (Copper)(0x108C)"},
{0x8086, 0x108E, 0xFFFF, 0xFFFF, "82573E KCS (Active Management)(0x108E)"},
{0x8086, 0x108F, 0xFFFF, 0xFFFF, "Active Management Technology - SOL(0x108F)"},
{0x8086, 0x1091, 0xFFFF, 0xFFFF, "PRO/100 VM Network Connection(0x1091)"},
{0x8086, 0x1092, 0xFFFF, 0xFFFF, "PRO/100 VE Network Connection(0x1092)"},
{0x8086, 0x1092, 0x1071, 0x8209, "Medion MIM 2240 Notebook PC [MD98100](0x1071-0x8209)"},
{0x8086, 0x1093, 0xFFFF, 0xFFFF, "PRO/100 VM Network Connection(0x1093)"},
{0x8086, 0x1094, 0xFFFF, 0xFFFF, "PRO/100 VE Network Connection(0x1094)"},
{0x8086, 0x1095, 0xFFFF, 0xFFFF, "PRO/100 VE Network Connection(0x1095)"},
{0x8086, 0x1096, 0xFFFF, 0xFFFF, "80003ES2LAN Gigabit Ethernet Controller (Copper)(0x1096)"},
{0x8086, 0x1096, 0x15D9, 0x1096, "Motherboard(0x15D9-0x1096)"},
{0x8086, 0x1096, 0x15D9, 0x8680, "X7DVL-E-O motherboard(0x15D9-0x8680)"},
{0x8086, 0x1096, 0x8086, 0x3476, "S5000PSLSATA Server Board(0x8086-0x3476)"},
{0x8086, 0x1097, 0xFFFF, 0xFFFF, "631xESB/632xESB DPT LAN Controller (Fiber)(0x1097)"},
{0x8086, 0x1098, 0xFFFF, 0xFFFF, "80003ES2LAN Gigabit Ethernet Controller (Serdes)(0x1098)"},
{0x8086, 0x1099, 0xFFFF, 0xFFFF, "82546GB Gigabit Ethernet Controller (Copper)(0x1099)"},
{0x8086, 0x1099, 0x8086, 0x1099, "PRO/1000 GT Quad Port Server Adapter(0x8086-0x1099)"},
{0x8086, 0x109A, 0xFFFF, 0xFFFF, "82573L Gigabit Ethernet Controller(0x109A)"},
{0x8086, 0x109A, 0x1179, 0xFF10, "PRO/1000 PL(0x1179-0xFF10)"},
{0x8086, 0x109A, 0x17AA, 0x2001, "ThinkPad T60(0x17AA-0x2001)"},
{0x8086, 0x109A, 0x17AA, 0x207E, "ThinkPad X60/X60s(0x17AA-0x207E)"},
{0x8086, 0x109A, 0x8086, 0x109A, "PRO/1000 PL Network Connection(0x8086-0x109A)"},
{0x8086, 0x109A, 0x8086, 0x309C, "Desktop Board D945GTP(0x8086-0x309C)"},
{0x8086, 0x109A, 0x8086, 0x30A5, "Desktop Board D975XBX(0x8086-0x30A5)"},
{0x8086, 0x109B, 0xFFFF, 0xFFFF, "82546GB PRO/1000 GF Quad Port Server Adapter(0x109B)"},
{0x8086, 0x109E, 0xFFFF, 0xFFFF, "82597EX 10GbE Ethernet Controller(0x109E)"},
{0x8086, 0x109E, 0x8086, 0xA01F, "PRO/10GbE CX4 Server Adapter(0x8086-0xA01F)"},
{0x8086, 0x109E, 0x8086, 0xA11F, "PRO/10GbE CX4 Server Adapter(0x8086-0xA11F)"},
{0x8086, 0x10A0, 0xFFFF, 0xFFFF, "82571EB PRO/1000 AT Quad Port Bypass Adapter(0x10A0)"},
{0x8086, 0x10A1, 0xFFFF, 0xFFFF, "82571EB PRO/1000 AF Quad Port Bypass Adapter(0x10A1)"},
{0x8086, 0x10A4, 0xFFFF, 0xFFFF, "82571EB Gigabit Ethernet Controller(0x10A4)"},
{0x8086, 0x10A4, 0x8086, 0x10A4, "PRO/1000 PT Quad Port Server Adapter(0x8086-0x10A4)"},
{0x8086, 0x10A4, 0x8086, 0x11A4, "PRO/1000 PT Quad Port Server Adapter(0x8086-0x11A4)"},
{0x8086, 0x10A5, 0xFFFF, 0xFFFF, "82571EB Gigabit Ethernet Controller (Fiber)(0x10A5)"},
{0x8086, 0x10A5, 0x8086, 0x10A5, "PRO/1000 PF Quad Port Server Adapter(0x8086-0x10A5)"},
{0x8086, 0x10A5, 0x8086, 0x10A6, "PRO/1000 PF Quad Port Server Adapter(0x8086-0x10A6)"},
{0x8086, 0x10A6, 0xFFFF, 0xFFFF, "82599EB 10-Gigabit Dummy Function(0x10A6)"},
{0x8086, 0x10A7, 0xFFFF, 0xFFFF, "82575EB Gigabit Network Connection(0x10A7)"},
{0x8086, 0x10A7, 0x8086, 0x10A8, "82575EB Gigabit Riser Card(0x8086-0x10A8)"},
{0x8086, 0x10A9, 0xFFFF, 0xFFFF, "82575EB Gigabit Backplane Connection(0x10A9)"},
{0x8086, 0x10B0, 0xFFFF, 0xFFFF, "82573L PRO/1000 PL Network Connection(0x10B0)"},
{0x8086, 0x10B2, 0xFFFF, 0xFFFF, "82573V PRO/1000 PM Network Connection(0x10B2)"},
{0x8086, 0x10B3, 0xFFFF, 0xFFFF, "82573E PRO/1000 PM Network Connection(0x10B3)"},
{0x8086, 0x10B4, 0xFFFF, 0xFFFF, "82573L PRO/1000 PL Network Connection(0x10B4)"},
{0x8086, 0x10B5, 0xFFFF, 0xFFFF, "82546GB Gigabit Ethernet Controller (Copper)(0x10B5)"},
{0x8086, 0x10B5, 0x103C, 0x3109, "NC340T PCI-X Quad-port Gigabit Server Adapter(0x103C-0x3109)"},
{0x8086, 0x10B5, 0x8086, 0x1099, "PRO/1000 GT Quad Port Server Adapter(0x8086-0x1099)"},
{0x8086, 0x10B5, 0x8086, 0x1199, "PRO/1000 GT Quad Port Server Adapter(0x8086-0x1199)"},
{0x8086, 0x10B6, 0xFFFF, 0xFFFF, "82598 10GbE PCI-Express Ethernet Controller(0x10B6)"},
{0x8086, 0x10B9, 0xFFFF, 0xFFFF, "82572EI Gigabit Ethernet Controller (Copper)(0x10B9)"},
{0x8086, 0x10B9, 0x103C, 0x704A, "110T PCIe Gigabit Server Adapter(0x103C-0x704A)"},
{0x8086, 0x10B9, 0x8086, 0x1083, "PRO/1000 PT Desktop Adapter(0x8086-0x1083)"},
{0x8086, 0x10B9, 0x8086, 0x1093, "PRO/1000 PT Desktop Adapter(0x8086-0x1093)"},
{0x8086, 0x10BA, 0xFFFF, 0xFFFF, "80003ES2LAN Gigabit Ethernet Controller (Copper)(0x10BA)"},
{0x8086, 0x10BB, 0xFFFF, 0xFFFF, "80003ES2LAN Gigabit Ethernet Controller (Serdes)(0x10BB)"},
{0x8086, 0x10BC, 0xFFFF, 0xFFFF, "82571EB/82571GB Gigabit Ethernet Controller (Copper)(0x10BC)"},
{0x8086, 0x10BC, 0x1014, 0x0368, "4-Port 10/100/1000 Base-TX PCI Express Adapter for POWER(0x1014-0x0368)"},
{0x8086, 0x10BC, 0x103C, 0x704B, "NC364T PCI Express Quad Port Gigabit Server Adapter(0x103C-0x704B)"},
{0x8086, 0x10BC, 0x108E, 0x11BC, "Quad Port Adapter(0x108E-0x11BC)"},
{0x8086, 0x10BC, 0x8086, 0x10BC, "PRO/1000 PT Quad Port LP Server Adapter(0x8086-0x10BC)"},
{0x8086, 0x10BC, 0x8086, 0x11BC, "PRO/1000 PT Quad Port LP Server Adapter (Kirkwood Low Profile)(0x8086-0x11BC)"},
{0x8086, 0x10BD, 0xFFFF, 0xFFFF, "82566DM-2 Gigabit Network Connection(0x10BD)"},
{0x8086, 0x10BD, 0x1028, 0x0211, "OptiPlex 755(0x1028-0x0211)"},
{0x8086, 0x10BF, 0xFFFF, 0xFFFF, "82567LF Gigabit Network Connection(0x10BF)"},
{0x8086, 0x10C0, 0xFFFF, 0xFFFF, "82562V-2 10/100 Network Connection(0x10C0)"},
{0x8086, 0x10C0, 0x1028, 0x020D, "Inspiron 530(0x1028-0x020D)"},
{0x8086, 0x10C2, 0xFFFF, 0xFFFF, "82562G-2 10/100 Network Connection(0x10C2)"},
{0x8086, 0x10C3, 0xFFFF, 0xFFFF, "82562GT-2 10/100 Network Connection(0x10C3)"},
{0x8086, 0x10C4, 0xFFFF, 0xFFFF, "82562GT 10/100 Network Connection(0x10C4)"},
{0x8086, 0x10C5, 0xFFFF, 0xFFFF, "82562G 10/100 Network Connection(0x10C5)"},
{0x8086, 0x10C6, 0xFFFF, 0xFFFF, "82598EB 10-Gigabit AF Dual Port Network Connection(0x10C6)"},
{0x8086, 0x10C6, 0x8086, 0xA05F, "10-Gigabit XF SR Dual Port Server Adapter(0x8086-0xA05F)"},
{0x8086, 0x10C6, 0x8086, 0xA15F, "10-Gigabit XF SR Dual Port Server Adapter(0x8086-0xA15F)"},
{0x8086, 0x10C7, 0xFFFF, 0xFFFF, "82598EB 10-Gigabit AF Network Connection(0x10C7)"},
{0x8086, 0x10C7, 0x1014, 0x037F, "10-Gigabit XF SR Server Adapter(0x1014-0x037F)"},
{0x8086, 0x10C7, 0x1014, 0x0380, "10-Gigabit XF LR Server Adapter(0x1014-0x0380)"},
{0x8086, 0x10C7, 0x8086, 0xA05F, "10-Gigabit XF SR Server Adapter(0x8086-0xA05F)"},
{0x8086, 0x10C7, 0x8086, 0xA15F, "10-Gigabit XF SR Server Adapter(0x8086-0xA15F)"},
{0x8086, 0x10C7, 0x8086, 0xA16F, "10-Gigabit XF SR Server Adapter(0x8086-0xA16F)"},
{0x8086, 0x10C8, 0xFFFF, 0xFFFF, "82598EB 10-Gigabit AT Network Connection(0x10C8)"},
{0x8086, 0x10C8, 0x8086, 0xA10C, "10-Gigabit AT Server Adapter(0x8086-0xA10C)"},
{0x8086, 0x10C8, 0x8086, 0xA11C, "10-Gigabit AT Server Adapter(0x8086-0xA11C)"},
{0x8086, 0x10C8, 0x8086, 0xA12C, "10-Gigabit AT Server Adapter(0x8086-0xA12C)"},
{0x8086, 0x10C9, 0xFFFF, 0xFFFF, "82576 Gigabit Network Connection(0x10C9)"},
{0x8086, 0x10C9, 0x103C, 0x31EF, "NC362i Integrated Dual port Gigabit Server Adapter(0x103C-0x31EF)"},
{0x8086, 0x10C9, 0x103C, 0x323F, "NC362i Integrated Dual port Gigabit Server Adapter(0x103C-0x323F)"},
{0x8086, 0x10C9, 0x10A9, 0x8028, "UV-BaseIO dual-port GbE(0x10A9-0x8028)"},
{0x8086, 0x10C9, 0x13A3, 0x0037, "DS4100 Secure Multi-Gigabit Server Adapter with Compression(0x13A3-0x0037)"},
{0x8086, 0x10C9, 0x15D9, 0xA811, "H8DGU(0x15D9-0xA811)"},
{0x8086, 0x10C9, 0x4C52, 0x9212, "LREC9212PT Dual-port 10Gb Ethernet Network Adapter(0x4C52-0x9212)"},
{0x8086, 0x10C9, 0x8086, 0xA01C, "Gigabit ET Dual Port Server Adapter(0x8086-0xA01C)"},
{0x8086, 0x10C9, 0x8086, 0xA03C, "Gigabit ET Dual Port Server Adapter(0x8086-0xA03C)"},
{0x8086, 0x10C9, 0x8086, 0xA04C, "Gigabit ET Dual Port Server Adapter(0x8086-0xA04C)"},
{0x8086, 0x10CA, 0xFFFF, 0xFFFF, "82576 Virtual Function(0x10CA)"},
{0x8086, 0x10CB, 0xFFFF, 0xFFFF, "82567V Gigabit Network Connection(0x10CB)"},
{0x8086, 0x10CC, 0xFFFF, 0xFFFF, "82567LM-2 Gigabit Network Connection(0x10CC)"},
{0x8086, 0x10CD, 0xFFFF, 0xFFFF, "82567LF-2 Gigabit Network Connection(0x10CD)"},
{0x8086, 0x10CE, 0xFFFF, 0xFFFF, "82567V-2 Gigabit Network Connection(0x10CE)"},
{0x8086, 0x10D3, 0xFFFF, 0xFFFF, "82574L Gigabit Network Connection(0x10D3)"},
{0x8086, 0x10D3, 0x103C, 0x1785, "NC112i 1-port Ethernet Server Adapter(0x103C-0x1785)"},
{0x8086, 0x10D3, 0x103C, 0x3250, "NC112T PCI Express single Port Gigabit Server Adapter(0x103C-0x3250)"},
{0x8086, 0x10D3, 0x1043, 0x8369, "Motherboard(0x1043-0x8369)"},
{0x8086, 0x10D3, 0x1093, 0x76E9, "PCIe-8233 Ethernet Adapter(0x1093-0x76E9)"},
{0x8086, 0x10D3, 0x10A9, 0x8029, "Prism XL Single Port Gigabit Ethernet(0x10A9-0x8029)"},
{0x8086, 0x10D3, 0x15D9, 0x0605, "X8SIL(0x15D9-0x0605)"},
{0x8086, 0x10D3, 0x15D9, 0x060A, "X7SPA-H/X7SPA-HF Motherboard(0x15D9-0x060A)"},
{0x8086, 0x10D3, 0x15D9, 0x060D, "C7SIM-Q Motherboard(0x15D9-0x060D)"},
{0x8086, 0x10D3, 0x4C52, 0x2201, "LRES2201PT Single-port 1Gb Ethernet Network Adapter(0x4C52-0x2201)"},
{0x8086, 0x10D3, 0x8086, 0x0001, "Gigabit CT2 Desktop Adapter(0x8086-0x0001)"},
{0x8086, 0x10D3, 0x8086, 0x3578, "Server Board S1200BTLR(0x8086-0x3578)"},
{0x8086, 0x10D3, 0x8086, 0x357A, "Server Board S1200BTS(0x8086-0x357A)"},
{0x8086, 0x10D3, 0x8086, 0xA01F, "Gigabit CT Desktop Adapter(0x8086-0xA01F)"},
{0x8086, 0x10D3, 0xE4BF, 0x50C1, "PC1-GROOVE(0xE4BF-0x50C1)"},
{0x8086, 0x10D3, 0xE4BF, 0x50C2, "PC2-LIMBO(0xE4BF-0x50C2)"},
{0x8086, 0x10D4, 0xFFFF, 0xFFFF, "Matrox Concord GE (customized Intel 82574)(0x10D4)"},
{0x8086, 0x10D5, 0xFFFF, 0xFFFF, "82571PT Gigabit PT Quad Port Server ExpressModule(0x10D5)"},
{0x8086, 0x10D6, 0xFFFF, 0xFFFF, "82575GB Gigabit Network Connection(0x10D6)"},
{0x8086, 0x10D6, 0x8086, 0x10D6, "Gigabit VT Quad Port Server Adapter(0x8086-0x10D6)"},
{0x8086, 0x10D6, 0x8086, 0x145A, "Gigabit VT Quad Port Server Adapter(0x8086-0x145A)"},
{0x8086, 0x10D6, 0x8086, 0x147A, "Gigabit VT Quad Port Server Adapter(0x8086-0x147A)"},
{0x8086, 0x10D8, 0xFFFF, 0xFFFF, "82599EB 10 Gigabit Unprogrammed(0x10D8)"},
{0x8086, 0x10D9, 0xFFFF, 0xFFFF, "82571EB Dual Port Gigabit Mezzanine Adapter(0x10D9)"},
{0x8086, 0x10D9, 0x103C, 0x1716, "NC360m Dual Port 1GbE BL-c Adapter(0x103C-0x1716)"},
{0x8086, 0x10DA, 0xFFFF, 0xFFFF, "82571EB Quad Port Gigabit Mezzanine Adapter(0x10DA)"},
{0x8086, 0x10DA, 0x103C, 0x1717, "NC364m Quad Port 1GbE BL-c Adapter(0x103C-0x1717)"},
{0x8086, 0x10DB, 0xFFFF, 0xFFFF, "82598EB 10-Gigabit Dual Port Network Connection(0x10DB)"},
{0x8086, 0x10DD, 0xFFFF, 0xFFFF, "82598EB 10-Gigabit AT CX4 Network Connection(0x10DD)"},
{0x8086, 0x10DE, 0xFFFF, 0xFFFF, "82567LM-3 Gigabit Network Connection(0x10DE)"},
{0x8086, 0x10DF, 0xFFFF, 0xFFFF, "82567LF-3 Gigabit Network Connection(0x10DF)"},
{0x8086, 0x10E1, 0xFFFF, 0xFFFF, "82598EB 10-Gigabit AF Dual Port Network Connection(0x10E1)"},
{0x8086, 0x10E1, 0x8086, 0xA15F, "10-Gigabit SR Dual Port Express Module(0x8086-0xA15F)"},
{0x8086, 0x10E2, 0xFFFF, 0xFFFF, "82575GB Gigabit Network Connection(0x10E2)"},
{0x8086, 0x10E2, 0x8086, 0x10E2, "Gigabit VT Quad Port Server Adapter(0x8086-0x10E2)"},
{0x8086, 0x10E5, 0xFFFF, 0xFFFF, "82567LM-4 Gigabit Network Connection(0x10E5)"},
{0x8086, 0x10E6, 0xFFFF, 0xFFFF, "82576 Gigabit Network Connection(0x10E6)"},
{0x8086, 0x10E6, 0x8086, 0xA01F, "Gigabit EF Dual Port Server Adapter(0x8086-0xA01F)"},
{0x8086, 0x10E6, 0x8086, 0xA02F, "Gigabit EF Dual Port Server Adapter(0x8086-0xA02F)"},
{0x8086, 0x10E7, 0xFFFF, 0xFFFF, "82576 Gigabit Network Connection(0x10E7)"},
{0x8086, 0x10E7, 0x103C, 0x31FF, "NC362i Integrated Dual Port BL-c Gigabit Server Adapter(0x103C-0x31FF)"},
{0x8086, 0x10E7, 0x4C52, 0x9701, "LREC9701EF Single-port 1Gb Ethernet Network Adapter(0x4C52-0x9701)"},
{0x8086, 0x10E8, 0xFFFF, 0xFFFF, "82576 Gigabit Network Connection(0x10E8)"},
{0x8086, 0x10E8, 0x8086, 0xA02B, "Gigabit ET Quad Port Server Adapter(0x8086-0xA02B)"},
{0x8086, 0x10E8, 0x8086, 0xA02C, "Gigabit ET Quad Port Server Adapter(0x8086-0xA02C)"},
{0x8086, 0x10EA, 0xFFFF, 0xFFFF, "82577LM Gigabit Network Connection(0x10EA)"},
{0x8086, 0x10EA, 0x1028, 0x040A, "Latitude E6410(0x1028-0x040A)"},
{0x8086, 0x10EA, 0x1028, 0x040B, "Latitude E6510(0x1028-0x040B)"},
{0x8086, 0x10EA, 0xE4BF, 0x50C1, "PC1-GROOVE(0xE4BF-0x50C1)"},
{0x8086, 0x10EB, 0xFFFF, 0xFFFF, "82577LC Gigabit Network Connection(0x10EB)"},
{0x8086, 0x10EC, 0xFFFF, 0xFFFF, "82598EB 10-Gigabit AT CX4 Network Connection(0x10EC)"},
{0x8086, 0x10EC, 0x8086, 0xA01F, "10-Gigabit CX4 Dual Port Server Adapter(0x8086-0xA01F)"},
{0x8086, 0x10EC, 0x8086, 0xA11F, "10-Gigabit CX4 Dual Port Server Adapter(0x8086-0xA11F)"},
{0x8086, 0x10ED, 0xFFFF, 0xFFFF, "82599 Ethernet Controller Virtual Function(0x10ED)"},
{0x8086, 0x10EF, 0xFFFF, 0xFFFF, "82578DM Gigabit Network Connection(0x10EF)"},
{0x8086, 0x10EF, 0x1028, 0x02DA, "OptiPlex 980(0x1028-0x02DA)"},
{0x8086, 0x10EF, 0x15D9, 0x060D, "C7SIM-Q Motherboard(0x15D9-0x060D)"},
{0x8086, 0x10F0, 0xFFFF, 0xFFFF, "82578DC Gigabit Network Connection(0x10F0)"},
{0x8086, 0x10F1, 0xFFFF, 0xFFFF, "82598EB 10-Gigabit AF Dual Port Network Connection(0x10F1)"},
{0x8086, 0x10F1, 0x8086, 0xA20F, "10-Gigabit AF DA Dual Port Server Adapter(0x8086-0xA20F)"},
{0x8086, 0x10F1, 0x8086, 0xA21F, "10-Gigabit AF DA Dual Port Server Adapter(0x8086-0xA21F)"},
{0x8086, 0x10F4, 0xFFFF, 0xFFFF, "82598EB 10-Gigabit AF Network Connection(0x10F4)"},
{0x8086, 0x10F4, 0x8086, 0x106F, "10-Gigabit XF LR Server Adapter(0x8086-0x106F)"},
{0x8086, 0x10F4, 0x8086, 0xA06F, "10-Gigabit XF LR Server Adapter(0x8086-0xA06F)"},
{0x8086, 0x10F5, 0xFFFF, 0xFFFF, "82567LM Gigabit Network Connection(0x10F5)"},
{0x8086, 0x10F5, 0x17AA, 0x20EE, "ThinkPad T400(0x17AA-0x20EE)"},
{0x8086, 0x10F6, 0xFFFF, 0xFFFF, "82574L Gigabit Network Connection(0x10F6)"},
{0x8086, 0x10F7, 0xFFFF, 0xFFFF, "10 Gigabit BR KX4 Dual Port Network Connection(0x10F7)"},
{0x8086, 0x10F7, 0x108E, 0x7B12, "Sun Dual 10GbE PCIe 2.0 FEM(0x108E-0x7B12)"},
{0x8086, 0x10F7, 0x8086, 0x000D, "Ethernet Mezzanine Adapter X520-KX4-2(0x8086-0x000D)"},
{0x8086, 0x10F8, 0xFFFF, 0xFFFF, "82599 10 Gigabit Dual Port Backplane Connection(0x10F8)"},
{0x8086, 0x10F8, 0x1028, 0x1F63, "10GbE 2P X520k bNDC(0x1028-0x1F63)"},
{0x8086, 0x10F8, 0x103C, 0x17D2, "Ethernet 10Gb 2-port 560M Adapter(0x103C-0x17D2)"},
{0x8086, 0x10F8, 0x103C, 0x18D0, "Ethernet 10Gb 2-port 560FLB Adapter(0x103C-0x18D0)"},
{0x8086, 0x10F8, 0x1059, 0x0111, "T4007 10GbE interface(0x1059-0x0111)"},
{0x8086, 0x10F8, 0x1059, 0x0130, "T4009 10GbE interface(0x1059-0x0130)"},
{0x8086, 0x10F8, 0x8086, 0x000C, "Ethernet X520 10GbE Dual Port KX4-KR Mezz(0x8086-0x000C)"},
{0x8086, 0x10F9, 0xFFFF, 0xFFFF, "82599 10 Gigabit Dual Port Network Connection(0x10F9)"},
{0x8086, 0x10FB, 0xFFFF, 0xFFFF, "82599ES 10-Gigabit SFI/SFP+ Network Connection(0x10FB)"},
{0x8086, 0x10FB, 0x1028, 0x1F72, "Ethernet 10G 4P X520/I350 rNDC(0x1028-0x1F72)"},
{0x8086, 0x10FB, 0x103C, 0x17D0, "Ethernet 10Gb 2-port 560FLR-SFP+ Adapter(0x103C-0x17D0)"},
{0x8086, 0x10FB, 0x103C, 0x17D2, "Ethernet 10Gb 2-port 560M Adapter(0x103C-0x17D2)"},
{0x8086, 0x10FB, 0x103C, 0x17D3, "Ethernet 10Gb 2-port 560SFP+ Adapter(0x103C-0x17D3)"},
{0x8086, 0x10FB, 0x103C, 0x211B, "Ethernet 10Gb 1-port P560FLR-SFP+ Adapter(0x103C-0x211B)"},
{0x8086, 0x10FB, 0x103C, 0x2147, "Ethernet 10Gb 1-port 561i Adapter(0x103C-0x2147)"},
{0x8086, 0x10FB, 0x103C, 0x2159, "Ethernet 10Gb 2-port 562i Adapter(0x103C-0x2159)"},
{0x8086, 0x10FB, 0x108E, 0x7B11, "Ethernet Server Adapter X520-2(0x108E-0x7B11)"},
{0x8086, 0x10FB, 0x1170, 0x004C, "82599 DP 10G Mezzanine Adapter(0x1170-0x004C)"},
{0x8086, 0x10FB, 0x1374, 0x1A08, "PE310G4SPI9/PE310G4SPI9L/PE310G4SPI9LA Quad Port Fiber 10 Gigabit Ethernet PCI Express Server Adapter(0x1374-0x1A08)"},
{0x8086, 0x10FB, 0x15D9, 0x0611, "AOC-STGN-i2S(0x15D9-0x0611)"},
{0x8086, 0x10FB, 0x1734, 0x11A9, "10 Gigabit Dual Port Network Connection(0x1734-0x11A9)"},
{0x8086, 0x10FB, 0x17AA, 0x1071, "ThinkServer X520-2 AnyFabric(0x17AA-0x1071)"},
{0x8086, 0x10FB, 0x17AA, 0x4007, "82599ES 10-Gigabit SFI/SFP+ Network Connection(0x17AA-0x4007)"},
{0x8086, 0x10FB, 0x17AA, 0x402B, "82599ES 10Gb 2-port Server Adapter X520-DA2(0x17AA-0x402B)"},
{0x8086, 0x10FB, 0x17AA, 0x402F, "FPGA Card XC7VX690T-3FFG1157E(0x17AA-0x402F)"},
{0x8086, 0x10FB, 0x18D4, 0x0C09, "82599ES 10Gb 2-port SFP+ OCP Mezz Card MOP81-I-10GS2(0x18D4-0x0C09)"},
{0x8086, 0x10FB, 0x193D, 0x1004, "560F-B(0x193D-0x1004)"},
{0x8086, 0x10FB, 0x1BD4, 0x001B, "10G SFP+ DP ER102Fi4 Rack Adapter(0x1BD4-0x001B)"},
{0x8086, 0x10FB, 0x1BD4, 0x002F, "10G SFP+ DP EP102Fi4A Adapter(0x1BD4-0x002F)"},
{0x8086, 0x10FB, 0x1BD4, 0x0032, "10G SFP+ DP EP102Fi4 Adapter(0x1BD4-0x0032)"},
{0x8086, 0x10FB, 0x1BD4, 0x0067, "F102I82599(0x1BD4-0x0067)"},
{0x8086, 0x10FB, 0x4C52, 0x1024, "LR-LINK LRES9804BF Quad-port 10Gb Ethernet Server Adapter(0x4C52-0x1024)"},
{0x8086, 0x10FB, 0x4C52, 0x3002, "LRES3002PF Dual-port 10Gb Ethernet Server Adapter for OCP(0x4C52-0x3002)"},
{0x8086, 0x10FB, 0x4C52, 0x3012, "LRES3012PF Dual-port 10Gb Ethernet Server Adapter for OCP(0x4C52-0x3012)"},
{0x8086, 0x10FB, 0x4C52, 0x9801, "LREC9801BF Single-port 10Gb Ethernet Server Adapter(0x4C52-0x9801)"},
{0x8086, 0x10FB, 0x4C52, 0x9802, "LREC9802BF Dual-port 10Gb Ethernet Server Adapter(0x4C52-0x9802)"},
{0x8086, 0x10FB, 0x8086, 0x0002, "Ethernet Server Adapter X520-DA2(0x8086-0x0002)"},
{0x8086, 0x10FB, 0x8086, 0x0003, "Ethernet Server Adapter X520-2(0x8086-0x0003)"},
{0x8086, 0x10FB, 0x8086, 0x0006, "Ethernet Server Adapter X520-1(0x8086-0x0006)"},
{0x8086, 0x10FB, 0x8086, 0x0008, "Ethernet OCP Server Adapter X520-2(0x8086-0x0008)"},
{0x8086, 0x10FB, 0x8086, 0x000A, "Ethernet Server Adapter X520-1(0x8086-0x000A)"},
{0x8086, 0x10FB, 0x8086, 0x000C, "Ethernet Server Adapter X520-2(0x8086-0x000C)"},
{0x8086, 0x10FB, 0x8086, 0x10A6, "82599ES 10Gb 2 port Server Adapter X520-DA2(0x8086-0x10A6)"},
{0x8086, 0x10FB, 0x8086, 0x7A11, "Ethernet Server Adapter X520-2(0x8086-0x7A11)"},
{0x8086, 0x10FB, 0x8086, 0x7A12, "Ethernet Server Adapter X520-2(0x8086-0x7A12)"},
{0x8086, 0x10FC, 0xFFFF, 0xFFFF, "82599 10 Gigabit Dual Port Network Connection(0x10FC)"},
{0x8086, 0x10FE, 0xFFFF, 0xFFFF, "82552 10/100 Network Connection(0x10FE)"},
{0x8086, 0x1107, 0xFFFF, 0xFFFF, "PRO/1000 MF Server Adapter (LX)(0x1107)"},
{0x8086, 0x1130, 0xFFFF, 0xFFFF, "82815 815 Chipset Host Bridge and Memory Controller Hub(0x1130)"},
{0x8086, 0x1130, 0x1025, 0x1016, "Travelmate 612 TX(0x1025-0x1016)"},
{0x8086, 0x1130, 0x1043, 0x8027, "CUSL2-C/TUSL2-C Mainboard(0x1043-0x8027)"},
{0x8086, 0x1130, 0x104D, 0x80DF, "Vaio PCG-FX403(0x104D-0x80DF)"},
{0x8086, 0x1130, 0x8086, 0x4532, "Desktop Board D815EEA2/D815EFV(0x8086-0x4532)"},
{0x8086, 0x1130, 0x8086, 0x4557, "D815EGEW Mainboard(0x8086-0x4557)"},
{0x8086, 0x1131, 0xFFFF, 0xFFFF, "82815 815 Chipset AGP Bridge(0x1131)"},
{0x8086, 0x1132, 0xFFFF, 0xFFFF, "82815 Chipset Graphics Controller (CGC)(0x1132)"},
{0x8086, 0x1132, 0x1025, 0x1016, "Travelmate 612 TX(0x1025-0x1016)"},
{0x8086, 0x1132, 0x103C, 0x2001, "e-pc 40(0x103C-0x2001)"},
{0x8086, 0x1132, 0x104D, 0x80DF, "Vaio PCG-FX403(0x104D-0x80DF)"},
{0x8086, 0x1132, 0x8086, 0x4532, "Desktop Board D815EEA2/D815EFV(0x8086-0x4532)"},
{0x8086, 0x1132, 0x8086, 0x4541, "D815EEA Motherboard(0x8086-0x4541)"},
{0x8086, 0x1132, 0x8086, 0x4557, "D815EGEW Mainboard(0x8086-0x4557)"},
{0x8086, 0x1136, 0xFFFF, 0xFFFF, "Thunderbolt 4 Bridge [Maple Ridge 4C 2020](0x1136)"},
{0x8086, 0x1137, 0xFFFF, 0xFFFF, "Thunderbolt 4 NHI [Maple Ridge 4C 2020](0x1137)"},
{0x8086, 0x1138, 0xFFFF, 0xFFFF, "Thunderbolt 4 USB Controller [Maple Ridge 4C 2020](0x1138)"},
{0x8086, 0x1161, 0xFFFF, 0xFFFF, "82806AA PCI64 Hub Advanced Programmable Interrupt Controller(0x1161)"},
{0x8086, 0x1161, 0x8086, 0x1161, "82806AA PCI64 Hub APIC(0x8086-0x1161)"},
{0x8086, 0x1162, 0xFFFF, 0xFFFF, "Xscale 80200 Big Endian Companion Chip(0x1162)"},
{0x8086, 0x1190, 0xFFFF, 0xFFFF, "Merrifield SD/SDIO/eMMC Controller(0x1190)"},
{0x8086, 0x1191, 0xFFFF, 0xFFFF, "Merrifield Serial IO HSUART Controller(0x1191)"},
{0x8086, 0x1192, 0xFFFF, 0xFFFF, "Merrifield Serial IO HSUART DMA Controller(0x1192)"},
{0x8086, 0x1194, 0xFFFF, 0xFFFF, "Merrifield Serial IO SPI Controller(0x1194)"},
{0x8086, 0x1195, 0xFFFF, 0xFFFF, "Merrifield Serial IO I2C Controller(0x1195)"},
{0x8086, 0x1196, 0xFFFF, 0xFFFF, "Merrifield Serial IO I2C Controller(0x1196)"},
{0x8086, 0x1199, 0xFFFF, 0xFFFF, "Merrifield GPIO Controller(0x1199)"},
{0x8086, 0x119E, 0xFFFF, 0xFFFF, "Merrifield USB Device Controller (OTG)(0x119E)"},
{0x8086, 0x11A0, 0xFFFF, 0xFFFF, "Merrifield SCU IPC(0x11A0)"},
{0x8086, 0x11A1, 0xFFFF, 0xFFFF, "Merrifield Power Management Unit(0x11A1)"},
{0x8086, 0x11A2, 0xFFFF, 0xFFFF, "Merrifield Serial IO DMA Controller(0x11A2)"},
{0x8086, 0x11A5, 0xFFFF, 0xFFFF, "Merrifield Serial IO PWM Controller(0x11A5)"},
{0x8086, 0x11C3, 0xFFFF, 0xFFFF, "Quark SoC X1000 PCIe Root Port 0(0x11C3)"},
{0x8086, 0x11C4, 0xFFFF, 0xFFFF, "Quark SoC X1000 PCIe Root Port 1(0x11C4)"},
{0x8086, 0x11EB, 0xFFFF, 0xFFFF, "Simics NVMe Controller(0x11EB)"},
{0x8086, 0x1200, 0xFFFF, 0xFFFF, "IXP1200 Network Processor(0x1200)"},
{0x8086, 0x1200, 0x172A, 0x0000, "AEP SSL Accelerator(0x172A-0x0000)"},
{0x8086, 0x1209, 0xFFFF, 0xFFFF, "8255xER/82551IT Fast Ethernet Controller(0x1209)"},
{0x8086, 0x1209, 0x140B, 0x0610, "PMC610 quad Ethernet board(0x140B-0x0610)"},
{0x8086, 0x1209, 0x1AF4, 0x1100, "QEMU Virtual Machine(0x1AF4-0x1100)"},
{0x8086, 0x1209, 0x4C53, 0x1050, "CT7 mainboard(0x4C53-0x1050)"},
{0x8086, 0x1209, 0x4C53, 0x1051, "CE7 mainboard(0x4C53-0x1051)"},
{0x8086, 0x1209, 0x4C53, 0x1070, "PC6 mainboard(0x4C53-0x1070)"},
{0x8086, 0x1221, 0xFFFF, 0xFFFF, "82092AA PCI to PCMCIA Bridge(0x1221)"},
{0x8086, 0x1222, 0xFFFF, 0xFFFF, "82092AA IDE Controller(0x1222)"},
{0x8086, 0x1223, 0xFFFF, 0xFFFF, "SAA7116(0x1223)"},
{0x8086, 0x1225, 0xFFFF, 0xFFFF, "82452KX/GX [Orion](0x1225)"},
{0x8086, 0x1226, 0xFFFF, 0xFFFF, "82596 PRO/10 PCI(0x1226)"},
{0x8086, 0x1227, 0xFFFF, 0xFFFF, "82865 EtherExpress PRO/100A(0x1227)"},
{0x8086, 0x1228, 0xFFFF, 0xFFFF, "82556 EtherExpress PRO/100 Smart(0x1228)"},
{0x8086, 0x1229, 0xFFFF, 0xFFFF, "82557/8/9/0/1 Ethernet Pro 100(0x1229)"},
{0x8086, 0x1229, 0x0E11, 0x3001, "82559 Fast Ethernet LOM with Alert on LAN*(0x0E11-0x3001)"},
{0x8086, 0x1229, 0x0E11, 0x3002, "82559 Fast Ethernet LOM with Alert on LAN*(0x0E11-0x3002)"},
{0x8086, 0x1229, 0x0E11, 0x3003, "82559 Fast Ethernet LOM with Alert on LAN*(0x0E11-0x3003)"},
{0x8086, 0x1229, 0x0E11, 0x3004, "82559 Fast Ethernet LOM with Alert on LAN*(0x0E11-0x3004)"},
{0x8086, 0x1229, 0x0E11, 0x3005, "82559 Fast Ethernet LOM with Alert on LAN*(0x0E11-0x3005)"},
{0x8086, 0x1229, 0x0E11, 0x3006, "82559 Fast Ethernet LOM with Alert on LAN*(0x0E11-0x3006)"},
{0x8086, 0x1229, 0x0E11, 0x3007, "82559 Fast Ethernet LOM with Alert on LAN*(0x0E11-0x3007)"},
{0x8086, 0x1229, 0x0E11, 0xB01E, "NC3120 Fast Ethernet NIC(0x0E11-0xB01E)"},
{0x8086, 0x1229, 0x0E11, 0xB01F, "NC3122 Fast Ethernet NIC (dual port)(0x0E11-0xB01F)"},
{0x8086, 0x1229, 0x0E11, 0xB02F, "NC1120 Ethernet NIC(0x0E11-0xB02F)"},
{0x8086, 0x1229, 0x0E11, 0xB04A, "Netelligent 10/100TX NIC with Wake on LAN(0x0E11-0xB04A)"},
{0x8086, 0x1229, 0x0E11, 0xB0C6, "NC3161 Fast Ethernet NIC (embedded, WOL)(0x0E11-0xB0C6)"},
{0x8086, 0x1229, 0x0E11, 0xB0C7, "NC3160 Fast Ethernet NIC (embedded)(0x0E11-0xB0C7)"},
{0x8086, 0x1229, 0x0E11, 0xB0D7, "NC3121 Fast Ethernet NIC (WOL)(0x0E11-0xB0D7)"},
{0x8086, 0x1229, 0x0E11, 0xB0DD, "NC3131 Fast Ethernet NIC (dual port)(0x0E11-0xB0DD)"},
{0x8086, 0x1229, 0x0E11, 0xB0DE, "NC3132 Fast Ethernet Module (dual port)(0x0E11-0xB0DE)"},
{0x8086, 0x1229, 0x0E11, 0xB0E1, "NC3133 Fast Ethernet Module (100-FX)(0x0E11-0xB0E1)"},
{0x8086, 0x1229, 0x0E11, 0xB134, "NC3163 Fast Ethernet NIC (embedded, WOL)(0x0E11-0xB134)"},
{0x8086, 0x1229, 0x0E11, 0xB13C, "NC3162 Fast Ethernet NIC (embedded)(0x0E11-0xB13C)"},
{0x8086, 0x1229, 0x0E11, 0xB144, "NC3123 Fast Ethernet NIC (WOL)(0x0E11-0xB144)"},
{0x8086, 0x1229, 0x0E11, 0xB163, "NC3134 Fast Ethernet NIC (dual port)(0x0E11-0xB163)"},
{0x8086, 0x1229, 0x0E11, 0xB164, "NC3135 Fast Ethernet Upgrade Module (dual port)(0x0E11-0xB164)"},
{0x8086, 0x1229, 0x0E11, 0xB1A4, "NC7131 Gigabit Server Adapter(0x0E11-0xB1A4)"},
{0x8086, 0x1229, 0x1014, 0x005C, "82558B Ethernet Pro 10/100(0x1014-0x005C)"},
{0x8086, 0x1229, 0x1014, 0x01BC, "82559 Fast Ethernet LAN On Motherboard(0x1014-0x01BC)"},
{0x8086, 0x1229, 0x1014, 0x01F1, "10/100 Ethernet Server Adapter(0x1014-0x01F1)"},
{0x8086, 0x1229, 0x1014, 0x01F2, "10/100 Ethernet Server Adapter(0x1014-0x01F2)"},
{0x8086, 0x1229, 0x1014, 0x0207, "Ethernet Pro/100 S(0x1014-0x0207)"},
{0x8086, 0x1229, 0x1014, 0x0232, "10/100 Dual Port Server Adapter(0x1014-0x0232)"},
{0x8086, 0x1229, 0x1014, 0x023A, "ThinkPad R30(0x1014-0x023A)"},
{0x8086, 0x1229, 0x1014, 0x105C, "Netfinity 10/100(0x1014-0x105C)"},
{0x8086, 0x1229, 0x1014, 0x2205, "ThinkPad A22p(0x1014-0x2205)"},
{0x8086, 0x1229, 0x1014, 0x305C, "10/100 EtherJet Management Adapter(0x1014-0x305C)"},
{0x8086, 0x1229, 0x1014, 0x405C, "10/100 EtherJet Adapter with Alert on LAN(0x1014-0x405C)"},
{0x8086, 0x1229, 0x1014, 0x505C, "10/100 EtherJet Secure Management Adapter(0x1014-0x505C)"},
{0x8086, 0x1229, 0x1014, 0x605C, "10/100 EtherJet Secure Management Adapter(0x1014-0x605C)"},
{0x8086, 0x1229, 0x1014, 0x705C, "10/100 Netfinity 10/100 Ethernet Security Adapter(0x1014-0x705C)"},
{0x8086, 0x1229, 0x1014, 0x805C, "10/100 Netfinity 10/100 Ethernet Security Adapter(0x1014-0x805C)"},
{0x8086, 0x1229, 0x1028, 0x009B, "10/100 Ethernet Server Adapter(0x1028-0x009B)"},
{0x8086, 0x1229, 0x1028, 0x00CE, "10/100 Ethernet Server Adapter(0x1028-0x00CE)"},
{0x8086, 0x1229, 0x1033, 0x8000, "PC-9821X-B06(0x1033-0x8000)"},
{0x8086, 0x1229, 0x1033, 0x8016, "PK-UG-X006(0x1033-0x8016)"},
{0x8086, 0x1229, 0x1033, 0x801F, "PK-UG-X006(0x1033-0x801F)"},
{0x8086, 0x1229, 0x1033, 0x8026, "PK-UG-X006(0x1033-0x8026)"},
{0x8086, 0x1229, 0x1033, 0x8063, "82559-based Fast Ethernet Adapter(0x1033-0x8063)"},
{0x8086, 0x1229, 0x1033, 0x8064, "82559-based Fast Ethernet Adapter(0x1033-0x8064)"},
{0x8086, 0x1229, 0x103C, 0x10C0, "NetServer 10/100TX(0x103C-0x10C0)"},
{0x8086, 0x1229, 0x103C, 0x10C3, "NetServer 10/100TX(0x103C-0x10C3)"},
{0x8086, 0x1229, 0x103C, 0x10CA, "NetServer 10/100TX(0x103C-0x10CA)"},
{0x8086, 0x1229, 0x103C, 0x10CB, "NetServer 10/100TX(0x103C-0x10CB)"},
{0x8086, 0x1229, 0x103C, 0x10E3, "NetServer 10/100TX(0x103C-0x10E3)"},
{0x8086, 0x1229, 0x103C, 0x10E4, "NetServer 10/100TX(0x103C-0x10E4)"},
{0x8086, 0x1229, 0x103C, 0x1200, "NetServer 10/100TX(0x103C-0x1200)"},
{0x8086, 0x1229, 0x108E, 0x10CF, "EtherExpress PRO/100(B)(0x108E-0x10CF)"},
{0x8086, 0x1229, 0x10C3, 0x1100, "SmartEther100 SC1100(0x10C3-0x1100)"},
{0x8086, 0x1229, 0x10CF, 0x1115, "8255x-based Ethernet Adapter (10/100)(0x10CF-0x1115)"},
{0x8086, 0x1229, 0x10CF, 0x1143, "8255x-based Ethernet Adapter (10/100)(0x10CF-0x1143)"},
{0x8086, 0x1229, 0x110A, 0x008B, "82551QM Fast Ethernet Multifuction PCI/CardBus Controller(0x110A-0x008B)"},
{0x8086, 0x1229, 0x114A, 0x0582, "PC8 onboard ethernet ETH2(0x114A-0x0582)"},
{0x8086, 0x1229, 0x1179, 0x0001, "8255x-based Ethernet Adapter (10/100)(0x1179-0x0001)"},
{0x8086, 0x1229, 0x1179, 0x0002, "PCI FastEther LAN on Docker(0x1179-0x0002)"},
{0x8086, 0x1229, 0x1179, 0x0003, "8255x-based Fast Ethernet(0x1179-0x0003)"},
{0x8086, 0x1229, 0x1259, 0x2560, "AT-2560 100(0x1259-0x2560)"},
{0x8086, 0x1229, 0x1259, 0x2561, "AT-2560 100 FX Ethernet Adapter(0x1259-0x2561)"},
{0x8086, 0x1229, 0x1266, 0x0001, "NE10/100 Adapter(0x1266-0x0001)"},
{0x8086, 0x1229, 0x13E9, 0x1000, "6221L-4U(0x13E9-0x1000)"},
{0x8086, 0x1229, 0x144D, 0x2501, "SEM-2000 MiniPCI LAN Adapter(0x144D-0x2501)"},
{0x8086, 0x1229, 0x144D, 0x2502, "SEM-2100IL MiniPCI LAN Adapter(0x144D-0x2502)"},
{0x8086, 0x1229, 0x1668, 0x1100, "EtherExpress PRO/100B (TX) (MiniPCI Ethernet+Modem)(0x1668-0x1100)"},
{0x8086, 0x1229, 0x1775, 0x1100, "CR11/VR11 Single Board Computer(0x1775-0x1100)"},
{0x8086, 0x1229, 0x1775, 0xCE90, "CE9(0x1775-0xCE90)"},
{0x8086, 0x1229, 0x1AF4, 0x1100, "QEMU Virtual Machine(0x1AF4-0x1100)"},
{0x8086, 0x1229, 0x4C53, 0x1080, "CT8 mainboard(0x4C53-0x1080)"},
{0x8086, 0x1229, 0x4C53, 0x10E0, "PSL09 PrPMC(0x4C53-0x10E0)"},
{0x8086, 0x1229, 0x8086, 0x0001, "EtherExpress PRO/100B (TX)(0x8086-0x0001)"},
{0x8086, 0x1229, 0x8086, 0x0002, "EtherExpress PRO/100B (T4)(0x8086-0x0002)"},
{0x8086, 0x1229, 0x8086, 0x0003, "EtherExpress PRO/10+(0x8086-0x0003)"},
{0x8086, 0x1229, 0x8086, 0x0004, "EtherExpress PRO/100 WfM(0x8086-0x0004)"},
{0x8086, 0x1229, 0x8086, 0x0005, "82557 10/100(0x8086-0x0005)"},
{0x8086, 0x1229, 0x8086, 0x0006, "82557 10/100 with Wake on LAN(0x8086-0x0006)"},
{0x8086, 0x1229, 0x8086, 0x0007, "82558 10/100 Adapter(0x8086-0x0007)"},
{0x8086, 0x1229, 0x8086, 0x0008, "82558 10/100 with Wake on LAN(0x8086-0x0008)"},
{0x8086, 0x1229, 0x8086, 0x0009, "82558B PRO/100+ PCI (TP)(0x8086-0x0009)"},
{0x8086, 0x1229, 0x8086, 0x000A, "EtherExpress PRO/100+ Management Adapter(0x8086-0x000A)"},
{0x8086, 0x1229, 0x8086, 0x000B, "EtherExpress PRO/100+(0x8086-0x000B)"},
{0x8086, 0x1229, 0x8086, 0x000C, "EtherExpress PRO/100+ Management Adapter(0x8086-0x000C)"},
{0x8086, 0x1229, 0x8086, 0x000D, "EtherExpress PRO/100+ Alert On LAN II* Adapter(0x8086-0x000D)"},
{0x8086, 0x1229, 0x8086, 0x000E, "EtherExpress PRO/100+ Management Adapter with Alert On LAN*(0x8086-0x000E)"},
{0x8086, 0x1229, 0x8086, 0x000F, "EtherExpress PRO/100 Desktop Adapter(0x8086-0x000F)"},
{0x8086, 0x1229, 0x8086, 0x0010, "EtherExpress PRO/100 S Management Adapter(0x8086-0x0010)"},
{0x8086, 0x1229, 0x8086, 0x0011, "EtherExpress PRO/100 S Management Adapter(0x8086-0x0011)"},
{0x8086, 0x1229, 0x8086, 0x0012, "EtherExpress PRO/100 S Advanced Management Adapter (D)(0x8086-0x0012)"},
{0x8086, 0x1229, 0x8086, 0x0013, "EtherExpress PRO/100 S Advanced Management Adapter (E)(0x8086-0x0013)"},
{0x8086, 0x1229, 0x8086, 0x0030, "EtherExpress PRO/100  Management Adapter with Alert On LAN* GC(0x8086-0x0030)"},
{0x8086, 0x1229, 0x8086, 0x0031, "EtherExpress PRO/100 Desktop Adapter(0x8086-0x0031)"},
{0x8086, 0x1229, 0x8086, 0x0040, "EtherExpress PRO/100 S Desktop Adapter(0x8086-0x0040)"},
{0x8086, 0x1229, 0x8086, 0x0041, "EtherExpress PRO/100 S Desktop Adapter(0x8086-0x0041)"},
{0x8086, 0x1229, 0x8086, 0x0042, "EtherExpress PRO/100 Desktop Adapter(0x8086-0x0042)"},
{0x8086, 0x1229, 0x8086, 0x0050, "EtherExpress PRO/100 S Desktop Adapter(0x8086-0x0050)"},
{0x8086, 0x1229, 0x8086, 0x1009, "EtherExpress PRO/100+ Server Adapter(0x8086-0x1009)"},
{0x8086, 0x1229, 0x8086, 0x100C, "EtherExpress PRO/100+ Server Adapter (PILA8470B)(0x8086-0x100C)"},
{0x8086, 0x1229, 0x8086, 0x1012, "EtherExpress PRO/100 S Server Adapter (D)(0x8086-0x1012)"},
{0x8086, 0x1229, 0x8086, 0x1013, "EtherExpress PRO/100 S Server Adapter (E)(0x8086-0x1013)"},
{0x8086, 0x1229, 0x8086, 0x1015, "EtherExpress PRO/100 S Dual Port Server Adapter(0x8086-0x1015)"},
{0x8086, 0x1229, 0x8086, 0x1017, "EtherExpress PRO/100+ Dual Port Server Adapter(0x8086-0x1017)"},
{0x8086, 0x1229, 0x8086, 0x1030, "EtherExpress PRO/100+ Management Adapter with Alert On LAN* G Server(0x8086-0x1030)"},
{0x8086, 0x1229, 0x8086, 0x1040, "EtherExpress PRO/100 S Server Adapter(0x8086-0x1040)"},
{0x8086, 0x1229, 0x8086, 0x1041, "EtherExpress PRO/100 S Server Adapter(0x8086-0x1041)"},
{0x8086, 0x1229, 0x8086, 0x1042, "EtherExpress PRO/100 Server Adapter(0x8086-0x1042)"},
{0x8086, 0x1229, 0x8086, 0x1050, "EtherExpress PRO/100 S Server Adapter(0x8086-0x1050)"},
{0x8086, 0x1229, 0x8086, 0x1051, "EtherExpress PRO/100 Server Adapter(0x8086-0x1051)"},
{0x8086, 0x1229, 0x8086, 0x1052, "EtherExpress PRO/100 Server Adapter(0x8086-0x1052)"},
{0x8086, 0x1229, 0x8086, 0x10F0, "EtherExpress PRO/100+ Dual Port Adapter(0x8086-0x10F0)"},
{0x8086, 0x1229, 0x8086, 0x1229, "82557/8/9 [Ethernet Pro 100](0x8086-0x1229)"},
{0x8086, 0x1229, 0x8086, 0x2009, "EtherExpress PRO/100 S Mobile Adapter(0x8086-0x2009)"},
{0x8086, 0x1229, 0x8086, 0x200D, "EtherExpress PRO/100 Cardbus(0x8086-0x200D)"},
{0x8086, 0x1229, 0x8086, 0x200E, "EtherExpress PRO/100 LAN+V90 Cardbus Modem(0x8086-0x200E)"},
{0x8086, 0x1229, 0x8086, 0x200F, "EtherExpress PRO/100 SR Mobile Adapter(0x8086-0x200F)"},
{0x8086, 0x1229, 0x8086, 0x2010, "EtherExpress PRO/100 S Mobile Combo Adapter(0x8086-0x2010)"},
{0x8086, 0x1229, 0x8086, 0x2013, "EtherExpress PRO/100 SR Mobile Combo Adapter(0x8086-0x2013)"},
{0x8086, 0x1229, 0x8086, 0x2016, "EtherExpress PRO/100 S Mobile Adapter(0x8086-0x2016)"},
{0x8086, 0x1229, 0x8086, 0x2017, "EtherExpress PRO/100 S Combo Mobile Adapter(0x8086-0x2017)"},
{0x8086, 0x1229, 0x8086, 0x2018, "EtherExpress PRO/100 SR Mobile Adapter(0x8086-0x2018)"},
{0x8086, 0x1229, 0x8086, 0x2019, "EtherExpress PRO/100 SR Combo Mobile Adapter(0x8086-0x2019)"},
{0x8086, 0x1229, 0x8086, 0x2101, "EtherExpress PRO/100 P Mobile Adapter(0x8086-0x2101)"},
{0x8086, 0x1229, 0x8086, 0x2102, "EtherExpress PRO/100 SP Mobile Adapter(0x8086-0x2102)"},
{0x8086, 0x1229, 0x8086, 0x2103, "EtherExpress PRO/100 SP Mobile Adapter(0x8086-0x2103)"},
{0x8086, 0x1229, 0x8086, 0x2104, "EtherExpress PRO/100 SP Mobile Adapter(0x8086-0x2104)"},
{0x8086, 0x1229, 0x8086, 0x2105, "EtherExpress PRO/100 SP Mobile Adapter(0x8086-0x2105)"},
{0x8086, 0x1229, 0x8086, 0x2106, "EtherExpress PRO/100 P Mobile Adapter(0x8086-0x2106)"},
{0x8086, 0x1229, 0x8086, 0x2107, "EtherExpress PRO/100 Network Connection(0x8086-0x2107)"},
{0x8086, 0x1229, 0x8086, 0x2108, "EtherExpress PRO/100 Network Connection(0x8086-0x2108)"},
{0x8086, 0x1229, 0x8086, 0x2200, "EtherExpress PRO/100 P Mobile Combo Adapter(0x8086-0x2200)"},
{0x8086, 0x1229, 0x8086, 0x2201, "EtherExpress PRO/100 P Mobile Combo Adapter(0x8086-0x2201)"},
{0x8086, 0x1229, 0x8086, 0x2202, "EtherExpress PRO/100 SP Mobile Combo Adapter(0x8086-0x2202)"},
{0x8086, 0x1229, 0x8086, 0x2203, "EtherExpress PRO/100+ MiniPCI(0x8086-0x2203)"},
{0x8086, 0x1229, 0x8086, 0x2204, "EtherExpress PRO/100+ MiniPCI(0x8086-0x2204)"},
{0x8086, 0x1229, 0x8086, 0x2205, "EtherExpress PRO/100 SP Mobile Combo Adapter(0x8086-0x2205)"},
{0x8086, 0x1229, 0x8086, 0x2206, "EtherExpress PRO/100 SP Mobile Combo Adapter(0x8086-0x2206)"},
{0x8086, 0x1229, 0x8086, 0x2207, "EtherExpress PRO/100 SP Mobile Combo Adapter(0x8086-0x2207)"},
{0x8086, 0x1229, 0x8086, 0x2208, "EtherExpress PRO/100 P Mobile Combo Adapter(0x8086-0x2208)"},
{0x8086, 0x1229, 0x8086, 0x2402, "EtherExpress PRO/100+ MiniPCI(0x8086-0x2402)"},
{0x8086, 0x1229, 0x8086, 0x2407, "EtherExpress PRO/100+ MiniPCI(0x8086-0x2407)"},
{0x8086, 0x1229, 0x8086, 0x2408, "EtherExpress PRO/100+ MiniPCI(0x8086-0x2408)"},
{0x8086, 0x1229, 0x8086, 0x2409, "EtherExpress PRO/100+ MiniPCI(0x8086-0x2409)"},
{0x8086, 0x1229, 0x8086, 0x240F, "EtherExpress PRO/100+ MiniPCI(0x8086-0x240F)"},
{0x8086, 0x1229, 0x8086, 0x2410, "EtherExpress PRO/100+ MiniPCI(0x8086-0x2410)"},
{0x8086, 0x1229, 0x8086, 0x2411, "EtherExpress PRO/100+ MiniPCI(0x8086-0x2411)"},
{0x8086, 0x1229, 0x8086, 0x2412, "EtherExpress PRO/100+ MiniPCI(0x8086-0x2412)"},
{0x8086, 0x1229, 0x8086, 0x2413, "EtherExpress PRO/100+ MiniPCI(0x8086-0x2413)"},
{0x8086, 0x1229, 0x8086, 0x3000, "82559 Fast Ethernet LAN on Motherboard(0x8086-0x3000)"},
{0x8086, 0x1229, 0x8086, 0x3001, "82559 Fast Ethernet LOM with Basic Alert on LAN*(0x8086-0x3001)"},
{0x8086, 0x1229, 0x8086, 0x3002, "82559 Fast Ethernet LOM with Alert on LAN II*(0x8086-0x3002)"},
{0x8086, 0x1229, 0x8086, 0x3006, "EtherExpress PRO/100 S Network Connection(0x8086-0x3006)"},
{0x8086, 0x1229, 0x8086, 0x3007, "EtherExpress PRO/100 S Network Connection(0x8086-0x3007)"},
{0x8086, 0x1229, 0x8086, 0x3008, "EtherExpress PRO/100 Network Connection(0x8086-0x3008)"},
{0x8086, 0x1229, 0x8086, 0x3010, "EtherExpress PRO/100 S Network Connection(0x8086-0x3010)"},
{0x8086, 0x1229, 0x8086, 0x3011, "EtherExpress PRO/100 S Network Connection(0x8086-0x3011)"},
{0x8086, 0x1229, 0x8086, 0x3012, "EtherExpress PRO/100 Network Connection(0x8086-0x3012)"},
{0x8086, 0x1229, 0x8086, 0x301A, "S845WD1-E mainboard(0x8086-0x301A)"},
{0x8086, 0x1229, 0x8086, 0x3411, "SDS2 Mainboard(0x8086-0x3411)"},
{0x8086, 0x122D, 0xFFFF, 0xFFFF, "430FX - 82437FX TSC [Triton I](0x122D)"},
{0x8086, 0x122E, 0xFFFF, 0xFFFF, "82371FB PIIX ISA [Triton I](0x122E)"},
{0x8086, 0x1230, 0xFFFF, 0xFFFF, "82371FB PIIX IDE [Triton I](0x1230)"},
{0x8086, 0x1231, 0xFFFF, 0xFFFF, "DSVD Modem(0x1231)"},
{0x8086, 0x1234, 0xFFFF, 0xFFFF, "430MX - 82371MX Mobile PCI I/O IDE Xcelerator (MPIIX)(0x1234)"},
{0x8086, 0x1235, 0xFFFF, 0xFFFF, "430MX - 82437MX Mob. System Ctrlr (MTSC) & 82438MX Data Path (MTDP)(0x1235)"},
{0x8086, 0x1237, 0xFFFF, 0xFFFF, "440FX - 82441FX PMC [Natoma](0x1237)"},
{0x8086, 0x1237, 0x01DE, 0xFFFE, "Propolis Virtual 440FX(0x01DE-0xFFFE)"},
{0x8086, 0x1237, 0x1AF4, 0x1100, "Qemu virtual machine(0x1AF4-0x1100)"},
{0x8086, 0x1239, 0xFFFF, 0xFFFF, "82371FB PIIX IDE Interface(0x1239)"},
{0x8086, 0x123B, 0xFFFF, 0xFFFF, "82380PB PCI to PCI Docking Bridge(0x123B)"},
{0x8086, 0x123C, 0xFFFF, 0xFFFF, "82380AB (MISA) Mobile PCI-to-ISA Bridge(0x123C)"},
{0x8086, 0x123D, 0xFFFF, 0xFFFF, "683053 Programmable Interrupt Device(0x123D)"},
{0x8086, 0x123E, 0xFFFF, 0xFFFF, "82466GX (IHPC) Integrated Hot-Plug Controller (hidden mode)(0x123E)"},
{0x8086, 0x123F, 0xFFFF, 0xFFFF, "82466GX Integrated Hot-Plug Controller (IHPC)(0x123F)"},
{0x8086, 0x1240, 0xFFFF, 0xFFFF, "82752 (752) AGP Graphics Accelerator(0x1240)"},
{0x8086, 0x124B, 0xFFFF, 0xFFFF, "82380FB (MPCI2) Mobile Docking Controller(0x124B)"},
{0x8086, 0x124C, 0xFFFF, 0xFFFF, "Ethernet Connection E823-L for backplane(0x124C)"},
{0x8086, 0x124D, 0xFFFF, 0xFFFF, "Ethernet Connection E823-L for SFP(0x124D)"},
{0x8086, 0x124E, 0xFFFF, 0xFFFF, "Ethernet Connection E823-L/X557-AT 10GBASE-T(0x124E)"},
{0x8086, 0x124F, 0xFFFF, 0xFFFF, "Ethernet Connection E823-L 1GbE(0x124F)"},
{0x8086, 0x1250, 0xFFFF, 0xFFFF, "430HX - 82439HX TXC [Triton II](0x1250)"},
{0x8086, 0x125B, 0xFFFF, 0xFFFF, "Ethernet Controller I226-LM(0x125B)"},
{0x8086, 0x125C, 0xFFFF, 0xFFFF, "Ethernet Controller I226-V(0x125C)"},
{0x8086, 0x125D, 0xFFFF, 0xFFFF, "Ethernet Controller I226-IT(0x125D)"},
{0x8086, 0x12D1, 0xFFFF, 0xFFFF, "Ethernet Controller E830-CC for backplane(0x12D1)"},
{0x8086, 0x12D2, 0xFFFF, 0xFFFF, "Ethernet Controller E830-CC for QSFP(0x12D2)"},
{0x8086, 0x12D2, 0x8086, 0x0002, "Ethernet Network Adapter E830-C-Q2 for OCP 3.0(0x8086-0x0002)"},
{0x8086, 0x12D2, 0x8086, 0x0004, "Ethernet Network Adapter E830-CC-Q1 for OCP 3.0(0x8086-0x0004)"},
{0x8086, 0x12D3, 0xFFFF, 0xFFFF, "Ethernet Controller E830-CC for SFP(0x12D3)"},
{0x8086, 0x12D3, 0x8086, 0x0001, "Ethernet Network Adapter E830-XXV-2 for OCP 3.0(0x8086-0x0001)"},
{0x8086, 0x12D3, 0x8086, 0x0003, "Ethernet Network Adapter E830-XXV-2(0x8086-0x0003)"},
{0x8086, 0x12D3, 0x8086, 0x0004, "Ethernet Network Adapter E830-XXV-4 for OCP 3.0(0x8086-0x0004)"},
{0x8086, 0x12D4, 0xFFFF, 0xFFFF, "Ethernet Controller E830-CC for SFP-DD(0x12D4)"},
{0x8086, 0x12D5, 0xFFFF, 0xFFFF, "Ethernet Controller E830-C for backplane(0x12D5)"},
{0x8086, 0x12D8, 0xFFFF, 0xFFFF, "Ethernet Controller E830-C for QSFP(0x12D8)"},
{0x8086, 0x12DA, 0xFFFF, 0xFFFF, "Ethernet Controller E830-C for SFP(0x12DA)"},
{0x8086, 0x12DC, 0xFFFF, 0xFFFF, "Ethernet Controller E830-XXV for backplane(0x12DC)"},
{0x8086, 0x12DD, 0xFFFF, 0xFFFF, "Ethernet Controller E830-XXV for QSFP(0x12DD)"},
{0x8086, 0x12DE, 0xFFFF, 0xFFFF, "Ethernet Controller E830-XXV for SFP(0x12DE)"},
{0x8086, 0x1360, 0xFFFF, 0xFFFF, "82806AA PCI64 Hub PCI Bridge(0x1360)"},
{0x8086, 0x1361, 0xFFFF, 0xFFFF, "82806AA PCI64 Hub Controller (HRes)(0x1361)"},
{0x8086, 0x1361, 0x8086, 0x1361, "82806AA PCI64 Hub Controller (HRes)(0x8086-0x1361)"},
{0x8086, 0x1361, 0x8086, 0x8000, "82806AA PCI64 Hub Controller (HRes)(0x8086-0x8000)"},
{0x8086, 0x1452, 0xFFFF, 0xFFFF, "Infrastructure Data Path Function(0x1452)"},
{0x8086, 0x145C, 0xFFFF, 0xFFFF, "Infrastructure Data Path Function(0x145C)"},
{0x8086, 0x1460, 0xFFFF, 0xFFFF, "82870P2 P64H2 Hub PCI Bridge(0x1460)"},
{0x8086, 0x1461, 0xFFFF, 0xFFFF, "82870P2 P64H2 I/OxAPIC(0x1461)"},
{0x8086, 0x1461, 0x15D9, 0x3480, "P4DP6(0x15D9-0x3480)"},
{0x8086, 0x1461, 0x4C53, 0x1090, "Cx9/Vx9 mainboard(0x4C53-0x1090)"},
{0x8086, 0x1462, 0xFFFF, 0xFFFF, "82870P2 P64H2 Hot Plug Controller(0x1462)"},
{0x8086, 0x1501, 0xFFFF, 0xFFFF, "82567V-3 Gigabit Network Connection(0x1501)"},
{0x8086, 0x1502, 0xFFFF, 0xFFFF, "82579LM Gigabit Network Connection (Lewisville)(0x1502)"},
{0x8086, 0x1502, 0x1028, 0x04A3, "Precision M4600(0x1028-0x04A3)"},
{0x8086, 0x1502, 0x17AA, 0x21CE, "ThinkPad T520(0x17AA-0x21CE)"},
{0x8086, 0x1502, 0x17AA, 0x3070, "ThinkCentre M91p(0x17AA-0x3070)"},
{0x8086, 0x1502, 0x8086, 0x3578, "Server Board S1200BTLR(0x8086-0x3578)"},
{0x8086, 0x1502, 0x8086, 0x357A, "Server Board S1200BTS(0x8086-0x357A)"},
{0x8086, 0x1503, 0xFFFF, 0xFFFF, "82579V Gigabit Network Connection(0x1503)"},
{0x8086, 0x1503, 0x1043, 0x849C, "P8P67 Deluxe Motherboard(0x1043-0x849C)"},
{0x8086, 0x1503, 0x10CF, 0x161C, "LIFEBOOK E752(0x10CF-0x161C)"},
{0x8086, 0x1503, 0x8086, 0x200D, "DH61CR motherboard(0x8086-0x200D)"},
{0x8086, 0x1507, 0xFFFF, 0xFFFF, "Ethernet Express Module X520-P2(0x1507)"},
{0x8086, 0x1508, 0xFFFF, 0xFFFF, "82598EB Gigabit BX Network Connection(0x1508)"},
{0x8086, 0x1509, 0xFFFF, 0xFFFF, "82580 Gigabit Network Connection(0x1509)"},
{0x8086, 0x150A, 0xFFFF, 0xFFFF, "82576NS Gigabit Network Connection(0x150A)"},
{0x8086, 0x150B, 0xFFFF, 0xFFFF, "82598EB 10-Gigabit AT2 Server Adapter(0x150B)"},
{0x8086, 0x150B, 0x8086, 0xA10C, "82598EB 10-Gigabit AT2 Server Adapter(0x8086-0xA10C)"},
{0x8086, 0x150B, 0x8086, 0xA11C, "82598EB 10-Gigabit AT2 Server Adapter(0x8086-0xA11C)"},
{0x8086, 0x150B, 0x8086, 0xA12C, "82598EB 10-Gigabit AT2 Server Adapter(0x8086-0xA12C)"},
{0x8086, 0x150C, 0xFFFF, 0xFFFF, "82583V Gigabit Network Connection(0x150C)"},
{0x8086, 0x150D, 0xFFFF, 0xFFFF, "82576 Gigabit Backplane Connection(0x150D)"},
{0x8086, 0x150D, 0x8086, 0xA10C, "Gigabit ET Quad Port Mezzanine Card(0x8086-0xA10C)"},
{0x8086, 0x150E, 0xFFFF, 0xFFFF, "82580 Gigabit Network Connection(0x150E)"},
{0x8086, 0x150E, 0x103C, 0x1780, "NC365T 4-port Ethernet Server Adapter(0x103C-0x1780)"},
{0x8086, 0x150E, 0x8086, 0x12A1, "Ethernet Server Adapter I340-T4(0x8086-0x12A1)"},
{0x8086, 0x150E, 0x8086, 0x12A2, "Ethernet Server Adapter I340-T4(0x8086-0x12A2)"},
{0x8086, 0x150F, 0xFFFF, 0xFFFF, "82580 Gigabit Fiber Network Connection(0x150F)"},
{0x8086, 0x1510, 0xFFFF, 0xFFFF, "82580 Gigabit Backplane Connection(0x1510)"},
{0x8086, 0x1511, 0xFFFF, 0xFFFF, "82580 Gigabit SFP Connection(0x1511)"},
{0x8086, 0x1513, 0xFFFF, 0xFFFF, "CV82524 Thunderbolt Controller [Light Ridge 4C 2010](0x1513)"},
{0x8086, 0x1514, 0xFFFF, 0xFFFF, "Ethernet X520 10GbE Dual Port KX4 Mezz(0x1514)"},
{0x8086, 0x1514, 0x8086, 0x000B, "Ethernet X520 10GbE Dual Port KX4 Mezz(0x8086-0x000B)"},
{0x8086, 0x1515, 0xFFFF, 0xFFFF, "X540 Ethernet Controller Virtual Function(0x1515)"},
{0x8086, 0x1516, 0xFFFF, 0xFFFF, "82580 Gigabit Network Connection(0x1516)"},
{0x8086, 0x1516, 0x8086, 0x12B1, "Ethernet Server Adapter I340-T2(0x8086-0x12B1)"},
{0x8086, 0x1516, 0x8086, 0x12B2, "Ethernet Server Adapter I340-T2(0x8086-0x12B2)"},
{0x8086, 0x1517, 0xFFFF, 0xFFFF, "82599ES 10 Gigabit Network Connection(0x1517)"},
{0x8086, 0x1517, 0x1137, 0x006A, "UCS CNA M61KR-I Intel Converged Network Adapter(0x1137-0x006A)"},
{0x8086, 0x1518, 0xFFFF, 0xFFFF, "82576NS SerDes Gigabit Network Connection(0x1518)"},
{0x8086, 0x151A, 0xFFFF, 0xFFFF, "DSL2310 Thunderbolt Controller [Eagle Ridge 2C 2011](0x151A)"},
{0x8086, 0x151B, 0xFFFF, 0xFFFF, "CVL2510 Thunderbolt Controller [Light Peak 2C 2010](0x151B)"},
{0x8086, 0x151C, 0xFFFF, 0xFFFF, "82599 10 Gigabit TN Network Connection(0x151C)"},
{0x8086, 0x151C, 0x108E, 0x7B13, "Dual 10GBASE-T LP(0x108E-0x7B13)"},
{0x8086, 0x151D, 0xFFFF, 0xFFFF, "Ethernet Connection E823-L for QSFP(0x151D)"},
{0x8086, 0x1520, 0xFFFF, 0xFFFF, "I350 Ethernet Controller Virtual Function(0x1520)"},
{0x8086, 0x1521, 0xFFFF, 0xFFFF, "I350 Gigabit Network Connection(0x1521)"},
{0x8086, 0x1521, 0x1028, 0x0602, "Gigabit 2P I350-t LOM(0x1028-0x0602)"},
{0x8086, 0x1521, 0x1028, 0x0693, "Gigabit 2P I350-t LOM(0x1028-0x0693)"},
{0x8086, 0x1521, 0x1028, 0x06E2, "Gigabit 2P I350-t LOM(0x1028-0x06E2)"},
{0x8086, 0x1521, 0x1028, 0x0757, "Gigabit I350-t LOM(0x1028-0x0757)"},
{0x8086, 0x1521, 0x1028, 0x075A, "Gigabit I350-t LOM(0x1028-0x075A)"},
{0x8086, 0x1521, 0x1028, 0x1F60, "Gigabit 4P I350-t rNDC(0x1028-0x1F60)"},
{0x8086, 0x1521, 0x1028, 0x1F62, "Gigabit 4P X540/I350 rNDC(0x1028-0x1F62)"},
{0x8086, 0x1521, 0x1028, 0x1FA8, "Ethernet 10G 4P X550/I350 rNDC(0x1028-0x1FA8)"},
{0x8086, 0x1521, 0x1028, 0x1FA9, "Ethernet 10G 4P X550 rNDC(0x1028-0x1FA9)"},
{0x8086, 0x1521, 0x1028, 0x1FAA, "Gigabit 4P X550/I350 rNDC(0x1028-0x1FAA)"},
{0x8086, 0x1521, 0x1028, 0xFF9A, "Gigabit 4P X710/I350 rNDC(0x1028-0xFF9A)"},
{0x8086, 0x1521, 0x103C, 0x17D1, "Ethernet 1Gb 4-port 366FLR Adapter(0x103C-0x17D1)"},
{0x8086, 0x1521, 0x103C, 0x2003, "Ethernet 1Gb 2-port 367i Adapter(0x103C-0x2003)"},
{0x8086, 0x1521, 0x103C, 0x2226, "Ethernet 1Gb 1-port 364i Adapter(0x103C-0x2226)"},
{0x8086, 0x1521, 0x103C, 0x337F, "Ethernet 1Gb 2-port 361i Adapter(0x103C-0x337F)"},
{0x8086, 0x1521, 0x103C, 0x3380, "Ethernet 1Gb 4-port 366i Adapter(0x103C-0x3380)"},
{0x8086, 0x1521, 0x103C, 0x339E, "Ethernet 1Gb 2-port 361T Adapter(0x103C-0x339E)"},
{0x8086, 0x1521, 0x103C, 0x8157, "Ethernet 1Gb 4-port 366T Adapter(0x103C-0x8157)"},
{0x8086, 0x1521, 0x108E, 0x7B16, "Quad Port GbE PCIe 2.0 ExpressModule, UTP(0x108E-0x7B16)"},
{0x8086, 0x1521, 0x108E, 0x7B18, "Quad Port GbE PCIe 2.0 Low Profile Adapter, UTP(0x108E-0x7B18)"},
{0x8086, 0x1521, 0x1093, 0x7648, "PCIe-8237R Ethernet Adapter(0x1093-0x7648)"},
{0x8086, 0x1521, 0x1093, 0x7649, "PCIe-8236 Ethernet Adapter(0x1093-0x7649)"},
{0x8086, 0x1521, 0x1093, 0x76B1, "PCIe-8237R-S Ethernet Adapter(0x1093-0x76B1)"},
{0x8086, 0x1521, 0x1093, 0x775B, "PCIe-8237 Ethernet Adapter(0x1093-0x775B)"},
{0x8086, 0x1521, 0x10A9, 0x802A, "UV2-BaseIO dual-port GbE(0x10A9-0x802A)"},
{0x8086, 0x1521, 0x1137, 0x023E, "1GigE I350 LOM(0x1137-0x023E)"},
{0x8086, 0x1521, 0x15D9, 0x0000, "AOC-SGP-i4(0x15D9-0x0000)"},
{0x8086, 0x1521, 0x15D9, 0x0652, "Dual Port i350 GbE MicroLP [AOC-CGP-i2](0x15D9-0x0652)"},
{0x8086, 0x1521, 0x17AA, 0x1074, "ThinkServer I350-T4 AnyFabric(0x17AA-0x1074)"},
{0x8086, 0x1521, 0x17AA, 0x4005, "I350 Gigabit Network Connection(0x17AA-0x4005)"},
{0x8086, 0x1521, 0x18D4, 0x0C07, "I350 1Gb 2-port RJ45 OCP Mezz Card MOP41-I-1GT2(0x18D4-0x0C07)"},
{0x8086, 0x1521, 0x193D, 0x1005, "360T-B(0x193D-0x1005)"},
{0x8086, 0x1521, 0x193D, 0x1007, "360T-L(0x193D-0x1007)"},
{0x8086, 0x1521, 0x193D, 0x1080, "NIC-ETH360T-3S-4P(0x193D-0x1080)"},
{0x8086, 0x1521, 0x1BD4, 0x001D, "1G base-T QP EP014Ti1 Adapter(0x1BD4-0x001D)"},
{0x8086, 0x1521, 0x1BD4, 0x0035, "1G base-T QP EP014Ti1 Adapter(0x1BD4-0x0035)"},
{0x8086, 0x1521, 0x1BD4, 0x0066, "F014I350(0x1BD4-0x0066)"},
{0x8086, 0x1521, 0x1BD4, 0x008A, "F012I350(0x1BD4-0x008A)"},
{0x8086, 0x1521, 0x1BD4, 0x008D, "ENFI1100-T4(0x1BD4-0x008D)"},
{0x8086, 0x1521, 0x4C52, 0x0350, "I350 1Gb 2-port Ethernet Network Adapter(0x4C52-0x0350)"},
{0x8086, 0x1521, 0x4C52, 0x1350, "LREC9222HT Dual-port 1Gb Ethernet Network Adapter(0x4C52-0x1350)"},
{0x8086, 0x1521, 0x4C52, 0x2003, "LRES2003PT Dual-port 1Gb Ethernet Network Adapter(0x4C52-0x2003)"},
{0x8086, 0x1521, 0x4C52, 0x2005, "LRES2005PT Quad-port 1Gb Ethernet Network Adapter(0x4C52-0x2005)"},
{0x8086, 0x1521, 0x4C52, 0x2006, "LRES2006PT Six-port 1Gb Ethernet Network Adapter(0x4C52-0x2006)"},
{0x8086, 0x1521, 0x4C52, 0x2008, "LRES2008PT Eight-port 1Gb Ethernet Network Adapter(0x4C52-0x2008)"},
{0x8086, 0x1521, 0x4C52, 0x2018, "LRES2018PT Twelve-port 1Gb Ethernet Network Adapter(0x4C52-0x2018)"},
{0x8086, 0x1521, 0x4C52, 0x2202, "LRES2202PT Dual-port 1Gb Ethernet Network Adapter(0x4C52-0x2202)"},
{0x8086, 0x1521, 0x4C52, 0x2217, "LRES2217PT Dual-port 1Gb Ethernet Network Adapter(0x4C52-0x2217)"},
{0x8086, 0x1521, 0x4C52, 0x3010, "LRES3010PF Dual-port 1Gb Ethernet Server Adapter for OCP(0x4C52-0x3010)"},
{0x8086, 0x1521, 0x4C52, 0x3023, "LRES3023PT Quad-port 1Gb Ethernet Server Adapter for OCP(0x4C52-0x3023)"},
{0x8086, 0x1521, 0x4C52, 0x3041, "LRES3041PT Dual-port 1Gb Ethernet Server Adapter for OCP(0x4C52-0x3041)"},
{0x8086, 0x1521, 0x4C52, 0x4006, "LRES4006MT Quad-port 1Gb Ethernet Netwaork Adapter(0x4C52-0x4006)"},
{0x8086, 0x1521, 0x4C52, 0x9712, "LREC9712HT Dual-port 10Gb Ethernet Network Adapter(0x4C52-0x9712)"},
{0x8086, 0x1521, 0x8086, 0x0001, "Ethernet Server Adapter I350-T4(0x8086-0x0001)"},
{0x8086, 0x1521, 0x8086, 0x0002, "Ethernet Server Adapter I350-T2(0x8086-0x0002)"},
{0x8086, 0x1521, 0x8086, 0x0003, "Ethernet Network Adapter I350-T4 for OCP NIC 3.0(0x8086-0x0003)"},
{0x8086, 0x1521, 0x8086, 0x00A1, "Ethernet Server Adapter I350-T4(0x8086-0x00A1)"},
{0x8086, 0x1521, 0x8086, 0x00A2, "Ethernet Server Adapter I350-T2(0x8086-0x00A2)"},
{0x8086, 0x1521, 0x8086, 0x00A3, "Ethernet Network Adapter I350-T4 for OCP NIC 3.0(0x8086-0x00A3)"},
{0x8086, 0x1521, 0x8086, 0x00AA, "Ethernet Network Adapter I350-T4 for OCP NIC 3.0(0x8086-0x00AA)"},
{0x8086, 0x1521, 0x8086, 0x4017, "Ethernet Network Adapter I350-T4 for OCP NIC 3.0(0x8086-0x4017)"},
{0x8086, 0x1521, 0x8086, 0x5001, "Ethernet Server Adapter I350-T4(0x8086-0x5001)"},
{0x8086, 0x1521, 0x8086, 0x5002, "Ethernet Server Adapter I350-T2(0x8086-0x5002)"},
{0x8086, 0x1521, 0x8086, 0x5003, "Ethernet 1G 4P I350-t OCP(0x8086-0x5003)"},
{0x8086, 0x1522, 0xFFFF, 0xFFFF, "I350 Gigabit Fiber Network Connection(0x1522)"},
{0x8086, 0x1522, 0x108E, 0x7B17, "Quad Port GbE PCIe 2.0 ExpressModule, MMF(0x108E-0x7B17)"},
{0x8086, 0x1522, 0x108E, 0x7B19, "Dual Port GbE PCIe 2.0 Low Profile Adapter, MMF(0x108E-0x7B19)"},
{0x8086, 0x1522, 0x4C52, 0x1006, "LRES1006PF Six-port 1Gb Ethernet Network Adapter(0x4C52-0x1006)"},
{0x8086, 0x1522, 0x4C52, 0x2203, "LRES2203PF Dual-port 1Gb Ethernet Network Adapter(0x4C52-0x2203)"},
{0x8086, 0x1522, 0x4C52, 0x9710, "LREC9710HF Single-port 1Gb Ethernet Network Adapter(0x4C52-0x9710)"},
{0x8086, 0x1522, 0x4C52, 0x9712, "LREC9712HF Dual-port 1Gb Ethernet Network Adapter(0x4C52-0x9712)"},
{0x8086, 0x1522, 0x4C52, 0x9714, "LREC9714HF Quad-port 1Gb Ethernet Network Adapter(0x4C52-0x9714)"},
{0x8086, 0x1522, 0x8086, 0x0002, "Ethernet Server Adapter I350-T2(0x8086-0x0002)"},
{0x8086, 0x1522, 0x8086, 0x0003, "Ethernet Server Adapter I350-F4(0x8086-0x0003)"},
{0x8086, 0x1522, 0x8086, 0x0004, "Ethernet Server Adapter I350-F2(0x8086-0x0004)"},
{0x8086, 0x1522, 0x8086, 0x0005, "Ethernet Server Adapter I350-F1(0x8086-0x0005)"},
{0x8086, 0x1522, 0x8086, 0x00A2, "Ethernet Server Adapter I350-T2(0x8086-0x00A2)"},
{0x8086, 0x1522, 0x8086, 0x00A3, "Ethernet Server Adapter I350-F4(0x8086-0x00A3)"},
{0x8086, 0x1522, 0x8086, 0x00A4, "Ethernet Server Adapter I350-F2(0x8086-0x00A4)"},
{0x8086, 0x1523, 0xFFFF, 0xFFFF, "I350 Gigabit Backplane Connection(0x1523)"},
{0x8086, 0x1523, 0x1028, 0x0060, "Gigabit 2P I350 LOM(0x1028-0x0060)"},
{0x8086, 0x1523, 0x1028, 0x1F9B, "Gigabit 4P I350-t bNDC(0x1028-0x1F9B)"},
{0x8086, 0x1523, 0x103C, 0x1784, "Ethernet 1Gb 2-port 361FLB Adapter(0x103C-0x1784)"},
{0x8086, 0x1523, 0x103C, 0x18D1, "Ethernet 1Gb 2-port 361FLB Adapter(0x103C-0x18D1)"},
{0x8086, 0x1523, 0x103C, 0x1989, "Ethernet 1Gb 2-port 363i Adapter(0x103C-0x1989)"},
{0x8086, 0x1523, 0x103C, 0x339F, "Ethernet 1Gb 4-port 366M Adapter(0x103C-0x339F)"},
{0x8086, 0x1523, 0x4C52, 0x9714, "LREC9714HT Quad-port 10Gb Ethernet Network Adapter(0x4C52-0x9714)"},
{0x8086, 0x1523, 0x8086, 0x1F52, "1GbE 4P I350 Mezz(0x8086-0x1F52)"},
{0x8086, 0x1524, 0xFFFF, 0xFFFF, "I350 Gigabit Connection(0x1524)"},
{0x8086, 0x1525, 0xFFFF, 0xFFFF, "82567V-4 Gigabit Network Connection(0x1525)"},
{0x8086, 0x1526, 0xFFFF, 0xFFFF, "82576 Gigabit Network Connection(0x1526)"},
{0x8086, 0x1526, 0x8086, 0xA05C, "Gigabit ET2 Quad Port Server Adapter(0x8086-0xA05C)"},
{0x8086, 0x1526, 0x8086, 0xA06C, "Gigabit ET2 Quad Port Server Adapter(0x8086-0xA06C)"},
{0x8086, 0x1527, 0xFFFF, 0xFFFF, "82580 Gigabit Fiber Network Connection(0x1527)"},
{0x8086, 0x1527, 0x8086, 0x0001, "Ethernet Server Adapter I340-F4(0x8086-0x0001)"},
{0x8086, 0x1527, 0x8086, 0x0002, "Ethernet Server Adapter I340-F4(0x8086-0x0002)"},
{0x8086, 0x1528, 0xFFFF, 0xFFFF, "Ethernet Controller 10-Gigabit X540-AT2(0x1528)"},
{0x8086, 0x1528, 0x1028, 0x1F61, "Ethernet 10G 4P X540/I350 rNDC(0x1028-0x1F61)"},
{0x8086, 0x1528, 0x103C, 0x192D, "561FLR-T 2-port 10Gb Ethernet Adapter(0x103C-0x192D)"},
{0x8086, 0x1528, 0x103C, 0x2004, "Ethernet 10Gb 2-port 561i Adapter(0x103C-0x2004)"},
{0x8086, 0x1528, 0x103C, 0x211A, "Ethernet 10Gb 2-port 561T Adapter(0x103C-0x211A)"},
{0x8086, 0x1528, 0x108E, 0x4853, "Ethernet Controller 10-Gigabit X540-AT2(0x108E-0x4853)"},
{0x8086, 0x1528, 0x108E, 0x7B14, "Sun Dual Port 10 GbE PCIe 2.0 ExpressModule, Base-T(0x108E-0x7B14)"},
{0x8086, 0x1528, 0x108E, 0x7B15, "Sun Dual Port 10 GbE PCIe 2.0 Low Profile Adapter, Base-T(0x108E-0x7B15)"},
{0x8086, 0x1528, 0x1137, 0x00BF, "Ethernet Converged Network Adapter X540-T2(0x1137-0x00BF)"},
{0x8086, 0x1528, 0x1170, 0x0052, "Ethernet Controller 10-Gigabit X540-AT2(0x1170-0x0052)"},
{0x8086, 0x1528, 0x15D9, 0x0734, "AOC-STG-I2T(0x15D9-0x0734)"},
{0x8086, 0x1528, 0x17AA, 0x1073, "ThinkServer X540-T2 AnyFabric(0x17AA-0x1073)"},
{0x8086, 0x1528, 0x17AA, 0x4006, "Ethernet Controller 10-Gigabit X540-AT2(0x17AA-0x4006)"},
{0x8086, 0x1528, 0x1BD4, 0x001A, "10G base-T DP ER102Ti3 Rack Adapter(0x1BD4-0x001A)"},
{0x8086, 0x1528, 0x1BD4, 0x0033, "10G base-T DP EP102Ti3 Adapter(0x1BD4-0x0033)"},
{0x8086, 0x1528, 0x1BD4, 0x0034, "10G base-T DP EP102Ti3A Adapter(0x1BD4-0x0034)"},
{0x8086, 0x1528, 0x4C52, 0x9802, "LREC9802BT Dual-port 10Gb Ethernet Network Adapter(0x4C52-0x9802)"},
{0x8086, 0x1528, 0x8086, 0x0001, "Ethernet Converged Network Adapter X540-T2(0x8086-0x0001)"},
{0x8086, 0x1528, 0x8086, 0x0002, "Ethernet Converged Network Adapter X540-T1(0x8086-0x0002)"},
{0x8086, 0x1528, 0x8086, 0x001A, "Ethernet Converged Network Adapter X540-T2(0x8086-0x001A)"},
{0x8086, 0x1528, 0x8086, 0x00A2, "Ethernet Converged Network Adapter X540-T1(0x8086-0x00A2)"},
{0x8086, 0x1528, 0x8086, 0x1F61, "Ethernet 10G 4P X540/I350 rNDC(0x8086-0x1F61)"},
{0x8086, 0x1528, 0x8086, 0x5003, "Ethernet 10G 2P X540-t Adapter(0x8086-0x5003)"},
{0x8086, 0x1528, 0x8086, 0x5004, "Ethernet 10G 2P X540-t Adapter(0x8086-0x5004)"},
{0x8086, 0x1529, 0xFFFF, 0xFFFF, "82599 10 Gigabit Dual Port Network Connection with FCoE(0x1529)"},
{0x8086, 0x152A, 0xFFFF, 0xFFFF, "82599 10 Gigabit Dual Port Backplane Connection with FCoE(0x152A)"},
{0x8086, 0x152E, 0xFFFF, 0xFFFF, "82599 Virtual Function(0x152E)"},
{0x8086, 0x152F, 0xFFFF, 0xFFFF, "I350 Virtual Function(0x152F)"},
{0x8086, 0x1530, 0xFFFF, 0xFFFF, "X540 Virtual Function(0x1530)"},
{0x8086, 0x1531, 0xFFFF, 0xFFFF, "I210 Gigabit Unprogrammed(0x1531)"},
{0x8086, 0x1533, 0xFFFF, 0xFFFF, "I210 Gigabit Network Connection(0x1533)"},
{0x8086, 0x1533, 0x1028, 0x0B35, "I210 Gigabit Network Connection(0x1028-0x0B35)"},
{0x8086, 0x1533, 0x103C, 0x0003, "Ethernet I210-T1 GbE NIC(0x103C-0x0003)"},
{0x8086, 0x1533, 0x1059, 0x0180, "RD10019 1GbE interface(0x1059-0x0180)"},
{0x8086, 0x1533, 0x1093, 0x7706, "Compact Vision System Ethernet Adapter(0x1093-0x7706)"},
{0x8086, 0x1533, 0x10A9, 0x802C, "UV300 BaseIO single-port GbE(0x10A9-0x802C)"},
{0x8086, 0x1533, 0x10A9, 0x802D, "UV3000 BaseIO GbE Network(0x10A9-0x802D)"},
{0x8086, 0x1533, 0x17AA, 0x1059, "I210 Gigabit Network Connection(0x17AA-0x1059)"},
{0x8086, 0x1533, 0x17AA, 0x1100, "ThinkServer Ethernet Server Adapter(0x17AA-0x1100)"},
{0x8086, 0x1533, 0x17AA, 0x1509, "I210 Gigabit Network Connection(0x17AA-0x1509)"},
{0x8086, 0x1533, 0x17AA, 0x404D, "I210 PCIe 1Gb 1-Port RJ45 LOM(0x17AA-0x404D)"},
{0x8086, 0x1533, 0x17AA, 0x407A, "I210 PCIe 1Gb 1-Port RJ45 LOM(0x17AA-0x407A)"},
{0x8086, 0x1533, 0x4C52, 0x1051, "LRES1051PT Dual-port 1Gb Ethernet Network Adapter(0x4C52-0x1051)"},
{0x8086, 0x1533, 0x4C52, 0x1210, "LREC9204CT Single-port 1Gb Ethernet Network Adapter(0x4C52-0x1210)"},
{0x8086, 0x1533, 0x4C52, 0x2057, "LRES2057PT Dual-port 1Gb Ethernet Network Adapter(0x4C52-0x2057)"},
{0x8086, 0x1533, 0x4C52, 0x2206, "LRES2206PT Single-port 1Gb Ethernet Network Adapter(0x4C52-0x2206)"},
{0x8086, 0x1533, 0x4C52, 0x2210, "LRES2210PT Single-port 1Gb Ethernet Network Adapter(0x4C52-0x2210)"},
{0x8086, 0x1533, 0x4C52, 0x2211, "LRES2211PT Single-port 1Gb Ethernet Network Adapter(0x4C52-0x2211)"},
{0x8086, 0x1533, 0x4C52, 0x2214, "LRES2214PT Single-port 1Gb Ethernet Network Adapter(0x4C52-0x2214)"},
{0x8086, 0x1533, 0x4C52, 0x3002, "LRES3002PT Dual-port 1Gb Ethernet Network Adapter(0x4C52-0x3002)"},
{0x8086, 0x1533, 0x4C52, 0x3004, "LRES3004PT Quad-port 1Gb Ethernet Network Adapter(0x4C52-0x3004)"},
{0x8086, 0x1533, 0x8086, 0x0001, "Ethernet Server Adapter I210-T1(0x8086-0x0001)"},
{0x8086, 0x1533, 0x8086, 0x0002, "Ethernet Server Adapter I210-T1(0x8086-0x0002)"},
{0x8086, 0x1536, 0xFFFF, 0xFFFF, "I210 Gigabit Fiber Network Connection(0x1536)"},
{0x8086, 0x1536, 0x4C52, 0x2204, "LRES2204PT Single-port 1Gb Ethernet Network Adapter(0x4C52-0x2204)"},
{0x8086, 0x1536, 0x4C52, 0x2212, "LRES2212PF Single-port 1Gb Ethernet Network Adapter(0x4C52-0x2212)"},
{0x8086, 0x1536, 0x4C52, 0x2213, "LRES2213PF Single-port 1Gb Ethernet Network Adapter(0x4C52-0x2213)"},
{0x8086, 0x1536, 0x4C52, 0x6230, "LREC6230PF Single-port 1Gb Ethernet Network Adapter(0x4C52-0x6230)"},
{0x8086, 0x1537, 0xFFFF, 0xFFFF, "I210 Gigabit Backplane Connection(0x1537)"},
{0x8086, 0x1537, 0x1059, 0x0110, "T4005 1GbE interface(0x1059-0x0110)"},
{0x8086, 0x1537, 0x1059, 0x0111, "T4007 1GbE interface(0x1059-0x0111)"},
{0x8086, 0x1537, 0x1059, 0x0120, "T4008 1GbE interface(0x1059-0x0120)"},
{0x8086, 0x1537, 0x1059, 0x0130, "T4009 1GbE interface(0x1059-0x0130)"},
{0x8086, 0x1537, 0x1059, 0x0140, "T2035 1GbE interface(0x1059-0x0140)"},
{0x8086, 0x1537, 0x1059, 0x0150, "RD-01068 1GbE interface(0x1059-0x0150)"},
{0x8086, 0x1537, 0x1059, 0x0170, "RD-01213 10GbE interface(0x1059-0x0170)"},
{0x8086, 0x1538, 0xFFFF, 0xFFFF, "I210 Gigabit Network Connection(0x1538)"},
{0x8086, 0x1539, 0xFFFF, 0xFFFF, "I211 Gigabit Network Connection(0x1539)"},
{0x8086, 0x153A, 0xFFFF, 0xFFFF, "Ethernet Connection I217-LM(0x153A)"},
{0x8086, 0x153A, 0x103C, 0x1909, "ZBook 15(0x103C-0x1909)"},
{0x8086, 0x153A, 0x103C, 0x1998, "EliteDesk 800 G1(0x103C-0x1998)"},
{0x8086, 0x153A, 0x17AA, 0x220E, "ThinkPad T440p(0x17AA-0x220E)"},
{0x8086, 0x153A, 0x17AA, 0x309F, "ThinkCentre M83(0x17AA-0x309F)"},
{0x8086, 0x153B, 0xFFFF, 0xFFFF, "Ethernet Connection I217-V(0x153B)"},
{0x8086, 0x1547, 0xFFFF, 0xFFFF, "DSL3510 Thunderbolt Controller [Cactus Ridge 4C 2012](0x1547)"},
{0x8086, 0x1548, 0xFFFF, 0xFFFF, "DSL3310 Thunderbolt Controller [Cactus Ridge 2C 2012](0x1548)"},
{0x8086, 0x1549, 0xFFFF, 0xFFFF, "DSL2210 Thunderbolt Controller [Port Ridge 1C 2011](0x1549)"},
{0x8086, 0x154A, 0xFFFF, 0xFFFF, "Ethernet Server Adapter X520-4(0x154A)"},
{0x8086, 0x154A, 0x8086, 0x011A, "Ethernet Converged Network Adapter X520-4(0x8086-0x011A)"},
{0x8086, 0x154A, 0x8086, 0x011B, "Ethernet Converged Network Adapter X520-4(0x8086-0x011B)"},
{0x8086, 0x154A, 0x8086, 0x011C, "Ethernet Converged Network Adapter X520-4(0x8086-0x011C)"},
{0x8086, 0x154C, 0xFFFF, 0xFFFF, "Ethernet Virtual Function 700 Series(0x154C)"},
{0x8086, 0x154D, 0xFFFF, 0xFFFF, "Ethernet 10G 2P X520 Adapter(0x154D)"},
{0x8086, 0x154D, 0x8086, 0x7B11, "10GbE 2P X520 Adapter(0x8086-0x7B11)"},
{0x8086, 0x1557, 0xFFFF, 0xFFFF, "82599 10 Gigabit Network Connection(0x1557)"},
{0x8086, 0x1557, 0x17AA, 0x4008, "82599EN 10 Gigabit Network Connection(0x17AA-0x4008)"},
{0x8086, 0x1557, 0x1BD4, 0x001C, "10G SFP+ SP ER101Fi4 Rack Adapter(0x1BD4-0x001C)"},
{0x8086, 0x1557, 0x1BD4, 0x0030, "10G SFP+ SP EP101Fi4A Adapter(0x1BD4-0x0030)"},
{0x8086, 0x1557, 0x8086, 0x0001, "Ethernet OCP Server Adapter X520-1(0x8086-0x0001)"},
{0x8086, 0x1558, 0xFFFF, 0xFFFF, "Ethernet Converged Network Adapter X520-Q1(0x1558)"},
{0x8086, 0x1558, 0x8086, 0x011A, "Ethernet Converged Network Adapter X520-Q1(0x8086-0x011A)"},
{0x8086, 0x1558, 0x8086, 0x011B, "Ethernet Converged Network Adapter X520-Q1(0x8086-0x011B)"},
{0x8086, 0x1559, 0xFFFF, 0xFFFF, "Ethernet Connection I218-V(0x1559)"},
{0x8086, 0x155A, 0xFFFF, 0xFFFF, "Ethernet Connection I218-LM(0x155A)"},
{0x8086, 0x155A, 0x17AA, 0x2214, "ThinkPad X240(0x17AA-0x2214)"},
{0x8086, 0x155C, 0xFFFF, 0xFFFF, "Ethernet Server Bypass Adapter(0x155C)"},
{0x8086, 0x155C, 0x8086, 0x0001, "Ethernet Server Bypass Adapter X540-T2(0x8086-0x0001)"},
{0x8086, 0x155D, 0xFFFF, 0xFFFF, "Ethernet Server Bypass Adapter(0x155D)"},
{0x8086, 0x155D, 0x8086, 0x0001, "Ethernet Server Bypass Adapter X520-SR2(0x8086-0x0001)"},
{0x8086, 0x155D, 0x8086, 0x0002, "Ethernet Server Bypass Adapter X520-LR2(0x8086-0x0002)"},
{0x8086, 0x1560, 0xFFFF, 0xFFFF, "Ethernet Controller X540(0x1560)"},
{0x8086, 0x1560, 0x4C52, 0x9801, "LREC9801BT Single-port 10Gb Ethernet Network Adapter(0x4C52-0x9801)"},
{0x8086, 0x1563, 0xFFFF, 0xFFFF, "Ethernet Controller X550(0x1563)"},
{0x8086, 0x1563, 0x1028, 0x1FA8, "Ethernet 10G 4P X550/I350 rNDC(0x1028-0x1FA8)"},
{0x8086, 0x1563, 0x1028, 0x1FA9, "Ethernet 10G 4P X550 rNDC(0x1028-0x1FA9)"},
{0x8086, 0x1563, 0x1137, 0x02B2, "X550-TX 10 Gig LOM(0x1137-0x02B2)"},
{0x8086, 0x1563, 0x1137, 0x02B3, "X550-TX 10 Gig LOM(0x1137-0x02B3)"},
{0x8086, 0x1563, 0x1170, 0x0001, "Intel Ethernet Controller X550-T2 OCP card(0x1170-0x0001)"},
{0x8086, 0x1563, 0x14C0, 0x1201, "X550 10Gb 2P RJ45 OCP Mezz(0x14C0-0x1201)"},
{0x8086, 0x1563, 0x1590, 0x00D1, "Ethernet 10Gb 2-port 562T Adapter(0x1590-0x00D1)"},
{0x8086, 0x1563, 0x1590, 0x00D2, "Ethernet 10Gb 2-port 562FLR-T Adapter(0x1590-0x00D2)"},
{0x8086, 0x1563, 0x16B8, 0x7217, "Twin10G Thunderbolt 3 Edition(0x16B8-0x7217)"},
{0x8086, 0x1563, 0x18D4, 0x0C08, "X550 10Gb 2-port RJ45 OCP Mezz Card MOP81-I-10GT2(0x18D4-0x0C08)"},
{0x8086, 0x1563, 0x193D, 0x1008, "560T-B(0x193D-0x1008)"},
{0x8086, 0x1563, 0x193D, 0x1009, "560T-L(0x193D-0x1009)"},
{0x8086, 0x1563, 0x193D, 0x1011, "UN-NIC-ETH563T-sL-2P(0x193D-0x1011)"},
{0x8086, 0x1563, 0x4C52, 0x1025, "LRES1025PT Dual-port 10Gb Ethernet Network Adapter(0x4C52-0x1025)"},
{0x8086, 0x1563, 0x4C52, 0x9812, "LREC9812BT Dual-port 10Gb Ethernet Network Adapter(0x4C52-0x9812)"},
{0x8086, 0x1563, 0x8086, 0x0001, "Ethernet Converged Network Adapter X550-T2(0x8086-0x0001)"},
{0x8086, 0x1563, 0x8086, 0x001A, "Ethernet Converged Network Adapter X550-T2(0x8086-0x001A)"},
{0x8086, 0x1563, 0x8086, 0x001B, "Ethernet Server Adapter X550-T2 for OCP(0x8086-0x001B)"},
{0x8086, 0x1563, 0x8086, 0x001D, "Ethernet 10G 2P X550-t Adapter(0x8086-0x001D)"},
{0x8086, 0x1563, 0x8086, 0x0022, "Ethernet Converged Network Adapter X550-T2(0x8086-0x0022)"},
{0x8086, 0x1564, 0xFFFF, 0xFFFF, "X550 Virtual Function(0x1564)"},
{0x8086, 0x1565, 0xFFFF, 0xFFFF, "X550 Virtual Function(0x1565)"},
{0x8086, 0x1566, 0xFFFF, 0xFFFF, "DSL4410 Thunderbolt NHI [Redwood Ridge 2C 2013](0x1566)"},
{0x8086, 0x1567, 0xFFFF, 0xFFFF, "DSL4410 Thunderbolt Bridge [Redwood Ridge 2C 2013](0x1567)"},
{0x8086, 0x1568, 0xFFFF, 0xFFFF, "DSL4510 Thunderbolt NHI [Redwood Ridge 4C 2013](0x1568)"},
{0x8086, 0x1569, 0xFFFF, 0xFFFF, "DSL4510 Thunderbolt Bridge [Redwood Ridge 4C 2013](0x1569)"},
{0x8086, 0x156A, 0xFFFF, 0xFFFF, "DSL5320 Thunderbolt 2 NHI [Falcon Ridge 2C 2013](0x156A)"},
{0x8086, 0x156B, 0xFFFF, 0xFFFF, "DSL5320 Thunderbolt 2 Bridge [Falcon Ridge 2C 2013](0x156B)"},
{0x8086, 0x156C, 0xFFFF, 0xFFFF, "DSL5520 Thunderbolt 2 NHI [Falcon Ridge 4C 2013](0x156C)"},
{0x8086, 0x156D, 0xFFFF, 0xFFFF, "DSL5520 Thunderbolt 2 Bridge [Falcon Ridge 4C 2013](0x156D)"},
{0x8086, 0x156F, 0xFFFF, 0xFFFF, "Ethernet Connection I219-LM(0x156F)"},
{0x8086, 0x156F, 0x1028, 0x06DC, "Latitude E7470(0x1028-0x06DC)"},
{0x8086, 0x156F, 0x103C, 0x8079, "EliteBook 840 G3(0x103C-0x8079)"},
{0x8086, 0x156F, 0x17AA, 0x2247, "ThinkPad T570(0x17AA-0x2247)"},
{0x8086, 0x1570, 0xFFFF, 0xFFFF, "Ethernet Connection I219-V(0x1570)"},
{0x8086, 0x1571, 0xFFFF, 0xFFFF, "Ethernet Virtual Function 700 Series(0x1571)"},
{0x8086, 0x1572, 0xFFFF, 0xFFFF, "Ethernet Controller X710 for 10GbE SFP+(0x1572)"},
{0x8086, 0x1572, 0x1028, 0x0000, "Ethernet 10G X710 rNDC(0x1028-0x0000)"},
{0x8086, 0x1572, 0x1028, 0x1F99, "Ethernet 10G 4P X710/I350 rNDC(0x1028-0x1F99)"},
{0x8086, 0x1572, 0x1028, 0x1F9C, "Ethernet 10G 4P X710 SFP+ rNDC(0x1028-0x1F9C)"},
{0x8086, 0x1572, 0x103C, 0x0000, "Ethernet 10Gb 562SFP+ Adapter(0x103C-0x0000)"},
{0x8086, 0x1572, 0x103C, 0x22FC, "Ethernet 10Gb 2-port 562FLR-SFP+ Adapter(0x103C-0x22FC)"},
{0x8086, 0x1572, 0x103C, 0x22FD, "Ethernet 10Gb 2-port 562SFP+ Adapter(0x103C-0x22FD)"},
{0x8086, 0x1572, 0x1137, 0x0000, "Ethernet Converged NIC X710-DA(0x1137-0x0000)"},
{0x8086, 0x1572, 0x1137, 0x013B, "Ethernet Converged NIC X710-DA4(0x1137-0x013B)"},
{0x8086, 0x1572, 0x1137, 0x020A, "Ethernet Converged NIC X710-DA2(0x1137-0x020A)"},
{0x8086, 0x1572, 0x1590, 0x0000, "Ethernet Controller X710 for 10GbE SFP+(0x1590-0x0000)"},
{0x8086, 0x1572, 0x1590, 0x0225, "Ethernet 10GbE 4P 563SFP+ Adapter(0x1590-0x0225)"},
{0x8086, 0x1572, 0x1590, 0x022F, "Ethernet 10Gb 2-port 564i Communication Board(0x1590-0x022F)"},
{0x8086, 0x1572, 0x17AA, 0x0000, "ThinkServer X710 AnyFabric for 10GbE SFP+(0x17AA-0x0000)"},
{0x8086, 0x1572, 0x17AA, 0x4001, "ThinkServer X710-4 AnyFabric for 10GbE SFP+(0x17AA-0x4001)"},
{0x8086, 0x1572, 0x17AA, 0x4002, "ThinkServer X710-2 AnyFabric for 10GbE SFP+(0x17AA-0x4002)"},
{0x8086, 0x1572, 0x193D, 0x1020, "NIC-ETH561F-sL-4x10G(0x193D-0x1020)"},
{0x8086, 0x1572, 0x193D, 0x1021, "NIC-ETH561F-sL-2x10G(0x193D-0x1021)"},
{0x8086, 0x1572, 0x193D, 0x1081, "NIC-ETH561F-3S-2P(0x193D-0x1081)"},
{0x8086, 0x1572, 0x19E5, 0xD11C, "Ethernet 2-port X710 10Gb SFP+ Adapter SP330(0x19E5-0xD11C)"},
{0x8086, 0x1572, 0x1BD4, 0x0042, "10G SFP+ DP EP102Fi4 Adapter(0x1BD4-0x0042)"},
{0x8086, 0x1572, 0x1BD4, 0x0056, "Ethernet Network Adapter X710-BM2 for OCP NIC 3.0(0x1BD4-0x0056)"},
{0x8086, 0x1572, 0x1BD4, 0x0065, "F102IX710(0x1BD4-0x0065)"},
{0x8086, 0x1572, 0x1BD4, 0x0074, "Ethernet Network Adapter X710-BM2 for lldp(0x1BD4-0x0074)"},
{0x8086, 0x1572, 0x1BD4, 0x008B, "F102IX710(0x1BD4-0x008B)"},
{0x8086, 0x1572, 0x4C52, 0x3003, "LRES3003PF Quad-port 10Gb Ethernet Server Adapter for OCP(0x4C52-0x3003)"},
{0x8086, 0x1572, 0x4C52, 0x3007, "LRES3007PF Quad-port 10Gb Ethernet Server Adapter for OCP(0x4C52-0x3007)"},
{0x8086, 0x1572, 0x4C52, 0x3039, "LRES3039PF Dual-port 10Gb Ethernet Server Adapter for OCP(0x4C52-0x3039)"},
{0x8086, 0x1572, 0x4C52, 0x9804, "LREC9804BF Quad-port 10Gb Ethernet Server Adapter(0x4C52-0x9804)"},
{0x8086, 0x1572, 0x4C52, 0x9812, "LREC9812BF Dual-port 10Gb Ethernet Server Adapter(0x4C52-0x9812)"},
{0x8086, 0x1572, 0x8086, 0x0000, "Ethernet Converged Network Adapter X710(0x8086-0x0000)"},
{0x8086, 0x1572, 0x8086, 0x0001, "Ethernet Converged Network Adapter X710-4(0x8086-0x0001)"},
{0x8086, 0x1572, 0x8086, 0x0002, "Ethernet Converged Network Adapter X710-4(0x8086-0x0002)"},
{0x8086, 0x1572, 0x8086, 0x0004, "Ethernet Converged Network Adapter X710-4(0x8086-0x0004)"},
{0x8086, 0x1572, 0x8086, 0x0005, "Ethernet Converged Network Adapter X710(0x8086-0x0005)"},
{0x8086, 0x1572, 0x8086, 0x0006, "Ethernet Converged Network Adapter X710(0x8086-0x0006)"},
{0x8086, 0x1572, 0x8086, 0x0007, "Ethernet Converged Network Adapter X710-2(0x8086-0x0007)"},
{0x8086, 0x1572, 0x8086, 0x0008, "Ethernet Converged Network Adapter X710-2(0x8086-0x0008)"},
{0x8086, 0x1572, 0x8086, 0x0009, "Ethernet Controller X710 for 10GbE SFP+(0x8086-0x0009)"},
{0x8086, 0x1572, 0x8086, 0x000A, "Ethernet Controller X710 for 10GbE SFP+(0x8086-0x000A)"},
{0x8086, 0x1572, 0x8086, 0x000B, "Ethernet Server Adapter X710-DA2 for OCP(0x8086-0x000B)"},
{0x8086, 0x1572, 0x8086, 0x000D, "Ethernet Controller X710 for 10GbE SFP+(0x8086-0x000D)"},
{0x8086, 0x1572, 0x8086, 0x000E, "Ethernet Server Adapter OCP X710-2(0x8086-0x000E)"},
{0x8086, 0x1572, 0x8086, 0x000F, "Ethernet Server Adapter OCP X710-2(0x8086-0x000F)"},
{0x8086, 0x1572, 0x8086, 0x0010, "Ethernet Converged Network Adapter X710(0x8086-0x0010)"},
{0x8086, 0x1572, 0x8086, 0x0011, "Ethernet Network Adapter X710-2 for OCP NIC 3.0(0x8086-0x0011)"},
{0x8086, 0x1572, 0x8086, 0x0012, "Ethernet Network Adapter X710-4 for OCP NIC 3.0(0x8086-0x0012)"},
{0x8086, 0x1572, 0x8086, 0x0013, "Ethernet 10G 2P X710 OCP(0x8086-0x0013)"},
{0x8086, 0x1572, 0x8086, 0x0014, "Ethernet 10G 4P X710 OCP(0x8086-0x0014)"},
{0x8086, 0x1572, 0x8086, 0x0015, "Ethernet Server Adapter X710-DA2 for OCP(0x8086-0x0015)"},
{0x8086, 0x1572, 0x8086, 0x00A1, "Ethernet Network Adapter X710-2 for OCP NIC 3.0(0x8086-0x00A1)"},
{0x8086, 0x1572, 0x8086, 0x00A2, "Ethernet Network Adapter X710-4 for OCP NIC 3.0(0x8086-0x00A2)"},
{0x8086, 0x1572, 0x8086, 0x4005, "Ethernet Controller X710 for 10GbE SFP+(0x8086-0x4005)"},
{0x8086, 0x1572, 0x8086, 0x4006, "Ethernet Controller X710 for 10GbE SFP+(0x8086-0x4006)"},
{0x8086, 0x1572, 0x8086, 0x4007, "Ethernet Controller X710 for 10GbE SFP+(0x8086-0x4007)"},
{0x8086, 0x1574, 0xFFFF, 0xFFFF, "Ethernet Controller XL710 Emulation(0x1574)"},
{0x8086, 0x1575, 0xFFFF, 0xFFFF, "DSL6340 Thunderbolt 3 NHI [Alpine Ridge 2C 2015](0x1575)"},
{0x8086, 0x1576, 0xFFFF, 0xFFFF, "DSL6340 Thunderbolt 3 Bridge [Alpine Ridge 2C 2015](0x1576)"},
{0x8086, 0x1577, 0xFFFF, 0xFFFF, "DSL6540 Thunderbolt 3 NHI [Alpine Ridge 4C 2015](0x1577)"},
{0x8086, 0x1578, 0xFFFF, 0xFFFF, "DSL6540 Thunderbolt 3 Bridge [Alpine Ridge 4C 2015](0x1578)"},
{0x8086, 0x157B, 0xFFFF, 0xFFFF, "I210 Gigabit Network Connection(0x157B)"},
{0x8086, 0x157B, 0xEA50, 0xCC10, "RXi2-BP(0xEA50-0xCC10)"},
{0x8086, 0x157C, 0xFFFF, 0xFFFF, "I210 Gigabit Backplane Connection(0x157C)"},
{0x8086, 0x157D, 0xFFFF, 0xFFFF, "DSL5110 Thunderbolt 2 NHI (Low Power) [Win Ridge 2C 2014](0x157D)"},
{0x8086, 0x157E, 0xFFFF, 0xFFFF, "DSL5110 Thunderbolt 2 Bridge (Low Power) [Win Ridge 2C 2014](0x157E)"},
{0x8086, 0x1580, 0xFFFF, 0xFFFF, "Ethernet Controller XL710 for 40GbE backplane(0x1580)"},
{0x8086, 0x1581, 0xFFFF, 0xFFFF, "Ethernet Controller X710 for 10GbE backplane(0x1581)"},
{0x8086, 0x1581, 0x1028, 0x0000, "Ethernet 10G X710-k bNDC(0x1028-0x0000)"},
{0x8086, 0x1581, 0x1028, 0x1F98, "Ethernet 10G 4P X710-k bNDC(0x1028-0x1F98)"},
{0x8086, 0x1581, 0x1028, 0x1F9E, "Ethernet 10G 2P X710-k bNDC(0x1028-0x1F9E)"},
{0x8086, 0x1581, 0x1059, 0x0150, "RD-01068 10GbE-KR interface(0x1059-0x0150)"},
{0x8086, 0x1581, 0x1059, 0x0170, "RD-01213 10GbE interface(0x1059-0x0170)"},
{0x8086, 0x1581, 0x1590, 0x0000, "Ethernet 2-port 563i Adapter(0x1590-0x0000)"},
{0x8086, 0x1581, 0x1590, 0x00F8, "Ethernet 2-port 563i Adapter(0x1590-0x00F8)"},
{0x8086, 0x1581, 0x193D, 0x100E, "NIC-ETH561i-Mb-4x10G(0x193D-0x100E)"},
{0x8086, 0x1581, 0x8086, 0x0000, "Ethernet Converged Network Adapter XL710-Q2(0x8086-0x0000)"},
{0x8086, 0x1583, 0xFFFF, 0xFFFF, "Ethernet Controller XL710 for 40GbE QSFP+(0x1583)"},
{0x8086, 0x1583, 0x1028, 0x0000, "Ethernet 40G 2P XL710 QSFP+ rNDC(0x1028-0x0000)"},
{0x8086, 0x1583, 0x1028, 0x1F9F, "Ethernet 40G 2P XL710 QSFP+ rNDC(0x1028-0x1F9F)"},
{0x8086, 0x1583, 0x108E, 0x0000, "10 Gb/40 Gb Ethernet Adapter(0x108E-0x0000)"},
{0x8086, 0x1583, 0x108E, 0x7B1B, "10 Gb/40 Gb Ethernet Adapter(0x108E-0x7B1B)"},
{0x8086, 0x1583, 0x108E, 0x7B1D, "10Gb/40Gb Ethernet Adapter(0x108E-0x7B1D)"},
{0x8086, 0x1583, 0x1137, 0x0000, "Ethernet Converged NIC XL710-QDA2(0x1137-0x0000)"},
{0x8086, 0x1583, 0x1137, 0x013C, "Ethernet Converged NIC XL710-QDA2(0x1137-0x013C)"},
{0x8086, 0x1583, 0x4C52, 0x3042, "LRES3042PF Dual-port 40Gb Ethernet Server Adapter for OCP(0x4C52-0x3042)"},
{0x8086, 0x1583, 0x4C52, 0x9902, "LREC9902BF Dual-port 40Gb Ethernet Server Adapter(0x4C52-0x9902)"},
{0x8086, 0x1583, 0x8086, 0x0000, "Ethernet Converged Network Adapter XL710-Q2(0x8086-0x0000)"},
{0x8086, 0x1583, 0x8086, 0x0001, "Ethernet Converged Network Adapter XL710-Q2(0x8086-0x0001)"},
{0x8086, 0x1583, 0x8086, 0x0002, "Ethernet Converged Network Adapter XL710-Q2(0x8086-0x0002)"},
{0x8086, 0x1583, 0x8086, 0x0003, "Ethernet I/O Module XL710-Q2(0x8086-0x0003)"},
{0x8086, 0x1583, 0x8086, 0x0004, "Ethernet Server Adapter XL710-Q2OCP(0x8086-0x0004)"},
{0x8086, 0x1583, 0x8086, 0x0006, "Ethernet Converged Network Adapter XL710-Q2(0x8086-0x0006)"},
{0x8086, 0x1584, 0xFFFF, 0xFFFF, "Ethernet Controller XL710 for 40GbE QSFP+(0x1584)"},
{0x8086, 0x1584, 0x4C52, 0x9901, "LREC9901BF Single-port 40Gb Ethernet Server Adapter(0x4C52-0x9901)"},
{0x8086, 0x1584, 0x8086, 0x0000, "Ethernet Converged Network Adapter XL710-Q1(0x8086-0x0000)"},
{0x8086, 0x1584, 0x8086, 0x0001, "Ethernet Converged Network Adapter XL710-Q1(0x8086-0x0001)"},
{0x8086, 0x1584, 0x8086, 0x0002, "Ethernet Converged Network Adapter XL710-Q1(0x8086-0x0002)"},
{0x8086, 0x1584, 0x8086, 0x0003, "Ethernet I/O Module XL710-Q1(0x8086-0x0003)"},
{0x8086, 0x1584, 0x8086, 0x0004, "Ethernet Server Adapter XL710-Q1OCP(0x8086-0x0004)"},
{0x8086, 0x1585, 0xFFFF, 0xFFFF, "Ethernet Controller X710 for 10GbE QSFP+(0x1585)"},
{0x8086, 0x1586, 0xFFFF, 0xFFFF, "Ethernet Controller X710 for 10GBASE-T(0x1586)"},
{0x8086, 0x1586, 0x108E, 0x0000, "Ethernet Controller X710 for 10GBASE-T(0x108E-0x0000)"},
{0x8086, 0x1586, 0x108E, 0x4857, "Ethernet Controller X710 for 10GBASE-T(0x108E-0x4857)"},
{0x8086, 0x1587, 0xFFFF, 0xFFFF, "Ethernet Controller XL710 for 20GbE backplane(0x1587)"},
{0x8086, 0x1587, 0x103C, 0x0000, "Ethernet 10/20Gb 2-port 660FLB Adapter(0x103C-0x0000)"},
{0x8086, 0x1587, 0x103C, 0x22FE, "Ethernet 10/20Gb 2-port 660FLB Adapter(0x103C-0x22FE)"},
{0x8086, 0x1588, 0xFFFF, 0xFFFF, "Ethernet Controller XL710 for 20GbE backplane(0x1588)"},
{0x8086, 0x1588, 0x103C, 0x0000, "Ethernet 10/20Gb 2-port 660M Adapter(0x103C-0x0000)"},
{0x8086, 0x1588, 0x103C, 0x22FF, "Ethernet 10/20Gb 2-port 660M Adapter(0x103C-0x22FF)"},
{0x8086, 0x1588, 0x1137, 0x0000, "Ethernet Network Adapter XXV710(0x1137-0x0000)"},
{0x8086, 0x1588, 0x1137, 0x02B4, "Ethernet Network Adapter XXV710 OCP 2.0(0x1137-0x02B4)"},
{0x8086, 0x1589, 0xFFFF, 0xFFFF, "Ethernet Controller X710/X557-AT 10GBASE-T(0x1589)"},
{0x8086, 0x1589, 0x108E, 0x0000, "Quad Port 10GBase-T Adapter(0x108E-0x0000)"},
{0x8086, 0x1589, 0x108E, 0x7B1C, "Quad Port 10GBase-T Adapter(0x108E-0x7B1C)"},
{0x8086, 0x1589, 0x4C52, 0x9804, "LREC9804BT Quad-port 10Gb Ethernet Network Adapter(0x4C52-0x9804)"},
{0x8086, 0x1589, 0x8086, 0x0000, "Ethernet Converged Network Adapter X710-T(0x8086-0x0000)"},
{0x8086, 0x1589, 0x8086, 0x0001, "Ethernet Converged Network Adapter X710-T4(0x8086-0x0001)"},
{0x8086, 0x1589, 0x8086, 0x0002, "Ethernet Converged Network Adapter X710-T4(0x8086-0x0002)"},
{0x8086, 0x1589, 0x8086, 0x0003, "Ethernet Converged Network Adapter X710-T(0x8086-0x0003)"},
{0x8086, 0x1589, 0x8086, 0x00A0, "Ethernet Converged Network Adapter X710-T4(0x8086-0x00A0)"},
{0x8086, 0x1589, 0x8086, 0x1003, "Ethernet Converged Network Adapter X710-T(0x8086-0x1003)"},
{0x8086, 0x158A, 0xFFFF, 0xFFFF, "Ethernet Controller XXV710 for 25GbE backplane(0x158A)"},
{0x8086, 0x158A, 0x1590, 0x0000, "10/25Gb Ethernet Adapter(0x1590-0x0000)"},
{0x8086, 0x158A, 0x1590, 0x0286, "Synergy 4610C 10/25Gb Ethernet Adapter(0x1590-0x0286)"},
{0x8086, 0x158A, 0x8086, 0x0000, "Ethernet Controller XXV710 for 25GbE backplane(0x8086-0x0000)"},
{0x8086, 0x158A, 0x8086, 0x000A, "Ethernet 25G 2P XXV710 Mezz(0x8086-0x000A)"},
{0x8086, 0x158B, 0xFFFF, 0xFFFF, "Ethernet Controller XXV710 for 25GbE SFP28(0x158B)"},
{0x8086, 0x158B, 0x1137, 0x0000, "Ethernet Network Adapter XXV710(0x1137-0x0000)"},
{0x8086, 0x158B, 0x1137, 0x0225, "Ethernet Network Adapter XXV710(0x1137-0x0225)"},
{0x8086, 0x158B, 0x1137, 0x02B4, "Ethernet Network Adapter XXV710 OCP 2.0(0x1137-0x02B4)"},
{0x8086, 0x158B, 0x1374, 0x0230, "Single Port 25 Gigabit Ethernet PCI Express Server Adapter (PE325G1I71)(0x1374-0x0230)"},
{0x8086, 0x158B, 0x1374, 0x0231, "Single Port 25 Gigabit Ethernet PCI Express Server Adapter (PE325G1I71EU)(0x1374-0x0231)"},
{0x8086, 0x158B, 0x1374, 0x0234, "Dual Port 25 Gigabit Ethernet PCI Express Server Adapter (PE325G2I71)(0x1374-0x0234)"},
{0x8086, 0x158B, 0x1374, 0x0235, "Dual Port 25 Gigabit Ethernet PCI Express Server Adapter (PE325G2I71EU)(0x1374-0x0235)"},
{0x8086, 0x158B, 0x1374, 0x0238, "Quad Port 25 Gigabit Ethernet PCI Express Server Adapter (PE325G4I71L)(0x1374-0x0238)"},
{0x8086, 0x158B, 0x1374, 0x0239, "Quad Port 25 Gigabit Ethernet PCI Express Server Adapter (PE325G4I71LEU)(0x1374-0x0239)"},
{0x8086, 0x158B, 0x1374, 0x023A, "Quad Port 25 Gigabit Ethernet PCI Express Server Adapter (PE31625G4I71L)(0x1374-0x023A)"},
{0x8086, 0x158B, 0x1374, 0x023B, "Quad Port 25 Gigabit Ethernet PCI Express Server Adapter (PE31625G4I71LEU)(0x1374-0x023B)"},
{0x8086, 0x158B, 0x1590, 0x0000, "Ethernet Network Adapter XXV710-2(0x1590-0x0000)"},
{0x8086, 0x158B, 0x1590, 0x0253, "Ethernet 10/25/Gb 2-port 661SFP28 Adapter(0x1590-0x0253)"},
{0x8086, 0x158B, 0x4C52, 0x3017, "LRES3017PF Dual-port 25Gb Ethernet Server Adapter for OCP(0x4C52-0x3017)"},
{0x8086, 0x158B, 0x8086, 0x0000, "Ethernet Network Adapter XXV710(0x8086-0x0000)"},
{0x8086, 0x158B, 0x8086, 0x0001, "Ethernet Network Adapter XXV710-2(0x8086-0x0001)"},
{0x8086, 0x158B, 0x8086, 0x0002, "Ethernet Network Adapter XXV710-2(0x8086-0x0002)"},
{0x8086, 0x158B, 0x8086, 0x0003, "Ethernet Network Adapter XXV710-1(0x8086-0x0003)"},
{0x8086, 0x158B, 0x8086, 0x0004, "Ethernet Network Adapter XXV710-1(0x8086-0x0004)"},
{0x8086, 0x158B, 0x8086, 0x0005, "Ethernet Network Adapter OCP XXV710-2(0x8086-0x0005)"},
{0x8086, 0x158B, 0x8086, 0x0006, "Ethernet Network Adapter OCP XXV710-2(0x8086-0x0006)"},
{0x8086, 0x158B, 0x8086, 0x0007, "Ethernet Network Adapter OCP XXV710-1(0x8086-0x0007)"},
{0x8086, 0x158B, 0x8086, 0x0008, "Ethernet Network Adapter OCP XXV710-1(0x8086-0x0008)"},
{0x8086, 0x158B, 0x8086, 0x0009, "Ethernet 25G 2P XXV710 Adapter(0x8086-0x0009)"},
{0x8086, 0x158B, 0x8086, 0x000A, "Ethernet 25G 2P XXV710 OCP(0x8086-0x000A)"},
{0x8086, 0x158B, 0x8086, 0x000C, "Ethernet Network Adapter XXV710-DA2 for OCP 3.0(0x8086-0x000C)"},
{0x8086, 0x158B, 0x8086, 0x000D, "Ethernet 25G 2P XXV710 OCP(0x8086-0x000D)"},
{0x8086, 0x158B, 0x8086, 0x4001, "Ethernet Network Adapter XXV710-2(0x8086-0x4001)"},
{0x8086, 0x1591, 0xFFFF, 0xFFFF, "Ethernet Controller E810-C for backplane(0x1591)"},
{0x8086, 0x1591, 0x8086, 0xBCCE, "Ethernet Controller E810-C for Intel(R) Open FPGA Stack(0x8086-0xBCCE)"},
{0x8086, 0x1592, 0xFFFF, 0xFFFF, "Ethernet Controller E810-C for QSFP(0x1592)"},
{0x8086, 0x1592, 0x1137, 0x02BF, "E810CQDA2 2x100 GbE QSFP28 PCIe NIC(0x1137-0x02BF)"},
{0x8086, 0x1592, 0x193D, 0x1050, "NIC-ETH1060F-LP-2P 2x100GbE Ethernet PCIe Card(0x193D-0x1050)"},
{0x8086, 0x1592, 0x4C52, 0x1014, "LRES1014PF Dual-port 100Gb Ethernet Server Adapter(0x4C52-0x1014)"},
{0x8086, 0x1592, 0x4C52, 0x3026, "LRES3026PF Dual-port 100Gb Ethernet Server Adapter for OCP(0x4C52-0x3026)"},
{0x8086, 0x1592, 0x8086, 0x0001, "Ethernet Network Adapter E810-C-Q1(0x8086-0x0001)"},
{0x8086, 0x1592, 0x8086, 0x0002, "Ethernet Network Adapter E810-C-Q2(0x8086-0x0002)"},
{0x8086, 0x1592, 0x8086, 0x0004, "Ethernet Network Adapter E810-C-Q2(0x8086-0x0004)"},
{0x8086, 0x1592, 0x8086, 0x0005, "Ethernet Network Adapter E810-C-Q1 for OCP3.0(0x8086-0x0005)"},
{0x8086, 0x1592, 0x8086, 0x0006, "Ethernet Network Adapter E810-C-Q2 for OCP3.0(0x8086-0x0006)"},
{0x8086, 0x1592, 0x8086, 0x0009, "Ethernet Network Adapter E810-C-Q1(0x8086-0x0009)"},
{0x8086, 0x1592, 0x8086, 0x000A, "Ethernet Network Adapter E810-C-Q1 for OCP(0x8086-0x000A)"},
{0x8086, 0x1592, 0x8086, 0x000B, "Ethernet 100G 2P E810-C Adapter(0x8086-0x000B)"},
{0x8086, 0x1592, 0x8086, 0x000C, "Ethernet 100G 2P E810-C OCP(0x8086-0x000C)"},
{0x8086, 0x1592, 0x8086, 0x000D, "Ethernet Network Adapter E810-L-Q2 for OCP 3.0(0x8086-0x000D)"},
{0x8086, 0x1592, 0x8086, 0x000E, "Ethernet Network Adapter E810-2C-Q2(0x8086-0x000E)"},
{0x8086, 0x1592, 0x8086, 0x000F, "Ethernet Network Adapter E810-C-Q2T(0x8086-0x000F)"},
{0x8086, 0x1592, 0x8086, 0x0010, "Ethernet 100G 2P E810-C-stg Adapter(0x8086-0x0010)"},
{0x8086, 0x1592, 0x8086, 0x0011, "Ethernet Network Adapter E810-C-Q1 for OCP3.0(0x8086-0x0011)"},
{0x8086, 0x1592, 0x8086, 0x0012, "Ethernet 100G 2P E810-C-st Adapter(0x8086-0x0012)"},
{0x8086, 0x1592, 0x8086, 0x0013, "Ethernet Network Adapter E810-C-Q1 for OCP 3.0(0x8086-0x0013)"},
{0x8086, 0x1592, 0x8086, 0x0014, "Ethernet 100G 2P E810-2C Adapter(0x8086-0x0014)"},
{0x8086, 0x1593, 0xFFFF, 0xFFFF, "Ethernet Controller E810-C for SFP(0x1593)"},
{0x8086, 0x1593, 0x1137, 0x02C3, "E810XXVDA4 4x25/10 GbE SFP28 PCIe NIC(0x1137-0x02C3)"},
{0x8086, 0x1593, 0x1137, 0x02E9, "E810XXVDA4TG 4x25/10 GbE SFP28 PCIe NIC(0x1137-0x02E9)"},
{0x8086, 0x1593, 0x1137, 0x02EA, "E810XXVDA4T 4x25/10 GbE SFP28 PCIe NIC(0x1137-0x02EA)"},
{0x8086, 0x1593, 0x4C52, 0x1023, "LRES1023PF Quad-port 25Gb Ethernet Server Adapter(0x4C52-0x1023)"},
{0x8086, 0x1593, 0x4C52, 0x3027, "LRES3027PF Quad-port 25Gb Ethernet Server Adapter for OCP(0x4C52-0x3027)"},
{0x8086, 0x1593, 0x8086, 0x0002, "Ethernet Network Adapter E810-L-2(0x8086-0x0002)"},
{0x8086, 0x1593, 0x8086, 0x0005, "Ethernet Network Adapter E810-XXV-4(0x8086-0x0005)"},
{0x8086, 0x1593, 0x8086, 0x0006, "Ethernet Network Adapter E810-XXV-4(0x8086-0x0006)"},
{0x8086, 0x1593, 0x8086, 0x0007, "Ethernet Network Adapter E810-XXV-4(0x8086-0x0007)"},
{0x8086, 0x1593, 0x8086, 0x0008, "Ethernet Network Adapter E810-XXV-2(0x8086-0x0008)"},
{0x8086, 0x1593, 0x8086, 0x0009, "Ethernet Network Adapter E810-XXV-2 for OCP 2.0(0x8086-0x0009)"},
{0x8086, 0x1593, 0x8086, 0x000A, "Ethernet 25G 4P E810-XXV Adapter(0x8086-0x000A)"},
{0x8086, 0x1593, 0x8086, 0x000C, "Ethernet Network Adapter E810-XXV-4 for OCP 3.0(0x8086-0x000C)"},
{0x8086, 0x1593, 0x8086, 0x000D, "Ethernet 25G 4P E810-XXV OCP(0x8086-0x000D)"},
{0x8086, 0x1593, 0x8086, 0x000E, "Ethernet Network Adapter E810-XXV-4T(0x8086-0x000E)"},
{0x8086, 0x1593, 0x8086, 0x000F, "Ethernet 25G 4P E810-XXV-stg Adapter(0x8086-0x000F)"},
{0x8086, 0x1593, 0x8086, 0x0010, "Ethernet 25G 4P E810-XXV-st Adapter(0x8086-0x0010)"},
{0x8086, 0x1593, 0x8086, 0x4010, "Ethernet Network Adapter E810-XXV-4(0x8086-0x4010)"},
{0x8086, 0x1593, 0x8086, 0x4013, "Ethernet Network Adapter E810-XXV-4 for OCP 3.0(0x8086-0x4013)"},
{0x8086, 0x1593, 0x8086, 0x401C, "Ethernet Network Adapter E810-XXV-4 for OCP 3.0(0x8086-0x401C)"},
{0x8086, 0x1599, 0xFFFF, 0xFFFF, "Ethernet Controller E810-XXV for backplane(0x1599)"},
{0x8086, 0x1599, 0x8086, 0x0001, "Ethernet 25G 2P E810-XXV-k Mezz(0x8086-0x0001)"},
{0x8086, 0x159A, 0xFFFF, 0xFFFF, "Ethernet Controller E810-XXV for QSFP(0x159A)"},
{0x8086, 0x159B, 0xFFFF, 0xFFFF, "Ethernet Controller E810-XXV for SFP(0x159B)"},
{0x8086, 0x159B, 0x1137, 0x02BE, "E810XXVDA2 2x25/10 GbE SFP28 PCIe NIC(0x1137-0x02BE)"},
{0x8086, 0x159B, 0x193D, 0x1085, "NIC-ETH660F-3S-2P(0x193D-0x1085)"},
{0x8086, 0x159B, 0x1BD4, 0x0057, "Ethernet Network Adapter E810-XXVAM2(0x1BD4-0x0057)"},
{0x8086, 0x159B, 0x1BD4, 0x0058, "Ethernet Network Adapter E810-XXVAM2 for OCP 3.0(0x1BD4-0x0058)"},
{0x8086, 0x159B, 0x1BD4, 0x006E, "Ethernet Network Adapter E810-XXVAM2 for BD(0x1BD4-0x006E)"},
{0x8086, 0x159B, 0x1BD4, 0x0083, "Ethernet Network Adapter E810-XXVAM2 for lldp(0x1BD4-0x0083)"},
{0x8086, 0x159B, 0x1BD4, 0x00A0, "S252IE810(0x1BD4-0x00A0)"},
{0x8086, 0x159B, 0x1EEC, 0x0102, "VSE-225-41E Dual-port 10Gb/25Gb Etherent PCIe(0x1EEC-0x0102)"},
{0x8086, 0x159B, 0x4C52, 0x0003, "LRES1021PF Dual-port 25Gb Ethernet Server Adapter(0x4C52-0x0003)"},
{0x8086, 0x159B, 0x4C52, 0x3029, "LRES3029PF Dual-port 25Gb Ethernet Server Adapter for OCP(0x4C52-0x3029)"},
{0x8086, 0x159B, 0x8086, 0x0001, "Ethernet 25G 2P E810-XXV OCP(0x8086-0x0001)"},
{0x8086, 0x159B, 0x8086, 0x0002, "Ethernet 25G 2P E810-XXV Adapter(0x8086-0x0002)"},
{0x8086, 0x159B, 0x8086, 0x0003, "Ethernet Network Adapter E810-XXV-2(0x8086-0x0003)"},
{0x8086, 0x159B, 0x8086, 0x0005, "Ethernet Network Adapter E810-XXV-2 for OCP 3.0(0x8086-0x0005)"},
{0x8086, 0x159B, 0x8086, 0x4001, "Ethernet Network Adapter E810-XXV-2(0x8086-0x4001)"},
{0x8086, 0x159B, 0x8086, 0x4002, "Ethernet Network Adapter E810-XXV-2 for OCP 3.0(0x8086-0x4002)"},
{0x8086, 0x159B, 0x8086, 0x4003, "Ethernet Network Adapter E810-XXV-2(0x8086-0x4003)"},
{0x8086, 0x159B, 0x8086, 0x4015, "Ethernet Network Adapter E810-XXV-2 for OCP 3.0(0x8086-0x4015)"},
{0x8086, 0x15A0, 0xFFFF, 0xFFFF, "Ethernet Connection (2) I218-LM(0x15A0)"},
{0x8086, 0x15A1, 0xFFFF, 0xFFFF, "Ethernet Connection (2) I218-V(0x15A1)"},
{0x8086, 0x15A2, 0xFFFF, 0xFFFF, "Ethernet Connection (3) I218-LM(0x15A2)"},
{0x8086, 0x15A3, 0xFFFF, 0xFFFF, "Ethernet Connection (3) I218-V(0x15A3)"},
{0x8086, 0x15A4, 0xFFFF, 0xFFFF, "Ethernet Switch FM10000 Host Interface(0x15A4)"},
{0x8086, 0x15A5, 0xFFFF, 0xFFFF, "Ethernet Switch FM10000 Host Virtual Interface(0x15A5)"},
{0x8086, 0x15A8, 0xFFFF, 0xFFFF, "Ethernet Connection X552 Virtual Function(0x15A8)"},
{0x8086, 0x15A9, 0xFFFF, 0xFFFF, "X552 Virtual Function(0x15A9)"},
{0x8086, 0x15AA, 0xFFFF, 0xFFFF, "Ethernet Connection X552 10 GbE Backplane(0x15AA)"},
{0x8086, 0x15AA, 0x1059, 0x0120, "T4008 10GbE interface(0x1059-0x0120)"},
{0x8086, 0x15AB, 0xFFFF, 0xFFFF, "Ethernet Connection X552 10 GbE Backplane(0x15AB)"},
{0x8086, 0x15AB, 0x1059, 0x0150, "RD-01068 10GbE interface(0x1059-0x0150)"},
{0x8086, 0x15AB, 0x1059, 0x0170, "RD-01213 10GbE interface(0x1059-0x0170)"},
{0x8086, 0x15AC, 0xFFFF, 0xFFFF, "Ethernet Connection X552 10 GbE SFP+(0x15AC)"},
{0x8086, 0x15AC, 0x1059, 0x0160, "RD-01167 10GbE interface(0x1059-0x0160)"},
{0x8086, 0x15AD, 0xFFFF, 0xFFFF, "Ethernet Connection X552/X557-AT 10GBASE-T(0x15AD)"},
{0x8086, 0x15AE, 0xFFFF, 0xFFFF, "Ethernet Connection X552 1000BASE-T(0x15AE)"},
{0x8086, 0x15B0, 0xFFFF, 0xFFFF, "Ethernet Connection X552 Backplane(0x15B0)"},
{0x8086, 0x15B4, 0xFFFF, 0xFFFF, "X553 Virtual Function(0x15B4)"},
{0x8086, 0x15B5, 0xFFFF, 0xFFFF, "DSL6340 USB 3.1 Controller [Alpine Ridge](0x15B5)"},
{0x8086, 0x15B6, 0xFFFF, 0xFFFF, "DSL6540 USB 3.1 Controller [Alpine Ridge](0x15B6)"},
{0x8086, 0x15B7, 0xFFFF, 0xFFFF, "Ethernet Connection (2) I219-LM(0x15B7)"},
{0x8086, 0x15B8, 0xFFFF, 0xFFFF, "Ethernet Connection (2) I219-V(0x15B8)"},
{0x8086, 0x15B8, 0x1462, 0x7994, "H110M ECO/GAMING(0x1462-0x7994)"},
{0x8086, 0x15B8, 0x1462, 0x7A72, "H270 PC MATE(0x1462-0x7A72)"},
{0x8086, 0x15B9, 0xFFFF, 0xFFFF, "Ethernet Connection (3) I219-LM(0x15B9)"},
{0x8086, 0x15BB, 0xFFFF, 0xFFFF, "Ethernet Connection (7) I219-LM(0x15BB)"},
{0x8086, 0x15BC, 0xFFFF, 0xFFFF, "Ethernet Connection (7) I219-V(0x15BC)"},
{0x8086, 0x15BD, 0xFFFF, 0xFFFF, "Ethernet Connection (6) I219-LM(0x15BD)"},
{0x8086, 0x15BE, 0xFFFF, 0xFFFF, "Ethernet Connection (6) I219-V(0x15BE)"},
{0x8086, 0x15BF, 0xFFFF, 0xFFFF, "JHL6240 Thunderbolt 3 NHI (Low Power) [Alpine Ridge LP 2016](0x15BF)"},
{0x8086, 0x15C0, 0xFFFF, 0xFFFF, "JHL6240 Thunderbolt 3 Bridge (Low Power) [Alpine Ridge LP 2016](0x15C0)"},
{0x8086, 0x15C1, 0xFFFF, 0xFFFF, "JHL6240 Thunderbolt 3 USB 3.1 Controller (Low Power) [Alpine Ridge LP 2016](0x15C1)"},
{0x8086, 0x15C2, 0xFFFF, 0xFFFF, "Ethernet Connection X553 Backplane(0x15C2)"},
{0x8086, 0x15C3, 0xFFFF, 0xFFFF, "Ethernet Connection X553 Backplane(0x15C3)"},
{0x8086, 0x15C4, 0xFFFF, 0xFFFF, "Ethernet Connection X553 10 GbE SFP+(0x15C4)"},
{0x8086, 0x15C5, 0xFFFF, 0xFFFF, "X553 Virtual Function(0x15C5)"},
{0x8086, 0x15C6, 0xFFFF, 0xFFFF, "Ethernet Connection X553 1GbE(0x15C6)"},
{0x8086, 0x15C7, 0xFFFF, 0xFFFF, "Ethernet Connection X553 1GbE(0x15C7)"},
{0x8086, 0x15C8, 0xFFFF, 0xFFFF, "Ethernet Connection X553/X557-AT 10GBASE-T(0x15C8)"},
{0x8086, 0x15CE, 0xFFFF, 0xFFFF, "Ethernet Connection X553 10 GbE SFP+(0x15CE)"},
{0x8086, 0x15D0, 0xFFFF, 0xFFFF, "Ethernet SDI Adapter(0x15D0)"},
{0x8086, 0x15D0, 0x8086, 0x0001, "Ethernet SDI Adapter FM10420-100GbE-QDA2(0x8086-0x0001)"},
{0x8086, 0x15D0, 0x8086, 0x0002, "Ethernet SDI Adapter FM10840-MTP2(0x8086-0x0002)"},
{0x8086, 0x15D1, 0xFFFF, 0xFFFF, "Ethernet Controller 10G X550T(0x15D1)"},
{0x8086, 0x15D1, 0x4C52, 0x9811, "LREC9811BT Single-port 10Gb Ethernet Network Adapter(0x4C52-0x9811)"},
{0x8086, 0x15D1, 0x8086, 0x0002, "Ethernet Converged Network Adapter X550-T1(0x8086-0x0002)"},
{0x8086, 0x15D1, 0x8086, 0x001B, "Ethernet Server Adapter X550-T1 for OCP(0x8086-0x001B)"},
{0x8086, 0x15D1, 0x8086, 0x0021, "Ethernet Converged Network Adapter X550-T1(0x8086-0x0021)"},
{0x8086, 0x15D1, 0x8086, 0x00A2, "Ethernet Converged Network Adapter X550-T1(0x8086-0x00A2)"},
{0x8086, 0x15D2, 0xFFFF, 0xFFFF, "JHL6540 Thunderbolt 3 NHI (C step) [Alpine Ridge 4C 2016](0x15D2)"},
{0x8086, 0x15D3, 0xFFFF, 0xFFFF, "JHL6540 Thunderbolt 3 Bridge (C step) [Alpine Ridge 4C 2016](0x15D3)"},
{0x8086, 0x15D4, 0xFFFF, 0xFFFF, "JHL6540 Thunderbolt 3 USB Controller (C step) [Alpine Ridge 4C 2016](0x15D4)"},
{0x8086, 0x15D5, 0xFFFF, 0xFFFF, "Ethernet SDI Adapter FM10420-25GbE-DA2(0x15D5)"},
{0x8086, 0x15D5, 0x8086, 0x0001, "Ethernet SDI Adapter FM10420-25GbE-DA2(0x8086-0x0001)"},
{0x8086, 0x15D6, 0xFFFF, 0xFFFF, "Ethernet Connection (5) I219-V(0x15D6)"},
{0x8086, 0x15D7, 0xFFFF, 0xFFFF, "Ethernet Connection (4) I219-LM(0x15D7)"},
{0x8086, 0x15D8, 0xFFFF, 0xFFFF, "Ethernet Connection (4) I219-V(0x15D8)"},
{0x8086, 0x15D8, 0x17AA, 0x2247, "ThinkPad T570(0x17AA-0x2247)"},
{0x8086, 0x15D8, 0x17AA, 0x224F, "ThinkPad X1 Carbon 5th Gen(0x17AA-0x224F)"},
{0x8086, 0x15D8, 0x17AA, 0x225D, "ThinkPad T480(0x17AA-0x225D)"},
{0x8086, 0x15D9, 0xFFFF, 0xFFFF, "JHL6340 Thunderbolt 3 NHI (C step) [Alpine Ridge 2C 2016](0x15D9)"},
{0x8086, 0x15DA, 0xFFFF, 0xFFFF, "JHL6340 Thunderbolt 3 Bridge (C step) [Alpine Ridge 2C 2016](0x15DA)"},
{0x8086, 0x15DB, 0xFFFF, 0xFFFF, "JHL6340 Thunderbolt 3 USB 3.1 Controller (C step) [Alpine Ridge 2C 2016](0x15DB)"},
{0x8086, 0x15DF, 0xFFFF, 0xFFFF, "Ethernet Connection (8) I219-LM(0x15DF)"},
{0x8086, 0x15E0, 0xFFFF, 0xFFFF, "Ethernet Connection (8) I219-V(0x15E0)"},
{0x8086, 0x15E1, 0xFFFF, 0xFFFF, "Ethernet Connection (9) I219-LM(0x15E1)"},
{0x8086, 0x15E2, 0xFFFF, 0xFFFF, "Ethernet Connection (9) I219-V(0x15E2)"},
{0x8086, 0x15E3, 0xFFFF, 0xFFFF, "Ethernet Connection (5) I219-LM(0x15E3)"},
{0x8086, 0x15E4, 0xFFFF, 0xFFFF, "Ethernet Connection X553 1GbE(0x15E4)"},
{0x8086, 0x15E5, 0xFFFF, 0xFFFF, "Ethernet Connection X553 1GbE(0x15E5)"},
{0x8086, 0x15E7, 0xFFFF, 0xFFFF, "JHL7540 Thunderbolt 3 Bridge [Titan Ridge 2C 2018](0x15E7)"},
{0x8086, 0x15E8, 0xFFFF, 0xFFFF, "JHL7540 Thunderbolt 3 NHI [Titan Ridge 2C 2018](0x15E8)"},
{0x8086, 0x15E9, 0xFFFF, 0xFFFF, "JHL7540 Thunderbolt 3 USB Controller [Titan Ridge 2C 2018](0x15E9)"},
{0x8086, 0x15EA, 0xFFFF, 0xFFFF, "JHL7540 Thunderbolt 3 Bridge [Titan Ridge 4C 2018](0x15EA)"},
{0x8086, 0x15EB, 0xFFFF, 0xFFFF, "JHL7540 Thunderbolt 3 NHI [Titan Ridge 4C 2018](0x15EB)"},
{0x8086, 0x15EB, 0x1028, 0x09BE, "Latitude 7410(0x1028-0x09BE)"},
{0x8086, 0x15EC, 0xFFFF, 0xFFFF, "JHL7540 Thunderbolt 3 USB Controller [Titan Ridge 4C 2018](0x15EC)"},
{0x8086, 0x15EC, 0x1028, 0x09BE, "Latitude 7410(0x1028-0x09BE)"},
{0x8086, 0x15EF, 0xFFFF, 0xFFFF, "JHL7540 Thunderbolt 3 Bridge [Titan Ridge DD 2018](0x15EF)"},
{0x8086, 0x15F0, 0xFFFF, 0xFFFF, "JHL7540 Thunderbolt 3 USB Controller [Titan Ridge DD 2018](0x15F0)"},
{0x8086, 0x15F2, 0xFFFF, 0xFFFF, "Ethernet Controller I225-LM(0x15F2)"},
{0x8086, 0x15F2, 0x4C52, 0x2031, "LRES2031PT Single-port 2.5Gb Ethernet Network Adapter(0x4C52-0x2031)"},
{0x8086, 0x15F2, 0x8086, 0x0001, "Ethernet Network Adapter I225-T1(0x8086-0x0001)"},
{0x8086, 0x15F2, 0x8086, 0x0002, "Ethernet Network Adapter I225-T1(0x8086-0x0002)"},
{0x8086, 0x15F3, 0xFFFF, 0xFFFF, "Ethernet Controller I225-V(0x15F3)"},
{0x8086, 0x15F3, 0x4C52, 0x2031, "LRES2031PT Single-port 2.5Gb Ethernet Network Adapter(0x4C52-0x2031)"},
{0x8086, 0x15F3, 0x8086, 0x0003, "Intel(R) Ethernet Controller (3) I225-V(0x8086-0x0003)"},
{0x8086, 0x15F4, 0xFFFF, 0xFFFF, "Ethernet Connection (15) I219-LM(0x15F4)"},
{0x8086, 0x15F5, 0xFFFF, 0xFFFF, "Ethernet Connection (15) I219-V(0x15F5)"},
{0x8086, 0x15F6, 0xFFFF, 0xFFFF, "I210 Gigabit Ethernet Connection(0x15F6)"},
{0x8086, 0x15F9, 0xFFFF, 0xFFFF, "Ethernet Connection (14) I219-LM(0x15F9)"},
{0x8086, 0x15FA, 0xFFFF, 0xFFFF, "Ethernet Connection (14) I219-V(0x15FA)"},
{0x8086, 0x15FB, 0xFFFF, 0xFFFF, "Ethernet Connection (13) I219-LM(0x15FB)"},
{0x8086, 0x15FC, 0xFFFF, 0xFFFF, "Ethernet Connection (13) I219-V(0x15FC)"},
{0x8086, 0x15FF, 0xFFFF, 0xFFFF, "Ethernet Controller X710 for 10GBASE-T(0x15FF)"},
{0x8086, 0x15FF, 0x1014, 0x0000, "PCIe3 4-port 10GbE Base-T Adapter(0x1014-0x0000)"},
{0x8086, 0x15FF, 0x108E, 0x7B1F, "Quad Port 10GBase-T Adapter - CP(0x108E-0x7B1F)"},
{0x8086, 0x15FF, 0x1137, 0x0000, "X710TLG GbE RJ45 PCIe NIC(0x1137-0x0000)"},
{0x8086, 0x15FF, 0x1137, 0x02C1, "X710T2LG 2x10 GbE RJ45 PCIe NIC(0x1137-0x02C1)"},
{0x8086, 0x15FF, 0x1137, 0x02C2, "X710T4LG 4x10 GbE RJ45 PCIe NIC(0x1137-0x02C2)"},
{0x8086, 0x15FF, 0x1137, 0x02D9, "Ethernet Network Adapter X710-T2L OCP 3.0(0x1137-0x02D9)"},
{0x8086, 0x15FF, 0x1137, 0x02DA, "Ethernet Network Adapter X710-T4L OCP 3.0(0x1137-0x02DA)"},
{0x8086, 0x15FF, 0x193D, 0x1082, "NIC-ETH565T-3S-2P(0x193D-0x1082)"},
{0x8086, 0x15FF, 0x4C52, 0x1012, "LRES1012PT Dual-port 10Gb Ethernet Network Adapter(0x4C52-0x1012)"},
{0x8086, 0x15FF, 0x4C52, 0x3021, "LRES3021PT Dual-port 10Gb Ethernet Server Adapter for OCP(0x4C52-0x3021)"},
{0x8086, 0x15FF, 0x8086, 0x0000, "Ethernet Network Adapter X710-TL(0x8086-0x0000)"},
{0x8086, 0x15FF, 0x8086, 0x0001, "Ethernet Network Adapter X710-T4L(0x8086-0x0001)"},
{0x8086, 0x15FF, 0x8086, 0x0002, "Ethernet Network Adapter X710-T4L(0x8086-0x0002)"},
{0x8086, 0x15FF, 0x8086, 0x0003, "Ethernet Network Adapter X710-T2L(0x8086-0x0003)"},
{0x8086, 0x15FF, 0x8086, 0x0004, "Ethernet Network Adapter X710-T2L(0x8086-0x0004)"},
{0x8086, 0x15FF, 0x8086, 0x0005, "Ethernet 10G 2P X710-T2L-t Adapter(0x8086-0x0005)"},
{0x8086, 0x15FF, 0x8086, 0x0006, "Ethernet 10G 4P X710-T4L-t Adapter(0x8086-0x0006)"},
{0x8086, 0x15FF, 0x8086, 0x0007, "Ethernet 10G 2P X710-T2L-t OCP(0x8086-0x0007)"},
{0x8086, 0x15FF, 0x8086, 0x0008, "Ethernet 10G 4P X710-T4L-t OCP(0x8086-0x0008)"},
{0x8086, 0x15FF, 0x8086, 0x0009, "Ethernet Network Adapter X710-T4L for OCP 3.0(0x8086-0x0009)"},
{0x8086, 0x15FF, 0x8086, 0x000A, "Ethernet Network Adapter X710-T4L for OCP 3.0(0x8086-0x000A)"},
{0x8086, 0x15FF, 0x8086, 0x000B, "Ethernet Network Adapter X710-T2L for OCP 3.0(0x8086-0x000B)"},
{0x8086, 0x15FF, 0x8086, 0x000C, "Ethernet Network Adapter X710-T2L for OCP 3.0(0x8086-0x000C)"},
{0x8086, 0x15FF, 0x8086, 0x000D, "Ethernet 10G 2P X710-T2L-t OCP(0x8086-0x000D)"},
{0x8086, 0x15FF, 0x8086, 0x000F, "Ethernet Network Adapter X710-T2L for OCP 3.0(0x8086-0x000F)"},
{0x8086, 0x15FF, 0x8086, 0x4009, "Ethernet Network Adapter X710-T2L(0x8086-0x4009)"},
{0x8086, 0x15FF, 0x8086, 0x4012, "Ethernet Network Adapter X710-T4L for OCP 3.0(0x8086-0x4012)"},
{0x8086, 0x15FF, 0x8086, 0x4018, "Ethernet Network Adapter X710-T2L for OCP 3.0(0x8086-0x4018)"},
{0x8086, 0x15FF, 0x8086, 0x4019, "Ethernet Network Adapter X710-T4L(0x8086-0x4019)"},
{0x8086, 0x1600, 0xFFFF, 0xFFFF, "Broadwell-U Host Bridge -OPI(0x1600)"},
{0x8086, 0x1601, 0xFFFF, 0xFFFF, "Broadwell-U PCI Express x16 Controller(0x1601)"},
{0x8086, 0x1602, 0xFFFF, 0xFFFF, "Broadwell-U Integrated Graphics(0x1602)"},
{0x8086, 0x1603, 0xFFFF, 0xFFFF, "Broadwell-U Processor Thermal Subsystem(0x1603)"},
{0x8086, 0x1604, 0xFFFF, 0xFFFF, "Broadwell-U Host Bridge -OPI(0x1604)"},
{0x8086, 0x1605, 0xFFFF, 0xFFFF, "Broadwell-U PCI Express x8 Controller(0x1605)"},
{0x8086, 0x1606, 0xFFFF, 0xFFFF, "HD Graphics(0x1606)"},
{0x8086, 0x1607, 0xFFFF, 0xFFFF, "Broadwell-U CHAPS Device(0x1607)"},
{0x8086, 0x1608, 0xFFFF, 0xFFFF, "Broadwell-U Host Bridge -OPI(0x1608)"},
{0x8086, 0x1609, 0xFFFF, 0xFFFF, "Broadwell-U x4 PCIe(0x1609)"},
{0x8086, 0x160A, 0xFFFF, 0xFFFF, "Broadwell-U Integrated Graphics(0x160A)"},
{0x8086, 0x160B, 0xFFFF, 0xFFFF, "Broadwell-U Integrated Graphics(0x160B)"},
{0x8086, 0x160C, 0xFFFF, 0xFFFF, "Broadwell-U Audio Controller(0x160C)"},
{0x8086, 0x160D, 0xFFFF, 0xFFFF, "Broadwell-U Integrated Graphics(0x160D)"},
{0x8086, 0x160E, 0xFFFF, 0xFFFF, "Broadwell-U Integrated Graphics(0x160E)"},
{0x8086, 0x160F, 0xFFFF, 0xFFFF, "Broadwell-U SoftSKU(0x160F)"},
{0x8086, 0x1610, 0xFFFF, 0xFFFF, "Broadwell-U Host Bridge - DMI(0x1610)"},
{0x8086, 0x1612, 0xFFFF, 0xFFFF, "HD Graphics 5600(0x1612)"},
{0x8086, 0x1614, 0xFFFF, 0xFFFF, "Broadwell-U Host Bridge - DMI(0x1614)"},
{0x8086, 0x1616, 0xFFFF, 0xFFFF, "HD Graphics 5500(0x1616)"},
{0x8086, 0x1616, 0x103C, 0x2216, "ZBook 15u G2 Mobile Workstation(0x103C-0x2216)"},
{0x8086, 0x1618, 0xFFFF, 0xFFFF, "Broadwell-U Host Bridge - DMI(0x1618)"},
{0x8086, 0x161A, 0xFFFF, 0xFFFF, "Broadwell-U Integrated Graphics(0x161A)"},
{0x8086, 0x161B, 0xFFFF, 0xFFFF, "Broadwell-U Integrated Graphics(0x161B)"},
{0x8086, 0x161D, 0xFFFF, 0xFFFF, "Broadwell-U Integrated Graphics(0x161D)"},
{0x8086, 0x161E, 0xFFFF, 0xFFFF, "HD Graphics 5300(0x161E)"},
{0x8086, 0x1622, 0xFFFF, 0xFFFF, "Iris Pro Graphics 6200(0x1622)"},
{0x8086, 0x1626, 0xFFFF, 0xFFFF, "HD Graphics 6000(0x1626)"},
{0x8086, 0x162A, 0xFFFF, 0xFFFF, "Iris Pro Graphics P6300(0x162A)"},
{0x8086, 0x162B, 0xFFFF, 0xFFFF, "Iris Graphics 6100(0x162B)"},
{0x8086, 0x162D, 0xFFFF, 0xFFFF, "Broadwell-U Integrated Graphics(0x162D)"},
{0x8086, 0x162E, 0xFFFF, 0xFFFF, "Broadwell-U Integrated Graphics(0x162E)"},
{0x8086, 0x1632, 0xFFFF, 0xFFFF, "Broadwell-U Integrated Graphics(0x1632)"},
{0x8086, 0x1636, 0xFFFF, 0xFFFF, "Broadwell-U Integrated Graphics(0x1636)"},
{0x8086, 0x163A, 0xFFFF, 0xFFFF, "Broadwell-U Integrated Graphics(0x163A)"},
{0x8086, 0x163B, 0xFFFF, 0xFFFF, "Broadwell-U Integrated Graphics(0x163B)"},
{0x8086, 0x163D, 0xFFFF, 0xFFFF, "Broadwell-U Integrated Graphics(0x163D)"},
{0x8086, 0x163E, 0xFFFF, 0xFFFF, "Broadwell-U Integrated Graphics(0x163E)"},
{0x8086, 0x1889, 0xFFFF, 0xFFFF, "Ethernet Adaptive Virtual Function(0x1889)"},
{0x8086, 0x188A, 0xFFFF, 0xFFFF, "Ethernet Connection E823-C for backplane(0x188A)"},
{0x8086, 0x188B, 0xFFFF, 0xFFFF, "Ethernet Connection E823-C for QSFP(0x188B)"},
{0x8086, 0x188C, 0xFFFF, 0xFFFF, "Ethernet Connection E823-C for SFP(0x188C)"},
{0x8086, 0x188C, 0x1028, 0x0ABD, "Ethernet Connection 25G 4P E823-C LOM(0x1028-0x0ABD)"},
{0x8086, 0x188C, 0x17AA, 0x405E, "E823 25G/10G Ethernet LOM Controller(0x17AA-0x405E)"},
{0x8086, 0x188D, 0xFFFF, 0xFFFF, "Ethernet Connection E823-C/X557-AT 10GBASE-T(0x188D)"},
{0x8086, 0x188E, 0xFFFF, 0xFFFF, "Ethernet Connection E823-C 1GbE(0x188E)"},
{0x8086, 0x188E, 0x17AA, 0x405F, "E823 1G Ethernet LOM Controller(0x17AA-0x405F)"},
{0x8086, 0x1890, 0xFFFF, 0xFFFF, "Ethernet Connection E822-C for backplane(0x1890)"},
{0x8086, 0x1891, 0xFFFF, 0xFFFF, "Ethernet Connection E822-C for QSFP(0x1891)"},
{0x8086, 0x1892, 0xFFFF, 0xFFFF, "Ethernet Connection E822-C for SFP(0x1892)"},
{0x8086, 0x1893, 0xFFFF, 0xFFFF, "Ethernet Connection E822-C/X557-AT 10GBASE-T(0x1893)"},
{0x8086, 0x1894, 0xFFFF, 0xFFFF, "Ethernet Connection E822-C 1GbE(0x1894)"},
{0x8086, 0x1897, 0xFFFF, 0xFFFF, "Ethernet Connection E822-L for backplane(0x1897)"},
{0x8086, 0x1898, 0xFFFF, 0xFFFF, "Ethernet Connection E822-L for SFP(0x1898)"},
{0x8086, 0x1899, 0xFFFF, 0xFFFF, "Ethernet Connection E822-L/X557-AT 10GBASE-T(0x1899)"},
{0x8086, 0x189A, 0xFFFF, 0xFFFF, "Ethernet Connection E822-L 1GbE(0x189A)"},
{0x8086, 0x18A0, 0xFFFF, 0xFFFF, "Atom Processor P5xxx Series QAT(0x18A0)"},
{0x8086, 0x18A1, 0xFFFF, 0xFFFF, "C4XXX Series QAT Virtual Function(0x18A1)"},
{0x8086, 0x18B3, 0xFFFF, 0xFFFF, "Atom Processor P5xxx Series SATA Controller(0x18B3)"},
{0x8086, 0x18D0, 0xFFFF, 0xFFFF, "Atom Processor P5xxx Series USB xHCI Controller(0x18D0)"},
{0x8086, 0x18D3, 0xFFFF, 0xFFFF, "Atom Processor P5xxx Series MEI Controller(0x18D3)"},
{0x8086, 0x18D6, 0xFFFF, 0xFFFF, "Atom Processor P5xxx Series MEI Controller(0x18D6)"},
{0x8086, 0x18DF, 0xFFFF, 0xFFFF, "Atom Processor P5xxx Series SMBus Controller(0x18DF)"},
{0x8086, 0x18E0, 0xFFFF, 0xFFFF, "Atom Processor P5xxx Series SPI Controller(0x18E0)"},
{0x8086, 0x18E1, 0xFFFF, 0xFFFF, "Atom Processor P5xxx Series Trace Hub(0x18E1)"},
{0x8086, 0x18EE, 0xFFFF, 0xFFFF, "200xx Series QAT(0x18EE)"},
{0x8086, 0x18EF, 0xFFFF, 0xFFFF, "200xx Series QAT Virtual Function(0x18EF)"},
{0x8086, 0x18F3, 0xFFFF, 0xFFFF, "Atom Processor P5xxx Series SATA Controller(0x18F3)"},
{0x8086, 0x1900, 0xFFFF, 0xFFFF, "Xeon E3-1200 v5/E3-1500 v5/6th Gen Core Processor Host Bridge/DRAM Registers(0x1900)"},
{0x8086, 0x1901, 0xFFFF, 0xFFFF, "6th-10th Gen Core Processor PCIe Controller (x16)(0x1901)"},
{0x8086, 0x1902, 0xFFFF, 0xFFFF, "HD Graphics 510(0x1902)"},
{0x8086, 0x1903, 0xFFFF, 0xFFFF, "Xeon E3-1200 v5/E3-1500 v5/6th Gen Core Processor Thermal Subsystem(0x1903)"},
{0x8086, 0x1903, 0x1028, 0x06D6, "Latitude 7275 tablet(0x1028-0x06D6)"},
{0x8086, 0x1903, 0x1028, 0x06DC, "Latitude E7470(0x1028-0x06DC)"},
{0x8086, 0x1903, 0x1028, 0x06E4, "XPS 15 9550(0x1028-0x06E4)"},
{0x8086, 0x1903, 0x1028, 0x06E6, "Latitude 11 5175 2-in-1(0x1028-0x06E6)"},
{0x8086, 0x1903, 0x1028, 0x09BE, "Latitude 7410(0x1028-0x09BE)"},
{0x8086, 0x1903, 0x103C, 0x825B, "OMEN-17-w001nv(0x103C-0x825B)"},
{0x8086, 0x1903, 0x17AA, 0x225D, "ThinkPad T480(0x17AA-0x225D)"},
{0x8086, 0x1904, 0xFFFF, 0xFFFF, "Xeon E3-1200 v5/E3-1500 v5/6th Gen Core Processor Host Bridge/DRAM Registers(0x1904)"},
{0x8086, 0x1904, 0x1028, 0x06DC, "Latitude E7470(0x1028-0x06DC)"},
{0x8086, 0x1904, 0x1028, 0x06F3, "Latitude 3570(0x1028-0x06F3)"},
{0x8086, 0x1904, 0x103C, 0x8079, "EliteBook 840 G3(0x103C-0x8079)"},
{0x8086, 0x1904, 0x17AA, 0x2247, "ThinkPad T570(0x17AA-0x2247)"},
{0x8086, 0x1904, 0x17AA, 0x382A, "B51-80 Laptop(0x17AA-0x382A)"},
{0x8086, 0x1905, 0xFFFF, 0xFFFF, "Xeon E3-1200 v5/E3-1500 v5/6th Gen Core Processor PCIe Controller (x8)(0x1905)"},
{0x8086, 0x1906, 0xFFFF, 0xFFFF, "HD Graphics 510(0x1906)"},
{0x8086, 0x1906, 0x17AA, 0x382A, "B51-80 Laptop(0x17AA-0x382A)"},
{0x8086, 0x1908, 0xFFFF, 0xFFFF, "Xeon E3-1200 v5/E3-1500 v5/6th Gen Core Processor Host Bridge/DRAM Registers(0x1908)"},
{0x8086, 0x1909, 0xFFFF, 0xFFFF, "Xeon E3-1200 v5/E3-1500 v5/6th Gen Core Processor PCIe Controller (x4)(0x1909)"},
{0x8086, 0x190B, 0xFFFF, 0xFFFF, "HD Graphics 510(0x190B)"},
{0x8086, 0x190C, 0xFFFF, 0xFFFF, "Xeon E3-1200 v5/E3-1500 v5/6th Gen Core Processor Host Bridge/DRAM Registers(0x190C)"},
{0x8086, 0x190C, 0x1028, 0x06D6, "Latitude 7275 tablet(0x1028-0x06D6)"},
{0x8086, 0x190C, 0x1028, 0x06E6, "Latitude 11 5175 2-in-1(0x1028-0x06E6)"},
{0x8086, 0x190F, 0xFFFF, 0xFFFF, "Xeon E3-1200 v5/E3-1500 v5/6th Gen Core Processor Host Bridge/DRAM Registers(0x190F)"},
{0x8086, 0x1910, 0xFFFF, 0xFFFF, "Xeon E3-1200 v5/E3-1500 v5/6th Gen Core Processor Host Bridge/DRAM Registers(0x1910)"},
{0x8086, 0x1910, 0x1028, 0x06E4, "XPS 15 9550(0x1028-0x06E4)"},
{0x8086, 0x1910, 0x103C, 0x825B, "OMEN-17-w001nv(0x103C-0x825B)"},
{0x8086, 0x1911, 0xFFFF, 0xFFFF, "Xeon E3-1200 v5/v6 / E3-1500 v5 / 6th/7th/8th Gen Core Processor Gaussian Mixture Model(0x1911)"},
{0x8086, 0x1911, 0x1028, 0x0869, "Vostro 3470(0x1028-0x0869)"},
{0x8086, 0x1911, 0x1028, 0x09BE, "Latitude 7410(0x1028-0x09BE)"},
{0x8086, 0x1911, 0x1462, 0x7994, "H110M ECO/GAMING(0x1462-0x7994)"},
{0x8086, 0x1911, 0x1462, 0x7A72, "H270 PC MATE(0x1462-0x7A72)"},
{0x8086, 0x1911, 0x17AA, 0x2247, "ThinkPad T570(0x17AA-0x2247)"},
{0x8086, 0x1911, 0x17AA, 0x224F, "ThinkPad X1 Carbon 5th Gen(0x17AA-0x224F)"},
{0x8086, 0x1911, 0x17AA, 0x225D, "ThinkPad T480(0x17AA-0x225D)"},
{0x8086, 0x1912, 0xFFFF, 0xFFFF, "HD Graphics 530(0x1912)"},
{0x8086, 0x1916, 0xFFFF, 0xFFFF, "Skylake GT2 [HD Graphics 520](0x1916)"},
{0x8086, 0x1916, 0x1028, 0x06DC, "Latitude E7470(0x1028-0x06DC)"},
{0x8086, 0x1916, 0x1028, 0x06F3, "Latitude 3570(0x1028-0x06F3)"},
{0x8086, 0x1916, 0x103C, 0x8079, "EliteBook 840 G3(0x103C-0x8079)"},
{0x8086, 0x1916, 0x17AA, 0x2247, "ThinkPad T570(0x17AA-0x2247)"},
{0x8086, 0x1918, 0xFFFF, 0xFFFF, "Xeon E3-1200 v5/E3-1500 v5/6th Gen Core Processor Host Bridge/DRAM Registers(0x1918)"},
{0x8086, 0x1919, 0xFFFF, 0xFFFF, "Xeon E3-1200 v5/E3-1500 v5/6th Gen Core Processor Imaging Unit(0x1919)"},
{0x8086, 0x1919, 0x1028, 0x06D6, "Latitude 7275 tablet(0x1028-0x06D6)"},
{0x8086, 0x1919, 0x1028, 0x06E6, "Latitude 11 5175 2-in-1(0x1028-0x06E6)"},
{0x8086, 0x191B, 0xFFFF, 0xFFFF, "HD Graphics 530(0x191B)"},
{0x8086, 0x191B, 0x1028, 0x06E4, "XPS 15 9550(0x1028-0x06E4)"},
{0x8086, 0x191B, 0x103C, 0x825B, "OMEN-17-w001nv(0x103C-0x825B)"},
{0x8086, 0x191D, 0xFFFF, 0xFFFF, "HD Graphics P530(0x191D)"},
{0x8086, 0x191E, 0xFFFF, 0xFFFF, "HD Graphics 515(0x191E)"},
{0x8086, 0x191E, 0x1028, 0x06D6, "Latitude 7275 tablet(0x1028-0x06D6)"},
{0x8086, 0x191E, 0x1028, 0x06E6, "Latitude 11 5175 2-in-1(0x1028-0x06E6)"},
{0x8086, 0x191F, 0xFFFF, 0xFFFF, "Xeon E3-1200 v5/E3-1500 v5/6th Gen Core Processor Host Bridge/DRAM Registers(0x191F)"},
{0x8086, 0x1921, 0xFFFF, 0xFFFF, "HD Graphics 520(0x1921)"},
{0x8086, 0x1923, 0xFFFF, 0xFFFF, "HD Graphics 535(0x1923)"},
{0x8086, 0x1926, 0xFFFF, 0xFFFF, "Iris Graphics 540(0x1926)"},
{0x8086, 0x1927, 0xFFFF, 0xFFFF, "Iris Graphics 550(0x1927)"},
{0x8086, 0x192B, 0xFFFF, 0xFFFF, "Iris Graphics 555(0x192B)"},
{0x8086, 0x192D, 0xFFFF, 0xFFFF, "Iris Graphics P555(0x192D)"},
{0x8086, 0x1932, 0xFFFF, 0xFFFF, "Iris Pro Graphics 580(0x1932)"},
{0x8086, 0x193A, 0xFFFF, 0xFFFF, "Iris Pro Graphics P580(0x193A)"},
{0x8086, 0x193B, 0xFFFF, 0xFFFF, "Iris Pro Graphics 580(0x193B)"},
{0x8086, 0x193D, 0xFFFF, 0xFFFF, "Iris Pro Graphics P580(0x193D)"},
{0x8086, 0x1960, 0xFFFF, 0xFFFF, "80960RP (i960RP) Microprocessor(0x1960)"},
{0x8086, 0x1960, 0x101E, 0x0431, "MegaRAID 431 RAID Controller(0x101E-0x0431)"},
{0x8086, 0x1960, 0x101E, 0x0438, "MegaRAID 438 Ultra2 LVD RAID Controller(0x101E-0x0438)"},
{0x8086, 0x1960, 0x101E, 0x0466, "MegaRAID 466 Express Plus RAID Controller(0x101E-0x0466)"},
{0x8086, 0x1960, 0x101E, 0x0467, "MegaRAID 467 Enterprise 1500 RAID Controller(0x101E-0x0467)"},
{0x8086, 0x1960, 0x101E, 0x0490, "MegaRAID 490 Express 300 RAID Controller(0x101E-0x0490)"},
{0x8086, 0x1960, 0x101E, 0x0762, "MegaRAID 762 Express RAID Controller(0x101E-0x0762)"},
{0x8086, 0x1960, 0x101E, 0x09A0, "PowerEdge Expandable RAID Controller 2/SC(0x101E-0x09A0)"},
{0x8086, 0x1960, 0x1028, 0x0467, "PowerEdge Expandable RAID Controller 2/DC(0x1028-0x0467)"},
{0x8086, 0x1960, 0x1028, 0x1111, "PowerEdge Expandable RAID Controller 2/SC(0x1028-0x1111)"},
{0x8086, 0x1960, 0x103C, 0x03A2, "MegaRAID(0x103C-0x03A2)"},
{0x8086, 0x1960, 0x103C, 0x10C6, "MegaRAID 438, NetRAID-3Si(0x103C-0x10C6)"},
{0x8086, 0x1960, 0x103C, 0x10C7, "MegaRAID T5, Integrated NetRAID(0x103C-0x10C7)"},
{0x8086, 0x1960, 0x103C, 0x10CC, "MegaRAID, Integrated NetRAID(0x103C-0x10CC)"},
{0x8086, 0x1960, 0x103C, 0x10CD, "NetRAID-1Si(0x103C-0x10CD)"},
{0x8086, 0x1960, 0x105A, 0x0000, "SuperTrak(0x105A-0x0000)"},
{0x8086, 0x1960, 0x105A, 0x2168, "SuperTrak Pro(0x105A-0x2168)"},
{0x8086, 0x1960, 0x105A, 0x5168, "SuperTrak66/100(0x105A-0x5168)"},
{0x8086, 0x1960, 0x1111, 0x1111, "MegaRAID 466, PowerEdge Expandable RAID Controller 2/SC(0x1111-0x1111)"},
{0x8086, 0x1960, 0x1111, 0x1112, "PowerEdge Expandable RAID Controller 2/SC(0x1111-0x1112)"},
{0x8086, 0x1960, 0x113C, 0x03A2, "MegaRAID(0x113C-0x03A2)"},
{0x8086, 0x1960, 0xE4BF, 0x1010, "CG1-RADIO(0xE4BF-0x1010)"},
{0x8086, 0x1960, 0xE4BF, 0x1020, "CU2-QUARTET(0xE4BF-0x1020)"},
{0x8086, 0x1960, 0xE4BF, 0x1040, "CU1-CHORUS(0xE4BF-0x1040)"},
{0x8086, 0x1960, 0xE4BF, 0x3100, "CX1-BAND(0xE4BF-0x3100)"},
{0x8086, 0x1962, 0xFFFF, 0xFFFF, "80960RM (i960RM) Microprocessor(0x1962)"},
{0x8086, 0x1962, 0x105A, 0x0000, "SuperTrak SX6000 I2O CPU(0x105A-0x0000)"},
{0x8086, 0x1964, 0xFFFF, 0xFFFF, "80960RN (i960RN) Microprocessor(0x1964)"},
{0x8086, 0x1980, 0xFFFF, 0xFFFF, "Atom Processor C3000 Series System Agent(0x1980)"},
{0x8086, 0x19A1, 0xFFFF, 0xFFFF, "Atom Processor C3000 Series Error Registers(0x19A1)"},
{0x8086, 0x19A2, 0xFFFF, 0xFFFF, "Atom Processor C3000 Series Root Complex Event Collector(0x19A2)"},
{0x8086, 0x19A3, 0xFFFF, 0xFFFF, "Atom Processor C3000 Series Integrated QAT Root Port(0x19A3)"},
{0x8086, 0x19A4, 0xFFFF, 0xFFFF, "Atom Processor C3000 Series PCI Express Root Port #0(0x19A4)"},
{0x8086, 0x19A5, 0xFFFF, 0xFFFF, "Atom Processor C3000 Series PCI Express Root Port #1(0x19A5)"},
{0x8086, 0x19A6, 0xFFFF, 0xFFFF, "Atom Processor C3000 Series PCI Express Root Port #2(0x19A6)"},
{0x8086, 0x19A7, 0xFFFF, 0xFFFF, "Atom Processor C3000 Series PCI Express Root Port #3(0x19A7)"},
{0x8086, 0x19A8, 0xFFFF, 0xFFFF, "Atom Processor C3000 Series PCI Express Root Port #4(0x19A8)"},
{0x8086, 0x19A9, 0xFFFF, 0xFFFF, "Atom Processor C3000 Series PCI Express Root Port #5(0x19A9)"},
{0x8086, 0x19AA, 0xFFFF, 0xFFFF, "Atom Processor C3000 Series PCI Express Root Port #6(0x19AA)"},
{0x8086, 0x19AB, 0xFFFF, 0xFFFF, "Atom Processor C3000 Series PCI Express Root Port #7(0x19AB)"},
{0x8086, 0x19AC, 0xFFFF, 0xFFFF, "Atom Processor C3000 Series SMBus Contoller - Host(0x19AC)"},
{0x8086, 0x19B0, 0xFFFF, 0xFFFF, "Atom Processor C3000 Series SATA Controller 0(0x19B0)"},
{0x8086, 0x19B1, 0xFFFF, 0xFFFF, "Atom Processor C3000 Series SATA Controller 0(0x19B1)"},
{0x8086, 0x19B2, 0xFFFF, 0xFFFF, "Atom Processor C3000 Series SATA Controller 0(0x19B2)"},
{0x8086, 0x19B3, 0xFFFF, 0xFFFF, "Atom Processor C3000 Series SATA Controller 0(0x19B3)"},
{0x8086, 0x19B4, 0xFFFF, 0xFFFF, "Atom Processor C3000 Series SATA Controller 0(0x19B4)"},
{0x8086, 0x19B5, 0xFFFF, 0xFFFF, "Atom Processor C3000 Series SATA Controller 0(0x19B5)"},
{0x8086, 0x19B6, 0xFFFF, 0xFFFF, "Atom Processor C3000 Series SATA Controller 0(0x19B6)"},
{0x8086, 0x19B7, 0xFFFF, 0xFFFF, "Atom Processor C3000 Series SATA Controller 0(0x19B7)"},
{0x8086, 0x19BE, 0xFFFF, 0xFFFF, "Atom Processor C3000 Series SATA Controller 0(0x19BE)"},
{0x8086, 0x19BF, 0xFFFF, 0xFFFF, "Atom Processor C3000 Series SATA Controller 0(0x19BF)"},
{0x8086, 0x19C0, 0xFFFF, 0xFFFF, "Atom Processor C3000 Series SATA Controller 1(0x19C0)"},
{0x8086, 0x19C1, 0xFFFF, 0xFFFF, "Atom Processor C3000 Series SATA Controller 1(0x19C1)"},
{0x8086, 0x19C2, 0xFFFF, 0xFFFF, "Atom Processor C3000 Series SATA Controller 1(0x19C2)"},
{0x8086, 0x19C3, 0xFFFF, 0xFFFF, "Atom Processor C3000 Series SATA Controller 1(0x19C3)"},
{0x8086, 0x19C4, 0xFFFF, 0xFFFF, "Atom Processor C3000 Series SATA Controller 1(0x19C4)"},
{0x8086, 0x19C5, 0xFFFF, 0xFFFF, "Atom Processor C3000 Series SATA Controller 1(0x19C5)"},
{0x8086, 0x19C6, 0xFFFF, 0xFFFF, "Atom Processor C3000 Series SATA Controller 1(0x19C6)"},
{0x8086, 0x19C7, 0xFFFF, 0xFFFF, "Atom Processor C3000 Series SATA Controller 1(0x19C7)"},
{0x8086, 0x19CE, 0xFFFF, 0xFFFF, "Atom Processor C3000 Series SATA Controller 1(0x19CE)"},
{0x8086, 0x19CF, 0xFFFF, 0xFFFF, "Atom Processor C3000 Series SATA Controller 1(0x19CF)"},
{0x8086, 0x19D0, 0xFFFF, 0xFFFF, "Atom Processor C3000 Series USB 3.0 xHCI Controller(0x19D0)"},
{0x8086, 0x19D1, 0xFFFF, 0xFFFF, "Atom Processor C3000 Series Integrated LAN Root Port #0(0x19D1)"},
{0x8086, 0x19D2, 0xFFFF, 0xFFFF, "Atom Processor C3000 Series Integrated LAN Root Port #1(0x19D2)"},
{0x8086, 0x19D3, 0xFFFF, 0xFFFF, "Atom Processor C3000 Series ME HECI 1(0x19D3)"},
{0x8086, 0x19D4, 0xFFFF, 0xFFFF, "Atom Processor C3000 Series ME HECI 2(0x19D4)"},
{0x8086, 0x19D5, 0xFFFF, 0xFFFF, "Atom Processor C3000 Series ME KT Controller(0x19D5)"},
{0x8086, 0x19D6, 0xFFFF, 0xFFFF, "Atom Processor C3000 Series ME HECI 3(0x19D6)"},
{0x8086, 0x19D8, 0xFFFF, 0xFFFF, "Atom Processor C3000 Series HSUART Controller(0x19D8)"},
{0x8086, 0x19DC, 0xFFFF, 0xFFFF, "Atom Processor C3000 Series LPC or eSPI(0x19DC)"},
{0x8086, 0x19DD, 0xFFFF, 0xFFFF, "Atom Processor C3000 Series Primary to Side Band (P2SB) Bridge(0x19DD)"},
{0x8086, 0x19DE, 0xFFFF, 0xFFFF, "Atom Processor C3000 Series Power Management Controller(0x19DE)"},
{0x8086, 0x19DF, 0xFFFF, 0xFFFF, "Atom Processor C3000 Series SMBus controller(0x19DF)"},
{0x8086, 0x19E0, 0xFFFF, 0xFFFF, "Atom Processor C3000 Series SPI Controller(0x19E0)"},
{0x8086, 0x19E2, 0xFFFF, 0xFFFF, "Atom Processor C3000 Series QuickAssist Technology(0x19E2)"},
{0x8086, 0x19E3, 0xFFFF, 0xFFFF, "Atom Processor C3000 Series QuickAssist Technology Virtual Function(0x19E3)"},
{0x8086, 0x1A1C, 0xFFFF, 0xFFFF, "Ethernet Connection (17) I219-LM(0x1A1C)"},
{0x8086, 0x1A1D, 0xFFFF, 0xFFFF, "Ethernet Connection (17) I219-V(0x1A1D)"},
{0x8086, 0x1A1E, 0xFFFF, 0xFFFF, "Ethernet Connection (16) I219-LM(0x1A1E)"},
{0x8086, 0x1A1E, 0x1028, 0x0B10, "Precision 3571(0x1028-0x0B10)"},
{0x8086, 0x1A1F, 0xFFFF, 0xFFFF, "Ethernet Connection (16) I219-V(0x1A1F)"},
{0x8086, 0x1A21, 0xFFFF, 0xFFFF, "82840 840 [Carmel] Chipset Host Bridge (Hub A)(0x1A21)"},
{0x8086, 0x1A23, 0xFFFF, 0xFFFF, "82840 840 [Carmel] Chipset AGP Bridge(0x1A23)"},
{0x8086, 0x1A24, 0xFFFF, 0xFFFF, "82840 840 [Carmel] Chipset PCI Bridge (Hub B)(0x1A24)"},
{0x8086, 0x1A30, 0xFFFF, 0xFFFF, "82845 845 [Brookdale] Chipset Host Bridge(0x1A30)"},
{0x8086, 0x1A30, 0x1028, 0x010E, "Optiplex GX240(0x1028-0x010E)"},
{0x8086, 0x1A30, 0x147B, 0x0505, "BL7 motherboard(0x147B-0x0505)"},
{0x8086, 0x1A30, 0x15D9, 0x3280, "Supermicro P4SBE Mainboard(0x15D9-0x3280)"},
{0x8086, 0x1A31, 0xFFFF, 0xFFFF, "82845 845 [Brookdale] Chipset AGP Bridge(0x1A31)"},
{0x8086, 0x1A38, 0xFFFF, 0xFFFF, "5000 Series Chipset DMA Engine(0x1A38)"},
{0x8086, 0x1A38, 0x15D9, 0x8680, "X7DVL-E-O motherboard(0x15D9-0x8680)"},
{0x8086, 0x1A38, 0x8086, 0x3476, "S5000PSLSATA Server Board(0x8086-0x3476)"},
{0x8086, 0x1A48, 0xFFFF, 0xFFFF, "82597EX 10GbE Ethernet Controller(0x1A48)"},
{0x8086, 0x1A48, 0x8086, 0xA01F, "PRO/10GbE SR Server Adapter(0x8086-0xA01F)"},
{0x8086, 0x1A48, 0x8086, 0xA11F, "PRO/10GbE SR Server Adapter(0x8086-0xA11F)"},
{0x8086, 0x1B48, 0xFFFF, 0xFFFF, "82597EX 10GbE Ethernet Controller(0x1B48)"},
{0x8086, 0x1B48, 0x8086, 0xA01F, "PRO/10GbE LR Server Adapter(0x8086-0xA01F)"},
{0x8086, 0x1B48, 0x8086, 0xA11F, "PRO/10GbE LR Server Adapter(0x8086-0xA11F)"},
{0x8086, 0x1BCD, 0xFFFF, 0xFFFF, "Emmitsburg (C740 Family) USB 3.2 Gen 1 xHCI Controller(0x1BCD)"},
{0x8086, 0x1BCD, 0x1BD4, 0x00A5, "RS0800I5H16i(0x1BD4-0x00A5)"},
{0x8086, 0x1BD2, 0xFFFF, 0xFFFF, "Sapphire Rapids SATA AHCI Controller(0x1BD2)"},
{0x8086, 0x1BF2, 0xFFFF, 0xFFFF, "Sapphire Rapids SATA AHCI Controller(0x1BF2)"},
{0x8086, 0x1C00, 0xFFFF, 0xFFFF, "6 Series/C200 Series Chipset Family Desktop SATA Controller (IDE mode, ports 0-3)(0x1C00)"},
{0x8086, 0x1C01, 0xFFFF, 0xFFFF, "6 Series/C200 Series Chipset Family Mobile SATA Controller (IDE mode, ports 0-3)(0x1C01)"},
{0x8086, 0x1C02, 0xFFFF, 0xFFFF, "6 Series/C200 Series Chipset Family 6 port Desktop SATA AHCI Controller(0x1C02)"},
{0x8086, 0x1C02, 0x1028, 0x04AA, "XPS 8300(0x1028-0x04AA)"},
{0x8086, 0x1C02, 0x1043, 0x844D, "P8 series motherboard(0x1043-0x844D)"},
{0x8086, 0x1C02, 0x17AA, 0x3070, "ThinkCentre M91p(0x17AA-0x3070)"},
{0x8086, 0x1C02, 0x8086, 0x200D, "DH61CR motherboard(0x8086-0x200D)"},
{0x8086, 0x1C02, 0x8086, 0x7270, "Server Board S1200BT Family(0x8086-0x7270)"},
{0x8086, 0x1C03, 0xFFFF, 0xFFFF, "6 Series/C200 Series Chipset Family 6 port Mobile SATA AHCI Controller(0x1C03)"},
{0x8086, 0x1C03, 0x1028, 0x04A3, "Precision M4600(0x1028-0x04A3)"},
{0x8086, 0x1C03, 0x1028, 0x04B2, "Vostro 3350(0x1028-0x04B2)"},
{0x8086, 0x1C03, 0x1028, 0x04DA, "Vostro 3750(0x1028-0x04DA)"},
{0x8086, 0x1C03, 0x17AA, 0x21CF, "ThinkPad T520(0x17AA-0x21CF)"},
{0x8086, 0x1C03, 0x8086, 0x7270, "Apple MacBookPro8,2 [Core i7, 15\", 2011](0x8086-0x7270)"},
{0x8086, 0x1C04, 0xFFFF, 0xFFFF, "6 Series/C200 Series Desktop SATA RAID Controller(0x1C04)"},
{0x8086, 0x1C04, 0x103C, 0x3118, "Smart Array B110i SATA RAID Controller(0x103C-0x3118)"},
{0x8086, 0x1C05, 0xFFFF, 0xFFFF, "6 Series/C200 Series Mobile SATA RAID Controller(0x1C05)"},
{0x8086, 0x1C06, 0xFFFF, 0xFFFF, "Z68 Express Chipset SATA RAID Controller(0x1C06)"},
{0x8086, 0x1C08, 0xFFFF, 0xFFFF, "6 Series/C200 Series Chipset Family Desktop SATA Controller (IDE mode, ports 4-5)(0x1C08)"},
{0x8086, 0x1C09, 0xFFFF, 0xFFFF, "6 Series/C200 Series Chipset Family Mobile SATA Controller (IDE mode, ports 4-5)(0x1C09)"},
{0x8086, 0x1C10, 0xFFFF, 0xFFFF, "6 Series/C200 Series Chipset Family PCI Express Root Port 1(0x1C10)"},
{0x8086, 0x1C10, 0x1028, 0x04AA, "XPS 8300(0x1028-0x04AA)"},
{0x8086, 0x1C10, 0x1028, 0x04DA, "Vostro 3750(0x1028-0x04DA)"},
{0x8086, 0x1C10, 0x1043, 0x844D, "P8 series motherboard(0x1043-0x844D)"},
{0x8086, 0x1C10, 0x17AA, 0x21CF, "ThinkPad T520(0x17AA-0x21CF)"},
{0x8086, 0x1C10, 0x8086, 0x7270, "Server Board S1200BTS / Apple MacBook Pro 8,1/8,2(0x8086-0x7270)"},
{0x8086, 0x1C12, 0xFFFF, 0xFFFF, "6 Series/C200 Series Chipset Family PCI Express Root Port 2(0x1C12)"},
{0x8086, 0x1C12, 0x1028, 0x04AA, "XPS 8300(0x1028-0x04AA)"},
{0x8086, 0x1C12, 0x17AA, 0x21CF, "ThinkPad T520(0x17AA-0x21CF)"},
{0x8086, 0x1C12, 0x8086, 0x7270, "Apple MacBookPro8,2 [Core i7, 15\", 2011](0x8086-0x7270)"},
{0x8086, 0x1C14, 0xFFFF, 0xFFFF, "6 Series/C200 Series Chipset Family PCI Express Root Port 3(0x1C14)"},
{0x8086, 0x1C14, 0x1028, 0x04DA, "Vostro 3750(0x1028-0x04DA)"},
{0x8086, 0x1C14, 0x8086, 0x7270, "Apple MacBookPro8,2 [Core i7, 15\", 2011](0x8086-0x7270)"},
{0x8086, 0x1C16, 0xFFFF, 0xFFFF, "6 Series/C200 Series Chipset Family PCI Express Root Port 4(0x1C16)"},
{0x8086, 0x1C16, 0x1028, 0x04AA, "XPS 8300(0x1028-0x04AA)"},
{0x8086, 0x1C16, 0x17AA, 0x21CF, "ThinkPad T520(0x17AA-0x21CF)"},
{0x8086, 0x1C18, 0xFFFF, 0xFFFF, "6 Series/C200 Series Chipset Family PCI Express Root Port 5(0x1C18)"},
{0x8086, 0x1C18, 0x1028, 0x04DA, "Vostro 3750(0x1028-0x04DA)"},
{0x8086, 0x1C18, 0x17AA, 0x21CF, "ThinkPad T520(0x17AA-0x21CF)"},
{0x8086, 0x1C18, 0x8086, 0x7270, "Server Board S1200BTS(0x8086-0x7270)"},
{0x8086, 0x1C1A, 0xFFFF, 0xFFFF, "6 Series/C200 Series Chipset Family PCI Express Root Port 6(0x1C1A)"},
{0x8086, 0x1C1A, 0x1028, 0x04DA, "Vostro 3750(0x1028-0x04DA)"},
{0x8086, 0x1C1A, 0x1043, 0x844D, "P8 series motherboard(0x1043-0x844D)"},
{0x8086, 0x1C1C, 0xFFFF, 0xFFFF, "6 Series/C200 Series Chipset Family PCI Express Root Port 7(0x1C1C)"},
{0x8086, 0x1C1E, 0xFFFF, 0xFFFF, "6 Series/C200 Series Chipset Family PCI Express Root Port 8(0x1C1E)"},
{0x8086, 0x1C1E, 0x1043, 0x844D, "P8 series motherboard(0x1043-0x844D)"},
{0x8086, 0x1C20, 0xFFFF, 0xFFFF, "6 Series/C200 Series Chipset Family High Definition Audio Controller(0x1C20)"},
{0x8086, 0x1C20, 0x1028, 0x0490, "Alienware M17x R3(0x1028-0x0490)"},
{0x8086, 0x1C20, 0x1028, 0x04A3, "Precision M4600(0x1028-0x04A3)"},
{0x8086, 0x1C20, 0x1028, 0x04AA, "XPS 8300(0x1028-0x04AA)"},
{0x8086, 0x1C20, 0x1028, 0x04B2, "Vostro 3350(0x1028-0x04B2)"},
{0x8086, 0x1C20, 0x1028, 0x04DA, "Vostro 3750(0x1028-0x04DA)"},
{0x8086, 0x1C20, 0x103C, 0x2ABF, "HP Pavilion p6-2100 Desktop PC Series(0x103C-0x2ABF)"},
{0x8086, 0x1C20, 0x1043, 0x8418, "P8P67 Deluxe Motherboard(0x1043-0x8418)"},
{0x8086, 0x1C20, 0x1043, 0x841B, "P8H67 Series Motherboard(0x1043-0x841B)"},
{0x8086, 0x1C20, 0x17AA, 0x21CF, "ThinkPad T520(0x17AA-0x21CF)"},
{0x8086, 0x1C20, 0x17AA, 0x3070, "ThinkCentre M91p(0x17AA-0x3070)"},
{0x8086, 0x1C20, 0x8086, 0x2008, "DQ67SW board(0x8086-0x2008)"},
{0x8086, 0x1C20, 0x8086, 0x200D, "DH61CR motherboard(0x8086-0x200D)"},
{0x8086, 0x1C20, 0x8086, 0x7270, "Apple MacBookPro8,2 [Core i7, 15\", 2011](0x8086-0x7270)"},
{0x8086, 0x1C22, 0xFFFF, 0xFFFF, "6 Series/C200 Series Chipset Family SMBus Controller(0x1C22)"},
{0x8086, 0x1C22, 0x1028, 0x04A3, "Precision M4600(0x1028-0x04A3)"},
{0x8086, 0x1C22, 0x1028, 0x04AA, "XPS 8300(0x1028-0x04AA)"},
{0x8086, 0x1C22, 0x1028, 0x04B2, "Vostro 3350(0x1028-0x04B2)"},
{0x8086, 0x1C22, 0x1028, 0x04DA, "Vostro 3750(0x1028-0x04DA)"},
{0x8086, 0x1C22, 0x1043, 0x844D, "P8 series motherboard(0x1043-0x844D)"},
{0x8086, 0x1C22, 0x17AA, 0x21CF, "ThinkPad T520(0x17AA-0x21CF)"},
{0x8086, 0x1C22, 0x17AA, 0x3070, "ThinkCentre M91p(0x17AA-0x3070)"},
{0x8086, 0x1C22, 0x8086, 0x200D, "DH61CR motherboard(0x8086-0x200D)"},
{0x8086, 0x1C22, 0x8086, 0x7270, "Server Board S1200BT Family / Apple MacBook Pro 8,1/8,2(0x8086-0x7270)"},
{0x8086, 0x1C24, 0xFFFF, 0xFFFF, "6 Series/C200 Series Chipset Family Thermal Management Controller(0x1C24)"},
{0x8086, 0x1C25, 0xFFFF, 0xFFFF, "6 Series/C200 Series Chipset Family DMI to PCI Bridge(0x1C25)"},
{0x8086, 0x1C26, 0xFFFF, 0xFFFF, "6 Series/C200 Series Chipset Family USB Enhanced Host Controller #1(0x1C26)"},
{0x8086, 0x1C26, 0x1028, 0x04A3, "Precision M4600(0x1028-0x04A3)"},
{0x8086, 0x1C26, 0x1028, 0x04AA, "XPS 8300(0x1028-0x04AA)"},
{0x8086, 0x1C26, 0x1028, 0x04B2, "Vostro 3350(0x1028-0x04B2)"},
{0x8086, 0x1C26, 0x1028, 0x04DA, "Vostro 3750(0x1028-0x04DA)"},
{0x8086, 0x1C26, 0x1043, 0x844D, "P8 series motherboard(0x1043-0x844D)"},
{0x8086, 0x1C26, 0x17AA, 0x21CF, "ThinkPad T520(0x17AA-0x21CF)"},
{0x8086, 0x1C26, 0x17AA, 0x3070, "ThinkCentre M91p(0x17AA-0x3070)"},
{0x8086, 0x1C26, 0x8086, 0x200D, "DH61CR motherboard(0x8086-0x200D)"},
{0x8086, 0x1C26, 0x8086, 0x7270, "Server Board S1200BT Family / Apple MacBook Pro 8,1/8,2(0x8086-0x7270)"},
{0x8086, 0x1C27, 0xFFFF, 0xFFFF, "6 Series/C200 Series Chipset Family USB Universal Host Controller #1(0x1C27)"},
{0x8086, 0x1C27, 0x8086, 0x7270, "Apple MacBookPro8,2 [Core i7, 15\", 2011](0x8086-0x7270)"},
{0x8086, 0x1C2C, 0xFFFF, 0xFFFF, "6 Series/C200 Series Chipset Family USB Universal Host Controller #5(0x1C2C)"},
{0x8086, 0x1C2C, 0x8086, 0x7270, "Apple MacBookPro8,2 [Core i7, 15\", 2011](0x8086-0x7270)"},
{0x8086, 0x1C2D, 0xFFFF, 0xFFFF, "6 Series/C200 Series Chipset Family USB Enhanced Host Controller #2(0x1C2D)"},
{0x8086, 0x1C2D, 0x1028, 0x04A3, "Precision M4600(0x1028-0x04A3)"},
{0x8086, 0x1C2D, 0x1028, 0x04AA, "XPS 8300(0x1028-0x04AA)"},
{0x8086, 0x1C2D, 0x1028, 0x04B2, "Vostro 3350(0x1028-0x04B2)"},
{0x8086, 0x1C2D, 0x1028, 0x04DA, "Vostro 3750(0x1028-0x04DA)"},
{0x8086, 0x1C2D, 0x1043, 0x844D, "P8 series motherboard(0x1043-0x844D)"},
{0x8086, 0x1C2D, 0x17AA, 0x21CF, "ThinkPad T520(0x17AA-0x21CF)"},
{0x8086, 0x1C2D, 0x17AA, 0x3070, "ThinkCentre M91p(0x17AA-0x3070)"},
{0x8086, 0x1C2D, 0x8086, 0x200D, "DH61CR motherboard(0x8086-0x200D)"},
{0x8086, 0x1C2D, 0x8086, 0x7270, "Server Board S1200BT Family / Apple MacBook Pro 8,1/8,2(0x8086-0x7270)"},
{0x8086, 0x1C33, 0xFFFF, 0xFFFF, "6 Series/C200 Series Chipset Family LAN Controller(0x1C33)"},
{0x8086, 0x1C35, 0xFFFF, 0xFFFF, "6 Series/C200 Series Chipset Family VECI Controller(0x1C35)"},
{0x8086, 0x1C3A, 0xFFFF, 0xFFFF, "6 Series/C200 Series Chipset Family MEI Controller #1(0x1C3A)"},
{0x8086, 0x1C3A, 0x1028, 0x0493, "Latitude E6420(0x1028-0x0493)"},
{0x8086, 0x1C3A, 0x1028, 0x04A3, "Precision M4600(0x1028-0x04A3)"},
{0x8086, 0x1C3A, 0x1028, 0x04AA, "XPS 8300(0x1028-0x04AA)"},
{0x8086, 0x1C3A, 0x1028, 0x04B2, "Vostro 3350(0x1028-0x04B2)"},
{0x8086, 0x1C3A, 0x1028, 0x04DA, "Vostro 3750(0x1028-0x04DA)"},
{0x8086, 0x1C3A, 0x1043, 0x844D, "P8 series motherboard(0x1043-0x844D)"},
{0x8086, 0x1C3A, 0x17AA, 0x21CF, "ThinkPad T520(0x17AA-0x21CF)"},
{0x8086, 0x1C3A, 0x17AA, 0x3070, "ThinkCentre M91p(0x17AA-0x3070)"},
{0x8086, 0x1C3A, 0x8086, 0x200D, "DH61CR motherboard(0x8086-0x200D)"},
{0x8086, 0x1C3A, 0x8086, 0x7270, "Apple MacBookPro8,2 [Core i7, 15\", 2011](0x8086-0x7270)"},
{0x8086, 0x1C3B, 0xFFFF, 0xFFFF, "6 Series/C200 Series Chipset Family MEI Controller #2(0x1C3B)"},
{0x8086, 0x1C3C, 0xFFFF, 0xFFFF, "6 Series/C200 Series Chipset Family IDE-r Controller(0x1C3C)"},
{0x8086, 0x1C3D, 0xFFFF, 0xFFFF, "6 Series/C200 Series Chipset Family KT Controller(0x1C3D)"},
{0x8086, 0x1C3D, 0x17AA, 0x3070, "ThinkCentre M91p(0x17AA-0x3070)"},
{0x8086, 0x1C40, 0xFFFF, 0xFFFF, "6 Series/C200 Series Chipset Family LPC Controller(0x1C40)"},
{0x8086, 0x1C41, 0xFFFF, 0xFFFF, "Mobile SFF 6 Series Chipset Family LPC Controller(0x1C41)"},
{0x8086, 0x1C42, 0xFFFF, 0xFFFF, "6 Series/C200 Series Chipset Family LPC Controller(0x1C42)"},
{0x8086, 0x1C43, 0xFFFF, 0xFFFF, "Mobile 6 Series Chipset Family LPC Controller(0x1C43)"},
{0x8086, 0x1C44, 0xFFFF, 0xFFFF, "Z68 Express Chipset LPC Controller(0x1C44)"},
{0x8086, 0x1C45, 0xFFFF, 0xFFFF, "6 Series/C200 Series Chipset Family LPC Controller(0x1C45)"},
{0x8086, 0x1C46, 0xFFFF, 0xFFFF, "P67 Express Chipset LPC Controller(0x1C46)"},
{0x8086, 0x1C46, 0x1043, 0x844D, "P8P67 Deluxe Motherboard(0x1043-0x844D)"},
{0x8086, 0x1C47, 0xFFFF, 0xFFFF, "UM67 Express Chipset LPC Controller(0x1C47)"},
{0x8086, 0x1C48, 0xFFFF, 0xFFFF, "6 Series/C200 Series Chipset Family LPC Controller(0x1C48)"},
{0x8086, 0x1C49, 0xFFFF, 0xFFFF, "HM65 Express Chipset LPC Controller(0x1C49)"},
{0x8086, 0x1C49, 0x8086, 0x7270, "Apple MacBookPro8,2 [Core i7, 15\", 2011](0x8086-0x7270)"},
{0x8086, 0x1C4A, 0xFFFF, 0xFFFF, "H67 Express Chipset LPC Controller(0x1C4A)"},
{0x8086, 0x1C4A, 0x1028, 0x04AA, "XPS 8300(0x1028-0x04AA)"},
{0x8086, 0x1C4A, 0x1043, 0x844D, "P8H67 Series Motherboard(0x1043-0x844D)"},
{0x8086, 0x1C4B, 0xFFFF, 0xFFFF, "HM67 Express Chipset LPC Controller(0x1C4B)"},
{0x8086, 0x1C4B, 0x1028, 0x04B2, "Vostro 3350(0x1028-0x04B2)"},
{0x8086, 0x1C4B, 0x1028, 0x04DA, "Vostro 3750(0x1028-0x04DA)"},
{0x8086, 0x1C4C, 0xFFFF, 0xFFFF, "Q65 Express Chipset LPC Controller(0x1C4C)"},
{0x8086, 0x1C4D, 0xFFFF, 0xFFFF, "QS67 Express Chipset LPC Controller(0x1C4D)"},
{0x8086, 0x1C4E, 0xFFFF, 0xFFFF, "Q67 Express Chipset LPC Controller(0x1C4E)"},
{0x8086, 0x1C4E, 0x17AA, 0x3070, "ThinkCentre M91p(0x17AA-0x3070)"},
{0x8086, 0x1C4F, 0xFFFF, 0xFFFF, "QM67 Express Chipset LPC Controller(0x1C4F)"},
{0x8086, 0x1C4F, 0x1028, 0x04A3, "Precision M4600(0x1028-0x04A3)"},
{0x8086, 0x1C4F, 0x17AA, 0x21CF, "ThinkPad T520(0x17AA-0x21CF)"},
{0x8086, 0x1C50, 0xFFFF, 0xFFFF, "B65 Express Chipset LPC Controller(0x1C50)"},
{0x8086, 0x1C51, 0xFFFF, 0xFFFF, "6 Series/C200 Series Chipset Family LPC Controller(0x1C51)"},
{0x8086, 0x1C52, 0xFFFF, 0xFFFF, "C202 Chipset LPC Controller(0x1C52)"},
{0x8086, 0x1C52, 0x8086, 0x7270, "Server Board S1200BTS(0x8086-0x7270)"},
{0x8086, 0x1C53, 0xFFFF, 0xFFFF, "6 Series/C200 Series Chipset Family LPC Controller(0x1C53)"},
{0x8086, 0x1C54, 0xFFFF, 0xFFFF, "C204 Chipset LPC Controller(0x1C54)"},
{0x8086, 0x1C55, 0xFFFF, 0xFFFF, "6 Series/C200 Series Chipset Family LPC Controller(0x1C55)"},
{0x8086, 0x1C56, 0xFFFF, 0xFFFF, "C206 Chipset LPC Controller(0x1C56)"},
{0x8086, 0x1C56, 0x1043, 0x844D, "P8B WS Motherboard(0x1043-0x844D)"},
{0x8086, 0x1C57, 0xFFFF, 0xFFFF, "6 Series/C200 Series Chipset Family LPC Controller(0x1C57)"},
{0x8086, 0x1C58, 0xFFFF, 0xFFFF, "Upgraded B65 Express Chipset LPC Controller(0x1C58)"},
{0x8086, 0x1C59, 0xFFFF, 0xFFFF, "Upgraded HM67 Express Chipset LPC Controller(0x1C59)"},
{0x8086, 0x1C5A, 0xFFFF, 0xFFFF, "Upgraded Q67 Express Chipset LPC Controller(0x1C5A)"},
{0x8086, 0x1C5B, 0xFFFF, 0xFFFF, "6 Series/C200 Series Chipset Family LPC Controller(0x1C5B)"},
{0x8086, 0x1C5C, 0xFFFF, 0xFFFF, "H61 Express Chipset LPC Controller(0x1C5C)"},
{0x8086, 0x1C5C, 0x8086, 0x200D, "DH61CR motherboard(0x8086-0x200D)"},
{0x8086, 0x1C5D, 0xFFFF, 0xFFFF, "6 Series/C200 Series Chipset Family LPC Controller(0x1C5D)"},
{0x8086, 0x1C5E, 0xFFFF, 0xFFFF, "6 Series/C200 Series Chipset Family LPC Controller(0x1C5E)"},
{0x8086, 0x1C5F, 0xFFFF, 0xFFFF, "6 Series/C200 Series Chipset Family LPC Controller(0x1C5F)"},
{0x8086, 0x1D00, 0xFFFF, 0xFFFF, "C600/X79 series chipset 4-Port SATA IDE Controller(0x1D00)"},
{0x8086, 0x1D02, 0xFFFF, 0xFFFF, "C600/X79 series chipset 6-Port SATA AHCI Controller(0x1D02)"},
{0x8086, 0x1D02, 0x1028, 0x04F7, "C602J on PowerEdge R320 server(0x1028-0x04F7)"},
{0x8086, 0x1D04, 0xFFFF, 0xFFFF, "C600/X79 series chipset SATA RAID Controller(0x1D04)"},
{0x8086, 0x1D06, 0xFFFF, 0xFFFF, "C600/X79 series chipset SATA Premium RAID Controller(0x1D06)"},
{0x8086, 0x1D08, 0xFFFF, 0xFFFF, "C600/X79 series chipset 2-Port SATA IDE Controller(0x1D08)"},
{0x8086, 0x1D10, 0xFFFF, 0xFFFF, "C600/X79 series chipset PCI Express Root Port 1(0x1D10)"},
{0x8086, 0x1D10, 0x1028, 0x04F7, "C602J on PowerEdge R320 server(0x1028-0x04F7)"},
{0x8086, 0x1D11, 0xFFFF, 0xFFFF, "C600/X79 series chipset PCI Express Root Port 1(0x1D11)"},
{0x8086, 0x1D12, 0xFFFF, 0xFFFF, "C600/X79 series chipset PCI Express Root Port 2(0x1D12)"},
{0x8086, 0x1D13, 0xFFFF, 0xFFFF, "C600/X79 series chipset PCI Express Root Port 2(0x1D13)"},
{0x8086, 0x1D14, 0xFFFF, 0xFFFF, "C600/X79 series chipset PCI Express Root Port 3(0x1D14)"},
{0x8086, 0x1D15, 0xFFFF, 0xFFFF, "C600/X79 series chipset PCI Express Root Port 3(0x1D15)"},
{0x8086, 0x1D16, 0xFFFF, 0xFFFF, "C600/X79 series chipset PCI Express Root Port 4(0x1D16)"},
{0x8086, 0x1D17, 0xFFFF, 0xFFFF, "C600/X79 series chipset PCI Express Root Port 4(0x1D17)"},
{0x8086, 0x1D18, 0xFFFF, 0xFFFF, "C600/X79 series chipset PCI Express Root Port 5(0x1D18)"},
{0x8086, 0x1D18, 0x1028, 0x04F7, "C602J on PowerEdge R320 server(0x1028-0x04F7)"},
{0x8086, 0x1D19, 0xFFFF, 0xFFFF, "C600/X79 series chipset PCI Express Root Port 5(0x1D19)"},
{0x8086, 0x1D1A, 0xFFFF, 0xFFFF, "C600/X79 series chipset PCI Express Root Port 6(0x1D1A)"},
{0x8086, 0x1D1B, 0xFFFF, 0xFFFF, "C600/X79 series chipset PCI Express Root Port 6(0x1D1B)"},
{0x8086, 0x1D1C, 0xFFFF, 0xFFFF, "C600/X79 series chipset PCI Express Root Port 7(0x1D1C)"},
{0x8086, 0x1D1D, 0xFFFF, 0xFFFF, "C600/X79 series chipset PCI Express Root Port 7(0x1D1D)"},
{0x8086, 0x1D1E, 0xFFFF, 0xFFFF, "C600/X79 series chipset PCI Express Root Port 8(0x1D1E)"},
{0x8086, 0x1D1E, 0x1028, 0x04F7, "C602J on PowerEdge R320 server(0x1028-0x04F7)"},
{0x8086, 0x1D1F, 0xFFFF, 0xFFFF, "C600/X79 series chipset PCI Express Root Port 8(0x1D1F)"},
{0x8086, 0x1D20, 0xFFFF, 0xFFFF, "C600/X79 series chipset High Definition Audio Controller(0x1D20)"},
{0x8086, 0x1D22, 0xFFFF, 0xFFFF, "C600/X79 series chipset SMBus Host Controller(0x1D22)"},
{0x8086, 0x1D22, 0x15D9, 0x066B, "X9SRL-F(0x15D9-0x066B)"},
{0x8086, 0x1D24, 0xFFFF, 0xFFFF, "C600/X79 series chipset Thermal Management Controller(0x1D24)"},
{0x8086, 0x1D24, 0x15D9, 0x066B, "X9SRL-F(0x15D9-0x066B)"},
{0x8086, 0x1D25, 0xFFFF, 0xFFFF, "C600/X79 series chipset DMI to PCI Bridge(0x1D25)"},
{0x8086, 0x1D26, 0xFFFF, 0xFFFF, "C600/X79 series chipset USB2 Enhanced Host Controller #1(0x1D26)"},
{0x8086, 0x1D26, 0x1028, 0x04F7, "C602J on PowerEdge R320 server(0x1028-0x04F7)"},
{0x8086, 0x1D26, 0x15D9, 0x066B, "X9SRL-F(0x15D9-0x066B)"},
{0x8086, 0x1D2D, 0xFFFF, 0xFFFF, "C600/X79 series chipset USB2 Enhanced Host Controller #2(0x1D2D)"},
{0x8086, 0x1D2D, 0x1028, 0x04F7, "C602J on PowerEdge R320 server(0x1028-0x04F7)"},
{0x8086, 0x1D2D, 0x103C, 0x18A9, "HP DL360e G8(0x103C-0x18A9)"},
{0x8086, 0x1D2D, 0x15D9, 0x066B, "X9SRL-F(0x15D9-0x066B)"},
{0x8086, 0x1D33, 0xFFFF, 0xFFFF, "C600/X79 series chipset LAN Controller(0x1D33)"},
{0x8086, 0x1D35, 0xFFFF, 0xFFFF, "C600/X79 series chipset VECI Controller(0x1D35)"},
{0x8086, 0x1D3A, 0xFFFF, 0xFFFF, "C600/X79 series chipset MEI Controller #1(0x1D3A)"},
{0x8086, 0x1D3A, 0x1028, 0x04F7, "C602J on PowerEdge R320 server(0x1028-0x04F7)"},
{0x8086, 0x1D3A, 0x15D9, 0x066B, "X9SRL-F(0x15D9-0x066B)"},
{0x8086, 0x1D3B, 0xFFFF, 0xFFFF, "C600/X79 series chipset MEI Controller #2(0x1D3B)"},
{0x8086, 0x1D3B, 0x1028, 0x04F7, "C602J on PowerEdge R320 server(0x1028-0x04F7)"},
{0x8086, 0x1D3B, 0x15D9, 0x066B, "X9SRL-F(0x15D9-0x066B)"},
{0x8086, 0x1D3C, 0xFFFF, 0xFFFF, "C600/X79 series chipset IDE-r Controller(0x1D3C)"},
{0x8086, 0x1D3D, 0xFFFF, 0xFFFF, "C600/X79 series chipset KT Controller(0x1D3D)"},
{0x8086, 0x1D3E, 0xFFFF, 0xFFFF, "C600/X79 series chipset PCI Express Virtual Root Port(0x1D3E)"},
{0x8086, 0x1D3E, 0x1028, 0x04F7, "C602J on PowerEdge R320 server(0x1028-0x04F7)"},
{0x8086, 0x1D3F, 0xFFFF, 0xFFFF, "C608/C606/X79 series chipset PCI Express Virtual Switch Port(0x1D3F)"},
{0x8086, 0x1D40, 0xFFFF, 0xFFFF, "C600/X79 series chipset LPC Controller(0x1D40)"},
{0x8086, 0x1D41, 0xFFFF, 0xFFFF, "C600/X79 series chipset LPC Controller(0x1D41)"},
{0x8086, 0x1D41, 0x1028, 0x04F7, "C602J on PowerEdge R320 server(0x1028-0x04F7)"},
{0x8086, 0x1D41, 0x15D9, 0x066B, "X9SRL-F(0x15D9-0x066B)"},
{0x8086, 0x1D50, 0xFFFF, 0xFFFF, "C608 chipset Dual 4-Port SATA/SAS Storage Control Unit(0x1D50)"},
{0x8086, 0x1D54, 0xFFFF, 0xFFFF, "C600/X79 series chipset Dual 4-Port SATA/SAS Storage Control Unit(0x1D54)"},
{0x8086, 0x1D55, 0xFFFF, 0xFFFF, "C600/X79 series chipset 4-Port SATA/SAS Storage Control Unit(0x1D55)"},
{0x8086, 0x1D58, 0xFFFF, 0xFFFF, "C606 chipset Dual 4-Port SATA/SAS Storage Control Unit(0x1D58)"},
{0x8086, 0x1D59, 0xFFFF, 0xFFFF, "C604/X79 series chipset 4-Port SATA/SAS Storage Control Unit(0x1D59)"},
{0x8086, 0x1D5A, 0xFFFF, 0xFFFF, "C600/X79 series chipset Dual 4-Port SATA Storage Control Unit(0x1D5A)"},
{0x8086, 0x1D5B, 0xFFFF, 0xFFFF, "C602 chipset 4-Port SATA Storage Control Unit(0x1D5B)"},
{0x8086, 0x1D5C, 0xFFFF, 0xFFFF, "C600/X79 series chipset Dual 4-Port SATA/SAS Storage Control Unit(0x1D5C)"},
{0x8086, 0x1D5D, 0xFFFF, 0xFFFF, "C600/X79 series chipset 4-Port SATA/SAS Storage Control Unit(0x1D5D)"},
{0x8086, 0x1D5E, 0xFFFF, 0xFFFF, "C600/X79 series chipset Dual 4-Port SATA Storage Control Unit(0x1D5E)"},
{0x8086, 0x1D5F, 0xFFFF, 0xFFFF, "C600/X79 series chipset 4-Port SATA Storage Control Unit(0x1D5F)"},
{0x8086, 0x1D60, 0xFFFF, 0xFFFF, "C608 chipset Dual 4-Port SATA/SAS Storage Control Unit(0x1D60)"},
{0x8086, 0x1D64, 0xFFFF, 0xFFFF, "C600/X79 series chipset Dual 4-Port SATA/SAS Storage Control Unit(0x1D64)"},
{0x8086, 0x1D65, 0xFFFF, 0xFFFF, "C600/X79 series chipset 4-Port SATA/SAS Storage Control Unit(0x1D65)"},
{0x8086, 0x1D68, 0xFFFF, 0xFFFF, "C606 chipset Dual 4-Port SATA/SAS Storage Control Unit(0x1D68)"},
{0x8086, 0x1D69, 0xFFFF, 0xFFFF, "C604/X79 series chipset 4-Port SATA/SAS Storage Control Unit(0x1D69)"},
{0x8086, 0x1D6A, 0xFFFF, 0xFFFF, "C600/X79 series chipset Dual 4-Port SATA Storage Control Unit(0x1D6A)"},
{0x8086, 0x1D6B, 0xFFFF, 0xFFFF, "C602 chipset 4-Port SATA Storage Control Unit(0x1D6B)"},
{0x8086, 0x1D6B, 0x0497, 0x1028, "Dell Precision T3600(0x0497-0x1028)"},
{0x8086, 0x1D6C, 0xFFFF, 0xFFFF, "C600/X79 series chipset Dual 4-Port SATA/SAS Storage Control Unit(0x1D6C)"},
{0x8086, 0x1D6D, 0xFFFF, 0xFFFF, "C600/X79 series chipset 4-Port SATA/SAS Storage Control Unit(0x1D6D)"},
{0x8086, 0x1D6E, 0xFFFF, 0xFFFF, "C600/X79 series chipset Dual 4-Port SATA Storage Control Unit(0x1D6E)"},
{0x8086, 0x1D6F, 0xFFFF, 0xFFFF, "C600/X79 series chipset 4-Port SATA Storage Control Unit(0x1D6F)"},
{0x8086, 0x1D70, 0xFFFF, 0xFFFF, "C600/X79 series chipset SMBus Controller 0(0x1D70)"},
{0x8086, 0x1D71, 0xFFFF, 0xFFFF, "C608/C606/X79 series chipset SMBus Controller 1(0x1D71)"},
{0x8086, 0x1D72, 0xFFFF, 0xFFFF, "C608 chipset SMBus Controller 2(0x1D72)"},
{0x8086, 0x1D74, 0xFFFF, 0xFFFF, "C608/C606/X79 series chipset PCI Express Upstream Port(0x1D74)"},
{0x8086, 0x1D76, 0xFFFF, 0xFFFF, "C600/X79 series chipset Multi-Function Glue(0x1D76)"},
{0x8086, 0x1E00, 0xFFFF, 0xFFFF, "7 Series/C210 Series Chipset Family 4-port SATA Controller [IDE mode](0x1E00)"},
{0x8086, 0x1E00, 0x1734, 0x11D6, "B75 [Ivy Bridge] chipset on Esprimo P510 D3171 motherboard(0x1734-0x11D6)"},
{0x8086, 0x1E01, 0xFFFF, 0xFFFF, "7 Series Chipset Family 4-port SATA Controller [IDE mode](0x1E01)"},
{0x8086, 0x1E01, 0x144D, 0xC652, "NP300E5C series laptop(0x144D-0xC652)"},
{0x8086, 0x1E02, 0xFFFF, 0xFFFF, "7 Series/C210 Series Chipset Family 6-port SATA Controller [AHCI mode](0x1E02)"},
{0x8086, 0x1E02, 0x1043, 0x84CA, "P8 series motherboard(0x1043-0x84CA)"},
{0x8086, 0x1E02, 0x1734, 0x11D6, "B75 [Ivy Bridge] chipset on Esprimo P510 D3171 motherboard(0x1734-0x11D6)"},
{0x8086, 0x1E02, 0x1849, 0x1E02, "Motherboard(0x1849-0x1E02)"},
{0x8086, 0x1E03, 0xFFFF, 0xFFFF, "7 Series Chipset Family 6-port SATA Controller [AHCI mode](0x1E03)"},
{0x8086, 0x1E03, 0x1043, 0x108D, "VivoBook X202EV(0x1043-0x108D)"},
{0x8086, 0x1E03, 0x1043, 0x1477, "N56VZ(0x1043-0x1477)"},
{0x8086, 0x1E03, 0x1043, 0x1517, "Zenbook Prime UX31A(0x1043-0x1517)"},
{0x8086, 0x1E03, 0x10CF, 0x16E2, "LIFEBOOK E752(0x10CF-0x16E2)"},
{0x8086, 0x1E03, 0x144D, 0xC652, "NP300E5C series laptop(0x144D-0xC652)"},
{0x8086, 0x1E04, 0xFFFF, 0xFFFF, "7 Series/C210 Series Chipset Family SATA Controller [RAID mode](0x1E04)"},
{0x8086, 0x1E05, 0xFFFF, 0xFFFF, "7 Series Chipset SATA Controller [RAID mode](0x1E05)"},
{0x8086, 0x1E06, 0xFFFF, 0xFFFF, "7 Series/C210 Series Chipset Family SATA Controller [RAID mode](0x1E06)"},
{0x8086, 0x1E07, 0xFFFF, 0xFFFF, "7 Series Chipset Family SATA Controller [RAID mode](0x1E07)"},
{0x8086, 0x1E08, 0xFFFF, 0xFFFF, "7 Series/C210 Series Chipset Family 2-port SATA Controller [IDE mode](0x1E08)"},
{0x8086, 0x1E09, 0xFFFF, 0xFFFF, "7 Series Chipset Family 2-port SATA Controller [IDE mode](0x1E09)"},
{0x8086, 0x1E09, 0x144D, 0xC652, "NP300E5C series laptop(0x144D-0xC652)"},
{0x8086, 0x1E0E, 0xFFFF, 0xFFFF, "7 Series/C210 Series Chipset Family SATA Controller [RAID mode](0x1E0E)"},
{0x8086, 0x1E10, 0xFFFF, 0xFFFF, "7 Series/C216 Chipset Family PCI Express Root Port 1(0x1E10)"},
{0x8086, 0x1E10, 0x1043, 0x108D, "VivoBook X202EV(0x1043-0x108D)"},
{0x8086, 0x1E10, 0x1043, 0x1477, "N56VZ(0x1043-0x1477)"},
{0x8086, 0x1E10, 0x1043, 0x1517, "Zenbook Prime UX31A(0x1043-0x1517)"},
{0x8086, 0x1E10, 0x1043, 0x84CA, "P8H77-I Motherboard(0x1043-0x84CA)"},
{0x8086, 0x1E10, 0x10CF, 0x16E9, "LIFEBOOK E752(0x10CF-0x16E9)"},
{0x8086, 0x1E10, 0x144D, 0xC652, "NP300E5C series laptop(0x144D-0xC652)"},
{0x8086, 0x1E10, 0x1734, 0x11D6, "B75 [Ivy Bridge] chipset on Esprimo P510 D3171 motherboard(0x1734-0x11D6)"},
{0x8086, 0x1E10, 0x1849, 0x1E10, "Motherboard(0x1849-0x1E10)"},
{0x8086, 0x1E12, 0xFFFF, 0xFFFF, "7 Series/C210 Series Chipset Family PCI Express Root Port 2(0x1E12)"},
{0x8086, 0x1E12, 0x1043, 0x108D, "VivoBook X202EV(0x1043-0x108D)"},
{0x8086, 0x1E12, 0x1043, 0x1477, "N56VZ(0x1043-0x1477)"},
{0x8086, 0x1E12, 0x1043, 0x1517, "Zenbook Prime UX31A(0x1043-0x1517)"},
{0x8086, 0x1E14, 0xFFFF, 0xFFFF, "7 Series/C210 Series Chipset Family PCI Express Root Port 3(0x1E14)"},
{0x8086, 0x1E14, 0x10CF, 0x16E9, "LIFEBOOK E752(0x10CF-0x16E9)"},
{0x8086, 0x1E16, 0xFFFF, 0xFFFF, "7 Series/C216 Chipset Family PCI Express Root Port 4(0x1E16)"},
{0x8086, 0x1E16, 0x1043, 0x108D, "VivoBook X202EV(0x1043-0x108D)"},
{0x8086, 0x1E16, 0x1043, 0x1477, "N56VZ(0x1043-0x1477)"},
{0x8086, 0x1E16, 0x144D, 0xC652, "NP300E5C series laptop(0x144D-0xC652)"},
{0x8086, 0x1E16, 0x1849, 0x1618, "Z77 Extreme4 motherboard(0x1849-0x1618)"},
{0x8086, 0x1E18, 0xFFFF, 0xFFFF, "7 Series/C210 Series Chipset Family PCI Express Root Port 5(0x1E18)"},
{0x8086, 0x1E18, 0x1043, 0x84CA, "P8H77-I Motherboard(0x1043-0x84CA)"},
{0x8086, 0x1E18, 0x1849, 0x1E18, "Motherboard(0x1849-0x1E18)"},
{0x8086, 0x1E1A, 0xFFFF, 0xFFFF, "7 Series/C210 Series Chipset Family PCI Express Root Port 6(0x1E1A)"},
{0x8086, 0x1E1A, 0x1734, 0x11D6, "B75 [Ivy Bridge] chipset on Esprimo P510 D3171 motherboard(0x1734-0x11D6)"},
{0x8086, 0x1E1A, 0x1849, 0x1E1A, "Motherboard(0x1849-0x1E1A)"},
{0x8086, 0x1E1C, 0xFFFF, 0xFFFF, "7 Series/C210 Series Chipset Family PCI Express Root Port 7(0x1E1C)"},
{0x8086, 0x1E1E, 0xFFFF, 0xFFFF, "7 Series/C210 Series Chipset Family PCI Express Root Port 8(0x1E1E)"},
{0x8086, 0x1E1E, 0x10CF, 0x16E9, "LIFEBOOK E752(0x10CF-0x16E9)"},
{0x8086, 0x1E1E, 0x1849, 0x1E1E, "Motherboard(0x1849-0x1E1E)"},
{0x8086, 0x1E20, 0xFFFF, 0xFFFF, "7 Series/C216 Chipset Family High Definition Audio Controller(0x1E20)"},
{0x8086, 0x1E20, 0x1028, 0x054B, "XPS One 2710(0x1028-0x054B)"},
{0x8086, 0x1E20, 0x1043, 0x108D, "VivoBook X202EV(0x1043-0x108D)"},
{0x8086, 0x1E20, 0x1043, 0x1477, "N56VZ(0x1043-0x1477)"},
{0x8086, 0x1E20, 0x1043, 0x1517, "Zenbook Prime UX31A(0x1043-0x1517)"},
{0x8086, 0x1E20, 0x1043, 0x8415, "P8H77-I Motherboard(0x1043-0x8415)"},
{0x8086, 0x1E20, 0x1043, 0x8445, "P8Z77-V LX Motherboard(0x1043-0x8445)"},
{0x8086, 0x1E20, 0x10CF, 0x1757, "LIFEBOOK E752(0x10CF-0x1757)"},
{0x8086, 0x1E20, 0x144D, 0xC652, "NP300E5C series laptop(0x144D-0xC652)"},
{0x8086, 0x1E20, 0x1734, 0x11D8, "B75 [Ivy Bridge] chipset CX20642 audio controller on Esprimo P510 D3171 motherboard(0x1734-0x11D8)"},
{0x8086, 0x1E20, 0x1849, 0x1898, "Z77 Extreme4 motherboard(0x1849-0x1898)"},
{0x8086, 0x1E22, 0xFFFF, 0xFFFF, "7 Series/C216 Chipset Family SMBus Controller(0x1E22)"},
{0x8086, 0x1E22, 0x1043, 0x108D, "VivoBook X202EV(0x1043-0x108D)"},
{0x8086, 0x1E22, 0x1043, 0x1477, "N56VZ(0x1043-0x1477)"},
{0x8086, 0x1E22, 0x1043, 0x1517, "Zenbook Prime UX31A(0x1043-0x1517)"},
{0x8086, 0x1E22, 0x1043, 0x84CA, "P8 series motherboard(0x1043-0x84CA)"},
{0x8086, 0x1E22, 0x10CF, 0x16E6, "LIFEBOOK E752(0x10CF-0x16E6)"},
{0x8086, 0x1E22, 0x144D, 0xC652, "NP300E5C series laptop(0x144D-0xC652)"},
{0x8086, 0x1E22, 0x1734, 0x11D6, "B75 [Ivy Bridge] chipset on Esprimo P510 D3171 motherboard(0x1734-0x11D6)"},
{0x8086, 0x1E22, 0x1849, 0x1E22, "Motherboard(0x1849-0x1E22)"},
{0x8086, 0x1E24, 0xFFFF, 0xFFFF, "7 Series/C210 Series Chipset Family Thermal Management Controller(0x1E24)"},
{0x8086, 0x1E24, 0x1043, 0x1517, "Zenbook Prime UX31A(0x1043-0x1517)"},
{0x8086, 0x1E25, 0xFFFF, 0xFFFF, "7 Series/C210 Series Chipset Family DMI to PCI Bridge(0x1E25)"},
{0x8086, 0x1E26, 0xFFFF, 0xFFFF, "7 Series/C216 Chipset Family USB Enhanced Host Controller #1(0x1E26)"},
{0x8086, 0x1E26, 0x1043, 0x108D, "VivoBook X202EV(0x1043-0x108D)"},
{0x8086, 0x1E26, 0x1043, 0x1477, "N56VZ(0x1043-0x1477)"},
{0x8086, 0x1E26, 0x1043, 0x1517, "Zenbook Prime UX31A(0x1043-0x1517)"},
{0x8086, 0x1E26, 0x1043, 0x84CA, "P8 series motherboard(0x1043-0x84CA)"},
{0x8086, 0x1E26, 0x10CF, 0x16E8, "LIFEBOOK E752(0x10CF-0x16E8)"},
{0x8086, 0x1E26, 0x144D, 0xC652, "NP300E5C series laptop(0x144D-0xC652)"},
{0x8086, 0x1E26, 0x1734, 0x11D6, "B75 [Ivy Bridge] chipset USB 2.0 controller on Esprimo P510 D3171 motherboard(0x1734-0x11D6)"},
{0x8086, 0x1E26, 0x1849, 0x1E26, "Motherboard(0x1849-0x1E26)"},
{0x8086, 0x1E2D, 0xFFFF, 0xFFFF, "7 Series/C216 Chipset Family USB Enhanced Host Controller #2(0x1E2D)"},
{0x8086, 0x1E2D, 0x1043, 0x108D, "VivoBook X202EV(0x1043-0x108D)"},
{0x8086, 0x1E2D, 0x1043, 0x1477, "N56VZ(0x1043-0x1477)"},
{0x8086, 0x1E2D, 0x1043, 0x1517, "Zenbook Prime UX31A(0x1043-0x1517)"},
{0x8086, 0x1E2D, 0x1043, 0x84CA, "P8 series motherboard(0x1043-0x84CA)"},
{0x8086, 0x1E2D, 0x10CF, 0x16E8, "LIFEBOOK E752(0x10CF-0x16E8)"},
{0x8086, 0x1E2D, 0x144D, 0xC652, "NP300E5C series laptop(0x144D-0xC652)"},
{0x8086, 0x1E2D, 0x1734, 0x11D6, "B75 [Ivy Bridge] chipset USB 2.0 controller on Esprimo P510 D3171 motherboard(0x1734-0x11D6)"},
{0x8086, 0x1E2D, 0x1849, 0x1E2D, "Motherboard(0x1849-0x1E2D)"},
{0x8086, 0x1E31, 0xFFFF, 0xFFFF, "7 Series/C210 Series Chipset Family USB xHCI Host Controller(0x1E31)"},
{0x8086, 0x1E31, 0x103C, 0x179B, "Elitebook 8470p(0x103C-0x179B)"},
{0x8086, 0x1E31, 0x103C, 0x17AB, "ProBook 6570b(0x103C-0x17AB)"},
{0x8086, 0x1E31, 0x1043, 0x108D, "VivoBook X202EV(0x1043-0x108D)"},
{0x8086, 0x1E31, 0x1043, 0x1477, "N56VZ(0x1043-0x1477)"},
{0x8086, 0x1E31, 0x1043, 0x1517, "Zenbook Prime UX31A(0x1043-0x1517)"},
{0x8086, 0x1E31, 0x1043, 0x84CA, "P8 series motherboard(0x1043-0x84CA)"},
{0x8086, 0x1E31, 0x10CF, 0x16EE, "LIFEBOOK E752(0x10CF-0x16EE)"},
{0x8086, 0x1E31, 0x1734, 0x11D6, "B75 [Ivy Bridge] chipset USB 3.0 controller on Esprimo P510 D3171 motherboard(0x1734-0x11D6)"},
{0x8086, 0x1E31, 0x17AA, 0x21F3, "ThinkPad T430(0x17AA-0x21F3)"},
{0x8086, 0x1E31, 0x1849, 0x1E31, "Motherboard(0x1849-0x1E31)"},
{0x8086, 0x1E33, 0xFFFF, 0xFFFF, "7 Series/C210 Series Chipset Family LAN Controller(0x1E33)"},
{0x8086, 0x1E3A, 0xFFFF, 0xFFFF, "7 Series/C216 Chipset Family MEI Controller #1(0x1E3A)"},
{0x8086, 0x1E3A, 0x1043, 0x108D, "VivoBook X202EV(0x1043-0x108D)"},
{0x8086, 0x1E3A, 0x1043, 0x1477, "N56VZ(0x1043-0x1477)"},
{0x8086, 0x1E3A, 0x1043, 0x1517, "Zenbook Prime UX31A(0x1043-0x1517)"},
{0x8086, 0x1E3A, 0x1043, 0x84CA, "P8 series motherboard(0x1043-0x84CA)"},
{0x8086, 0x1E3A, 0x10CF, 0x16EA, "LIFEBOOK E752(0x10CF-0x16EA)"},
{0x8086, 0x1E3A, 0x144D, 0xC652, "NP300E5C series laptop(0x144D-0xC652)"},
{0x8086, 0x1E3A, 0x1734, 0x11D6, "B75 [Ivy Bridge] chipset on Esprimo P510 D3171 motherboard(0x1734-0x11D6)"},
{0x8086, 0x1E3A, 0x1849, 0x1E3A, "Motherboard(0x1849-0x1E3A)"},
{0x8086, 0x1E3B, 0xFFFF, 0xFFFF, "7 Series/C210 Series Chipset Family MEI Controller #2(0x1E3B)"},
{0x8086, 0x1E3C, 0xFFFF, 0xFFFF, "7 Series/C210 Series Chipset Family IDE-r Controller(0x1E3C)"},
{0x8086, 0x1E3D, 0xFFFF, 0xFFFF, "7 Series/C210 Series Chipset Family KT Controller(0x1E3D)"},
{0x8086, 0x1E41, 0xFFFF, 0xFFFF, "7 Series Chipset Family LPC Controller(0x1E41)"},
{0x8086, 0x1E42, 0xFFFF, 0xFFFF, "7 Series Chipset Family LPC Controller(0x1E42)"},
{0x8086, 0x1E43, 0xFFFF, 0xFFFF, "7 Series Chipset Family LPC Controller(0x1E43)"},
{0x8086, 0x1E44, 0xFFFF, 0xFFFF, "Z77 Express Chipset LPC Controller(0x1E44)"},
{0x8086, 0x1E44, 0x1043, 0x84CA, "P8 series motherboard(0x1043-0x84CA)"},
{0x8086, 0x1E44, 0x1849, 0x1E44, "Motherboard(0x1849-0x1E44)"},
{0x8086, 0x1E45, 0xFFFF, 0xFFFF, "7 Series Chipset Family LPC Controller(0x1E45)"},
{0x8086, 0x1E46, 0xFFFF, 0xFFFF, "Z75 Express Chipset LPC Controller(0x1E46)"},
{0x8086, 0x1E47, 0xFFFF, 0xFFFF, "Q77 Express Chipset LPC Controller(0x1E47)"},
{0x8086, 0x1E48, 0xFFFF, 0xFFFF, "Q75 Express Chipset LPC Controller(0x1E48)"},
{0x8086, 0x1E49, 0xFFFF, 0xFFFF, "B75 Express Chipset LPC Controller(0x1E49)"},
{0x8086, 0x1E49, 0x1734, 0x11D6, "Esprimo P510 D3171 motherboard(0x1734-0x11D6)"},
{0x8086, 0x1E4A, 0xFFFF, 0xFFFF, "H77 Express Chipset LPC Controller(0x1E4A)"},
{0x8086, 0x1E4A, 0x1043, 0x84CA, "P8H77-I Motherboard(0x1043-0x84CA)"},
{0x8086, 0x1E4B, 0xFFFF, 0xFFFF, "7 Series Chipset Family LPC Controller(0x1E4B)"},
{0x8086, 0x1E4C, 0xFFFF, 0xFFFF, "7 Series Chipset Family LPC Controller(0x1E4C)"},
{0x8086, 0x1E4D, 0xFFFF, 0xFFFF, "7 Series Chipset Family LPC Controller(0x1E4D)"},
{0x8086, 0x1E4E, 0xFFFF, 0xFFFF, "7 Series Chipset Family LPC Controller(0x1E4E)"},
{0x8086, 0x1E4F, 0xFFFF, 0xFFFF, "7 Series Chipset Family LPC Controller(0x1E4F)"},
{0x8086, 0x1E50, 0xFFFF, 0xFFFF, "7 Series Chipset Family LPC Controller(0x1E50)"},
{0x8086, 0x1E51, 0xFFFF, 0xFFFF, "7 Series Chipset Family LPC Controller(0x1E51)"},
{0x8086, 0x1E52, 0xFFFF, 0xFFFF, "7 Series Chipset Family LPC Controller(0x1E52)"},
{0x8086, 0x1E53, 0xFFFF, 0xFFFF, "C216 Series Chipset LPC Controller(0x1E53)"},
{0x8086, 0x1E54, 0xFFFF, 0xFFFF, "7 Series Chipset Family LPC Controller(0x1E54)"},
{0x8086, 0x1E55, 0xFFFF, 0xFFFF, "QM77 Express Chipset LPC Controller(0x1E55)"},
{0x8086, 0x1E56, 0xFFFF, 0xFFFF, "QS77 Express Chipset LPC Controller(0x1E56)"},
{0x8086, 0x1E57, 0xFFFF, 0xFFFF, "HM77 Express Chipset LPC Controller(0x1E57)"},
{0x8086, 0x1E58, 0xFFFF, 0xFFFF, "UM77 Express Chipset LPC Controller(0x1E58)"},
{0x8086, 0x1E59, 0xFFFF, 0xFFFF, "HM76 Express Chipset LPC Controller(0x1E59)"},
{0x8086, 0x1E59, 0x1043, 0x1477, "N56VZ(0x1043-0x1477)"},
{0x8086, 0x1E59, 0x1043, 0x1517, "Zenbook Prime UX31A(0x1043-0x1517)"},
{0x8086, 0x1E59, 0x10CF, 0x16E0, "LIFEBOOK E752(0x10CF-0x16E0)"},
{0x8086, 0x1E5A, 0xFFFF, 0xFFFF, "7 Series Chipset Family LPC Controller(0x1E5A)"},
{0x8086, 0x1E5B, 0xFFFF, 0xFFFF, "UM77 Express Chipset LPC Controller(0x1E5B)"},
{0x8086, 0x1E5C, 0xFFFF, 0xFFFF, "7 Series Chipset Family LPC Controller(0x1E5C)"},
{0x8086, 0x1E5D, 0xFFFF, 0xFFFF, "HM75 Express Chipset LPC Controller(0x1E5D)"},
{0x8086, 0x1E5D, 0x144D, 0xC652, "NP300E5C series laptop(0x144D-0xC652)"},
{0x8086, 0x1E5E, 0xFFFF, 0xFFFF, "HM70 Express Chipset LPC Controller(0x1E5E)"},
{0x8086, 0x1E5E, 0x1043, 0x108D, "VivoBook X202EV(0x1043-0x108D)"},
{0x8086, 0x1E5F, 0xFFFF, 0xFFFF, "NM70 Express Chipset LPC Controller(0x1E5F)"},
{0x8086, 0x1F00, 0xFFFF, 0xFFFF, "Atom processor C2000 SoC Transaction Router(0x1F00)"},
{0x8086, 0x1F01, 0xFFFF, 0xFFFF, "Atom processor C2000 SoC Transaction Router(0x1F01)"},
{0x8086, 0x1F02, 0xFFFF, 0xFFFF, "Atom processor C2000 SoC Transaction Router(0x1F02)"},
{0x8086, 0x1F03, 0xFFFF, 0xFFFF, "Atom processor C2000 SoC Transaction Router(0x1F03)"},
{0x8086, 0x1F04, 0xFFFF, 0xFFFF, "Atom processor C2000 SoC Transaction Router(0x1F04)"},
{0x8086, 0x1F05, 0xFFFF, 0xFFFF, "Atom processor C2000 SoC Transaction Router(0x1F05)"},
{0x8086, 0x1F06, 0xFFFF, 0xFFFF, "Atom processor C2000 SoC Transaction Router(0x1F06)"},
{0x8086, 0x1F07, 0xFFFF, 0xFFFF, "Atom processor C2000 SoC Transaction Router(0x1F07)"},
{0x8086, 0x1F08, 0xFFFF, 0xFFFF, "Atom processor C2000 SoC Transaction Router(0x1F08)"},
{0x8086, 0x1F09, 0xFFFF, 0xFFFF, "Atom processor C2000 SoC Transaction Router(0x1F09)"},
{0x8086, 0x1F0A, 0xFFFF, 0xFFFF, "Atom processor C2000 SoC Transaction Router(0x1F0A)"},
{0x8086, 0x1F0B, 0xFFFF, 0xFFFF, "Atom processor C2000 SoC Transaction Router(0x1F0B)"},
{0x8086, 0x1F0C, 0xFFFF, 0xFFFF, "Atom processor C2000 SoC Transaction Router(0x1F0C)"},
{0x8086, 0x1F0D, 0xFFFF, 0xFFFF, "Atom processor C2000 SoC Transaction Router(0x1F0D)"},
{0x8086, 0x1F0E, 0xFFFF, 0xFFFF, "Atom processor C2000 SoC Transaction Router(0x1F0E)"},
{0x8086, 0x1F0F, 0xFFFF, 0xFFFF, "Atom processor C2000 SoC Transaction Router(0x1F0F)"},
{0x8086, 0x1F10, 0xFFFF, 0xFFFF, "Atom processor C2000 PCIe Root Port 1(0x1F10)"},
{0x8086, 0x1F11, 0xFFFF, 0xFFFF, "Atom processor C2000 PCIe Root Port 2(0x1F11)"},
{0x8086, 0x1F12, 0xFFFF, 0xFFFF, "Atom processor C2000 PCIe Root Port 3(0x1F12)"},
{0x8086, 0x1F13, 0xFFFF, 0xFFFF, "Atom processor C2000 PCIe Root Port 4(0x1F13)"},
{0x8086, 0x1F14, 0xFFFF, 0xFFFF, "Atom processor C2000 RAS(0x1F14)"},
{0x8086, 0x1F15, 0xFFFF, 0xFFFF, "Atom processor C2000 SMBus 2.0(0x1F15)"},
{0x8086, 0x1F16, 0xFFFF, 0xFFFF, "Atom processor C2000 RCEC(0x1F16)"},
{0x8086, 0x1F18, 0xFFFF, 0xFFFF, "Atom processor C2000 QAT(0x1F18)"},
{0x8086, 0x1F19, 0xFFFF, 0xFFFF, "Atom processor C2000 QAT(0x1F19)"},
{0x8086, 0x1F20, 0xFFFF, 0xFFFF, "Atom processor C2000 4-Port IDE SATA2 Controller(0x1F20)"},
{0x8086, 0x1F21, 0xFFFF, 0xFFFF, "Atom processor C2000 4-Port IDE SATA2 Controller(0x1F21)"},
{0x8086, 0x1F22, 0xFFFF, 0xFFFF, "Atom processor C2000 AHCI SATA2 Controller(0x1F22)"},
{0x8086, 0x1F23, 0xFFFF, 0xFFFF, "Atom processor C2000 AHCI SATA2 Controller(0x1F23)"},
{0x8086, 0x1F24, 0xFFFF, 0xFFFF, "Atom processor C2000 RAID SATA2 Controller(0x1F24)"},
{0x8086, 0x1F25, 0xFFFF, 0xFFFF, "Atom processor C2000 RAID SATA2 Controller(0x1F25)"},
{0x8086, 0x1F26, 0xFFFF, 0xFFFF, "Atom processor C2000 RAID SATA2 Controller(0x1F26)"},
{0x8086, 0x1F27, 0xFFFF, 0xFFFF, "Atom processor C2000 RAID SATA2 Controller(0x1F27)"},
{0x8086, 0x1F2C, 0xFFFF, 0xFFFF, "Atom processor C2000 USB Enhanced Host Controller(0x1F2C)"},
{0x8086, 0x1F2C, 0x0200, 0x1028, "Atom C2338 on Dell 0K8Y0N motherboard(0x0200-0x1028)"},
{0x8086, 0x1F2E, 0xFFFF, 0xFFFF, "Atom processor C2000 RAID SATA2 Controller(0x1F2E)"},
{0x8086, 0x1F2F, 0xFFFF, 0xFFFF, "Atom processor C2000 RAID SATA2 Controller(0x1F2F)"},
{0x8086, 0x1F30, 0xFFFF, 0xFFFF, "Atom processor C2000 2-Port IDE SATA3 Controller(0x1F30)"},
{0x8086, 0x1F31, 0xFFFF, 0xFFFF, "Atom processor C2000 2-Port IDE SATA3 Controller(0x1F31)"},
{0x8086, 0x1F32, 0xFFFF, 0xFFFF, "Atom processor C2000 AHCI SATA3 Controller(0x1F32)"},
{0x8086, 0x1F33, 0xFFFF, 0xFFFF, "Atom processor C2000 AHCI SATA3 Controller(0x1F33)"},
{0x8086, 0x1F34, 0xFFFF, 0xFFFF, "Atom processor C2000 RAID SATA3 Controller(0x1F34)"},
{0x8086, 0x1F35, 0xFFFF, 0xFFFF, "Atom processor C2000 RAID SATA3 Controller(0x1F35)"},
{0x8086, 0x1F36, 0xFFFF, 0xFFFF, "Atom processor C2000 RAID SATA3 Controller(0x1F36)"},
{0x8086, 0x1F37, 0xFFFF, 0xFFFF, "Atom processor C2000 RAID SATA3 Controller(0x1F37)"},
{0x8086, 0x1F38, 0xFFFF, 0xFFFF, "Atom processor C2000 PCU(0x1F38)"},
{0x8086, 0x1F39, 0xFFFF, 0xFFFF, "Atom processor C2000 PCU(0x1F39)"},
{0x8086, 0x1F3A, 0xFFFF, 0xFFFF, "Atom processor C2000 PCU(0x1F3A)"},
{0x8086, 0x1F3B, 0xFFFF, 0xFFFF, "Atom processor C2000 PCU(0x1F3B)"},
{0x8086, 0x1F3C, 0xFFFF, 0xFFFF, "Atom processor C2000 PCU SMBus(0x1F3C)"},
{0x8086, 0x1F3D, 0xFFFF, 0xFFFF, "Atom Processor C2000 PECI SMBus(0x1F3D)"},
{0x8086, 0x1F3E, 0xFFFF, 0xFFFF, "Atom processor C2000 RAID SATA3 Controller(0x1F3E)"},
{0x8086, 0x1F3F, 0xFFFF, 0xFFFF, "Atom processor C2000 RAID SATA3 Controller(0x1F3F)"},
{0x8086, 0x1F40, 0xFFFF, 0xFFFF, "Ethernet Connection I354 1.0 GbE Backplane(0x1F40)"},
{0x8086, 0x1F40, 0x1028, 0x05F1, "Ethernet Connection I354 1.0 GbE Backplane(0x1028-0x05F1)"},
{0x8086, 0x1F41, 0xFFFF, 0xFFFF, "Ethernet Connection I354(0x1F41)"},
{0x8086, 0x1F42, 0xFFFF, 0xFFFF, "Atom processor C2000 GbE(0x1F42)"},
{0x8086, 0x1F44, 0xFFFF, 0xFFFF, "Atom processor C2000 GbE Virtual Function(0x1F44)"},
{0x8086, 0x1F45, 0xFFFF, 0xFFFF, "Ethernet Connection I354 2.5 GbE Backplane(0x1F45)"},
{0x8086, 0x2014, 0xFFFF, 0xFFFF, "Sky Lake-E Ubox Registers(0x2014)"},
{0x8086, 0x2015, 0xFFFF, 0xFFFF, "Sky Lake-E Ubox Registers(0x2015)"},
{0x8086, 0x2016, 0xFFFF, 0xFFFF, "Sky Lake-E Ubox Registers(0x2016)"},
{0x8086, 0x2018, 0xFFFF, 0xFFFF, "Sky Lake-E M2PCI Registers(0x2018)"},
{0x8086, 0x201A, 0xFFFF, 0xFFFF, "Sky Lake-E Non-Transparent Bridge Registers(0x201A)"},
{0x8086, 0x201C, 0xFFFF, 0xFFFF, "Sky Lake-E Non-Transparent Bridge Registers(0x201C)"},
{0x8086, 0x201D, 0xFFFF, 0xFFFF, "Volume Management Device NVMe RAID Controller(0x201D)"},
{0x8086, 0x2020, 0xFFFF, 0xFFFF, "Sky Lake-E DMI3 Registers(0x2020)"},
{0x8086, 0x2020, 0x15D9, 0x095D, "X11SPM-TF(0x15D9-0x095D)"},
{0x8086, 0x2021, 0xFFFF, 0xFFFF, "Sky Lake-E CBDMA Registers(0x2021)"},
{0x8086, 0x2024, 0xFFFF, 0xFFFF, "Sky Lake-E MM/Vt-d Configuration Registers(0x2024)"},
{0x8086, 0x2025, 0xFFFF, 0xFFFF, "Sky Lake-E RAS(0x2025)"},
{0x8086, 0x2026, 0xFFFF, 0xFFFF, "Sky Lake-E IOAPIC(0x2026)"},
{0x8086, 0x2030, 0xFFFF, 0xFFFF, "Sky Lake-E PCI Express Root Port A(0x2030)"},
{0x8086, 0x2031, 0xFFFF, 0xFFFF, "Sky Lake-E PCI Express Root Port B(0x2031)"},
{0x8086, 0x2032, 0xFFFF, 0xFFFF, "Sky Lake-E PCI Express Root Port C(0x2032)"},
{0x8086, 0x2033, 0xFFFF, 0xFFFF, "Sky Lake-E PCI Express Root Port D(0x2033)"},
{0x8086, 0x2034, 0xFFFF, 0xFFFF, "Sky Lake-E VT-d(0x2034)"},
{0x8086, 0x2035, 0xFFFF, 0xFFFF, "Sky Lake-E RAS Configuration Registers(0x2035)"},
{0x8086, 0x2036, 0xFFFF, 0xFFFF, "Sky Lake-E IOxAPIC Configuration Registers(0x2036)"},
{0x8086, 0x2040, 0xFFFF, 0xFFFF, "Sky Lake-E Integrated Memory Controller(0x2040)"},
{0x8086, 0x2041, 0xFFFF, 0xFFFF, "Sky Lake-E Integrated Memory Controller(0x2041)"},
{0x8086, 0x2042, 0xFFFF, 0xFFFF, "Sky Lake-E Integrated Memory Controller(0x2042)"},
{0x8086, 0x2043, 0xFFFF, 0xFFFF, "Sky Lake-E Integrated Memory Controller(0x2043)"},
{0x8086, 0x2044, 0xFFFF, 0xFFFF, "Sky Lake-E Integrated Memory Controller(0x2044)"},
{0x8086, 0x2045, 0xFFFF, 0xFFFF, "Sky Lake-E LM Channel 1(0x2045)"},
{0x8086, 0x2046, 0xFFFF, 0xFFFF, "Sky Lake-E LMS Channel 1(0x2046)"},
{0x8086, 0x2047, 0xFFFF, 0xFFFF, "Sky Lake-E LMDP Channel 1(0x2047)"},
{0x8086, 0x2048, 0xFFFF, 0xFFFF, "Sky Lake-E DECS Channel 2(0x2048)"},
{0x8086, 0x2049, 0xFFFF, 0xFFFF, "Sky Lake-E LM Channel 2(0x2049)"},
{0x8086, 0x204A, 0xFFFF, 0xFFFF, "Sky Lake-E LMS Channel 2(0x204A)"},
{0x8086, 0x204B, 0xFFFF, 0xFFFF, "Sky Lake-E LMDP Channel 2(0x204B)"},
{0x8086, 0x204C, 0xFFFF, 0xFFFF, "Sky Lake-E M3KTI Registers(0x204C)"},
{0x8086, 0x204D, 0xFFFF, 0xFFFF, "Sky Lake-E M3KTI Registers(0x204D)"},
{0x8086, 0x204E, 0xFFFF, 0xFFFF, "Sky Lake-E M3KTI Registers(0x204E)"},
{0x8086, 0x2054, 0xFFFF, 0xFFFF, "Sky Lake-E CHA Registers(0x2054)"},
{0x8086, 0x2055, 0xFFFF, 0xFFFF, "Sky Lake-E CHA Registers(0x2055)"},
{0x8086, 0x2056, 0xFFFF, 0xFFFF, "Sky Lake-E CHA Registers(0x2056)"},
{0x8086, 0x2057, 0xFFFF, 0xFFFF, "Sky Lake-E CHA Registers(0x2057)"},
{0x8086, 0x2058, 0xFFFF, 0xFFFF, "Sky Lake-E KTI 0(0x2058)"},
{0x8086, 0x2059, 0xFFFF, 0xFFFF, "Sky Lake-E UPI Registers(0x2059)"},
{0x8086, 0x2066, 0xFFFF, 0xFFFF, "Sky Lake-E Integrated Memory Controller(0x2066)"},
{0x8086, 0x2068, 0xFFFF, 0xFFFF, "Sky Lake-E DDRIO Registers(0x2068)"},
{0x8086, 0x2069, 0xFFFF, 0xFFFF, "Sky Lake-E DDRIO Registers(0x2069)"},
{0x8086, 0x206A, 0xFFFF, 0xFFFF, "Sky Lake-E IOxAPIC Configuration Registers(0x206A)"},
{0x8086, 0x206E, 0xFFFF, 0xFFFF, "Sky Lake-E DDRIO Registers(0x206E)"},
{0x8086, 0x206F, 0xFFFF, 0xFFFF, "Sky Lake-E DDRIO Registers(0x206F)"},
{0x8086, 0x2078, 0xFFFF, 0xFFFF, "Sky Lake-E PCU Registers(0x2078)"},
{0x8086, 0x207A, 0xFFFF, 0xFFFF, "Sky Lake-E PCU Registers(0x207A)"},
{0x8086, 0x2080, 0xFFFF, 0xFFFF, "Sky Lake-E PCU Registers(0x2080)"},
{0x8086, 0x2081, 0xFFFF, 0xFFFF, "Sky Lake-E PCU Registers(0x2081)"},
{0x8086, 0x2082, 0xFFFF, 0xFFFF, "Sky Lake-E PCU Registers(0x2082)"},
{0x8086, 0x2083, 0xFFFF, 0xFFFF, "Sky Lake-E PCU Registers(0x2083)"},
{0x8086, 0x2084, 0xFFFF, 0xFFFF, "Sky Lake-E PCU Registers(0x2084)"},
{0x8086, 0x2085, 0xFFFF, 0xFFFF, "Sky Lake-E PCU Registers(0x2085)"},
{0x8086, 0x2086, 0xFFFF, 0xFFFF, "Sky Lake-E PCU Registers(0x2086)"},
{0x8086, 0x2088, 0xFFFF, 0xFFFF, "Sky Lake-E DDRIO Registers(0x2088)"},
{0x8086, 0x208D, 0xFFFF, 0xFFFF, "Sky Lake-E CHA Registers(0x208D)"},
{0x8086, 0x208E, 0xFFFF, 0xFFFF, "Sky Lake-E CHA Registers(0x208E)"},
{0x8086, 0x2240, 0xFFFF, 0xFFFF, "Larrabee(0x2240)"},
{0x8086, 0x2241, 0xFFFF, 0xFFFF, "Larrabee(0x2241)"},
{0x8086, 0x2250, 0xFFFF, 0xFFFF, "Xeon Phi coprocessor 5100 series(0x2250)"},
{0x8086, 0x225C, 0xFFFF, 0xFFFF, "Xeon Phi coprocessor SE10/7120 series(0x225C)"},
{0x8086, 0x225D, 0xFFFF, 0xFFFF, "Xeon Phi coprocessor 3120 series(0x225D)"},
{0x8086, 0x225E, 0xFFFF, 0xFFFF, "Xeon Phi coprocessor 31S1(0x225E)"},
{0x8086, 0x2262, 0xFFFF, 0xFFFF, "Xeon Phi coprocessor 7220(0x2262)"},
{0x8086, 0x2280, 0xFFFF, 0xFFFF, "Atom/Celeron/Pentium Processor x5-E8000/J3xxx/N3xxx Series SoC Transaction Register(0x2280)"},
{0x8086, 0x2284, 0xFFFF, 0xFFFF, "Atom/Celeron/Pentium Processor x5-E8000/J3xxx/N3xxx Series High Definition Audio Controller(0x2284)"},
{0x8086, 0x2286, 0xFFFF, 0xFFFF, "Atom/Celeron/Pentium Processor x5-E8000/J3xxx/N3xxx Series LPIO1 DMA Controller(0x2286)"},
{0x8086, 0x228A, 0xFFFF, 0xFFFF, "Atom/Celeron/Pentium Processor x5-E8000/J3xxx/N3xxx Series LPIO1 HSUART Controller #1(0x228A)"},
{0x8086, 0x228C, 0xFFFF, 0xFFFF, "Atom/Celeron/Pentium Processor x5-E8000/J3xxx/N3xxx Series LPIO1 HSUART Controller #2(0x228C)"},
{0x8086, 0x2292, 0xFFFF, 0xFFFF, "Atom/Celeron/Pentium Processor x5-E8000/J3xxx/N3xxx SMBus Controller(0x2292)"},
{0x8086, 0x2294, 0xFFFF, 0xFFFF, "Atom/Celeron/Pentium Processor x5-E8000/J3xxx/N3xxx Series MMC Controller(0x2294)"},
{0x8086, 0x2295, 0xFFFF, 0xFFFF, "Atom/Celeron/Pentium Processor x5-E8000/J3xxx/N3xxx Series SDIO Controller(0x2295)"},
{0x8086, 0x2296, 0xFFFF, 0xFFFF, "Atom/Celeron/Pentium Processor x5-E8000/J3xxx/N3xxx Series SD Controller(0x2296)"},
{0x8086, 0x2298, 0xFFFF, 0xFFFF, "Atom/Celeron/Pentium Processor x5-E8000/J3xxx/N3xxx Series Trusted Execution Engine(0x2298)"},
{0x8086, 0x229C, 0xFFFF, 0xFFFF, "Atom/Celeron/Pentium Processor x5-E8000/J3xxx/N3xxx Series PCU(0x229C)"},
{0x8086, 0x22A3, 0xFFFF, 0xFFFF, "Atom/Celeron/Pentium Processor x5-E8000/J3xxx/N3xxx Series SATA Controller(0x22A3)"},
{0x8086, 0x22A4, 0xFFFF, 0xFFFF, "Atom/Celeron/Pentium Processor x5-E8000/J3xxx/N3xxx Series SATA AHCI Controller(0x22A4)"},
{0x8086, 0x22A8, 0xFFFF, 0xFFFF, "Atom/Celeron/Pentium Processor x5-E8000/J3xxx/N3xxx Series Low Power Engine Audio(0x22A8)"},
{0x8086, 0x22B0, 0xFFFF, 0xFFFF, "Atom/Celeron/Pentium Processor x5-E8000/J3xxx/N3xxx Integrated Graphics Controller(0x22B0)"},
{0x8086, 0x22B1, 0xFFFF, 0xFFFF, "Atom/Celeron/Pentium Processor x5-E8000/J3xxx/N3xxx Integrated Graphics Controller(0x22B1)"},
{0x8086, 0x22B5, 0xFFFF, 0xFFFF, "Atom/Celeron/Pentium Processor x5-E8000/J3xxx/N3xxx Series USB xHCI Controller(0x22B5)"},
{0x8086, 0x22B8, 0xFFFF, 0xFFFF, "Atom/Celeron/Pentium Processor x5-E8000/J3xxx/N3xxx Series Imaging Unit(0x22B8)"},
{0x8086, 0x22C0, 0xFFFF, 0xFFFF, "Atom/Celeron/Pentium Processor x5-E8000/J3xxx/N3xxx Series LPIO2 DMA Controller(0x22C0)"},
{0x8086, 0x22C1, 0xFFFF, 0xFFFF, "Atom/Celeron/Pentium Processor x5-E8000/J3xxx/N3xxx Series LPIO2 I2C Controller #1(0x22C1)"},
{0x8086, 0x22C2, 0xFFFF, 0xFFFF, "Atom/Celeron/Pentium Processor x5-E8000/J3xxx/N3xxx Series LPIO2 I2C Controller #2(0x22C2)"},
{0x8086, 0x22C3, 0xFFFF, 0xFFFF, "Atom/Celeron/Pentium Processor x5-E8000/J3xxx/N3xxx Series LPIO2 I2C Controller #3(0x22C3)"},
{0x8086, 0x22C4, 0xFFFF, 0xFFFF, "Atom/Celeron/Pentium Processor x5-E8000/J3xxx/N3xxx Series LPIO2 I2C Controller #4(0x22C4)"},
{0x8086, 0x22C5, 0xFFFF, 0xFFFF, "Atom/Celeron/Pentium Processor x5-E8000/J3xxx/N3xxx Series LPIO2 I2C Controller #5(0x22C5)"},
{0x8086, 0x22C6, 0xFFFF, 0xFFFF, "Atom/Celeron/Pentium Processor x5-E8000/J3xxx/N3xxx Series LPIO2 I2C Controller #6(0x22C6)"},
{0x8086, 0x22C7, 0xFFFF, 0xFFFF, "Atom/Celeron/Pentium Processor x5-E8000/J3xxx/N3xxx Series LPIO2 I2C Controller #7(0x22C7)"},
{0x8086, 0x22C8, 0xFFFF, 0xFFFF, "Atom/Celeron/Pentium Processor x5-E8000/J3xxx/N3xxx Series PCI Express Port #1(0x22C8)"},
{0x8086, 0x22CA, 0xFFFF, 0xFFFF, "Atom/Celeron/Pentium Processor x5-E8000/J3xxx/N3xxx Series PCI Express Port #2(0x22CA)"},
{0x8086, 0x22CC, 0xFFFF, 0xFFFF, "Atom/Celeron/Pentium Processor x5-E8000/J3xxx/N3xxx Series PCI Express Port #3(0x22CC)"},
{0x8086, 0x22CE, 0xFFFF, 0xFFFF, "Atom/Celeron/Pentium Processor x5-E8000/J3xxx/N3xxx Series PCI Express Port #4(0x22CE)"},
{0x8086, 0x22DC, 0xFFFF, 0xFFFF, "Atom/Celeron/Pentium Processor x5-E8000/J3xxx/N3xxx Series Power Management Controller(0x22DC)"},
{0x8086, 0x2310, 0xFFFF, 0xFFFF, "DH89xxCC LPC Controller(0x2310)"},
{0x8086, 0x2323, 0xFFFF, 0xFFFF, "DH89xxCC 4 Port SATA AHCI Controller(0x2323)"},
{0x8086, 0x2330, 0xFFFF, 0xFFFF, "DH89xxCC SMBus Controller(0x2330)"},
{0x8086, 0x2331, 0xFFFF, 0xFFFF, "DH89xxCC Chap Counter(0x2331)"},
{0x8086, 0x2332, 0xFFFF, 0xFFFF, "DH89xxCC Thermal Subsystem(0x2332)"},
{0x8086, 0x2334, 0xFFFF, 0xFFFF, "DH89xxCC USB2 Enhanced Host Controller #1(0x2334)"},
{0x8086, 0x2335, 0xFFFF, 0xFFFF, "DH89xxCC USB2 Enhanced Host Controller #1(0x2335)"},
{0x8086, 0x2342, 0xFFFF, 0xFFFF, "DH89xxCC PCI Express Root Port #1(0x2342)"},
{0x8086, 0x2343, 0xFFFF, 0xFFFF, "DH89xxCC PCI Express Root Port #1(0x2343)"},
{0x8086, 0x2344, 0xFFFF, 0xFFFF, "DH89xxCC PCI Express Root Port #2(0x2344)"},
{0x8086, 0x2345, 0xFFFF, 0xFFFF, "DH89xxCC PCI Express Root Port #2(0x2345)"},
{0x8086, 0x2346, 0xFFFF, 0xFFFF, "DH89xxCC PCI Express Root Port #3(0x2346)"},
{0x8086, 0x2347, 0xFFFF, 0xFFFF, "DH89xxCC PCI Express Root Port #3(0x2347)"},
{0x8086, 0x2348, 0xFFFF, 0xFFFF, "DH89xxCC PCI Express Root Port #4(0x2348)"},
{0x8086, 0x2349, 0xFFFF, 0xFFFF, "DH89xxCC PCI Express Root Port #4(0x2349)"},
{0x8086, 0x2360, 0xFFFF, 0xFFFF, "DH89xxCC Watchdog Timer(0x2360)"},
{0x8086, 0x2364, 0xFFFF, 0xFFFF, "DH89xxCC MEI 0(0x2364)"},
{0x8086, 0x2365, 0xFFFF, 0xFFFF, "DH89xxCC MEI 1(0x2365)"},
{0x8086, 0x2390, 0xFFFF, 0xFFFF, "DH895XCC Series LPC Controller(0x2390)"},
{0x8086, 0x23A1, 0xFFFF, 0xFFFF, "DH895XCC Series 2-Port SATA Controller [IDE Mode](0x23A1)"},
{0x8086, 0x23A3, 0xFFFF, 0xFFFF, "DH895XCC Series 4-Port SATA Controller [AHCI Mode](0x23A3)"},
{0x8086, 0x23A6, 0xFFFF, 0xFFFF, "DH895XCC Series 2-Port SATA Controller [IDE Mode](0x23A6)"},
{0x8086, 0x23B0, 0xFFFF, 0xFFFF, "DH895XCC Series SMBus Controller(0x23B0)"},
{0x8086, 0x23B1, 0xFFFF, 0xFFFF, "DH895XCC Series CHAP Counter(0x23B1)"},
{0x8086, 0x23B2, 0xFFFF, 0xFFFF, "DH895XCC Series Thermal Management Controller(0x23B2)"},
{0x8086, 0x23B4, 0xFFFF, 0xFFFF, "DH895XCC Series USB2 Enhanced Host Controller #1(0x23B4)"},
{0x8086, 0x23B5, 0xFFFF, 0xFFFF, "DH895XCC Series USB2 Enhanced Host Controller #1(0x23B5)"},
{0x8086, 0x23C2, 0xFFFF, 0xFFFF, "DH895XCC Series PCI Express Root Port #1(0x23C2)"},
{0x8086, 0x23C3, 0xFFFF, 0xFFFF, "DH895XCC Series PCI Express Root Port #1(0x23C3)"},
{0x8086, 0x23C4, 0xFFFF, 0xFFFF, "DH895XCC Series PCI Express Root Port #2(0x23C4)"},
{0x8086, 0x23C5, 0xFFFF, 0xFFFF, "DH895XCC Series PCI Express Root Port #2(0x23C5)"},
{0x8086, 0x23C6, 0xFFFF, 0xFFFF, "CDH895XCC Series PCI Express Root Port #3(0x23C6)"},
{0x8086, 0x23C7, 0xFFFF, 0xFFFF, "DH895XCC Series PCI Express Root Port #3(0x23C7)"},
{0x8086, 0x23C8, 0xFFFF, 0xFFFF, "DH895XCC Series PCI Express Root Port #4(0x23C8)"},
{0x8086, 0x23C9, 0xFFFF, 0xFFFF, "DH895XCC Series PCI Express Root Port #4(0x23C9)"},
{0x8086, 0x23E0, 0xFFFF, 0xFFFF, "DH895XCC Series Watchdog Timer(0x23E0)"},
{0x8086, 0x23E4, 0xFFFF, 0xFFFF, "DH895XCC Series MEI Controller #1(0x23E4)"},
{0x8086, 0x23E5, 0xFFFF, 0xFFFF, "DH895XCC Series MEI Controller #2(0x23E5)"},
{0x8086, 0x2410, 0xFFFF, 0xFFFF, "82801AA ISA Bridge (LPC)(0x2410)"},
{0x8086, 0x2411, 0xFFFF, 0xFFFF, "82801AA IDE Controller(0x2411)"},
{0x8086, 0x2412, 0xFFFF, 0xFFFF, "82801AA USB Controller(0x2412)"},
{0x8086, 0x2413, 0xFFFF, 0xFFFF, "82801AA SMBus Controller(0x2413)"},
{0x8086, 0x2415, 0xFFFF, 0xFFFF, "82801AA AC'97 Audio Controller(0x2415)"},
{0x8086, 0x2415, 0x1028, 0x0095, "Precision Workstation 220 Integrated Digital Audio(0x1028-0x0095)"},
{0x8086, 0x2415, 0x1028, 0x00B4, "OptiPlex GX110(0x1028-0x00B4)"},
{0x8086, 0x2415, 0x110A, 0x0051, "Activy 2xx(0x110A-0x0051)"},
{0x8086, 0x2415, 0x11D4, 0x0040, "SoundMAX Integrated Digital Audio(0x11D4-0x0040)"},
{0x8086, 0x2415, 0x11D4, 0x0048, "SoundMAX Integrated Digital Audio(0x11D4-0x0048)"},
{0x8086, 0x2415, 0x11D4, 0x5340, "SoundMAX Integrated Digital Audio(0x11D4-0x5340)"},
{0x8086, 0x2415, 0x1734, 0x1025, "Activy 3xx(0x1734-0x1025)"},
{0x8086, 0x2415, 0x1AF4, 0x1100, "QEMU Virtual Machine(0x1AF4-0x1100)"},
{0x8086, 0x2416, 0xFFFF, 0xFFFF, "82801AA AC'97 Modem Controller(0x2416)"},
{0x8086, 0x2418, 0xFFFF, 0xFFFF, "82801AA PCI Bridge(0x2418)"},
{0x8086, 0x2420, 0xFFFF, 0xFFFF, "82801AB ISA Bridge (LPC)(0x2420)"},
{0x8086, 0x2421, 0xFFFF, 0xFFFF, "82801AB IDE Controller(0x2421)"},
{0x8086, 0x2422, 0xFFFF, 0xFFFF, "82801AB USB Controller(0x2422)"},
{0x8086, 0x2423, 0xFFFF, 0xFFFF, "82801AB SMBus Controller(0x2423)"},
{0x8086, 0x2425, 0xFFFF, 0xFFFF, "82801AB AC'97 Audio Controller(0x2425)"},
{0x8086, 0x2425, 0x11D4, 0x0040, "SoundMAX Integrated Digital Audio(0x11D4-0x0040)"},
{0x8086, 0x2425, 0x11D4, 0x0048, "SoundMAX Integrated Digital Audio(0x11D4-0x0048)"},
{0x8086, 0x2426, 0xFFFF, 0xFFFF, "82801AB AC'97 Modem Controller(0x2426)"},
{0x8086, 0x2428, 0xFFFF, 0xFFFF, "82801AB PCI Bridge(0x2428)"},
{0x8086, 0x2440, 0xFFFF, 0xFFFF, "82801BA ISA Bridge (LPC)(0x2440)"},
{0x8086, 0x2440, 0x8086, 0x5744, "S845WD1-E(0x8086-0x5744)"},
{0x8086, 0x2442, 0xFFFF, 0xFFFF, "82801BA/BAM UHCI USB 1.1 Controller #1(0x2442)"},
{0x8086, 0x2442, 0x1014, 0x01C6, "Netvista A40/A40p(0x1014-0x01C6)"},
{0x8086, 0x2442, 0x1025, 0x1016, "Travelmate 612 TX(0x1025-0x1016)"},
{0x8086, 0x2442, 0x1028, 0x00C7, "Dimension 8100(0x1028-0x00C7)"},
{0x8086, 0x2442, 0x1028, 0x00D8, "Precision 530(0x1028-0x00D8)"},
{0x8086, 0x2442, 0x1028, 0x010E, "Optiplex GX240(0x1028-0x010E)"},
{0x8086, 0x2442, 0x103C, 0x126F, "e-pc 40(0x103C-0x126F)"},
{0x8086, 0x2442, 0x1043, 0x8027, "CUSL2-C/TUSL2-C Mainboard(0x1043-0x8027)"},
{0x8086, 0x2442, 0x104D, 0x80DF, "Vaio PCG-FX403(0x104D-0x80DF)"},
{0x8086, 0x2442, 0x147B, 0x0505, "BL7 motherboard(0x147B-0x0505)"},
{0x8086, 0x2442, 0x147B, 0x0507, "TH7II-RAID(0x147B-0x0507)"},
{0x8086, 0x2442, 0x8086, 0x4532, "Desktop Board D815EEA2/D815EFV(0x8086-0x4532)"},
{0x8086, 0x2442, 0x8086, 0x4557, "D815EGEW Mainboard(0x8086-0x4557)"},
{0x8086, 0x2442, 0x8086, 0x4D44, "D850EMV2 motherboard(0x8086-0x4D44)"},
{0x8086, 0x2442, 0x8086, 0x5744, "S845WD1-E mainboard(0x8086-0x5744)"},
{0x8086, 0x2443, 0xFFFF, 0xFFFF, "82801BA/BAM SMBus Controller(0x2443)"},
{0x8086, 0x2443, 0x1014, 0x01C6, "Netvista A40/A40p(0x1014-0x01C6)"},
{0x8086, 0x2443, 0x1025, 0x1016, "Travelmate 612 TX(0x1025-0x1016)"},
{0x8086, 0x2443, 0x1028, 0x00C7, "Dimension 8100(0x1028-0x00C7)"},
{0x8086, 0x2443, 0x1028, 0x00D8, "Precision 530(0x1028-0x00D8)"},
{0x8086, 0x2443, 0x1028, 0x010E, "Optiplex GX240(0x1028-0x010E)"},
{0x8086, 0x2443, 0x103C, 0x126F, "e-pc 40(0x103C-0x126F)"},
{0x8086, 0x2443, 0x1043, 0x8027, "CUSL2-C/TUSL2-C Mainboard(0x1043-0x8027)"},
{0x8086, 0x2443, 0x104D, 0x80DF, "Vaio PCG-FX403(0x104D-0x80DF)"},
{0x8086, 0x2443, 0x147B, 0x0505, "BL7 motherboard(0x147B-0x0505)"},
{0x8086, 0x2443, 0x147B, 0x0507, "TH7II-RAID(0x147B-0x0507)"},
{0x8086, 0x2443, 0x15D9, 0x3280, "Supermicro P4SBE Mainboard(0x15D9-0x3280)"},
{0x8086, 0x2443, 0x8086, 0x4532, "Desktop Board D815EEA2/D815EFV(0x8086-0x4532)"},
{0x8086, 0x2443, 0x8086, 0x4557, "D815EGEW Mainboard(0x8086-0x4557)"},
{0x8086, 0x2443, 0x8086, 0x5744, "S845WD1-E mainboard(0x8086-0x5744)"},
{0x8086, 0x2444, 0xFFFF, 0xFFFF, "82801BA/BAM UHCI USB 1.1 Controller #2(0x2444)"},
{0x8086, 0x2444, 0x1025, 0x1016, "Travelmate 612 TX(0x1025-0x1016)"},
{0x8086, 0x2444, 0x1028, 0x00C7, "Dimension 8100(0x1028-0x00C7)"},
{0x8086, 0x2444, 0x1028, 0x00D8, "Precision 530(0x1028-0x00D8)"},
{0x8086, 0x2444, 0x1028, 0x010E, "Optiplex GX240(0x1028-0x010E)"},
{0x8086, 0x2444, 0x103C, 0x126F, "e-pc 40(0x103C-0x126F)"},
{0x8086, 0x2444, 0x1043, 0x8027, "CUSL2-C/TUSL2-C Mainboard(0x1043-0x8027)"},
{0x8086, 0x2444, 0x104D, 0x80DF, "Vaio PCG-FX403(0x104D-0x80DF)"},
{0x8086, 0x2444, 0x147B, 0x0505, "BL7 motherboard(0x147B-0x0505)"},
{0x8086, 0x2444, 0x147B, 0x0507, "TH7II-RAID(0x147B-0x0507)"},
{0x8086, 0x2444, 0x8086, 0x4532, "Desktop Board D815EEA2/D815EFV(0x8086-0x4532)"},
{0x8086, 0x2444, 0x8086, 0x5744, "S845WD1-E mainboard(0x8086-0x5744)"},
{0x8086, 0x2445, 0xFFFF, 0xFFFF, "82801BA/BAM AC'97 Audio Controller(0x2445)"},
{0x8086, 0x2445, 0x0E11, 0x000B, "Compaq Deskpro EN Audio(0x0E11-0x000B)"},
{0x8086, 0x2445, 0x0E11, 0x0088, "Evo D500(0x0E11-0x0088)"},
{0x8086, 0x2445, 0x1014, 0x01C6, "Netvista A40/A40p(0x1014-0x01C6)"},
{0x8086, 0x2445, 0x1025, 0x1016, "Travelmate 612 TX(0x1025-0x1016)"},
{0x8086, 0x2445, 0x1028, 0x00D8, "Precision 530(0x1028-0x00D8)"},
{0x8086, 0x2445, 0x103C, 0x126F, "e-pc 40(0x103C-0x126F)"},
{0x8086, 0x2445, 0x104D, 0x80DF, "Vaio PCG-FX403(0x104D-0x80DF)"},
{0x8086, 0x2445, 0x11D4, 0x5340, "AD1885 AC97 codec(0x11D4-0x5340)"},
{0x8086, 0x2445, 0x1462, 0x3370, "STAC9721 AC(0x1462-0x3370)"},
{0x8086, 0x2445, 0x147B, 0x0505, "BL7 motherboard(0x147B-0x0505)"},
{0x8086, 0x2445, 0x147B, 0x0507, "TH7II-RAID(0x147B-0x0507)"},
{0x8086, 0x2445, 0x8086, 0x4557, "D815EGEW Mainboard(0x8086-0x4557)"},
{0x8086, 0x2445, 0x8086, 0x4656, "Desktop Board D815EFV(0x8086-0x4656)"},
{0x8086, 0x2445, 0x8086, 0x4D44, "D850EMV2 motherboard(0x8086-0x4D44)"},
{0x8086, 0x2446, 0xFFFF, 0xFFFF, "82801BA/BAM AC'97 Modem Controller(0x2446)"},
{0x8086, 0x2446, 0x1025, 0x1016, "Travelmate 612 TX(0x1025-0x1016)"},
{0x8086, 0x2446, 0x104D, 0x80DF, "Vaio PCG-FX403(0x104D-0x80DF)"},
{0x8086, 0x2448, 0xFFFF, 0xFFFF, "82801 Mobile PCI Bridge(0x2448)"},
{0x8086, 0x2448, 0x1028, 0x040A, "Latitude E6410(0x1028-0x040A)"},
{0x8086, 0x2448, 0x1028, 0x040B, "Latitude E6510(0x1028-0x040B)"},
{0x8086, 0x2448, 0x103C, 0x0934, "Compaq nw8240 Mobile Workstation(0x103C-0x0934)"},
{0x8086, 0x2448, 0x103C, 0x0944, "Compaq nc6220 Notebook PC(0x103C-0x0944)"},
{0x8086, 0x2448, 0x103C, 0x099C, "NX6110/NC6120(0x103C-0x099C)"},
{0x8086, 0x2448, 0x103C, 0x309F, "Compaq nx9420 Notebook(0x103C-0x309F)"},
{0x8086, 0x2448, 0x103C, 0x30A3, "Compaq nw8440(0x103C-0x30A3)"},
{0x8086, 0x2448, 0x103C, 0x30C1, "Compaq 6910p(0x103C-0x30C1)"},
{0x8086, 0x2448, 0x1043, 0x1017, "X58LE(0x1043-0x1017)"},
{0x8086, 0x2448, 0x104D, 0x902D, "VAIO VGN-NR120E(0x104D-0x902D)"},
{0x8086, 0x2448, 0x105B, 0x0D7C, "D270S/D250S Motherboard(0x105B-0x0D7C)"},
{0x8086, 0x2448, 0x1071, 0x8209, "Medion MIM 2240 Notebook PC [MD98100](0x1071-0x8209)"},
{0x8086, 0x2448, 0x144D, 0xC00C, "P30 notebook(0x144D-0xC00C)"},
{0x8086, 0x2448, 0x144D, 0xC06A, "R730 Laptop(0x144D-0xC06A)"},
{0x8086, 0x2448, 0x144D, 0xC072, "Notebook N150P(0x144D-0xC072)"},
{0x8086, 0x2448, 0x1458, 0x5000, "GA-D525TUD(0x1458-0x5000)"},
{0x8086, 0x2448, 0x1734, 0x1055, "Amilo M1420(0x1734-0x1055)"},
{0x8086, 0x2448, 0x17AA, 0x2013, "ThinkPad R60e(0x17AA-0x2013)"},
{0x8086, 0x2448, 0x17AA, 0x20AE, "ThinkPad T61/R61(0x17AA-0x20AE)"},
{0x8086, 0x2448, 0x17C0, 0x10D2, "Medion Akoya E7214 Notebook PC [MD98410](0x17C0-0x10D2)"},
{0x8086, 0x2448, 0x17C0, 0x4083, "Medion WIM 2210 Notebook PC [MD96850](0x17C0-0x4083)"},
{0x8086, 0x2448, 0x8086, 0x544B, "Desktop Board D425KT(0x8086-0x544B)"},
{0x8086, 0x2448, 0xE4BF, 0xCC47, "CCG-RUMBA(0xE4BF-0xCC47)"},
{0x8086, 0x2449, 0xFFFF, 0xFFFF, "82801BA/BAM/CA/CAM Ethernet Controller(0x2449)"},
{0x8086, 0x2449, 0x0E11, 0x0012, "EtherExpress PRO/100 VM(0x0E11-0x0012)"},
{0x8086, 0x2449, 0x0E11, 0x0091, "EtherExpress PRO/100 VE(0x0E11-0x0091)"},
{0x8086, 0x2449, 0x1014, 0x01CE, "EtherExpress PRO/100 VE(0x1014-0x01CE)"},
{0x8086, 0x2449, 0x1014, 0x01DC, "EtherExpress PRO/100 VE(0x1014-0x01DC)"},
{0x8086, 0x2449, 0x1014, 0x01EB, "EtherExpress PRO/100 VE(0x1014-0x01EB)"},
{0x8086, 0x2449, 0x1014, 0x01EC, "EtherExpress PRO/100 VE(0x1014-0x01EC)"},
{0x8086, 0x2449, 0x1014, 0x0202, "EtherExpress PRO/100 VE(0x1014-0x0202)"},
{0x8086, 0x2449, 0x1014, 0x0205, "EtherExpress PRO/100 VE(0x1014-0x0205)"},
{0x8086, 0x2449, 0x1014, 0x0217, "EtherExpress PRO/100 VE(0x1014-0x0217)"},
{0x8086, 0x2449, 0x1014, 0x0234, "EtherExpress PRO/100 VE(0x1014-0x0234)"},
{0x8086, 0x2449, 0x1014, 0x023D, "EtherExpress PRO/100 VE(0x1014-0x023D)"},
{0x8086, 0x2449, 0x1014, 0x0244, "EtherExpress PRO/100 VE(0x1014-0x0244)"},
{0x8086, 0x2449, 0x1014, 0x0245, "EtherExpress PRO/100 VE(0x1014-0x0245)"},
{0x8086, 0x2449, 0x1014, 0x0265, "PRO/100 VE Desktop Connection(0x1014-0x0265)"},
{0x8086, 0x2449, 0x1014, 0x0267, "PRO/100 VE Desktop Connection(0x1014-0x0267)"},
{0x8086, 0x2449, 0x1014, 0x026A, "PRO/100 VE Desktop Connection(0x1014-0x026A)"},
{0x8086, 0x2449, 0x109F, 0x315D, "EtherExpress PRO/100 VE(0x109F-0x315D)"},
{0x8086, 0x2449, 0x109F, 0x3181, "EtherExpress PRO/100 VE(0x109F-0x3181)"},
{0x8086, 0x2449, 0x1179, 0xFF01, "PRO/100 VE Network Connection(0x1179-0xFF01)"},
{0x8086, 0x2449, 0x1186, 0x7801, "EtherExpress PRO/100 VE(0x1186-0x7801)"},
{0x8086, 0x2449, 0x144D, 0x2602, "HomePNA 1M CNR(0x144D-0x2602)"},
{0x8086, 0x2449, 0x1AF4, 0x1100, "QEMU Virtual Machine(0x1AF4-0x1100)"},
{0x8086, 0x2449, 0x8086, 0x3010, "EtherExpress PRO/100 VE(0x8086-0x3010)"},
{0x8086, 0x2449, 0x8086, 0x3011, "EtherExpress PRO/100 VM(0x8086-0x3011)"},
{0x8086, 0x2449, 0x8086, 0x3012, "82562EH based Phoneline(0x8086-0x3012)"},
{0x8086, 0x2449, 0x8086, 0x3013, "EtherExpress PRO/100 VE(0x8086-0x3013)"},
{0x8086, 0x2449, 0x8086, 0x3014, "EtherExpress PRO/100 VM(0x8086-0x3014)"},
{0x8086, 0x2449, 0x8086, 0x3015, "82562EH based Phoneline(0x8086-0x3015)"},
{0x8086, 0x2449, 0x8086, 0x3016, "EtherExpress PRO/100 P Mobile Combo(0x8086-0x3016)"},
{0x8086, 0x2449, 0x8086, 0x3017, "EtherExpress PRO/100 P Mobile(0x8086-0x3017)"},
{0x8086, 0x2449, 0x8086, 0x3018, "EtherExpress PRO/100(0x8086-0x3018)"},
{0x8086, 0x244A, 0xFFFF, 0xFFFF, "82801BAM IDE U100 Controller(0x244A)"},
{0x8086, 0x244A, 0x1025, 0x1016, "Travelmate 612TX(0x1025-0x1016)"},
{0x8086, 0x244A, 0x104D, 0x80DF, "Vaio PCG-FX403(0x104D-0x80DF)"},
{0x8086, 0x244B, 0xFFFF, 0xFFFF, "82801BA IDE U100 Controller(0x244B)"},
{0x8086, 0x244B, 0x1014, 0x01C6, "Netvista A40/A40p(0x1014-0x01C6)"},
{0x8086, 0x244B, 0x1028, 0x00C7, "Dimension 8100(0x1028-0x00C7)"},
{0x8086, 0x244B, 0x1028, 0x00D8, "Precision 530(0x1028-0x00D8)"},
{0x8086, 0x244B, 0x1028, 0x010E, "Optiplex GX240(0x1028-0x010E)"},
{0x8086, 0x244B, 0x103C, 0x126F, "e-pc 40(0x103C-0x126F)"},
{0x8086, 0x244B, 0x1043, 0x8027, "CUSL2-C/TUSL2-C Mainboard(0x1043-0x8027)"},
{0x8086, 0x244B, 0x147B, 0x0505, "BL7 motherboard(0x147B-0x0505)"},
{0x8086, 0x244B, 0x147B, 0x0507, "TH7II-RAID(0x147B-0x0507)"},
{0x8086, 0x244B, 0x15D9, 0x3280, "Supermicro P4SBE Mainboard(0x15D9-0x3280)"},
{0x8086, 0x244B, 0x8086, 0x4532, "Desktop Board D815EEA2/D815EFV(0x8086-0x4532)"},
{0x8086, 0x244B, 0x8086, 0x4557, "D815EGEW Mainboard(0x8086-0x4557)"},
{0x8086, 0x244B, 0x8086, 0x4D44, "D850EMV2 motherboard(0x8086-0x4D44)"},
{0x8086, 0x244B, 0x8086, 0x5744, "S845WD1-E mainboard(0x8086-0x5744)"},
{0x8086, 0x244C, 0xFFFF, 0xFFFF, "82801BAM ISA Bridge (LPC)(0x244C)"},
{0x8086, 0x244E, 0xFFFF, 0xFFFF, "82801 PCI Bridge(0x244E)"},
{0x8086, 0x244E, 0x1014, 0x0267, "NetVista A30p(0x1014-0x0267)"},
{0x8086, 0x244E, 0x1028, 0x020D, "Inspiron 530(0x1028-0x020D)"},
{0x8086, 0x244E, 0x1028, 0x0211, "Optiplex 755(0x1028-0x0211)"},
{0x8086, 0x244E, 0x1028, 0x02DA, "OptiPlex 980(0x1028-0x02DA)"},
{0x8086, 0x244E, 0x1028, 0x04F7, "PowerEdge R320 server(0x1028-0x04F7)"},
{0x8086, 0x244E, 0x103C, 0x130A, "Z600 Workstation(0x103C-0x130A)"},
{0x8086, 0x244E, 0x103C, 0x2A3B, "Pavilion A1512X(0x103C-0x2A3B)"},
{0x8086, 0x244E, 0x103C, 0x2A6F, "Asus IPIBL-LB Motherboard(0x103C-0x2A6F)"},
{0x8086, 0x244E, 0x103C, 0x31FE, "ProLiant DL140 G3(0x103C-0x31FE)"},
{0x8086, 0x244E, 0x103C, 0x330B, "ProLiant ML150 G6 Server(0x103C-0x330B)"},
{0x8086, 0x244E, 0x1043, 0x81EC, "P5B Motherboard(0x1043-0x81EC)"},
{0x8086, 0x244E, 0x1043, 0x8277, "P5K PRO Motherboard(0x1043-0x8277)"},
{0x8086, 0x244E, 0x1043, 0x844D, "P8 series motherboard(0x1043-0x844D)"},
{0x8086, 0x244E, 0x1043, 0x8534, "ASUS B85-PLUS(0x1043-0x8534)"},
{0x8086, 0x244E, 0x1458, 0x5000, "Motherboard(0x1458-0x5000)"},
{0x8086, 0x244E, 0x1462, 0x7345, "MS-7345 Motherboard: Intel 82801I/IR [ICH9/ICH9R](0x1462-0x7345)"},
{0x8086, 0x244E, 0x1462, 0x7418, "Wind PC MS-7418(0x1462-0x7418)"},
{0x8086, 0x244E, 0x15D9, 0x060D, "C7SIM-Q Motherboard(0x15D9-0x060D)"},
{0x8086, 0x244E, 0x15D9, 0x9680, "X7DBN Motherboard(0x15D9-0x9680)"},
{0x8086, 0x244E, 0x1734, 0x11D6, "B75 [Ivy Bridge] chipset on Esprimo P510 D3171 motherboard(0x1734-0x11D6)"},
{0x8086, 0x244E, 0x1775, 0x11CC, "CC11/CL11(0x1775-0x11CC)"},
{0x8086, 0x244E, 0x17AA, 0x3070, "ThinkCentre M91p(0x17AA-0x3070)"},
{0x8086, 0x244E, 0x8086, 0x7270, "Server Board S1200BTS(0x8086-0x7270)"},
{0x8086, 0x2450, 0xFFFF, 0xFFFF, "82801E ISA Bridge (LPC)(0x2450)"},
{0x8086, 0x2452, 0xFFFF, 0xFFFF, "82801E USB Controller(0x2452)"},
{0x8086, 0x2453, 0xFFFF, 0xFFFF, "82801E SMBus Controller(0x2453)"},
{0x8086, 0x2459, 0xFFFF, 0xFFFF, "82801E Ethernet Controller 0(0x2459)"},
{0x8086, 0x245B, 0xFFFF, 0xFFFF, "82801E IDE U100 Controller(0x245B)"},
{0x8086, 0x245D, 0xFFFF, 0xFFFF, "82801E Ethernet Controller 1(0x245D)"},
{0x8086, 0x245E, 0xFFFF, 0xFFFF, "82801E PCI Bridge(0x245E)"},
{0x8086, 0x2480, 0xFFFF, 0xFFFF, "82801CA LPC Interface Controller(0x2480)"},
{0x8086, 0x2482, 0xFFFF, 0xFFFF, "82801CA/CAM USB Controller #1(0x2482)"},
{0x8086, 0x2482, 0x0E11, 0x0030, "Evo N600c(0x0E11-0x0030)"},
{0x8086, 0x2482, 0x1014, 0x0220, "ThinkPad A/T/X Series(0x1014-0x0220)"},
{0x8086, 0x2482, 0x104D, 0x80E7, "VAIO PCG-GR214EP/GR214MP/GR215MP/GR314MP/GR315MP(0x104D-0x80E7)"},
{0x8086, 0x2482, 0x15D9, 0x3480, "P4DP6(0x15D9-0x3480)"},
{0x8086, 0x2482, 0x8086, 0x1958, "vpr Matrix 170B4(0x8086-0x1958)"},
{0x8086, 0x2482, 0x8086, 0x3424, "SE7501HG2 Mainboard(0x8086-0x3424)"},
{0x8086, 0x2482, 0x8086, 0x4541, "Latitude C640(0x8086-0x4541)"},
{0x8086, 0x2483, 0xFFFF, 0xFFFF, "82801CA/CAM SMBus Controller(0x2483)"},
{0x8086, 0x2483, 0x1014, 0x0220, "ThinkPad A/T/X Series(0x1014-0x0220)"},
{0x8086, 0x2483, 0x104D, 0x80E7, "VAIO PCG-GR214EP/GR214MP/GR215MP/GR314MP/GR315MP(0x104D-0x80E7)"},
{0x8086, 0x2483, 0x15D9, 0x3480, "P4DP6(0x15D9-0x3480)"},
{0x8086, 0x2483, 0x8086, 0x1958, "vpr Matrix 170B4(0x8086-0x1958)"},
{0x8086, 0x2484, 0xFFFF, 0xFFFF, "82801CA/CAM USB Controller #2(0x2484)"},
{0x8086, 0x2484, 0x0E11, 0x0030, "Evo N600c(0x0E11-0x0030)"},
{0x8086, 0x2484, 0x1014, 0x0220, "ThinkPad A/T/X Series(0x1014-0x0220)"},
{0x8086, 0x2484, 0x104D, 0x80E7, "VAIO PCG-GR214EP/GR214MP/GR215MP/GR314MP/GR315MP(0x104D-0x80E7)"},
{0x8086, 0x2484, 0x15D9, 0x3480, "P4DP6(0x15D9-0x3480)"},
{0x8086, 0x2484, 0x8086, 0x1958, "vpr Matrix 170B4(0x8086-0x1958)"},
{0x8086, 0x2485, 0xFFFF, 0xFFFF, "82801CA/CAM AC'97 Audio Controller(0x2485)"},
{0x8086, 0x2485, 0x1013, 0x5959, "Crystal WMD Audio Codec(0x1013-0x5959)"},
{0x8086, 0x2485, 0x1014, 0x0222, "ThinkPad A30/A30p/T23(0x1014-0x0222)"},
{0x8086, 0x2485, 0x1014, 0x0508, "ThinkPad T30(0x1014-0x0508)"},
{0x8086, 0x2485, 0x1014, 0x051C, "ThinkPad A/T/X Series(0x1014-0x051C)"},
{0x8086, 0x2485, 0x1043, 0x1583, "L3C (SPDIF)(0x1043-0x1583)"},
{0x8086, 0x2485, 0x1043, 0x1623, "L2B (no SPDIF)(0x1043-0x1623)"},
{0x8086, 0x2485, 0x1043, 0x1643, "L3F(0x1043-0x1643)"},
{0x8086, 0x2485, 0x104D, 0x80E7, "VAIO PCG-GR214EP/GR214MP/GR215MP/GR314MP/GR315MP(0x104D-0x80E7)"},
{0x8086, 0x2485, 0x144D, 0xC006, "vpr Matrix 170B4(0x144D-0xC006)"},
{0x8086, 0x2486, 0xFFFF, 0xFFFF, "82801CA/CAM AC'97 Modem Controller(0x2486)"},
{0x8086, 0x2486, 0x1014, 0x0223, "ThinkPad A/T/X Series(0x1014-0x0223)"},
{0x8086, 0x2486, 0x1014, 0x0503, "ThinkPad R31(0x1014-0x0503)"},
{0x8086, 0x2486, 0x1014, 0x051A, "ThinkPad A/T/X Series(0x1014-0x051A)"},
{0x8086, 0x2486, 0x101F, 0x1025, "620 Series(0x101F-0x1025)"},
{0x8086, 0x2486, 0x1043, 0x1496, "PCtel HSP56 MR(0x1043-0x1496)"},
{0x8086, 0x2486, 0x104D, 0x80E7, "VAIO PCG-GR214EP/GR214MP/GR215MP/GR314MP/GR315MP(0x104D-0x80E7)"},
{0x8086, 0x2486, 0x134D, 0x4C21, "Dell Inspiron 2100 internal modem(0x134D-0x4C21)"},
{0x8086, 0x2486, 0x144D, 0x2115, "vpr Matrix 170B4 internal modem(0x144D-0x2115)"},
{0x8086, 0x2486, 0x14F1, 0x5421, "MD56ORD V.92 MDC Modem(0x14F1-0x5421)"},
{0x8086, 0x2487, 0xFFFF, 0xFFFF, "82801CA/CAM USB Controller #3(0x2487)"},
{0x8086, 0x2487, 0x0E11, 0x0030, "Evo N600c(0x0E11-0x0030)"},
{0x8086, 0x2487, 0x1014, 0x0220, "ThinkPad A/T/X Series(0x1014-0x0220)"},
{0x8086, 0x2487, 0x104D, 0x80E7, "VAIO PCG-GR214EP/GR214MP/GR215MP/GR314MP/GR315MP(0x104D-0x80E7)"},
{0x8086, 0x2487, 0x15D9, 0x3480, "P4DP6(0x15D9-0x3480)"},
{0x8086, 0x2487, 0x8086, 0x1958, "vpr Matrix 170B4(0x8086-0x1958)"},
{0x8086, 0x248A, 0xFFFF, 0xFFFF, "82801CAM IDE U100 Controller(0x248A)"},
{0x8086, 0x248A, 0x0E11, 0x0030, "Evo N600c(0x0E11-0x0030)"},
{0x8086, 0x248A, 0x1014, 0x0220, "ThinkPad A/T/X Series(0x1014-0x0220)"},
{0x8086, 0x248A, 0x104D, 0x80E7, "VAIO PCG-GR214EP/GR214MP/GR215MP/GR314MP/GR315MP(0x104D-0x80E7)"},
{0x8086, 0x248A, 0x8086, 0x1958, "vpr Matrix 170B4(0x8086-0x1958)"},
{0x8086, 0x248A, 0x8086, 0x4541, "Latitude C640(0x8086-0x4541)"},
{0x8086, 0x248B, 0xFFFF, 0xFFFF, "82801CA Ultra ATA Storage Controller(0x248B)"},
{0x8086, 0x248B, 0x15D9, 0x3480, "P4DP6(0x15D9-0x3480)"},
{0x8086, 0x248C, 0xFFFF, 0xFFFF, "82801CAM ISA Bridge (LPC)(0x248C)"},
{0x8086, 0x24C0, 0xFFFF, 0xFFFF, "82801DB/DBL (ICH4/ICH4-L) LPC Interface Bridge(0x24C0)"},
{0x8086, 0x24C0, 0x1014, 0x0267, "NetVista A30p(0x1014-0x0267)"},
{0x8086, 0x24C0, 0x1462, 0x5800, "845PE Max (MS-6580)(0x1462-0x5800)"},
{0x8086, 0x24C1, 0xFFFF, 0xFFFF, "82801DBL (ICH4-L) IDE Controller(0x24C1)"},
{0x8086, 0x24C2, 0xFFFF, 0xFFFF, "82801DB/DBL/DBM (ICH4/ICH4-L/ICH4-M) USB UHCI Controller #1(0x24C2)"},
{0x8086, 0x24C2, 0x1014, 0x0267, "NetVista A30p(0x1014-0x0267)"},
{0x8086, 0x24C2, 0x1014, 0x052D, "ThinkPad(0x1014-0x052D)"},
{0x8086, 0x24C2, 0x1025, 0x005A, "TravelMate 290(0x1025-0x005A)"},
{0x8086, 0x24C2, 0x1025, 0x0064, "Extensa 3000 series laptop: Intel 82801DBM (ICH4-M)(0x1025-0x0064)"},
{0x8086, 0x24C2, 0x1028, 0x0126, "Optiplex GX260(0x1028-0x0126)"},
{0x8086, 0x24C2, 0x1028, 0x0160, "Dimension 2400(0x1028-0x0160)"},
{0x8086, 0x24C2, 0x1028, 0x0163, "Latitude D505(0x1028-0x0163)"},
{0x8086, 0x24C2, 0x1028, 0x018D, "Inspiron 700m/710m(0x1028-0x018D)"},
{0x8086, 0x24C2, 0x1028, 0x0196, "Inspiron 5160(0x1028-0x0196)"},
{0x8086, 0x24C2, 0x103C, 0x088C, "NC8000 laptop(0x103C-0x088C)"},
{0x8086, 0x24C2, 0x103C, 0x0890, "NC6000 laptop(0x103C-0x0890)"},
{0x8086, 0x24C2, 0x103C, 0x08B0, "tc1100 tablet(0x103C-0x08B0)"},
{0x8086, 0x24C2, 0x1043, 0x8089, "P4B533(0x1043-0x8089)"},
{0x8086, 0x24C2, 0x1071, 0x8160, "MIM2000(0x1071-0x8160)"},
{0x8086, 0x24C2, 0x114A, 0x0582, "PC8 onboard USB 1.x(0x114A-0x0582)"},
{0x8086, 0x24C2, 0x144D, 0xC005, "X10 Laptop(0x144D-0xC005)"},
{0x8086, 0x24C2, 0x144D, 0xC00C, "P30/P35 notebook(0x144D-0xC00C)"},
{0x8086, 0x24C2, 0x1462, 0x5800, "845PE Max (MS-6580)(0x1462-0x5800)"},
{0x8086, 0x24C2, 0x1509, 0x2990, "Averatec 5110H laptop(0x1509-0x2990)"},
{0x8086, 0x24C2, 0x1734, 0x1004, "D1451 Mainboard (SCENIC N300, i845GV)(0x1734-0x1004)"},
{0x8086, 0x24C2, 0x1734, 0x1055, "Amilo M1420(0x1734-0x1055)"},
{0x8086, 0x24C2, 0x4C53, 0x1090, "Cx9 / Vx9 mainboard(0x4C53-0x1090)"},
{0x8086, 0x24C2, 0x8086, 0x24C2, "Latitude X300(0x8086-0x24C2)"},
{0x8086, 0x24C2, 0x8086, 0x4541, "Latitude D400/D500(0x8086-0x4541)"},
{0x8086, 0x24C2, 0xE4BF, 0x0CC9, "CC9-SAMBA(0xE4BF-0x0CC9)"},
{0x8086, 0x24C2, 0xE4BF, 0x0CD2, "CD2-BEBOP(0xE4BF-0x0CD2)"},
{0x8086, 0x24C3, 0xFFFF, 0xFFFF, "82801DB/DBL/DBM (ICH4/ICH4-L/ICH4-M) SMBus Controller(0x24C3)"},
{0x8086, 0x24C3, 0x1014, 0x0267, "NetVista A30p(0x1014-0x0267)"},
{0x8086, 0x24C3, 0x1014, 0x052D, "ThinkPad(0x1014-0x052D)"},
{0x8086, 0x24C3, 0x1025, 0x005A, "TravelMate 290(0x1025-0x005A)"},
{0x8086, 0x24C3, 0x1025, 0x0064, "Extensa 3000 series laptop: Intel 82801DBM (ICH4-M)(0x1025-0x0064)"},
{0x8086, 0x24C3, 0x1028, 0x0126, "Optiplex GX260(0x1028-0x0126)"},
{0x8086, 0x24C3, 0x1028, 0x014F, "Latitude X300(0x1028-0x014F)"},
{0x8086, 0x24C3, 0x1028, 0x0160, "Dimension 2400(0x1028-0x0160)"},
{0x8086, 0x24C3, 0x1028, 0x018D, "Inspiron 700m/710m(0x1028-0x018D)"},
{0x8086, 0x24C3, 0x103C, 0x088C, "NC8000 laptop(0x103C-0x088C)"},
{0x8086, 0x24C3, 0x103C, 0x0890, "NC6000 laptop(0x103C-0x0890)"},
{0x8086, 0x24C3, 0x103C, 0x08B0, "tc1100 tablet(0x103C-0x08B0)"},
{0x8086, 0x24C3, 0x1071, 0x8160, "MIM2000(0x1071-0x8160)"},
{0x8086, 0x24C3, 0x114A, 0x0582, "PC8 onboard SMbus(0x114A-0x0582)"},
{0x8086, 0x24C3, 0x144D, 0xC005, "X10 Laptop(0x144D-0xC005)"},
{0x8086, 0x24C3, 0x144D, 0xC00C, "P30/P35 notebook(0x144D-0xC00C)"},
{0x8086, 0x24C3, 0x1458, 0x24C2, "GA-8PE667 Ultra(0x1458-0x24C2)"},
{0x8086, 0x24C3, 0x1462, 0x5800, "845PE Max (MS-6580)(0x1462-0x5800)"},
{0x8086, 0x24C3, 0x1734, 0x1004, "D1451 Mainboard (SCENIC N300, i845GV)(0x1734-0x1004)"},
{0x8086, 0x24C3, 0x1734, 0x1055, "Amilo M1420(0x1734-0x1055)"},
{0x8086, 0x24C3, 0x4C53, 0x1090, "Cx9 / Vx9 mainboard(0x4C53-0x1090)"},
{0x8086, 0x24C3, 0xE4BF, 0x0CC9, "CC9-SAMBA(0xE4BF-0x0CC9)"},
{0x8086, 0x24C3, 0xE4BF, 0x0CD2, "CD2-BEBOP(0xE4BF-0x0CD2)"},
{0x8086, 0x24C4, 0xFFFF, 0xFFFF, "82801DB/DBL/DBM (ICH4/ICH4-L/ICH4-M) USB UHCI Controller #2(0x24C4)"},
{0x8086, 0x24C4, 0x1014, 0x0267, "NetVista A30p(0x1014-0x0267)"},
{0x8086, 0x24C4, 0x1014, 0x052D, "ThinkPad(0x1014-0x052D)"},
{0x8086, 0x24C4, 0x1025, 0x005A, "TravelMate 290(0x1025-0x005A)"},
{0x8086, 0x24C4, 0x1025, 0x0064, "Extensa 3000 series laptop: Intel 82801DBM (ICH4-M)(0x1025-0x0064)"},
{0x8086, 0x24C4, 0x1028, 0x0126, "Optiplex GX260(0x1028-0x0126)"},
{0x8086, 0x24C4, 0x1028, 0x0160, "Dimension 2400(0x1028-0x0160)"},
{0x8086, 0x24C4, 0x1028, 0x0163, "Latitude D505(0x1028-0x0163)"},
{0x8086, 0x24C4, 0x1028, 0x018D, "Inspiron 700m/710m(0x1028-0x018D)"},
{0x8086, 0x24C4, 0x1028, 0x0196, "Inspiron 5160(0x1028-0x0196)"},
{0x8086, 0x24C4, 0x103C, 0x088C, "NC8000 laptop(0x103C-0x088C)"},
{0x8086, 0x24C4, 0x103C, 0x0890, "NC6000 laptop(0x103C-0x0890)"},
{0x8086, 0x24C4, 0x103C, 0x08B0, "tc1100 tablet(0x103C-0x08B0)"},
{0x8086, 0x24C4, 0x1043, 0x8089, "P4B533(0x1043-0x8089)"},
{0x8086, 0x24C4, 0x1071, 0x8160, "MIM2000(0x1071-0x8160)"},
{0x8086, 0x24C4, 0x144D, 0xC00C, "P30/P35 notebook(0x144D-0xC00C)"},
{0x8086, 0x24C4, 0x1462, 0x5800, "845PE Max (MS-6580)(0x1462-0x5800)"},
{0x8086, 0x24C4, 0x1509, 0x2990, "Averatec 5110H(0x1509-0x2990)"},
{0x8086, 0x24C4, 0x1734, 0x1004, "D1451 Mainboard (SCENIC N300, i845GV)(0x1734-0x1004)"},
{0x8086, 0x24C4, 0x4C53, 0x1090, "Cx9 / Vx9 mainboard(0x4C53-0x1090)"},
{0x8086, 0x24C4, 0x8086, 0x24C2, "Latitude X300(0x8086-0x24C2)"},
{0x8086, 0x24C4, 0x8086, 0x4541, "Latitude D400/D500(0x8086-0x4541)"},
{0x8086, 0x24C4, 0xE4BF, 0x0CC9, "CC9-SAMBA(0xE4BF-0x0CC9)"},
{0x8086, 0x24C4, 0xE4BF, 0x0CD2, "CD2-BEBOP(0xE4BF-0x0CD2)"},
{0x8086, 0x24C5, 0xFFFF, 0xFFFF, "82801DB/DBL/DBM (ICH4/ICH4-L/ICH4-M) AC'97 Audio Controller(0x24C5)"},
{0x8086, 0x24C5, 0x0E11, 0x00B8, "Analog Devices Inc. codec [SoundMAX](0x0E11-0x00B8)"},
{0x8086, 0x24C5, 0x1014, 0x0267, "NetVista A30p(0x1014-0x0267)"},
{0x8086, 0x24C5, 0x1014, 0x0537, "ThinkPad T4x Series(0x1014-0x0537)"},
{0x8086, 0x24C5, 0x1014, 0x055F, "Thinkpad R50e model 1634(0x1014-0x055F)"},
{0x8086, 0x24C5, 0x1025, 0x005A, "TravelMate 290(0x1025-0x005A)"},
{0x8086, 0x24C5, 0x1025, 0x0064, "Extensa 3000 series laptop: Intel 82801DBM (ICH4-M)(0x1025-0x0064)"},
{0x8086, 0x24C5, 0x1028, 0x0139, "Latitude D400(0x1028-0x0139)"},
{0x8086, 0x24C5, 0x1028, 0x014F, "Latitude X300(0x1028-0x014F)"},
{0x8086, 0x24C5, 0x1028, 0x0152, "Latitude D500(0x1028-0x0152)"},
{0x8086, 0x24C5, 0x1028, 0x0160, "Dimension 2400(0x1028-0x0160)"},
{0x8086, 0x24C5, 0x1028, 0x0163, "Latitude D505(0x1028-0x0163)"},
{0x8086, 0x24C5, 0x1028, 0x018D, "Inspiron 700m/710m [SigmaTel STAC9750,51](0x1028-0x018D)"},
{0x8086, 0x24C5, 0x1028, 0x0196, "Inspiron 5160(0x1028-0x0196)"},
{0x8086, 0x24C5, 0x103C, 0x088C, "NC8000 laptop(0x103C-0x088C)"},
{0x8086, 0x24C5, 0x103C, 0x0890, "NC6000 laptop(0x103C-0x0890)"},
{0x8086, 0x24C5, 0x103C, 0x08B0, "tc1100 tablet(0x103C-0x08B0)"},
{0x8086, 0x24C5, 0x1043, 0x1713, "M2400N/M6800N laptop(0x1043-0x1713)"},
{0x8086, 0x24C5, 0x1043, 0x80B0, "P4B533(0x1043-0x80B0)"},
{0x8086, 0x24C5, 0x1071, 0x8160, "MIM2000(0x1071-0x8160)"},
{0x8086, 0x24C5, 0x1179, 0x0201, "Toshiba Tecra M1(0x1179-0x0201)"},
{0x8086, 0x24C5, 0x144D, 0xC005, "X10 Laptop(0x144D-0xC005)"},
{0x8086, 0x24C5, 0x144D, 0xC00C, "P30/P35 notebook(0x144D-0xC00C)"},
{0x8086, 0x24C5, 0x1458, 0xA002, "GA-8PE667 Ultra(0x1458-0xA002)"},
{0x8086, 0x24C5, 0x1462, 0x5800, "845PE Max (MS-6580)(0x1462-0x5800)"},
{0x8086, 0x24C5, 0x1734, 0x1005, "D1451 (SCENIC N300, i845GV) Sigmatel STAC9750T(0x1734-0x1005)"},
{0x8086, 0x24C5, 0x1734, 0x1055, "Amilo M1420(0x1734-0x1055)"},
{0x8086, 0x24C6, 0xFFFF, 0xFFFF, "82801DB/DBL/DBM (ICH4/ICH4-L/ICH4-M) AC'97 Modem Controller(0x24C6)"},
{0x8086, 0x24C6, 0x1014, 0x0524, "ThinkPad T4x Series(0x1014-0x0524)"},
{0x8086, 0x24C6, 0x1014, 0x0525, "ThinkPad(0x1014-0x0525)"},
{0x8086, 0x24C6, 0x1014, 0x0559, "ThinkPad R50e(0x1014-0x0559)"},
{0x8086, 0x24C6, 0x1025, 0x003C, "Aspire 2001WLCi (Compal CL50 motherboard) implementation(0x1025-0x003C)"},
{0x8086, 0x24C6, 0x1025, 0x005A, "TravelMate 290(0x1025-0x005A)"},
{0x8086, 0x24C6, 0x1025, 0x0064, "Extensa 3000 series laptop: Intel 82801DBM (ICH4-M)(0x1025-0x0064)"},
{0x8086, 0x24C6, 0x1028, 0x0196, "Inspiron 5160(0x1028-0x0196)"},
{0x8086, 0x24C6, 0x103C, 0x088C, "NC8000 laptop(0x103C-0x088C)"},
{0x8086, 0x24C6, 0x103C, 0x0890, "NC6000 laptop(0x103C-0x0890)"},
{0x8086, 0x24C6, 0x103C, 0x08B0, "tc1100 tablet(0x103C-0x08B0)"},
{0x8086, 0x24C6, 0x1043, 0x1716, "M2400N laptop(0x1043-0x1716)"},
{0x8086, 0x24C6, 0x1043, 0x1826, "M6800N(0x1043-0x1826)"},
{0x8086, 0x24C6, 0x1071, 0x8160, "MIM2000(0x1071-0x8160)"},
{0x8086, 0x24C6, 0x134D, 0x4C21, "Latitude D500(0x134D-0x4C21)"},
{0x8086, 0x24C6, 0x144D, 0x2115, "X10 Laptop(0x144D-0x2115)"},
{0x8086, 0x24C6, 0x144D, 0xC00C, "P30/P35 notebook(0x144D-0xC00C)"},
{0x8086, 0x24C6, 0x14F1, 0x5422, "D480 MDC V.9x Modem(0x14F1-0x5422)"},
{0x8086, 0x24C7, 0xFFFF, 0xFFFF, "82801DB/DBL/DBM (ICH4/ICH4-L/ICH4-M) USB UHCI Controller #3(0x24C7)"},
{0x8086, 0x24C7, 0x1014, 0x0267, "NetVista A30p(0x1014-0x0267)"},
{0x8086, 0x24C7, 0x1014, 0x052D, "ThinkPad(0x1014-0x052D)"},
{0x8086, 0x24C7, 0x1025, 0x005A, "TravelMate 290(0x1025-0x005A)"},
{0x8086, 0x24C7, 0x1025, 0x0064, "Extensa 3000 series laptop: Intel 82801DBM (ICH4-M)(0x1025-0x0064)"},
{0x8086, 0x24C7, 0x1028, 0x0126, "Optiplex GX260(0x1028-0x0126)"},
{0x8086, 0x24C7, 0x1028, 0x0160, "Dimension 2400(0x1028-0x0160)"},
{0x8086, 0x24C7, 0x1028, 0x0163, "Latitude D505(0x1028-0x0163)"},
{0x8086, 0x24C7, 0x1028, 0x018D, "Inspiron 700m/710m(0x1028-0x018D)"},
{0x8086, 0x24C7, 0x1028, 0x0196, "Inspiron 5160(0x1028-0x0196)"},
{0x8086, 0x24C7, 0x103C, 0x088C, "NC8000 laptop(0x103C-0x088C)"},
{0x8086, 0x24C7, 0x103C, 0x0890, "NC6000 laptop(0x103C-0x0890)"},
{0x8086, 0x24C7, 0x103C, 0x08B0, "tc1100 tablet(0x103C-0x08B0)"},
{0x8086, 0x24C7, 0x1043, 0x8089, "P4B533(0x1043-0x8089)"},
{0x8086, 0x24C7, 0x1071, 0x8160, "MIM2000(0x1071-0x8160)"},
{0x8086, 0x24C7, 0x144D, 0xC00C, "P30/P35 notebook(0x144D-0xC00C)"},
{0x8086, 0x24C7, 0x1462, 0x5800, "845PE Max (MS-6580)(0x1462-0x5800)"},
{0x8086, 0x24C7, 0x1509, 0x2990, "Averatec 5110H(0x1509-0x2990)"},
{0x8086, 0x24C7, 0x1734, 0x1004, "D1451 Mainboard (SCENIC N300, i845GV)(0x1734-0x1004)"},
{0x8086, 0x24C7, 0x4C53, 0x1090, "Cx9 / Vx9 mainboard(0x4C53-0x1090)"},
{0x8086, 0x24C7, 0x8086, 0x24C2, "Latitude X300(0x8086-0x24C2)"},
{0x8086, 0x24C7, 0x8086, 0x4541, "Latitude D400/D500(0x8086-0x4541)"},
{0x8086, 0x24C7, 0xE4BF, 0x0CC9, "CC9-SAMBA(0xE4BF-0x0CC9)"},
{0x8086, 0x24C7, 0xE4BF, 0x0CD2, "CD2-BEBOP(0xE4BF-0x0CD2)"},
{0x8086, 0x24CA, 0xFFFF, 0xFFFF, "82801DBM (ICH4-M) IDE Controller(0x24CA)"},
{0x8086, 0x24CA, 0x1014, 0x052D, "ThinkPad(0x1014-0x052D)"},
{0x8086, 0x24CA, 0x1025, 0x005A, "TravelMate 290(0x1025-0x005A)"},
{0x8086, 0x24CA, 0x1025, 0x0064, "Extensa 3000 series laptop: Intel 82801DBM (ICH4-M)(0x1025-0x0064)"},
{0x8086, 0x24CA, 0x1028, 0x014F, "Latitude X300(0x1028-0x014F)"},
{0x8086, 0x24CA, 0x1028, 0x0163, "Latitude D505(0x1028-0x0163)"},
{0x8086, 0x24CA, 0x1028, 0x018D, "Inspiron 700m/710m(0x1028-0x018D)"},
{0x8086, 0x24CA, 0x1028, 0x0196, "Inspiron 5160(0x1028-0x0196)"},
{0x8086, 0x24CA, 0x103C, 0x088C, "NC8000 laptop(0x103C-0x088C)"},
{0x8086, 0x24CA, 0x103C, 0x0890, "NC6000 laptop(0x103C-0x0890)"},
{0x8086, 0x24CA, 0x103C, 0x08B0, "tc1100 tablet(0x103C-0x08B0)"},
{0x8086, 0x24CA, 0x1071, 0x8160, "MIM2000(0x1071-0x8160)"},
{0x8086, 0x24CA, 0x144D, 0xC005, "X10 Laptop(0x144D-0xC005)"},
{0x8086, 0x24CA, 0x144D, 0xC00C, "P30/P35 notebook(0x144D-0xC00C)"},
{0x8086, 0x24CA, 0x1734, 0x1055, "Amilo M1420(0x1734-0x1055)"},
{0x8086, 0x24CA, 0x8086, 0x4541, "Latitude D400/D500(0x8086-0x4541)"},
{0x8086, 0x24CB, 0xFFFF, 0xFFFF, "82801DB (ICH4) IDE Controller(0x24CB)"},
{0x8086, 0x24CB, 0x1014, 0x0267, "NetVista A30p(0x1014-0x0267)"},
{0x8086, 0x24CB, 0x1028, 0x0126, "Optiplex GX260(0x1028-0x0126)"},
{0x8086, 0x24CB, 0x1028, 0x0160, "Dimension 2400(0x1028-0x0160)"},
{0x8086, 0x24CB, 0x1043, 0x8089, "P4B533(0x1043-0x8089)"},
{0x8086, 0x24CB, 0x114A, 0x0582, "PC8 onboard IDE(0x114A-0x0582)"},
{0x8086, 0x24CB, 0x1458, 0x24C2, "GA-8PE667 Ultra(0x1458-0x24C2)"},
{0x8086, 0x24CB, 0x1462, 0x5800, "845PE Max (MS-6580)(0x1462-0x5800)"},
{0x8086, 0x24CB, 0x1734, 0x1004, "D1451 Mainboard (SCENIC N300, i845GV)(0x1734-0x1004)"},
{0x8086, 0x24CB, 0x4C53, 0x1090, "Cx9 / Vx9 mainboard(0x4C53-0x1090)"},
{0x8086, 0x24CB, 0xE4BF, 0x0CC9, "CC9-SAMBA(0xE4BF-0x0CC9)"},
{0x8086, 0x24CB, 0xE4BF, 0x0CD2, "CD2-BEBOP(0xE4BF-0x0CD2)"},
{0x8086, 0x24CC, 0xFFFF, 0xFFFF, "82801DBM (ICH4-M) LPC Interface Bridge(0x24CC)"},
{0x8086, 0x24CC, 0x144D, 0xC00C, "P30 notebook(0x144D-0xC00C)"},
{0x8086, 0x24CC, 0x1734, 0x1055, "Amilo M1420(0x1734-0x1055)"},
{0x8086, 0x24CD, 0xFFFF, 0xFFFF, "82801DB/DBM (ICH4/ICH4-M) USB2 EHCI Controller(0x24CD)"},
{0x8086, 0x24CD, 0x1014, 0x0267, "NetVista A30p(0x1014-0x0267)"},
{0x8086, 0x24CD, 0x1014, 0x052E, "ThinkPad(0x1014-0x052E)"},
{0x8086, 0x24CD, 0x1025, 0x005A, "TravelMate 290(0x1025-0x005A)"},
{0x8086, 0x24CD, 0x1025, 0x0064, "Extensa 3000 series laptop: Intel 82801DBM (ICH4-M)(0x1025-0x0064)"},
{0x8086, 0x24CD, 0x1028, 0x011D, "Latitude D600(0x1028-0x011D)"},
{0x8086, 0x24CD, 0x1028, 0x0126, "Optiplex GX260(0x1028-0x0126)"},
{0x8086, 0x24CD, 0x1028, 0x0139, "Latitude D400(0x1028-0x0139)"},
{0x8086, 0x24CD, 0x1028, 0x0152, "Latitude D500(0x1028-0x0152)"},
{0x8086, 0x24CD, 0x1028, 0x0160, "Dimension 2400(0x1028-0x0160)"},
{0x8086, 0x24CD, 0x1028, 0x0163, "Latitude D505(0x1028-0x0163)"},
{0x8086, 0x24CD, 0x1028, 0x018D, "Inspiron 700m/710m(0x1028-0x018D)"},
{0x8086, 0x24CD, 0x1028, 0x0196, "Inspiron 5160(0x1028-0x0196)"},
{0x8086, 0x24CD, 0x103C, 0x088C, "NC8000 laptop(0x103C-0x088C)"},
{0x8086, 0x24CD, 0x103C, 0x0890, "NC6000 laptop(0x103C-0x0890)"},
{0x8086, 0x24CD, 0x103C, 0x08B0, "tc1100 tablet(0x103C-0x08B0)"},
{0x8086, 0x24CD, 0x1043, 0x8089, "P4B533(0x1043-0x8089)"},
{0x8086, 0x24CD, 0x1071, 0x8160, "MIM2000(0x1071-0x8160)"},
{0x8086, 0x24CD, 0x114A, 0x0582, "PC8 onboard USB 2.0(0x114A-0x0582)"},
{0x8086, 0x24CD, 0x1179, 0xFF00, "Satellite 2430(0x1179-0xFF00)"},
{0x8086, 0x24CD, 0x144D, 0xC005, "X10 Laptop(0x144D-0xC005)"},
{0x8086, 0x24CD, 0x144D, 0xC00C, "P30/P35 notebook(0x144D-0xC00C)"},
{0x8086, 0x24CD, 0x1462, 0x3981, "845PE Max (MS-6580)(0x1462-0x3981)"},
{0x8086, 0x24CD, 0x1509, 0x1968, "Averatec 5110H(0x1509-0x1968)"},
{0x8086, 0x24CD, 0x1734, 0x1004, "D1451 Mainboard (SCENIC N300, i845GV)(0x1734-0x1004)"},
{0x8086, 0x24CD, 0x1734, 0x1055, "Amilo M1420(0x1734-0x1055)"},
{0x8086, 0x24CD, 0x1AF4, 0x1100, "QEMU Virtual Machine(0x1AF4-0x1100)"},
{0x8086, 0x24CD, 0x4C53, 0x1090, "Cx9 / Vx9 mainboard(0x4C53-0x1090)"},
{0x8086, 0x24CD, 0x8086, 0x24C2, "Latitude X300(0x8086-0x24C2)"},
{0x8086, 0x24CD, 0xE4BF, 0x0CC9, "CC9-SAMBA(0xE4BF-0x0CC9)"},
{0x8086, 0x24CD, 0xE4BF, 0x0CD2, "CD2-BEBOP(0xE4BF-0x0CD2)"},
{0x8086, 0x24D0, 0xFFFF, 0xFFFF, "82801EB/ER (ICH5/ICH5R) LPC Interface Bridge(0x24D0)"},
{0x8086, 0x24D1, 0xFFFF, 0xFFFF, "82801EB (ICH5) SATA Controller(0x24D1)"},
{0x8086, 0x24D1, 0x1028, 0x0168, "Precision Workstation 670 Mainboard(0x1028-0x0168)"},
{0x8086, 0x24D1, 0x1028, 0x0169, "Precision 470(0x1028-0x0169)"},
{0x8086, 0x24D1, 0x1028, 0x019A, "PowerEdge SC1425(0x1028-0x019A)"},
{0x8086, 0x24D1, 0x103C, 0x12BC, "d530 CMT (DG746A)(0x103C-0x12BC)"},
{0x8086, 0x24D1, 0x103C, 0x3208, "ProLiant DL140 G2(0x103C-0x3208)"},
{0x8086, 0x24D1, 0x1043, 0x80A6, "P4P800 series motherboard(0x1043-0x80A6)"},
{0x8086, 0x24D1, 0x1458, 0x24D1, "GA-8IPE1000 Pro2 motherboard (865PE)(0x1458-0x24D1)"},
{0x8086, 0x24D1, 0x1462, 0x7280, "865PE Neo2 (MS-6728)(0x1462-0x7280)"},
{0x8086, 0x24D1, 0x1462, 0x7650, "Hetis 865GV-E (MS-7065)(0x1462-0x7650)"},
{0x8086, 0x24D1, 0x1565, 0x5200, "P4TSV Motherboard (865G)(0x1565-0x5200)"},
{0x8086, 0x24D1, 0x15D9, 0x4580, "P4SCE Mainboard(0x15D9-0x4580)"},
{0x8086, 0x24D1, 0x8086, 0x3427, "S875WP1-E mainboard(0x8086-0x3427)"},
{0x8086, 0x24D1, 0x8086, 0x4246, "Desktop Board D865GBF(0x8086-0x4246)"},
{0x8086, 0x24D1, 0x8086, 0x4C43, "Desktop Board D865GLC(0x8086-0x4C43)"},
{0x8086, 0x24D1, 0x8086, 0x524C, "D865PERL mainboard(0x8086-0x524C)"},
{0x8086, 0x24D2, 0xFFFF, 0xFFFF, "82801EB/ER (ICH5/ICH5R) USB UHCI Controller #1(0x24D2)"},
{0x8086, 0x24D2, 0x1014, 0x0287, "ThinkCentre S50(0x1014-0x0287)"},
{0x8086, 0x24D2, 0x1014, 0x02DD, "eServer xSeries server mainboard(0x1014-0x02DD)"},
{0x8086, 0x24D2, 0x1014, 0x02ED, "eServer xSeries server mainboard(0x1014-0x02ED)"},
{0x8086, 0x24D2, 0x1028, 0x0168, "Precision Workstation 670 Mainboard(0x1028-0x0168)"},
{0x8086, 0x24D2, 0x1028, 0x0169, "Precision 470(0x1028-0x0169)"},
{0x8086, 0x24D2, 0x1028, 0x016C, "PowerEdge 1850 onboard UHCI(0x1028-0x016C)"},
{0x8086, 0x24D2, 0x1028, 0x016D, "PowerEdge 2850 onboard UHCI(0x1028-0x016D)"},
{0x8086, 0x24D2, 0x1028, 0x0170, "PowerEdge 6850 onboard UHCI(0x1028-0x0170)"},
{0x8086, 0x24D2, 0x1028, 0x0183, "PowerEdge 1800(0x1028-0x0183)"},
{0x8086, 0x24D2, 0x1028, 0x019A, "PowerEdge SC1425(0x1028-0x019A)"},
{0x8086, 0x24D2, 0x103C, 0x006A, "NX9500(0x103C-0x006A)"},
{0x8086, 0x24D2, 0x103C, 0x12BC, "d530 CMT (DG746A)(0x103C-0x12BC)"},
{0x8086, 0x24D2, 0x103C, 0x3208, "ProLiant DL140 G2(0x103C-0x3208)"},
{0x8086, 0x24D2, 0x1043, 0x80A6, "P4P800/P5P800 series motherboard(0x1043-0x80A6)"},
{0x8086, 0x24D2, 0x1458, 0x24D2, "GA-8IPE1000/8KNXP motherboard(0x1458-0x24D2)"},
{0x8086, 0x24D2, 0x1462, 0x7280, "865PE Neo2 (MS-6728)(0x1462-0x7280)"},
{0x8086, 0x24D2, 0x1565, 0x3101, "P4TSV Motherboard (865G)(0x1565-0x3101)"},
{0x8086, 0x24D2, 0x15D9, 0x4580, "P4SCE Mainboard(0x15D9-0x4580)"},
{0x8086, 0x24D2, 0x1734, 0x101C, "PRIMERGY RX/TX series onboard UHCI(0x1734-0x101C)"},
{0x8086, 0x24D2, 0x8086, 0x3427, "S875WP1-E mainboard(0x8086-0x3427)"},
{0x8086, 0x24D2, 0x8086, 0x4246, "Desktop Board D865GBF(0x8086-0x4246)"},
{0x8086, 0x24D2, 0x8086, 0x4C43, "Desktop Board D865GLC(0x8086-0x4C43)"},
{0x8086, 0x24D2, 0x8086, 0x524C, "D865PERL mainboard(0x8086-0x524C)"},
{0x8086, 0x24D3, 0xFFFF, 0xFFFF, "82801EB/ER (ICH5/ICH5R) SMBus Controller(0x24D3)"},
{0x8086, 0x24D3, 0x1014, 0x0287, "ThinkCentre S50(0x1014-0x0287)"},
{0x8086, 0x24D3, 0x1014, 0x02DD, "eServer xSeries server mainboard(0x1014-0x02DD)"},
{0x8086, 0x24D3, 0x1014, 0x02ED, "eServer xSeries server mainboard(0x1014-0x02ED)"},
{0x8086, 0x24D3, 0x1028, 0x0156, "Precision 360(0x1028-0x0156)"},
{0x8086, 0x24D3, 0x1028, 0x0168, "Precision Workstation 670 Mainboard(0x1028-0x0168)"},
{0x8086, 0x24D3, 0x1028, 0x0169, "Precision 470(0x1028-0x0169)"},
{0x8086, 0x24D3, 0x103C, 0x12BC, "d330 uT(0x103C-0x12BC)"},
{0x8086, 0x24D3, 0x103C, 0x3208, "ProLiant DL140 G2(0x103C-0x3208)"},
{0x8086, 0x24D3, 0x1043, 0x80A6, "P4P800/P5P800 series motherboard(0x1043-0x80A6)"},
{0x8086, 0x24D3, 0x1458, 0x24D2, "GA-8IPE1000 Pro2 motherboard (865PE)(0x1458-0x24D2)"},
{0x8086, 0x24D3, 0x1462, 0x7280, "865PE Neo2 (MS-6728)(0x1462-0x7280)"},
{0x8086, 0x24D3, 0x1462, 0x7650, "Hetis 865GV-E (MS-7065)(0x1462-0x7650)"},
{0x8086, 0x24D3, 0x1565, 0x3101, "P4TSV Motherboard (865G)(0x1565-0x3101)"},
{0x8086, 0x24D3, 0x15D9, 0x4580, "P4SCE Mainboard(0x15D9-0x4580)"},
{0x8086, 0x24D3, 0x1734, 0x101C, "PRIMERGY RX/TX S2 series SMBus(0x1734-0x101C)"},
{0x8086, 0x24D3, 0x8086, 0x3427, "S875WP1-E mainboard(0x8086-0x3427)"},
{0x8086, 0x24D3, 0x8086, 0x4246, "Desktop Board D865GBF(0x8086-0x4246)"},
{0x8086, 0x24D3, 0x8086, 0x4C43, "Desktop Board D865GLC(0x8086-0x4C43)"},
{0x8086, 0x24D3, 0x8086, 0x524C, "D865PERL mainboard(0x8086-0x524C)"},
{0x8086, 0x24D4, 0xFFFF, 0xFFFF, "82801EB/ER (ICH5/ICH5R) USB UHCI Controller #2(0x24D4)"},
{0x8086, 0x24D4, 0x1014, 0x0287, "ThinkCentre S50(0x1014-0x0287)"},
{0x8086, 0x24D4, 0x1014, 0x02DD, "eServer xSeries server mainboard(0x1014-0x02DD)"},
{0x8086, 0x24D4, 0x1014, 0x02ED, "eServer xSeries server mainboard(0x1014-0x02ED)"},
{0x8086, 0x24D4, 0x1028, 0x0168, "Precision Workstation 670 Mainboard(0x1028-0x0168)"},
{0x8086, 0x24D4, 0x1028, 0x0169, "Precision 470(0x1028-0x0169)"},
{0x8086, 0x24D4, 0x1028, 0x016C, "PowerEdge 1850 onboard UHCI(0x1028-0x016C)"},
{0x8086, 0x24D4, 0x1028, 0x016D, "PowerEdge 2850 onboard UHCI(0x1028-0x016D)"},
{0x8086, 0x24D4, 0x1028, 0x0170, "PowerEdge 6850 onboard UHCI(0x1028-0x0170)"},
{0x8086, 0x24D4, 0x1028, 0x0183, "PowerEdge 1800(0x1028-0x0183)"},
{0x8086, 0x24D4, 0x1028, 0x019A, "PowerEdge SC1425(0x1028-0x019A)"},
{0x8086, 0x24D4, 0x103C, 0x006A, "NX9500(0x103C-0x006A)"},
{0x8086, 0x24D4, 0x103C, 0x12BC, "d530 CMT (DG746A)(0x103C-0x12BC)"},
{0x8086, 0x24D4, 0x103C, 0x3208, "ProLiant DL140 G2(0x103C-0x3208)"},
{0x8086, 0x24D4, 0x1043, 0x80A6, "P4P800/P5P800 series motherboard(0x1043-0x80A6)"},
{0x8086, 0x24D4, 0x1458, 0x24D2, "GA-8IPE1000 Pro2 motherboard (865PE)(0x1458-0x24D2)"},
{0x8086, 0x24D4, 0x1462, 0x7280, "865PE Neo2 (MS-6728)(0x1462-0x7280)"},
{0x8086, 0x24D4, 0x1462, 0x7650, "Hetis 865GV-E (MS-7065)(0x1462-0x7650)"},
{0x8086, 0x24D4, 0x1565, 0x3101, "P4TSV Motherboard (865G)(0x1565-0x3101)"},
{0x8086, 0x24D4, 0x15D9, 0x4580, "P4SCE Mainboard(0x15D9-0x4580)"},
{0x8086, 0x24D4, 0x1734, 0x101C, "PRIMERGY RX/TX S2 series onboard UHCI(0x1734-0x101C)"},
{0x8086, 0x24D4, 0x8086, 0x3427, "S875WP1-E mainboard(0x8086-0x3427)"},
{0x8086, 0x24D4, 0x8086, 0x4246, "Desktop Board D865GBF(0x8086-0x4246)"},
{0x8086, 0x24D4, 0x8086, 0x4C43, "Desktop Board D865GLC(0x8086-0x4C43)"},
{0x8086, 0x24D4, 0x8086, 0x524C, "D865PERL mainboard(0x8086-0x524C)"},
{0x8086, 0x24D5, 0xFFFF, 0xFFFF, "82801EB/ER (ICH5/ICH5R) AC'97 Audio Controller(0x24D5)"},
{0x8086, 0x24D5, 0x100A, 0x147B, "Abit IS7-E motherboard(0x100A-0x147B)"},
{0x8086, 0x24D5, 0x1014, 0x0287, "ThinkCentre S50(0x1014-0x0287)"},
{0x8086, 0x24D5, 0x1028, 0x0168, "Precision Workstation 670 Mainboard(0x1028-0x0168)"},
{0x8086, 0x24D5, 0x1028, 0x0169, "Precision 470(0x1028-0x0169)"},
{0x8086, 0x24D5, 0x103C, 0x006A, "NX9500(0x103C-0x006A)"},
{0x8086, 0x24D5, 0x103C, 0x12BC, "d330 uT(0x103C-0x12BC)"},
{0x8086, 0x24D5, 0x1043, 0x80F3, "P4P800 series motherboard(0x1043-0x80F3)"},
{0x8086, 0x24D5, 0x1043, 0x810F, "P5P800-MX Mainboard(0x1043-0x810F)"},
{0x8086, 0x24D5, 0x1458, 0xA002, "GA-8IPE1000/8KNXP motherboard(0x1458-0xA002)"},
{0x8086, 0x24D5, 0x1462, 0x0080, "865PE Neo2-V (MS-6788) Mainboard(0x1462-0x0080)"},
{0x8086, 0x24D5, 0x1462, 0x7280, "865PE Neo2 (MS-6728)(0x1462-0x7280)"},
{0x8086, 0x24D5, 0x1462, 0x7650, "Hetis 865GV-E (MS-7065)(0x1462-0x7650)"},
{0x8086, 0x24D5, 0x8086, 0xA000, "D865PERL mainboard(0x8086-0xA000)"},
{0x8086, 0x24D5, 0x8086, 0xE000, "D865PERL mainboard(0x8086-0xE000)"},
{0x8086, 0x24D5, 0x8086, 0xE001, "Desktop Board D865GBF(0x8086-0xE001)"},
{0x8086, 0x24D5, 0x8086, 0xE002, "SoundMax Integrated Digital Audio(0x8086-0xE002)"},
{0x8086, 0x24D6, 0xFFFF, 0xFFFF, "82801EB/ER (ICH5/ICH5R) AC'97 Modem Controller(0x24D6)"},
{0x8086, 0x24D6, 0x103C, 0x006A, "NX9500(0x103C-0x006A)"},
{0x8086, 0x24D7, 0xFFFF, 0xFFFF, "82801EB/ER (ICH5/ICH5R) USB UHCI Controller #3(0x24D7)"},
{0x8086, 0x24D7, 0x1014, 0x0287, "ThinkCentre S50(0x1014-0x0287)"},
{0x8086, 0x24D7, 0x1014, 0x02ED, "xSeries server mainboard(0x1014-0x02ED)"},
{0x8086, 0x24D7, 0x1028, 0x0168, "Precision Workstation 670 Mainboard(0x1028-0x0168)"},
{0x8086, 0x24D7, 0x1028, 0x0169, "Precision 470(0x1028-0x0169)"},
{0x8086, 0x24D7, 0x1028, 0x016C, "PowerEdge 1850 onboard UHCI(0x1028-0x016C)"},
{0x8086, 0x24D7, 0x1028, 0x016D, "PowerEdge 2850 onboard UHCI(0x1028-0x016D)"},
{0x8086, 0x24D7, 0x1028, 0x0170, "PowerEdge 6850 onboard UHCI(0x1028-0x0170)"},
{0x8086, 0x24D7, 0x1028, 0x0183, "PowerEdge 1800(0x1028-0x0183)"},
{0x8086, 0x24D7, 0x103C, 0x006A, "NX9500(0x103C-0x006A)"},
{0x8086, 0x24D7, 0x103C, 0x12BC, "d530 CMT (DG746A)(0x103C-0x12BC)"},
{0x8086, 0x24D7, 0x1043, 0x80A6, "P4P800/P5P800 series motherboard(0x1043-0x80A6)"},
{0x8086, 0x24D7, 0x1458, 0x24D2, "GA-8IPE1000 Pro2 motherboard (865PE)(0x1458-0x24D2)"},
{0x8086, 0x24D7, 0x1462, 0x7280, "865PE Neo2 (MS-6728)(0x1462-0x7280)"},
{0x8086, 0x24D7, 0x1462, 0x7650, "Hetis 865GV-E (MS-7065)(0x1462-0x7650)"},
{0x8086, 0x24D7, 0x1565, 0x3101, "P4TSV Motherboard (865G)(0x1565-0x3101)"},
{0x8086, 0x24D7, 0x15D9, 0x4580, "P4SCE Mainboard(0x15D9-0x4580)"},
{0x8086, 0x24D7, 0x1734, 0x101C, "PRIMERGY RX/TX S2 series onboard UHCI(0x1734-0x101C)"},
{0x8086, 0x24D7, 0x8086, 0x3427, "S875WP1-E mainboard(0x8086-0x3427)"},
{0x8086, 0x24D7, 0x8086, 0x4246, "Desktop Board D865GBF(0x8086-0x4246)"},
{0x8086, 0x24D7, 0x8086, 0x4C43, "Desktop Board D865GLC(0x8086-0x4C43)"},
{0x8086, 0x24D7, 0x8086, 0x524C, "D865PERL mainboard(0x8086-0x524C)"},
{0x8086, 0x24DB, 0xFFFF, 0xFFFF, "82801EB/ER (ICH5/ICH5R) IDE Controller(0x24DB)"},
{0x8086, 0x24DB, 0x1014, 0x0287, "ThinkCentre S50(0x1014-0x0287)"},
{0x8086, 0x24DB, 0x1014, 0x02DD, "eServer xSeries server mainboard(0x1014-0x02DD)"},
{0x8086, 0x24DB, 0x1014, 0x02ED, "eServer xSeries server mainboard(0x1014-0x02ED)"},
{0x8086, 0x24DB, 0x1028, 0x0168, "Precision Workstation 670 Mainboard(0x1028-0x0168)"},
{0x8086, 0x24DB, 0x1028, 0x0169, "Precision 470(0x1028-0x0169)"},
{0x8086, 0x24DB, 0x1028, 0x016C, "PowerEdge 1850 IDE Controller(0x1028-0x016C)"},
{0x8086, 0x24DB, 0x1028, 0x016D, "PowerEdge 2850 IDE Controller(0x1028-0x016D)"},
{0x8086, 0x24DB, 0x1028, 0x0170, "PowerEdge 6850 IDE Controller(0x1028-0x0170)"},
{0x8086, 0x24DB, 0x1028, 0x019A, "PowerEdge SC1425(0x1028-0x019A)"},
{0x8086, 0x24DB, 0x103C, 0x006A, "NX9500(0x103C-0x006A)"},
{0x8086, 0x24DB, 0x103C, 0x12BC, "d530 CMT (DG746A)(0x103C-0x12BC)"},
{0x8086, 0x24DB, 0x1043, 0x80A6, "P4P800/P5P800 series motherboard(0x1043-0x80A6)"},
{0x8086, 0x24DB, 0x1458, 0x24D2, "GA-8IPE1000 Pro2 motherboard (865PE)(0x1458-0x24D2)"},
{0x8086, 0x24DB, 0x1462, 0x7280, "865PE Neo2 (MS-6728)(0x1462-0x7280)"},
{0x8086, 0x24DB, 0x1462, 0x7580, "MSI 875P(0x1462-0x7580)"},
{0x8086, 0x24DB, 0x1462, 0x7650, "Hetis 865GV-E (MS-7065)(0x1462-0x7650)"},
{0x8086, 0x24DB, 0x1565, 0x3101, "P4TSV Motherboard (865G)(0x1565-0x3101)"},
{0x8086, 0x24DB, 0x15D9, 0x4580, "P4SCE Mainboard(0x15D9-0x4580)"},
{0x8086, 0x24DB, 0x1734, 0x101C, "PRIMERGY RX/TX S2 series onboard IDE(0x1734-0x101C)"},
{0x8086, 0x24DB, 0x8086, 0x24DB, "P4C800 Mainboard(0x8086-0x24DB)"},
{0x8086, 0x24DB, 0x8086, 0x3427, "S875WP1-E mainboard(0x8086-0x3427)"},
{0x8086, 0x24DB, 0x8086, 0x4246, "Desktop Board D865GBF(0x8086-0x4246)"},
{0x8086, 0x24DB, 0x8086, 0x4C43, "Desktop Board D865GLC(0x8086-0x4C43)"},
{0x8086, 0x24DB, 0x8086, 0x524C, "D865PERL mainboard(0x8086-0x524C)"},
{0x8086, 0x24DC, 0xFFFF, 0xFFFF, "82801EB (ICH5) LPC Interface Bridge(0x24DC)"},
{0x8086, 0x24DD, 0xFFFF, 0xFFFF, "82801EB/ER (ICH5/ICH5R) USB2 EHCI Controller(0x24DD)"},
{0x8086, 0x24DD, 0x1014, 0x0287, "ThinkCentre S50(0x1014-0x0287)"},
{0x8086, 0x24DD, 0x1014, 0x02DD, "eServer xSeries server mainboard(0x1014-0x02DD)"},
{0x8086, 0x24DD, 0x1014, 0x02ED, "eServer xSeries server mainboard(0x1014-0x02ED)"},
{0x8086, 0x24DD, 0x1028, 0x0168, "Precision Workstation 670 Mainboard(0x1028-0x0168)"},
{0x8086, 0x24DD, 0x1028, 0x0169, "Precision 470(0x1028-0x0169)"},
{0x8086, 0x24DD, 0x1028, 0x016C, "PowerEdge 1850 onboard EHCI(0x1028-0x016C)"},
{0x8086, 0x24DD, 0x1028, 0x016D, "PowerEdge 2850 onboard EHCI(0x1028-0x016D)"},
{0x8086, 0x24DD, 0x1028, 0x0170, "PowerEdge 6850 onboard EHCI(0x1028-0x0170)"},
{0x8086, 0x24DD, 0x1028, 0x0183, "PowerEdge 1800(0x1028-0x0183)"},
{0x8086, 0x24DD, 0x1028, 0x019A, "PowerEdge SC1425(0x1028-0x019A)"},
{0x8086, 0x24DD, 0x103C, 0x006A, "NX9500(0x103C-0x006A)"},
{0x8086, 0x24DD, 0x103C, 0x12BC, "d530 CMT (DG746A)(0x103C-0x12BC)"},
{0x8086, 0x24DD, 0x103C, 0x3208, "ProLiant DL140 G2(0x103C-0x3208)"},
{0x8086, 0x24DD, 0x1043, 0x80A6, "P4P800/P5P800 series motherboard(0x1043-0x80A6)"},
{0x8086, 0x24DD, 0x1458, 0x5006, "GA-8IPE1000 Pro2 motherboard (865PE)(0x1458-0x5006)"},
{0x8086, 0x24DD, 0x1462, 0x7280, "865PE Neo2 (MS-6728)(0x1462-0x7280)"},
{0x8086, 0x24DD, 0x1462, 0x7650, "Hetis 865GV-E (MS-7065)(0x1462-0x7650)"},
{0x8086, 0x24DD, 0x8086, 0x3427, "S875WP1-E mainboard(0x8086-0x3427)"},
{0x8086, 0x24DD, 0x8086, 0x4246, "Desktop Board D865GBF(0x8086-0x4246)"},
{0x8086, 0x24DD, 0x8086, 0x4C43, "Desktop Board D865GLC(0x8086-0x4C43)"},
{0x8086, 0x24DD, 0x8086, 0x524C, "D865PERL mainboard(0x8086-0x524C)"},
{0x8086, 0x24DE, 0xFFFF, 0xFFFF, "82801EB/ER (ICH5/ICH5R) USB UHCI Controller #4(0x24DE)"},
{0x8086, 0x24DE, 0x1014, 0x0287, "ThinkCentre S50(0x1014-0x0287)"},
{0x8086, 0x24DE, 0x1014, 0x02ED, "xSeries server mainboard(0x1014-0x02ED)"},
{0x8086, 0x24DE, 0x1028, 0x0168, "Precision Workstation 670 Mainboard(0x1028-0x0168)"},
{0x8086, 0x24DE, 0x1028, 0x0169, "Precision 470(0x1028-0x0169)"},
{0x8086, 0x24DE, 0x1043, 0x80A6, "P4P800/P5P800 series motherboard(0x1043-0x80A6)"},
{0x8086, 0x24DE, 0x1458, 0x24D2, "GA-8IPE1000 Pro2 motherboard (865PE)(0x1458-0x24D2)"},
{0x8086, 0x24DE, 0x1462, 0x7280, "865PE Neo2 (MS-6728)(0x1462-0x7280)"},
{0x8086, 0x24DE, 0x1462, 0x7650, "Hetis 865GV-E (MS-7065)(0x1462-0x7650)"},
{0x8086, 0x24DE, 0x1565, 0x3101, "P4TSV Motherboard (865G)(0x1565-0x3101)"},
{0x8086, 0x24DE, 0x15D9, 0x4580, "P4SCE Mainboard(0x15D9-0x4580)"},
{0x8086, 0x24DE, 0x1734, 0x101C, "PRIMERGY RX/TX S2 series onboard UHCI(0x1734-0x101C)"},
{0x8086, 0x24DE, 0x8086, 0x3427, "S875WP1-E mainboard(0x8086-0x3427)"},
{0x8086, 0x24DE, 0x8086, 0x4246, "Desktop Board D865GBF(0x8086-0x4246)"},
{0x8086, 0x24DE, 0x8086, 0x4C43, "Desktop Board D865GLC(0x8086-0x4C43)"},
{0x8086, 0x24DE, 0x8086, 0x524C, "D865PERL mainboard(0x8086-0x524C)"},
{0x8086, 0x24DF, 0xFFFF, 0xFFFF, "82801ER (ICH5R) SATA Controller(0x24DF)"},
{0x8086, 0x24DF, 0x1028, 0x0168, "Precision Workstation 670 Mainboard(0x1028-0x0168)"},
{0x8086, 0x24F0, 0xFFFF, 0xFFFF, "Omni-Path HFI Silicon 100 Series [discrete](0x24F0)"},
{0x8086, 0x24F0, 0x10A9, 0x802E, "Omni-path HFI 100 Series, 1-port A-board(0x10A9-0x802E)"},
{0x8086, 0x24F0, 0x10A9, 0x802F, "Omni-path HFI 100 Series, 2-port A-board(0x10A9-0x802F)"},
{0x8086, 0x24F0, 0x10A9, 0x8030, "Omni-path HFI 100 Series, 1-port B-board(0x10A9-0x8030)"},
{0x8086, 0x24F0, 0x10A9, 0x8031, "Omni-path HFI 100 Series, 2-port B-board(0x10A9-0x8031)"},
{0x8086, 0x24F0, 0x1590, 0x00E7, "100Gb 1-port OP101 QSFP28 x8 PCIe Gen3 with Intel Omni-Path Adapter(0x1590-0x00E7)"},
{0x8086, 0x24F0, 0x1590, 0x00E8, "100Gb 1-port OP101 QSFP28 x16 PCIe Gen3 with Intel Omni-Path Adapter(0x1590-0x00E8)"},
{0x8086, 0x24F0, 0x1590, 0x021C, "Apollo 100Gb 1-port Intel Omni-Path Architecture 860z Mezzanine FIO Adapter(0x1590-0x021C)"},
{0x8086, 0x24F0, 0x15D9, 0x0934, "Omni-Path HFI Adapter 100 Series, 1 Port, PCIe x16, SIOM Module(0x15D9-0x0934)"},
{0x8086, 0x24F0, 0x15D9, 0x099B, "Omni-path HFI Mezz AOC, 1 Port, PCIe x16.(0x15D9-0x099B)"},
{0x8086, 0x24F0, 0x1CB8, 0x0001, "Omni-Path HFI Adapter 100 Series, 1 Port, PCIe x16, TC4600 QSFP28(0x1CB8-0x0001)"},
{0x8086, 0x24F0, 0x1CB8, 0x0002, "Omni-Path HFI Adapter 100 Series, 1 Port, PCIe x16, TC6600 Fixed Port(0x1CB8-0x0002)"},
{0x8086, 0x24F0, 0x1CB8, 0x0003, "Omni-Path HFI Adapter 100 Series, 2 Port, 2 PCIe x16, Earth Simulation QSFP28(0x1CB8-0x0003)"},
{0x8086, 0x24F0, 0x1CB8, 0x0004, "Omni-Path HFI Adapter 100 Series, 1 Port, PCIe x16, TC4600E QSFP28(0x1CB8-0x0004)"},
{0x8086, 0x24F0, 0x434E, 0x0001, "Omni-Path HFI Adapter 100 Series, 1 Port, OCP 3.0(0x434E-0x0001)"},
{0x8086, 0x24F0, 0x434E, 0x2628, "Omni-Path HFI Adapter 100 Series, 1 Port, PCIe x16(0x434E-0x2628)"},
{0x8086, 0x24F0, 0x8086, 0x2628, "Omni-Path HFI Adapter 100 Series, 1 Port, PCIe x16(0x8086-0x2628)"},
{0x8086, 0x24F0, 0x8086, 0x2629, "Omni-Path HFI Adapter 100 Series, 1 Port, PCIe x8(0x8086-0x2629)"},
{0x8086, 0x24F0, 0x8086, 0x262A, "Omni-Path HFI Adapter 100 Series, 2 Ports, Split PCIe x16(0x8086-0x262A)"},
{0x8086, 0x24F0, 0x8086, 0x262D, "Omni-Path HFI Adapter 100 Series, 1 Port, PCIe x16, IO Module AHWKPTP100HF(0x8086-0x262D)"},
{0x8086, 0x24F1, 0xFFFF, 0xFFFF, "Omni-Path HFI Silicon 100 Series [integrated](0x24F1)"},
{0x8086, 0x24F3, 0xFFFF, 0xFFFF, "Wireless 8260(0x24F3)"},
{0x8086, 0x24F3, 0x8086, 0x0010, "Dual Band Wireless-AC 8260 [Snow Field Peak AC](0x8086-0x0010)"},
{0x8086, 0x24F3, 0x8086, 0x1010, "Dual Band Wireless-AC 8260(0x8086-0x1010)"},
{0x8086, 0x24F4, 0xFFFF, 0xFFFF, "Wireless 8260(0x24F4)"},
{0x8086, 0x24F4, 0x8086, 0x0030, "Dual Band Wireless-AC 8260 [Snow Field Peak AC](0x8086-0x0030)"},
{0x8086, 0x24FB, 0xFFFF, 0xFFFF, "Dual Band Wireless-AC 3168NGW [Stone Peak](0x24FB)"},
{0x8086, 0x24FD, 0xFFFF, 0xFFFF, "Wireless 8265 / 8275(0x24FD)"},
{0x8086, 0x24FD, 0x8086, 0x0010, "Dual Band Wireless-AC 8265 [Windstorm Peak](0x8086-0x0010)"},
{0x8086, 0x24FD, 0x8086, 0x0150, "Dual Band Wireless-AC 8265(0x8086-0x0150)"},
{0x8086, 0x24FD, 0x8086, 0x1010, "Dual Band Wireless-AC 8265(0x8086-0x1010)"},
{0x8086, 0x24FD, 0x8086, 0x1130, "Dual Band Wireless-AC 8265(0x8086-0x1130)"},
{0x8086, 0x2500, 0xFFFF, 0xFFFF, "82820 820 (Camino) Chipset Host Bridge (MCH)(0x2500)"},
{0x8086, 0x2500, 0x1028, 0x0095, "Precision Workstation 220 Chipset(0x1028-0x0095)"},
{0x8086, 0x2500, 0x1043, 0x801C, "P3C-2000 system chipset(0x1043-0x801C)"},
{0x8086, 0x2501, 0xFFFF, 0xFFFF, "82820 820 (Camino) Chipset Host Bridge (MCH)(0x2501)"},
{0x8086, 0x2501, 0x1043, 0x801C, "P3C-2000 system chipset(0x1043-0x801C)"},
{0x8086, 0x250B, 0xFFFF, 0xFFFF, "82820 820 (Camino) Chipset Host Bridge(0x250B)"},
{0x8086, 0x250F, 0xFFFF, 0xFFFF, "82820 820 (Camino) Chipset AGP Bridge(0x250F)"},
{0x8086, 0x2520, 0xFFFF, 0xFFFF, "82805AA MTH Memory Translator Hub(0x2520)"},
{0x8086, 0x2521, 0xFFFF, 0xFFFF, "82804AA MRH-S Memory Repeater Hub for SDRAM(0x2521)"},
{0x8086, 0x2522, 0xFFFF, 0xFFFF, "NVMe Optane Memory Series(0x2522)"},
{0x8086, 0x2522, 0x8086, 0x3806, "Optane Memory 16GB(0x8086-0x3806)"},
{0x8086, 0x2522, 0x8086, 0x3810, "Optane Memory M10 16GB(0x8086-0x3810)"},
{0x8086, 0x2525, 0xFFFF, 0xFFFF, "Optane NVME SSD P1600X Series(0x2525)"},
{0x8086, 0x2526, 0xFFFF, 0xFFFF, "Wi-Fi 5(802.11ac) Wireless-AC 9x6x [Thunder Peak](0x2526)"},
{0x8086, 0x2526, 0x8086, 0x0014, "Dual Band Wi-Fi 5 Wireless-AC 9260 160MHz 2x2(0x8086-0x0014)"},
{0x8086, 0x2526, 0x8086, 0x0210, "Dual Band Wi-Fi 5 Wireless-AC 9260 80MHz 2x2(0x8086-0x0210)"},
{0x8086, 0x2526, 0x8086, 0x0214, "Dual Band Wi-Fi 5 Wireless-AC 9260 80MHz 2x2(0x8086-0x0214)"},
{0x8086, 0x2526, 0x8086, 0x0230, "Dual Band Wi-Fi 5 Wireless-AC 9560 80MHz 2x2(0x8086-0x0230)"},
{0x8086, 0x2526, 0x8086, 0x0234, "Dual Band Wi-Fi 5 Wireless-AC 9560 80MHz 2x2(0x8086-0x0234)"},
{0x8086, 0x2526, 0x8086, 0x0238, "Dual Band Wi-Fi 5 Wireless-AC 9560 80MHz 2x2(0x8086-0x0238)"},
{0x8086, 0x2526, 0x8086, 0x023C, "Dual Band Wi-Fi 5 Wireless-AC 9560 80MHz 2x2(0x8086-0x023C)"},
{0x8086, 0x2526, 0x8086, 0x0260, "Dual Band Wi-Fi 5 Wireless-AC 9461 80MHz 1x1(0x8086-0x0260)"},
{0x8086, 0x2526, 0x8086, 0x0264, "Dual Band Wi-Fi 5 Wireless-AC 9461 80MHz 1x1(0x8086-0x0264)"},
{0x8086, 0x2526, 0x8086, 0x02A0, "Dual Band Wi-Fi 5 Wireless-AC 9462 80MHz 1x1(0x8086-0x02A0)"},
{0x8086, 0x2526, 0x8086, 0x02A4, "Dual Band Wi-Fi 5 Wireless-AC 9462 80MHz 1x1(0x8086-0x02A4)"},
{0x8086, 0x2530, 0xFFFF, 0xFFFF, "82850 850 (Tehama) Chipset Host Bridge (MCH)(0x2530)"},
{0x8086, 0x2530, 0x1028, 0x00C7, "Dimension 8100(0x1028-0x00C7)"},
{0x8086, 0x2530, 0x147B, 0x0507, "TH7II-RAID(0x147B-0x0507)"},
{0x8086, 0x2531, 0xFFFF, 0xFFFF, "82860 860 (Wombat) Chipset Host Bridge (MCH)(0x2531)"},
{0x8086, 0x2531, 0x1028, 0x00D8, "Precision 530(0x1028-0x00D8)"},
{0x8086, 0x2532, 0xFFFF, 0xFFFF, "82850 850 (Tehama) Chipset AGP Bridge(0x2532)"},
{0x8086, 0x2533, 0xFFFF, 0xFFFF, "82860 860 (Wombat) Chipset AGP Bridge(0x2533)"},
{0x8086, 0x2534, 0xFFFF, 0xFFFF, "82860 860 (Wombat) Chipset PCI Bridge(0x2534)"},
{0x8086, 0x2540, 0xFFFF, 0xFFFF, "E7500 Memory Controller Hub(0x2540)"},
{0x8086, 0x2540, 0x15D9, 0x3480, "P4DP6(0x15D9-0x3480)"},
{0x8086, 0x2541, 0xFFFF, 0xFFFF, "E7500/E7501 Host RASUM Controller(0x2541)"},
{0x8086, 0x2541, 0x15D9, 0x3480, "P4DP6(0x15D9-0x3480)"},
{0x8086, 0x2541, 0x4C53, 0x1090, "Cx9 / Vx9 mainboard(0x4C53-0x1090)"},
{0x8086, 0x2541, 0x8086, 0x3424, "SE7501HG2 Mainboard(0x8086-0x3424)"},
{0x8086, 0x2543, 0xFFFF, 0xFFFF, "E7500/E7501 Hub Interface B PCI-to-PCI Bridge(0x2543)"},
{0x8086, 0x2544, 0xFFFF, 0xFFFF, "E7500/E7501 Hub Interface B RASUM Controller(0x2544)"},
{0x8086, 0x2544, 0x4C53, 0x1090, "Cx9 / Vx9 mainboard(0x4C53-0x1090)"},
{0x8086, 0x2545, 0xFFFF, 0xFFFF, "E7500/E7501 Hub Interface C PCI-to-PCI Bridge(0x2545)"},
{0x8086, 0x2546, 0xFFFF, 0xFFFF, "E7500/E7501 Hub Interface C RASUM Controller(0x2546)"},
{0x8086, 0x2547, 0xFFFF, 0xFFFF, "E7500/E7501 Hub Interface D PCI-to-PCI Bridge(0x2547)"},
{0x8086, 0x2548, 0xFFFF, 0xFFFF, "E7500/E7501 Hub Interface D RASUM Controller(0x2548)"},
{0x8086, 0x254C, 0xFFFF, 0xFFFF, "E7501 Memory Controller Hub(0x254C)"},
{0x8086, 0x254C, 0x4C53, 0x1090, "Cx9 / Vx9 mainboard(0x4C53-0x1090)"},
{0x8086, 0x254C, 0x8086, 0x3424, "SE7501HG2 Mainboard(0x8086-0x3424)"},
{0x8086, 0x2550, 0xFFFF, 0xFFFF, "E7505 Memory Controller Hub(0x2550)"},
{0x8086, 0x2551, 0xFFFF, 0xFFFF, "E7505/E7205 Series RAS Controller(0x2551)"},
{0x8086, 0x2552, 0xFFFF, 0xFFFF, "E7505/E7205 PCI-to-AGP Bridge(0x2552)"},
{0x8086, 0x2553, 0xFFFF, 0xFFFF, "E7505 Hub Interface B PCI-to-PCI Bridge(0x2553)"},
{0x8086, 0x2554, 0xFFFF, 0xFFFF, "E7505 Hub Interface B PCI-to-PCI Bridge RAS Controller(0x2554)"},
{0x8086, 0x255D, 0xFFFF, 0xFFFF, "E7205 Memory Controller Hub(0x255D)"},
{0x8086, 0x2560, 0xFFFF, 0xFFFF, "82845G/GL[Brookdale-G]/GE/PE DRAM Controller/Host-Hub Interface(0x2560)"},
{0x8086, 0x2560, 0x1028, 0x0126, "Optiplex GX260(0x1028-0x0126)"},
{0x8086, 0x2560, 0x1458, 0x2560, "GA-8PE667 Ultra(0x1458-0x2560)"},
{0x8086, 0x2560, 0x1462, 0x5800, "845PE Max (MS-6580)(0x1462-0x5800)"},
{0x8086, 0x2561, 0xFFFF, 0xFFFF, "82845G/GL[Brookdale-G]/GE/PE Host-to-AGP Bridge(0x2561)"},
{0x8086, 0x2562, 0xFFFF, 0xFFFF, "82845G/GL[Brookdale-G]/GE Chipset Integrated Graphics Device(0x2562)"},
{0x8086, 0x2562, 0x0E11, 0x00B9, "Evo D510 SFF(0x0E11-0x00B9)"},
{0x8086, 0x2562, 0x1014, 0x0267, "NetVista A30p(0x1014-0x0267)"},
{0x8086, 0x2562, 0x1028, 0x0160, "Dimension 2400(0x1028-0x0160)"},
{0x8086, 0x2562, 0x1734, 0x1003, "D1521 Mainboard (Fujitsu-Siemens)(0x1734-0x1003)"},
{0x8086, 0x2562, 0x1734, 0x1004, "D1451 Mainboard (SCENIC N300, i845GV)(0x1734-0x1004)"},
{0x8086, 0x2570, 0xFFFF, 0xFFFF, "82865G/PE/P DRAM Controller/Host-Hub Interface(0x2570)"},
{0x8086, 0x2570, 0x103C, 0x006A, "NX9500(0x103C-0x006A)"},
{0x8086, 0x2570, 0x103C, 0x12BC, "d330 uT(0x103C-0x12BC)"},
{0x8086, 0x2570, 0x1043, 0x80F2, "P4P800/P5P800 series motherboard(0x1043-0x80F2)"},
{0x8086, 0x2570, 0x1458, 0x2570, "GA-8IPE1000 Pro2 motherboard (865PE)(0x1458-0x2570)"},
{0x8086, 0x2571, 0xFFFF, 0xFFFF, "82865G/PE/P AGP Bridge(0x2571)"},
{0x8086, 0x2572, 0xFFFF, 0xFFFF, "82865G Integrated Graphics Controller(0x2572)"},
{0x8086, 0x2572, 0x1014, 0x0287, "ThinkCentre S50(0x1014-0x0287)"},
{0x8086, 0x2572, 0x1028, 0x019D, "Dimension 3000(0x1028-0x019D)"},
{0x8086, 0x2572, 0x103C, 0x12BC, "D530 sff(dc578av)(0x103C-0x12BC)"},
{0x8086, 0x2572, 0x1043, 0x80A5, "P5P800-MX Mainboard(0x1043-0x80A5)"},
{0x8086, 0x2572, 0x1462, 0x7650, "Hetis 865GV-E (MS-7065)(0x1462-0x7650)"},
{0x8086, 0x2572, 0x1734, 0x101B, "Fujitsu-Siemens Scenic E300 i865GV(0x1734-0x101B)"},
{0x8086, 0x2572, 0x8086, 0x4246, "Desktop Board D865GBF(0x8086-0x4246)"},
{0x8086, 0x2572, 0x8086, 0x4C43, "Desktop Board D865GLC(0x8086-0x4C43)"},
{0x8086, 0x2573, 0xFFFF, 0xFFFF, "82865G/PE/P PCI to CSA Bridge(0x2573)"},
{0x8086, 0x2576, 0xFFFF, 0xFFFF, "82865G/PE/P Processor to I/O Memory Interface(0x2576)"},
{0x8086, 0x2578, 0xFFFF, 0xFFFF, "82875P/E7210 Memory Controller Hub(0x2578)"},
{0x8086, 0x2578, 0x1458, 0x2578, "GA-8KNXP motherboard (875P)(0x1458-0x2578)"},
{0x8086, 0x2578, 0x1462, 0x7580, "MS-6758 (875P Neo)(0x1462-0x7580)"},
{0x8086, 0x2578, 0x15D9, 0x4580, "P4SCE Motherboard(0x15D9-0x4580)"},
{0x8086, 0x2579, 0xFFFF, 0xFFFF, "82875P Processor to AGP Controller(0x2579)"},
{0x8086, 0x257B, 0xFFFF, 0xFFFF, "82875P/E7210 Processor to PCI to CSA Bridge(0x257B)"},
{0x8086, 0x257E, 0xFFFF, 0xFFFF, "82875P/E7210 Processor to I/O Memory Interface(0x257E)"},
{0x8086, 0x2580, 0xFFFF, 0xFFFF, "82915G/P/GV/GL/PL/910GL Memory Controller Hub(0x2580)"},
{0x8086, 0x2580, 0x1458, 0x2580, "GA-8I915ME-G Mainboard(0x1458-0x2580)"},
{0x8086, 0x2580, 0x1462, 0x7028, "915P/G Neo2(0x1462-0x7028)"},
{0x8086, 0x2580, 0x1734, 0x105B, "Scenic W620(0x1734-0x105B)"},
{0x8086, 0x2581, 0xFFFF, 0xFFFF, "82915G/P/GV/GL/PL/910GL PCI Express Root Port(0x2581)"},
{0x8086, 0x2582, 0xFFFF, 0xFFFF, "82915G/GV/910GL Integrated Graphics Controller(0x2582)"},
{0x8086, 0x2582, 0x1028, 0x1079, "Optiplex GX280(0x1028-0x1079)"},
{0x8086, 0x2582, 0x103C, 0x3006, "DC7100 SFF(DX878AV)(0x103C-0x3006)"},
{0x8086, 0x2582, 0x1043, 0x2582, "P5GD1-VW Mainboard(0x1043-0x2582)"},
{0x8086, 0x2582, 0x1458, 0x2582, "GA-8I915ME-G Mainboard(0x1458-0x2582)"},
{0x8086, 0x2582, 0x1734, 0x105B, "Scenic W620(0x1734-0x105B)"},
{0x8086, 0x2582, 0x1849, 0x2582, "ASRock P4Dual-915GL(0x1849-0x2582)"},
{0x8086, 0x2584, 0xFFFF, 0xFFFF, "82925X/XE Memory Controller Hub(0x2584)"},
{0x8086, 0x2584, 0x1028, 0x0177, "Dimension 8400(0x1028-0x0177)"},
{0x8086, 0x2585, 0xFFFF, 0xFFFF, "82925X/XE PCI Express Root Port(0x2585)"},
{0x8086, 0x2588, 0xFFFF, 0xFFFF, "E7220/E7221 Memory Controller Hub(0x2588)"},
{0x8086, 0x2589, 0xFFFF, 0xFFFF, "E7220/E7221 PCI Express Root Port(0x2589)"},
{0x8086, 0x258A, 0xFFFF, 0xFFFF, "E7221 Integrated Graphics Controller(0x258A)"},
{0x8086, 0x2590, 0xFFFF, 0xFFFF, "Mobile 915GM/PM/GMS/910GML Express Processor to DRAM Controller(0x2590)"},
{0x8086, 0x2590, 0x1014, 0x0575, "ThinkPad X41 / Z60t(0x1014-0x0575)"},
{0x8086, 0x2590, 0x1028, 0x0182, "Latitude C610(0x1028-0x0182)"},
{0x8086, 0x2590, 0x103C, 0x0934, "Compaq nw8240/nx8220(0x103C-0x0934)"},
{0x8086, 0x2590, 0x103C, 0x0944, "Compaq nc6220 Notebook PC(0x103C-0x0944)"},
{0x8086, 0x2590, 0x103C, 0x099C, "NX6110/NC6120(0x103C-0x099C)"},
{0x8086, 0x2590, 0x1043, 0x82D9, "Asus Eee PC 900(0x1043-0x82D9)"},
{0x8086, 0x2590, 0x104D, 0x81B7, "Vaio VGN-S3XP(0x104D-0x81B7)"},
{0x8086, 0x2590, 0xA304, 0x81B7, "Vaio VGN-S3XP(0xA304-0x81B7)"},
{0x8086, 0x2590, 0xE4BF, 0x0CCD, "CCD-CALYPSO(0xE4BF-0x0CCD)"},
{0x8086, 0x2590, 0xE4BF, 0x0CD3, "CD3-JIVE(0xE4BF-0x0CD3)"},
{0x8086, 0x2590, 0xE4BF, 0x58B1, "XB1(0xE4BF-0x58B1)"},
{0x8086, 0x2591, 0xFFFF, 0xFFFF, "Mobile 915GM/PM Express PCI Express Root Port(0x2591)"},
{0x8086, 0x2591, 0x103C, 0x0934, "Compaq nw8240 Mobile Workstation(0x103C-0x0934)"},
{0x8086, 0x2592, 0xFFFF, 0xFFFF, "Mobile 915GM/GMS/910GML Express Graphics Controller(0x2592)"},
{0x8086, 0x2592, 0x1014, 0x0582, "ThinkPad X41(0x1014-0x0582)"},
{0x8086, 0x2592, 0x103C, 0x099C, "NX6110/NC6120(0x103C-0x099C)"},
{0x8086, 0x2592, 0x103C, 0x308A, "NC6220(0x103C-0x308A)"},
{0x8086, 0x2592, 0x1043, 0x1881, "GMA 900 915GM Integrated Graphics(0x1043-0x1881)"},
{0x8086, 0x2592, 0xE4BF, 0x0CCD, "CCD-CALYPSO(0xE4BF-0x0CCD)"},
{0x8086, 0x2592, 0xE4BF, 0x0CD3, "CD3-JIVE(0xE4BF-0x0CD3)"},
{0x8086, 0x2592, 0xE4BF, 0x58B1, "XB1(0xE4BF-0x58B1)"},
{0x8086, 0x25A1, 0xFFFF, 0xFFFF, "6300ESB LPC Interface Controller(0x25A1)"},
{0x8086, 0x25A2, 0xFFFF, 0xFFFF, "6300ESB PATA Storage Controller(0x25A2)"},
{0x8086, 0x25A2, 0x1734, 0x1073, "Primergy Econel 200 D2020 mainboard(0x1734-0x1073)"},
{0x8086, 0x25A2, 0x1775, 0x10D0, "V5D Single Board Computer IDE(0x1775-0x10D0)"},
{0x8086, 0x25A2, 0x1775, 0x1100, "CR11/VR11 Single Board Computer(0x1775-0x1100)"},
{0x8086, 0x25A2, 0x1775, 0xCE90, "CE9(0x1775-0xCE90)"},
{0x8086, 0x25A2, 0x4C53, 0x10B0, "CL9 mainboard(0x4C53-0x10B0)"},
{0x8086, 0x25A2, 0x4C53, 0x10E0, "PSL09 PrPMC(0x4C53-0x10E0)"},
{0x8086, 0x25A3, 0xFFFF, 0xFFFF, "6300ESB SATA Storage Controller(0x25A3)"},
{0x8086, 0x25A3, 0x1734, 0x1073, "Primergy Econel 200 D2020 mainboard(0x1734-0x1073)"},
{0x8086, 0x25A3, 0x1775, 0x1100, "CR11/VR11 Single Board Computer(0x1775-0x1100)"},
{0x8086, 0x25A3, 0x1775, 0xCE90, "CE9(0x1775-0xCE90)"},
{0x8086, 0x25A3, 0x4C53, 0x10B0, "CL9 mainboard(0x4C53-0x10B0)"},
{0x8086, 0x25A3, 0x4C53, 0x10D0, "Telum ASLP10 Processor AMC(0x4C53-0x10D0)"},
{0x8086, 0x25A3, 0x4C53, 0x10E0, "PSL09 PrPMC(0x4C53-0x10E0)"},
{0x8086, 0x25A4, 0xFFFF, 0xFFFF, "6300ESB SMBus Controller(0x25A4)"},
{0x8086, 0x25A4, 0x1734, 0x1073, "Primergy Econel 200 D2020 mainboard(0x1734-0x1073)"},
{0x8086, 0x25A4, 0x1775, 0x10D0, "V5D Single Board Computer(0x1775-0x10D0)"},
{0x8086, 0x25A4, 0x1775, 0x1100, "CR11/VR11 Single Board Computer(0x1775-0x1100)"},
{0x8086, 0x25A4, 0x1775, 0xCE90, "CE9(0x1775-0xCE90)"},
{0x8086, 0x25A4, 0x4C53, 0x10B0, "CL9 mainboard(0x4C53-0x10B0)"},
{0x8086, 0x25A4, 0x4C53, 0x10D0, "Telum ASLP10 Processor AMC(0x4C53-0x10D0)"},
{0x8086, 0x25A4, 0x4C53, 0x10E0, "PSL09 PrPMC(0x4C53-0x10E0)"},
{0x8086, 0x25A6, 0xFFFF, 0xFFFF, "6300ESB AC'97 Audio Controller(0x25A6)"},
{0x8086, 0x25A6, 0x1775, 0x1100, "CR11/VR11 Single Board Computer(0x1775-0x1100)"},
{0x8086, 0x25A6, 0x1775, 0xCE90, "CE9(0x1775-0xCE90)"},
{0x8086, 0x25A6, 0x4C53, 0x10B0, "CL9 mainboard(0x4C53-0x10B0)"},
{0x8086, 0x25A7, 0xFFFF, 0xFFFF, "6300ESB AC'97 Modem Controller(0x25A7)"},
{0x8086, 0x25A9, 0xFFFF, 0xFFFF, "6300ESB USB Universal Host Controller(0x25A9)"},
{0x8086, 0x25A9, 0x1734, 0x1073, "Primergy Econel 200 D2020 mainboard(0x1734-0x1073)"},
{0x8086, 0x25A9, 0x1775, 0x10D0, "V5D Single Board Computer USB(0x1775-0x10D0)"},
{0x8086, 0x25A9, 0x1775, 0x1100, "CR11/VR11 Single Board Computer(0x1775-0x1100)"},
{0x8086, 0x25A9, 0x1775, 0xCE90, "CE9(0x1775-0xCE90)"},
{0x8086, 0x25A9, 0x4C53, 0x10B0, "CL9 mainboard(0x4C53-0x10B0)"},
{0x8086, 0x25A9, 0x4C53, 0x10D0, "Telum ASLP10 Processor AMC(0x4C53-0x10D0)"},
{0x8086, 0x25A9, 0x4C53, 0x10E0, "PSL09 PrPMC(0x4C53-0x10E0)"},
{0x8086, 0x25AA, 0xFFFF, 0xFFFF, "6300ESB USB Universal Host Controller(0x25AA)"},
{0x8086, 0x25AA, 0x1734, 0x1073, "Primergy Econel 200 D2020 mainboard(0x1734-0x1073)"},
{0x8086, 0x25AA, 0x1775, 0x1100, "CR11/VR11 Single Board Computer(0x1775-0x1100)"},
{0x8086, 0x25AA, 0x1775, 0xCE90, "CE9(0x1775-0xCE90)"},
{0x8086, 0x25AA, 0x4C53, 0x10B0, "CL9 mainboard(0x4C53-0x10B0)"},
{0x8086, 0x25AA, 0x4C53, 0x10D0, "Telum ASLP10 Processor AMC(0x4C53-0x10D0)"},
{0x8086, 0x25AA, 0x4C53, 0x10E0, "PSL09 PrPMC(0x4C53-0x10E0)"},
{0x8086, 0x25AB, 0xFFFF, 0xFFFF, "6300ESB Watchdog Timer(0x25AB)"},
{0x8086, 0x25AB, 0x1734, 0x1073, "Primergy Econel 200 D2020 mainboard(0x1734-0x1073)"},
{0x8086, 0x25AB, 0x1775, 0x10D0, "V5D Single Board Computer(0x1775-0x10D0)"},
{0x8086, 0x25AB, 0x1775, 0x1100, "CR11/VR11 Single Board Computer(0x1775-0x1100)"},
{0x8086, 0x25AB, 0x1775, 0xCE90, "CE9(0x1775-0xCE90)"},
{0x8086, 0x25AB, 0x1AF4, 0x1100, "QEMU Virtual Machine(0x1AF4-0x1100)"},
{0x8086, 0x25AB, 0x4C53, 0x10B0, "CL9 mainboard(0x4C53-0x10B0)"},
{0x8086, 0x25AB, 0x4C53, 0x10D0, "Telum ASLP10 Processor AMC(0x4C53-0x10D0)"},
{0x8086, 0x25AB, 0x4C53, 0x10E0, "PSL09 PrPMC(0x4C53-0x10E0)"},
{0x8086, 0x25AC, 0xFFFF, 0xFFFF, "6300ESB I/O Advanced Programmable Interrupt Controller(0x25AC)"},
{0x8086, 0x25AC, 0x1734, 0x1073, "Primergy Econel 200 D2020 mainboard(0x1734-0x1073)"},
{0x8086, 0x25AC, 0x1775, 0x10D0, "V5D Single Board Computer(0x1775-0x10D0)"},
{0x8086, 0x25AC, 0x1775, 0x1100, "CR11/VR11 Single Board Computer(0x1775-0x1100)"},
{0x8086, 0x25AC, 0x1775, 0xCE90, "CE9(0x1775-0xCE90)"},
{0x8086, 0x25AC, 0x4C53, 0x10B0, "CL9 mainboard(0x4C53-0x10B0)"},
{0x8086, 0x25AC, 0x4C53, 0x10D0, "Telum ASLP10 Processor AMC(0x4C53-0x10D0)"},
{0x8086, 0x25AC, 0x4C53, 0x10E0, "PSL09 PrPMC(0x4C53-0x10E0)"},
{0x8086, 0x25AD, 0xFFFF, 0xFFFF, "6300ESB USB2 Enhanced Host Controller(0x25AD)"},
{0x8086, 0x25AD, 0x1734, 0x1073, "Primergy Econel 200 D2020 mainboard(0x1734-0x1073)"},
{0x8086, 0x25AD, 0x1775, 0x10D0, "V5D Single Board Computer USB 2.0(0x1775-0x10D0)"},
{0x8086, 0x25AD, 0x1775, 0x1100, "CR11/VR11 Single Board Computer(0x1775-0x1100)"},
{0x8086, 0x25AD, 0x1775, 0xCE90, "CE9(0x1775-0xCE90)"},
{0x8086, 0x25AD, 0x4C53, 0x10B0, "CL9 mainboard(0x4C53-0x10B0)"},
{0x8086, 0x25AD, 0x4C53, 0x10D0, "Telum ASLP10 Processor AMC(0x4C53-0x10D0)"},
{0x8086, 0x25AD, 0x4C53, 0x10E0, "PSL09 PrPMC(0x4C53-0x10E0)"},
{0x8086, 0x25AE, 0xFFFF, 0xFFFF, "6300ESB 64-bit PCI-X Bridge(0x25AE)"},
{0x8086, 0x25B0, 0xFFFF, 0xFFFF, "6300ESB SATA RAID Controller(0x25B0)"},
{0x8086, 0x25B0, 0x1775, 0x1100, "CR11/VR11 Single Board Computer(0x1775-0x1100)"},
{0x8086, 0x25B0, 0x4C53, 0x10D0, "Telum ASLP10 Processor AMC(0x4C53-0x10D0)"},
{0x8086, 0x25B0, 0x4C53, 0x10E0, "PSL09 PrPMC(0x4C53-0x10E0)"},
{0x8086, 0x25C0, 0xFFFF, 0xFFFF, "5000X Chipset Memory Controller Hub(0x25C0)"},
{0x8086, 0x25D0, 0xFFFF, 0xFFFF, "5000Z Chipset Memory Controller Hub(0x25D0)"},
{0x8086, 0x25D4, 0xFFFF, 0xFFFF, "5000V Chipset Memory Controller Hub(0x25D4)"},
{0x8086, 0x25D4, 0x15D9, 0x8680, "X7DVL-E-O motherboard(0x15D9-0x8680)"},
{0x8086, 0x25D8, 0xFFFF, 0xFFFF, "5000P Chipset Memory Controller Hub(0x25D8)"},
{0x8086, 0x25D8, 0x103C, 0x31FD, "ProLiant DL360 G5(0x103C-0x31FD)"},
{0x8086, 0x25D8, 0x15D9, 0x9680, "X7DBN Motherboard(0x15D9-0x9680)"},
{0x8086, 0x25D8, 0x8086, 0x3476, "S5000PSLSATA Server Board(0x8086-0x3476)"},
{0x8086, 0x25E2, 0xFFFF, 0xFFFF, "5000 Series Chipset PCI Express x4 Port 2(0x25E2)"},
{0x8086, 0x25E3, 0xFFFF, 0xFFFF, "5000 Series Chipset PCI Express x4 Port 3(0x25E3)"},
{0x8086, 0x25E4, 0xFFFF, 0xFFFF, "5000 Series Chipset PCI Express x4 Port 4(0x25E4)"},
{0x8086, 0x25E5, 0xFFFF, 0xFFFF, "5000 Series Chipset PCI Express x4 Port 5(0x25E5)"},
{0x8086, 0x25E6, 0xFFFF, 0xFFFF, "5000 Series Chipset PCI Express x4 Port 6(0x25E6)"},
{0x8086, 0x25E7, 0xFFFF, 0xFFFF, "5000 Series Chipset PCI Express x4 Port 7(0x25E7)"},
{0x8086, 0x25F0, 0xFFFF, 0xFFFF, "5000 Series Chipset FSB Registers(0x25F0)"},
{0x8086, 0x25F0, 0x1028, 0x01BB, "PowerEdge 1955 FSB Registers(0x1028-0x01BB)"},
{0x8086, 0x25F0, 0x103C, 0x31FD, "ProLiant DL140 G3, DL360 G5(0x103C-0x31FD)"},
{0x8086, 0x25F0, 0x15D9, 0x8680, "X7DVL-E-O motherboard(0x15D9-0x8680)"},
{0x8086, 0x25F0, 0x15D9, 0x9680, "X7DBN Motherboard(0x15D9-0x9680)"},
{0x8086, 0x25F0, 0x8086, 0x3476, "S5000PSLSATA Server Board(0x8086-0x3476)"},
{0x8086, 0x25F1, 0xFFFF, 0xFFFF, "5000 Series Chipset Reserved Registers(0x25F1)"},
{0x8086, 0x25F1, 0x103C, 0x31FD, "ProLiant DL140 G3, DL360 G5(0x103C-0x31FD)"},
{0x8086, 0x25F1, 0x15D9, 0x8680, "X7DVL-E-O motherboard(0x15D9-0x8680)"},
{0x8086, 0x25F1, 0x15D9, 0x9680, "X7DBN Motherboard(0x15D9-0x9680)"},
{0x8086, 0x25F1, 0x8086, 0x3476, "S5000PSLSATA Server Board(0x8086-0x3476)"},
{0x8086, 0x25F3, 0xFFFF, 0xFFFF, "5000 Series Chipset Reserved Registers(0x25F3)"},
{0x8086, 0x25F3, 0x103C, 0x31FD, "ProLiant DL140 G3, DL360 G5(0x103C-0x31FD)"},
{0x8086, 0x25F3, 0x15D9, 0x8680, "X7DVL-E-O motherboard(0x15D9-0x8680)"},
{0x8086, 0x25F3, 0x15D9, 0x9680, "X7DBN Motherboard(0x15D9-0x9680)"},
{0x8086, 0x25F3, 0x8086, 0x3476, "S5000PSLSATA Server Board(0x8086-0x3476)"},
{0x8086, 0x25F5, 0xFFFF, 0xFFFF, "5000 Series Chipset FBD Registers(0x25F5)"},
{0x8086, 0x25F5, 0x103C, 0x31FD, "ProLiant DL140 G3, DL360 G5(0x103C-0x31FD)"},
{0x8086, 0x25F5, 0x15D9, 0x8680, "X7DVL-E-O motherboard(0x15D9-0x8680)"},
{0x8086, 0x25F5, 0x15D9, 0x9680, "X7DBN Motherboard(0x15D9-0x9680)"},
{0x8086, 0x25F5, 0x8086, 0x3476, "S5000PSLSATA Server Board(0x8086-0x3476)"},
{0x8086, 0x25F6, 0xFFFF, 0xFFFF, "5000 Series Chipset FBD Registers(0x25F6)"},
{0x8086, 0x25F6, 0x103C, 0x31FD, "ProLiant DL140 G3, DL360 G5(0x103C-0x31FD)"},
{0x8086, 0x25F6, 0x15D9, 0x8680, "X7DVL-E-O motherboard(0x15D9-0x8680)"},
{0x8086, 0x25F6, 0x15D9, 0x9680, "X7DBN Motherboard(0x15D9-0x9680)"},
{0x8086, 0x25F6, 0x8086, 0x3476, "S5000PSLSATA Server Board(0x8086-0x3476)"},
{0x8086, 0x25F7, 0xFFFF, 0xFFFF, "5000 Series Chipset PCI Express x8 Port 2-3(0x25F7)"},
{0x8086, 0x25F8, 0xFFFF, 0xFFFF, "5000 Series Chipset PCI Express x8 Port 4-5(0x25F8)"},
{0x8086, 0x25F9, 0xFFFF, 0xFFFF, "5000 Series Chipset PCI Express x8 Port 6-7(0x25F9)"},
{0x8086, 0x25FA, 0xFFFF, 0xFFFF, "5000X Chipset PCI Express x16 Port 4-7(0x25FA)"},
{0x8086, 0x2600, 0xFFFF, 0xFFFF, "E8500/E8501 Hub Interface 1.5(0x2600)"},
{0x8086, 0x2600, 0x1028, 0x0170, "PowerEdge 6850 Hub Interface(0x1028-0x0170)"},
{0x8086, 0x2601, 0xFFFF, 0xFFFF, "E8500/E8501 PCI Express x4 Port D(0x2601)"},
{0x8086, 0x2602, 0xFFFF, 0xFFFF, "E8500/E8501 PCI Express x4 Port C0(0x2602)"},
{0x8086, 0x2603, 0xFFFF, 0xFFFF, "E8500/E8501 PCI Express x4 Port C1(0x2603)"},
{0x8086, 0x2604, 0xFFFF, 0xFFFF, "E8500/E8501 PCI Express x4 Port B0(0x2604)"},
{0x8086, 0x2605, 0xFFFF, 0xFFFF, "E8500/E8501 PCI Express x4 Port B1(0x2605)"},
{0x8086, 0x2606, 0xFFFF, 0xFFFF, "E8500/E8501 PCI Express x4 Port A0(0x2606)"},
{0x8086, 0x2607, 0xFFFF, 0xFFFF, "E8500/E8501 PCI Express x4 Port A1(0x2607)"},
{0x8086, 0x2608, 0xFFFF, 0xFFFF, "E8500/E8501 PCI Express x8 Port C(0x2608)"},
{0x8086, 0x2609, 0xFFFF, 0xFFFF, "E8500/E8501 PCI Express x8 Port B(0x2609)"},
{0x8086, 0x260A, 0xFFFF, 0xFFFF, "E8500/E8501 PCI Express x8 Port A(0x260A)"},
{0x8086, 0x260C, 0xFFFF, 0xFFFF, "E8500/E8501 IMI Registers(0x260C)"},
{0x8086, 0x2610, 0xFFFF, 0xFFFF, "E8500/E8501 FSB Registers(0x2610)"},
{0x8086, 0x2611, 0xFFFF, 0xFFFF, "E8500/E8501 Address Mapping Registers(0x2611)"},
{0x8086, 0x2612, 0xFFFF, 0xFFFF, "E8500/E8501 RAS Registers(0x2612)"},
{0x8086, 0x2613, 0xFFFF, 0xFFFF, "E8500/E8501 Reserved Registers(0x2613)"},
{0x8086, 0x2614, 0xFFFF, 0xFFFF, "E8500/E8501 Reserved Registers(0x2614)"},
{0x8086, 0x2615, 0xFFFF, 0xFFFF, "E8500/E8501 Miscellaneous Registers(0x2615)"},
{0x8086, 0x2617, 0xFFFF, 0xFFFF, "E8500/E8501 Reserved Registers(0x2617)"},
{0x8086, 0x2618, 0xFFFF, 0xFFFF, "E8500/E8501 Reserved Registers(0x2618)"},
{0x8086, 0x2619, 0xFFFF, 0xFFFF, "E8500/E8501 Reserved Registers(0x2619)"},
{0x8086, 0x261A, 0xFFFF, 0xFFFF, "E8500/E8501 Reserved Registers(0x261A)"},
{0x8086, 0x261B, 0xFFFF, 0xFFFF, "E8500/E8501 Reserved Registers(0x261B)"},
{0x8086, 0x261C, 0xFFFF, 0xFFFF, "E8500/E8501 Reserved Registers(0x261C)"},
{0x8086, 0x261D, 0xFFFF, 0xFFFF, "E8500/E8501 Reserved Registers(0x261D)"},
{0x8086, 0x261E, 0xFFFF, 0xFFFF, "E8500/E8501 Reserved Registers(0x261E)"},
{0x8086, 0x2620, 0xFFFF, 0xFFFF, "E8500/E8501 eXternal Memory Bridge(0x2620)"},
{0x8086, 0x2620, 0x1028, 0x0170, "PowerEdge 6850 Memory Bridge(0x1028-0x0170)"},
{0x8086, 0x2621, 0xFFFF, 0xFFFF, "E8500/E8501 XMB Miscellaneous Registers(0x2621)"},
{0x8086, 0x2621, 0x1028, 0x0170, "PowerEdge 6850 XMB Registers(0x1028-0x0170)"},
{0x8086, 0x2622, 0xFFFF, 0xFFFF, "E8500/E8501 XMB Memory Interleaving Registers(0x2622)"},
{0x8086, 0x2622, 0x1028, 0x0170, "PowerEdge 6850 Memory Interleaving Registers(0x1028-0x0170)"},
{0x8086, 0x2623, 0xFFFF, 0xFFFF, "E8500/E8501 XMB DDR Initialization and Calibration(0x2623)"},
{0x8086, 0x2623, 0x1028, 0x0170, "PowerEdge 6850 DDR Initialization and Calibration(0x1028-0x0170)"},
{0x8086, 0x2624, 0xFFFF, 0xFFFF, "E8500/E8501 XMB Reserved Registers(0x2624)"},
{0x8086, 0x2624, 0x1028, 0x0170, "PowerEdge 6850 Reserved Registers(0x1028-0x0170)"},
{0x8086, 0x2625, 0xFFFF, 0xFFFF, "E8500/E8501 XMB Reserved Registers(0x2625)"},
{0x8086, 0x2625, 0x1028, 0x0170, "PowerEdge 6850 Reserved Registers(0x1028-0x0170)"},
{0x8086, 0x2626, 0xFFFF, 0xFFFF, "E8500/E8501 XMB Reserved Registers(0x2626)"},
{0x8086, 0x2626, 0x1028, 0x0170, "PowerEdge 6850 Reserved Registers(0x1028-0x0170)"},
{0x8086, 0x2627, 0xFFFF, 0xFFFF, "E8500/E8501 XMB Reserved Registers(0x2627)"},
{0x8086, 0x2627, 0x1028, 0x0170, "PowerEdge 6850 Reserved Registers(0x1028-0x0170)"},
{0x8086, 0x2640, 0xFFFF, 0xFFFF, "82801FB/FR (ICH6/ICH6R) LPC Interface Bridge(0x2640)"},
{0x8086, 0x2640, 0x1462, 0x7028, "915P/G Neo2(0x1462-0x7028)"},
{0x8086, 0x2640, 0x1734, 0x105C, "Scenic W620(0x1734-0x105C)"},
{0x8086, 0x2640, 0xE4BF, 0x0CCD, "CCD-CALYPSO(0xE4BF-0x0CCD)"},
{0x8086, 0x2640, 0xE4BF, 0x0CD3, "CD3-JIVE(0xE4BF-0x0CD3)"},
{0x8086, 0x2640, 0xE4BF, 0x58B1, "XB1(0xE4BF-0x58B1)"},
{0x8086, 0x2641, 0xFFFF, 0xFFFF, "82801FBM (ICH6M) LPC Interface Bridge(0x2641)"},
{0x8086, 0x2641, 0x1014, 0x0568, "ThinkPad X41(0x1014-0x0568)"},
{0x8086, 0x2641, 0x103C, 0x0934, "Compaq nw8240/nx8220(0x103C-0x0934)"},
{0x8086, 0x2641, 0x103C, 0x0944, "Compaq nc6220 Notebook PC(0x103C-0x0944)"},
{0x8086, 0x2641, 0x103C, 0x099C, "NX6110/NC6120(0x103C-0x099C)"},
{0x8086, 0x2642, 0xFFFF, 0xFFFF, "82801FW/FRW (ICH6W/ICH6RW) LPC Interface Bridge(0x2642)"},
{0x8086, 0x2651, 0xFFFF, 0xFFFF, "82801FB/FW (ICH6/ICH6W) SATA Controller(0x2651)"},
{0x8086, 0x2651, 0x1028, 0x0179, "Optiplex GX280(0x1028-0x0179)"},
{0x8086, 0x2651, 0x1043, 0x2601, "P5GD1-VW Mainboard(0x1043-0x2601)"},
{0x8086, 0x2651, 0x1734, 0x105C, "Scenic W620(0x1734-0x105C)"},
{0x8086, 0x2651, 0x8086, 0x4147, "D915GAG Motherboard(0x8086-0x4147)"},
{0x8086, 0x2651, 0xE4BF, 0x0CCD, "CCD-CALYPSO(0xE4BF-0x0CCD)"},
{0x8086, 0x2651, 0xE4BF, 0x0CD3, "CD3-JIVE(0xE4BF-0x0CD3)"},
{0x8086, 0x2651, 0xE4BF, 0x58B1, "XB1(0xE4BF-0x58B1)"},
{0x8086, 0x2652, 0xFFFF, 0xFFFF, "82801FR/FRW (ICH6R/ICH6RW) SATA Controller(0x2652)"},
{0x8086, 0x2652, 0x1028, 0x0177, "Dimension 8400(0x1028-0x0177)"},
{0x8086, 0x2652, 0x1462, 0x7028, "915P/G Neo2(0x1462-0x7028)"},
{0x8086, 0x2653, 0xFFFF, 0xFFFF, "82801FBM (ICH6M) SATA Controller(0x2653)"},
{0x8086, 0x2653, 0x1014, 0x056A, "ThinkPad X41(0x1014-0x056A)"},
{0x8086, 0x2658, 0xFFFF, 0xFFFF, "82801FB/FBM/FR/FW/FRW (ICH6 Family) USB UHCI #1(0x2658)"},
{0x8086, 0x2658, 0x1014, 0x0565, "ThinkPad X41(0x1014-0x0565)"},
{0x8086, 0x2658, 0x1028, 0x0177, "Dimension 8400(0x1028-0x0177)"},
{0x8086, 0x2658, 0x1028, 0x0179, "Optiplex GX280(0x1028-0x0179)"},
{0x8086, 0x2658, 0x103C, 0x0934, "Compaq nw8240/nx8220(0x103C-0x0934)"},
{0x8086, 0x2658, 0x103C, 0x0944, "Compaq nc6220 Notebook PC(0x103C-0x0944)"},
{0x8086, 0x2658, 0x103C, 0x099C, "NX6110/NC6120(0x103C-0x099C)"},
{0x8086, 0x2658, 0x1043, 0x80A6, "P5GD1-VW Mainboard(0x1043-0x80A6)"},
{0x8086, 0x2658, 0x1458, 0x2558, "GA-8I915ME-G Mainboard(0x1458-0x2558)"},
{0x8086, 0x2658, 0x1462, 0x7028, "915P/G Neo2(0x1462-0x7028)"},
{0x8086, 0x2658, 0x1734, 0x105C, "Scenic W620(0x1734-0x105C)"},
{0x8086, 0x2658, 0xE4BF, 0x0CCD, "CCD-CALYPSO(0xE4BF-0x0CCD)"},
{0x8086, 0x2658, 0xE4BF, 0x0CD3, "CD3-JIVE(0xE4BF-0x0CD3)"},
{0x8086, 0x2658, 0xE4BF, 0x58B1, "XB1(0xE4BF-0x58B1)"},
{0x8086, 0x2659, 0xFFFF, 0xFFFF, "82801FB/FBM/FR/FW/FRW (ICH6 Family) USB UHCI #2(0x2659)"},
{0x8086, 0x2659, 0x1014, 0x0565, "ThinkPad X41(0x1014-0x0565)"},
{0x8086, 0x2659, 0x1028, 0x0177, "Dimension 8400(0x1028-0x0177)"},
{0x8086, 0x2659, 0x1028, 0x0179, "Optiplex GX280(0x1028-0x0179)"},
{0x8086, 0x2659, 0x103C, 0x0934, "Compaq nw8240/nx8220(0x103C-0x0934)"},
{0x8086, 0x2659, 0x103C, 0x0944, "Compaq nc6220 Notebook PC(0x103C-0x0944)"},
{0x8086, 0x2659, 0x103C, 0x099C, "NX6110/NC6120(0x103C-0x099C)"},
{0x8086, 0x2659, 0x1043, 0x80A6, "P5GD1-VW Mainboard(0x1043-0x80A6)"},
{0x8086, 0x2659, 0x1458, 0x2659, "GA-8I915ME-G Mainboard(0x1458-0x2659)"},
{0x8086, 0x2659, 0x1462, 0x7028, "915P/G Neo2(0x1462-0x7028)"},
{0x8086, 0x2659, 0x1734, 0x105C, "Scenic W620(0x1734-0x105C)"},
{0x8086, 0x2659, 0xE4BF, 0x0CCD, "CCD-CALYPSO(0xE4BF-0x0CCD)"},
{0x8086, 0x2659, 0xE4BF, 0x0CD3, "CD3-JIVE(0xE4BF-0x0CD3)"},
{0x8086, 0x2659, 0xE4BF, 0x58B1, "XB1(0xE4BF-0x58B1)"},
{0x8086, 0x265A, 0xFFFF, 0xFFFF, "82801FB/FBM/FR/FW/FRW (ICH6 Family) USB UHCI #3(0x265A)"},
{0x8086, 0x265A, 0x1014, 0x0565, "ThinkPad X41(0x1014-0x0565)"},
{0x8086, 0x265A, 0x1028, 0x0177, "Dimension 8400(0x1028-0x0177)"},
{0x8086, 0x265A, 0x1028, 0x0179, "Optiplex GX280(0x1028-0x0179)"},
{0x8086, 0x265A, 0x103C, 0x0934, "Compaq nw8240/nx8220(0x103C-0x0934)"},
{0x8086, 0x265A, 0x103C, 0x0944, "Compaq nc6220 Notebook PC(0x103C-0x0944)"},
{0x8086, 0x265A, 0x103C, 0x099C, "NX6110/NC6120(0x103C-0x099C)"},
{0x8086, 0x265A, 0x1043, 0x80A6, "P5GD1-VW Mainboard(0x1043-0x80A6)"},
{0x8086, 0x265A, 0x1458, 0x265A, "GA-8I915ME-G Mainboard(0x1458-0x265A)"},
{0x8086, 0x265A, 0x1462, 0x7028, "915P/G Neo2(0x1462-0x7028)"},
{0x8086, 0x265A, 0x1734, 0x105C, "Scenic W620(0x1734-0x105C)"},
{0x8086, 0x265A, 0xE4BF, 0x0CCD, "CCD-CALYPSO(0xE4BF-0x0CCD)"},
{0x8086, 0x265A, 0xE4BF, 0x0CD3, "CD3-JIVE(0xE4BF-0x0CD3)"},
{0x8086, 0x265A, 0xE4BF, 0x58B1, "XB1(0xE4BF-0x58B1)"},
{0x8086, 0x265B, 0xFFFF, 0xFFFF, "82801FB/FBM/FR/FW/FRW (ICH6 Family) USB UHCI #4(0x265B)"},
{0x8086, 0x265B, 0x1014, 0x0565, "ThinkPad X41(0x1014-0x0565)"},
{0x8086, 0x265B, 0x1028, 0x0177, "Dimension 8400(0x1028-0x0177)"},
{0x8086, 0x265B, 0x1028, 0x0179, "Optiplex GX280(0x1028-0x0179)"},
{0x8086, 0x265B, 0x103C, 0x099C, "NX6110/NC6120(0x103C-0x099C)"},
{0x8086, 0x265B, 0x1043, 0x80A6, "P5GD1-VW Mainboard(0x1043-0x80A6)"},
{0x8086, 0x265B, 0x1458, 0x265A, "GA-8I915ME-G Mainboard(0x1458-0x265A)"},
{0x8086, 0x265B, 0x1462, 0x7028, "915P/G Neo2(0x1462-0x7028)"},
{0x8086, 0x265B, 0x1734, 0x105C, "Scenic W620(0x1734-0x105C)"},
{0x8086, 0x265B, 0xE4BF, 0x0CCD, "CCD-CALYPSO(0xE4BF-0x0CCD)"},
{0x8086, 0x265B, 0xE4BF, 0x0CD3, "CD3-JIVE(0xE4BF-0x0CD3)"},
{0x8086, 0x265B, 0xE4BF, 0x58B1, "XB1(0xE4BF-0x58B1)"},
{0x8086, 0x265C, 0xFFFF, 0xFFFF, "82801FB/FBM/FR/FW/FRW (ICH6 Family) USB2 EHCI Controller(0x265C)"},
{0x8086, 0x265C, 0x1014, 0x0566, "ThinkPad X41(0x1014-0x0566)"},
{0x8086, 0x265C, 0x1028, 0x0177, "Dimension 8400(0x1028-0x0177)"},
{0x8086, 0x265C, 0x1028, 0x0179, "Optiplex GX280(0x1028-0x0179)"},
{0x8086, 0x265C, 0x103C, 0x0934, "Compaq nw8240/nx8220(0x103C-0x0934)"},
{0x8086, 0x265C, 0x103C, 0x0944, "Compaq nc6220 Notebook PC(0x103C-0x0944)"},
{0x8086, 0x265C, 0x103C, 0x099C, "NX6110/NC6120(0x103C-0x099C)"},
{0x8086, 0x265C, 0x1043, 0x80A6, "P5GD1-VW Mainboard(0x1043-0x80A6)"},
{0x8086, 0x265C, 0x1458, 0x5006, "GA-8I915ME-G Mainboard(0x1458-0x5006)"},
{0x8086, 0x265C, 0x1462, 0x7028, "915P/G Neo2(0x1462-0x7028)"},
{0x8086, 0x265C, 0x1734, 0x105C, "Scenic W620(0x1734-0x105C)"},
{0x8086, 0x265C, 0x8086, 0x265C, "Dimension 3100(0x8086-0x265C)"},
{0x8086, 0x265C, 0xE4BF, 0x0CCD, "CCD-CALYPSO(0xE4BF-0x0CCD)"},
{0x8086, 0x265C, 0xE4BF, 0x0CD3, "CD3-JIVE(0xE4BF-0x0CD3)"},
{0x8086, 0x265C, 0xE4BF, 0x58B1, "XB1(0xE4BF-0x58B1)"},
{0x8086, 0x2660, 0xFFFF, 0xFFFF, "82801FB/FBM/FR/FW/FRW (ICH6 Family) PCI Express Port 1(0x2660)"},
{0x8086, 0x2660, 0x103C, 0x0934, "Compaq nw8240 Mobile Workstation(0x103C-0x0934)"},
{0x8086, 0x2660, 0x103C, 0x0944, "Compaq nc6220 Notebook PC(0x103C-0x0944)"},
{0x8086, 0x2660, 0x103C, 0x099C, "NX6110/NC6120(0x103C-0x099C)"},
{0x8086, 0x2660, 0xE4BF, 0x0CCD, "CCD-CALYPSO(0xE4BF-0x0CCD)"},
{0x8086, 0x2660, 0xE4BF, 0x0CD3, "CD3-JIVE(0xE4BF-0x0CD3)"},
{0x8086, 0x2660, 0xE4BF, 0x58B1, "XB1(0xE4BF-0x58B1)"},
{0x8086, 0x2662, 0xFFFF, 0xFFFF, "82801FB/FBM/FR/FW/FRW (ICH6 Family) PCI Express Port 2(0x2662)"},
{0x8086, 0x2662, 0x103C, 0x0934, "Compaq nw8240 Mobile Workstation(0x103C-0x0934)"},
{0x8086, 0x2662, 0x103C, 0x0944, "Compaq nc6220 Notebook PC(0x103C-0x0944)"},
{0x8086, 0x2662, 0xE4BF, 0x0CCD, "CCD-CALYPSO(0xE4BF-0x0CCD)"},
{0x8086, 0x2662, 0xE4BF, 0x0CD3, "CD3-JIVE(0xE4BF-0x0CD3)"},
{0x8086, 0x2662, 0xE4BF, 0x58B1, "XB1(0xE4BF-0x58B1)"},
{0x8086, 0x2664, 0xFFFF, 0xFFFF, "82801FB/FBM/FR/FW/FRW (ICH6 Family) PCI Express Port 3(0x2664)"},
{0x8086, 0x2664, 0xE4BF, 0x0CCD, "CCD-CALYPSO(0xE4BF-0x0CCD)"},
{0x8086, 0x2664, 0xE4BF, 0x0CD3, "CD3-JIVE(0xE4BF-0x0CD3)"},
{0x8086, 0x2664, 0xE4BF, 0x58B1, "XB1(0xE4BF-0x58B1)"},
{0x8086, 0x2666, 0xFFFF, 0xFFFF, "82801FB/FBM/FR/FW/FRW (ICH6 Family) PCI Express Port 4(0x2666)"},
{0x8086, 0x2666, 0xE4BF, 0x0CCD, "CCD-CALYPSO(0xE4BF-0x0CCD)"},
{0x8086, 0x2666, 0xE4BF, 0x0CD3, "CD3-JIVE(0xE4BF-0x0CD3)"},
{0x8086, 0x2666, 0xE4BF, 0x58B1, "XB1(0xE4BF-0x58B1)"},
{0x8086, 0x2668, 0xFFFF, 0xFFFF, "82801FB/FBM/FR/FW/FRW (ICH6 Family) High Definition Audio Controller(0x2668)"},
{0x8086, 0x2668, 0x1014, 0x05B7, "ThinkPad Z60t(0x1014-0x05B7)"},
{0x8086, 0x2668, 0x103C, 0x2A09, "PufferM-UL8E(0x103C-0x2A09)"},
{0x8086, 0x2668, 0x1043, 0x1173, "A6VC(0x1043-0x1173)"},
{0x8086, 0x2668, 0x1043, 0x814E, "P5GD1-VW Mainboard(0x1043-0x814E)"},
{0x8086, 0x2668, 0x1462, 0x7028, "915P/G Neo2(0x1462-0x7028)"},
{0x8086, 0x2668, 0x1AF4, 0x1100, "QEMU Virtual Machine(0x1AF4-0x1100)"},
{0x8086, 0x266A, 0xFFFF, 0xFFFF, "82801FB/FBM/FR/FW/FRW (ICH6 Family) SMBus Controller(0x266A)"},
{0x8086, 0x266A, 0x1014, 0x056B, "ThinkPad X41(0x1014-0x056B)"},
{0x8086, 0x266A, 0x1028, 0x0177, "Dimension 8400(0x1028-0x0177)"},
{0x8086, 0x266A, 0x1028, 0x0179, "Optiplex GX280(0x1028-0x0179)"},
{0x8086, 0x266A, 0x1043, 0x80A6, "P5GD1-VW Mainboard(0x1043-0x80A6)"},
{0x8086, 0x266A, 0x1458, 0x266A, "GA-8I915ME-G Mainboard(0x1458-0x266A)"},
{0x8086, 0x266A, 0x1462, 0x7028, "915P/G Neo2(0x1462-0x7028)"},
{0x8086, 0x266A, 0x1734, 0x105C, "Scenic W620(0x1734-0x105C)"},
{0x8086, 0x266A, 0xE4BF, 0x0CCD, "CCD-CALYPSO(0xE4BF-0x0CCD)"},
{0x8086, 0x266A, 0xE4BF, 0x0CD3, "CD3-JIVE(0xE4BF-0x0CD3)"},
{0x8086, 0x266A, 0xE4BF, 0x58B1, "XB1(0xE4BF-0x58B1)"},
{0x8086, 0x266C, 0xFFFF, 0xFFFF, "82801FB/FBM/FR/FW/FRW (ICH6 Family) LAN Controller(0x266C)"},
{0x8086, 0x266D, 0xFFFF, 0xFFFF, "82801FB/FBM/FR/FW/FRW (ICH6 Family) AC'97 Modem Controller(0x266D)"},
{0x8086, 0x266D, 0x1025, 0x006A, "Conexant AC'97 CoDec (in Acer TravelMate 2410 serie laptop)(0x1025-0x006A)"},
{0x8086, 0x266D, 0x103C, 0x0934, "Compaq nw8240/nx8220(0x103C-0x0934)"},
{0x8086, 0x266D, 0x103C, 0x099C, "NX6110/NC6120(0x103C-0x099C)"},
{0x8086, 0x266E, 0xFFFF, 0xFFFF, "82801FB/FBM/FR/FW/FRW (ICH6 Family) AC'97 Audio Controller(0x266E)"},
{0x8086, 0x266E, 0x1014, 0x0581, "ThinkPad X41 (Analog Devices AD1981B codec)(0x1014-0x0581)"},
{0x8086, 0x266E, 0x1025, 0x006A, "Realtek ALC 655 codec (in Acer TravelMate 2410 serie laptop)(0x1025-0x006A)"},
{0x8086, 0x266E, 0x1028, 0x0177, "Dimension 8400(0x1028-0x0177)"},
{0x8086, 0x266E, 0x1028, 0x0179, "Optiplex GX280(0x1028-0x0179)"},
{0x8086, 0x266E, 0x1028, 0x0182, "Latitude D610 Laptop(0x1028-0x0182)"},
{0x8086, 0x266E, 0x1028, 0x0187, "Precision M70 Laptop(0x1028-0x0187)"},
{0x8086, 0x266E, 0x1028, 0x0188, "Inspiron 6000 laptop(0x1028-0x0188)"},
{0x8086, 0x266E, 0x103C, 0x0934, "Compaq nw8240/nx8220(0x103C-0x0934)"},
{0x8086, 0x266E, 0x103C, 0x0944, "Compaq NC6220(0x103C-0x0944)"},
{0x8086, 0x266E, 0x103C, 0x099C, "NX6110/NC6120(0x103C-0x099C)"},
{0x8086, 0x266E, 0x103C, 0x3006, "DC7100 SFF(DX878AV)(0x103C-0x3006)"},
{0x8086, 0x266E, 0x1458, 0xA002, "GA-8I915ME-G Mainboard(0x1458-0xA002)"},
{0x8086, 0x266E, 0x152D, 0x0745, "Packard Bell A8550 Laptop(0x152D-0x0745)"},
{0x8086, 0x266E, 0x1734, 0x105A, "Scenic W620(0x1734-0x105A)"},
{0x8086, 0x266F, 0xFFFF, 0xFFFF, "82801FB/FBM/FR/FW/FRW (ICH6 Family) IDE Controller(0x266F)"},
{0x8086, 0x266F, 0x1028, 0x0177, "Dimension 8400(0x1028-0x0177)"},
{0x8086, 0x266F, 0x103C, 0x0934, "Compaq nw8240/nx8220(0x103C-0x0934)"},
{0x8086, 0x266F, 0x103C, 0x0944, "Compaq nc6220 Notebook PC(0x103C-0x0944)"},
{0x8086, 0x266F, 0x103C, 0x099C, "NX6110/NC6120(0x103C-0x099C)"},
{0x8086, 0x266F, 0x1043, 0x80A6, "P5GD1-VW Mainboard(0x1043-0x80A6)"},
{0x8086, 0x266F, 0x1458, 0x266F, "GA-8I915ME-G Mainboard(0x1458-0x266F)"},
{0x8086, 0x266F, 0x1462, 0x7028, "915P/G Neo2(0x1462-0x7028)"},
{0x8086, 0x266F, 0x1734, 0x105C, "Scenic W620(0x1734-0x105C)"},
{0x8086, 0x266F, 0xE4BF, 0x0CCD, "CCD-CALYPSO(0xE4BF-0x0CCD)"},
{0x8086, 0x266F, 0xE4BF, 0x0CD3, "CD3-JIVE(0xE4BF-0x0CD3)"},
{0x8086, 0x266F, 0xE4BF, 0x58B1, "XB1(0xE4BF-0x58B1)"},
{0x8086, 0x2670, 0xFFFF, 0xFFFF, "631xESB/632xESB/3100 Chipset LPC Interface Controller(0x2670)"},
{0x8086, 0x2670, 0x103C, 0x31FE, "ProLiant DL140 G3(0x103C-0x31FE)"},
{0x8086, 0x2670, 0x15D9, 0x8680, "X7DVL-E-O motherboard(0x15D9-0x8680)"},
{0x8086, 0x2670, 0x15D9, 0x9680, "X7DBN Motherboard(0x15D9-0x9680)"},
{0x8086, 0x2670, 0x8086, 0x3476, "S5000PSLSATA Server Board(0x8086-0x3476)"},
{0x8086, 0x2680, 0xFFFF, 0xFFFF, "631xESB/632xESB/3100 Chipset SATA IDE Controller(0x2680)"},
{0x8086, 0x2681, 0xFFFF, 0xFFFF, "631xESB/632xESB SATA AHCI Controller(0x2681)"},
{0x8086, 0x2681, 0x103C, 0x31FE, "ProLiant DL140 G3(0x103C-0x31FE)"},
{0x8086, 0x2681, 0x15D9, 0x8680, "X7DVL-E-O motherboard(0x15D9-0x8680)"},
{0x8086, 0x2681, 0x15D9, 0x9680, "X7DBN Motherboard(0x15D9-0x9680)"},
{0x8086, 0x2681, 0x8086, 0x3476, "S5000PSLSATA Server Board(0x8086-0x3476)"},
{0x8086, 0x2682, 0xFFFF, 0xFFFF, "631xESB/632xESB SATA RAID Controller(0x2682)"},
{0x8086, 0x2682, 0x103C, 0x31FE, "Adaptec Serial ATA HostRAID(0x103C-0x31FE)"},
{0x8086, 0x2683, 0xFFFF, 0xFFFF, "631xESB/632xESB SATA RAID Controller(0x2683)"},
{0x8086, 0x2688, 0xFFFF, 0xFFFF, "631xESB/632xESB/3100 Chipset UHCI USB Controller #1(0x2688)"},
{0x8086, 0x2688, 0x1028, 0x01BB, "PowerEdge 1955 onboard USB(0x1028-0x01BB)"},
{0x8086, 0x2688, 0x1028, 0x01F0, "PowerEdge R900 onboard USB(0x1028-0x01F0)"},
{0x8086, 0x2688, 0x103C, 0x31FE, "ProLiant DL140 G3, DL360 G5(0x103C-0x31FE)"},
{0x8086, 0x2688, 0x15D9, 0x8680, "X7DVL-E-O motherboard(0x15D9-0x8680)"},
{0x8086, 0x2688, 0x15D9, 0x9680, "X7DBN Motherboard(0x15D9-0x9680)"},
{0x8086, 0x2688, 0x8086, 0x3476, "S5000PSLSATA Server Board(0x8086-0x3476)"},
{0x8086, 0x2689, 0xFFFF, 0xFFFF, "631xESB/632xESB/3100 Chipset UHCI USB Controller #2(0x2689)"},
{0x8086, 0x2689, 0x1028, 0x01BB, "PowerEdge 1955 onboard USB(0x1028-0x01BB)"},
{0x8086, 0x2689, 0x1028, 0x01F0, "PowerEdge R900 onboard USB(0x1028-0x01F0)"},
{0x8086, 0x2689, 0x103C, 0x31FE, "ProLiant DL140 G3, DL360 G5(0x103C-0x31FE)"},
{0x8086, 0x2689, 0x15D9, 0x8680, "X7DVL-E-O motherboard(0x15D9-0x8680)"},
{0x8086, 0x2689, 0x15D9, 0x9680, "X7DBN Motherboard(0x15D9-0x9680)"},
{0x8086, 0x2689, 0x8086, 0x3476, "S5000PSLSATA Server Board(0x8086-0x3476)"},
{0x8086, 0x268A, 0xFFFF, 0xFFFF, "631xESB/632xESB/3100 Chipset UHCI USB Controller #3(0x268A)"},
{0x8086, 0x268A, 0x1028, 0x01F0, "PowerEdge R900 onboard USB(0x1028-0x01F0)"},
{0x8086, 0x268A, 0x103C, 0x31FE, "ProLiant DL140 G3, DL360 G5(0x103C-0x31FE)"},
{0x8086, 0x268A, 0x15D9, 0x8680, "X7DVL-E-O motherboard(0x15D9-0x8680)"},
{0x8086, 0x268A, 0x15D9, 0x9680, "X7DBN Motherboard(0x15D9-0x9680)"},
{0x8086, 0x268A, 0x8086, 0x3476, "S5000PSLSATA Server Board(0x8086-0x3476)"},
{0x8086, 0x268B, 0xFFFF, 0xFFFF, "631xESB/632xESB/3100 Chipset UHCI USB Controller #4(0x268B)"},
{0x8086, 0x268B, 0x1028, 0x01F0, "PowerEdge R900 onboard USB(0x1028-0x01F0)"},
{0x8086, 0x268B, 0x103C, 0x31FE, "ProLiant DL360 G5(0x103C-0x31FE)"},
{0x8086, 0x268B, 0x15D9, 0x8680, "X7DVL-E-O motherboard(0x15D9-0x8680)"},
{0x8086, 0x268B, 0x8086, 0x3476, "S5000PSLSATA Server Board(0x8086-0x3476)"},
{0x8086, 0x268C, 0xFFFF, 0xFFFF, "631xESB/632xESB/3100 Chipset EHCI USB2 Controller(0x268C)"},
{0x8086, 0x268C, 0x1028, 0x01BB, "PowerEdge 1955 onboard USB(0x1028-0x01BB)"},
{0x8086, 0x268C, 0x1028, 0x01F0, "PowerEdge R900 onboard USB(0x1028-0x01F0)"},
{0x8086, 0x268C, 0x103C, 0x31FE, "ProLiant DL140 G3, DL360 G5(0x103C-0x31FE)"},
{0x8086, 0x268C, 0x15D9, 0x8680, "X7DVL-E-O motherboard(0x15D9-0x8680)"},
{0x8086, 0x268C, 0x15D9, 0x9680, "X7DBN Motherboard(0x15D9-0x9680)"},
{0x8086, 0x268C, 0x8086, 0x3476, "S5000PSLSATA Server Board(0x8086-0x3476)"},
{0x8086, 0x2690, 0xFFFF, 0xFFFF, "631xESB/632xESB/3100 Chipset PCI Express Root Port 1(0x2690)"},
{0x8086, 0x2690, 0x103C, 0x31FE, "ProLiant DL140 G3(0x103C-0x31FE)"},
{0x8086, 0x2690, 0x15D9, 0x9680, "X7DBN Motherboard(0x15D9-0x9680)"},
{0x8086, 0x2692, 0xFFFF, 0xFFFF, "631xESB/632xESB/3100 Chipset PCI Express Root Port 2(0x2692)"},
{0x8086, 0x2692, 0x103C, 0x31FE, "ProLiant DL140 G3(0x103C-0x31FE)"},
{0x8086, 0x2694, 0xFFFF, 0xFFFF, "631xESB/632xESB/3100 Chipset PCI Express Root Port 3(0x2694)"},
{0x8086, 0x2696, 0xFFFF, 0xFFFF, "631xESB/632xESB/3100 Chipset PCI Express Root Port 4(0x2696)"},
{0x8086, 0x2698, 0xFFFF, 0xFFFF, "631xESB/632xESB AC '97 Audio Controller(0x2698)"},
{0x8086, 0x2699, 0xFFFF, 0xFFFF, "631xESB/632xESB AC '97 Modem Controller(0x2699)"},
{0x8086, 0x269A, 0xFFFF, 0xFFFF, "631xESB/632xESB High Definition Audio Controller(0x269A)"},
{0x8086, 0x269B, 0xFFFF, 0xFFFF, "631xESB/632xESB/3100 Chipset SMBus Controller(0x269B)"},
{0x8086, 0x269B, 0x103C, 0x31FE, "ProLiant DL140 G3(0x103C-0x31FE)"},
{0x8086, 0x269B, 0x15D9, 0x8680, "X7DVL-E-O motherboard(0x15D9-0x8680)"},
{0x8086, 0x269B, 0x15D9, 0x9680, "X7DBN Motherboard(0x15D9-0x9680)"},
{0x8086, 0x269B, 0x8086, 0x3476, "S5000PSLSATA Server Board(0x8086-0x3476)"},
{0x8086, 0x269E, 0xFFFF, 0xFFFF, "631xESB/632xESB IDE Controller(0x269E)"},
{0x8086, 0x269E, 0x103C, 0x31FE, "ProLiant DL140 G3, DL360 G5(0x103C-0x31FE)"},
{0x8086, 0x269E, 0x15D9, 0x8680, "X7DVL-E-O motherboard(0x15D9-0x8680)"},
{0x8086, 0x269E, 0x15D9, 0x9680, "X7DBN Motherboard(0x15D9-0x9680)"},
{0x8086, 0x2700, 0xFFFF, 0xFFFF, "Optane SSD 900P Series(0x2700)"},
{0x8086, 0x2700, 0x8086, 0x3900, "900P Series [Add-in Card](0x8086-0x3900)"},
{0x8086, 0x2700, 0x8086, 0x3901, "900P Series [2.5\" SFF](0x8086-0x3901)"},
{0x8086, 0x2701, 0xFFFF, 0xFFFF, "NVMe Datacenter SSD [Optane](0x2701)"},
{0x8086, 0x2701, 0x1028, 0x2000, "Express Flash NVMe [Optane] 375GB 2.5\" U.2 (P4800X)(0x1028-0x2000)"},
{0x8086, 0x2701, 0x1028, 0x2001, "Express Flash NVMe [Optane] 750GB 2.5\" U.2 (P4800X)(0x1028-0x2001)"},
{0x8086, 0x2701, 0x1028, 0x2002, "Express Flash NVMe [Optane] 750GB AIC (P4800X)(0x1028-0x2002)"},
{0x8086, 0x2701, 0x1028, 0x200A, "Express Flash NVMe [Optane] 375GB AIC (P4800X)(0x1028-0x200A)"},
{0x8086, 0x2701, 0x8086, 0x3904, "NVMe Datacenter SSD [Optane] x4 AIC (P4800X)(0x8086-0x3904)"},
{0x8086, 0x2701, 0x8086, 0x3905, "NVMe Datacenter SSD [Optane] 15mm 2.5\" U.2 (P4800X)(0x8086-0x3905)"},
{0x8086, 0x2723, 0xFFFF, 0xFFFF, "Wi-Fi 6 AX200(0x2723)"},
{0x8086, 0x2723, 0x1A56, 0x1654, "Killer Wi-Fi 6 AX1650x (AX200NGW)(0x1A56-0x1654)"},
{0x8086, 0x2723, 0x8086, 0x0084, "Wi-Fi 6 AX200NGW(0x8086-0x0084)"},
{0x8086, 0x2725, 0xFFFF, 0xFFFF, "Wi-Fi 6E(802.11ax) AX210/AX1675* 2x2 [Typhoon Peak](0x2725)"},
{0x8086, 0x2725, 0x1A56, 0x1673, "Killer AX1675w 160MHz(0x1A56-0x1673)"},
{0x8086, 0x2725, 0x1A56, 0x1674, "Killer Wi-Fi 6E AX1675x 160MHz(0x1A56-0x1674)"},
{0x8086, 0x2725, 0x8086, 0x0020, "Wi-Fi 6 AX210 160MHz(0x8086-0x0020)"},
{0x8086, 0x2725, 0x8086, 0x0024, "Wi-Fi 6 AX210 160MHz(0x8086-0x0024)"},
{0x8086, 0x2725, 0x8086, 0x0310, "Wi-Fi 6 AX210 160MHz(0x8086-0x0310)"},
{0x8086, 0x2725, 0x8086, 0x0510, "Wi-Fi 6 AX210 160MHz(0x8086-0x0510)"},
{0x8086, 0x2725, 0x8086, 0x0A10, "Wi-Fi 6 AX210 160MHz(0x8086-0x0A10)"},
{0x8086, 0x2725, 0x8086, 0x2020, "Wi-Fi 6 AX210 160MHz(0x8086-0x2020)"},
{0x8086, 0x2725, 0x8086, 0x4020, "Wi-Fi 6 AX210 160MHz(0x8086-0x4020)"},
{0x8086, 0x2725, 0x8086, 0x6020, "Wi-Fi 6 AX210 160MHz(0x8086-0x6020)"},
{0x8086, 0x2725, 0x8086, 0x6024, "Wi-Fi 6 AX210 160MHz(0x8086-0x6024)"},
{0x8086, 0x2725, 0x8086, 0xE020, "Wi-Fi 6 AX210 160MHz(0x8086-0xE020)"},
{0x8086, 0x2725, 0x8086, 0xE024, "Wi-Fi 6 AX210 160MHz(0x8086-0xE024)"},
{0x8086, 0x272B, 0xFFFF, 0xFFFF, "Wi-Fi 7(802.11be) AX1775*/AX1790*/BE20*/BE401/BE1750* 2x2(0x272B)"},
{0x8086, 0x272B, 0x8086, 0x00F0, "BE200 320MHz [Gale Peak](0x8086-0x00F0)"},
{0x8086, 0x272B, 0x8086, 0x00F4, "BE200 320MHz [Gale Peak](0x8086-0x00F4)"},
{0x8086, 0x272B, 0x8086, 0x02F4, "BE202 160MHz [Misty Peak](0x8086-0x02F4)"},
{0x8086, 0x272B, 0x8086, 0x40F0, "BE200 320MHz [Gale Peak](0x8086-0x40F0)"},
{0x8086, 0x272B, 0x8086, 0x42F4, "BE202 160MHz [Misty Peak](0x8086-0x42F4)"},
{0x8086, 0x272B, 0x8086, 0xE0F4, "BE200 320MHz [Gale Peak](0x8086-0xE0F4)"},
{0x8086, 0x2770, 0xFFFF, 0xFFFF, "82945G/GZ/P/PL Memory Controller Hub(0x2770)"},
{0x8086, 0x2770, 0x1028, 0x01AD, "OptiPlex GX620(0x1028-0x01AD)"},
{0x8086, 0x2770, 0x103C, 0x2A3B, "Pavilion A1512X(0x103C-0x2A3B)"},
{0x8086, 0x2770, 0x1043, 0x817A, "P5LD2-VM Mainboard(0x1043-0x817A)"},
{0x8086, 0x2770, 0x107B, 0x5048, "E4500(0x107B-0x5048)"},
{0x8086, 0x2770, 0x1462, 0x7418, "Wind PC MS-7418(0x1462-0x7418)"},
{0x8086, 0x2770, 0x1849, 0x2770, "ConRoe1333-D667(0x1849-0x2770)"},
{0x8086, 0x2770, 0x8086, 0x544E, "DeskTop Board D945GTP(0x8086-0x544E)"},
{0x8086, 0x2771, 0xFFFF, 0xFFFF, "82945G/GZ/P/PL PCI Express Root Port(0x2771)"},
{0x8086, 0x2772, 0xFFFF, 0xFFFF, "82945G/GZ Integrated Graphics Controller(0x2772)"},
{0x8086, 0x2772, 0x103C, 0x2A3B, "Pavilion A1512X(0x103C-0x2A3B)"},
{0x8086, 0x2772, 0x1462, 0x7418, "Wind PC MS-7418(0x1462-0x7418)"},
{0x8086, 0x2772, 0x1849, 0x2772, "ConRoe1333-D667(0x1849-0x2772)"},
{0x8086, 0x2772, 0x8086, 0x544E, "DeskTop Board D945GTP(0x8086-0x544E)"},
{0x8086, 0x2772, 0x8086, 0xD605, "Desktop Board D945GCCR(0x8086-0xD605)"},
{0x8086, 0x2774, 0xFFFF, 0xFFFF, "82955X Memory Controller Hub(0x2774)"},
{0x8086, 0x2775, 0xFFFF, 0xFFFF, "82955X PCI Express Root Port(0x2775)"},
{0x8086, 0x2776, 0xFFFF, 0xFFFF, "82945G/GZ Integrated Graphics Controller(0x2776)"},
{0x8086, 0x2778, 0xFFFF, 0xFFFF, "E7230/3000/3010 Memory Controller Hub(0x2778)"},
{0x8086, 0x2778, 0x1028, 0x01DF, "PowerEdge SC440(0x1028-0x01DF)"},
{0x8086, 0x2778, 0x1028, 0x01E6, "PowerEdge 860(0x1028-0x01E6)"},
{0x8086, 0x2779, 0xFFFF, 0xFFFF, "E7230/3000/3010 PCI Express Root Port(0x2779)"},
{0x8086, 0x277A, 0xFFFF, 0xFFFF, "82975X/3010 PCI Express Root Port(0x277A)"},
{0x8086, 0x277C, 0xFFFF, 0xFFFF, "82975X Memory Controller Hub(0x277C)"},
{0x8086, 0x277C, 0x1043, 0x8178, "P5WDG2 WS Professional motherboard(0x1043-0x8178)"},
{0x8086, 0x277D, 0xFFFF, 0xFFFF, "82975X PCI Express Root Port(0x277D)"},
{0x8086, 0x2780, 0xFFFF, 0xFFFF, "82915G/GV/GL/910GL [Grantsdale] Graphics Device(0x2780)"},
{0x8086, 0x2782, 0xFFFF, 0xFFFF, "82915G Integrated Graphics Controller(0x2782)"},
{0x8086, 0x2782, 0x1043, 0x2582, "P5GD1-VW Mainboard(0x1043-0x2582)"},
{0x8086, 0x2782, 0x1734, 0x105B, "Scenic W620(0x1734-0x105B)"},
{0x8086, 0x2792, 0xFFFF, 0xFFFF, "Mobile 915GM/GMS/910GML Express Graphics Controller(0x2792)"},
{0x8086, 0x2792, 0x1014, 0x0582, "ThinkPad X41(0x1014-0x0582)"},
{0x8086, 0x2792, 0x103C, 0x099C, "NX6110/NC6120(0x103C-0x099C)"},
{0x8086, 0x2792, 0x103C, 0x308A, "Compaq nc6220 Notebook PC(0x103C-0x308A)"},
{0x8086, 0x2792, 0x1043, 0x1881, "GMA 900 915GM Integrated Graphics(0x1043-0x1881)"},
{0x8086, 0x2792, 0xE4BF, 0x0CCD, "CCD-CALYPSO(0xE4BF-0x0CCD)"},
{0x8086, 0x2792, 0xE4BF, 0x0CD3, "CD3-JIVE(0xE4BF-0x0CD3)"},
{0x8086, 0x2792, 0xE4BF, 0x58B1, "XB1(0xE4BF-0x58B1)"},
{0x8086, 0x27A0, 0xFFFF, 0xFFFF, "Mobile 945GM/PM/GMS, 943/940GML and 945GT Express Memory Controller Hub(0x27A0)"},
{0x8086, 0x27A0, 0x1025, 0x006C, "9814 WKMI(0x1025-0x006C)"},
{0x8086, 0x27A0, 0x1028, 0x01D7, "XPS M1210(0x1028-0x01D7)"},
{0x8086, 0x27A0, 0x103C, 0x309F, "Compaq nx9420 Notebook(0x103C-0x309F)"},
{0x8086, 0x27A0, 0x103C, 0x30A1, "NC2400(0x103C-0x30A1)"},
{0x8086, 0x27A0, 0x103C, 0x30A3, "Compaq nw8440(0x103C-0x30A3)"},
{0x8086, 0x27A0, 0x103C, 0x30D5, "530 Laptop(0x103C-0x30D5)"},
{0x8086, 0x27A0, 0x1043, 0x1237, "A6J-Q008(0x1043-0x1237)"},
{0x8086, 0x27A0, 0x1071, 0x8209, "Medion MIM 2240 Notebook PC [MD98100](0x1071-0x8209)"},
{0x8086, 0x27A0, 0x17AA, 0x2015, "ThinkPad T60(0x17AA-0x2015)"},
{0x8086, 0x27A0, 0x17AA, 0x2017, "ThinkPad R60/T60/X60 series(0x17AA-0x2017)"},
{0x8086, 0x27A1, 0xFFFF, 0xFFFF, "Mobile 945GM/PM/GMS, 943/940GML and 945GT Express PCI Express Root Port(0x27A1)"},
{0x8086, 0x27A1, 0x103C, 0x309F, "Compaq nx9420 Notebook(0x103C-0x309F)"},
{0x8086, 0x27A1, 0x103C, 0x30A3, "Compaq nw8440(0x103C-0x30A3)"},
{0x8086, 0x27A1, 0x1071, 0x8209, "Medion MIM 2240 Notebook PC [MD98100](0x1071-0x8209)"},
{0x8086, 0x27A2, 0xFFFF, 0xFFFF, "Mobile 945GM/GMS, 943/940GML Express Integrated Graphics Controller(0x27A2)"},
{0x8086, 0x27A2, 0x103C, 0x30A1, "NC2400(0x103C-0x30A1)"},
{0x8086, 0x27A2, 0x103C, 0x30D5, "530 Laptop(0x103C-0x30D5)"},
{0x8086, 0x27A2, 0x17AA, 0x201A, "ThinkPad R60/T60/X60 series(0x17AA-0x201A)"},
{0x8086, 0x27A2, 0x9902, 0x1584, "CCE MPL-D10H120F(0x9902-0x1584)"},
{0x8086, 0x27A6, 0xFFFF, 0xFFFF, "Mobile 945GM/GMS/GME, 943/940GML Express Integrated Graphics Controller(0x27A6)"},
{0x8086, 0x27A6, 0x103C, 0x30A1, "NC2400(0x103C-0x30A1)"},
{0x8086, 0x27A6, 0x103C, 0x30D5, "530 Laptop(0x103C-0x30D5)"},
{0x8086, 0x27A6, 0x1775, 0x11CC, "CC11/CL11 integrated graphics (secondary)(0x1775-0x11CC)"},
{0x8086, 0x27A6, 0x17AA, 0x201A, "ThinkPad R60/T60/X60 series(0x17AA-0x201A)"},
{0x8086, 0x27AC, 0xFFFF, 0xFFFF, "Mobile 945GSE Express Memory Controller Hub(0x27AC)"},
{0x8086, 0x27AC, 0x1775, 0x11CC, "CC11/CL11(0x1775-0x11CC)"},
{0x8086, 0x27AD, 0xFFFF, 0xFFFF, "Mobile 945GSE Express PCI Express Root Port(0x27AD)"},
{0x8086, 0x27AE, 0xFFFF, 0xFFFF, "Mobile 945GSE Express Integrated Graphics Controller(0x27AE)"},
{0x8086, 0x27AE, 0x1775, 0x11CC, "CC11/CL11 integrated graphics (primary)(0x1775-0x11CC)"},
{0x8086, 0x27B0, 0xFFFF, 0xFFFF, "82801GH (ICH7DH) LPC Interface Bridge(0x27B0)"},
{0x8086, 0x27B0, 0x103C, 0x2A3B, "Pavilion A1512X(0x103C-0x2A3B)"},
{0x8086, 0x27B0, 0x8086, 0x544E, "DeskTop Board D945GTP(0x8086-0x544E)"},
{0x8086, 0x27B8, 0xFFFF, 0xFFFF, "82801GB/GR (ICH7 Family) LPC Interface Bridge(0x27B8)"},
{0x8086, 0x27B8, 0x1028, 0x01E6, "PowerEdge 860(0x1028-0x01E6)"},
{0x8086, 0x27B8, 0x103C, 0x2A8C, "Compaq 500B Microtower(0x103C-0x2A8C)"},
{0x8086, 0x27B8, 0x1043, 0x8179, "P5B-MX/WiFi-AP, P5KPL-VM Motherboard(0x1043-0x8179)"},
{0x8086, 0x27B8, 0x107B, 0x5048, "E4500(0x107B-0x5048)"},
{0x8086, 0x27B8, 0x1462, 0x7418, "Wind PC MS-7418(0x1462-0x7418)"},
{0x8086, 0x27B8, 0x1775, 0x11CC, "CC11/CL11(0x1775-0x11CC)"},
{0x8086, 0x27B8, 0x8086, 0x544E, "DeskTop Board D945GTP(0x8086-0x544E)"},
{0x8086, 0x27B9, 0xFFFF, 0xFFFF, "82801GBM (ICH7-M) LPC Interface Bridge(0x27B9)"},
{0x8086, 0x27B9, 0x1028, 0x01D7, "XPS M1210(0x1028-0x01D7)"},
{0x8086, 0x27B9, 0x103C, 0x309F, "Compaq nx9420 Notebook(0x103C-0x309F)"},
{0x8086, 0x27B9, 0x103C, 0x30A1, "NC2400(0x103C-0x30A1)"},
{0x8086, 0x27B9, 0x103C, 0x30A3, "Compaq nw8440(0x103C-0x30A3)"},
{0x8086, 0x27B9, 0x103C, 0x30D5, "530 Laptop(0x103C-0x30D5)"},
{0x8086, 0x27B9, 0x1071, 0x8209, "Medion MIM 2240 Notebook PC [MD98100](0x1071-0x8209)"},
{0x8086, 0x27B9, 0x10F7, 0x8338, "Panasonic CF-Y5 laptop(0x10F7-0x8338)"},
{0x8086, 0x27B9, 0x17AA, 0x2009, "ThinkPad R60/T60/X60 series(0x17AA-0x2009)"},
{0x8086, 0x27BC, 0xFFFF, 0xFFFF, "NM10 Family LPC Controller(0x27BC)"},
{0x8086, 0x27BC, 0x1043, 0x83AD, "Eee PC 1015PX(0x1043-0x83AD)"},
{0x8086, 0x27BC, 0x105B, 0x0D7C, "D270S/D250S Motherboard(0x105B-0x0D7C)"},
{0x8086, 0x27BC, 0x144D, 0xC072, "Notebook N150P(0x144D-0xC072)"},
{0x8086, 0x27BC, 0x1458, 0x5001, "GA-D525TUD(0x1458-0x5001)"},
{0x8086, 0x27BC, 0x8086, 0x4F4D, "DeskTop Board D510MO(0x8086-0x4F4D)"},
{0x8086, 0x27BC, 0x8086, 0x544B, "Desktop Board D425KT(0x8086-0x544B)"},
{0x8086, 0x27BD, 0xFFFF, 0xFFFF, "82801GHM (ICH7-M DH) LPC Interface Bridge(0x27BD)"},
{0x8086, 0x27BD, 0x1025, 0x006C, "9814 WKMI(0x1025-0x006C)"},
{0x8086, 0x27C0, 0xFFFF, 0xFFFF, "NM10/ICH7 Family SATA Controller [IDE mode](0x27C0)"},
{0x8086, 0x27C0, 0x1028, 0x01AD, "OptiPlex GX620(0x1028-0x01AD)"},
{0x8086, 0x27C0, 0x1028, 0x01DF, "PowerEdge SC440(0x1028-0x01DF)"},
{0x8086, 0x27C0, 0x1028, 0x01E6, "PowerEdge 860(0x1028-0x01E6)"},
{0x8086, 0x27C0, 0x103C, 0x2A8C, "Compaq 500B Microtower(0x103C-0x2A8C)"},
{0x8086, 0x27C0, 0x1043, 0x8179, "P5B-MX/WiFi-AP, P5KPL-VM Motherboard(0x1043-0x8179)"},
{0x8086, 0x27C0, 0x107B, 0x5048, "E4500(0x107B-0x5048)"},
{0x8086, 0x27C0, 0x1462, 0x2310, "MSI Hetis 945(0x1462-0x2310)"},
{0x8086, 0x27C0, 0x1462, 0x7236, "945P Neo3-F Rev. 2.2 motherboard(0x1462-0x7236)"},
{0x8086, 0x27C0, 0x1462, 0x7418, "Wind PC MS-7418(0x1462-0x7418)"},
{0x8086, 0x27C0, 0x1775, 0x11CC, "CC11/CL11(0x1775-0x11CC)"},
{0x8086, 0x27C0, 0x8086, 0x544B, "Desktop Board D425KT(0x8086-0x544B)"},
{0x8086, 0x27C0, 0x8086, 0x544E, "DeskTop Board D945GTP(0x8086-0x544E)"},
{0x8086, 0x27C1, 0xFFFF, 0xFFFF, "NM10/ICH7 Family SATA Controller [AHCI mode](0x27C1)"},
{0x8086, 0x27C1, 0x1028, 0x01DF, "PowerEdge SC440(0x1028-0x01DF)"},
{0x8086, 0x27C1, 0x103C, 0x2A3B, "Pavilion A1512X(0x103C-0x2A3B)"},
{0x8086, 0x27C1, 0x1043, 0x83AD, "Eee PC 1015PX(0x1043-0x83AD)"},
{0x8086, 0x27C1, 0x105B, 0x0D7C, "D270S/D250S Motherboard(0x105B-0x0D7C)"},
{0x8086, 0x27C1, 0x144D, 0xC072, "Notebook N150P(0x144D-0xC072)"},
{0x8086, 0x27C1, 0x1458, 0xB005, "GA-D525TUD(0x1458-0xB005)"},
{0x8086, 0x27C1, 0x1775, 0x11CC, "CC11/CL11(0x1775-0x11CC)"},
{0x8086, 0x27C1, 0x8086, 0x4F4D, "DeskTop Board D510MO(0x8086-0x4F4D)"},
{0x8086, 0x27C1, 0x8086, 0x5842, "DeskTop Board D975XBX(0x8086-0x5842)"},
{0x8086, 0x27C3, 0xFFFF, 0xFFFF, "82801GR/GDH (ICH7R/ICH7DH) SATA Controller [RAID mode](0x27C3)"},
{0x8086, 0x27C3, 0x1775, 0x11CC, "CC11/CL11(0x1775-0x11CC)"},
{0x8086, 0x27C3, 0x8086, 0x544E, "DeskTop Board D945GTP(0x8086-0x544E)"},
{0x8086, 0x27C4, 0xFFFF, 0xFFFF, "82801GBM/GHM (ICH7-M Family) SATA Controller [IDE mode](0x27C4)"},
{0x8086, 0x27C4, 0x1025, 0x006C, "9814 WKMI(0x1025-0x006C)"},
{0x8086, 0x27C4, 0x1028, 0x01D7, "XPS M1210(0x1028-0x01D7)"},
{0x8086, 0x27C4, 0x1071, 0x8209, "Medion MIM 2240 Notebook PC [MD98100](0x1071-0x8209)"},
{0x8086, 0x27C4, 0x17AA, 0x200E, "ThinkPad T60(0x17AA-0x200E)"},
{0x8086, 0x27C5, 0xFFFF, 0xFFFF, "82801GBM/GHM (ICH7-M Family) SATA Controller [AHCI mode](0x27C5)"},
{0x8086, 0x27C5, 0x103C, 0x309F, "Compaq nx9420 Notebook(0x103C-0x309F)"},
{0x8086, 0x27C5, 0x103C, 0x30A3, "Compaq nw8440(0x103C-0x30A3)"},
{0x8086, 0x27C5, 0x103C, 0x30D5, "530 Laptop(0x103C-0x30D5)"},
{0x8086, 0x27C5, 0x17AA, 0x200D, "ThinkPad R60/T60/X60 series(0x17AA-0x200D)"},
{0x8086, 0x27C6, 0xFFFF, 0xFFFF, "82801GHM (ICH7-M DH) SATA Controller [RAID mode](0x27C6)"},
{0x8086, 0x27C8, 0xFFFF, 0xFFFF, "NM10/ICH7 Family USB UHCI Controller #1(0x27C8)"},
{0x8086, 0x27C8, 0x1025, 0x006C, "9814 WKMI(0x1025-0x006C)"},
{0x8086, 0x27C8, 0x1028, 0x01AD, "OptiPlex GX620(0x1028-0x01AD)"},
{0x8086, 0x27C8, 0x1028, 0x01D7, "XPS M1210(0x1028-0x01D7)"},
{0x8086, 0x27C8, 0x1028, 0x01DF, "PowerEdge SC440(0x1028-0x01DF)"},
{0x8086, 0x27C8, 0x1028, 0x01E6, "PowerEdge 860(0x1028-0x01E6)"},
{0x8086, 0x27C8, 0x103C, 0x2A3B, "Pavilion A1512X(0x103C-0x2A3B)"},
{0x8086, 0x27C8, 0x103C, 0x2A8C, "Compaq 500B Microtower(0x103C-0x2A8C)"},
{0x8086, 0x27C8, 0x103C, 0x309F, "Compaq nx9420 Notebook(0x103C-0x309F)"},
{0x8086, 0x27C8, 0x103C, 0x30A1, "NC2400(0x103C-0x30A1)"},
{0x8086, 0x27C8, 0x103C, 0x30A3, "Compaq nw8440(0x103C-0x30A3)"},
{0x8086, 0x27C8, 0x103C, 0x30D5, "530 Laptop(0x103C-0x30D5)"},
{0x8086, 0x27C8, 0x1043, 0x1237, "A6J-Q008(0x1043-0x1237)"},
{0x8086, 0x27C8, 0x1043, 0x8179, "P5B-MX/WiFi-AP, P5KPL-VM, P5LD2-VM Mainboard(0x1043-0x8179)"},
{0x8086, 0x27C8, 0x1043, 0x83AD, "Eee PC 1015PX(0x1043-0x83AD)"},
{0x8086, 0x27C8, 0x105B, 0x0D7C, "D270S/D250S Motherboard(0x105B-0x0D7C)"},
{0x8086, 0x27C8, 0x1071, 0x8209, "Medion MIM 2240 Notebook PC [MD98100](0x1071-0x8209)"},
{0x8086, 0x27C8, 0x107B, 0x5048, "E4500(0x107B-0x5048)"},
{0x8086, 0x27C8, 0x144D, 0xC072, "Notebook N150P(0x144D-0xC072)"},
{0x8086, 0x27C8, 0x1458, 0x5004, "GA-D525TUD(0x1458-0x5004)"},
{0x8086, 0x27C8, 0x1462, 0x7418, "Wind PC MS-7418(0x1462-0x7418)"},
{0x8086, 0x27C8, 0x1775, 0x11CC, "CC11/CL11(0x1775-0x11CC)"},
{0x8086, 0x27C8, 0x17AA, 0x200A, "ThinkPad R60/T60/X60 series(0x17AA-0x200A)"},
{0x8086, 0x27C8, 0x8086, 0x4F4D, "DeskTop Board D510MO(0x8086-0x4F4D)"},
{0x8086, 0x27C8, 0x8086, 0x544B, "Desktop Board D425KT(0x8086-0x544B)"},
{0x8086, 0x27C8, 0x8086, 0x544E, "DeskTop Board D945GTP(0x8086-0x544E)"},
{0x8086, 0x27C9, 0xFFFF, 0xFFFF, "NM10/ICH7 Family USB UHCI Controller #2(0x27C9)"},
{0x8086, 0x27C9, 0x1025, 0x006C, "9814 WKMI(0x1025-0x006C)"},
{0x8086, 0x27C9, 0x1028, 0x01AD, "OptiPlex GX620(0x1028-0x01AD)"},
{0x8086, 0x27C9, 0x1028, 0x01D7, "XPS M1210(0x1028-0x01D7)"},
{0x8086, 0x27C9, 0x1028, 0x01DF, "PowerEdge SC440(0x1028-0x01DF)"},
{0x8086, 0x27C9, 0x1028, 0x01E6, "PowerEdge 860(0x1028-0x01E6)"},
{0x8086, 0x27C9, 0x103C, 0x2A3B, "Pavilion A1512X(0x103C-0x2A3B)"},
{0x8086, 0x27C9, 0x103C, 0x2A8C, "Compaq 500B Microtower(0x103C-0x2A8C)"},
{0x8086, 0x27C9, 0x103C, 0x309F, "Compaq nx9420 Notebook(0x103C-0x309F)"},
{0x8086, 0x27C9, 0x103C, 0x30A1, "NC2400(0x103C-0x30A1)"},
{0x8086, 0x27C9, 0x103C, 0x30A3, "Compaq nw8440(0x103C-0x30A3)"},
{0x8086, 0x27C9, 0x1043, 0x1237, "A6J-Q008(0x1043-0x1237)"},
{0x8086, 0x27C9, 0x1043, 0x8179, "P5B-MX/WiFi-AP, P5KPL-VM, P5LD2-VM Mainboard(0x1043-0x8179)"},
{0x8086, 0x27C9, 0x1043, 0x83AD, "Eee PC 1015PX(0x1043-0x83AD)"},
{0x8086, 0x27C9, 0x105B, 0x0D7C, "D270S/D250S Motherboard(0x105B-0x0D7C)"},
{0x8086, 0x27C9, 0x1071, 0x8209, "Medion MIM 2240 Notebook PC [MD98100](0x1071-0x8209)"},
{0x8086, 0x27C9, 0x107B, 0x5048, "E4500(0x107B-0x5048)"},
{0x8086, 0x27C9, 0x144D, 0xC072, "Notebook N150P(0x144D-0xC072)"},
{0x8086, 0x27C9, 0x1458, 0x5004, "GA-D525TUD(0x1458-0x5004)"},
{0x8086, 0x27C9, 0x1462, 0x7418, "Wind PC MS-7418(0x1462-0x7418)"},
{0x8086, 0x27C9, 0x1775, 0x11CC, "CC11/CL11(0x1775-0x11CC)"},
{0x8086, 0x27C9, 0x17AA, 0x200A, "ThinkPad R60/T60/X60 series(0x17AA-0x200A)"},
{0x8086, 0x27C9, 0x8086, 0x4F4D, "DeskTop Board D510MO(0x8086-0x4F4D)"},
{0x8086, 0x27C9, 0x8086, 0x544B, "Desktop Board D425KT(0x8086-0x544B)"},
{0x8086, 0x27C9, 0x8086, 0x544E, "DeskTop Board D945GTP(0x8086-0x544E)"},
{0x8086, 0x27CA, 0xFFFF, 0xFFFF, "NM10/ICH7 Family USB UHCI Controller #3(0x27CA)"},
{0x8086, 0x27CA, 0x1025, 0x006C, "9814 WKMI(0x1025-0x006C)"},
{0x8086, 0x27CA, 0x1028, 0x01AD, "OptiPlex GX620(0x1028-0x01AD)"},
{0x8086, 0x27CA, 0x1028, 0x01D7, "XPS M1210(0x1028-0x01D7)"},
{0x8086, 0x27CA, 0x1028, 0x01DF, "PowerEdge SC440(0x1028-0x01DF)"},
{0x8086, 0x27CA, 0x1028, 0x01E6, "PowerEdge 860(0x1028-0x01E6)"},
{0x8086, 0x27CA, 0x103C, 0x2A3B, "Pavilion A1512X(0x103C-0x2A3B)"},
{0x8086, 0x27CA, 0x103C, 0x2A8C, "Compaq 500B Microtower(0x103C-0x2A8C)"},
{0x8086, 0x27CA, 0x103C, 0x309F, "Compaq nx9420 Notebook(0x103C-0x309F)"},
{0x8086, 0x27CA, 0x103C, 0x30A1, "NC2400(0x103C-0x30A1)"},
{0x8086, 0x27CA, 0x103C, 0x30A3, "Compaq nw8440(0x103C-0x30A3)"},
{0x8086, 0x27CA, 0x1043, 0x1237, "A6J-Q008(0x1043-0x1237)"},
{0x8086, 0x27CA, 0x1043, 0x8179, "P5B-MX/WiFi-AP, P5KPL-VM, P5LD2-VM Mainboard(0x1043-0x8179)"},
{0x8086, 0x27CA, 0x1043, 0x83AD, "Eee PC 1015PX(0x1043-0x83AD)"},
{0x8086, 0x27CA, 0x105B, 0x0D7C, "D270S/D250S Motherboard(0x105B-0x0D7C)"},
{0x8086, 0x27CA, 0x1071, 0x8209, "Medion MIM 2240 Notebook PC [MD98100](0x1071-0x8209)"},
{0x8086, 0x27CA, 0x107B, 0x5048, "E4500(0x107B-0x5048)"},
{0x8086, 0x27CA, 0x144D, 0xC072, "Notebook N150P(0x144D-0xC072)"},
{0x8086, 0x27CA, 0x1458, 0x5004, "GA-D525TUD(0x1458-0x5004)"},
{0x8086, 0x27CA, 0x1462, 0x7418, "Wind PC MS-7418(0x1462-0x7418)"},
{0x8086, 0x27CA, 0x1775, 0x11CC, "CC11/CL11(0x1775-0x11CC)"},
{0x8086, 0x27CA, 0x17AA, 0x200A, "ThinkPad R60/T60/X60 series(0x17AA-0x200A)"},
{0x8086, 0x27CA, 0x8086, 0x4F4D, "DeskTop Board D510MO(0x8086-0x4F4D)"},
{0x8086, 0x27CA, 0x8086, 0x544E, "DeskTop Board D945GTP(0x8086-0x544E)"},
{0x8086, 0x27CB, 0xFFFF, 0xFFFF, "NM10/ICH7 Family USB UHCI Controller #4(0x27CB)"},
{0x8086, 0x27CB, 0x1025, 0x006C, "9814 WKMI(0x1025-0x006C)"},
{0x8086, 0x27CB, 0x1028, 0x01AD, "OptiPlex GX620(0x1028-0x01AD)"},
{0x8086, 0x27CB, 0x1028, 0x01D7, "XPS M1210(0x1028-0x01D7)"},
{0x8086, 0x27CB, 0x1028, 0x01DF, "PowerEdge SC440(0x1028-0x01DF)"},
{0x8086, 0x27CB, 0x103C, 0x2A3B, "Pavilion A1512X(0x103C-0x2A3B)"},
{0x8086, 0x27CB, 0x103C, 0x2A8C, "Compaq 500B Microtower(0x103C-0x2A8C)"},
{0x8086, 0x27CB, 0x103C, 0x309F, "Compaq nx9420 Notebook(0x103C-0x309F)"},
{0x8086, 0x27CB, 0x103C, 0x30A1, "NC2400(0x103C-0x30A1)"},
{0x8086, 0x27CB, 0x103C, 0x30A3, "Compaq nw8440(0x103C-0x30A3)"},
{0x8086, 0x27CB, 0x1043, 0x1237, "A6J-Q008(0x1043-0x1237)"},
{0x8086, 0x27CB, 0x1043, 0x8179, "P5B-MX/WiFi-AP, P5KPL-VM, P5LD2-VM Mainboard(0x1043-0x8179)"},
{0x8086, 0x27CB, 0x1043, 0x83AD, "Eee PC 1015PX(0x1043-0x83AD)"},
{0x8086, 0x27CB, 0x105B, 0x0D7C, "D270S/D250S Motherboard(0x105B-0x0D7C)"},
{0x8086, 0x27CB, 0x1071, 0x8209, "Medion MIM 2240 Notebook PC [MD98100](0x1071-0x8209)"},
{0x8086, 0x27CB, 0x107B, 0x5048, "E4500(0x107B-0x5048)"},
{0x8086, 0x27CB, 0x144D, 0xC072, "Notebook N150P(0x144D-0xC072)"},
{0x8086, 0x27CB, 0x1458, 0x5004, "GA-D525TUD(0x1458-0x5004)"},
{0x8086, 0x27CB, 0x1462, 0x7418, "Wind PC MS-7418(0x1462-0x7418)"},
{0x8086, 0x27CB, 0x1775, 0x11CC, "CC11/CL11(0x1775-0x11CC)"},
{0x8086, 0x27CB, 0x17AA, 0x200A, "ThinkPad R60/T60/X60 series(0x17AA-0x200A)"},
{0x8086, 0x27CB, 0x8086, 0x4F4D, "DeskTop Board D510MO(0x8086-0x4F4D)"},
{0x8086, 0x27CB, 0x8086, 0x544E, "DeskTop Board D945GTP(0x8086-0x544E)"},
{0x8086, 0x27CC, 0xFFFF, 0xFFFF, "NM10/ICH7 Family USB2 EHCI Controller(0x27CC)"},
{0x8086, 0x27CC, 0x1025, 0x006C, "9814 WKMI(0x1025-0x006C)"},
{0x8086, 0x27CC, 0x1028, 0x01AD, "OptiPlex GX620(0x1028-0x01AD)"},
{0x8086, 0x27CC, 0x1028, 0x01D7, "XPS M1210(0x1028-0x01D7)"},
{0x8086, 0x27CC, 0x1028, 0x01DF, "PowerEdge SC440(0x1028-0x01DF)"},
{0x8086, 0x27CC, 0x1028, 0x01E6, "PowerEdge 860(0x1028-0x01E6)"},
{0x8086, 0x27CC, 0x103C, 0x2A3B, "Pavilion A1512X(0x103C-0x2A3B)"},
{0x8086, 0x27CC, 0x103C, 0x2A8C, "Compaq 500B Microtower(0x103C-0x2A8C)"},
{0x8086, 0x27CC, 0x103C, 0x309F, "Compaq nx9420 Notebook(0x103C-0x309F)"},
{0x8086, 0x27CC, 0x103C, 0x30A1, "NC2400(0x103C-0x30A1)"},
{0x8086, 0x27CC, 0x103C, 0x30A3, "Compaq nw8440(0x103C-0x30A3)"},
{0x8086, 0x27CC, 0x103C, 0x30D5, "530 Laptop(0x103C-0x30D5)"},
{0x8086, 0x27CC, 0x1043, 0x1237, "A6J-Q008(0x1043-0x1237)"},
{0x8086, 0x27CC, 0x1043, 0x8179, "P5B-MX/WiFi-AP, P5KPL-VM, P5LD2-VM Mainboard(0x1043-0x8179)"},
{0x8086, 0x27CC, 0x1043, 0x83AD, "Eee PC 1015PX(0x1043-0x83AD)"},
{0x8086, 0x27CC, 0x105B, 0x0D7C, "D270S/D250S Motherboard(0x105B-0x0D7C)"},
{0x8086, 0x27CC, 0x1071, 0x8209, "Medion MIM 2240 Notebook PC [MD98100](0x1071-0x8209)"},
{0x8086, 0x27CC, 0x144D, 0xC072, "Notebook N150P(0x144D-0xC072)"},
{0x8086, 0x27CC, 0x1458, 0x5006, "GA-D525TUD(0x1458-0x5006)"},
{0x8086, 0x27CC, 0x1462, 0x7418, "Wind PC MS-7418(0x1462-0x7418)"},
{0x8086, 0x27CC, 0x1775, 0x11CC, "CC11/CL11(0x1775-0x11CC)"},
{0x8086, 0x27CC, 0x17AA, 0x200B, "ThinkPad R60/T60/X60 series(0x17AA-0x200B)"},
{0x8086, 0x27CC, 0x8086, 0x4F4D, "DeskTop Board D510MO(0x8086-0x4F4D)"},
{0x8086, 0x27CC, 0x8086, 0x544B, "Desktop Board D425KT(0x8086-0x544B)"},
{0x8086, 0x27CC, 0x8086, 0x544E, "DeskTop Board D945GTP(0x8086-0x544E)"},
{0x8086, 0x27D0, 0xFFFF, 0xFFFF, "NM10/ICH7 Family PCI Express Port 1(0x27D0)"},
{0x8086, 0x27D0, 0x103C, 0x309F, "Compaq nx9420 Notebook(0x103C-0x309F)"},
{0x8086, 0x27D0, 0x103C, 0x30A3, "Compaq nw8440(0x103C-0x30A3)"},
{0x8086, 0x27D0, 0x1071, 0x8209, "Medion MIM 2240 Notebook PC [MD98100](0x1071-0x8209)"},
{0x8086, 0x27D0, 0x144D, 0xC072, "Notebook N150P(0x144D-0xC072)"},
{0x8086, 0x27D0, 0x1458, 0x5001, "GA-D525TUD(0x1458-0x5001)"},
{0x8086, 0x27D0, 0x1462, 0x7418, "Wind PC MS-7418(0x1462-0x7418)"},
{0x8086, 0x27D0, 0x1775, 0x11CC, "CC11/CL11(0x1775-0x11CC)"},
{0x8086, 0x27D0, 0x17AA, 0x2011, "ThinkPad R60e(0x17AA-0x2011)"},
{0x8086, 0x27D0, 0x8086, 0x544B, "Desktop Board D425KT(0x8086-0x544B)"},
{0x8086, 0x27D2, 0xFFFF, 0xFFFF, "NM10/ICH7 Family PCI Express Port 2(0x27D2)"},
{0x8086, 0x27D2, 0x103C, 0x309F, "Compaq nx9420 Notebook(0x103C-0x309F)"},
{0x8086, 0x27D2, 0x103C, 0x30A3, "Compaq nw8440(0x103C-0x30A3)"},
{0x8086, 0x27D2, 0x1071, 0x8209, "Medion MIM 2240 Notebook PC [MD98100](0x1071-0x8209)"},
{0x8086, 0x27D2, 0x144D, 0xC072, "Notebook N150P(0x144D-0xC072)"},
{0x8086, 0x27D2, 0x1462, 0x7418, "Wind PC MS-7418(0x1462-0x7418)"},
{0x8086, 0x27D2, 0x1775, 0x11CC, "CC11/CL11(0x1775-0x11CC)"},
{0x8086, 0x27D2, 0x17AA, 0x2011, "ThinkPad R60e(0x17AA-0x2011)"},
{0x8086, 0x27D2, 0x8086, 0x544B, "Desktop Board D425KT(0x8086-0x544B)"},
{0x8086, 0x27D4, 0xFFFF, 0xFFFF, "NM10/ICH7 Family PCI Express Port 3(0x27D4)"},
{0x8086, 0x27D4, 0x1071, 0x8209, "Medion MIM 2240 Notebook PC [MD98100](0x1071-0x8209)"},
{0x8086, 0x27D4, 0x144D, 0xC072, "Notebook N150P(0x144D-0xC072)"},
{0x8086, 0x27D4, 0x1462, 0x7418, "Wind PC MS-7418(0x1462-0x7418)"},
{0x8086, 0x27D4, 0x1775, 0x11CC, "CC11/CL11(0x1775-0x11CC)"},
{0x8086, 0x27D4, 0x17AA, 0x2011, "ThinkPad R60e(0x17AA-0x2011)"},
{0x8086, 0x27D4, 0x8086, 0x544B, "Desktop Board D425KT(0x8086-0x544B)"},
{0x8086, 0x27D6, 0xFFFF, 0xFFFF, "NM10/ICH7 Family PCI Express Port 4(0x27D6)"},
{0x8086, 0x27D6, 0x103C, 0x30A3, "Compaq nw8440(0x103C-0x30A3)"},
{0x8086, 0x27D6, 0x1071, 0x8209, "Medion MIM 2240 Notebook PC [MD98100](0x1071-0x8209)"},
{0x8086, 0x27D6, 0x144D, 0xC072, "Notebook N150P(0x144D-0xC072)"},
{0x8086, 0x27D6, 0x1462, 0x7418, "Wind PC MS-7418(0x1462-0x7418)"},
{0x8086, 0x27D6, 0x1775, 0x11CC, "CC11/CL11(0x1775-0x11CC)"},
{0x8086, 0x27D6, 0x17AA, 0x2011, "ThinkPad R60e(0x17AA-0x2011)"},
{0x8086, 0x27D6, 0x8086, 0x544B, "Desktop Board D425KT(0x8086-0x544B)"},
{0x8086, 0x27D8, 0xFFFF, 0xFFFF, "NM10/ICH7 Family High Definition Audio Controller(0x27D8)"},
{0x8086, 0x27D8, 0x1025, 0x006C, "9814 WKMI(0x1025-0x006C)"},
{0x8086, 0x27D8, 0x1028, 0x01D7, "XPS M1210(0x1028-0x01D7)"},
{0x8086, 0x27D8, 0x103C, 0x2A3B, "Pavilion A1512X(0x103C-0x2A3B)"},
{0x8086, 0x27D8, 0x103C, 0x2A8C, "Compaq 500B Microtower(0x103C-0x2A8C)"},
{0x8086, 0x27D8, 0x103C, 0x309F, "Compaq nx9420 Notebook(0x103C-0x309F)"},
{0x8086, 0x27D8, 0x103C, 0x30A1, "NC2400(0x103C-0x30A1)"},
{0x8086, 0x27D8, 0x103C, 0x30A3, "Compaq nw8440(0x103C-0x30A3)"},
{0x8086, 0x27D8, 0x103C, 0x30D5, "530 Laptop(0x103C-0x30D5)"},
{0x8086, 0x27D8, 0x1043, 0x1123, "A6J-Q008(0x1043-0x1123)"},
{0x8086, 0x27D8, 0x1043, 0x13C4, "G2P(0x1043-0x13C4)"},
{0x8086, 0x27D8, 0x1043, 0x817F, "P5LD2-VM Mainboard (Realtek ALC 882 codec)(0x1043-0x817F)"},
{0x8086, 0x27D8, 0x1043, 0x8249, "P5B-MX/WiFi-AP(0x1043-0x8249)"},
{0x8086, 0x27D8, 0x1043, 0x8290, "P5KPL-VM Motherboard(0x1043-0x8290)"},
{0x8086, 0x27D8, 0x1043, 0x82EA, "P5KPL-CM Motherboard(0x1043-0x82EA)"},
{0x8086, 0x27D8, 0x1043, 0x8437, "Eee PC 1015PX(0x1043-0x8437)"},
{0x8086, 0x27D8, 0x105B, 0x0D7C, "D270S/D250S Motherboard(0x105B-0x0D7C)"},
{0x8086, 0x27D8, 0x1071, 0x8207, "Medion MIM 2240 Notebook PC [MD98100](0x1071-0x8207)"},
{0x8086, 0x27D8, 0x107B, 0x5048, "E4500(0x107B-0x5048)"},
{0x8086, 0x27D8, 0x10F7, 0x8338, "Panasonic CF-Y5 laptop(0x10F7-0x8338)"},
{0x8086, 0x27D8, 0x1179, 0xFF10, "Toshiba Satellite A100-796 audio (Realtek ALC861)(0x1179-0xFF10)"},
{0x8086, 0x27D8, 0x1179, 0xFF31, "AC97 Data Fax SoftModem with SmartCP(0x1179-0xFF31)"},
{0x8086, 0x27D8, 0x1447, 0x1043, "Asus A8JP (Analog Devices AD1986A)(0x1447-0x1043)"},
{0x8086, 0x27D8, 0x144D, 0xC072, "Notebook N150P(0x144D-0xC072)"},
{0x8086, 0x27D8, 0x1458, 0xA002, "GA-D525TUD (Realtek ALC887)(0x1458-0xA002)"},
{0x8086, 0x27D8, 0x1458, 0xA102, "GA-8I945PG-RH Mainboard(0x1458-0xA102)"},
{0x8086, 0x27D8, 0x1462, 0x7418, "Wind PC MS-7418(0x1462-0x7418)"},
{0x8086, 0x27D8, 0x152D, 0x0753, "Softmodem(0x152D-0x0753)"},
{0x8086, 0x27D8, 0x1734, 0x10AD, "Conexant softmodem SmartCP(0x1734-0x10AD)"},
{0x8086, 0x27D8, 0x17AA, 0x2010, "ThinkPad R60/T60/X60 series(0x17AA-0x2010)"},
{0x8086, 0x27D8, 0x17AA, 0x3802, "3000 C200 audio [Realtek ALC861VD](0x17AA-0x3802)"},
{0x8086, 0x27D8, 0x8086, 0x1112, "DeskTop Board D945GTP(0x8086-0x1112)"},
{0x8086, 0x27D8, 0x8086, 0x27D8, "DeskTop Board D945GTP(0x8086-0x27D8)"},
{0x8086, 0x27D8, 0x8086, 0xD618, "DeskTop Board D510MO(0x8086-0xD618)"},
{0x8086, 0x27D8, 0x8384, 0x7680, "STAC9221 HD Audio Codec(0x8384-0x7680)"},
{0x8086, 0x27DA, 0xFFFF, 0xFFFF, "NM10/ICH7 Family SMBus Controller(0x27DA)"},
{0x8086, 0x27DA, 0x1025, 0x006C, "9814 WKMI(0x1025-0x006C)"},
{0x8086, 0x27DA, 0x1028, 0x01AD, "OptiPlex GX620(0x1028-0x01AD)"},
{0x8086, 0x27DA, 0x1028, 0x01D7, "XPS M1210(0x1028-0x01D7)"},
{0x8086, 0x27DA, 0x1028, 0x01DF, "PowerEdge SC440(0x1028-0x01DF)"},
{0x8086, 0x27DA, 0x1028, 0x01E6, "PowerEdge 860(0x1028-0x01E6)"},
{0x8086, 0x27DA, 0x103C, 0x2A3B, "Pavilion A1512X(0x103C-0x2A3B)"},
{0x8086, 0x27DA, 0x103C, 0x2A8C, "Compaq 500B Microtower(0x103C-0x2A8C)"},
{0x8086, 0x27DA, 0x1043, 0x8179, "P5B-MX/WiFi-AP, P5KPL-VM Motherboard(0x1043-0x8179)"},
{0x8086, 0x27DA, 0x105B, 0x0D7C, "D270S/D250S Motherboard(0x105B-0x0D7C)"},
{0x8086, 0x27DA, 0x1071, 0x8209, "Medion MIM 2240 Notebook PC [MD98100](0x1071-0x8209)"},
{0x8086, 0x27DA, 0x10F7, 0x8338, "Panasonic CF-Y5 laptop(0x10F7-0x8338)"},
{0x8086, 0x27DA, 0x144D, 0xC072, "Notebook N150P(0x144D-0xC072)"},
{0x8086, 0x27DA, 0x1458, 0x5001, "GA-8I945PG-RH/GA-D525TUD Mainboard(0x1458-0x5001)"},
{0x8086, 0x27DA, 0x1462, 0x7418, "Wind PC MS-7418(0x1462-0x7418)"},
{0x8086, 0x27DA, 0x1775, 0x11CC, "CC11/CL11(0x1775-0x11CC)"},
{0x8086, 0x27DA, 0x17AA, 0x200F, "ThinkPad R60/T60/X60 series(0x17AA-0x200F)"},
{0x8086, 0x27DA, 0x8086, 0x4F4D, "DeskTop Board D510MO(0x8086-0x4F4D)"},
{0x8086, 0x27DA, 0x8086, 0x544B, "Desktop Board D425KT(0x8086-0x544B)"},
{0x8086, 0x27DA, 0x8086, 0x544E, "DeskTop Board D945GTP(0x8086-0x544E)"},
{0x8086, 0x27DA, 0x8086, 0x5842, "DeskTop Board D975XBX(0x8086-0x5842)"},
{0x8086, 0x27DC, 0xFFFF, 0xFFFF, "NM10/ICH7 Family LAN Controller(0x27DC)"},
{0x8086, 0x27DC, 0x103C, 0x2A3B, "Pavilion A1512X(0x103C-0x2A3B)"},
{0x8086, 0x27DC, 0x8086, 0x308D, "DeskTop Board D945GTP(0x8086-0x308D)"},
{0x8086, 0x27DD, 0xFFFF, 0xFFFF, "82801G (ICH7 Family) AC'97 Modem Controller(0x27DD)"},
{0x8086, 0x27DE, 0xFFFF, 0xFFFF, "82801G (ICH7 Family) AC'97 Audio Controller(0x27DE)"},
{0x8086, 0x27DE, 0x1028, 0x01AD, "OptiPlex GX620(0x1028-0x01AD)"},
{0x8086, 0x27DE, 0x1462, 0x7267, "Realtek ALC883 Audio Controller(0x1462-0x7267)"},
{0x8086, 0x27DE, 0x1775, 0x11CC, "CC11 integrated audio (AD1981BL codec)(0x1775-0x11CC)"},
{0x8086, 0x27DF, 0xFFFF, 0xFFFF, "82801G (ICH7 Family) IDE Controller(0x27DF)"},
{0x8086, 0x27DF, 0x1028, 0x01DF, "PowerEdge SC440(0x1028-0x01DF)"},
{0x8086, 0x27DF, 0x1028, 0x01E6, "PowerEdge 860(0x1028-0x01E6)"},
{0x8086, 0x27DF, 0x103C, 0x2A3B, "Pavilion A1512X(0x103C-0x2A3B)"},
{0x8086, 0x27DF, 0x103C, 0x2A8C, "Compaq 500B Microtower(0x103C-0x2A8C)"},
{0x8086, 0x27DF, 0x103C, 0x309F, "Compaq nx9420 Notebook(0x103C-0x309F)"},
{0x8086, 0x27DF, 0x103C, 0x30A1, "NC2400(0x103C-0x30A1)"},
{0x8086, 0x27DF, 0x103C, 0x30A3, "Compaq nw8440(0x103C-0x30A3)"},
{0x8086, 0x27DF, 0x103C, 0x30D5, "530 Laptop(0x103C-0x30D5)"},
{0x8086, 0x27DF, 0x1043, 0x1237, "A6J-Q008(0x1043-0x1237)"},
{0x8086, 0x27DF, 0x1043, 0x8179, "P5B-MX/WiFi-AP, P5KPL-VM Motherboard(0x1043-0x8179)"},
{0x8086, 0x27DF, 0x107B, 0x5048, "E4500(0x107B-0x5048)"},
{0x8086, 0x27DF, 0x10F7, 0x8338, "Panasonic CF-Y5 laptop(0x10F7-0x8338)"},
{0x8086, 0x27DF, 0x1462, 0x7418, "Wind PC MS-7418(0x1462-0x7418)"},
{0x8086, 0x27DF, 0x1775, 0x11CC, "CC11/CL11(0x1775-0x11CC)"},
{0x8086, 0x27DF, 0x17AA, 0x200C, "ThinkPad R60/T60/X60 series(0x17AA-0x200C)"},
{0x8086, 0x27DF, 0x8086, 0x544E, "DeskTop Board D945GTP(0x8086-0x544E)"},
{0x8086, 0x27E0, 0xFFFF, 0xFFFF, "82801GR/GH/GHM (ICH7 Family) PCI Express Port 5(0x27E0)"},
{0x8086, 0x27E0, 0x1775, 0x11CC, "CC11/CL11(0x1775-0x11CC)"},
{0x8086, 0x27E2, 0xFFFF, 0xFFFF, "82801GR/GH/GHM (ICH7 Family) PCI Express Port 6(0x27E2)"},
{0x8086, 0x27E2, 0x1775, 0x11CC, "CC11/CL11(0x1775-0x11CC)"},
{0x8086, 0x2810, 0xFFFF, 0xFFFF, "82801HB/HR (ICH8/R) LPC Interface Controller(0x2810)"},
{0x8086, 0x2810, 0x1043, 0x81EC, "P5B(0x1043-0x81EC)"},
{0x8086, 0x2811, 0xFFFF, 0xFFFF, "82801HEM (ICH8M-E) LPC Interface Controller(0x2811)"},
{0x8086, 0x2811, 0x103C, 0x30C1, "Compaq 6910p(0x103C-0x30C1)"},
{0x8086, 0x2811, 0x17AA, 0x20B6, "ThinkPad T61/R61(0x17AA-0x20B6)"},
{0x8086, 0x2811, 0xE4BF, 0xCC47, "CCG-RUMBA(0xE4BF-0xCC47)"},
{0x8086, 0x2812, 0xFFFF, 0xFFFF, "82801HH (ICH8DH) LPC Interface Controller(0x2812)"},
{0x8086, 0x2814, 0xFFFF, 0xFFFF, "82801HO (ICH8DO) LPC Interface Controller(0x2814)"},
{0x8086, 0x2815, 0xFFFF, 0xFFFF, "82801HM (ICH8M) LPC Interface Controller(0x2815)"},
{0x8086, 0x2815, 0x1025, 0x0121, "Aspire 5920G(0x1025-0x0121)"},
{0x8086, 0x2815, 0x1028, 0x01F3, "Inspiron 1420(0x1028-0x01F3)"},
{0x8086, 0x2815, 0x1028, 0x022F, "Inspiron 1525(0x1028-0x022F)"},
{0x8086, 0x2815, 0x103C, 0x30C0, "Compaq 6710b(0x103C-0x30C0)"},
{0x8086, 0x2815, 0x103C, 0x30CC, "Pavilion dv6700(0x103C-0x30CC)"},
{0x8086, 0x2815, 0x103C, 0x30D9, "Presario C700(0x103C-0x30D9)"},
{0x8086, 0x2815, 0x1043, 0x1017, "X58LE(0x1043-0x1017)"},
{0x8086, 0x2815, 0x104D, 0x9005, "Vaio VGN-FZ260E(0x104D-0x9005)"},
{0x8086, 0x2815, 0x104D, 0x902D, "VAIO VGN-NR120E(0x104D-0x902D)"},
{0x8086, 0x2815, 0x17AA, 0x20A5, "ThinkPad R61(0x17AA-0x20A5)"},
{0x8086, 0x2815, 0x17C0, 0x4083, "Medion WIM 2210 Notebook PC [MD96850](0x17C0-0x4083)"},
{0x8086, 0x2820, 0xFFFF, 0xFFFF, "82801H (ICH8 Family) 4 port SATA Controller [IDE mode](0x2820)"},
{0x8086, 0x2820, 0x1028, 0x01DA, "OptiPlex 745(0x1028-0x01DA)"},
{0x8086, 0x2820, 0x1462, 0x7235, "P965 Neo MS-7235 mainboard(0x1462-0x7235)"},
{0x8086, 0x2821, 0xFFFF, 0xFFFF, "82801HR/HO/HH (ICH8R/DO/DH) 6 port SATA Controller [AHCI mode](0x2821)"},
{0x8086, 0x2822, 0xFFFF, 0xFFFF, "SATA Controller [RAID mode](0x2822)"},
{0x8086, 0x2822, 0x1028, 0x020D, "Inspiron 530(0x1028-0x020D)"},
{0x8086, 0x2822, 0x103C, 0x2A6F, "Asus IPIBL-LB Motherboard(0x103C-0x2A6F)"},
{0x8086, 0x2822, 0x1043, 0x8277, "P5K PRO Motherboard: 82801IR [ICH9R](0x1043-0x8277)"},
{0x8086, 0x2822, 0x1462, 0x7345, "MS-7345 Motherboard: Intel 82801I/IR [ICH9/ICH9R](0x1462-0x7345)"},
{0x8086, 0x2823, 0xFFFF, 0xFFFF, "sSATA Controller [RAID Mode](0x2823)"},
{0x8086, 0x2824, 0xFFFF, 0xFFFF, "82801HB (ICH8) 4 port SATA Controller [AHCI mode](0x2824)"},
{0x8086, 0x2824, 0x1043, 0x81EC, "P5B(0x1043-0x81EC)"},
{0x8086, 0x2825, 0xFFFF, 0xFFFF, "82801HR/HO/HH (ICH8R/DO/DH) 2 port SATA Controller [IDE mode](0x2825)"},
{0x8086, 0x2825, 0x1028, 0x01DA, "OptiPlex 745(0x1028-0x01DA)"},
{0x8086, 0x2825, 0x1462, 0x7235, "P965 Neo MS-7235 mainboard(0x1462-0x7235)"},
{0x8086, 0x2826, 0xFFFF, 0xFFFF, "SATA Controller [RAID Mode](0x2826)"},
{0x8086, 0x2826, 0x1D49, 0x0100, "Intel RSTe SATA Software RAID(0x1D49-0x0100)"},
{0x8086, 0x2826, 0x1D49, 0x0101, "Intel RSTe SATA Software RAID(0x1D49-0x0101)"},
{0x8086, 0x2826, 0x1D49, 0x0102, "Intel RSTe SATA Software RAID(0x1D49-0x0102)"},
{0x8086, 0x2826, 0x1D49, 0x0103, "Intel RSTe SATA Software RAID(0x1D49-0x0103)"},
{0x8086, 0x2826, 0x1D49, 0x0104, "Intel RSTe SATA Software RAID(0x1D49-0x0104)"},
{0x8086, 0x2826, 0x1D49, 0x0105, "Intel RSTe SATA Software RAID(0x1D49-0x0105)"},
{0x8086, 0x2827, 0xFFFF, 0xFFFF, "sSATA Controller [RAID Mode](0x2827)"},
{0x8086, 0x2828, 0xFFFF, 0xFFFF, "82801HM/HEM (ICH8M/ICH8M-E) SATA Controller [IDE mode](0x2828)"},
{0x8086, 0x2828, 0x1028, 0x01F3, "Inspiron 1420(0x1028-0x01F3)"},
{0x8086, 0x2828, 0x103C, 0x30C0, "Compaq 6710b(0x103C-0x30C0)"},
{0x8086, 0x2828, 0x17AA, 0x20A8, "ThinkPad R61(0x17AA-0x20A8)"},
{0x8086, 0x2828, 0xE4BF, 0xCC47, "CCG-RUMBA(0xE4BF-0xCC47)"},
{0x8086, 0x2829, 0xFFFF, 0xFFFF, "82801HM/HEM (ICH8M/ICH8M-E) SATA Controller [AHCI mode](0x2829)"},
{0x8086, 0x2829, 0x1025, 0x0121, "Aspire 5920G(0x1025-0x0121)"},
{0x8086, 0x2829, 0x1028, 0x022F, "Inspiron 1525(0x1028-0x022F)"},
{0x8086, 0x2829, 0x103C, 0x30C0, "Compaq 6710b(0x103C-0x30C0)"},
{0x8086, 0x2829, 0x103C, 0x30C1, "Compaq 6910p(0x103C-0x30C1)"},
{0x8086, 0x2829, 0x103C, 0x30CC, "Pavilion dv6700(0x103C-0x30CC)"},
{0x8086, 0x2829, 0x103C, 0x30D9, "Presario C700(0x103C-0x30D9)"},
{0x8086, 0x2829, 0x1043, 0x1017, "X58LE(0x1043-0x1017)"},
{0x8086, 0x2829, 0x104D, 0x9005, "Vaio VGN-FZ260E(0x104D-0x9005)"},
{0x8086, 0x2829, 0x104D, 0x902D, "VAIO VGN-NR120E(0x104D-0x902D)"},
{0x8086, 0x2829, 0x17AA, 0x20A7, "ThinkPad T61/R61(0x17AA-0x20A7)"},
{0x8086, 0x2829, 0x17C0, 0x4083, "Medion WIM 2210 Notebook PC [MD96850](0x17C0-0x4083)"},
{0x8086, 0x2829, 0xE4BF, 0xCC47, "CCG-RUMBA(0xE4BF-0xCC47)"},
{0x8086, 0x282A, 0xFFFF, 0xFFFF, "82801 Mobile SATA Controller [RAID mode](0x282A)"},
{0x8086, 0x282A, 0x1028, 0x040B, "Latitude E6510(0x1028-0x040B)"},
{0x8086, 0x282A, 0xE4BF, 0x50C1, "PC1-GROOVE(0xE4BF-0x50C1)"},
{0x8086, 0x282F, 0xFFFF, 0xFFFF, "tSATA Controller [RAID Mode](0x282F)"},
{0x8086, 0x2830, 0xFFFF, 0xFFFF, "82801H (ICH8 Family) USB UHCI Controller #1(0x2830)"},
{0x8086, 0x2830, 0x1025, 0x0121, "Aspire 5920G(0x1025-0x0121)"},
{0x8086, 0x2830, 0x1028, 0x01DA, "OptiPlex 745(0x1028-0x01DA)"},
{0x8086, 0x2830, 0x1028, 0x01F3, "Inspiron 1420(0x1028-0x01F3)"},
{0x8086, 0x2830, 0x1028, 0x022F, "Inspiron 1525(0x1028-0x022F)"},
{0x8086, 0x2830, 0x103C, 0x30C0, "Compaq 6710b(0x103C-0x30C0)"},
{0x8086, 0x2830, 0x103C, 0x30C1, "Compaq 6910p(0x103C-0x30C1)"},
{0x8086, 0x2830, 0x103C, 0x30CC, "Pavilion dv6700(0x103C-0x30CC)"},
{0x8086, 0x2830, 0x103C, 0x30D9, "Presario C700(0x103C-0x30D9)"},
{0x8086, 0x2830, 0x1043, 0x1017, "X58LE(0x1043-0x1017)"},
{0x8086, 0x2830, 0x1043, 0x81EC, "P5B(0x1043-0x81EC)"},
{0x8086, 0x2830, 0x104D, 0x9005, "Vaio VGN-FZ260E(0x104D-0x9005)"},
{0x8086, 0x2830, 0x104D, 0x902D, "VAIO VGN-NR120E(0x104D-0x902D)"},
{0x8086, 0x2830, 0x1462, 0x7235, "P965 Neo MS-7235 mainboard(0x1462-0x7235)"},
{0x8086, 0x2830, 0x17AA, 0x20AA, "ThinkPad T61/R61(0x17AA-0x20AA)"},
{0x8086, 0x2830, 0x17C0, 0x4083, "Medion WIM 2210 Notebook PC [MD96850](0x17C0-0x4083)"},
{0x8086, 0x2830, 0xE4BF, 0xCC47, "CCG-RUMBA(0xE4BF-0xCC47)"},
{0x8086, 0x2831, 0xFFFF, 0xFFFF, "82801H (ICH8 Family) USB UHCI Controller #2(0x2831)"},
{0x8086, 0x2831, 0x1025, 0x0121, "Aspire 5920G(0x1025-0x0121)"},
{0x8086, 0x2831, 0x1028, 0x01DA, "OptiPlex 745(0x1028-0x01DA)"},
{0x8086, 0x2831, 0x1028, 0x01F3, "Inspiron 1420(0x1028-0x01F3)"},
{0x8086, 0x2831, 0x1028, 0x022F, "Inspiron 1525(0x1028-0x022F)"},
{0x8086, 0x2831, 0x103C, 0x30C0, "Compaq 6710b(0x103C-0x30C0)"},
{0x8086, 0x2831, 0x103C, 0x30C1, "Compaq 6910p(0x103C-0x30C1)"},
{0x8086, 0x2831, 0x103C, 0x30CC, "Pavilion dv6700(0x103C-0x30CC)"},
{0x8086, 0x2831, 0x103C, 0x30D9, "Presario C700(0x103C-0x30D9)"},
{0x8086, 0x2831, 0x1043, 0x1017, "X58LE(0x1043-0x1017)"},
{0x8086, 0x2831, 0x1043, 0x81EC, "P5B(0x1043-0x81EC)"},
{0x8086, 0x2831, 0x104D, 0x9005, "Vaio VGN-FZ260E(0x104D-0x9005)"},
{0x8086, 0x2831, 0x104D, 0x902D, "VAIO VGN-NR120E(0x104D-0x902D)"},
{0x8086, 0x2831, 0x1462, 0x7235, "P965 Neo MS-7235 mainboard(0x1462-0x7235)"},
{0x8086, 0x2831, 0x17AA, 0x20AA, "ThinkPad T61/R61(0x17AA-0x20AA)"},
{0x8086, 0x2831, 0x17C0, 0x4083, "Medion WIM 2210 Notebook PC [MD96850](0x17C0-0x4083)"},
{0x8086, 0x2831, 0xE4BF, 0xCC47, "CCG-RUMBA(0xE4BF-0xCC47)"},
{0x8086, 0x2832, 0xFFFF, 0xFFFF, "82801H (ICH8 Family) USB UHCI Controller #3(0x2832)"},
{0x8086, 0x2832, 0x1025, 0x0121, "Aspire 5920G(0x1025-0x0121)"},
{0x8086, 0x2832, 0x1028, 0x01DA, "OptiPlex 745(0x1028-0x01DA)"},
{0x8086, 0x2832, 0x1028, 0x01F3, "Inspiron 1420(0x1028-0x01F3)"},
{0x8086, 0x2832, 0x1028, 0x022F, "Inspiron 1525(0x1028-0x022F)"},
{0x8086, 0x2832, 0x103C, 0x30C0, "Compaq 6710b(0x103C-0x30C0)"},
{0x8086, 0x2832, 0x103C, 0x30C1, "Compaq 6910p(0x103C-0x30C1)"},
{0x8086, 0x2832, 0x103C, 0x30CC, "Pavilion dv6700(0x103C-0x30CC)"},
{0x8086, 0x2832, 0x103C, 0x30D9, "Presario C700(0x103C-0x30D9)"},
{0x8086, 0x2832, 0x1043, 0x1017, "X58LE(0x1043-0x1017)"},
{0x8086, 0x2832, 0x1043, 0x81EC, "P5B(0x1043-0x81EC)"},
{0x8086, 0x2832, 0x104D, 0x9005, "Vaio VGN-FZ260E(0x104D-0x9005)"},
{0x8086, 0x2832, 0x104D, 0x902D, "VAIO VGN-NR120E(0x104D-0x902D)"},
{0x8086, 0x2832, 0x17AA, 0x20AA, "ThinkPad T61/R61(0x17AA-0x20AA)"},
{0x8086, 0x2832, 0x17C0, 0x4083, "Medion WIM 2210 Notebook PC [MD96850](0x17C0-0x4083)"},
{0x8086, 0x2832, 0xE4BF, 0xCC47, "CCG-RUMBA(0xE4BF-0xCC47)"},
{0x8086, 0x2833, 0xFFFF, 0xFFFF, "82801H (ICH8 Family) USB UHCI Controller #4(0x2833)"},
{0x8086, 0x2833, 0x1043, 0x81EC, "P5B(0x1043-0x81EC)"},
{0x8086, 0x2834, 0xFFFF, 0xFFFF, "82801H (ICH8 Family) USB UHCI Controller #4(0x2834)"},
{0x8086, 0x2834, 0x1025, 0x0121, "Aspire 5920G(0x1025-0x0121)"},
{0x8086, 0x2834, 0x1028, 0x01DA, "OptiPlex 745(0x1028-0x01DA)"},
{0x8086, 0x2834, 0x1028, 0x01F3, "Inspiron 1420(0x1028-0x01F3)"},
{0x8086, 0x2834, 0x1028, 0x022F, "Inspiron 1525(0x1028-0x022F)"},
{0x8086, 0x2834, 0x103C, 0x30C0, "Compaq 6710b(0x103C-0x30C0)"},
{0x8086, 0x2834, 0x103C, 0x30C1, "Compaq 6910p(0x103C-0x30C1)"},
{0x8086, 0x2834, 0x103C, 0x30CC, "Pavilion dv6700(0x103C-0x30CC)"},
{0x8086, 0x2834, 0x1043, 0x1017, "X58LE(0x1043-0x1017)"},
{0x8086, 0x2834, 0x1043, 0x81EC, "P5B(0x1043-0x81EC)"},
{0x8086, 0x2834, 0x104D, 0x9005, "Vaio VGN-FZ260E(0x104D-0x9005)"},
{0x8086, 0x2834, 0x104D, 0x902D, "VAIO VGN-NR120E(0x104D-0x902D)"},
{0x8086, 0x2834, 0x1462, 0x7235, "P965 Neo MS-7235 mainboard(0x1462-0x7235)"},
{0x8086, 0x2834, 0x17AA, 0x20AA, "ThinkPad T61/R61(0x17AA-0x20AA)"},
{0x8086, 0x2834, 0x17C0, 0x4083, "Medion WIM 2210 Notebook PC [MD96850](0x17C0-0x4083)"},
{0x8086, 0x2834, 0xE4BF, 0xCC47, "CCG-RUMBA(0xE4BF-0xCC47)"},
{0x8086, 0x2835, 0xFFFF, 0xFFFF, "82801H (ICH8 Family) USB UHCI Controller #5(0x2835)"},
{0x8086, 0x2835, 0x1025, 0x0121, "Aspire 5920G(0x1025-0x0121)"},
{0x8086, 0x2835, 0x1028, 0x01DA, "OptiPlex 745(0x1028-0x01DA)"},
{0x8086, 0x2835, 0x1028, 0x01F3, "Inspiron 1420(0x1028-0x01F3)"},
{0x8086, 0x2835, 0x1028, 0x022F, "Inspiron 1525(0x1028-0x022F)"},
{0x8086, 0x2835, 0x103C, 0x30C0, "Compaq 6710b(0x103C-0x30C0)"},
{0x8086, 0x2835, 0x103C, 0x30C1, "Compaq 6910p(0x103C-0x30C1)"},
{0x8086, 0x2835, 0x103C, 0x30CC, "Pavilion dv6700(0x103C-0x30CC)"},
{0x8086, 0x2835, 0x1043, 0x1017, "X58LE(0x1043-0x1017)"},
{0x8086, 0x2835, 0x1043, 0x81EC, "P5B(0x1043-0x81EC)"},
{0x8086, 0x2835, 0x104D, 0x9005, "Vaio VGN-FZ260E(0x104D-0x9005)"},
{0x8086, 0x2835, 0x104D, 0x902D, "VAIO VGN-NR120E(0x104D-0x902D)"},
{0x8086, 0x2835, 0x17AA, 0x20AA, "Thinkpad T61/R61(0x17AA-0x20AA)"},
{0x8086, 0x2835, 0x17C0, 0x4083, "Medion WIM 2210 Notebook PC [MD96850](0x17C0-0x4083)"},
{0x8086, 0x2835, 0xE4BF, 0xCC47, "CCG-RUMBA(0xE4BF-0xCC47)"},
{0x8086, 0x2836, 0xFFFF, 0xFFFF, "82801H (ICH8 Family) USB2 EHCI Controller #1(0x2836)"},
{0x8086, 0x2836, 0x1025, 0x0121, "Aspire 5920G(0x1025-0x0121)"},
{0x8086, 0x2836, 0x1028, 0x01DA, "OptiPlex 745(0x1028-0x01DA)"},
{0x8086, 0x2836, 0x1028, 0x01F3, "Inspiron 1420(0x1028-0x01F3)"},
{0x8086, 0x2836, 0x1028, 0x022F, "Inspiron 1525(0x1028-0x022F)"},
{0x8086, 0x2836, 0x103C, 0x30C0, "Compaq 6710b(0x103C-0x30C0)"},
{0x8086, 0x2836, 0x103C, 0x30C1, "Compaq 6910p(0x103C-0x30C1)"},
{0x8086, 0x2836, 0x103C, 0x30CC, "Pavilion dv6700(0x103C-0x30CC)"},
{0x8086, 0x2836, 0x103C, 0x30D9, "Presario C700(0x103C-0x30D9)"},
{0x8086, 0x2836, 0x1043, 0x1017, "X58LE(0x1043-0x1017)"},
{0x8086, 0x2836, 0x1043, 0x81EC, "P5B(0x1043-0x81EC)"},
{0x8086, 0x2836, 0x104D, 0x9005, "Vaio VGN-FZ260E(0x104D-0x9005)"},
{0x8086, 0x2836, 0x104D, 0x902D, "VAIO VGN-NR120E(0x104D-0x902D)"},
{0x8086, 0x2836, 0x1462, 0x7235, "P965 Neo MS-7235 mainboard(0x1462-0x7235)"},
{0x8086, 0x2836, 0x17AA, 0x20AB, "ThinkPad T61/R61(0x17AA-0x20AB)"},
{0x8086, 0x2836, 0x17C0, 0x4083, "Medion WIM 2210 Notebook PC [MD96850](0x17C0-0x4083)"},
{0x8086, 0x2836, 0xE4BF, 0xCC47, "CCG-RUMBA(0xE4BF-0xCC47)"},
{0x8086, 0x283A, 0xFFFF, 0xFFFF, "82801H (ICH8 Family) USB2 EHCI Controller #2(0x283A)"},
{0x8086, 0x283A, 0x1025, 0x0121, "Aspire 5920G(0x1025-0x0121)"},
{0x8086, 0x283A, 0x1028, 0x01DA, "OptiPlex 745(0x1028-0x01DA)"},
{0x8086, 0x283A, 0x1028, 0x01F3, "Inspiron 1420(0x1028-0x01F3)"},
{0x8086, 0x283A, 0x1028, 0x022F, "Inspiron 1525(0x1028-0x022F)"},
{0x8086, 0x283A, 0x103C, 0x30C0, "Compaq 6710b(0x103C-0x30C0)"},
{0x8086, 0x283A, 0x103C, 0x30C1, "Compaq 6910p(0x103C-0x30C1)"},
{0x8086, 0x283A, 0x103C, 0x30CC, "Pavilion dv6700(0x103C-0x30CC)"},
{0x8086, 0x283A, 0x1043, 0x1017, "X58LE(0x1043-0x1017)"},
{0x8086, 0x283A, 0x1043, 0x81EC, "P5B(0x1043-0x81EC)"},
{0x8086, 0x283A, 0x104D, 0x9005, "Vaio VGN-FZ260E(0x104D-0x9005)"},
{0x8086, 0x283A, 0x104D, 0x902D, "VAIO VGN-NR120E(0x104D-0x902D)"},
{0x8086, 0x283A, 0x17AA, 0x20AB, "ThinkPad T61/R61(0x17AA-0x20AB)"},
{0x8086, 0x283A, 0x17C0, 0x4083, "Medion WIM 2210 Notebook PC [MD96850](0x17C0-0x4083)"},
{0x8086, 0x283A, 0xE4BF, 0xCC47, "CCG-RUMBA(0xE4BF-0xCC47)"},
{0x8086, 0x283E, 0xFFFF, 0xFFFF, "82801H (ICH8 Family) SMBus Controller(0x283E)"},
{0x8086, 0x283E, 0x1025, 0x0121, "Aspire 5920G(0x1025-0x0121)"},
{0x8086, 0x283E, 0x1028, 0x01DA, "OptiPlex 745(0x1028-0x01DA)"},
{0x8086, 0x283E, 0x1028, 0x01F3, "Inspiron 1420(0x1028-0x01F3)"},
{0x8086, 0x283E, 0x1028, 0x022F, "Inspiron 1525(0x1028-0x022F)"},
{0x8086, 0x283E, 0x103C, 0x30D9, "Presario C700(0x103C-0x30D9)"},
{0x8086, 0x283E, 0x1043, 0x1017, "X58LE(0x1043-0x1017)"},
{0x8086, 0x283E, 0x1043, 0x81EC, "P5B(0x1043-0x81EC)"},
{0x8086, 0x283E, 0x104D, 0x9005, "Vaio VGN-FZ260E(0x104D-0x9005)"},
{0x8086, 0x283E, 0x104D, 0x9008, "Vaio VGN-SZ79SN_C(0x104D-0x9008)"},
{0x8086, 0x283E, 0x104D, 0x902D, "VAIO VGN-NR120E(0x104D-0x902D)"},
{0x8086, 0x283E, 0x1462, 0x7235, "P965 Neo MS-7235 mainboard(0x1462-0x7235)"},
{0x8086, 0x283E, 0x17AA, 0x20A9, "ThinkPad T61/R61(0x17AA-0x20A9)"},
{0x8086, 0x283E, 0x17C0, 0x4083, "Medion WIM 2210 Notebook PC [MD96850](0x17C0-0x4083)"},
{0x8086, 0x283E, 0xE4BF, 0xCC47, "CCG-RUMBA(0xE4BF-0xCC47)"},
{0x8086, 0x283F, 0xFFFF, 0xFFFF, "82801H (ICH8 Family) PCI Express Port 1(0x283F)"},
{0x8086, 0x283F, 0x1028, 0x01DA, "OptiPlex 745(0x1028-0x01DA)"},
{0x8086, 0x283F, 0x103C, 0x30C1, "Compaq 6910p(0x103C-0x30C1)"},
{0x8086, 0x283F, 0x1043, 0x1017, "X58LE(0x1043-0x1017)"},
{0x8086, 0x283F, 0x1043, 0x81EC, "P5B(0x1043-0x81EC)"},
{0x8086, 0x283F, 0x104D, 0x902D, "VAIO VGN-NR120E(0x104D-0x902D)"},
{0x8086, 0x283F, 0x17AA, 0x20AD, "ThinkPad T61/R61(0x17AA-0x20AD)"},
{0x8086, 0x283F, 0x17C0, 0x4083, "Medion WIM 2210 Notebook PC [MD96850](0x17C0-0x4083)"},
{0x8086, 0x2841, 0xFFFF, 0xFFFF, "82801H (ICH8 Family) PCI Express Port 2(0x2841)"},
{0x8086, 0x2841, 0x103C, 0x30C1, "Compaq 6910p(0x103C-0x30C1)"},
{0x8086, 0x2841, 0x1043, 0x1017, "X58LE(0x1043-0x1017)"},
{0x8086, 0x2841, 0x1043, 0x81EC, "P5B(0x1043-0x81EC)"},
{0x8086, 0x2841, 0x104D, 0x902D, "VAIO VGN-NR120E(0x104D-0x902D)"},
{0x8086, 0x2841, 0x17AA, 0x20AD, "ThinkPad T61/R61(0x17AA-0x20AD)"},
{0x8086, 0x2841, 0x17C0, 0x4083, "Medion WIM 2210 Notebook PC [MD96850](0x17C0-0x4083)"},
{0x8086, 0x2843, 0xFFFF, 0xFFFF, "82801H (ICH8 Family) PCI Express Port 3(0x2843)"},
{0x8086, 0x2843, 0x1043, 0x1017, "X58LE(0x1043-0x1017)"},
{0x8086, 0x2843, 0x1043, 0x81EC, "P5B(0x1043-0x81EC)"},
{0x8086, 0x2843, 0x104D, 0x902D, "VAIO VGN-NR120E(0x104D-0x902D)"},
{0x8086, 0x2843, 0x17AA, 0x20AD, "ThinkPad T61/R61(0x17AA-0x20AD)"},
{0x8086, 0x2843, 0x17C0, 0x4083, "Medion WIM 2210 Notebook PC [MD96850](0x17C0-0x4083)"},
{0x8086, 0x2845, 0xFFFF, 0xFFFF, "82801H (ICH8 Family) PCI Express Port 4(0x2845)"},
{0x8086, 0x2845, 0x1043, 0x1017, "X58LE(0x1043-0x1017)"},
{0x8086, 0x2845, 0x1043, 0x81EC, "P5B(0x1043-0x81EC)"},
{0x8086, 0x2845, 0x17AA, 0x20AD, "ThinkPad T61/R61(0x17AA-0x20AD)"},
{0x8086, 0x2845, 0x17C0, 0x4083, "Medion WIM 2210 Notebook PC [MD96850](0x17C0-0x4083)"},
{0x8086, 0x2847, 0xFFFF, 0xFFFF, "82801H (ICH8 Family) PCI Express Port 5(0x2847)"},
{0x8086, 0x2847, 0x1028, 0x01DA, "OptiPlex 745(0x1028-0x01DA)"},
{0x8086, 0x2847, 0x103C, 0x30C1, "Compaq 6910p(0x103C-0x30C1)"},
{0x8086, 0x2847, 0x1043, 0x81EC, "P5B(0x1043-0x81EC)"},
{0x8086, 0x2847, 0x17AA, 0x20AD, "ThinkPad T61/R61(0x17AA-0x20AD)"},
{0x8086, 0x2847, 0x17C0, 0x4083, "Medion WIM 2210 Notebook PC [MD96850](0x17C0-0x4083)"},
{0x8086, 0x2849, 0xFFFF, 0xFFFF, "82801H (ICH8 Family) PCI Express Port 6(0x2849)"},
{0x8086, 0x284B, 0xFFFF, 0xFFFF, "82801H (ICH8 Family) HD Audio Controller(0x284B)"},
{0x8086, 0x284B, 0x1025, 0x011F, "Realtek ALC268 audio codec(0x1025-0x011F)"},
{0x8086, 0x284B, 0x1025, 0x0121, "Aspire 5920G(0x1025-0x0121)"},
{0x8086, 0x284B, 0x1025, 0x0145, "Realtek ALC889 (Aspire 8920G w. Dolby Theater)(0x1025-0x0145)"},
{0x8086, 0x284B, 0x1028, 0x01DA, "OptiPlex 745(0x1028-0x01DA)"},
{0x8086, 0x284B, 0x1028, 0x01F3, "Inspiron 1420(0x1028-0x01F3)"},
{0x8086, 0x284B, 0x1028, 0x01F9, "Latitude D630(0x1028-0x01F9)"},
{0x8086, 0x284B, 0x1028, 0x01FF, "Precision M4300(0x1028-0x01FF)"},
{0x8086, 0x284B, 0x1028, 0x022F, "Inspiron 1525(0x1028-0x022F)"},
{0x8086, 0x284B, 0x1028, 0x0256, "Studio 1735(0x1028-0x0256)"},
{0x8086, 0x284B, 0x103C, 0x2802, "Compaq dc7700p(0x103C-0x2802)"},
{0x8086, 0x284B, 0x103C, 0x30C0, "Compaq 6710b(0x103C-0x30C0)"},
{0x8086, 0x284B, 0x103C, 0x30C1, "Compaq 6910p(0x103C-0x30C1)"},
{0x8086, 0x284B, 0x103C, 0x30CC, "Pavilion dv6700(0x103C-0x30CC)"},
{0x8086, 0x284B, 0x1043, 0x1339, "M51S series(0x1043-0x1339)"},
{0x8086, 0x284B, 0x1043, 0x17F3, "X58LE(0x1043-0x17F3)"},
{0x8086, 0x284B, 0x1043, 0x81EC, "P5B(0x1043-0x81EC)"},
{0x8086, 0x284B, 0x104D, 0x9005, "Vaio VGN-FZ260E(0x104D-0x9005)"},
{0x8086, 0x284B, 0x104D, 0x9008, "Vaio VGN-SZ79SN_C(0x104D-0x9008)"},
{0x8086, 0x284B, 0x104D, 0x9016, "Sony VAIO VGN-AR51M(0x104D-0x9016)"},
{0x8086, 0x284B, 0x104D, 0x902D, "VAIO VGN-NR120E(0x104D-0x902D)"},
{0x8086, 0x284B, 0x14F1, 0x5051, "Presario C700(0x14F1-0x5051)"},
{0x8086, 0x284B, 0x17AA, 0x20AC, "ThinkPad T61/R61(0x17AA-0x20AC)"},
{0x8086, 0x284B, 0x17C0, 0x4088, "Medion WIM 2210 Notebook PC [MD96850](0x17C0-0x4088)"},
{0x8086, 0x284B, 0x8384, 0x7616, "Dell Vostro 1400(0x8384-0x7616)"},
{0x8086, 0x284B, 0xE4BF, 0xCC47, "CCG-RUMBA(0xE4BF-0xCC47)"},
{0x8086, 0x284F, 0xFFFF, 0xFFFF, "82801H (ICH8 Family) Thermal Reporting Device(0x284F)"},
{0x8086, 0x2850, 0xFFFF, 0xFFFF, "82801HM/HEM (ICH8M/ICH8M-E) IDE Controller(0x2850)"},
{0x8086, 0x2850, 0x1025, 0x0121, "Aspire 5920G(0x1025-0x0121)"},
{0x8086, 0x2850, 0x1028, 0x01F3, "Inspiron 1420(0x1028-0x01F3)"},
{0x8086, 0x2850, 0x1028, 0x022F, "Inspiron 1525(0x1028-0x022F)"},
{0x8086, 0x2850, 0x103C, 0x30C0, "Compaq 6710b(0x103C-0x30C0)"},
{0x8086, 0x2850, 0x103C, 0x30C1, "Compaq 6910p(0x103C-0x30C1)"},
{0x8086, 0x2850, 0x103C, 0x30CC, "Pavilion dv6700(0x103C-0x30CC)"},
{0x8086, 0x2850, 0x103C, 0x30D9, "Presario C700(0x103C-0x30D9)"},
{0x8086, 0x2850, 0x1043, 0x1017, "X58LE(0x1043-0x1017)"},
{0x8086, 0x2850, 0x104D, 0x9005, "Vaio VGN-FZ260E(0x104D-0x9005)"},
{0x8086, 0x2850, 0x104D, 0x902D, "VAIO VGN-NR120E(0x104D-0x902D)"},
{0x8086, 0x2850, 0x17AA, 0x20A6, "ThinkPad T61/R61(0x17AA-0x20A6)"},
{0x8086, 0x2850, 0x17C0, 0x4083, "Medion WIM 2210 Notebook PC [MD96850](0x17C0-0x4083)"},
{0x8086, 0x2850, 0xE4BF, 0xCC47, "CCG-RUMBA(0xE4BF-0xCC47)"},
{0x8086, 0x28C0, 0xFFFF, 0xFFFF, "Volume Management Device NVMe RAID Controller(0x28C0)"},
{0x8086, 0x2912, 0xFFFF, 0xFFFF, "82801IH (ICH9DH) LPC Interface Controller(0x2912)"},
{0x8086, 0x2914, 0xFFFF, 0xFFFF, "82801IO (ICH9DO) LPC Interface Controller(0x2914)"},
{0x8086, 0x2914, 0x1028, 0x0211, "Optiplex 755(0x1028-0x0211)"},
{0x8086, 0x2916, 0xFFFF, 0xFFFF, "82801IR (ICH9R) LPC Interface Controller(0x2916)"},
{0x8086, 0x2916, 0x1028, 0x020D, "Inspiron 530(0x1028-0x020D)"},
{0x8086, 0x2916, 0x103C, 0x2A6F, "Asus IPIBL-LB Motherboard(0x103C-0x2A6F)"},
{0x8086, 0x2916, 0x1043, 0x8277, "P5K PRO Motherboard(0x1043-0x8277)"},
{0x8086, 0x2916, 0x1462, 0x7345, "MS-7345 Motherboard(0x1462-0x7345)"},
{0x8086, 0x2916, 0x8086, 0x5044, "Desktop Board DP35DP(0x8086-0x5044)"},
{0x8086, 0x2917, 0xFFFF, 0xFFFF, "ICH9M-E LPC Interface Controller(0x2917)"},
{0x8086, 0x2917, 0x17AA, 0x20F5, "ThinkPad T400(0x17AA-0x20F5)"},
{0x8086, 0x2917, 0xE4BF, 0xCC4D, "CCM-BOOGIE(0xE4BF-0xCC4D)"},
{0x8086, 0x2918, 0xFFFF, 0xFFFF, "82801IB (ICH9) LPC Interface Controller(0x2918)"},
{0x8086, 0x2918, 0x1028, 0x0236, "PowerEdge R610 82801IB (ICH9) LPC Interface Controller(0x1028-0x0236)"},
{0x8086, 0x2918, 0x1462, 0x7360, "G33/P35 Neo(0x1462-0x7360)"},
{0x8086, 0x2918, 0x1AF4, 0x1100, "QEMU Virtual Machine(0x1AF4-0x1100)"},
{0x8086, 0x2919, 0xFFFF, 0xFFFF, "ICH9M LPC Interface Controller(0x2919)"},
{0x8086, 0x2920, 0xFFFF, 0xFFFF, "82801IR/IO/IH (ICH9R/DO/DH) 4 port SATA Controller [IDE mode](0x2920)"},
{0x8086, 0x2920, 0x1028, 0x020D, "Inspiron 530(0x1028-0x020D)"},
{0x8086, 0x2920, 0x1028, 0x020F, "PowerEdge R300 onboard SATA Controller(0x1028-0x020F)"},
{0x8086, 0x2920, 0x1028, 0x0210, "PowerEdge T300 onboard SATA Controller(0x1028-0x0210)"},
{0x8086, 0x2920, 0x1028, 0x0211, "Optiplex 755(0x1028-0x0211)"},
{0x8086, 0x2920, 0x1028, 0x023C, "PowerEdge R200 onboard SATA Controller(0x1028-0x023C)"},
{0x8086, 0x2920, 0x1043, 0x8277, "P5K PRO Motherboard: 82801IR [ICH9R](0x1043-0x8277)"},
{0x8086, 0x2920, 0x1462, 0x7345, "MS-7345 Motherboard: Intel 82801IR [ICH9R](0x1462-0x7345)"},
{0x8086, 0x2921, 0xFFFF, 0xFFFF, "82801IB (ICH9) 2 port SATA Controller [IDE mode](0x2921)"},
{0x8086, 0x2921, 0x1028, 0x0235, "PowerEdge R710 SATA IDE Controller(0x1028-0x0235)"},
{0x8086, 0x2921, 0x1028, 0x0236, "PowerEdge R610 SATA IDE Controller(0x1028-0x0236)"},
{0x8086, 0x2921, 0x1028, 0x0237, "PowerEdge T610 SATA IDE Controller(0x1028-0x0237)"},
{0x8086, 0x2921, 0x1462, 0x7360, "G33/P35 Neo(0x1462-0x7360)"},
{0x8086, 0x2922, 0xFFFF, 0xFFFF, "82801IR/IO/IH (ICH9R/DO/DH) 6 port SATA Controller [AHCI mode](0x2922)"},
{0x8086, 0x2922, 0x1043, 0x8277, "P5K PRO Motherboard: 82801IR [ICH9R](0x1043-0x8277)"},
{0x8086, 0x2922, 0x1462, 0x7345, "MS-7345 Motherboard: Intel 82801IR [ICH9R](0x1462-0x7345)"},
{0x8086, 0x2922, 0x1AF4, 0x1100, "QEMU Virtual Machine(0x1AF4-0x1100)"},
{0x8086, 0x2922, 0x8086, 0x5044, "Desktop Board DP35DP(0x8086-0x5044)"},
{0x8086, 0x2923, 0xFFFF, 0xFFFF, "82801IB (ICH9) 4 port SATA Controller [AHCI mode](0x2923)"},
{0x8086, 0x2925, 0xFFFF, 0xFFFF, "82801IR/IO (ICH9R/DO) SATA Controller [RAID mode](0x2925)"},
{0x8086, 0x2925, 0x1734, 0x10E0, "System Board D2542(0x1734-0x10E0)"},
{0x8086, 0x2925, 0x8086, 0x2925, "System Board D2542(0x8086-0x2925)"},
{0x8086, 0x2926, 0xFFFF, 0xFFFF, "82801I (ICH9 Family) 2 port SATA Controller [IDE mode](0x2926)"},
{0x8086, 0x2926, 0x1028, 0x020D, "Inspiron 530(0x1028-0x020D)"},
{0x8086, 0x2926, 0x1028, 0x020F, "PowerEdge R300 onboard SATA Controller(0x1028-0x020F)"},
{0x8086, 0x2926, 0x1028, 0x0210, "PowerEdge T300 onboard SATA Controller(0x1028-0x0210)"},
{0x8086, 0x2926, 0x1028, 0x0211, "Optiplex 755(0x1028-0x0211)"},
{0x8086, 0x2926, 0x1043, 0x8277, "P5K PRO Motherboard: 82801IR [ICH9R](0x1043-0x8277)"},
{0x8086, 0x2926, 0x1462, 0x7345, "MS-7345 Motherboard: Intel 82801IR [ICH9R](0x1462-0x7345)"},
{0x8086, 0x2926, 0x1462, 0x7360, "G33/P35 Neo(0x1462-0x7360)"},
{0x8086, 0x2928, 0xFFFF, 0xFFFF, "82801IBM/IEM (ICH9M/ICH9M-E) 2 port SATA Controller [IDE mode](0x2928)"},
{0x8086, 0x2929, 0xFFFF, 0xFFFF, "82801IBM/IEM (ICH9M/ICH9M-E) 4 port SATA Controller [AHCI mode](0x2929)"},
{0x8086, 0x2929, 0x103C, 0x3628, "dv6-1190en(0x103C-0x3628)"},
{0x8086, 0x2929, 0x17AA, 0x20F8, "ThinkPad T400(0x17AA-0x20F8)"},
{0x8086, 0x2929, 0xE4BF, 0xCC4D, "CCM-BOOGIE(0xE4BF-0xCC4D)"},
{0x8086, 0x292C, 0xFFFF, 0xFFFF, "82801IEM (ICH9M-E) SATA Controller [RAID mode](0x292C)"},
{0x8086, 0x292D, 0xFFFF, 0xFFFF, "82801IBM/IEM (ICH9M/ICH9M-E) 2 port SATA Controller [IDE mode](0x292D)"},
{0x8086, 0x292D, 0xE4BF, 0xCC4D, "CCM-BOOGIE(0xE4BF-0xCC4D)"},
{0x8086, 0x2930, 0xFFFF, 0xFFFF, "82801I (ICH9 Family) SMBus Controller(0x2930)"},
{0x8086, 0x2930, 0x1028, 0x020D, "Inspiron 530(0x1028-0x020D)"},
{0x8086, 0x2930, 0x1028, 0x0211, "Optiplex 755(0x1028-0x0211)"},
{0x8086, 0x2930, 0x103C, 0x2A6F, "Asus IPIBL-LB Motherboard(0x103C-0x2A6F)"},
{0x8086, 0x2930, 0x103C, 0x3628, "dv6-1190en(0x103C-0x3628)"},
{0x8086, 0x2930, 0x1043, 0x8277, "P5K PRO Motherboard: 82801IR [ICH9R](0x1043-0x8277)"},
{0x8086, 0x2930, 0x1462, 0x7345, "MS-7345 Motherboard: Intel 82801I/IR [ICH9/ICH9R](0x1462-0x7345)"},
{0x8086, 0x2930, 0x1462, 0x7360, "G33/P35 Neo(0x1462-0x7360)"},
{0x8086, 0x2930, 0x17AA, 0x20F9, "ThinkPad T400(0x17AA-0x20F9)"},
{0x8086, 0x2930, 0x1AF4, 0x1100, "QEMU Virtual Machine(0x1AF4-0x1100)"},
{0x8086, 0x2930, 0x8086, 0x5044, "Desktop Board DP35DP(0x8086-0x5044)"},
{0x8086, 0x2930, 0xE4BF, 0xCC4D, "CCM-BOOGIE(0xE4BF-0xCC4D)"},
{0x8086, 0x2932, 0xFFFF, 0xFFFF, "82801I (ICH9 Family) Thermal Subsystem(0x2932)"},
{0x8086, 0x2932, 0x103C, 0x3628, "dv6-1190en(0x103C-0x3628)"},
{0x8086, 0x2934, 0xFFFF, 0xFFFF, "82801I (ICH9 Family) USB UHCI Controller #1(0x2934)"},
{0x8086, 0x2934, 0x1028, 0x020D, "Inspiron 530(0x1028-0x020D)"},
{0x8086, 0x2934, 0x1028, 0x020F, "PowerEdge R300 onboard UHCI(0x1028-0x020F)"},
{0x8086, 0x2934, 0x1028, 0x0210, "PowerEdge T300 onboard UHCI(0x1028-0x0210)"},
{0x8086, 0x2934, 0x1028, 0x0211, "Optiplex 755(0x1028-0x0211)"},
{0x8086, 0x2934, 0x1028, 0x0235, "PowerEdge R710 USB UHCI Controller(0x1028-0x0235)"},
{0x8086, 0x2934, 0x1028, 0x0236, "PowerEdge R610 USB UHCI Controller(0x1028-0x0236)"},
{0x8086, 0x2934, 0x1028, 0x0237, "PowerEdge T610 USB UHCI Controller(0x1028-0x0237)"},
{0x8086, 0x2934, 0x1028, 0x023C, "PowerEdge R200 onboard UHCI(0x1028-0x023C)"},
{0x8086, 0x2934, 0x1028, 0x0287, "PowerEdge M610 onboard UHCI(0x1028-0x0287)"},
{0x8086, 0x2934, 0x1028, 0x029C, "PowerEdge M710 USB UHCI Controller(0x1028-0x029C)"},
{0x8086, 0x2934, 0x1028, 0x2011, "Optiplex 755(0x1028-0x2011)"},
{0x8086, 0x2934, 0x103C, 0x2A6F, "Asus IPIBL-LB Motherboard(0x103C-0x2A6F)"},
{0x8086, 0x2934, 0x1043, 0x8277, "P5K PRO Motherboard: 82801IR [ICH9R](0x1043-0x8277)"},
{0x8086, 0x2934, 0x1462, 0x7345, "MS-7345 Motherboard: Intel 82801I/IR [ICH9/ICH9R](0x1462-0x7345)"},
{0x8086, 0x2934, 0x1462, 0x7360, "G33/P35 Neo(0x1462-0x7360)"},
{0x8086, 0x2934, 0x17AA, 0x20F0, "ThinkPad T400(0x17AA-0x20F0)"},
{0x8086, 0x2934, 0x1AF4, 0x1100, "QEMU Virtual Machine(0x1AF4-0x1100)"},
{0x8086, 0x2934, 0x8086, 0x5044, "Desktop Board DP35DP(0x8086-0x5044)"},
{0x8086, 0x2934, 0xE4BF, 0xCC4D, "CCM-BOOGIE(0xE4BF-0xCC4D)"},
{0x8086, 0x2935, 0xFFFF, 0xFFFF, "82801I (ICH9 Family) USB UHCI Controller #2(0x2935)"},
{0x8086, 0x2935, 0x1028, 0x020D, "Inspiron 530(0x1028-0x020D)"},
{0x8086, 0x2935, 0x1028, 0x020F, "PowerEdge R300 onboard UHCI(0x1028-0x020F)"},
{0x8086, 0x2935, 0x1028, 0x0210, "PowerEdge T300 onboard UHCI(0x1028-0x0210)"},
{0x8086, 0x2935, 0x1028, 0x0211, "Optiplex 755(0x1028-0x0211)"},
{0x8086, 0x2935, 0x1028, 0x0235, "PowerEdge R710 USB UHCI Controller(0x1028-0x0235)"},
{0x8086, 0x2935, 0x1028, 0x0236, "PowerEdge R610 USB UHCI Controller(0x1028-0x0236)"},
{0x8086, 0x2935, 0x1028, 0x0237, "PowerEdge T610 USB UHCI Controller(0x1028-0x0237)"},
{0x8086, 0x2935, 0x1028, 0x023C, "PowerEdge R200 onboard UHCI(0x1028-0x023C)"},
{0x8086, 0x2935, 0x1028, 0x0287, "PowerEdge M610 onboard UHCI(0x1028-0x0287)"},
{0x8086, 0x2935, 0x1028, 0x029C, "PowerEdge M710 USB UHCI Controller(0x1028-0x029C)"},
{0x8086, 0x2935, 0x103C, 0x2A6F, "Asus IPIBL-LB Motherboard(0x103C-0x2A6F)"},
{0x8086, 0x2935, 0x1043, 0x8277, "P5K PRO Motherboard: 82801IR [ICH9R](0x1043-0x8277)"},
{0x8086, 0x2935, 0x1462, 0x7345, "MS-7345 Motherboard: Intel 82801I/IR [ICH9/ICH9R](0x1462-0x7345)"},
{0x8086, 0x2935, 0x1462, 0x7360, "G33/P35 Neo(0x1462-0x7360)"},
{0x8086, 0x2935, 0x17AA, 0x20F0, "ThinkPad T400(0x17AA-0x20F0)"},
{0x8086, 0x2935, 0x1AF4, 0x1100, "QEMU Virtual Machine(0x1AF4-0x1100)"},
{0x8086, 0x2935, 0x8086, 0x5044, "Desktop Board DP35DP(0x8086-0x5044)"},
{0x8086, 0x2935, 0xE4BF, 0xCC4D, "CCM-BOOGIE(0xE4BF-0xCC4D)"},
{0x8086, 0x2936, 0xFFFF, 0xFFFF, "82801I (ICH9 Family) USB UHCI Controller #3(0x2936)"},
{0x8086, 0x2936, 0x1028, 0x020D, "Inspiron 530(0x1028-0x020D)"},
{0x8086, 0x2936, 0x1028, 0x020F, "PowerEdge R300 onboard UHCI(0x1028-0x020F)"},
{0x8086, 0x2936, 0x1028, 0x0210, "PowerEdge T300 onboard UHCI(0x1028-0x0210)"},
{0x8086, 0x2936, 0x1028, 0x0211, "Optiplex 755(0x1028-0x0211)"},
{0x8086, 0x2936, 0x1028, 0x0237, "PowerEdge T610 USB UHCI Controller(0x1028-0x0237)"},
{0x8086, 0x2936, 0x1028, 0x023C, "PowerEdge R200 onboard UHCI(0x1028-0x023C)"},
{0x8086, 0x2936, 0x1028, 0x0287, "PowerEdge M610 onboard UHCI(0x1028-0x0287)"},
{0x8086, 0x2936, 0x1028, 0x029C, "PowerEdge M710 USB UHCI Controller(0x1028-0x029C)"},
{0x8086, 0x2936, 0x103C, 0x2A6F, "Asus IPIBL-LB Motherboard(0x103C-0x2A6F)"},
{0x8086, 0x2936, 0x1043, 0x8277, "P5K PRO Motherboard: 82801IR [ICH9R](0x1043-0x8277)"},
{0x8086, 0x2936, 0x1462, 0x7345, "MS-7345 Motherboard: Intel 82801I/IR [ICH9/ICH9R](0x1462-0x7345)"},
{0x8086, 0x2936, 0x1462, 0x7360, "G33/P35 Neo(0x1462-0x7360)"},
{0x8086, 0x2936, 0x17AA, 0x20F0, "ThinkPad T400(0x17AA-0x20F0)"},
{0x8086, 0x2936, 0x1AF4, 0x1100, "QEMU Virtual Machine(0x1AF4-0x1100)"},
{0x8086, 0x2936, 0x8086, 0x5044, "Desktop Board DP35DP(0x8086-0x5044)"},
{0x8086, 0x2936, 0xE4BF, 0xCC4D, "CCM-BOOGIE(0xE4BF-0xCC4D)"},
{0x8086, 0x2937, 0xFFFF, 0xFFFF, "82801I (ICH9 Family) USB UHCI Controller #4(0x2937)"},
{0x8086, 0x2937, 0x1028, 0x020D, "Inspiron 530(0x1028-0x020D)"},
{0x8086, 0x2937, 0x1028, 0x0211, "Optiplex 755(0x1028-0x0211)"},
{0x8086, 0x2937, 0x1028, 0x0235, "PowerEdge R710 USB UHCI Controller(0x1028-0x0235)"},
{0x8086, 0x2937, 0x1028, 0x0236, "PowerEdge R610 USB UHCI Controller(0x1028-0x0236)"},
{0x8086, 0x2937, 0x1028, 0x0237, "PowerEdge T610 USB UHCI Controller(0x1028-0x0237)"},
{0x8086, 0x2937, 0x1028, 0x0287, "PowerEdge M610 onboard UHCI(0x1028-0x0287)"},
{0x8086, 0x2937, 0x1028, 0x029C, "PowerEdge M710 USB UHCI Controller(0x1028-0x029C)"},
{0x8086, 0x2937, 0x1028, 0x2011, "Optiplex 755(0x1028-0x2011)"},
{0x8086, 0x2937, 0x103C, 0x2A6F, "Asus IPIBL-LB Motherboard(0x103C-0x2A6F)"},
{0x8086, 0x2937, 0x1043, 0x8277, "P5K PRO Motherboard: 82801IR [ICH9R](0x1043-0x8277)"},
{0x8086, 0x2937, 0x1462, 0x7345, "MS-7345 Motherboard: Intel 82801I/IR [ICH9/ICH9R](0x1462-0x7345)"},
{0x8086, 0x2937, 0x1462, 0x7360, "G33/P35 Neo(0x1462-0x7360)"},
{0x8086, 0x2937, 0x17AA, 0x20F0, "ThinkPad T400(0x17AA-0x20F0)"},
{0x8086, 0x2937, 0x1AF4, 0x1100, "QEMU Virtual Machine(0x1AF4-0x1100)"},
{0x8086, 0x2937, 0x8086, 0x2937, "Optiplex 755(0x8086-0x2937)"},
{0x8086, 0x2937, 0x8086, 0x2942, "828011 (ICH9 Family ) USB UHCI Controller(0x8086-0x2942)"},
{0x8086, 0x2937, 0x8086, 0x5044, "Desktop Board DP35DP(0x8086-0x5044)"},
{0x8086, 0x2937, 0xE4BF, 0xCC4D, "CCM-BOOGIE(0xE4BF-0xCC4D)"},
{0x8086, 0x2938, 0xFFFF, 0xFFFF, "82801I (ICH9 Family) USB UHCI Controller #5(0x2938)"},
{0x8086, 0x2938, 0x1028, 0x020D, "Inspiron 530(0x1028-0x020D)"},
{0x8086, 0x2938, 0x1028, 0x0211, "Optiplex 755(0x1028-0x0211)"},
{0x8086, 0x2938, 0x1028, 0x0235, "PowerEdge R710 USB UHCI Controller(0x1028-0x0235)"},
{0x8086, 0x2938, 0x1028, 0x0236, "PowerEdge R610 USB UHCI Controller(0x1028-0x0236)"},
{0x8086, 0x2938, 0x1028, 0x0237, "PowerEdge T610 USB UHCI Controller(0x1028-0x0237)"},
{0x8086, 0x2938, 0x1028, 0x0287, "PowerEdge M610 onboard UHCI(0x1028-0x0287)"},
{0x8086, 0x2938, 0x1028, 0x029C, "PowerEdge M710 USB UHCI Controller(0x1028-0x029C)"},
{0x8086, 0x2938, 0x103C, 0x2A6F, "Asus IPIBL-LB Motherboard(0x103C-0x2A6F)"},
{0x8086, 0x2938, 0x1043, 0x8277, "P5K PRO Motherboard: 82801IR [ICH9R](0x1043-0x8277)"},
{0x8086, 0x2938, 0x1462, 0x7345, "MS-7345 Motherboard: Intel 82801I/IR [ICH9/ICH9R](0x1462-0x7345)"},
{0x8086, 0x2938, 0x1462, 0x7360, "G33/P35 Neo(0x1462-0x7360)"},
{0x8086, 0x2938, 0x17AA, 0x20F0, "ThinkPad T400(0x17AA-0x20F0)"},
{0x8086, 0x2938, 0x1AF4, 0x1100, "QEMU Virtual Machine(0x1AF4-0x1100)"},
{0x8086, 0x2938, 0x8086, 0x2938, "Optiplex 755(0x8086-0x2938)"},
{0x8086, 0x2938, 0x8086, 0x5044, "Desktop Board DP35DP(0x8086-0x5044)"},
{0x8086, 0x2938, 0xE4BF, 0xCC4D, "CCM-BOOGIE(0xE4BF-0xCC4D)"},
{0x8086, 0x2939, 0xFFFF, 0xFFFF, "82801I (ICH9 Family) USB UHCI Controller #6(0x2939)"},
{0x8086, 0x2939, 0x1028, 0x020D, "Inspiron 530(0x1028-0x020D)"},
{0x8086, 0x2939, 0x1028, 0x0210, "PowerEdge T300 onboard UHCI(0x1028-0x0210)"},
{0x8086, 0x2939, 0x1028, 0x0237, "PowerEdge T610 USB UHCI Controller(0x1028-0x0237)"},
{0x8086, 0x2939, 0x103C, 0x2A6F, "Asus IPIBL-LB Motherboard(0x103C-0x2A6F)"},
{0x8086, 0x2939, 0x1043, 0x8277, "P5K PRO Motherboard: 82801IR [ICH9R](0x1043-0x8277)"},
{0x8086, 0x2939, 0x1462, 0x7345, "MS-7345 Motherboard: Intel 82801I/IR [ICH9/ICH9R](0x1462-0x7345)"},
{0x8086, 0x2939, 0x1462, 0x7360, "G33/P35 Neo(0x1462-0x7360)"},
{0x8086, 0x2939, 0x17AA, 0x20F0, "ThinkPad T400(0x17AA-0x20F0)"},
{0x8086, 0x2939, 0x1AF4, 0x1100, "QEMU Virtual Machine(0x1AF4-0x1100)"},
{0x8086, 0x2939, 0x8086, 0x5044, "Desktop Board DP35DP(0x8086-0x5044)"},
{0x8086, 0x2939, 0xE4BF, 0xCC4D, "CCM-BOOGIE(0xE4BF-0xCC4D)"},
{0x8086, 0x293A, 0xFFFF, 0xFFFF, "82801I (ICH9 Family) USB2 EHCI Controller #1(0x293A)"},
{0x8086, 0x293A, 0x1028, 0x020D, "Inspiron 530(0x1028-0x020D)"},
{0x8086, 0x293A, 0x1028, 0x020F, "PowerEdge R300 onboard EHCI(0x1028-0x020F)"},
{0x8086, 0x293A, 0x1028, 0x0210, "PowerEdge T300 onboard EHCI(0x1028-0x0210)"},
{0x8086, 0x293A, 0x1028, 0x0211, "Optiplex 755(0x1028-0x0211)"},
{0x8086, 0x293A, 0x1028, 0x0235, "PowerEdge R710 USB EHCI Controller(0x1028-0x0235)"},
{0x8086, 0x293A, 0x1028, 0x0236, "PowerEdge R610 USB EHCI Controller(0x1028-0x0236)"},
{0x8086, 0x293A, 0x1028, 0x0237, "PowerEdge T610 USB EHCI Controller(0x1028-0x0237)"},
{0x8086, 0x293A, 0x1028, 0x023C, "PowerEdge R200 onboard EHCI(0x1028-0x023C)"},
{0x8086, 0x293A, 0x1028, 0x0287, "PowerEdge M610 onboard EHCI(0x1028-0x0287)"},
{0x8086, 0x293A, 0x1028, 0x029C, "PowerEdge M710 USB EHCI Controller(0x1028-0x029C)"},
{0x8086, 0x293A, 0x103C, 0x2A6F, "Asus IPIBL-LB Motherboard(0x103C-0x2A6F)"},
{0x8086, 0x293A, 0x1043, 0x8277, "P5K PRO Motherboard: 82801IR [ICH9R](0x1043-0x8277)"},
{0x8086, 0x293A, 0x1462, 0x7345, "MS-7345 Motherboard: Intel 82801I/IR [ICH9/ICH9R](0x1462-0x7345)"},
{0x8086, 0x293A, 0x1462, 0x7360, "G33/P35 Neo(0x1462-0x7360)"},
{0x8086, 0x293A, 0x17AA, 0x20F1, "ThinkPad T400(0x17AA-0x20F1)"},
{0x8086, 0x293A, 0x1AF4, 0x1100, "QEMU Virtual Machine(0x1AF4-0x1100)"},
{0x8086, 0x293A, 0x8086, 0x5044, "Desktop Board DP35DP(0x8086-0x5044)"},
{0x8086, 0x293A, 0xE4BF, 0xCC4D, "CCM-BOOGIE(0xE4BF-0xCC4D)"},
{0x8086, 0x293C, 0xFFFF, 0xFFFF, "82801I (ICH9 Family) USB2 EHCI Controller #2(0x293C)"},
{0x8086, 0x293C, 0x1028, 0x020D, "Inspiron 530(0x1028-0x020D)"},
{0x8086, 0x293C, 0x1028, 0x0211, "Optiplex 755(0x1028-0x0211)"},
{0x8086, 0x293C, 0x1028, 0x0235, "PowerEdge R710 USB EHCI Controller(0x1028-0x0235)"},
{0x8086, 0x293C, 0x1028, 0x0236, "PowerEdge R610 USB EHCI Controller(0x1028-0x0236)"},
{0x8086, 0x293C, 0x1028, 0x0237, "PowerEdge T610 USB EHCI Controller(0x1028-0x0237)"},
{0x8086, 0x293C, 0x1028, 0x0287, "PowerEdge M610 onboard EHCI(0x1028-0x0287)"},
{0x8086, 0x293C, 0x1028, 0x029C, "PowerEdge M710 USB EHCI Controller(0x1028-0x029C)"},
{0x8086, 0x293C, 0x103C, 0x2A6F, "Asus IPIBL-LB Motherboard(0x103C-0x2A6F)"},
{0x8086, 0x293C, 0x1043, 0x8277, "P5K PRO Motherboard: 82801IR [ICH9R](0x1043-0x8277)"},
{0x8086, 0x293C, 0x1462, 0x7345, "MS-7345 Motherboard: Intel 82801I/IR [ICH9/ICH9R](0x1462-0x7345)"},
{0x8086, 0x293C, 0x1462, 0x7360, "G33/P35 Neo(0x1462-0x7360)"},
{0x8086, 0x293C, 0x17AA, 0x20F1, "ThinkPad T400(0x17AA-0x20F1)"},
{0x8086, 0x293C, 0x1AF4, 0x1100, "QEMU Virtual Machine(0x1AF4-0x1100)"},
{0x8086, 0x293C, 0x8086, 0x293C, "Optiplex 755(0x8086-0x293C)"},
{0x8086, 0x293C, 0x8086, 0x5044, "Desktop Board DP35DP(0x8086-0x5044)"},
{0x8086, 0x293C, 0xE4BF, 0xCC4D, "CCM-BOOGIE(0xE4BF-0xCC4D)"},
{0x8086, 0x293E, 0xFFFF, 0xFFFF, "82801I (ICH9 Family) HD Audio Controller(0x293E)"},
{0x8086, 0x293E, 0x1028, 0x020D, "Inspiron 530(0x1028-0x020D)"},
{0x8086, 0x293E, 0x1028, 0x0211, "Optiplex 755(0x1028-0x0211)"},
{0x8086, 0x293E, 0x103C, 0x2A6F, "Asus IPIBL-LB Motherboard(0x103C-0x2A6F)"},
{0x8086, 0x293E, 0x103C, 0x3628, "dv6-1190en(0x103C-0x3628)"},
{0x8086, 0x293E, 0x1043, 0x829F, "P5K PRO Motherboard: 82801IR [ICH9R](0x1043-0x829F)"},
{0x8086, 0x293E, 0x1462, 0x735A, "MS-7345 Motherboard: Intel 82801I/IR [ICH9/ICH9R](0x1462-0x735A)"},
{0x8086, 0x293E, 0x1462, 0x7360, "G33/P35 Neo(0x1462-0x7360)"},
{0x8086, 0x293E, 0x17AA, 0x20F2, "ThinkPad T400(0x17AA-0x20F2)"},
{0x8086, 0x293E, 0x1AF4, 0x1100, "QEMU Virtual Machine(0x1AF4-0x1100)"},
{0x8086, 0x293E, 0x8086, 0x293E, "Optiplex 755(0x8086-0x293E)"},
{0x8086, 0x293E, 0x8086, 0x2940, "Optiplex 755(0x8086-0x2940)"},
{0x8086, 0x293E, 0xE4BF, 0xCC4D, "CCM-BOOGIE(0xE4BF-0xCC4D)"},
{0x8086, 0x2940, 0xFFFF, 0xFFFF, "82801I (ICH9 Family) PCI Express Port 1(0x2940)"},
{0x8086, 0x2940, 0x1028, 0x020D, "Inspiron 530(0x1028-0x020D)"},
{0x8086, 0x2940, 0x1028, 0x0211, "Optiplex 755(0x1028-0x0211)"},
{0x8086, 0x2940, 0x103C, 0x2A6F, "Asus IPIBL-LB Motherboard(0x103C-0x2A6F)"},
{0x8086, 0x2940, 0x1043, 0x8277, "P5K PRO Motherboard: 82801IR [ICH9R](0x1043-0x8277)"},
{0x8086, 0x2940, 0x1462, 0x7345, "MS-7345 Motherboard: Intel 82801I/IR [ICH9/ICH9R](0x1462-0x7345)"},
{0x8086, 0x2940, 0x8086, 0x2940, "Optiplex 755(0x8086-0x2940)"},
{0x8086, 0x2942, 0xFFFF, 0xFFFF, "82801I (ICH9 Family) PCI Express Port 2(0x2942)"},
{0x8086, 0x2942, 0x1028, 0x020D, "Inspiron 530(0x1028-0x020D)"},
{0x8086, 0x2944, 0xFFFF, 0xFFFF, "82801I (ICH9 Family) PCI Express Port 3(0x2944)"},
{0x8086, 0x2944, 0x1028, 0x020D, "Inspiron 530(0x1028-0x020D)"},
{0x8086, 0x2944, 0x103C, 0x2A6F, "Asus IPIBL-LB Motherboard(0x103C-0x2A6F)"},
{0x8086, 0x2946, 0xFFFF, 0xFFFF, "82801I (ICH9 Family) PCI Express Port 4(0x2946)"},
{0x8086, 0x2946, 0x1028, 0x020D, "Inspiron 530(0x1028-0x020D)"},
{0x8086, 0x2948, 0xFFFF, 0xFFFF, "82801I (ICH9 Family) PCI Express Port 5(0x2948)"},
{0x8086, 0x2948, 0x1028, 0x020D, "Inspiron 530(0x1028-0x020D)"},
{0x8086, 0x2948, 0x1043, 0x8277, "P5K PRO Motherboard: 82801IR [ICH9R](0x1043-0x8277)"},
{0x8086, 0x2948, 0x1462, 0x7345, "MS-7345 Motherboard: Intel 82801I/IR [ICH9/ICH9R](0x1462-0x7345)"},
{0x8086, 0x294A, 0xFFFF, 0xFFFF, "82801I (ICH9 Family) PCI Express Port 6(0x294A)"},
{0x8086, 0x294A, 0x1028, 0x020D, "Inspiron 530(0x1028-0x020D)"},
{0x8086, 0x294A, 0x1043, 0x8277, "P5K PRO Motherboard: 82801IR [ICH9R](0x1043-0x8277)"},
{0x8086, 0x294A, 0x1462, 0x7345, "MS-7345 Motherboard: Intel 82801I/IR [ICH9/ICH9R](0x1462-0x7345)"},
{0x8086, 0x294C, 0xFFFF, 0xFFFF, "82566DC-2 Gigabit Network Connection(0x294C)"},
{0x8086, 0x294C, 0x17AA, 0x302E, "82566DM-2 Gigabit Network Connection(0x17AA-0x302E)"},
{0x8086, 0x2970, 0xFFFF, 0xFFFF, "82946GZ/PL/GL Memory Controller Hub(0x2970)"},
{0x8086, 0x2970, 0x1043, 0x823B, "P5B-MX/WiFi-AP(0x1043-0x823B)"},
{0x8086, 0x2971, 0xFFFF, 0xFFFF, "82946GZ/PL/GL PCI Express Root Port(0x2971)"},
{0x8086, 0x2972, 0xFFFF, 0xFFFF, "82946GZ/GL Integrated Graphics Controller(0x2972)"},
{0x8086, 0x2972, 0x1043, 0x823B, "P5B-MX/WiFi-AP(0x1043-0x823B)"},
{0x8086, 0x2973, 0xFFFF, 0xFFFF, "82946GZ/GL Integrated Graphics Controller(0x2973)"},
{0x8086, 0x2974, 0xFFFF, 0xFFFF, "82946GZ/GL HECI Controller(0x2974)"},
{0x8086, 0x2975, 0xFFFF, 0xFFFF, "82946GZ/GL HECI Controller(0x2975)"},
{0x8086, 0x2976, 0xFFFF, 0xFFFF, "82946GZ/GL PT IDER Controller(0x2976)"},
{0x8086, 0x2977, 0xFFFF, 0xFFFF, "82946GZ/GL KT Controller(0x2977)"},
{0x8086, 0x2980, 0xFFFF, 0xFFFF, "82G35 Express DRAM Controller(0x2980)"},
{0x8086, 0x2981, 0xFFFF, 0xFFFF, "82G35 Express PCI Express Root Port(0x2981)"},
{0x8086, 0x2982, 0xFFFF, 0xFFFF, "82G35 Express Integrated Graphics Controller(0x2982)"},
{0x8086, 0x2983, 0xFFFF, 0xFFFF, "82G35 Express Integrated Graphics Controller(0x2983)"},
{0x8086, 0x2984, 0xFFFF, 0xFFFF, "82G35 Express HECI Controller(0x2984)"},
{0x8086, 0x2990, 0xFFFF, 0xFFFF, "82Q963/Q965 Memory Controller Hub(0x2990)"},
{0x8086, 0x2990, 0x1028, 0x01DA, "OptiPlex 745(0x1028-0x01DA)"},
{0x8086, 0x2991, 0xFFFF, 0xFFFF, "82Q963/Q965 PCI Express Root Port(0x2991)"},
{0x8086, 0x2992, 0xFFFF, 0xFFFF, "82Q963/Q965 Integrated Graphics Controller(0x2992)"},
{0x8086, 0x2993, 0xFFFF, 0xFFFF, "82Q963/Q965 Integrated Graphics Controller(0x2993)"},
{0x8086, 0x2994, 0xFFFF, 0xFFFF, "82Q963/Q965 HECI Controller(0x2994)"},
{0x8086, 0x2995, 0xFFFF, 0xFFFF, "82Q963/Q965 HECI Controller(0x2995)"},
{0x8086, 0x2996, 0xFFFF, 0xFFFF, "82Q963/Q965 PT IDER Controller(0x2996)"},
{0x8086, 0x2997, 0xFFFF, 0xFFFF, "82Q963/Q965 KT Controller(0x2997)"},
{0x8086, 0x29A0, 0xFFFF, 0xFFFF, "82P965/G965 Memory Controller Hub(0x29A0)"},
{0x8086, 0x29A0, 0x1043, 0x81EA, "P5B(0x1043-0x81EA)"},
{0x8086, 0x29A0, 0x1462, 0x7276, "MS-7276 [G965MDH](0x1462-0x7276)"},
{0x8086, 0x29A1, 0xFFFF, 0xFFFF, "82P965/G965 PCI Express Root Port(0x29A1)"},
{0x8086, 0x29A2, 0xFFFF, 0xFFFF, "82G965 Integrated Graphics Controller(0x29A2)"},
{0x8086, 0x29A2, 0x1462, 0x7276, "MS-7276 [G965MDH](0x1462-0x7276)"},
{0x8086, 0x29A3, 0xFFFF, 0xFFFF, "82G965 Integrated Graphics Controller(0x29A3)"},
{0x8086, 0x29A4, 0xFFFF, 0xFFFF, "82P965/G965 HECI Controller(0x29A4)"},
{0x8086, 0x29A5, 0xFFFF, 0xFFFF, "82P965/G965 HECI Controller(0x29A5)"},
{0x8086, 0x29A6, 0xFFFF, 0xFFFF, "82P965/G965 PT IDER Controller(0x29A6)"},
{0x8086, 0x29A7, 0xFFFF, 0xFFFF, "82P965/G965 KT Controller(0x29A7)"},
{0x8086, 0x29B0, 0xFFFF, 0xFFFF, "82Q35 Express DRAM Controller(0x29B0)"},
{0x8086, 0x29B0, 0x1028, 0x0211, "OptiPlex 755(0x1028-0x0211)"},
{0x8086, 0x29B1, 0xFFFF, 0xFFFF, "82Q35 Express PCI Express Root Port(0x29B1)"},
{0x8086, 0x29B1, 0x1028, 0x0211, "OptiPlex 755(0x1028-0x0211)"},
{0x8086, 0x29B2, 0xFFFF, 0xFFFF, "82Q35 Express Integrated Graphics Controller(0x29B2)"},
{0x8086, 0x29B2, 0x1028, 0x0211, "OptiPlex 755(0x1028-0x0211)"},
{0x8086, 0x29B3, 0xFFFF, 0xFFFF, "82Q35 Express Integrated Graphics Controller(0x29B3)"},
{0x8086, 0x29B3, 0x1028, 0x0211, "OptiPlex 755(0x1028-0x0211)"},
{0x8086, 0x29B4, 0xFFFF, 0xFFFF, "82Q35 Express MEI Controller(0x29B4)"},
{0x8086, 0x29B4, 0x1028, 0x0211, "OptiPlex 755(0x1028-0x0211)"},
{0x8086, 0x29B5, 0xFFFF, 0xFFFF, "82Q35 Express MEI Controller(0x29B5)"},
{0x8086, 0x29B6, 0xFFFF, 0xFFFF, "82Q35 Express PT IDER Controller(0x29B6)"},
{0x8086, 0x29B6, 0x1028, 0x0211, "OptiPlex 755(0x1028-0x0211)"},
{0x8086, 0x29B7, 0xFFFF, 0xFFFF, "82Q35 Express Serial KT Controller(0x29B7)"},
{0x8086, 0x29B7, 0x1028, 0x0211, "OptiPlex 755(0x1028-0x0211)"},
{0x8086, 0x29C0, 0xFFFF, 0xFFFF, "82G33/G31/P35/P31 Express DRAM Controller(0x29C0)"},
{0x8086, 0x29C0, 0x1028, 0x020D, "Inspiron 530(0x1028-0x020D)"},
{0x8086, 0x29C0, 0x103C, 0x2A6F, "Asus IPIBL-LB Motherboard(0x103C-0x2A6F)"},
{0x8086, 0x29C0, 0x1043, 0x8276, "P5K PRO Motherboard: Intel 82P35 Northbridge(0x1043-0x8276)"},
{0x8086, 0x29C0, 0x1043, 0x82B0, "P5KPL-VM Motherboard(0x1043-0x82B0)"},
{0x8086, 0x29C0, 0x1462, 0x7345, "MS-7345 Motherboard: Intel 82G33/P35 Northbridge(0x1462-0x7345)"},
{0x8086, 0x29C0, 0x1462, 0x7360, "G33/P35 Neo(0x1462-0x7360)"},
{0x8086, 0x29C0, 0x1AF4, 0x1100, "QEMU Virtual Machine(0x1AF4-0x1100)"},
{0x8086, 0x29C0, 0x8086, 0x5044, "Desktop Board DP35DP(0x8086-0x5044)"},
{0x8086, 0x29C1, 0xFFFF, 0xFFFF, "82G33/G31/P35/P31 Express PCI Express Root Port(0x29C1)"},
{0x8086, 0x29C1, 0x1028, 0x020D, "Inspiron 530(0x1028-0x020D)"},
{0x8086, 0x29C1, 0x1043, 0x8276, "P5K PRO Motherboard: Intel 82P35 Northbridge(0x1043-0x8276)"},
{0x8086, 0x29C2, 0xFFFF, 0xFFFF, "82G33/G31 Express Integrated Graphics Controller(0x29C2)"},
{0x8086, 0x29C2, 0x1028, 0x020D, "Inspiron 530(0x1028-0x020D)"},
{0x8086, 0x29C2, 0x1043, 0x82B0, "P5KPL-VM Motherboard(0x1043-0x82B0)"},
{0x8086, 0x29C3, 0xFFFF, 0xFFFF, "82G33/G31 Express Integrated Graphics Controller(0x29C3)"},
{0x8086, 0x29C3, 0x1028, 0x020D, "Inspiron 530(0x1028-0x020D)"},
{0x8086, 0x29C3, 0x1043, 0x82B0, "P5KPL-VM Motherboard(0x1043-0x82B0)"},
{0x8086, 0x29C4, 0xFFFF, 0xFFFF, "82G33/G31/P35/P31 Express MEI Controller(0x29C4)"},
{0x8086, 0x29C4, 0x8086, 0x5044, "Desktop Board DP35DP(0x8086-0x5044)"},
{0x8086, 0x29C5, 0xFFFF, 0xFFFF, "82G33/G31/P35/P31 Express MEI Controller(0x29C5)"},
{0x8086, 0x29C6, 0xFFFF, 0xFFFF, "82G33/G31/P35/P31 Express PT IDER Controller(0x29C6)"},
{0x8086, 0x29C7, 0xFFFF, 0xFFFF, "82G33/G31/P35/P31 Express Serial KT Controller(0x29C7)"},
{0x8086, 0x29CF, 0xFFFF, 0xFFFF, "Virtual HECI Controller(0x29CF)"},
{0x8086, 0x29D0, 0xFFFF, 0xFFFF, "82Q33 Express DRAM Controller(0x29D0)"},
{0x8086, 0x29D1, 0xFFFF, 0xFFFF, "82Q33 Express PCI Express Root Port(0x29D1)"},
{0x8086, 0x29D2, 0xFFFF, 0xFFFF, "82Q33 Express Integrated Graphics Controller(0x29D2)"},
{0x8086, 0x29D3, 0xFFFF, 0xFFFF, "82Q33 Express Integrated Graphics Controller(0x29D3)"},
{0x8086, 0x29D4, 0xFFFF, 0xFFFF, "82Q33 Express MEI Controller(0x29D4)"},
{0x8086, 0x29D5, 0xFFFF, 0xFFFF, "82Q33 Express MEI Controller(0x29D5)"},
{0x8086, 0x29D6, 0xFFFF, 0xFFFF, "82Q33 Express PT IDER Controller(0x29D6)"},
{0x8086, 0x29D7, 0xFFFF, 0xFFFF, "82Q33 Express Serial KT Controller(0x29D7)"},
{0x8086, 0x29E0, 0xFFFF, 0xFFFF, "82X38/X48 Express DRAM Controller(0x29E0)"},
{0x8086, 0x29E1, 0xFFFF, 0xFFFF, "82X38/X48 Express Host-Primary PCI Express Bridge(0x29E1)"},
{0x8086, 0x29E4, 0xFFFF, 0xFFFF, "82X38/X48 Express MEI Controller(0x29E4)"},
{0x8086, 0x29E5, 0xFFFF, 0xFFFF, "82X38/X48 Express MEI Controller(0x29E5)"},
{0x8086, 0x29E6, 0xFFFF, 0xFFFF, "82X38/X48 Express PT IDER Controller(0x29E6)"},
{0x8086, 0x29E7, 0xFFFF, 0xFFFF, "82X38/X48 Express Serial KT Controller(0x29E7)"},
{0x8086, 0x29E9, 0xFFFF, 0xFFFF, "82X38/X48 Express Host-Secondary PCI Express Bridge(0x29E9)"},
{0x8086, 0x29F0, 0xFFFF, 0xFFFF, "3200/3210 Chipset DRAM Controller(0x29F0)"},
{0x8086, 0x29F1, 0xFFFF, 0xFFFF, "3200/3210 Chipset Host-Primary PCI Express Bridge(0x29F1)"},
{0x8086, 0x29F4, 0xFFFF, 0xFFFF, "3200/3210 Chipset MEI Controller(0x29F4)"},
{0x8086, 0x29F5, 0xFFFF, 0xFFFF, "3200/3210 Chipset MEI Controller(0x29F5)"},
{0x8086, 0x29F6, 0xFFFF, 0xFFFF, "3200/3210 Chipset PT IDER Controller(0x29F6)"},
{0x8086, 0x29F7, 0xFFFF, 0xFFFF, "3200/3210 Chipset Serial KT Controller(0x29F7)"},
{0x8086, 0x29F9, 0xFFFF, 0xFFFF, "3210 Chipset Host-Secondary PCI Express Bridge(0x29F9)"},
{0x8086, 0x2A00, 0xFFFF, 0xFFFF, "Mobile PM965/GM965/GL960 Memory Controller Hub(0x2A00)"},
{0x8086, 0x2A00, 0x1025, 0x0121, "Aspire 5920G(0x1025-0x0121)"},
{0x8086, 0x2A00, 0x1028, 0x01F3, "Inspiron 1420(0x1028-0x01F3)"},
{0x8086, 0x2A00, 0x1028, 0x022F, "Inspiron 1525(0x1028-0x022F)"},
{0x8086, 0x2A00, 0x103C, 0x30C0, "Compaq 6710b(0x103C-0x30C0)"},
{0x8086, 0x2A00, 0x103C, 0x30C1, "Compaq 6910p(0x103C-0x30C1)"},
{0x8086, 0x2A00, 0x103C, 0x30C5, "Compaq 8510p(0x103C-0x30C5)"},
{0x8086, 0x2A00, 0x103C, 0x30CC, "Pavilion dv6700(0x103C-0x30CC)"},
{0x8086, 0x2A00, 0x103C, 0x30D9, "Presario C700(0x103C-0x30D9)"},
{0x8086, 0x2A00, 0x1043, 0x1017, "X58LE(0x1043-0x1017)"},
{0x8086, 0x2A00, 0x104D, 0x9005, "Vaio VGN-FZ260E(0x104D-0x9005)"},
{0x8086, 0x2A00, 0x104D, 0x902D, "VAIO VGN-NR120E(0x104D-0x902D)"},
{0x8086, 0x2A00, 0x17AA, 0x20B1, "ThinkPad T61(0x17AA-0x20B1)"},
{0x8086, 0x2A00, 0x17AA, 0x20B3, "ThinkPad T61/R61(0x17AA-0x20B3)"},
{0x8086, 0x2A00, 0x17C0, 0x4082, "Medion WIM 2210 Notebook PC [MD96850](0x17C0-0x4082)"},
{0x8086, 0x2A00, 0xE4BF, 0xCC47, "CCG-RUMBA(0xE4BF-0xCC47)"},
{0x8086, 0x2A01, 0xFFFF, 0xFFFF, "Mobile PM965/GM965/GL960 PCI Express Root Port(0x2A01)"},
{0x8086, 0x2A02, 0xFFFF, 0xFFFF, "Mobile GM965/GL960 Integrated Graphics Controller (primary)(0x2A02)"},
{0x8086, 0x2A02, 0x1028, 0x01F3, "Inspiron 1420(0x1028-0x01F3)"},
{0x8086, 0x2A02, 0x1028, 0x01F9, "Latitude D630(0x1028-0x01F9)"},
{0x8086, 0x2A02, 0x1028, 0x022F, "Inspiron 1525(0x1028-0x022F)"},
{0x8086, 0x2A02, 0x103C, 0x30C0, "Compaq 6710b(0x103C-0x30C0)"},
{0x8086, 0x2A02, 0x103C, 0x30D9, "Presario C700(0x103C-0x30D9)"},
{0x8086, 0x2A02, 0x1043, 0x14E2, "X58LE(0x1043-0x14E2)"},
{0x8086, 0x2A02, 0x104D, 0x902D, "VAIO VGN-NR120E(0x104D-0x902D)"},
{0x8086, 0x2A02, 0x17AA, 0x20B5, "GM965 [X3100] on ThinkPad T61/R61(0x17AA-0x20B5)"},
{0x8086, 0x2A02, 0x17C0, 0x4082, "GM965 on Medion WIM 2210 Notebook PC [MD96850](0x17C0-0x4082)"},
{0x8086, 0x2A02, 0xE4BF, 0xCC47, "CCG-RUMBA(0xE4BF-0xCC47)"},
{0x8086, 0x2A03, 0xFFFF, 0xFFFF, "Mobile GM965/GL960 Integrated Graphics Controller (secondary)(0x2A03)"},
{0x8086, 0x2A03, 0x1028, 0x01F3, "Inspiron 1420(0x1028-0x01F3)"},
{0x8086, 0x2A03, 0x1028, 0x022F, "Inspiron 1525(0x1028-0x022F)"},
{0x8086, 0x2A03, 0x103C, 0x30C0, "Compaq 6710b(0x103C-0x30C0)"},
{0x8086, 0x2A03, 0x103C, 0x30D9, "Presario C700(0x103C-0x30D9)"},
{0x8086, 0x2A03, 0x1043, 0x14E2, "X58LE(0x1043-0x14E2)"},
{0x8086, 0x2A03, 0x104D, 0x902D, "VAIO VGN-NR120E(0x104D-0x902D)"},
{0x8086, 0x2A03, 0x17AA, 0x20B5, "GM965 [X3100] on ThinkPad T61/R61(0x17AA-0x20B5)"},
{0x8086, 0x2A03, 0x17C0, 0x4082, "GM965 on Medion WIM 2210 Notebook PC [MD96850](0x17C0-0x4082)"},
{0x8086, 0x2A03, 0xE4BF, 0xCC47, "CCG-RUMBA(0xE4BF-0xCC47)"},
{0x8086, 0x2A04, 0xFFFF, 0xFFFF, "Mobile PM965/GM965 MEI Controller(0x2A04)"},
{0x8086, 0x2A04, 0x103C, 0x30C1, "Compaq 6910p(0x103C-0x30C1)"},
{0x8086, 0x2A05, 0xFFFF, 0xFFFF, "Mobile PM965/GM965 MEI Controller(0x2A05)"},
{0x8086, 0x2A06, 0xFFFF, 0xFFFF, "Mobile PM965/GM965 PT IDER Controller(0x2A06)"},
{0x8086, 0x2A06, 0x103C, 0x30C1, "Compaq 6910p(0x103C-0x30C1)"},
{0x8086, 0x2A07, 0xFFFF, 0xFFFF, "Mobile PM965/GM965 KT Controller(0x2A07)"},
{0x8086, 0x2A07, 0x103C, 0x30C1, "Compaq 6910p(0x103C-0x30C1)"},
{0x8086, 0x2A10, 0xFFFF, 0xFFFF, "Mobile GME965/GLE960 Memory Controller Hub(0x2A10)"},
{0x8086, 0x2A10, 0xE4BF, 0xCC47, "CCG-RUMBA(0xE4BF-0xCC47)"},
{0x8086, 0x2A11, 0xFFFF, 0xFFFF, "Mobile GME965/GLE960 PCI Express Root Port(0x2A11)"},
{0x8086, 0x2A12, 0xFFFF, 0xFFFF, "Mobile GME965/GLE960 Integrated Graphics Controller(0x2A12)"},
{0x8086, 0x2A12, 0xE4BF, 0xCC47, "CCG-RUMBA(0xE4BF-0xCC47)"},
{0x8086, 0x2A13, 0xFFFF, 0xFFFF, "Mobile GME965/GLE960 Integrated Graphics Controller(0x2A13)"},
{0x8086, 0x2A13, 0xE4BF, 0xCC47, "CCG-RUMBA(0xE4BF-0xCC47)"},
{0x8086, 0x2A14, 0xFFFF, 0xFFFF, "Mobile GME965/GLE960 MEI Controller(0x2A14)"},
{0x8086, 0x2A15, 0xFFFF, 0xFFFF, "Mobile GME965/GLE960 MEI Controller(0x2A15)"},
{0x8086, 0x2A16, 0xFFFF, 0xFFFF, "Mobile GME965/GLE960 PT IDER Controller(0x2A16)"},
{0x8086, 0x2A17, 0xFFFF, 0xFFFF, "Mobile GME965/GLE960 KT Controller(0x2A17)"},
{0x8086, 0x2A40, 0xFFFF, 0xFFFF, "Mobile 4 Series Chipset Memory Controller Hub(0x2A40)"},
{0x8086, 0x2A40, 0x17AA, 0x20E0, "ThinkPad T400(0x17AA-0x20E0)"},
{0x8086, 0x2A40, 0xE4BF, 0xCC4D, "CCM-BOOGIE(0xE4BF-0xCC4D)"},
{0x8086, 0x2A41, 0xFFFF, 0xFFFF, "Mobile 4 Series Chipset PCI Express Graphics Port(0x2A41)"},
{0x8086, 0x2A41, 0xE4BF, 0xCC4D, "CCM-BOOGIE(0xE4BF-0xCC4D)"},
{0x8086, 0x2A42, 0xFFFF, 0xFFFF, "Mobile 4 Series Chipset Integrated Graphics Controller(0x2A42)"},
{0x8086, 0x2A42, 0x1028, 0x02AA, "Dell Inspiron 1545(0x1028-0x02AA)"},
{0x8086, 0x2A42, 0x17AA, 0x2112, "ThinkPad T400(0x17AA-0x2112)"},
{0x8086, 0x2A42, 0xE4BF, 0xCC4D, "CCM-BOOGIE(0xE4BF-0xCC4D)"},
{0x8086, 0x2A43, 0xFFFF, 0xFFFF, "Mobile 4 Series Chipset Integrated Graphics Controller(0x2A43)"},
{0x8086, 0x2A43, 0x17AA, 0x2112, "ThinkPad T400(0x17AA-0x2112)"},
{0x8086, 0x2A43, 0xE4BF, 0xCC4D, "CCM-BOOGIE(0xE4BF-0xCC4D)"},
{0x8086, 0x2A44, 0xFFFF, 0xFFFF, "Mobile 4 Series Chipset MEI Controller(0x2A44)"},
{0x8086, 0x2A44, 0x17AA, 0x20E6, "ThinkPad T400(0x17AA-0x20E6)"},
{0x8086, 0x2A45, 0xFFFF, 0xFFFF, "Mobile 4 Series Chipset MEI Controller(0x2A45)"},
{0x8086, 0x2A46, 0xFFFF, 0xFFFF, "Mobile 4 Series Chipset PT IDER Controller(0x2A46)"},
{0x8086, 0x2A47, 0xFFFF, 0xFFFF, "Mobile 4 Series Chipset AMT SOL Redirection(0x2A47)"},
{0x8086, 0x2A50, 0xFFFF, 0xFFFF, "Cantiga MEI Controller(0x2A50)"},
{0x8086, 0x2A51, 0xFFFF, 0xFFFF, "Cantiga MEI Controller(0x2A51)"},
{0x8086, 0x2A52, 0xFFFF, 0xFFFF, "Cantiga PT IDER Controller(0x2A52)"},
{0x8086, 0x2A53, 0xFFFF, 0xFFFF, "Cantiga AMT SOL Redirection(0x2A53)"},
{0x8086, 0x2B00, 0xFFFF, 0xFFFF, "Xeon Processor E7 Product Family System Configuration Controller 1(0x2B00)"},
{0x8086, 0x2B02, 0xFFFF, 0xFFFF, "Xeon Processor E7 Product Family System Configuration Controller 2(0x2B02)"},
{0x8086, 0x2B04, 0xFFFF, 0xFFFF, "Xeon Processor E7 Product Family Power Controller(0x2B04)"},
{0x8086, 0x2B08, 0xFFFF, 0xFFFF, "Xeon Processor E7 Product Family Caching Agent 0(0x2B08)"},
{0x8086, 0x2B0C, 0xFFFF, 0xFFFF, "Xeon Processor E7 Product Family Caching Agent 1(0x2B0C)"},
{0x8086, 0x2B10, 0xFFFF, 0xFFFF, "Xeon Processor E7 Product Family QPI Home Agent 0(0x2B10)"},
{0x8086, 0x2B13, 0xFFFF, 0xFFFF, "Xeon Processor E7 Product Family Memory Controller 0c(0x2B13)"},
{0x8086, 0x2B14, 0xFFFF, 0xFFFF, "Xeon Processor E7 Product Family Memory Controller 0a(0x2B14)"},
{0x8086, 0x2B16, 0xFFFF, 0xFFFF, "Xeon Processor E7 Product Family Memory Controller 0b(0x2B16)"},
{0x8086, 0x2B18, 0xFFFF, 0xFFFF, "Xeon Processor E7 Product Family QPI Home Agent 1(0x2B18)"},
{0x8086, 0x2B1B, 0xFFFF, 0xFFFF, "Xeon Processor E7 Product Family Memory Controller 1c(0x2B1B)"},
{0x8086, 0x2B1C, 0xFFFF, 0xFFFF, "Xeon Processor E7 Product Family Memory Controller 1a(0x2B1C)"},
{0x8086, 0x2B1E, 0xFFFF, 0xFFFF, "Xeon Processor E7 Product Family Memory Controller 1b(0x2B1E)"},
{0x8086, 0x2B20, 0xFFFF, 0xFFFF, "Xeon Processor E7 Product Family Last Level Cache Coherence Engine 0(0x2B20)"},
{0x8086, 0x2B22, 0xFFFF, 0xFFFF, "Xeon Processor E7 Product Family System Configuration Controller 3(0x2B22)"},
{0x8086, 0x2B24, 0xFFFF, 0xFFFF, "Xeon Processor E7 Product Family Last Level Cache Coherence Engine 1(0x2B24)"},
{0x8086, 0x2B28, 0xFFFF, 0xFFFF, "Xeon Processor E7 Product Family Last Level Cache Coherence Engine 2(0x2B28)"},
{0x8086, 0x2B2A, 0xFFFF, 0xFFFF, "Xeon Processor E7 Product Family System Configuration Controller 4(0x2B2A)"},
{0x8086, 0x2B2C, 0xFFFF, 0xFFFF, "Xeon Processor E7 Product Family Last Level Cache Coherence Engine 3(0x2B2C)"},
{0x8086, 0x2B30, 0xFFFF, 0xFFFF, "Xeon Processor E7 Product Family Last Level Cache Coherence Engine 4(0x2B30)"},
{0x8086, 0x2B34, 0xFFFF, 0xFFFF, "Xeon Processor E7 Product Family Last Level Cache Coherence Engine 5(0x2B34)"},
{0x8086, 0x2B38, 0xFFFF, 0xFFFF, "Xeon Processor E7 Product Family Last Level Cache Coherence Engine 6(0x2B38)"},
{0x8086, 0x2B3C, 0xFFFF, 0xFFFF, "Xeon Processor E7 Product Family Last Level Cache Coherence Engine 7(0x2B3C)"},
{0x8086, 0x2B40, 0xFFFF, 0xFFFF, "Xeon Processor E7 Product Family QPI Router Port 0-1(0x2B40)"},
{0x8086, 0x2B42, 0xFFFF, 0xFFFF, "Xeon Processor E7 Product Family QPI Router Port 2-3(0x2B42)"},
{0x8086, 0x2B44, 0xFFFF, 0xFFFF, "Xeon Processor E7 Product Family QPI Router Port 4-5(0x2B44)"},
{0x8086, 0x2B46, 0xFFFF, 0xFFFF, "Xeon Processor E7 Product Family QPI Router Port 6-7(0x2B46)"},
{0x8086, 0x2B48, 0xFFFF, 0xFFFF, "Xeon Processor E7 Product Family Test and Debug 0(0x2B48)"},
{0x8086, 0x2B4C, 0xFFFF, 0xFFFF, "Xeon Processor E7 Product Family Test and Debug 1(0x2B4C)"},
{0x8086, 0x2B50, 0xFFFF, 0xFFFF, "Xeon Processor E7 Product Family QPI Physical Port 0: REUT control/status(0x2B50)"},
{0x8086, 0x2B52, 0xFFFF, 0xFFFF, "Xeon Processor E7 Product Family QPI Physical Port 0: Misc. control/status(0x2B52)"},
{0x8086, 0x2B54, 0xFFFF, 0xFFFF, "Xeon Processor E7 Product Family QPI Physical Port 1: REUT control/status(0x2B54)"},
{0x8086, 0x2B56, 0xFFFF, 0xFFFF, "Xeon Processor E7 Product Family QPI Physical Port 1: Misc. control/status(0x2B56)"},
{0x8086, 0x2B58, 0xFFFF, 0xFFFF, "Xeon Processor E7 Product Family QPI Physical Port 2: REUT control/status(0x2B58)"},
{0x8086, 0x2B5A, 0xFFFF, 0xFFFF, "Xeon Processor E7 Product Family QPI Physical Port 2: Misc. control/status(0x2B5A)"},
{0x8086, 0x2B5C, 0xFFFF, 0xFFFF, "Xeon Processor E7 Product Family QPI Physical Port 3: REUT control/status(0x2B5C)"},
{0x8086, 0x2B5E, 0xFFFF, 0xFFFF, "Xeon Processor E7 Product Family QPI Physical Port 3: Misc. control/status(0x2B5E)"},
{0x8086, 0x2B60, 0xFFFF, 0xFFFF, "Xeon Processor E7 Product Family SMI Physical Port 0: REUT control/status(0x2B60)"},
{0x8086, 0x2B62, 0xFFFF, 0xFFFF, "Xeon Processor E7 Product Family SMI Physical Port 0: Misc control/status(0x2B62)"},
{0x8086, 0x2B64, 0xFFFF, 0xFFFF, "Xeon Processor E7 Product Family SMI Physical Port 1: REUT control/status(0x2B64)"},
{0x8086, 0x2B66, 0xFFFF, 0xFFFF, "Xeon Processor E7 Product Family SMI Physical Port 1: Misc control/status(0x2B66)"},
{0x8086, 0x2B68, 0xFFFF, 0xFFFF, "Xeon Processor E7 Product Family Last Level Cache Coherence Engine 8(0x2B68)"},
{0x8086, 0x2B6C, 0xFFFF, 0xFFFF, "Xeon Processor E7 Product Family Last Level Cache Coherence Engine 9(0x2B6C)"},
{0x8086, 0x2B80, 0xFFFF, 0xFFFF, "Atom CE2700 Series [Puma 7](0x2B80)"},
{0x8086, 0x2B98, 0xFFFF, 0xFFFF, "Puma 7 Trusted Execution Engine(0x2B98)"},
{0x8086, 0x2BB5, 0xFFFF, 0xFFFF, "Puma 7 xHCI Controller(0x2BB5)"},
{0x8086, 0x2BB7, 0xFFFF, 0xFFFF, "Puma 7 USB Device Controller (OTG)(0x2BB7)"},
{0x8086, 0x2BDC, 0xFFFF, 0xFFFF, "Puma 7 Thermal(0x2BDC)"},
{0x8086, 0x2BE2, 0xFFFF, 0xFFFF, "Puma 7 Security Processor(0x2BE2)"},
{0x8086, 0x2C01, 0xFFFF, 0xFFFF, "Xeon 5500/Core i7 QuickPath Architecture System Address Decoder(0x2C01)"},
{0x8086, 0x2C10, 0xFFFF, 0xFFFF, "Xeon 5500/Core i7 QPI Link 0(0x2C10)"},
{0x8086, 0x2C11, 0xFFFF, 0xFFFF, "Xeon 5500/Core i7 QPI Physical 0(0x2C11)"},
{0x8086, 0x2C14, 0xFFFF, 0xFFFF, "Xeon 5500/Core i7 QPI Link 1(0x2C14)"},
{0x8086, 0x2C15, 0xFFFF, 0xFFFF, "Xeon 5500/Core i7 QPI Physical 1(0x2C15)"},
{0x8086, 0x2C18, 0xFFFF, 0xFFFF, "Xeon 5500/Core i7 Integrated Memory Controller(0x2C18)"},
{0x8086, 0x2C19, 0xFFFF, 0xFFFF, "Xeon 5500/Core i7 Integrated Memory Controller Target Address Decoder(0x2C19)"},
{0x8086, 0x2C1A, 0xFFFF, 0xFFFF, "Xeon 5500/Core i7 Integrated Memory Controller RAS Registers(0x2C1A)"},
{0x8086, 0x2C1C, 0xFFFF, 0xFFFF, "Xeon 5500/Core i7 Integrated Memory Controller Test Registers(0x2C1C)"},
{0x8086, 0x2C20, 0xFFFF, 0xFFFF, "Xeon 5500/Core i7 Integrated Memory Controller Channel 0 Control Registers(0x2C20)"},
{0x8086, 0x2C21, 0xFFFF, 0xFFFF, "Xeon 5500/Core i7 Integrated Memory Controller Channel 0 Address Registers(0x2C21)"},
{0x8086, 0x2C22, 0xFFFF, 0xFFFF, "Xeon 5500/Core i7 Integrated Memory Controller Channel 0 Rank Registers(0x2C22)"},
{0x8086, 0x2C23, 0xFFFF, 0xFFFF, "Xeon 5500/Core i7 Integrated Memory Controller Channel 0 Thermal Control Registers(0x2C23)"},
{0x8086, 0x2C28, 0xFFFF, 0xFFFF, "Xeon 5500/Core i7 Integrated Memory Controller Channel 1 Control Registers(0x2C28)"},
{0x8086, 0x2C29, 0xFFFF, 0xFFFF, "Xeon 5500/Core i7 Integrated Memory Controller Channel 1 Address Registers(0x2C29)"},
{0x8086, 0x2C2A, 0xFFFF, 0xFFFF, "Xeon 5500/Core i7 Integrated Memory Controller Channel 1 Rank Registers(0x2C2A)"},
{0x8086, 0x2C2B, 0xFFFF, 0xFFFF, "Xeon 5500/Core i7 Integrated Memory Controller Channel 1 Thermal Control Registers(0x2C2B)"},
{0x8086, 0x2C30, 0xFFFF, 0xFFFF, "Xeon 5500/Core i7 Integrated Memory Controller Channel 2 Control Registers(0x2C30)"},
{0x8086, 0x2C31, 0xFFFF, 0xFFFF, "Xeon 5500/Core i7 Integrated Memory Controller Channel 2 Address Registers(0x2C31)"},
{0x8086, 0x2C32, 0xFFFF, 0xFFFF, "Xeon 5500/Core i7 Integrated Memory Controller Channel 2 Rank Registers(0x2C32)"},
{0x8086, 0x2C33, 0xFFFF, 0xFFFF, "Xeon 5500/Core i7 Integrated Memory Controller Channel 2 Thermal Control Registers(0x2C33)"},
{0x8086, 0x2C40, 0xFFFF, 0xFFFF, "Xeon 5500/Core i7 QuickPath Architecture Generic Non-Core Registers(0x2C40)"},
{0x8086, 0x2C41, 0xFFFF, 0xFFFF, "Xeon 5500/Core i7 QuickPath Architecture Generic Non-Core Registers(0x2C41)"},
{0x8086, 0x2C50, 0xFFFF, 0xFFFF, "Core Processor QuickPath Architecture Generic Non-Core Registers(0x2C50)"},
{0x8086, 0x2C51, 0xFFFF, 0xFFFF, "Core Processor QuickPath Architecture Generic Non-Core Registers(0x2C51)"},
{0x8086, 0x2C52, 0xFFFF, 0xFFFF, "Core Processor QuickPath Architecture Generic Non-Core Registers(0x2C52)"},
{0x8086, 0x2C53, 0xFFFF, 0xFFFF, "Core Processor QuickPath Architecture Generic Non-Core Registers(0x2C53)"},
{0x8086, 0x2C54, 0xFFFF, 0xFFFF, "Core Processor QuickPath Architecture Generic Non-Core Registers(0x2C54)"},
{0x8086, 0x2C55, 0xFFFF, 0xFFFF, "Core Processor QuickPath Architecture Generic Non-Core Registers(0x2C55)"},
{0x8086, 0x2C56, 0xFFFF, 0xFFFF, "Core Processor QuickPath Architecture Generic Non-Core Registers(0x2C56)"},
{0x8086, 0x2C57, 0xFFFF, 0xFFFF, "Core Processor QuickPath Architecture Generic Non-Core Registers(0x2C57)"},
{0x8086, 0x2C58, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 QPI Generic Non-core Registers(0x2C58)"},
{0x8086, 0x2C59, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 QPI Generic Non-core Registers(0x2C59)"},
{0x8086, 0x2C5A, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 QPI Generic Non-core Registers(0x2C5A)"},
{0x8086, 0x2C5B, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 QPI Generic Non-core Registers(0x2C5B)"},
{0x8086, 0x2C5C, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 QPI Generic Non-core Registers(0x2C5C)"},
{0x8086, 0x2C5D, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 QPI Generic Non-core Registers(0x2C5D)"},
{0x8086, 0x2C5E, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 QPI Generic Non-core Registers(0x2C5E)"},
{0x8086, 0x2C5F, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 QPI Generic Non-core Registers(0x2C5F)"},
{0x8086, 0x2C61, 0xFFFF, 0xFFFF, "Core Processor QuickPath Architecture Generic Non-core Registers(0x2C61)"},
{0x8086, 0x2C62, 0xFFFF, 0xFFFF, "Core Processor QuickPath Architecture Generic Non-core Registers(0x2C62)"},
{0x8086, 0x2C70, 0xFFFF, 0xFFFF, "Xeon 5600 Series QuickPath Architecture Generic Non-core Registers(0x2C70)"},
{0x8086, 0x2C81, 0xFFFF, 0xFFFF, "Core Processor QuickPath Architecture System Address Decoder(0x2C81)"},
{0x8086, 0x2C90, 0xFFFF, 0xFFFF, "Core Processor QPI Link 0(0x2C90)"},
{0x8086, 0x2C91, 0xFFFF, 0xFFFF, "Core Processor QPI Physical 0(0x2C91)"},
{0x8086, 0x2C98, 0xFFFF, 0xFFFF, "Core Processor Integrated Memory Controller(0x2C98)"},
{0x8086, 0x2C99, 0xFFFF, 0xFFFF, "Core Processor Integrated Memory Controller Target Address Decoder(0x2C99)"},
{0x8086, 0x2C9A, 0xFFFF, 0xFFFF, "Core Processor Integrated Memory Controller Test Registers(0x2C9A)"},
{0x8086, 0x2C9C, 0xFFFF, 0xFFFF, "Core Processor Integrated Memory Controller Test Registers(0x2C9C)"},
{0x8086, 0x2CA0, 0xFFFF, 0xFFFF, "Core Processor Integrated Memory Controller Channel 0 Control Registers(0x2CA0)"},
{0x8086, 0x2CA1, 0xFFFF, 0xFFFF, "Core Processor Integrated Memory Controller Channel 0 Address Registers(0x2CA1)"},
{0x8086, 0x2CA2, 0xFFFF, 0xFFFF, "Core Processor Integrated Memory Controller Channel 0 Rank Registers(0x2CA2)"},
{0x8086, 0x2CA3, 0xFFFF, 0xFFFF, "Core Processor Integrated Memory Controller Channel 0 Thermal Control Registers(0x2CA3)"},
{0x8086, 0x2CA8, 0xFFFF, 0xFFFF, "Core Processor Integrated Memory Controller Channel 1 Control Registers(0x2CA8)"},
{0x8086, 0x2CA9, 0xFFFF, 0xFFFF, "Core Processor Integrated Memory Controller Channel 1 Address Registers(0x2CA9)"},
{0x8086, 0x2CAA, 0xFFFF, 0xFFFF, "Core Processor Integrated Memory Controller Channel 1 Rank Registers(0x2CAA)"},
{0x8086, 0x2CAB, 0xFFFF, 0xFFFF, "Core Processor Integrated Memory Controller Channel 1 Thermal Control Registers(0x2CAB)"},
{0x8086, 0x2CC1, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 QPI System Address Decoder(0x2CC1)"},
{0x8086, 0x2CD0, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 QPI Link 0(0x2CD0)"},
{0x8086, 0x2CD1, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 QPI Physical 0(0x2CD1)"},
{0x8086, 0x2CD4, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 QPI Link 1(0x2CD4)"},
{0x8086, 0x2CD5, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 QPI Physical 1(0x2CD5)"},
{0x8086, 0x2CD8, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 Integrated Memory Controller Registers(0x2CD8)"},
{0x8086, 0x2CD9, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 Integrated Memory Controller Target Address Decoder(0x2CD9)"},
{0x8086, 0x2CDA, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 Integrated Memory Controller RAS Registers(0x2CDA)"},
{0x8086, 0x2CDC, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 Integrated Memory Controller Test Registers(0x2CDC)"},
{0x8086, 0x2CE0, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 Integrated Memory Controller Channel 0 Control(0x2CE0)"},
{0x8086, 0x2CE1, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 Integrated Memory Controller Channel 0 Address(0x2CE1)"},
{0x8086, 0x2CE2, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 Integrated Memory Controller Channel 0 Rank(0x2CE2)"},
{0x8086, 0x2CE3, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 Integrated Memory Controller Channel 0 Thermal Control(0x2CE3)"},
{0x8086, 0x2CE8, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 Integrated Memory Controller Channel 1 Control(0x2CE8)"},
{0x8086, 0x2CE9, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 Integrated Memory Controller Channel 1 Address(0x2CE9)"},
{0x8086, 0x2CEA, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 Integrated Memory Controller Channel 1 Rank(0x2CEA)"},
{0x8086, 0x2CEB, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 Integrated Memory Controller Channel 1 Thermal Control(0x2CEB)"},
{0x8086, 0x2CF0, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 Integrated Memory Controller Channel 2 Control(0x2CF0)"},
{0x8086, 0x2CF1, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 Integrated Memory Controller Channel 2 Address(0x2CF1)"},
{0x8086, 0x2CF2, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 Integrated Memory Controller Channel 2 Rank(0x2CF2)"},
{0x8086, 0x2CF3, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 Integrated Memory Controller Channel 2 Thermal Control(0x2CF3)"},
{0x8086, 0x2D01, 0xFFFF, 0xFFFF, "Core Processor QuickPath Architecture System Address Decoder(0x2D01)"},
{0x8086, 0x2D10, 0xFFFF, 0xFFFF, "Core Processor QPI Link 0(0x2D10)"},
{0x8086, 0x2D11, 0xFFFF, 0xFFFF, "1st Generation Core i3/5/7 Processor QPI Physical 0(0x2D11)"},
{0x8086, 0x2D12, 0xFFFF, 0xFFFF, "1st Generation Core i3/5/7 Processor Reserved(0x2D12)"},
{0x8086, 0x2D13, 0xFFFF, 0xFFFF, "1st Generation Core i3/5/7 Processor Reserved(0x2D13)"},
{0x8086, 0x2D81, 0xFFFF, 0xFFFF, "Xeon 5600 Series QuickPath Architecture System Address Decoder(0x2D81)"},
{0x8086, 0x2D90, 0xFFFF, 0xFFFF, "Xeon 5600 Series QPI Link 0(0x2D90)"},
{0x8086, 0x2D91, 0xFFFF, 0xFFFF, "Xeon 5600 Series QPI Physical 0(0x2D91)"},
{0x8086, 0x2D92, 0xFFFF, 0xFFFF, "Xeon 5600 Series Mirror Port Link 0(0x2D92)"},
{0x8086, 0x2D93, 0xFFFF, 0xFFFF, "Xeon 5600 Series Mirror Port Link 1(0x2D93)"},
{0x8086, 0x2D94, 0xFFFF, 0xFFFF, "Xeon 5600 Series QPI Link 1(0x2D94)"},
{0x8086, 0x2D95, 0xFFFF, 0xFFFF, "Xeon 5600 Series QPI Physical 1(0x2D95)"},
{0x8086, 0x2D98, 0xFFFF, 0xFFFF, "Xeon 5600 Series Integrated Memory Controller Registers(0x2D98)"},
{0x8086, 0x2D99, 0xFFFF, 0xFFFF, "Xeon 5600 Series Integrated Memory Controller Target Address Decoder(0x2D99)"},
{0x8086, 0x2D9A, 0xFFFF, 0xFFFF, "Xeon 5600 Series Integrated Memory Controller RAS Registers(0x2D9A)"},
{0x8086, 0x2D9C, 0xFFFF, 0xFFFF, "Xeon 5600 Series Integrated Memory Controller Test Registers(0x2D9C)"},
{0x8086, 0x2DA0, 0xFFFF, 0xFFFF, "Xeon 5600 Series Integrated Memory Controller Channel 0 Control(0x2DA0)"},
{0x8086, 0x2DA1, 0xFFFF, 0xFFFF, "Xeon 5600 Series Integrated Memory Controller Channel 0 Address(0x2DA1)"},
{0x8086, 0x2DA2, 0xFFFF, 0xFFFF, "Xeon 5600 Series Integrated Memory Controller Channel 0 Rank(0x2DA2)"},
{0x8086, 0x2DA3, 0xFFFF, 0xFFFF, "Xeon 5600 Series Integrated Memory Controller Channel 0 Thermal Control(0x2DA3)"},
{0x8086, 0x2DA8, 0xFFFF, 0xFFFF, "Xeon 5600 Series Integrated Memory Controller Channel 1 Control(0x2DA8)"},
{0x8086, 0x2DA9, 0xFFFF, 0xFFFF, "Xeon 5600 Series Integrated Memory Controller Channel 1 Address(0x2DA9)"},
{0x8086, 0x2DAA, 0xFFFF, 0xFFFF, "Xeon 5600 Series Integrated Memory Controller Channel 1 Rank(0x2DAA)"},
{0x8086, 0x2DAB, 0xFFFF, 0xFFFF, "Xeon 5600 Series Integrated Memory Controller Channel 1 Thermal Control(0x2DAB)"},
{0x8086, 0x2DB0, 0xFFFF, 0xFFFF, "Xeon 5600 Series Integrated Memory Controller Channel 2 Control(0x2DB0)"},
{0x8086, 0x2DB1, 0xFFFF, 0xFFFF, "Xeon 5600 Series Integrated Memory Controller Channel 2 Address(0x2DB1)"},
{0x8086, 0x2DB2, 0xFFFF, 0xFFFF, "Xeon 5600 Series Integrated Memory Controller Channel 2 Rank(0x2DB2)"},
{0x8086, 0x2DB3, 0xFFFF, 0xFFFF, "Xeon 5600 Series Integrated Memory Controller Channel 2 Thermal Control(0x2DB3)"},
{0x8086, 0x2E00, 0xFFFF, 0xFFFF, "4 Series Chipset DRAM Controller(0x2E00)"},
{0x8086, 0x2E01, 0xFFFF, 0xFFFF, "4 Series Chipset PCI Express Root Port(0x2E01)"},
{0x8086, 0x2E02, 0xFFFF, 0xFFFF, "4 Series Chipset Integrated Graphics Controller(0x2E02)"},
{0x8086, 0x2E03, 0xFFFF, 0xFFFF, "4 Series Chipset Integrated Graphics Controller(0x2E03)"},
{0x8086, 0x2E04, 0xFFFF, 0xFFFF, "4 Series Chipset HECI Controller(0x2E04)"},
{0x8086, 0x2E05, 0xFFFF, 0xFFFF, "4 Series Chipset HECI Controller(0x2E05)"},
{0x8086, 0x2E06, 0xFFFF, 0xFFFF, "4 Series Chipset PT IDER Controller(0x2E06)"},
{0x8086, 0x2E07, 0xFFFF, 0xFFFF, "4 Series Chipset Serial KT Controller(0x2E07)"},
{0x8086, 0x2E10, 0xFFFF, 0xFFFF, "4 Series Chipset DRAM Controller(0x2E10)"},
{0x8086, 0x2E11, 0xFFFF, 0xFFFF, "4 Series Chipset PCI Express Root Port(0x2E11)"},
{0x8086, 0x2E12, 0xFFFF, 0xFFFF, "4 Series Chipset Integrated Graphics Controller(0x2E12)"},
{0x8086, 0x2E12, 0x17AA, 0x3048, "ThinkCentre M6258(0x17AA-0x3048)"},
{0x8086, 0x2E13, 0xFFFF, 0xFFFF, "4 Series Chipset Integrated Graphics Controller(0x2E13)"},
{0x8086, 0x2E14, 0xFFFF, 0xFFFF, "4 Series Chipset HECI Controller(0x2E14)"},
{0x8086, 0x2E15, 0xFFFF, 0xFFFF, "4 Series Chipset HECI Controller(0x2E15)"},
{0x8086, 0x2E16, 0xFFFF, 0xFFFF, "4 Series Chipset PT IDER Controller(0x2E16)"},
{0x8086, 0x2E17, 0xFFFF, 0xFFFF, "4 Series Chipset Serial KT Controller(0x2E17)"},
{0x8086, 0x2E20, 0xFFFF, 0xFFFF, "4 Series Chipset DRAM Controller(0x2E20)"},
{0x8086, 0x2E20, 0x1028, 0x0283, "Vostro 220(0x1028-0x0283)"},
{0x8086, 0x2E20, 0x1043, 0x82D3, "P5Q Deluxe Motherboard(0x1043-0x82D3)"},
{0x8086, 0x2E20, 0x1458, 0x5000, "GA-EP45-DS5/GA-EG45M-DS2H Motherboard(0x1458-0x5000)"},
{0x8086, 0x2E21, 0xFFFF, 0xFFFF, "4 Series Chipset PCI Express Root Port(0x2E21)"},
{0x8086, 0x2E21, 0x1043, 0x82D3, "P5Q Deluxe Motherboard(0x1043-0x82D3)"},
{0x8086, 0x2E21, 0x1458, 0x5000, "GA-EP45-DS5 Motherboard(0x1458-0x5000)"},
{0x8086, 0x2E22, 0xFFFF, 0xFFFF, "4 Series Chipset Integrated Graphics Controller(0x2E22)"},
{0x8086, 0x2E22, 0x1458, 0xD000, "GA-EG45M-DS2H Mainboard(0x1458-0xD000)"},
{0x8086, 0x2E23, 0xFFFF, 0xFFFF, "4 Series Chipset Integrated Graphics Controller(0x2E23)"},
{0x8086, 0x2E23, 0x1458, 0xD000, "GA-EG45M-DS2H Mainboard(0x1458-0xD000)"},
{0x8086, 0x2E24, 0xFFFF, 0xFFFF, "4 Series Chipset HECI Controller(0x2E24)"},
{0x8086, 0x2E25, 0xFFFF, 0xFFFF, "4 Series Chipset HECI Controller(0x2E25)"},
{0x8086, 0x2E26, 0xFFFF, 0xFFFF, "4 Series Chipset PT IDER Controller(0x2E26)"},
{0x8086, 0x2E27, 0xFFFF, 0xFFFF, "4 Series Chipset Serial KT Controller(0x2E27)"},
{0x8086, 0x2E29, 0xFFFF, 0xFFFF, "4 Series Chipset PCI Express Root Port(0x2E29)"},
{0x8086, 0x2E30, 0xFFFF, 0xFFFF, "4 Series Chipset DRAM Controller(0x2E30)"},
{0x8086, 0x2E30, 0x103C, 0x2A8C, "Compaq 500B Microtower(0x103C-0x2A8C)"},
{0x8086, 0x2E31, 0xFFFF, 0xFFFF, "4 Series Chipset PCI Express Root Port(0x2E31)"},
{0x8086, 0x2E32, 0xFFFF, 0xFFFF, "4 Series Chipset Integrated Graphics Controller(0x2E32)"},
{0x8086, 0x2E32, 0x103C, 0x2A8C, "Compaq 500B Microtower(0x103C-0x2A8C)"},
{0x8086, 0x2E33, 0xFFFF, 0xFFFF, "4 Series Chipset Integrated Graphics Controller(0x2E33)"},
{0x8086, 0x2E34, 0xFFFF, 0xFFFF, "4 Series Chipset HECI Controller(0x2E34)"},
{0x8086, 0x2E35, 0xFFFF, 0xFFFF, "4 Series Chipset HECI Controller(0x2E35)"},
{0x8086, 0x2E36, 0xFFFF, 0xFFFF, "4 Series Chipset PT IDER Controller(0x2E36)"},
{0x8086, 0x2E37, 0xFFFF, 0xFFFF, "4 Series Chipset Serial KT Controller(0x2E37)"},
{0x8086, 0x2E40, 0xFFFF, 0xFFFF, "4 Series Chipset DRAM Controller(0x2E40)"},
{0x8086, 0x2E41, 0xFFFF, 0xFFFF, "4 Series Chipset PCI Express Root Port(0x2E41)"},
{0x8086, 0x2E42, 0xFFFF, 0xFFFF, "4 Series Chipset Integrated Graphics Controller(0x2E42)"},
{0x8086, 0x2E43, 0xFFFF, 0xFFFF, "4 Series Chipset Integrated Graphics Controller(0x2E43)"},
{0x8086, 0x2E44, 0xFFFF, 0xFFFF, "4 Series Chipset HECI Controller(0x2E44)"},
{0x8086, 0x2E45, 0xFFFF, 0xFFFF, "4 Series Chipset HECI Controller(0x2E45)"},
{0x8086, 0x2E46, 0xFFFF, 0xFFFF, "4 Series Chipset PT IDER Controller(0x2E46)"},
{0x8086, 0x2E47, 0xFFFF, 0xFFFF, "4 Series Chipset Serial KT Controller(0x2E47)"},
{0x8086, 0x2E50, 0xFFFF, 0xFFFF, "CE Media Processor CE3100(0x2E50)"},
{0x8086, 0x2E52, 0xFFFF, 0xFFFF, "CE Media Processor Clock and Reset Controller(0x2E52)"},
{0x8086, 0x2E58, 0xFFFF, 0xFFFF, "CE Media Processor Interrupt Controller(0x2E58)"},
{0x8086, 0x2E5A, 0xFFFF, 0xFFFF, "CE Media Processor CE3100 A/V Bridge(0x2E5A)"},
{0x8086, 0x2E5B, 0xFFFF, 0xFFFF, "Graphics Media Accelerator 500 Graphics(0x2E5B)"},
{0x8086, 0x2E5C, 0xFFFF, 0xFFFF, "CE Media Processor Video Decoder(0x2E5C)"},
{0x8086, 0x2E5D, 0xFFFF, 0xFFFF, "CE Media Processor Transport Stream Interface(0x2E5D)"},
{0x8086, 0x2E5E, 0xFFFF, 0xFFFF, "CE Media Processor Transport Stream Processor 0(0x2E5E)"},
{0x8086, 0x2E5F, 0xFFFF, 0xFFFF, "CE Media Processor Audio DSP(0x2E5F)"},
{0x8086, 0x2E60, 0xFFFF, 0xFFFF, "CE Media Processor Audio Interfaces(0x2E60)"},
{0x8086, 0x2E61, 0xFFFF, 0xFFFF, "CE Media Processor Video Display Controller(0x2E61)"},
{0x8086, 0x2E62, 0xFFFF, 0xFFFF, "CE Media Processor Video Processing Unit(0x2E62)"},
{0x8086, 0x2E63, 0xFFFF, 0xFFFF, "CE Media Processor HDMI Tx Interface(0x2E63)"},
{0x8086, 0x2E64, 0xFFFF, 0xFFFF, "Atom CE2600/3100/4100/4200/5300 Security Processor(0x2E64)"},
{0x8086, 0x2E65, 0xFFFF, 0xFFFF, "CE Media Processor Expansion Bus Interface(0x2E65)"},
{0x8086, 0x2E66, 0xFFFF, 0xFFFF, "CE Media Processor UART(0x2E66)"},
{0x8086, 0x2E67, 0xFFFF, 0xFFFF, "CE Media Processor General Purpose I/Os(0x2E67)"},
{0x8086, 0x2E68, 0xFFFF, 0xFFFF, "CE Media Processor I2C Interface(0x2E68)"},
{0x8086, 0x2E69, 0xFFFF, 0xFFFF, "CE Media Processor Smart Card Interface(0x2E69)"},
{0x8086, 0x2E6A, 0xFFFF, 0xFFFF, "CE Media Processor SPI Master Interface(0x2E6A)"},
{0x8086, 0x2E6E, 0xFFFF, 0xFFFF, "CE Media Processor Gigabit Ethernet Controller(0x2E6E)"},
{0x8086, 0x2E6F, 0xFFFF, 0xFFFF, "CE Media Processor Media Timing Unit(0x2E6F)"},
{0x8086, 0x2E70, 0xFFFF, 0xFFFF, "CE Media Processor USB(0x2E70)"},
{0x8086, 0x2E71, 0xFFFF, 0xFFFF, "CE Media Processor SATA(0x2E71)"},
{0x8086, 0x2E73, 0xFFFF, 0xFFFF, "CE Media Processor CE3100 PCI Express(0x2E73)"},
{0x8086, 0x2E90, 0xFFFF, 0xFFFF, "4 Series Chipset DRAM Controller(0x2E90)"},
{0x8086, 0x2E91, 0xFFFF, 0xFFFF, "4 Series Chipset PCI Express Root Port(0x2E91)"},
{0x8086, 0x2E92, 0xFFFF, 0xFFFF, "4 Series Chipset Integrated Graphics Controller(0x2E92)"},
{0x8086, 0x2E93, 0xFFFF, 0xFFFF, "4 Series Chipset Integrated Graphics Controller(0x2E93)"},
{0x8086, 0x2E94, 0xFFFF, 0xFFFF, "4 Series Chipset HECI Controller(0x2E94)"},
{0x8086, 0x2E95, 0xFFFF, 0xFFFF, "4 Series Chipset HECI Controller(0x2E95)"},
{0x8086, 0x2E96, 0xFFFF, 0xFFFF, "4 Series Chipset PT IDER Controller(0x2E96)"},
{0x8086, 0x2F00, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 DMI2(0x2F00)"},
{0x8086, 0x2F01, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 PCI Express Root Port 0(0x2F01)"},
{0x8086, 0x2F02, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 PCI Express Root Port 1(0x2F02)"},
{0x8086, 0x2F03, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 PCI Express Root Port 1(0x2F03)"},
{0x8086, 0x2F04, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 PCI Express Root Port 2(0x2F04)"},
{0x8086, 0x2F05, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 PCI Express Root Port 2(0x2F05)"},
{0x8086, 0x2F06, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 PCI Express Root Port 2(0x2F06)"},
{0x8086, 0x2F07, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 PCI Express Root Port 2(0x2F07)"},
{0x8086, 0x2F08, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 PCI Express Root Port 3(0x2F08)"},
{0x8086, 0x2F09, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 PCI Express Root Port 3(0x2F09)"},
{0x8086, 0x2F0A, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 PCI Express Root Port 3(0x2F0A)"},
{0x8086, 0x2F0B, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 PCI Express Root Port 3(0x2F0B)"},
{0x8086, 0x2F0D, 0xFFFF, 0xFFFF, "Haswell Xeon Non-Transparent Bridge (Back-to-back)(0x2F0D)"},
{0x8086, 0x2F0E, 0xFFFF, 0xFFFF, "Haswell Xeon Non-Transparent Bridge (Primary Side)(0x2F0E)"},
{0x8086, 0x2F0F, 0xFFFF, 0xFFFF, "Haswell Xeon Non-Transparent Bridge (Secondary Side)(0x2F0F)"},
{0x8086, 0x2F10, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 IIO Debug(0x2F10)"},
{0x8086, 0x2F11, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 IIO Debug(0x2F11)"},
{0x8086, 0x2F12, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 IIO Debug(0x2F12)"},
{0x8086, 0x2F13, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 IIO Debug(0x2F13)"},
{0x8086, 0x2F14, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 IIO Debug(0x2F14)"},
{0x8086, 0x2F15, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 IIO Debug(0x2F15)"},
{0x8086, 0x2F16, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 IIO Debug(0x2F16)"},
{0x8086, 0x2F17, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 IIO Debug(0x2F17)"},
{0x8086, 0x2F18, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 IIO Debug(0x2F18)"},
{0x8086, 0x2F19, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 IIO Debug(0x2F19)"},
{0x8086, 0x2F1A, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 IIO Debug(0x2F1A)"},
{0x8086, 0x2F1B, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 IIO Debug(0x2F1B)"},
{0x8086, 0x2F1C, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 IIO Debug(0x2F1C)"},
{0x8086, 0x2F1D, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 PCIe Ring Interface(0x2F1D)"},
{0x8086, 0x2F1E, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Scratchpad & Semaphore Registers(0x2F1E)"},
{0x8086, 0x2F1F, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Scratchpad & Semaphore Registers(0x2F1F)"},
{0x8086, 0x2F20, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 DMA Channel 0(0x2F20)"},
{0x8086, 0x2F21, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 DMA Channel 1(0x2F21)"},
{0x8086, 0x2F22, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 DMA Channel 2(0x2F22)"},
{0x8086, 0x2F23, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 DMA Channel 3(0x2F23)"},
{0x8086, 0x2F24, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 DMA Channel 4(0x2F24)"},
{0x8086, 0x2F25, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 DMA Channel 5(0x2F25)"},
{0x8086, 0x2F26, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 DMA Channel 6(0x2F26)"},
{0x8086, 0x2F27, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 DMA Channel 7(0x2F27)"},
{0x8086, 0x2F28, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Address Map, VTd_Misc, System Management(0x2F28)"},
{0x8086, 0x2F29, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Hot Plug(0x2F29)"},
{0x8086, 0x2F2A, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 RAS, Control Status and Global Errors(0x2F2A)"},
{0x8086, 0x2F2C, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 I/O APIC(0x2F2C)"},
{0x8086, 0x2F2E, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 RAID 5/6(0x2F2E)"},
{0x8086, 0x2F2F, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 RAID 5/6(0x2F2F)"},
{0x8086, 0x2F30, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Home Agent 0(0x2F30)"},
{0x8086, 0x2F32, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 QPI Link 0(0x2F32)"},
{0x8086, 0x2F33, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 QPI Link 1(0x2F33)"},
{0x8086, 0x2F34, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 PCIe Ring Interface(0x2F34)"},
{0x8086, 0x2F36, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 R3 QPI Link 0 & 1 Monitoring(0x2F36)"},
{0x8086, 0x2F37, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 R3 QPI Link 0 & 1 Monitoring(0x2F37)"},
{0x8086, 0x2F38, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Home Agent 1(0x2F38)"},
{0x8086, 0x2F39, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 I/O Performance Monitoring(0x2F39)"},
{0x8086, 0x2F3A, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 QPI Link 2(0x2F3A)"},
{0x8086, 0x2F3E, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 R3 QPI Link 2 Monitoring(0x2F3E)"},
{0x8086, 0x2F3F, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 R3 QPI Link 2 Monitoring(0x2F3F)"},
{0x8086, 0x2F40, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 QPI Link 2(0x2F40)"},
{0x8086, 0x2F41, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 R3 QPI Link 2 Monitoring(0x2F41)"},
{0x8086, 0x2F43, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 QPI Link 2(0x2F43)"},
{0x8086, 0x2F45, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 QPI Link 2 Debug(0x2F45)"},
{0x8086, 0x2F46, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 QPI Link 2 Debug(0x2F46)"},
{0x8086, 0x2F47, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 QPI Link 2 Debug(0x2F47)"},
{0x8086, 0x2F60, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Home Agent 1(0x2F60)"},
{0x8086, 0x2F68, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Integrated Memory Controller 1 Target Address, Thermal & RAS Registers(0x2F68)"},
{0x8086, 0x2F6A, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Integrated Memory Controller 1 Channel Target Address Decoder(0x2F6A)"},
{0x8086, 0x2F6B, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Integrated Memory Controller 1 Channel Target Address Decoder(0x2F6B)"},
{0x8086, 0x2F6C, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Integrated Memory Controller 1 Channel Target Address Decoder(0x2F6C)"},
{0x8086, 0x2F6D, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Integrated Memory Controller 1 Channel Target Address Decoder(0x2F6D)"},
{0x8086, 0x2F6E, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 DDRIO Channel 2/3 Broadcast(0x2F6E)"},
{0x8086, 0x2F6F, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 DDRIO Global Broadcast(0x2F6F)"},
{0x8086, 0x2F70, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Home Agent 0 Debug(0x2F70)"},
{0x8086, 0x2F71, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Integrated Memory Controller 0 Target Address, Thermal & RAS Registers(0x2F71)"},
{0x8086, 0x2F76, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 E3 QPI Link Debug(0x2F76)"},
{0x8086, 0x2F78, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Home Agent 1 Debug(0x2F78)"},
{0x8086, 0x2F79, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Integrated Memory Controller 1 Target Address, Thermal & RAS Registers(0x2F79)"},
{0x8086, 0x2F7D, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Scratchpad & Semaphore Registers(0x2F7D)"},
{0x8086, 0x2F7E, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 E3 QPI Link Debug(0x2F7E)"},
{0x8086, 0x2F80, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 QPI Link 0(0x2F80)"},
{0x8086, 0x2F81, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 R3 QPI Link 0 & 1 Monitoring(0x2F81)"},
{0x8086, 0x2F83, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 QPI Link 0(0x2F83)"},
{0x8086, 0x2F85, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 QPI Link 0 Debug(0x2F85)"},
{0x8086, 0x2F86, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 QPI Link 0 Debug(0x2F86)"},
{0x8086, 0x2F87, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 QPI Link 0 Debug(0x2F87)"},
{0x8086, 0x2F88, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 VCU(0x2F88)"},
{0x8086, 0x2F8A, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 VCU(0x2F8A)"},
{0x8086, 0x2F90, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 QPI Link 1(0x2F90)"},
{0x8086, 0x2F93, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 QPI Link 1(0x2F93)"},
{0x8086, 0x2F95, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 QPI Link 1 Debug(0x2F95)"},
{0x8086, 0x2F96, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 QPI Link 1 Debug(0x2F96)"},
{0x8086, 0x2F98, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Power Control Unit(0x2F98)"},
{0x8086, 0x2F99, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Power Control Unit(0x2F99)"},
{0x8086, 0x2F9A, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Power Control Unit(0x2F9A)"},
{0x8086, 0x2F9C, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Power Control Unit(0x2F9C)"},
{0x8086, 0x2FA0, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Home Agent 0(0x2FA0)"},
{0x8086, 0x2FA8, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Integrated Memory Controller 0 Target Address, Thermal & RAS Registers(0x2FA8)"},
{0x8086, 0x2FAA, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Integrated Memory Controller 0 Channel Target Address Decoder(0x2FAA)"},
{0x8086, 0x2FAB, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Integrated Memory Controller 0 Channel Target Address Decoder(0x2FAB)"},
{0x8086, 0x2FAC, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Integrated Memory Controller 0 Channel Target Address Decoder(0x2FAC)"},
{0x8086, 0x2FAD, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Integrated Memory Controller 0 Channel Target Address Decoder(0x2FAD)"},
{0x8086, 0x2FAE, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 DDRIO Channel 0/1 Broadcast(0x2FAE)"},
{0x8086, 0x2FAF, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 DDRIO Global Broadcast(0x2FAF)"},
{0x8086, 0x2FB0, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Integrated Memory Controller 0 Channel 0 Thermal Control(0x2FB0)"},
{0x8086, 0x2FB1, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Integrated Memory Controller 0 Channel 1 Thermal Control(0x2FB1)"},
{0x8086, 0x2FB2, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Integrated Memory Controller 0 Channel 0 ERROR Registers(0x2FB2)"},
{0x8086, 0x2FB3, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Integrated Memory Controller 0 Channel 1 ERROR Registers(0x2FB3)"},
{0x8086, 0x2FB4, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Integrated Memory Controller 0 Channel 2 Thermal Control(0x2FB4)"},
{0x8086, 0x2FB5, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Integrated Memory Controller 0 Channel 3 Thermal Control(0x2FB5)"},
{0x8086, 0x2FB6, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Integrated Memory Controller 0 Channel 2 ERROR Registers(0x2FB6)"},
{0x8086, 0x2FB7, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Integrated Memory Controller 0 Channel 3 ERROR Registers(0x2FB7)"},
{0x8086, 0x2FB8, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 DDRIO (VMSE) 2 & 3(0x2FB8)"},
{0x8086, 0x2FB9, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 DDRIO (VMSE) 2 & 3(0x2FB9)"},
{0x8086, 0x2FBA, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 DDRIO (VMSE) 2 & 3(0x2FBA)"},
{0x8086, 0x2FBB, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 DDRIO (VMSE) 2 & 3(0x2FBB)"},
{0x8086, 0x2FBC, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 DDRIO (VMSE) 0 & 1(0x2FBC)"},
{0x8086, 0x2FBD, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 DDRIO (VMSE) 0 & 1(0x2FBD)"},
{0x8086, 0x2FBE, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 DDRIO (VMSE) 0 & 1(0x2FBE)"},
{0x8086, 0x2FBF, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 DDRIO (VMSE) 0 & 1(0x2FBF)"},
{0x8086, 0x2FC0, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Power Control Unit(0x2FC0)"},
{0x8086, 0x2FC1, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Power Control Unit(0x2FC1)"},
{0x8086, 0x2FC2, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Power Control Unit(0x2FC2)"},
{0x8086, 0x2FC3, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Power Control Unit(0x2FC3)"},
{0x8086, 0x2FC4, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Power Control Unit(0x2FC4)"},
{0x8086, 0x2FC5, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Power Control Unit(0x2FC5)"},
{0x8086, 0x2FD0, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Integrated Memory Controller 1 Channel 0 Thermal Control(0x2FD0)"},
{0x8086, 0x2FD1, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Integrated Memory Controller 1 Channel 1 Thermal Control(0x2FD1)"},
{0x8086, 0x2FD2, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Integrated Memory Controller 1 Channel 0 ERROR Registers(0x2FD2)"},
{0x8086, 0x2FD3, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Integrated Memory Controller 1 Channel 1 ERROR Registers(0x2FD3)"},
{0x8086, 0x2FD4, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Integrated Memory Controller 1 Channel 2 Thermal Control(0x2FD4)"},
{0x8086, 0x2FD5, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Integrated Memory Controller 1 Channel 3 Thermal Control(0x2FD5)"},
{0x8086, 0x2FD6, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Integrated Memory Controller 1 Channel 2 ERROR Registers(0x2FD6)"},
{0x8086, 0x2FD7, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Integrated Memory Controller 1 Channel 3 ERROR Registers(0x2FD7)"},
{0x8086, 0x2FE0, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Unicast Registers(0x2FE0)"},
{0x8086, 0x2FE1, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Unicast Registers(0x2FE1)"},
{0x8086, 0x2FE2, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Unicast Registers(0x2FE2)"},
{0x8086, 0x2FE3, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Unicast Registers(0x2FE3)"},
{0x8086, 0x2FE4, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Unicast Registers(0x2FE4)"},
{0x8086, 0x2FE5, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Unicast Registers(0x2FE5)"},
{0x8086, 0x2FE6, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Unicast Registers(0x2FE6)"},
{0x8086, 0x2FE7, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Unicast Registers(0x2FE7)"},
{0x8086, 0x2FE8, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Unicast Registers(0x2FE8)"},
{0x8086, 0x2FE9, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Unicast Registers(0x2FE9)"},
{0x8086, 0x2FEA, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Unicast Registers(0x2FEA)"},
{0x8086, 0x2FEB, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Unicast Registers(0x2FEB)"},
{0x8086, 0x2FEC, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Unicast Registers(0x2FEC)"},
{0x8086, 0x2FED, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Unicast Registers(0x2FED)"},
{0x8086, 0x2FEE, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Unicast Registers(0x2FEE)"},
{0x8086, 0x2FEF, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Unicast Registers(0x2FEF)"},
{0x8086, 0x2FF0, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Unicast Registers(0x2FF0)"},
{0x8086, 0x2FF1, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Unicast Registers(0x2FF1)"},
{0x8086, 0x2FF2, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Unicast Registers(0x2FF2)"},
{0x8086, 0x2FF3, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Unicast Registers(0x2FF3)"},
{0x8086, 0x2FF4, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Unicast Registers(0x2FF4)"},
{0x8086, 0x2FF5, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Unicast Registers(0x2FF5)"},
{0x8086, 0x2FF6, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Unicast Registers(0x2FF6)"},
{0x8086, 0x2FF7, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Unicast Registers(0x2FF7)"},
{0x8086, 0x2FF8, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Buffered Ring Agent(0x2FF8)"},
{0x8086, 0x2FF9, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Buffered Ring Agent(0x2FF9)"},
{0x8086, 0x2FFA, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Buffered Ring Agent(0x2FFA)"},
{0x8086, 0x2FFB, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 Buffered Ring Agent(0x2FFB)"},
{0x8086, 0x2FFC, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 System Address Decoder & Broadcast Registers(0x2FFC)"},
{0x8086, 0x2FFD, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 System Address Decoder & Broadcast Registers(0x2FFD)"},
{0x8086, 0x2FFE, 0xFFFF, 0xFFFF, "Xeon E7 v3/Xeon E5 v3/Core i7 System Address Decoder & Broadcast Registers(0x2FFE)"},
{0x8086, 0x3101, 0xFFFF, 0xFFFF, "Killer E3100X 2.5 Gigabit Ethernet Controller(0x3101)"},
{0x8086, 0x3140, 0xFFFF, 0xFFFF, "Easel/Monette Hill Image Processor [Pixel Visual Core](0x3140)"},
{0x8086, 0x3165, 0xFFFF, 0xFFFF, "Wireless 3165(0x3165)"},
{0x8086, 0x3165, 0x8086, 0x4010, "Dual Band Wireless AC 3165 [Stone Peak 1x1](0x8086-0x4010)"},
{0x8086, 0x3165, 0x8086, 0x4210, "Dual Band Wireless AC 3165 [Stone Peak 1x1](0x8086-0x4210)"},
{0x8086, 0x3166, 0xFFFF, 0xFFFF, "Dual Band Wireless-AC 3165 Plus Bluetooth(0x3166)"},
{0x8086, 0x3166, 0x8086, 0x4210, "Dual Band Wireless-AC 3165(0x8086-0x4210)"},
{0x8086, 0x3184, 0xFFFF, 0xFFFF, "GeminiLake [UHD Graphics 605](0x3184)"},
{0x8086, 0x3185, 0xFFFF, 0xFFFF, "GeminiLake [UHD Graphics 600](0x3185)"},
{0x8086, 0x318C, 0xFFFF, 0xFFFF, "Celeron/Pentium Silver Processor Dynamic Platform and Thermal Framework Processor Participant(0x318C)"},
{0x8086, 0x318E, 0xFFFF, 0xFFFF, "Celeron/Pentium Silver Processor NorthPeak(0x318E)"},
{0x8086, 0x3190, 0xFFFF, 0xFFFF, "Celeron/Pentium Silver Processor Gaussian Mixture Model(0x3190)"},
{0x8086, 0x3192, 0xFFFF, 0xFFFF, "Gemini Lake P2SB(0x3192)"},
{0x8086, 0x3197, 0xFFFF, 0xFFFF, "Celeron/Pentium Silver Processor PCI-default ISA-bridge(0x3197)"},
{0x8086, 0x3198, 0xFFFF, 0xFFFF, "Celeron/Pentium Silver Processor High Definition Audio(0x3198)"},
{0x8086, 0x3198, 0x17AA, 0x380B, "V130-15IGM Laptop (Lenovo) - Type 81HL(0x17AA-0x380B)"},
{0x8086, 0x319A, 0xFFFF, 0xFFFF, "Celeron/Pentium Silver Processor Trusted Execution Engine Interface(0x319A)"},
{0x8086, 0x31A2, 0xFFFF, 0xFFFF, "Celeron/Pentium Silver Processor Integrated Sensor Solution(0x31A2)"},
{0x8086, 0x31A8, 0xFFFF, 0xFFFF, "Celeron/Pentium Silver Processor USB 3.0 xHCI Controller(0x31A8)"},
{0x8086, 0x31A8, 0x1849, 0x31A8, "Celeron/Pentium Silver Processor USB 3.0 xHCI Controller(0x1849-0x31A8)"},
{0x8086, 0x31AC, 0xFFFF, 0xFFFF, "Celeron/Pentium Silver Processor I2C 0(0x31AC)"},
{0x8086, 0x31AE, 0xFFFF, 0xFFFF, "Celeron/Pentium Silver Processor I2C 1(0x31AE)"},
{0x8086, 0x31B0, 0xFFFF, 0xFFFF, "Celeron/Pentium Silver Processor I2C 2(0x31B0)"},
{0x8086, 0x31B2, 0xFFFF, 0xFFFF, "Celeron/Pentium Silver Processor I2C 3(0x31B2)"},
{0x8086, 0x31B4, 0xFFFF, 0xFFFF, "Celeron/Pentium Silver Processor I2C 4(0x31B4)"},
{0x8086, 0x31B6, 0xFFFF, 0xFFFF, "Celeron/Pentium Silver Processor I2C 5(0x31B6)"},
{0x8086, 0x31B8, 0xFFFF, 0xFFFF, "Celeron/Pentium Silver Processor I2C 6(0x31B8)"},
{0x8086, 0x31BA, 0xFFFF, 0xFFFF, "Celeron/Pentium Silver Processor I2C 7(0x31BA)"},
{0x8086, 0x31BC, 0xFFFF, 0xFFFF, "Celeron/Pentium Silver Processor Serial IO UART Host Controller(0x31BC)"},
{0x8086, 0x31BE, 0xFFFF, 0xFFFF, "Celeron/Pentium Silver Processor Serial IO UART Host Controller(0x31BE)"},
{0x8086, 0x31C0, 0xFFFF, 0xFFFF, "Celeron/Pentium Silver Processor Serial IO UART Host Controller(0x31C0)"},
{0x8086, 0x31C2, 0xFFFF, 0xFFFF, "Celeron/Pentium Silver Processor Serial IO SPI Host Controller(0x31C2)"},
{0x8086, 0x31C4, 0xFFFF, 0xFFFF, "Celeron/Pentium Silver Processor Serial IO SPI Host Controller(0x31C4)"},
{0x8086, 0x31C6, 0xFFFF, 0xFFFF, "Celeron/Pentium Silver Processor Serial IO SPI Host Controller(0x31C6)"},
{0x8086, 0x31CC, 0xFFFF, 0xFFFF, "Celeron/Pentium Silver Processor SDA Standard Compliant SD Host Controller(0x31CC)"},
{0x8086, 0x31D4, 0xFFFF, 0xFFFF, "Celeron/Pentium Silver Processor Gaussian Mixture Model(0x31D4)"},
{0x8086, 0x31D6, 0xFFFF, 0xFFFF, "Gemini Lake PCI Express Root Port(0x31D6)"},
{0x8086, 0x31D7, 0xFFFF, 0xFFFF, "Gemini Lake PCI Express Root Port(0x31D7)"},
{0x8086, 0x31D8, 0xFFFF, 0xFFFF, "Gemini Lake PCI Express Root Port(0x31D8)"},
{0x8086, 0x31D9, 0xFFFF, 0xFFFF, "Gemini Lake PCI Express Root Port(0x31D9)"},
{0x8086, 0x31DA, 0xFFFF, 0xFFFF, "Gemini Lake PCI Express Root Port(0x31DA)"},
{0x8086, 0x31DB, 0xFFFF, 0xFFFF, "Gemini Lake PCI Express Root Port(0x31DB)"},
{0x8086, 0x31DC, 0xFFFF, 0xFFFF, "Gemini Lake PCH CNVi WiFi(0x31DC)"},
{0x8086, 0x31DC, 0x1A56, 0x1552, "Killer(R) Wireless-AC 1550i Wireless Network Adapter (9560NGW)(0x1A56-0x1552)"},
{0x8086, 0x31DC, 0x8086, 0x0034, "Wireless-AC 9560(0x8086-0x0034)"},
{0x8086, 0x31E3, 0xFFFF, 0xFFFF, "Celeron/Pentium Silver Processor SATA Controller(0x31E3)"},
{0x8086, 0x31E8, 0xFFFF, 0xFFFF, "Celeron/Pentium Silver Processor LPC Controller(0x31E8)"},
{0x8086, 0x31EE, 0xFFFF, 0xFFFF, "Celeron/Pentium Silver Processor Serial IO UART Host Controller(0x31EE)"},
{0x8086, 0x31F0, 0xFFFF, 0xFFFF, "Gemini Lake Host Bridge(0x31F0)"},
{0x8086, 0x3200, 0xFFFF, 0xFFFF, "GD31244 PCI-X SATA HBA(0x3200)"},
{0x8086, 0x3200, 0x1775, 0xC200, "C2K onboard SATA host bus adapter(0x1775-0xC200)"},
{0x8086, 0x3310, 0xFFFF, 0xFFFF, "IOP348 I/O Processor(0x3310)"},
{0x8086, 0x3310, 0x1054, 0x3030, "HRA380 Hitachi RAID Adapter to PCIe(0x1054-0x3030)"},
{0x8086, 0x3310, 0x1054, 0x3034, "HRA381 Hitachi RAID Adapter to PCIe(0x1054-0x3034)"},
{0x8086, 0x3313, 0xFFFF, 0xFFFF, "IOP348 I/O Processor (SL8e) in IOC Mode SAS/SATA(0x3313)"},
{0x8086, 0x331B, 0xFFFF, 0xFFFF, "IOP348 I/O Processor (SL8x) in IOC Mode SAS/SATA(0x331B)"},
{0x8086, 0x3331, 0xFFFF, 0xFFFF, "IOC340 I/O Controller (VV8e) SAS/SATA(0x3331)"},
{0x8086, 0x3339, 0xFFFF, 0xFFFF, "IOC340 I/O Controller (VV8x) SAS/SATA(0x3339)"},
{0x8086, 0x3340, 0xFFFF, 0xFFFF, "82855PM Processor to I/O Controller(0x3340)"},
{0x8086, 0x3340, 0x1014, 0x0529, "Thinkpad T40 series(0x1014-0x0529)"},
{0x8086, 0x3340, 0x1025, 0x005A, "TravelMate 290(0x1025-0x005A)"},
{0x8086, 0x3340, 0x103C, 0x088C, "NC8000 laptop(0x103C-0x088C)"},
{0x8086, 0x3340, 0x103C, 0x0890, "NC6000 laptop(0x103C-0x0890)"},
{0x8086, 0x3340, 0x103C, 0x08B0, "tc1100 tablet(0x103C-0x08B0)"},
{0x8086, 0x3340, 0x144D, 0xC005, "X10 Laptop(0x144D-0xC005)"},
{0x8086, 0x3340, 0x144D, 0xC00C, "P30/P35 notebook(0x144D-0xC00C)"},
{0x8086, 0x3341, 0xFFFF, 0xFFFF, "82855PM Processor to AGP Controller(0x3341)"},
{0x8086, 0x3341, 0x144D, 0xC00C, "P30 notebook(0x144D-0xC00C)"},
{0x8086, 0x3363, 0xFFFF, 0xFFFF, "IOC340 I/O Controller in IOC Mode SAS/SATA(0x3363)"},
{0x8086, 0x3382, 0xFFFF, 0xFFFF, "81342 [Chevelon] I/O Processor (ATUe)(0x3382)"},
{0x8086, 0x33C3, 0xFFFF, 0xFFFF, "IOP348 I/O Processor (SL8De) in IOC Mode SAS/SATA(0x33C3)"},
{0x8086, 0x33CB, 0xFFFF, 0xFFFF, "IOP348 I/O Processor (SL8Dx) in IOC Mode SAS/SATA(0x33CB)"},
{0x8086, 0x3400, 0xFFFF, 0xFFFF, "5520/5500/X58 I/O Hub to ESI Port(0x3400)"},
{0x8086, 0x3401, 0xFFFF, 0xFFFF, "5520/5500/X58 I/O Hub to ESI Port(0x3401)"},
{0x8086, 0x3402, 0xFFFF, 0xFFFF, "5520/5500/X58 I/O Hub to ESI Port(0x3402)"},
{0x8086, 0x3403, 0xFFFF, 0xFFFF, "5500 I/O Hub to ESI Port(0x3403)"},
{0x8086, 0x3403, 0x1028, 0x0236, "PowerEdge R610 I/O Hub to ESI Port(0x1028-0x0236)"},
{0x8086, 0x3403, 0x1028, 0x0287, "PowerEdge M610 I/O Hub to ESI Port(0x1028-0x0287)"},
{0x8086, 0x3403, 0x1028, 0x028C, "PowerEdge R410 I/O Hub to ESI Port(0x1028-0x028C)"},
{0x8086, 0x3403, 0x1028, 0x028D, "PowerEdge T410 I/O Hub to ESI Port(0x1028-0x028D)"},
{0x8086, 0x3403, 0x103C, 0x330B, "ProLiant ML150 G6 Server(0x103C-0x330B)"},
{0x8086, 0x3404, 0xFFFF, 0xFFFF, "5520/5500/X58 I/O Hub to ESI Port(0x3404)"},
{0x8086, 0x3405, 0xFFFF, 0xFFFF, "5520/5500/X58 I/O Hub to ESI Port(0x3405)"},
{0x8086, 0x3406, 0xFFFF, 0xFFFF, "5520 I/O Hub to ESI Port(0x3406)"},
{0x8086, 0x3406, 0x103C, 0x330B, "ProLiant G6 series(0x103C-0x330B)"},
{0x8086, 0x3407, 0xFFFF, 0xFFFF, "5520/5500/X58 I/O Hub to ESI Port(0x3407)"},
{0x8086, 0x3408, 0xFFFF, 0xFFFF, "5520/5500/X58 I/O Hub PCI Express Root Port 1(0x3408)"},
{0x8086, 0x3408, 0x103C, 0x330B, "ProLiant G6 series(0x103C-0x330B)"},
{0x8086, 0x3409, 0xFFFF, 0xFFFF, "5520/5500/X58 I/O Hub PCI Express Root Port 2(0x3409)"},
{0x8086, 0x340A, 0xFFFF, 0xFFFF, "5520/5500/X58 I/O Hub PCI Express Root Port 3(0x340A)"},
{0x8086, 0x340A, 0x103C, 0x330B, "ProLiant ML150 G6 Server(0x103C-0x330B)"},
{0x8086, 0x340B, 0xFFFF, 0xFFFF, "5520/X58 I/O Hub PCI Express Root Port 4(0x340B)"},
{0x8086, 0x340C, 0xFFFF, 0xFFFF, "5520/X58 I/O Hub PCI Express Root Port 5(0x340C)"},
{0x8086, 0x340D, 0xFFFF, 0xFFFF, "5520/X58 I/O Hub PCI Express Root Port 6(0x340D)"},
{0x8086, 0x340E, 0xFFFF, 0xFFFF, "5520/5500/X58 I/O Hub PCI Express Root Port 7(0x340E)"},
{0x8086, 0x340E, 0x103C, 0x330B, "ProLiant ML150 G6 Server(0x103C-0x330B)"},
{0x8086, 0x340F, 0xFFFF, 0xFFFF, "5520/5500/X58 I/O Hub PCI Express Root Port 8(0x340F)"},
{0x8086, 0x3410, 0xFFFF, 0xFFFF, "7500/5520/5500/X58 I/O Hub PCI Express Root Port 9(0x3410)"},
{0x8086, 0x3411, 0xFFFF, 0xFFFF, "7500/5520/5500/X58 I/O Hub PCI Express Root Port 10(0x3411)"},
{0x8086, 0x3418, 0xFFFF, 0xFFFF, "7500/5520/5500/X58 Physical Layer Port 0(0x3418)"},
{0x8086, 0x3419, 0xFFFF, 0xFFFF, "7500/5520/5500 Physical Layer Port 1(0x3419)"},
{0x8086, 0x3420, 0xFFFF, 0xFFFF, "7500/5520/5500/X58 I/O Hub PCI Express Root Port 0(0x3420)"},
{0x8086, 0x3421, 0xFFFF, 0xFFFF, "7500/5520/5500/X58 I/O Hub PCI Express Root Port 0(0x3421)"},
{0x8086, 0x3422, 0xFFFF, 0xFFFF, "7500/5520/5500/X58 I/O Hub GPIO and Scratch Pad Registers(0x3422)"},
{0x8086, 0x3422, 0x103C, 0x330B, "ProLiant G6 series(0x103C-0x330B)"},
{0x8086, 0x3423, 0xFFFF, 0xFFFF, "7500/5520/5500/X58 I/O Hub Control Status and RAS Registers(0x3423)"},
{0x8086, 0x3423, 0x103C, 0x330B, "ProLiant G6 series(0x103C-0x330B)"},
{0x8086, 0x3425, 0xFFFF, 0xFFFF, "7500/5520/5500/X58 Physical and Link Layer Registers Port 0(0x3425)"},
{0x8086, 0x3426, 0xFFFF, 0xFFFF, "7500/5520/5500/X58 Routing and Protocol Layer Registers Port 0(0x3426)"},
{0x8086, 0x3427, 0xFFFF, 0xFFFF, "7500/5520/5500 Physical and Link Layer Registers Port 1(0x3427)"},
{0x8086, 0x3428, 0xFFFF, 0xFFFF, "7500/5520/5500 Routing & Protocol Layer Register Port 1(0x3428)"},
{0x8086, 0x3429, 0xFFFF, 0xFFFF, "5520/5500/X58 Chipset QuickData Technology Device(0x3429)"},
{0x8086, 0x342A, 0xFFFF, 0xFFFF, "5520/5500/X58 Chipset QuickData Technology Device(0x342A)"},
{0x8086, 0x342B, 0xFFFF, 0xFFFF, "5520/5500/X58 Chipset QuickData Technology Device(0x342B)"},
{0x8086, 0x342C, 0xFFFF, 0xFFFF, "5520/5500/X58 Chipset QuickData Technology Device(0x342C)"},
{0x8086, 0x342D, 0xFFFF, 0xFFFF, "7500/5520/5500/X58 I/O Hub I/OxAPIC Interrupt Controller(0x342D)"},
{0x8086, 0x342E, 0xFFFF, 0xFFFF, "7500/5520/5500/X58 I/O Hub System Management Registers(0x342E)"},
{0x8086, 0x342E, 0x103C, 0x330B, "ProLiant G6 series(0x103C-0x330B)"},
{0x8086, 0x342F, 0xFFFF, 0xFFFF, "7500/5520/5500/X58 Trusted Execution Technology Registers(0x342F)"},
{0x8086, 0x3430, 0xFFFF, 0xFFFF, "5520/5500/X58 Chipset QuickData Technology Device(0x3430)"},
{0x8086, 0x3431, 0xFFFF, 0xFFFF, "5520/5500/X58 Chipset QuickData Technology Device(0x3431)"},
{0x8086, 0x3432, 0xFFFF, 0xFFFF, "5520/5500/X58 Chipset QuickData Technology Device(0x3432)"},
{0x8086, 0x3433, 0xFFFF, 0xFFFF, "5520/5500/X58 Chipset QuickData Technology Device(0x3433)"},
{0x8086, 0x3438, 0xFFFF, 0xFFFF, "7500/5520/5500/X58 I/O Hub Throttle Registers(0x3438)"},
{0x8086, 0x3440, 0xFFFF, 0xFFFF, "Ice Lake UPI Misc(0x3440)"},
{0x8086, 0x3441, 0xFFFF, 0xFFFF, "Ice Lake UPI Link/Phy0(0x3441)"},
{0x8086, 0x3456, 0xFFFF, 0xFFFF, "Ice Lake NorthPeak(0x3456)"},
{0x8086, 0x347E, 0xFFFF, 0xFFFF, "Ice Lake Xeon Non-Transparent Bridge(0x347E)"},
{0x8086, 0x3482, 0xFFFF, 0xFFFF, "Ice Lake-LP LPC Controller(0x3482)"},
{0x8086, 0x34A3, 0xFFFF, 0xFFFF, "Ice Lake-LP SMBus Controller(0x34A3)"},
{0x8086, 0x34A4, 0xFFFF, 0xFFFF, "Ice Lake-LP SPI Controller(0x34A4)"},
{0x8086, 0x34A8, 0xFFFF, 0xFFFF, "Ice Lake-LP Serial IO UART Controller #0(0x34A8)"},
{0x8086, 0x34A9, 0xFFFF, 0xFFFF, "Ice Lake-LP Serial IO UART Controller #1(0x34A9)"},
{0x8086, 0x34AA, 0xFFFF, 0xFFFF, "Ice Lake-LP Serial IO SPI Controller #0(0x34AA)"},
{0x8086, 0x34AB, 0xFFFF, 0xFFFF, "Ice Lake-LP Serial IO SPI Controller #1(0x34AB)"},
{0x8086, 0x34B0, 0xFFFF, 0xFFFF, "Ice Lake-LP PCI Express Root Port #9(0x34B0)"},
{0x8086, 0x34B1, 0xFFFF, 0xFFFF, "Ice Lake-LP PCIe Port #10(0x34B1)"},
{0x8086, 0x34B4, 0xFFFF, 0xFFFF, "Ice Lake-LP PCIe Port #13(0x34B4)"},
{0x8086, 0x34B5, 0xFFFF, 0xFFFF, "Ice Lake-LP PCIe Port #14(0x34B5)"},
{0x8086, 0x34B7, 0xFFFF, 0xFFFF, "Ice Lake-LP PCI Express Root Port #16(0x34B7)"},
{0x8086, 0x34B8, 0xFFFF, 0xFFFF, "Ice Lake-LP PCIe Port #1(0x34B8)"},
{0x8086, 0x34BA, 0xFFFF, 0xFFFF, "Ice Lake-LP PCI Express Root Port #3(0x34BA)"},
{0x8086, 0x34BB, 0xFFFF, 0xFFFF, "Ice Lake-LP PCIe Port #4(0x34BB)"},
{0x8086, 0x34BC, 0xFFFF, 0xFFFF, "Ice Lake-LP PCI Express Root Port #5(0x34BC)"},
{0x8086, 0x34BD, 0xFFFF, 0xFFFF, "Ice Lake-LP PCIe Port #6(0x34BD)"},
{0x8086, 0x34BE, 0xFFFF, 0xFFFF, "Ice Lake-LP PCIe Port #7(0x34BE)"},
{0x8086, 0x34BF, 0xFFFF, 0xFFFF, "Ice Lake-LP PCIe Port #8(0x34BF)"},
{0x8086, 0x34C4, 0xFFFF, 0xFFFF, "Ice Lake-LP SD Host Controller(0x34C4)"},
{0x8086, 0x34C5, 0xFFFF, 0xFFFF, "Ice Lake-LP Serial IO I2c Controller #4(0x34C5)"},
{0x8086, 0x34C6, 0xFFFF, 0xFFFF, "Ice Lake-LP Serial IO I2c Controller #5(0x34C6)"},
{0x8086, 0x34C8, 0xFFFF, 0xFFFF, "Ice Lake-LP Smart Sound Technology Audio Controller(0x34C8)"},
{0x8086, 0x34D3, 0xFFFF, 0xFFFF, "Ice Lake-LP SATA Controller [AHCI mode](0x34D3)"},
{0x8086, 0x34E0, 0xFFFF, 0xFFFF, "Ice Lake-LP Management Engine(0x34E0)"},
{0x8086, 0x34E8, 0xFFFF, 0xFFFF, "Ice Lake-LP Serial IO I2C Controller #0(0x34E8)"},
{0x8086, 0x34E9, 0xFFFF, 0xFFFF, "Ice Lake-LP Serial IO I2C Controller #1(0x34E9)"},
{0x8086, 0x34EA, 0xFFFF, 0xFFFF, "Ice Lake-LP Serial IO I2C Controller #2(0x34EA)"},
{0x8086, 0x34EB, 0xFFFF, 0xFFFF, "Ice Lake-LP Serial IO I2C Controller #3(0x34EB)"},
{0x8086, 0x34ED, 0xFFFF, 0xFFFF, "Ice Lake-LP USB 3.1 xHCI Host Controller(0x34ED)"},
{0x8086, 0x34EF, 0xFFFF, 0xFFFF, "Ice Lake-LP DRAM Controller(0x34EF)"},
{0x8086, 0x34F0, 0xFFFF, 0xFFFF, "Ice Lake-LP PCH CNVi WiFi(0x34F0)"},
{0x8086, 0x34F0, 0x1A56, 0x1552, "Killer(R) Wireless-AC 1550i Wireless Network Adapter (9560NGW)(0x1A56-0x1552)"},
{0x8086, 0x34F0, 0x8086, 0x0074, "Wi-Fi 6 AX201(0x8086-0x0074)"},
{0x8086, 0x34F0, 0x8086, 0x0264, "Wireless-AC 9461(0x8086-0x0264)"},
{0x8086, 0x34F8, 0xFFFF, 0xFFFF, "Ice Lake-LP SD Controller(0x34F8)"},
{0x8086, 0x34FC, 0xFFFF, 0xFFFF, "Ice Lake-LP Integrated Sensor Solution(0x34FC)"},
{0x8086, 0x3500, 0xFFFF, 0xFFFF, "6311ESB/6321ESB PCI Express Upstream Port(0x3500)"},
{0x8086, 0x3500, 0x103C, 0x31FE, "ProLiant DL140 G3(0x103C-0x31FE)"},
{0x8086, 0x3500, 0x15D9, 0x9680, "X7DBN Motherboard(0x15D9-0x9680)"},
{0x8086, 0x3501, 0xFFFF, 0xFFFF, "6310ESB PCI Express Upstream Port(0x3501)"},
{0x8086, 0x3504, 0xFFFF, 0xFFFF, "6311ESB/6321ESB I/OxAPIC Interrupt Controller(0x3504)"},
{0x8086, 0x3505, 0xFFFF, 0xFFFF, "6310ESB I/OxAPIC Interrupt Controller(0x3505)"},
{0x8086, 0x350C, 0xFFFF, 0xFFFF, "6311ESB/6321ESB PCI Express to PCI-X Bridge(0x350C)"},
{0x8086, 0x350C, 0x103C, 0x31FE, "ProLiant DL140 G3(0x103C-0x31FE)"},
{0x8086, 0x350C, 0x15D9, 0x9680, "X7DBN Motherboard(0x15D9-0x9680)"},
{0x8086, 0x350D, 0xFFFF, 0xFFFF, "6310ESB PCI Express to PCI-X Bridge(0x350D)"},
{0x8086, 0x3510, 0xFFFF, 0xFFFF, "6311ESB/6321ESB PCI Express Downstream Port E1(0x3510)"},
{0x8086, 0x3510, 0x103C, 0x31FE, "ProLiant DL140 G3(0x103C-0x31FE)"},
{0x8086, 0x3510, 0x15D9, 0x9680, "X7DBN Motherboard(0x15D9-0x9680)"},
{0x8086, 0x3511, 0xFFFF, 0xFFFF, "6310ESB PCI Express Downstream Port E1(0x3511)"},
{0x8086, 0x3514, 0xFFFF, 0xFFFF, "6311ESB/6321ESB PCI Express Downstream Port E2(0x3514)"},
{0x8086, 0x3515, 0xFFFF, 0xFFFF, "6310ESB PCI Express Downstream Port E2(0x3515)"},
{0x8086, 0x3518, 0xFFFF, 0xFFFF, "6311ESB/6321ESB PCI Express Downstream Port E3(0x3518)"},
{0x8086, 0x3518, 0x15D9, 0x9680, "X7DBN Motherboard(0x15D9-0x9680)"},
{0x8086, 0x3519, 0xFFFF, 0xFFFF, "6310ESB PCI Express Downstream Port E3(0x3519)"},
{0x8086, 0x3575, 0xFFFF, 0xFFFF, "82830M/MG/MP Host Bridge(0x3575)"},
{0x8086, 0x3575, 0x0E11, 0x0030, "Evo N600c(0x0E11-0x0030)"},
{0x8086, 0x3575, 0x1014, 0x021D, "ThinkPad A/T/X Series(0x1014-0x021D)"},
{0x8086, 0x3575, 0x104D, 0x80E7, "VAIO PCG-GR214EP/GR214MP/GR215MP/GR314MP/GR315MP(0x104D-0x80E7)"},
{0x8086, 0x3576, 0xFFFF, 0xFFFF, "82830M/MP AGP Bridge(0x3576)"},
{0x8086, 0x3577, 0xFFFF, 0xFFFF, "82830M/MG Integrated Graphics Controller(0x3577)"},
{0x8086, 0x3577, 0x1014, 0x0513, "ThinkPad A/T/X Series(0x1014-0x0513)"},
{0x8086, 0x3578, 0xFFFF, 0xFFFF, "82830M/MG/MP Host Bridge(0x3578)"},
{0x8086, 0x3580, 0xFFFF, 0xFFFF, "82852/82855 GM/GME/PM/GMV Processor to I/O Controller(0x3580)"},
{0x8086, 0x3580, 0x1014, 0x055C, "ThinkPad R50e(0x1014-0x055C)"},
{0x8086, 0x3580, 0x1025, 0x0064, "Extensa 3000 series laptop(0x1025-0x0064)"},
{0x8086, 0x3580, 0x1028, 0x0139, "Latitude D400(0x1028-0x0139)"},
{0x8086, 0x3580, 0x1028, 0x014F, "Latitude X300(0x1028-0x014F)"},
{0x8086, 0x3580, 0x1028, 0x0152, "Latitude D500(0x1028-0x0152)"},
{0x8086, 0x3580, 0x1028, 0x0163, "Latitude D505(0x1028-0x0163)"},
{0x8086, 0x3580, 0x1028, 0x018D, "Inspiron 700m/710m(0x1028-0x018D)"},
{0x8086, 0x3580, 0x1028, 0x0196, "Inspiron 5160(0x1028-0x0196)"},
{0x8086, 0x3580, 0x114A, 0x0582, "PC8(0x114A-0x0582)"},
{0x8086, 0x3580, 0x1734, 0x1055, "Amilo M1420(0x1734-0x1055)"},
{0x8086, 0x3580, 0x1775, 0x10D0, "V5D Single Board Computer(0x1775-0x10D0)"},
{0x8086, 0x3580, 0x1775, 0xCE90, "CE9(0x1775-0xCE90)"},
{0x8086, 0x3580, 0x4C53, 0x10B0, "CL9 mainboard(0x4C53-0x10B0)"},
{0x8086, 0x3580, 0x4C53, 0x10E0, "PSL09 PrPMC(0x4C53-0x10E0)"},
{0x8086, 0x3580, 0xE4BF, 0x0CC9, "CC9-SAMBA(0xE4BF-0x0CC9)"},
{0x8086, 0x3580, 0xE4BF, 0x0CD2, "CD2-BEBOP(0xE4BF-0x0CD2)"},
{0x8086, 0x3581, 0xFFFF, 0xFFFF, "82852/82855 GM/GME/PM/GMV Processor to AGP Controller(0x3581)"},
{0x8086, 0x3581, 0x1734, 0x1055, "Amilo M1420(0x1734-0x1055)"},
{0x8086, 0x3582, 0xFFFF, 0xFFFF, "82852/855GM Integrated Graphics Device(0x3582)"},
{0x8086, 0x3582, 0x1014, 0x0562, "ThinkPad R50e(0x1014-0x0562)"},
{0x8086, 0x3582, 0x1028, 0x0139, "Latitude D400(0x1028-0x0139)"},
{0x8086, 0x3582, 0x1028, 0x014F, "Latitude X300(0x1028-0x014F)"},
{0x8086, 0x3582, 0x1028, 0x0152, "Latitude D500(0x1028-0x0152)"},
{0x8086, 0x3582, 0x1028, 0x0163, "Latitude D505(0x1028-0x0163)"},
{0x8086, 0x3582, 0x1028, 0x018D, "Inspiron 700m/710m(0x1028-0x018D)"},
{0x8086, 0x3582, 0x114A, 0x0582, "PC8 integrated graphics(0x114A-0x0582)"},
{0x8086, 0x3582, 0x1775, 0x10D0, "V5D Single Board Computer VGA(0x1775-0x10D0)"},
{0x8086, 0x3582, 0x1775, 0xCE90, "CE9(0x1775-0xCE90)"},
{0x8086, 0x3582, 0x4C53, 0x10B0, "CL9 mainboard(0x4C53-0x10B0)"},
{0x8086, 0x3582, 0x4C53, 0x10E0, "PSL09 PrPMC(0x4C53-0x10E0)"},
{0x8086, 0x3582, 0xE4BF, 0x0CC9, "CC9-SAMBA(0xE4BF-0x0CC9)"},
{0x8086, 0x3582, 0xE4BF, 0x0CD2, "CD2-BEBOP(0xE4BF-0x0CD2)"},
{0x8086, 0x3584, 0xFFFF, 0xFFFF, "82852/82855 GM/GME/PM/GMV Processor to I/O Controller(0x3584)"},
{0x8086, 0x3584, 0x1014, 0x055D, "ThinkPad R50e(0x1014-0x055D)"},
{0x8086, 0x3584, 0x1025, 0x0064, "Extensa 3000 series laptop(0x1025-0x0064)"},
{0x8086, 0x3584, 0x1028, 0x0139, "Latitude D400(0x1028-0x0139)"},
{0x8086, 0x3584, 0x1028, 0x014F, "Latitude X300(0x1028-0x014F)"},
{0x8086, 0x3584, 0x1028, 0x0152, "Latitude D500(0x1028-0x0152)"},
{0x8086, 0x3584, 0x1028, 0x0163, "Latitude D505(0x1028-0x0163)"},
{0x8086, 0x3584, 0x1028, 0x018D, "Inspiron 700m/710m(0x1028-0x018D)"},
{0x8086, 0x3584, 0x1028, 0x0196, "Inspiron 5160(0x1028-0x0196)"},
{0x8086, 0x3584, 0x114A, 0x0582, "PC8(0x114A-0x0582)"},
{0x8086, 0x3584, 0x1734, 0x1055, "Amilo M1420(0x1734-0x1055)"},
{0x8086, 0x3584, 0x1775, 0x10D0, "V5D Single Board Computer(0x1775-0x10D0)"},
{0x8086, 0x3584, 0x1775, 0xCE90, "CE9(0x1775-0xCE90)"},
{0x8086, 0x3584, 0x4C53, 0x10B0, "CL9 mainboard(0x4C53-0x10B0)"},
{0x8086, 0x3584, 0x4C53, 0x10E0, "PSL09 PrPMC(0x4C53-0x10E0)"},
{0x8086, 0x3585, 0xFFFF, 0xFFFF, "82852/82855 GM/GME/PM/GMV Processor to I/O Controller(0x3585)"},
{0x8086, 0x3585, 0x1014, 0x055E, "ThinkPad R50e(0x1014-0x055E)"},
{0x8086, 0x3585, 0x1025, 0x0064, "Extensa 3000 series laptop(0x1025-0x0064)"},
{0x8086, 0x3585, 0x1028, 0x0139, "Latitude D400(0x1028-0x0139)"},
{0x8086, 0x3585, 0x1028, 0x014F, "Latitude X300(0x1028-0x014F)"},
{0x8086, 0x3585, 0x1028, 0x0152, "Latitude D500(0x1028-0x0152)"},
{0x8086, 0x3585, 0x1028, 0x0163, "Latitude D505(0x1028-0x0163)"},
{0x8086, 0x3585, 0x1028, 0x018D, "Inspiron 700m/710m(0x1028-0x018D)"},
{0x8086, 0x3585, 0x1028, 0x0196, "Inspiron 5160(0x1028-0x0196)"},
{0x8086, 0x3585, 0x114A, 0x0582, "PC8(0x114A-0x0582)"},
{0x8086, 0x3585, 0x1734, 0x1055, "Amilo M1420(0x1734-0x1055)"},
{0x8086, 0x3585, 0x1775, 0x10D0, "V5D Single Board Computer(0x1775-0x10D0)"},
{0x8086, 0x3585, 0x1775, 0xCE90, "CE9(0x1775-0xCE90)"},
{0x8086, 0x3585, 0x4C53, 0x10B0, "CL9 mainboard(0x4C53-0x10B0)"},
{0x8086, 0x3585, 0x4C53, 0x10E0, "PSL09 PrPMC(0x4C53-0x10E0)"},
{0x8086, 0x358C, 0xFFFF, 0xFFFF, "82854 GMCH(0x358C)"},
{0x8086, 0x358E, 0xFFFF, 0xFFFF, "82854 GMCH Integrated Graphics Device(0x358E)"},
{0x8086, 0x3590, 0xFFFF, 0xFFFF, "E7520 Memory Controller Hub(0x3590)"},
{0x8086, 0x3590, 0x1014, 0x02DD, "eServer xSeries server mainboard(0x1014-0x02DD)"},
{0x8086, 0x3590, 0x1028, 0x016C, "PowerEdge 1850 Memory Controller Hub(0x1028-0x016C)"},
{0x8086, 0x3590, 0x1028, 0x016D, "PowerEdge 2850 Memory Controller Hub(0x1028-0x016D)"},
{0x8086, 0x3590, 0x1028, 0x019A, "PowerEdge SC1425(0x1028-0x019A)"},
{0x8086, 0x3590, 0x1734, 0x103E, "PRIMERGY RX/TX S2 series(0x1734-0x103E)"},
{0x8086, 0x3590, 0x1775, 0x1100, "CR11/VR11 Single Board Computer(0x1775-0x1100)"},
{0x8086, 0x3590, 0x4C53, 0x10D0, "Telum ASLP10 Processor AMC(0x4C53-0x10D0)"},
{0x8086, 0x3591, 0xFFFF, 0xFFFF, "E7525/E7520 Error Reporting Registers(0x3591)"},
{0x8086, 0x3591, 0x1014, 0x02DD, "eServer xSeries server mainboard(0x1014-0x02DD)"},
{0x8086, 0x3591, 0x1028, 0x0168, "Precision Workstation 670 Mainboard(0x1028-0x0168)"},
{0x8086, 0x3591, 0x1028, 0x0169, "Precision 470(0x1028-0x0169)"},
{0x8086, 0x3591, 0x103C, 0x3208, "ProLiant DL140 G2(0x103C-0x3208)"},
{0x8086, 0x3591, 0x4C53, 0x10D0, "Telum ASLP10 Processor AMC(0x4C53-0x10D0)"},
{0x8086, 0x3592, 0xFFFF, 0xFFFF, "E7320 Memory Controller Hub(0x3592)"},
{0x8086, 0x3592, 0x1734, 0x1073, "Primergy Econel 200 D2020 mainboard(0x1734-0x1073)"},
{0x8086, 0x3593, 0xFFFF, 0xFFFF, "E7320 Error Reporting Registers(0x3593)"},
{0x8086, 0x3593, 0x1734, 0x1073, "Primergy Econel 200 D2020 mainboard(0x1734-0x1073)"},
{0x8086, 0x3594, 0xFFFF, 0xFFFF, "E7520 DMA Controller(0x3594)"},
{0x8086, 0x3594, 0x1775, 0x1100, "CR11/VR11 Single Board Computer(0x1775-0x1100)"},
{0x8086, 0x3594, 0x4C53, 0x10D0, "Telum ASLP10 Processor AMC(0x4C53-0x10D0)"},
{0x8086, 0x3595, 0xFFFF, 0xFFFF, "E7525/E7520/E7320 PCI Express Port A(0x3595)"},
{0x8086, 0x3595, 0x1775, 0x1100, "CR11/VR11 Single Board Computer(0x1775-0x1100)"},
{0x8086, 0x3596, 0xFFFF, 0xFFFF, "E7525/E7520/E7320 PCI Express Port A1(0x3596)"},
{0x8086, 0x3597, 0xFFFF, 0xFFFF, "E7525/E7520 PCI Express Port B(0x3597)"},
{0x8086, 0x3597, 0x1775, 0x1100, "CR11/VR11 Single Board Computer(0x1775-0x1100)"},
{0x8086, 0x3598, 0xFFFF, 0xFFFF, "E7520 PCI Express Port B1(0x3598)"},
{0x8086, 0x3598, 0x1775, 0x1100, "CR11/VR11 Single Board Computer(0x1775-0x1100)"},
{0x8086, 0x3599, 0xFFFF, 0xFFFF, "E7520 PCI Express Port C(0x3599)"},
{0x8086, 0x3599, 0x1775, 0x1100, "CR11/VR11 Single Board Computer(0x1775-0x1100)"},
{0x8086, 0x359A, 0xFFFF, 0xFFFF, "E7520 PCI Express Port C1(0x359A)"},
{0x8086, 0x359B, 0xFFFF, 0xFFFF, "E7525/E7520/E7320 Extended Configuration Registers(0x359B)"},
{0x8086, 0x359B, 0x1014, 0x02DD, "eServer xSeries server mainboard(0x1014-0x02DD)"},
{0x8086, 0x359E, 0xFFFF, 0xFFFF, "E7525 Memory Controller Hub(0x359E)"},
{0x8086, 0x359E, 0x1028, 0x0168, "Precision Workstation 670 Mainboard(0x1028-0x0168)"},
{0x8086, 0x359E, 0x1028, 0x0169, "Precision 470(0x1028-0x0169)"},
{0x8086, 0x35B0, 0xFFFF, 0xFFFF, "3100 Chipset Memory I/O Controller Hub(0x35B0)"},
{0x8086, 0x35B1, 0xFFFF, 0xFFFF, "3100 DRAM Controller Error Reporting Registers(0x35B1)"},
{0x8086, 0x35B5, 0xFFFF, 0xFFFF, "3100 Chipset Enhanced DMA Controller(0x35B5)"},
{0x8086, 0x35B6, 0xFFFF, 0xFFFF, "3100 Chipset PCI Express Port A(0x35B6)"},
{0x8086, 0x35B7, 0xFFFF, 0xFFFF, "3100 Chipset PCI Express Port A1(0x35B7)"},
{0x8086, 0x35C8, 0xFFFF, 0xFFFF, "3100 Extended Configuration Test Overflow Registers(0x35C8)"},
{0x8086, 0x3600, 0xFFFF, 0xFFFF, "7300 Chipset Memory Controller Hub(0x3600)"},
{0x8086, 0x3604, 0xFFFF, 0xFFFF, "7300 Chipset PCI Express Port 1(0x3604)"},
{0x8086, 0x3605, 0xFFFF, 0xFFFF, "7300 Chipset PCI Express Port 2(0x3605)"},
{0x8086, 0x3606, 0xFFFF, 0xFFFF, "7300 Chipset PCI Express Port 3(0x3606)"},
{0x8086, 0x3607, 0xFFFF, 0xFFFF, "7300 Chipset PCI Express Port 4(0x3607)"},
{0x8086, 0x3608, 0xFFFF, 0xFFFF, "7300 Chipset PCI Express Port 5(0x3608)"},
{0x8086, 0x3609, 0xFFFF, 0xFFFF, "7300 Chipset PCI Express Port 6(0x3609)"},
{0x8086, 0x360A, 0xFFFF, 0xFFFF, "7300 Chipset PCI Express Port 7(0x360A)"},
{0x8086, 0x360B, 0xFFFF, 0xFFFF, "7300 Chipset QuickData Technology Device(0x360B)"},
{0x8086, 0x360C, 0xFFFF, 0xFFFF, "7300 Chipset FSB Registers(0x360C)"},
{0x8086, 0x360C, 0x1028, 0x01F0, "PowerEdge R900 7300 Chipset FSB Registers(0x1028-0x01F0)"},
{0x8086, 0x360D, 0xFFFF, 0xFFFF, "7300 Chipset Snoop Filter Registers(0x360D)"},
{0x8086, 0x360E, 0xFFFF, 0xFFFF, "7300 Chipset Debug and Miscellaneous Registers(0x360E)"},
{0x8086, 0x360F, 0xFFFF, 0xFFFF, "7300 Chipset FBD Branch 0 Registers(0x360F)"},
{0x8086, 0x3610, 0xFFFF, 0xFFFF, "7300 Chipset FBD Branch 1 Registers(0x3610)"},
{0x8086, 0x3700, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 DMI(0x3700)"},
{0x8086, 0x3701, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 DMI(0x3701)"},
{0x8086, 0x3702, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 DMI(0x3702)"},
{0x8086, 0x3703, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 DMI(0x3703)"},
{0x8086, 0x3704, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 DMI(0x3704)"},
{0x8086, 0x3705, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 DMI(0x3705)"},
{0x8086, 0x3706, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 DMI(0x3706)"},
{0x8086, 0x3707, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 DMI(0x3707)"},
{0x8086, 0x3708, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 DMI(0x3708)"},
{0x8086, 0x3709, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 DMI(0x3709)"},
{0x8086, 0x370A, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 DMI(0x370A)"},
{0x8086, 0x370B, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 DMI(0x370B)"},
{0x8086, 0x370C, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 DMI(0x370C)"},
{0x8086, 0x370D, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 DMI(0x370D)"},
{0x8086, 0x370E, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 DMI(0x370E)"},
{0x8086, 0x370F, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 DMI(0x370F)"},
{0x8086, 0x3710, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 CB3 DMA(0x3710)"},
{0x8086, 0x3711, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 CB3 DMA(0x3711)"},
{0x8086, 0x3712, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 CB3 DMA(0x3712)"},
{0x8086, 0x3713, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 CB3 DMA(0x3713)"},
{0x8086, 0x3714, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 CB3 DMA(0x3714)"},
{0x8086, 0x3715, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 CB3 DMA(0x3715)"},
{0x8086, 0x3716, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 CB3 DMA(0x3716)"},
{0x8086, 0x3717, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 CB3 DMA(0x3717)"},
{0x8086, 0x3718, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 CB3 DMA(0x3718)"},
{0x8086, 0x3719, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 CB3 DMA(0x3719)"},
{0x8086, 0x371A, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 QPI Link(0x371A)"},
{0x8086, 0x371B, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 QPI Routing and Protocol(0x371B)"},
{0x8086, 0x371D, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 QPI Routing and Protocol(0x371D)"},
{0x8086, 0x3720, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 PCI Express Root Port 0(0x3720)"},
{0x8086, 0x3721, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 PCI Express Root Port 1(0x3721)"},
{0x8086, 0x3722, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 PCI Express Root Port 2(0x3722)"},
{0x8086, 0x3723, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 PCI Express Root Port 3(0x3723)"},
{0x8086, 0x3724, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 PCI Express Root Port 4(0x3724)"},
{0x8086, 0x3725, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 NTB Primary(0x3725)"},
{0x8086, 0x3726, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 NTB Primary(0x3726)"},
{0x8086, 0x3727, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 NTB Secondary(0x3727)"},
{0x8086, 0x3728, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 Core(0x3728)"},
{0x8086, 0x3729, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 Core(0x3729)"},
{0x8086, 0x372A, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 Core(0x372A)"},
{0x8086, 0x372B, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 Core(0x372B)"},
{0x8086, 0x372C, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 Reserved(0x372C)"},
{0x8086, 0x373F, 0xFFFF, 0xFFFF, "Xeon C5500/C3500 IOxAPIC(0x373F)"},
{0x8086, 0x37C8, 0xFFFF, 0xFFFF, "C62x Chipset QuickAssist Technology(0x37C8)"},
{0x8086, 0x37C8, 0x8086, 0x0001, "QuickAssist Adapter 8960(0x8086-0x0001)"},
{0x8086, 0x37C8, 0x8086, 0x0002, "QuickAssist Adapter 8970(0x8086-0x0002)"},
{0x8086, 0x37C9, 0xFFFF, 0xFFFF, "C62x Chipset QuickAssist Technology Virtual Function(0x37C9)"},
{0x8086, 0x37CC, 0xFFFF, 0xFFFF, "Ethernet Connection X722(0x37CC)"},
{0x8086, 0x37CD, 0xFFFF, 0xFFFF, "Ethernet Virtual Function 700 Series(0x37CD)"},
{0x8086, 0x37CE, 0xFFFF, 0xFFFF, "Ethernet Connection X722 for 10GbE backplane(0x37CE)"},
{0x8086, 0x37CE, 0x1590, 0x0215, "Ethernet 10Gb 2-port 568i Adapter(0x1590-0x0215)"},
{0x8086, 0x37CE, 0x17AA, 0x4023, "Intel Ethernet Connection X722 for 10GbE backplane(0x17AA-0x4023)"},
{0x8086, 0x37CE, 0x17AA, 0x4025, "Ethernet Connection X722 for 10GbE backplane(0x17AA-0x4025)"},
{0x8086, 0x37CF, 0xFFFF, 0xFFFF, "Ethernet Connection X722 for 10GbE QSFP+(0x37CF)"},
{0x8086, 0x37D0, 0xFFFF, 0xFFFF, "Ethernet Connection X722 for 10GbE SFP+(0x37D0)"},
{0x8086, 0x37D0, 0x17AA, 0x4020, "Intel Ethernet Connection X722 for 10G SFP+(0x17AA-0x4020)"},
{0x8086, 0x37D0, 0x17AA, 0x4021, "Intel Ethernet Connection X722 for 10G SFP+(0x17AA-0x4021)"},
{0x8086, 0x37D0, 0x17AA, 0x4022, "Ethernet Connection X722 for 10GbE SFP+(0x17AA-0x4022)"},
{0x8086, 0x37D0, 0x8086, 0x0001, "Ethernet Network Adapter X722-2(0x8086-0x0001)"},
{0x8086, 0x37D0, 0x8086, 0x0002, "Ethernet Network Adapter X722-2(0x8086-0x0002)"},
{0x8086, 0x37D0, 0x8086, 0x0003, "Ethernet Network Adapter X722-4(0x8086-0x0003)"},
{0x8086, 0x37D0, 0x8086, 0x0004, "Ethernet Network Adapter X722-4(0x8086-0x0004)"},
{0x8086, 0x37D1, 0xFFFF, 0xFFFF, "Ethernet Connection X722 for 1GbE(0x37D1)"},
{0x8086, 0x37D1, 0x14CD, 0x0010, "88E1514 Ethernet OCP 2x1G RJ45 Phy Card [USI-1514-1GbaseT](0x14CD-0x0010)"},
{0x8086, 0x37D1, 0x1590, 0x0216, "Ethernet 1Gb 2-port 368i Adapter(0x1590-0x0216)"},
{0x8086, 0x37D1, 0x1590, 0x0217, "Ethernet 1Gb 2-port 368FLR-MMT Adapter(0x1590-0x0217)"},
{0x8086, 0x37D1, 0x1590, 0x0247, "Ethernet 1Gb 4-port 369i Adapter(0x1590-0x0247)"},
{0x8086, 0x37D1, 0x17AA, 0x4020, "Ethernet Connection X722 for 1GbE(0x17AA-0x4020)"},
{0x8086, 0x37D1, 0x17AA, 0x4021, "Ethernet Connection X722 for 1GbE(0x17AA-0x4021)"},
{0x8086, 0x37D1, 0x17AA, 0x4022, "Ethernet Connection X722 for 1GbE(0x17AA-0x4022)"},
{0x8086, 0x37D1, 0x17AA, 0x4024, "Ethernet Connection X722 for 1GbE(0x17AA-0x4024)"},
{0x8086, 0x37D2, 0xFFFF, 0xFFFF, "Ethernet Connection X722 for 10GBASE-T(0x37D2)"},
{0x8086, 0x37D2, 0x1059, 0x0180, "RD10019 10GbE interface(0x1059-0x0180)"},
{0x8086, 0x37D2, 0x1170, 0x37D2, "Ethernet Connection X722 for 10GBASE-T(0x1170-0x37D2)"},
{0x8086, 0x37D2, 0x14CD, 0x0030, "Ethernet OCP 2x10G RJ45 Phy Card [USI-X557-10GbaseT](0x14CD-0x0030)"},
{0x8086, 0x37D2, 0x1590, 0x0218, "Ethernet 10Gb 2-port 568FLR-MMT Adapter(0x1590-0x0218)"},
{0x8086, 0x37D2, 0x17AA, 0x4020, "Ethernet Connection X722 for 10GBASE-T(0x17AA-0x4020)"},
{0x8086, 0x37D2, 0x17AA, 0x4021, "Ethernet Connection X722 for 10GBASE-T(0x17AA-0x4021)"},
{0x8086, 0x37D2, 0x17AA, 0x4022, "Ethernet Connection X722 for 10GBASE-T(0x17AA-0x4022)"},
{0x8086, 0x37D2, 0x17AA, 0x4024, "Ethernet Connection X722 for 10GBASE-T(0x17AA-0x4024)"},
{0x8086, 0x37D2, 0x17AA, 0x4025, "Ethernet Connection X722 for 10GBASE-T(0x17AA-0x4025)"},
{0x8086, 0x37D3, 0xFFFF, 0xFFFF, "Ethernet Connection X722 for 10GbE SFP+(0x37D3)"},
{0x8086, 0x37D3, 0x1590, 0x0219, "Ethernet 10Gb 2-port 568FLR-MMSFP+ Adapter(0x1590-0x0219)"},
{0x8086, 0x37D3, 0x17AA, 0x4020, "Ethernet Connection X722 for 10GbE SFP+(0x17AA-0x4020)"},
{0x8086, 0x37D3, 0x17AA, 0x4021, "Ethernet Connection X722 for 10GbE SFP+(0x17AA-0x4021)"},
{0x8086, 0x37D3, 0x17AA, 0x4025, "Ethernet Connection X722 for 10GbE SFP+(0x17AA-0x4025)"},
{0x8086, 0x37D4, 0xFFFF, 0xFFFF, "Ethernet Connection X722 for 10GbE QSFP+(0x37D4)"},
{0x8086, 0x37D9, 0xFFFF, 0xFFFF, "X722 Hyper-V Virtual Function(0x37D9)"},
{0x8086, 0x3882, 0xFFFF, 0xFFFF, "Ice Lake LPC Controller(0x3882)"},
{0x8086, 0x38A4, 0xFFFF, 0xFFFF, "Ice Lake SPI Controller(0x38A4)"},
{0x8086, 0x38C8, 0xFFFF, 0xFFFF, "Ice Lake-LP Smart Sound Technology Audio Controller(0x38C8)"},
{0x8086, 0x38E0, 0xFFFF, 0xFFFF, "Ice Lake Management Engine Interface(0x38E0)"},
{0x8086, 0x3A00, 0xFFFF, 0xFFFF, "82801JD/DO (ICH10 Family) 4-port SATA IDE Controller(0x3A00)"},
{0x8086, 0x3A02, 0xFFFF, 0xFFFF, "82801JD/DO (ICH10 Family) SATA AHCI Controller(0x3A02)"},
{0x8086, 0x3A05, 0xFFFF, 0xFFFF, "82801JD/DO (ICH10 Family) SATA RAID Controller(0x3A05)"},
{0x8086, 0x3A06, 0xFFFF, 0xFFFF, "82801JD/DO (ICH10 Family) 2-port SATA IDE Controller(0x3A06)"},
{0x8086, 0x3A14, 0xFFFF, 0xFFFF, "82801JDO (ICH10DO) LPC Interface Controller(0x3A14)"},
{0x8086, 0x3A16, 0xFFFF, 0xFFFF, "82801JIR (ICH10R) LPC Interface Controller(0x3A16)"},
{0x8086, 0x3A16, 0x1028, 0x028C, "PowerEdge R410 LPC Interface Controller(0x1028-0x028C)"},
{0x8086, 0x3A16, 0x1028, 0x028D, "PowerEdge T410 LPC Interface Controller(0x1028-0x028D)"},
{0x8086, 0x3A16, 0x103C, 0x330B, "ProLiant G6 series(0x103C-0x330B)"},
{0x8086, 0x3A16, 0x1043, 0x82D4, "P5Q Deluxe Motherboard(0x1043-0x82D4)"},
{0x8086, 0x3A16, 0x1458, 0x5001, "GA-EP45-DS5 Motherboard(0x1458-0x5001)"},
{0x8086, 0x3A18, 0xFFFF, 0xFFFF, "82801JIB (ICH10) LPC Interface Controller(0x3A18)"},
{0x8086, 0x3A1A, 0xFFFF, 0xFFFF, "82801JD (ICH10D) LPC Interface Controller(0x3A1A)"},
{0x8086, 0x3A20, 0xFFFF, 0xFFFF, "82801JI (ICH10 Family) 4 port SATA IDE Controller #1(0x3A20)"},
{0x8086, 0x3A20, 0x1028, 0x028C, "PowerEdge R410 SATA IDE Controller(0x1028-0x028C)"},
{0x8086, 0x3A20, 0x1028, 0x028D, "PowerEdge T410 SATA IDE Controller(0x1028-0x028D)"},
{0x8086, 0x3A22, 0xFFFF, 0xFFFF, "82801JI (ICH10 Family) SATA AHCI Controller(0x3A22)"},
{0x8086, 0x3A22, 0x103C, 0x330B, "ProLiant G6 series(0x103C-0x330B)"},
{0x8086, 0x3A22, 0x1043, 0x82D4, "P5Q Deluxe Motherboard(0x1043-0x82D4)"},
{0x8086, 0x3A22, 0x1458, 0xB005, "GA-EP45-DS5/GA-EG45M-DS2H Motherboard(0x1458-0xB005)"},
{0x8086, 0x3A25, 0xFFFF, 0xFFFF, "82801JIR (ICH10R) SATA RAID Controller(0x3A25)"},
{0x8086, 0x3A25, 0x1028, 0x028C, "PERC S100 Controller (PE R410)(0x1028-0x028C)"},
{0x8086, 0x3A25, 0x1028, 0x028D, "PERC S100 Controller (PE T410)(0x1028-0x028D)"},
{0x8086, 0x3A25, 0x1028, 0x02F1, "PERC S100 Controller (PE R510)(0x1028-0x02F1)"},
{0x8086, 0x3A26, 0xFFFF, 0xFFFF, "82801JI (ICH10 Family) 2 port SATA IDE Controller #2(0x3A26)"},
{0x8086, 0x3A26, 0x1028, 0x028C, "PowerEdge R410 SATA IDE Controller(0x1028-0x028C)"},
{0x8086, 0x3A26, 0x1028, 0x028D, "PowerEdge T410 SATA IDE Controller(0x1028-0x028D)"},
{0x8086, 0x3A30, 0xFFFF, 0xFFFF, "82801JI (ICH10 Family) SMBus Controller(0x3A30)"},
{0x8086, 0x3A30, 0x1043, 0x82D4, "P5Q Deluxe Motherboard(0x1043-0x82D4)"},
{0x8086, 0x3A30, 0x1458, 0x5001, "GA-EP45-DS5/GA-EG45M-DS2H Motherboard(0x1458-0x5001)"},
{0x8086, 0x3A32, 0xFFFF, 0xFFFF, "82801JI (ICH10 Family) Thermal Subsystem(0x3A32)"},
{0x8086, 0x3A34, 0xFFFF, 0xFFFF, "82801JI (ICH10 Family) USB UHCI Controller #1(0x3A34)"},
{0x8086, 0x3A34, 0x1028, 0x028C, "PowerEdge R410 USB UHCI Controller(0x1028-0x028C)"},
{0x8086, 0x3A34, 0x1028, 0x028D, "PowerEdge T410 USB UHCI Controller(0x1028-0x028D)"},
{0x8086, 0x3A34, 0x103C, 0x330B, "ProLiant G6 series(0x103C-0x330B)"},
{0x8086, 0x3A34, 0x1043, 0x82D4, "P5Q Deluxe Motherboard(0x1043-0x82D4)"},
{0x8086, 0x3A34, 0x1458, 0x5004, "GA-EP45-DS5 Motherboard(0x1458-0x5004)"},
{0x8086, 0x3A35, 0xFFFF, 0xFFFF, "82801JI (ICH10 Family) USB UHCI Controller #2(0x3A35)"},
{0x8086, 0x3A35, 0x1028, 0x028C, "PowerEdge R410 USB UHCI Controller(0x1028-0x028C)"},
{0x8086, 0x3A35, 0x1028, 0x028D, "PowerEdge T410 USB UHCI Controller(0x1028-0x028D)"},
{0x8086, 0x3A35, 0x103C, 0x330B, "ProLiant G6 series(0x103C-0x330B)"},
{0x8086, 0x3A35, 0x1043, 0x82D4, "P5Q Deluxe Motherboard(0x1043-0x82D4)"},
{0x8086, 0x3A35, 0x1458, 0x5004, "GA-EP45-DS5 Motherboard(0x1458-0x5004)"},
{0x8086, 0x3A36, 0xFFFF, 0xFFFF, "82801JI (ICH10 Family) USB UHCI Controller #3(0x3A36)"},
{0x8086, 0x3A36, 0x1028, 0x028C, "PowerEdge R410 USB UHCI Controller(0x1028-0x028C)"},
{0x8086, 0x3A36, 0x1028, 0x028D, "PowerEdge T410 USB UHCI Controller(0x1028-0x028D)"},
{0x8086, 0x3A36, 0x103C, 0x330B, "ProLiant G6 series(0x103C-0x330B)"},
{0x8086, 0x3A36, 0x1043, 0x82D4, "P5Q Deluxe Motherboard(0x1043-0x82D4)"},
{0x8086, 0x3A36, 0x1458, 0x5004, "GA-EP45-DS5 Motherboard(0x1458-0x5004)"},
{0x8086, 0x3A37, 0xFFFF, 0xFFFF, "82801JI (ICH10 Family) USB UHCI Controller #4(0x3A37)"},
{0x8086, 0x3A37, 0x1028, 0x028C, "PowerEdge R410 USB UHCI Controller(0x1028-0x028C)"},
{0x8086, 0x3A37, 0x1028, 0x028D, "PowerEdge T410 USB UHCI Controller(0x1028-0x028D)"},
{0x8086, 0x3A37, 0x103C, 0x330B, "ProLiant G6 series(0x103C-0x330B)"},
{0x8086, 0x3A37, 0x1043, 0x82D4, "P5Q Deluxe Motherboard(0x1043-0x82D4)"},
{0x8086, 0x3A37, 0x1458, 0x5004, "Motherboard(0x1458-0x5004)"},
{0x8086, 0x3A38, 0xFFFF, 0xFFFF, "82801JI (ICH10 Family) USB UHCI Controller #5(0x3A38)"},
{0x8086, 0x3A38, 0x1028, 0x028C, "PowerEdge R410 USB UHCI Controller(0x1028-0x028C)"},
{0x8086, 0x3A38, 0x1028, 0x028D, "PowerEdge T410 USB UHCI Controller(0x1028-0x028D)"},
{0x8086, 0x3A38, 0x103C, 0x330B, "ProLiant ML150 G6 Server(0x103C-0x330B)"},
{0x8086, 0x3A38, 0x1043, 0x82D4, "P5Q Deluxe Motherboard(0x1043-0x82D4)"},
{0x8086, 0x3A38, 0x1458, 0x5004, "Motherboard(0x1458-0x5004)"},
{0x8086, 0x3A39, 0xFFFF, 0xFFFF, "82801JI (ICH10 Family) USB UHCI Controller #6(0x3A39)"},
{0x8086, 0x3A39, 0x1028, 0x028C, "PowerEdge R410 USB UHCI Controller(0x1028-0x028C)"},
{0x8086, 0x3A39, 0x1028, 0x028D, "PowerEdge T410 USB UHCI Controller(0x1028-0x028D)"},
{0x8086, 0x3A39, 0x103C, 0x330B, "ProLiant ML150 G6 Server(0x103C-0x330B)"},
{0x8086, 0x3A39, 0x1043, 0x82D4, "P5Q Deluxe Motherboard(0x1043-0x82D4)"},
{0x8086, 0x3A39, 0x1458, 0x5004, "Motherboard(0x1458-0x5004)"},
{0x8086, 0x3A3A, 0xFFFF, 0xFFFF, "82801JI (ICH10 Family) USB2 EHCI Controller #1(0x3A3A)"},
{0x8086, 0x3A3A, 0x1028, 0x028C, "PowerEdge R410 USB EHCI Controller(0x1028-0x028C)"},
{0x8086, 0x3A3A, 0x1028, 0x028D, "PowerEdge T410 USB EHCI Controller(0x1028-0x028D)"},
{0x8086, 0x3A3A, 0x103C, 0x330B, "ProLiant G6 series(0x103C-0x330B)"},
{0x8086, 0x3A3A, 0x1043, 0x82D4, "P5Q Deluxe Motherboard(0x1043-0x82D4)"},
{0x8086, 0x3A3A, 0x1458, 0x5006, "GA-EP45-DS5 Motherboard(0x1458-0x5006)"},
{0x8086, 0x3A3C, 0xFFFF, 0xFFFF, "82801JI (ICH10 Family) USB2 EHCI Controller #2(0x3A3C)"},
{0x8086, 0x3A3C, 0x1028, 0x028C, "PowerEdge R410 USB EHCI Controller(0x1028-0x028C)"},
{0x8086, 0x3A3C, 0x1028, 0x028D, "PowerEdge T410 USB EHCI Controller(0x1028-0x028D)"},
{0x8086, 0x3A3C, 0x103C, 0x330B, "ProLiant G6 series(0x103C-0x330B)"},
{0x8086, 0x3A3C, 0x1043, 0x82D4, "P5Q Deluxe Motherboard(0x1043-0x82D4)"},
{0x8086, 0x3A3C, 0x1458, 0x5006, "Motherboard(0x1458-0x5006)"},
{0x8086, 0x3A3E, 0xFFFF, 0xFFFF, "82801JI (ICH10 Family) HD Audio Controller(0x3A3E)"},
{0x8086, 0x3A3E, 0x1043, 0x8311, "P5Q Deluxe Motherboard(0x1043-0x8311)"},
{0x8086, 0x3A3E, 0x1458, 0xA002, "GA-EP45-UD3R Motherboard(0x1458-0xA002)"},
{0x8086, 0x3A3E, 0x1458, 0xA102, "GA-EP45-DS5/GA-EG45M-DS2H Motherboard(0x1458-0xA102)"},
{0x8086, 0x3A40, 0xFFFF, 0xFFFF, "82801JI (ICH10 Family) PCI Express Root Port 1(0x3A40)"},
{0x8086, 0x3A40, 0x1028, 0x028C, "PowerEdge R410 PCI Express Port 1(0x1028-0x028C)"},
{0x8086, 0x3A40, 0x1028, 0x028D, "PowerEdge T410 PCI Express Port 1(0x1028-0x028D)"},
{0x8086, 0x3A40, 0x103C, 0x330B, "ProLiant ML150 G6 Server(0x103C-0x330B)"},
{0x8086, 0x3A40, 0x1043, 0x82D4, "P5Q Deluxe Motherboard(0x1043-0x82D4)"},
{0x8086, 0x3A40, 0x1043, 0x82EA, "P6T DeLuxe Motherboard(0x1043-0x82EA)"},
{0x8086, 0x3A40, 0x1458, 0x5001, "GA-EP45-DS5/GA-EG45M-DS2H Motherboard(0x1458-0x5001)"},
{0x8086, 0x3A42, 0xFFFF, 0xFFFF, "82801JI (ICH10 Family) PCI Express Port 2(0x3A42)"},
{0x8086, 0x3A44, 0xFFFF, 0xFFFF, "82801JI (ICH10 Family) PCI Express Root Port 3(0x3A44)"},
{0x8086, 0x3A44, 0x1043, 0x82EA, "P6T DeLuxe Motherboard(0x1043-0x82EA)"},
{0x8086, 0x3A46, 0xFFFF, 0xFFFF, "82801JI (ICH10 Family) PCI Express Root Port 4(0x3A46)"},
{0x8086, 0x3A46, 0x1043, 0x82EA, "P6T DeLuxe Motherboard(0x1043-0x82EA)"},
{0x8086, 0x3A46, 0x1458, 0x5001, "GA-EP45-DS5 Motherboard(0x1458-0x5001)"},
{0x8086, 0x3A48, 0xFFFF, 0xFFFF, "82801JI (ICH10 Family) PCI Express Root Port 5(0x3A48)"},
{0x8086, 0x3A48, 0x103C, 0x330B, "ProLiant ML150 G6 Server(0x103C-0x330B)"},
{0x8086, 0x3A48, 0x1043, 0x82EA, "P6T Deluxe Motherboard(0x1043-0x82EA)"},
{0x8086, 0x3A48, 0x1458, 0x5001, "GA-EP45-DS5 Motherboard(0x1458-0x5001)"},
{0x8086, 0x3A4A, 0xFFFF, 0xFFFF, "82801JI (ICH10 Family) PCI Express Root Port 6(0x3A4A)"},
{0x8086, 0x3A4A, 0x103C, 0x330B, "ProLiant ML150 G6 Server(0x103C-0x330B)"},
{0x8086, 0x3A4A, 0x1043, 0x82D4, "P5Q Deluxe Motherboard(0x1043-0x82D4)"},
{0x8086, 0x3A4A, 0x1043, 0x82EA, "P6T DeLuxe Motherboard(0x1043-0x82EA)"},
{0x8086, 0x3A4A, 0x1458, 0x5001, "GA-EP45-DS5/GA-EG45M-DS2H Motherboard(0x1458-0x5001)"},
{0x8086, 0x3A4C, 0xFFFF, 0xFFFF, "82801JI (ICH10 Family) Gigabit Ethernet Controller(0x3A4C)"},
{0x8086, 0x3A51, 0xFFFF, 0xFFFF, "82801JDO (ICH10DO) VECI Controller(0x3A51)"},
{0x8086, 0x3A55, 0xFFFF, 0xFFFF, "82801JD/DO (ICH10 Family) Virtual SATA Controller(0x3A55)"},
{0x8086, 0x3A60, 0xFFFF, 0xFFFF, "82801JD/DO (ICH10 Family) SMBus Controller(0x3A60)"},
{0x8086, 0x3A62, 0xFFFF, 0xFFFF, "82801JD/DO (ICH10 Family) Thermal Subsystem(0x3A62)"},
{0x8086, 0x3A64, 0xFFFF, 0xFFFF, "82801JD/DO (ICH10 Family) USB UHCI Controller #1(0x3A64)"},
{0x8086, 0x3A65, 0xFFFF, 0xFFFF, "82801JD/DO (ICH10 Family) USB UHCI Controller #2(0x3A65)"},
{0x8086, 0x3A66, 0xFFFF, 0xFFFF, "82801JD/DO (ICH10 Family) USB UHCI Controller #3(0x3A66)"},
{0x8086, 0x3A67, 0xFFFF, 0xFFFF, "82801JD/DO (ICH10 Family) USB UHCI Controller #4(0x3A67)"},
{0x8086, 0x3A68, 0xFFFF, 0xFFFF, "82801JD/DO (ICH10 Family) USB UHCI Controller #5(0x3A68)"},
{0x8086, 0x3A69, 0xFFFF, 0xFFFF, "82801JD/DO (ICH10 Family) USB UHCI Controller #6(0x3A69)"},
{0x8086, 0x3A6A, 0xFFFF, 0xFFFF, "82801JD/DO (ICH10 Family) USB2 EHCI Controller #1(0x3A6A)"},
{0x8086, 0x3A6C, 0xFFFF, 0xFFFF, "82801JD/DO (ICH10 Family) USB2 EHCI Controller #2(0x3A6C)"},
{0x8086, 0x3A6E, 0xFFFF, 0xFFFF, "82801JD/DO (ICH10 Family) HD Audio Controller(0x3A6E)"},
{0x8086, 0x3A70, 0xFFFF, 0xFFFF, "82801JD/DO (ICH10 Family) PCI Express Port 1(0x3A70)"},
{0x8086, 0x3A72, 0xFFFF, 0xFFFF, "82801JD/DO (ICH10 Family) PCI Express Port 2(0x3A72)"},
{0x8086, 0x3A74, 0xFFFF, 0xFFFF, "82801JD/DO (ICH10 Family) PCI Express Port 3(0x3A74)"},
{0x8086, 0x3A76, 0xFFFF, 0xFFFF, "82801JD/DO (ICH10 Family) PCI Express Port 4(0x3A76)"},
{0x8086, 0x3A78, 0xFFFF, 0xFFFF, "82801JD/DO (ICH10 Family) PCI Express Port 5(0x3A78)"},
{0x8086, 0x3A7A, 0xFFFF, 0xFFFF, "82801JD/DO (ICH10 Family) PCI Express Port 6(0x3A7A)"},
{0x8086, 0x3A7C, 0xFFFF, 0xFFFF, "82801JD/DO (ICH10 Family) Gigabit Ethernet Controller(0x3A7C)"},
{0x8086, 0x3B00, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset LPC Interface Controller(0x3B00)"},
{0x8086, 0x3B01, 0xFFFF, 0xFFFF, "Mobile 5 Series Chipset LPC Interface Controller(0x3B01)"},
{0x8086, 0x3B02, 0xFFFF, 0xFFFF, "P55 Chipset LPC Interface Controller(0x3B02)"},
{0x8086, 0x3B03, 0xFFFF, 0xFFFF, "PM55 Chipset LPC Interface Controller(0x3B03)"},
{0x8086, 0x3B04, 0xFFFF, 0xFFFF, "5 Series Chipset LPC Interface Controller(0x3B04)"},
{0x8086, 0x3B05, 0xFFFF, 0xFFFF, "Mobile 5 Series Chipset LPC Interface Controller(0x3B05)"},
{0x8086, 0x3B06, 0xFFFF, 0xFFFF, "H55 Chipset LPC Interface Controller(0x3B06)"},
{0x8086, 0x3B07, 0xFFFF, 0xFFFF, "QM57 Chipset LPC Interface Controller(0x3B07)"},
{0x8086, 0x3B07, 0x1028, 0x040A, "Latitude E6410(0x1028-0x040A)"},
{0x8086, 0x3B07, 0x1028, 0x040B, "Latitude E6510(0x1028-0x040B)"},
{0x8086, 0x3B07, 0xE4BF, 0x50C1, "PC1-GROOVE(0xE4BF-0x50C1)"},
{0x8086, 0x3B08, 0xFFFF, 0xFFFF, "H57 Chipset LPC Interface Controller(0x3B08)"},
{0x8086, 0x3B09, 0xFFFF, 0xFFFF, "HM55 Chipset LPC Interface Controller(0x3B09)"},
{0x8086, 0x3B09, 0x1025, 0x0347, "Aspire 7740G(0x1025-0x0347)"},
{0x8086, 0x3B09, 0x144D, 0xC06A, "R730 Laptop(0x144D-0xC06A)"},
{0x8086, 0x3B09, 0x17C0, 0x10D2, "Medion Akoya E7214 Notebook PC [MD98410](0x17C0-0x10D2)"},
{0x8086, 0x3B0A, 0xFFFF, 0xFFFF, "Q57 Chipset LPC Interface Controller(0x3B0A)"},
{0x8086, 0x3B0A, 0x1028, 0x02DA, "OptiPlex 980(0x1028-0x02DA)"},
{0x8086, 0x3B0A, 0x15D9, 0x060D, "C7SIM-Q Motherboard(0x15D9-0x060D)"},
{0x8086, 0x3B0B, 0xFFFF, 0xFFFF, "HM57 Chipset LPC Interface Controller(0x3B0B)"},
{0x8086, 0x3B0C, 0xFFFF, 0xFFFF, "5 Series Chipset LPC Interface Controller(0x3B0C)"},
{0x8086, 0x3B0D, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset LPC Interface Controller(0x3B0D)"},
{0x8086, 0x3B0E, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset LPC Interface Controller(0x3B0E)"},
{0x8086, 0x3B0F, 0xFFFF, 0xFFFF, "QS57 Chipset LPC Interface Controller(0x3B0F)"},
{0x8086, 0x3B10, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset LPC Interface Controller(0x3B10)"},
{0x8086, 0x3B11, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset LPC Interface Controller(0x3B11)"},
{0x8086, 0x3B12, 0xFFFF, 0xFFFF, "3400 Series Chipset LPC Interface Controller(0x3B12)"},
{0x8086, 0x3B13, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset LPC Interface Controller(0x3B13)"},
{0x8086, 0x3B14, 0xFFFF, 0xFFFF, "3420 Chipset LPC Interface Controller(0x3B14)"},
{0x8086, 0x3B14, 0x15D9, 0x0605, "X8SIL(0x15D9-0x0605)"},
{0x8086, 0x3B15, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset LPC Interface Controller(0x3B15)"},
{0x8086, 0x3B16, 0xFFFF, 0xFFFF, "3450 Chipset LPC Interface Controller(0x3B16)"},
{0x8086, 0x3B17, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset LPC Interface Controller(0x3B17)"},
{0x8086, 0x3B18, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset LPC Interface Controller(0x3B18)"},
{0x8086, 0x3B19, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset LPC Interface Controller(0x3B19)"},
{0x8086, 0x3B1A, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset LPC Interface Controller(0x3B1A)"},
{0x8086, 0x3B1B, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset LPC Interface Controller(0x3B1B)"},
{0x8086, 0x3B1C, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset LPC Interface Controller(0x3B1C)"},
{0x8086, 0x3B1D, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset LPC Interface Controller(0x3B1D)"},
{0x8086, 0x3B1E, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset LPC Interface Controller(0x3B1E)"},
{0x8086, 0x3B1F, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset LPC Interface Controller(0x3B1F)"},
{0x8086, 0x3B20, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset 4 port SATA IDE Controller(0x3B20)"},
{0x8086, 0x3B21, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset 2 port SATA IDE Controller(0x3B21)"},
{0x8086, 0x3B22, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset 6 port SATA AHCI Controller(0x3B22)"},
{0x8086, 0x3B22, 0x1028, 0x02DA, "OptiPlex 980(0x1028-0x02DA)"},
{0x8086, 0x3B22, 0x15D9, 0x0605, "X8SIL(0x15D9-0x0605)"},
{0x8086, 0x3B22, 0x15D9, 0x060D, "C7SIM-Q Motherboard(0x15D9-0x060D)"},
{0x8086, 0x3B23, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset 4 port SATA AHCI Controller(0x3B23)"},
{0x8086, 0x3B25, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset SATA RAID Controller(0x3B25)"},
{0x8086, 0x3B25, 0x103C, 0x3118, "Smart Array B110i SATA RAID Controller(0x103C-0x3118)"},
{0x8086, 0x3B26, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset 2 port SATA IDE Controller(0x3B26)"},
{0x8086, 0x3B28, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset 4 port SATA IDE Controller(0x3B28)"},
{0x8086, 0x3B28, 0x144D, 0xC06A, "R730 Laptop(0x144D-0xC06A)"},
{0x8086, 0x3B28, 0x17C0, 0x10D2, "Medion Akoya E7214 Notebook PC [MD98410](0x17C0-0x10D2)"},
{0x8086, 0x3B29, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset 4 port SATA AHCI Controller(0x3B29)"},
{0x8086, 0x3B29, 0x1025, 0x0347, "Aspire 7740G(0x1025-0x0347)"},
{0x8086, 0x3B29, 0x144D, 0xC06A, "R730 Laptop(0x144D-0xC06A)"},
{0x8086, 0x3B29, 0x17C0, 0x10D2, "Medion Akoya E7214 Notebook PC [MD98410](0x17C0-0x10D2)"},
{0x8086, 0x3B2C, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset SATA RAID Controller(0x3B2C)"},
{0x8086, 0x3B2D, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset 2 port SATA IDE Controller(0x3B2D)"},
{0x8086, 0x3B2D, 0x144D, 0xC06A, "R730 Laptop(0x144D-0xC06A)"},
{0x8086, 0x3B2D, 0x17C0, 0x10D2, "Medion Akoya E7214 Notebook PC [MD98410](0x17C0-0x10D2)"},
{0x8086, 0x3B2D, 0xE4BF, 0x50C1, "PC1-GROOVE(0xE4BF-0x50C1)"},
{0x8086, 0x3B2E, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset 4 port SATA IDE Controller(0x3B2E)"},
{0x8086, 0x3B2E, 0xE4BF, 0x50C1, "PC1-GROOVE(0xE4BF-0x50C1)"},
{0x8086, 0x3B2F, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset 6 port SATA AHCI Controller(0x3B2F)"},
{0x8086, 0x3B2F, 0x1028, 0x040A, "Latitude E6410(0x1028-0x040A)"},
{0x8086, 0x3B2F, 0x1028, 0x040B, "Latitude E6510(0x1028-0x040B)"},
{0x8086, 0x3B2F, 0xE4BF, 0x50C1, "PC1-GROOVE(0xE4BF-0x50C1)"},
{0x8086, 0x3B30, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset SMBus Controller(0x3B30)"},
{0x8086, 0x3B30, 0x1025, 0x0347, "Aspire 7740G(0x1025-0x0347)"},
{0x8086, 0x3B30, 0x1028, 0x02DA, "OptiPlex 980(0x1028-0x02DA)"},
{0x8086, 0x3B30, 0x1028, 0x040A, "Latitude E6410(0x1028-0x040A)"},
{0x8086, 0x3B30, 0x1028, 0x040B, "Latitude E6510(0x1028-0x040B)"},
{0x8086, 0x3B30, 0x1043, 0x3838, "P7P55-M Motherboard(0x1043-0x3838)"},
{0x8086, 0x3B30, 0x1043, 0x8383, "P7P55-M Motherboard(0x1043-0x8383)"},
{0x8086, 0x3B30, 0x144D, 0xC06A, "R730 Laptop(0x144D-0xC06A)"},
{0x8086, 0x3B30, 0x15D9, 0x0605, "X8SIL(0x15D9-0x0605)"},
{0x8086, 0x3B30, 0x15D9, 0x060D, "C7SIM-Q Motherboard(0x15D9-0x060D)"},
{0x8086, 0x3B30, 0x17C0, 0x10D2, "Medion Akoya E7214 Notebook PC [MD98410](0x17C0-0x10D2)"},
{0x8086, 0x3B30, 0xE4BF, 0x50C1, "PC1-GROOVE(0xE4BF-0x50C1)"},
{0x8086, 0x3B32, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset Thermal Subsystem(0x3B32)"},
{0x8086, 0x3B32, 0x1025, 0x0347, "Aspire 7740G(0x1025-0x0347)"},
{0x8086, 0x3B32, 0x1028, 0x040A, "Latitude E6410(0x1028-0x040A)"},
{0x8086, 0x3B32, 0x144D, 0xC06A, "R730 Laptop(0x144D-0xC06A)"},
{0x8086, 0x3B32, 0x17C0, 0x10D2, "Medion Akoya E7214 Notebook PC [MD98410](0x17C0-0x10D2)"},
{0x8086, 0x3B34, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset USB2 Enhanced Host Controller(0x3B34)"},
{0x8086, 0x3B34, 0x1025, 0x0347, "Aspire 7740G(0x1025-0x0347)"},
{0x8086, 0x3B34, 0x1028, 0x02DA, "OptiPlex 980(0x1028-0x02DA)"},
{0x8086, 0x3B34, 0x1028, 0x040A, "Latitude E6410(0x1028-0x040A)"},
{0x8086, 0x3B34, 0x1028, 0x040B, "Latitude E6510(0x1028-0x040B)"},
{0x8086, 0x3B34, 0x144D, 0xC06A, "R730 Laptop(0x144D-0xC06A)"},
{0x8086, 0x3B34, 0x15D9, 0x0605, "X8SIL(0x15D9-0x0605)"},
{0x8086, 0x3B34, 0x15D9, 0x060D, "C7SIM-Q Motherboard(0x15D9-0x060D)"},
{0x8086, 0x3B34, 0x17C0, 0x10D2, "Medion Akoya E7214 Notebook PC [MD98410](0x17C0-0x10D2)"},
{0x8086, 0x3B34, 0xE4BF, 0x50C1, "PC1-GROOVE(0xE4BF-0x50C1)"},
{0x8086, 0x3B36, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset USB Universal Host Controller(0x3B36)"},
{0x8086, 0x3B37, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset USB Universal Host Controller(0x3B37)"},
{0x8086, 0x3B38, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset USB Universal Host Controller(0x3B38)"},
{0x8086, 0x3B39, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset USB Universal Host Controller(0x3B39)"},
{0x8086, 0x3B3A, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset USB Universal Host Controller(0x3B3A)"},
{0x8086, 0x3B3B, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset USB Universal Host Controller(0x3B3B)"},
{0x8086, 0x3B3C, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset USB2 Enhanced Host Controller(0x3B3C)"},
{0x8086, 0x3B3C, 0x1025, 0x0347, "Aspire 7740G(0x1025-0x0347)"},
{0x8086, 0x3B3C, 0x1028, 0x02DA, "OptiPlex 980(0x1028-0x02DA)"},
{0x8086, 0x3B3C, 0x1028, 0x040A, "Latitude E6410(0x1028-0x040A)"},
{0x8086, 0x3B3C, 0x1028, 0x040B, "Latitude E6510(0x1028-0x040B)"},
{0x8086, 0x3B3C, 0x144D, 0xC06A, "R730 Laptop(0x144D-0xC06A)"},
{0x8086, 0x3B3C, 0x15D9, 0x0605, "X8SIL(0x15D9-0x0605)"},
{0x8086, 0x3B3C, 0x15D9, 0x060D, "C7SIM-Q Motherboard(0x15D9-0x060D)"},
{0x8086, 0x3B3C, 0x17C0, 0x10D2, "Medion Akoya E7214 Notebook PC [MD98410](0x17C0-0x10D2)"},
{0x8086, 0x3B3C, 0xE4BF, 0x50C1, "PC1-GROOVE(0xE4BF-0x50C1)"},
{0x8086, 0x3B3E, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset USB Universal Host Controller(0x3B3E)"},
{0x8086, 0x3B3F, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset USB Universal Host Controller(0x3B3F)"},
{0x8086, 0x3B40, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset USB Universal Host Controller(0x3B40)"},
{0x8086, 0x3B41, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset LAN Controller(0x3B41)"},
{0x8086, 0x3B42, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset PCI Express Root Port 1(0x3B42)"},
{0x8086, 0x3B42, 0x1028, 0x02DA, "OptiPlex 980(0x1028-0x02DA)"},
{0x8086, 0x3B42, 0x1028, 0x040A, "Latitude E6410(0x1028-0x040A)"},
{0x8086, 0x3B42, 0x1028, 0x040B, "Latitude E6510(0x1028-0x040B)"},
{0x8086, 0x3B42, 0x103C, 0x1521, "EliteBook 8540p(0x103C-0x1521)"},
{0x8086, 0x3B42, 0x144D, 0xC06A, "R730 Laptop(0x144D-0xC06A)"},
{0x8086, 0x3B42, 0x15D9, 0x060D, "C7SIM-Q Motherboard(0x15D9-0x060D)"},
{0x8086, 0x3B42, 0x17C0, 0x10D2, "Medion Akoya E7214 Notebook PC [MD98410](0x17C0-0x10D2)"},
{0x8086, 0x3B44, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset PCI Express Root Port 2(0x3B44)"},
{0x8086, 0x3B44, 0x1028, 0x040A, "Latitude E6410(0x1028-0x040A)"},
{0x8086, 0x3B44, 0x1028, 0x040B, "Latitude E6510(0x1028-0x040B)"},
{0x8086, 0x3B44, 0x15D9, 0x060D, "C7SIM-Q Motherboard(0x15D9-0x060D)"},
{0x8086, 0x3B44, 0x17C0, 0x10D2, "Medion Akoya E7214 Notebook PC [MD98410](0x17C0-0x10D2)"},
{0x8086, 0x3B46, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset PCI Express Root Port 3(0x3B46)"},
{0x8086, 0x3B46, 0x1028, 0x040A, "Latitude E6410(0x1028-0x040A)"},
{0x8086, 0x3B46, 0x1028, 0x040B, "Latitude E6510(0x1028-0x040B)"},
{0x8086, 0x3B46, 0x144D, 0xC06A, "R730 Laptop(0x144D-0xC06A)"},
{0x8086, 0x3B46, 0x17C0, 0x10D2, "Medion Akoya E7214 Notebook PC [MD98410](0x17C0-0x10D2)"},
{0x8086, 0x3B48, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset PCI Express Root Port 4(0x3B48)"},
{0x8086, 0x3B48, 0x1028, 0x040A, "Latitude E6410(0x1028-0x040A)"},
{0x8086, 0x3B48, 0x1028, 0x040B, "Latitude E6510(0x1028-0x040B)"},
{0x8086, 0x3B48, 0x144D, 0xC06A, "R730 Laptop(0x144D-0xC06A)"},
{0x8086, 0x3B4A, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset PCI Express Root Port 5(0x3B4A)"},
{0x8086, 0x3B4A, 0x1028, 0x02DA, "OptiPlex 980(0x1028-0x02DA)"},
{0x8086, 0x3B4A, 0x17C0, 0x10D2, "Medion Akoya E7214 Notebook PC [MD98410](0x17C0-0x10D2)"},
{0x8086, 0x3B4C, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset PCI Express Root Port 6(0x3B4C)"},
{0x8086, 0x3B4E, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset PCI Express Root Port 7(0x3B4E)"},
{0x8086, 0x3B50, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset PCI Express Root Port 8(0x3B50)"},
{0x8086, 0x3B53, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset VECI Controller(0x3B53)"},
{0x8086, 0x3B56, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset High Definition Audio(0x3B56)"},
{0x8086, 0x3B56, 0x1025, 0x0347, "Aspire 7740G(0x1025-0x0347)"},
{0x8086, 0x3B56, 0x1028, 0x02DA, "OptiPlex 980(0x1028-0x02DA)"},
{0x8086, 0x3B56, 0x1028, 0x040A, "Latitude E6410(0x1028-0x040A)"},
{0x8086, 0x3B56, 0x1028, 0x040B, "Latitude E6510(0x1028-0x040B)"},
{0x8086, 0x3B56, 0x1043, 0x1373, "G73-series gaming laptop(0x1043-0x1373)"},
{0x8086, 0x3B56, 0x144D, 0xC06A, "R730 Laptop(0x144D-0xC06A)"},
{0x8086, 0x3B56, 0x15D9, 0x060D, "C7SIM-Q Motherboard(0x15D9-0x060D)"},
{0x8086, 0x3B56, 0x17C0, 0x10D2, "Medion Akoya E7214 Notebook PC [MD98410](0x17C0-0x10D2)"},
{0x8086, 0x3B56, 0xE4BF, 0x50C1, "PC1-GROOVE(0xE4BF-0x50C1)"},
{0x8086, 0x3B57, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset High Definition Audio(0x3B57)"},
{0x8086, 0x3B64, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset HECI Controller(0x3B64)"},
{0x8086, 0x3B64, 0x1025, 0x0347, "Aspire 7740G(0x1025-0x0347)"},
{0x8086, 0x3B64, 0x15D9, 0x060D, "C7SIM-Q Motherboard(0x15D9-0x060D)"},
{0x8086, 0x3B64, 0x17C0, 0x10D2, "Medion Akoya E7214 Notebook PC [MD98410](0x17C0-0x10D2)"},
{0x8086, 0x3B64, 0xE4BF, 0x50C1, "PC1-GROOVE(0xE4BF-0x50C1)"},
{0x8086, 0x3B65, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset HECI Controller(0x3B65)"},
{0x8086, 0x3B66, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset PT IDER Controller(0x3B66)"},
{0x8086, 0x3B67, 0xFFFF, 0xFFFF, "5 Series/3400 Series Chipset KT Controller(0x3B67)"},
{0x8086, 0x3B67, 0xE4BF, 0x50C1, "PC1-GROOVE(0xE4BF-0x50C1)"},
{0x8086, 0x3C00, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 DMI2(0x3C00)"},
{0x8086, 0x3C01, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 DMI2 in PCI Express Mode(0x3C01)"},
{0x8086, 0x3C02, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 IIO PCI Express Root Port 1a(0x3C02)"},
{0x8086, 0x3C03, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 IIO PCI Express Root Port 1b(0x3C03)"},
{0x8086, 0x3C04, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 IIO PCI Express Root Port 2a(0x3C04)"},
{0x8086, 0x3C05, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 IIO PCI Express Root Port 2b(0x3C05)"},
{0x8086, 0x3C06, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 IIO PCI Express Root Port 2c(0x3C06)"},
{0x8086, 0x3C07, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 IIO PCI Express Root Port 2d(0x3C07)"},
{0x8086, 0x3C08, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 IIO PCI Express Root Port 3a in PCI Express Mode(0x3C08)"},
{0x8086, 0x3C09, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 IIO PCI Express Root Port 3b(0x3C09)"},
{0x8086, 0x3C0A, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 IIO PCI Express Root Port 3c(0x3C0A)"},
{0x8086, 0x3C0B, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 IIO PCI Express Root Port 3d(0x3C0B)"},
{0x8086, 0x3C0D, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 Non-Transparent Bridge(0x3C0D)"},
{0x8086, 0x3C0E, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 Non-Transparent Bridge(0x3C0E)"},
{0x8086, 0x3C0F, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 Non-Transparent Bridge(0x3C0F)"},
{0x8086, 0x3C20, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 DMA Channel 0(0x3C20)"},
{0x8086, 0x3C21, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 DMA Channel 1(0x3C21)"},
{0x8086, 0x3C22, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 DMA Channel 2(0x3C22)"},
{0x8086, 0x3C23, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 DMA Channel 3(0x3C23)"},
{0x8086, 0x3C24, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 DMA Channel 4(0x3C24)"},
{0x8086, 0x3C25, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 DMA Channel 5(0x3C25)"},
{0x8086, 0x3C26, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 DMA Channel 6(0x3C26)"},
{0x8086, 0x3C27, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 DMA Channel 7(0x3C27)"},
{0x8086, 0x3C28, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 Address Map, VTd_Misc, System Management(0x3C28)"},
{0x8086, 0x3C2A, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 Control Status and Global Errors(0x3C2A)"},
{0x8086, 0x3C2C, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 I/O APIC(0x3C2C)"},
{0x8086, 0x3C2E, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 DMA(0x3C2E)"},
{0x8086, 0x3C2F, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 DMA(0x3C2F)"},
{0x8086, 0x3C40, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 IIO Switch and IRP Performance Monitor(0x3C40)"},
{0x8086, 0x3C43, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 Ring to PCI Express Performance Monitor(0x3C43)"},
{0x8086, 0x3C44, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 Ring to QuickPath Interconnect Link 0 Performance Monitor(0x3C44)"},
{0x8086, 0x3C45, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 Ring to QuickPath Interconnect Link 1 Performance Monitor(0x3C45)"},
{0x8086, 0x3C46, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 Processor Home Agent Performance Monitoring(0x3C46)"},
{0x8086, 0x3C71, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 Integrated Memory Controller RAS Registers(0x3C71)"},
{0x8086, 0x3C80, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 QPI Link 0(0x3C80)"},
{0x8086, 0x3C83, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 QPI Link Reut 0(0x3C83)"},
{0x8086, 0x3C84, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 QPI Link Reut 0(0x3C84)"},
{0x8086, 0x3C90, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 QPI Link 1(0x3C90)"},
{0x8086, 0x3C93, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 QPI Link Reut 1(0x3C93)"},
{0x8086, 0x3C94, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 QPI Link Reut 1(0x3C94)"},
{0x8086, 0x3CA0, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 Processor Home Agent(0x3CA0)"},
{0x8086, 0x3CA8, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 Integrated Memory Controller Registers(0x3CA8)"},
{0x8086, 0x3CAA, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 Integrated Memory Controller Target Address Decoder 0(0x3CAA)"},
{0x8086, 0x3CAB, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 Integrated Memory Controller Target Address Decoder 1(0x3CAB)"},
{0x8086, 0x3CAC, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 Integrated Memory Controller Target Address Decoder 2(0x3CAC)"},
{0x8086, 0x3CAD, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 Integrated Memory Controller Target Address Decoder 3(0x3CAD)"},
{0x8086, 0x3CAE, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 Integrated Memory Controller Target Address Decoder 4(0x3CAE)"},
{0x8086, 0x3CB0, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 Integrated Memory Controller Channel 0-3 Thermal Control 0(0x3CB0)"},
{0x8086, 0x3CB1, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 Integrated Memory Controller Channel 0-3 Thermal Control 1(0x3CB1)"},
{0x8086, 0x3CB2, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 Integrated Memory Controller ERROR Registers 0(0x3CB2)"},
{0x8086, 0x3CB3, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 Integrated Memory Controller ERROR Registers 1(0x3CB3)"},
{0x8086, 0x3CB4, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 Integrated Memory Controller Channel 0-3 Thermal Control 2(0x3CB4)"},
{0x8086, 0x3CB5, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 Integrated Memory Controller Channel 0-3 Thermal Control 3(0x3CB5)"},
{0x8086, 0x3CB6, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 Integrated Memory Controller ERROR Registers 2(0x3CB6)"},
{0x8086, 0x3CB7, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 Integrated Memory Controller ERROR Registers 3(0x3CB7)"},
{0x8086, 0x3CB8, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 DDRIO(0x3CB8)"},
{0x8086, 0x3CC0, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 Power Control Unit 0(0x3CC0)"},
{0x8086, 0x3CC1, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 Power Control Unit 1(0x3CC1)"},
{0x8086, 0x3CC2, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 Power Control Unit 2(0x3CC2)"},
{0x8086, 0x3CD0, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 Power Control Unit 3(0x3CD0)"},
{0x8086, 0x3CE0, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 Interrupt Control Registers(0x3CE0)"},
{0x8086, 0x3CE3, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 Semaphore and Scratchpad Configuration Registers(0x3CE3)"},
{0x8086, 0x3CE4, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 R2PCIe(0x3CE4)"},
{0x8086, 0x3CE6, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 QuickPath Interconnect Agent Ring Registers(0x3CE6)"},
{0x8086, 0x3CE8, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 Unicast Register 0(0x3CE8)"},
{0x8086, 0x3CE9, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 Unicast Register 5(0x3CE9)"},
{0x8086, 0x3CEA, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 Unicast Register 1(0x3CEA)"},
{0x8086, 0x3CEB, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 Unicast Register 6(0x3CEB)"},
{0x8086, 0x3CEC, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 Unicast Register 3(0x3CEC)"},
{0x8086, 0x3CED, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 Unicast Register 7(0x3CED)"},
{0x8086, 0x3CEE, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 Unicast Register 4(0x3CEE)"},
{0x8086, 0x3CEF, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 Unicast Register 8(0x3CEF)"},
{0x8086, 0x3CF4, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 Integrated Memory Controller System Address Decoder 0(0x3CF4)"},
{0x8086, 0x3CF5, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 Integrated Memory Controller System Address Decoder 1(0x3CF5)"},
{0x8086, 0x3CF6, 0xFFFF, 0xFFFF, "Xeon E5/Core i7 System Address Decoder(0x3CF6)"},
{0x8086, 0x3E10, 0xFFFF, 0xFFFF, "8th Gen Core 4-core Processor Host Bridge/DRAM Registers [Coffee Lake H](0x3E10)"},
{0x8086, 0x3E18, 0xFFFF, 0xFFFF, "8th Gen Core 4-core Workstation Processor Host Bridge/DRAM Registers [Coffee Lake S](0x3E18)"},
{0x8086, 0x3E1F, 0xFFFF, 0xFFFF, "8th Gen Core 4-core Desktop Processor Host Bridge/DRAM Registers [Coffee Lake S](0x3E1F)"},
{0x8086, 0x3E1F, 0x1458, 0x5000, "Z370 AORUS Gaming K3-CF(0x1458-0x5000)"},
{0x8086, 0x3E30, 0xFFFF, 0xFFFF, "8th/9th Gen Core 8-core Desktop Processor Host Bridge/DRAM Registers [Coffee Lake S](0x3E30)"},
{0x8086, 0x3E33, 0xFFFF, 0xFFFF, "8th/9th Gen Core Processor Host Bridge/DRAM Registers [Coffee Lake](0x3E33)"},
{0x8086, 0x3E34, 0xFFFF, 0xFFFF, "Coffee Lake HOST and DRAM Controller(0x3E34)"},
{0x8086, 0x3E35, 0xFFFF, 0xFFFF, "Coffee Lake Host Bridge/DRAM Registers(0x3E35)"},
{0x8086, 0x3E81, 0xFFFF, 0xFFFF, "8th Gen Core Processor PCIe Controller (x16)(0x3E81)"},
{0x8086, 0x3E85, 0xFFFF, 0xFFFF, "8th Gen Core Processor PCIe Controller (x8)(0x3E85)"},
{0x8086, 0x3E89, 0xFFFF, 0xFFFF, "8th Gen Core Processor PCIe Controller (x4)(0x3E89)"},
{0x8086, 0x3E90, 0xFFFF, 0xFFFF, "CoffeeLake-S GT1 [UHD Graphics 610](0x3E90)"},
{0x8086, 0x3E91, 0xFFFF, 0xFFFF, "CoffeeLake-S GT2 [UHD Graphics 630](0x3E91)"},
{0x8086, 0x3E92, 0xFFFF, 0xFFFF, "CoffeeLake-S GT2 [UHD Graphics 630](0x3E92)"},
{0x8086, 0x3E92, 0x1028, 0x0869, "Vostro 3470(0x1028-0x0869)"},
{0x8086, 0x3E93, 0xFFFF, 0xFFFF, "CoffeeLake-S GT1 [UHD Graphics 610](0x3E93)"},
{0x8086, 0x3E94, 0xFFFF, 0xFFFF, "Coffee Lake-S GT2 [UHD Graphics P630](0x3E94)"},
{0x8086, 0x3E96, 0xFFFF, 0xFFFF, "CoffeeLake-S GT2 [UHD Graphics P630](0x3E96)"},
{0x8086, 0x3E98, 0xFFFF, 0xFFFF, "CoffeeLake-S GT2 [UHD Graphics 630](0x3E98)"},
{0x8086, 0x3E9A, 0xFFFF, 0xFFFF, "Coffee Lake-S GT2 [UHD Graphics P630](0x3E9A)"},
{0x8086, 0x3E9B, 0xFFFF, 0xFFFF, "CoffeeLake-H GT2 [UHD Graphics 630](0x3E9B)"},
{0x8086, 0x3E9C, 0xFFFF, 0xFFFF, "Coffee Lake-S GT1 [UHD Graphics 610](0x3E9C)"},
{0x8086, 0x3EA0, 0xFFFF, 0xFFFF, "WhiskeyLake-U GT2 [UHD Graphics 620](0x3EA0)"},
{0x8086, 0x3EA0, 0x1028, 0x089E, "Inspiron 5482(0x1028-0x089E)"},
{0x8086, 0x3EA1, 0xFFFF, 0xFFFF, "Whiskey Lake-U GT1 [UHD Graphics 610](0x3EA1)"},
{0x8086, 0x3EA5, 0xFFFF, 0xFFFF, "CoffeeLake-U GT3e [Iris Plus Graphics 655](0x3EA5)"},
{0x8086, 0x3EA6, 0xFFFF, 0xFFFF, "Coffee Lake-U GT3 [Iris Plus Graphics 645](0x3EA6)"},
{0x8086, 0x3EA8, 0xFFFF, 0xFFFF, "Coffee Lake-U GT3 [Iris Plus Graphics 655](0x3EA8)"},
{0x8086, 0x3EA9, 0xFFFF, 0xFFFF, "Coffee Lake-U GT2 [UHD Graphics 620](0x3EA9)"},
{0x8086, 0x3EC2, 0xFFFF, 0xFFFF, "8th Gen Core Processor Host Bridge/DRAM Registers(0x3EC2)"},
{0x8086, 0x3EC2, 0x1028, 0x0869, "Vostro 3470(0x1028-0x0869)"},
{0x8086, 0x3EC2, 0x1043, 0x8694, "PRIME H310M-D(0x1043-0x8694)"},
{0x8086, 0x3EC4, 0xFFFF, 0xFFFF, "8th Gen Core Processor Host Bridge/DRAM Registers(0x3EC4)"},
{0x8086, 0x3EC6, 0xFFFF, 0xFFFF, "8th Gen Core Processor Host Bridge/DRAM Registers(0x3EC6)"},
{0x8086, 0x3ECA, 0xFFFF, 0xFFFF, "8th Gen Core Processor Host Bridge/DRAM Registers(0x3ECA)"},
{0x8086, 0x3ED0, 0xFFFF, 0xFFFF, "8th Gen Core Processor Host Bridge/DRAM Registers(0x3ED0)"},
{0x8086, 0x4000, 0xFFFF, 0xFFFF, "5400 Chipset Memory Controller Hub(0x4000)"},
{0x8086, 0x4001, 0xFFFF, 0xFFFF, "5400 Chipset Memory Controller Hub(0x4001)"},
{0x8086, 0x4003, 0xFFFF, 0xFFFF, "5400 Chipset Memory Controller Hub(0x4003)"},
{0x8086, 0x4021, 0xFFFF, 0xFFFF, "5400 Chipset PCI Express Port 1(0x4021)"},
{0x8086, 0x4022, 0xFFFF, 0xFFFF, "5400 Chipset PCI Express Port 2(0x4022)"},
{0x8086, 0x4023, 0xFFFF, 0xFFFF, "5400 Chipset PCI Express Port 3(0x4023)"},
{0x8086, 0x4024, 0xFFFF, 0xFFFF, "5400 Chipset PCI Express Port 4(0x4024)"},
{0x8086, 0x4025, 0xFFFF, 0xFFFF, "5400 Chipset PCI Express Port 5(0x4025)"},
{0x8086, 0x4026, 0xFFFF, 0xFFFF, "5400 Chipset PCI Express Port 6(0x4026)"},
{0x8086, 0x4027, 0xFFFF, 0xFFFF, "5400 Chipset PCI Express Port 7(0x4027)"},
{0x8086, 0x4028, 0xFFFF, 0xFFFF, "5400 Chipset PCI Express Port 8(0x4028)"},
{0x8086, 0x4029, 0xFFFF, 0xFFFF, "5400 Chipset PCI Express Port 9(0x4029)"},
{0x8086, 0x402D, 0xFFFF, 0xFFFF, "5400 Chipset IBIST Registers(0x402D)"},
{0x8086, 0x402E, 0xFFFF, 0xFFFF, "5400 Chipset IBIST Registers(0x402E)"},
{0x8086, 0x402F, 0xFFFF, 0xFFFF, "5400 Chipset QuickData Technology Device(0x402F)"},
{0x8086, 0x4030, 0xFFFF, 0xFFFF, "5400 Chipset FSB Registers(0x4030)"},
{0x8086, 0x4031, 0xFFFF, 0xFFFF, "5400 Chipset CE/SF Registers(0x4031)"},
{0x8086, 0x4032, 0xFFFF, 0xFFFF, "5400 Chipset IOxAPIC(0x4032)"},
{0x8086, 0x4035, 0xFFFF, 0xFFFF, "5400 Chipset FBD Registers(0x4035)"},
{0x8086, 0x4036, 0xFFFF, 0xFFFF, "5400 Chipset FBD Registers(0x4036)"},
{0x8086, 0x4041, 0xFFFF, 0xFFFF, "NVMe Datacenter SSD [Optane](0x4041)"},
{0x8086, 0x4100, 0xFFFF, 0xFFFF, "Moorestown Graphics and Video(0x4100)"},
{0x8086, 0x4108, 0xFFFF, 0xFFFF, "Atom Processor E6xx Integrated Graphics Controller(0x4108)"},
{0x8086, 0x4109, 0xFFFF, 0xFFFF, "Atom Processor E6xx Integrated Graphics Controller(0x4109)"},
{0x8086, 0x410A, 0xFFFF, 0xFFFF, "Atom Processor E6xx Integrated Graphics Controller(0x410A)"},
{0x8086, 0x410B, 0xFFFF, 0xFFFF, "Atom Processor E6xx Integrated Graphics Controller(0x410B)"},
{0x8086, 0x410C, 0xFFFF, 0xFFFF, "Atom Processor E6xx Integrated Graphics Controller(0x410C)"},
{0x8086, 0x410D, 0xFFFF, 0xFFFF, "Atom Processor E6xx Integrated Graphics Controller(0x410D)"},
{0x8086, 0x410E, 0xFFFF, 0xFFFF, "Atom Processor E6xx Integrated Graphics Controller(0x410E)"},
{0x8086, 0x410F, 0xFFFF, 0xFFFF, "Atom Processor E6xx Integrated Graphics Controller(0x410F)"},
{0x8086, 0x4114, 0xFFFF, 0xFFFF, "Atom Processor E6xx PCI Host Bridge #1(0x4114)"},
{0x8086, 0x4115, 0xFFFF, 0xFFFF, "Atom Processor E6xx PCI Host Bridge #2(0x4115)"},
{0x8086, 0x4116, 0xFFFF, 0xFFFF, "Atom Processor E6xx PCI Host Bridge #3(0x4116)"},
{0x8086, 0x4117, 0xFFFF, 0xFFFF, "Atom Processor E6xx PCI Host Bridge #4(0x4117)"},
{0x8086, 0x4140, 0xFFFF, 0xFFFF, "NVMe Datacenter SSD [Optane](0x4140)"},
{0x8086, 0x4140, 0x1028, 0x2134, "NVMe Datacenter SSD [Optane] SED 400GB 2.5\" U.2 (P5800X)(0x1028-0x2134)"},
{0x8086, 0x4140, 0x1028, 0x2135, "NVMe Datacenter SSD [Optane] SED 800GB 2.5\" U.2 (P5800X)(0x1028-0x2135)"},
{0x8086, 0x4140, 0x1028, 0x2136, "NVMe Datacenter SSD [Optane] SED 1.6TB 2.5\" U.2 (P5800X)(0x1028-0x2136)"},
{0x8086, 0x4140, 0x1028, 0x2137, "NVMe Datacenter SSD [Optane] 400GB 2.5\" U.2 (P5800X)(0x1028-0x2137)"},
{0x8086, 0x4140, 0x1028, 0x2138, "NVMe Datacenter SSD [Optane] 800GB 2.5\" U.2 (P5800X)(0x1028-0x2138)"},
{0x8086, 0x4140, 0x1028, 0x2139, "NVMe Datacenter SSD [Optane] 1.6TB 2.5\" U.2 (P5800X)(0x1028-0x2139)"},
{0x8086, 0x4220, 0xFFFF, 0xFFFF, "PRO/Wireless 2200BG [Calexico2] Network Connection(0x4220)"},
{0x8086, 0x4220, 0x103C, 0x0934, "Compaq nw8240/nx8220(0x103C-0x0934)"},
{0x8086, 0x4220, 0x103C, 0x12F6, "nc6120/nc6220/nw8240/nx8220(0x103C-0x12F6)"},
{0x8086, 0x4220, 0x8086, 0x2701, "WM3B2200BG Mini-PCI Card(0x8086-0x2701)"},
{0x8086, 0x4220, 0x8086, 0x2712, "IBM ThinkPad R50e(0x8086-0x2712)"},
{0x8086, 0x4220, 0x8086, 0x2721, "Dell B130 laptop integrated WLAN(0x8086-0x2721)"},
{0x8086, 0x4220, 0x8086, 0x2722, "Dell Latitude D600(0x8086-0x2722)"},
{0x8086, 0x4220, 0x8086, 0x2731, "Samsung P35 integrated WLAN(0x8086-0x2731)"},
{0x8086, 0x4222, 0xFFFF, 0xFFFF, "PRO/Wireless 3945ABG [Golan] Network Connection(0x4222)"},
{0x8086, 0x4222, 0x103C, 0x135C, "PRO/Wireless 3945ABG [Golan] Network Connection(0x103C-0x135C)"},
{0x8086, 0x4222, 0x8086, 0x1000, "PRO/Wireless 3945ABG Network Connection(0x8086-0x1000)"},
{0x8086, 0x4222, 0x8086, 0x1001, "WM3945ABG MOW2(0x8086-0x1001)"},
{0x8086, 0x4222, 0x8086, 0x1005, "PRO/Wireless 3945BG Network Connection(0x8086-0x1005)"},
{0x8086, 0x4222, 0x8086, 0x1034, "PRO/Wireless 3945BG Network Connection(0x8086-0x1034)"},
{0x8086, 0x4222, 0x8086, 0x1044, "PRO/Wireless 3945BG Network Connection(0x8086-0x1044)"},
{0x8086, 0x4222, 0x8086, 0x1C00, "PRO/Wireless 3945ABG Network Connection(0x8086-0x1C00)"},
{0x8086, 0x4223, 0xFFFF, 0xFFFF, "PRO/Wireless 2915ABG [Calexico2] Network Connection(0x4223)"},
{0x8086, 0x4223, 0x1000, 0x8086, "mPCI 3B Americas/Europe ZZA(0x1000-0x8086)"},
{0x8086, 0x4223, 0x1001, 0x8086, "mPCI 3B Europe ZZE(0x1001-0x8086)"},
{0x8086, 0x4223, 0x1002, 0x8086, "mPCI 3B Japan ZZJ(0x1002-0x8086)"},
{0x8086, 0x4223, 0x1003, 0x8086, "mPCI 3B High-Band ZZH(0x1003-0x8086)"},
{0x8086, 0x4223, 0x103C, 0x1351, "Compaq nc6220(0x103C-0x1351)"},
{0x8086, 0x4224, 0xFFFF, 0xFFFF, "PRO/Wireless 2915ABG [Calexico2] Network Connection(0x4224)"},
{0x8086, 0x4227, 0xFFFF, 0xFFFF, "PRO/Wireless 3945ABG [Golan] Network Connection(0x4227)"},
{0x8086, 0x4227, 0x8086, 0x1010, "ThinkPad R60e(0x8086-0x1010)"},
{0x8086, 0x4227, 0x8086, 0x1011, "ThinkPad T60/R60e/X60s/R61(0x8086-0x1011)"},
{0x8086, 0x4227, 0x8086, 0x1014, "PRO/Wireless 3945BG Network Connection(0x8086-0x1014)"},
{0x8086, 0x4229, 0xFFFF, 0xFFFF, "PRO/Wireless 4965 AG or AGN [Kedron] Network Connection(0x4229)"},
{0x8086, 0x4229, 0x8086, 0x1100, "Vaio VGN-SZ79SN_C(0x8086-0x1100)"},
{0x8086, 0x4229, 0x8086, 0x1101, "PRO/Wireless 4965 AG or AGN(0x8086-0x1101)"},
{0x8086, 0x422B, 0xFFFF, 0xFFFF, "Centrino Ultimate-N 6300(0x422B)"},
{0x8086, 0x422B, 0x8086, 0x1101, "Centrino Ultimate-N 6300 3x3 AGN(0x8086-0x1101)"},
{0x8086, 0x422B, 0x8086, 0x1121, "Centrino Ultimate-N 6300 3x3 AGN(0x8086-0x1121)"},
{0x8086, 0x422C, 0xFFFF, 0xFFFF, "Centrino Advanced-N 6200(0x422C)"},
{0x8086, 0x422C, 0x8086, 0x1301, "Centrino Advanced-N 6200 2x2 AGN(0x8086-0x1301)"},
{0x8086, 0x422C, 0x8086, 0x1306, "Centrino Advanced-N 6200 2x2 ABG(0x8086-0x1306)"},
{0x8086, 0x422C, 0x8086, 0x1307, "Centrino Advanced-N 6200 2x2 BG(0x8086-0x1307)"},
{0x8086, 0x422C, 0x8086, 0x1321, "Centrino Advanced-N 6200 2x2 AGN(0x8086-0x1321)"},
{0x8086, 0x422C, 0x8086, 0x1326, "Centrino Advanced-N 6200 2x2 ABG(0x8086-0x1326)"},
{0x8086, 0x4230, 0xFFFF, 0xFFFF, "PRO/Wireless 4965 AG or AGN [Kedron] Network Connection(0x4230)"},
{0x8086, 0x4230, 0x8086, 0x1110, "Lenovo ThinkPad T51(0x8086-0x1110)"},
{0x8086, 0x4230, 0x8086, 0x1111, "Lenovo ThinkPad T61(0x8086-0x1111)"},
{0x8086, 0x4232, 0xFFFF, 0xFFFF, "WiFi Link 5100(0x4232)"},
{0x8086, 0x4232, 0x8086, 0x1201, "WiFi Link 5100 AGN(0x8086-0x1201)"},
{0x8086, 0x4232, 0x8086, 0x1204, "WiFi Link 5100 AGN(0x8086-0x1204)"},
{0x8086, 0x4232, 0x8086, 0x1205, "WiFi Link 5100 BGN(0x8086-0x1205)"},
{0x8086, 0x4232, 0x8086, 0x1206, "WiFi Link 5100 ABG(0x8086-0x1206)"},
{0x8086, 0x4232, 0x8086, 0x1221, "WiFi Link 5100 AGN(0x8086-0x1221)"},
{0x8086, 0x4232, 0x8086, 0x1224, "WiFi Link 5100 AGN(0x8086-0x1224)"},
{0x8086, 0x4232, 0x8086, 0x1225, "WiFi Link 5100 BGN(0x8086-0x1225)"},
{0x8086, 0x4232, 0x8086, 0x1226, "WiFi Link 5100 ABG(0x8086-0x1226)"},
{0x8086, 0x4232, 0x8086, 0x1301, "WiFi Link 5100 AGN(0x8086-0x1301)"},
{0x8086, 0x4232, 0x8086, 0x1304, "WiFi Link 5100 AGN(0x8086-0x1304)"},
{0x8086, 0x4232, 0x8086, 0x1305, "WiFi Link 5100 BGN(0x8086-0x1305)"},
{0x8086, 0x4232, 0x8086, 0x1306, "WiFi Link 5100 ABG(0x8086-0x1306)"},
{0x8086, 0x4232, 0x8086, 0x1321, "WiFi Link 5100 AGN(0x8086-0x1321)"},
{0x8086, 0x4232, 0x8086, 0x1324, "WiFi Link 5100 AGN(0x8086-0x1324)"},
{0x8086, 0x4232, 0x8086, 0x1325, "WiFi Link 5100 BGN(0x8086-0x1325)"},
{0x8086, 0x4232, 0x8086, 0x1326, "WiFi Link 5100 ABG(0x8086-0x1326)"},
{0x8086, 0x4235, 0xFFFF, 0xFFFF, "Ultimate N WiFi Link 5300(0x4235)"},
{0x8086, 0x4236, 0xFFFF, 0xFFFF, "Ultimate N WiFi Link 5300(0x4236)"},
{0x8086, 0x4237, 0xFFFF, 0xFFFF, "PRO/Wireless 5100 AGN [Shiloh] Network Connection(0x4237)"},
{0x8086, 0x4237, 0x8086, 0x1211, "WiFi Link 5100 AGN(0x8086-0x1211)"},
{0x8086, 0x4237, 0x8086, 0x1214, "WiFi Link 5100 AGN(0x8086-0x1214)"},
{0x8086, 0x4237, 0x8086, 0x1215, "WiFi Link 5100 BGN(0x8086-0x1215)"},
{0x8086, 0x4237, 0x8086, 0x1216, "WiFi Link 5100 ABG(0x8086-0x1216)"},
{0x8086, 0x4237, 0x8086, 0x1311, "WiFi Link 5100 AGN(0x8086-0x1311)"},
{0x8086, 0x4237, 0x8086, 0x1314, "WiFi Link 5100 AGN(0x8086-0x1314)"},
{0x8086, 0x4237, 0x8086, 0x1315, "WiFi Link 5100 BGN(0x8086-0x1315)"},
{0x8086, 0x4237, 0x8086, 0x1316, "WiFi Link 5100 ABG(0x8086-0x1316)"},
{0x8086, 0x4238, 0xFFFF, 0xFFFF, "Centrino Ultimate-N 6300(0x4238)"},
{0x8086, 0x4238, 0x8086, 0x1111, "Centrino Ultimate-N 6300 3x3 AGN(0x8086-0x1111)"},
{0x8086, 0x4239, 0xFFFF, 0xFFFF, "Centrino Advanced-N 6200(0x4239)"},
{0x8086, 0x4239, 0x8086, 0x1311, "Centrino Advanced-N 6200 2x2 AGN(0x8086-0x1311)"},
{0x8086, 0x4239, 0x8086, 0x1316, "Centrino Advanced-N 6200 2x2 ABG(0x8086-0x1316)"},
{0x8086, 0x423A, 0xFFFF, 0xFFFF, "PRO/Wireless 5350 AGN [Echo Peak] Network Connection(0x423A)"},
{0x8086, 0x423B, 0xFFFF, 0xFFFF, "PRO/Wireless 5350 AGN [Echo Peak] Network Connection(0x423B)"},
{0x8086, 0x423C, 0xFFFF, 0xFFFF, "WiMAX/WiFi Link 5150(0x423C)"},
{0x8086, 0x423C, 0x8086, 0x1201, "WiMAX/WiFi Link 5150 AGN(0x8086-0x1201)"},
{0x8086, 0x423C, 0x8086, 0x1206, "WiMAX/WiFi Link 5150 ABG(0x8086-0x1206)"},
{0x8086, 0x423C, 0x8086, 0x1221, "WiMAX/WiFi Link 5150 AGN(0x8086-0x1221)"},
{0x8086, 0x423C, 0x8086, 0x1301, "WiMAX/WiFi Link 5150 AGN(0x8086-0x1301)"},
{0x8086, 0x423C, 0x8086, 0x1306, "WiMAX/WiFi Link 5150 ABG(0x8086-0x1306)"},
{0x8086, 0x423C, 0x8086, 0x1321, "WiMAX/WiFi Link 5150 AGN(0x8086-0x1321)"},
{0x8086, 0x423D, 0xFFFF, 0xFFFF, "WiMAX/WiFi Link 5150(0x423D)"},
{0x8086, 0x423D, 0x8086, 0x1211, "WiMAX/WiFi Link 5150 AGN(0x8086-0x1211)"},
{0x8086, 0x423D, 0x8086, 0x1216, "WiMAX/WiFi Link 5150 ABG(0x8086-0x1216)"},
{0x8086, 0x423D, 0x8086, 0x1311, "WiMAX/WiFi Link 5150 AGN(0x8086-0x1311)"},
{0x8086, 0x423D, 0x8086, 0x1316, "WiMAX/WiFi Link 5150 ABG(0x8086-0x1316)"},
{0x8086, 0x4384, 0xFFFF, 0xFFFF, "Q570 LPC/eSPI Controller(0x4384)"},
{0x8086, 0x4385, 0xFFFF, 0xFFFF, "Z590 LPC/eSPI Controller(0x4385)"},
{0x8086, 0x4386, 0xFFFF, 0xFFFF, "H570 LPC/eSPI Controller(0x4386)"},
{0x8086, 0x4387, 0xFFFF, 0xFFFF, "B560 LPC/eSPI Controller(0x4387)"},
{0x8086, 0x4388, 0xFFFF, 0xFFFF, "H510 LPC/eSPI Controller(0x4388)"},
{0x8086, 0x4389, 0xFFFF, 0xFFFF, "WM590 LPC/eSPI Controller(0x4389)"},
{0x8086, 0x438A, 0xFFFF, 0xFFFF, "QM580 LPC/eSPI Controller(0x438A)"},
{0x8086, 0x438B, 0xFFFF, 0xFFFF, "HM570 LPC/eSPI Controller(0x438B)"},
{0x8086, 0x438C, 0xFFFF, 0xFFFF, "C252 LPC/eSPI Controller(0x438C)"},
{0x8086, 0x438D, 0xFFFF, 0xFFFF, "C256 LPC/eSPI Controller(0x438D)"},
{0x8086, 0x438E, 0xFFFF, 0xFFFF, "H310D LPC/eSPI Controller(0x438E)"},
{0x8086, 0x438F, 0xFFFF, 0xFFFF, "W580 LPC/eSPI Controller(0x438F)"},
{0x8086, 0x4390, 0xFFFF, 0xFFFF, "RM590E LPC/eSPI Controller(0x4390)"},
{0x8086, 0x4391, 0xFFFF, 0xFFFF, "R580E LPC/eSPI Controller(0x4391)"},
{0x8086, 0x43A3, 0xFFFF, 0xFFFF, "Tiger Lake-H SMBus Controller(0x43A3)"},
{0x8086, 0x43A4, 0xFFFF, 0xFFFF, "Tiger Lake-H SPI Controller(0x43A4)"},
{0x8086, 0x43B0, 0xFFFF, 0xFFFF, "Tiger Lake-H PCI Express Root Port #9(0x43B0)"},
{0x8086, 0x43B8, 0xFFFF, 0xFFFF, "Tiger Lake-H PCIe Root Port #1(0x43B8)"},
{0x8086, 0x43BA, 0xFFFF, 0xFFFF, "Tiger Lake-H PCIe Root Port #3(0x43BA)"},
{0x8086, 0x43BB, 0xFFFF, 0xFFFF, "Tiger Lake-H PCIe Root Port #4(0x43BB)"},
{0x8086, 0x43BC, 0xFFFF, 0xFFFF, "Tiger Lake-H PCI Express Root Port #5(0x43BC)"},
{0x8086, 0x43C0, 0xFFFF, 0xFFFF, "Tiger Lake-H PCIe Root Port #17(0x43C0)"},
{0x8086, 0x43C7, 0xFFFF, 0xFFFF, "Tiger Lake-H PCIe Root Port #24(0x43C7)"},
{0x8086, 0x43C8, 0xFFFF, 0xFFFF, "Tiger Lake-H HD Audio Controller(0x43C8)"},
{0x8086, 0x43D3, 0xFFFF, 0xFFFF, "Tiger Lake SATA AHCI Controller(0x43D3)"},
{0x8086, 0x43E0, 0xFFFF, 0xFFFF, "Tiger Lake-H Management Engine Interface(0x43E0)"},
{0x8086, 0x43E8, 0xFFFF, 0xFFFF, "Tiger Lake-H Serial IO I2C Controller #0(0x43E8)"},
{0x8086, 0x43E9, 0xFFFF, 0xFFFF, "Tiger Lake-H Serial IO I2C Controller #1(0x43E9)"},
{0x8086, 0x43ED, 0xFFFF, 0xFFFF, "Tiger Lake-H USB 3.2 Gen 2x1 xHCI Host Controller(0x43ED)"},
{0x8086, 0x43EF, 0xFFFF, 0xFFFF, "Tiger Lake-H Shared SRAM(0x43EF)"},
{0x8086, 0x43F0, 0xFFFF, 0xFFFF, "Tiger Lake PCH CNVi WiFi(0x43F0)"},
{0x8086, 0x43F0, 0x8086, 0x0034, "Wireless-AC 9560(0x8086-0x0034)"},
{0x8086, 0x43F0, 0x8086, 0x0074, "Wi-Fi 6 AX201 160MHz(0x8086-0x0074)"},
{0x8086, 0x43F0, 0x8086, 0x0264, "Wireless-AC 9461(0x8086-0x0264)"},
{0x8086, 0x43F0, 0x8086, 0x02A4, "Wireless-AC 9462(0x8086-0x02A4)"},
{0x8086, 0x43FC, 0xFFFF, 0xFFFF, "Tiger Lake-H Integrated Sensor Hub(0x43FC)"},
{0x8086, 0x444E, 0xFFFF, 0xFFFF, "Turbo Memory Controller(0x444E)"},
{0x8086, 0x4511, 0xFFFF, 0xFFFF, "Elkhart Lake Gaussian and Neural Accelerator(0x4511)"},
{0x8086, 0x4538, 0xFFFF, 0xFFFF, "Elkhart Lake PCI-e Root Complex(0x4538)"},
{0x8086, 0x4555, 0xFFFF, 0xFFFF, "Elkhart Lake [UHD Graphics Gen11 16EU](0x4555)"},
{0x8086, 0x4571, 0xFFFF, 0xFFFF, "Elkhart Lake [UHD Graphics Gen11 32EU](0x4571)"},
{0x8086, 0x4601, 0xFFFF, 0xFFFF, "Alder Lake-U15 Host and DRAM Controller(0x4601)"},
{0x8086, 0x4602, 0xFFFF, 0xFFFF, "Alder Lake Host and DRAM Controller(0x4602)"},
{0x8086, 0x460D, 0xFFFF, 0xFFFF, "12th Gen Core Processor PCI Express x16 Controller #1(0x460D)"},
{0x8086, 0x461D, 0xFFFF, 0xFFFF, "Alder Lake Innovation Platform Framework Processor Participant(0x461D)"},
{0x8086, 0x461D, 0x1028, 0x0B10, "Precision 3571(0x1028-0x0B10)"},
{0x8086, 0x461E, 0xFFFF, 0xFFFF, "Alder Lake-P Thunderbolt 4 USB Controller(0x461E)"},
{0x8086, 0x461E, 0x1028, 0x0B10, "Precision 3571(0x1028-0x0B10)"},
{0x8086, 0x461F, 0xFFFF, 0xFFFF, "Alder Lake-P Thunderbolt 4 PCI Express Root Port #3(0x461F)"},
{0x8086, 0x4626, 0xFFFF, 0xFFFF, "Alder Lake-P Integrated Graphics Controller(0x4626)"},
{0x8086, 0x4628, 0xFFFF, 0xFFFF, "Alder Lake-UP3 GT2 [UHD Graphics](0x4628)"},
{0x8086, 0x4629, 0xFFFF, 0xFFFF, "12th Gen Core Processor Host Bridge/DRAM Registers(0x4629)"},
{0x8086, 0x462A, 0xFFFF, 0xFFFF, "AlderLake-P [UHD Graphics](0x462A)"},
{0x8086, 0x462F, 0xFFFF, 0xFFFF, "Alder Lake-P Thunderbolt 4 PCI Express Root Port #2(0x462F)"},
{0x8086, 0x4636, 0xFFFF, 0xFFFF, "AlderLake-P [UHD Graphics](0x4636)"},
{0x8086, 0x4638, 0xFFFF, 0xFFFF, "AlderLake-P [UHD Graphics](0x4638)"},
{0x8086, 0x463A, 0xFFFF, 0xFFFF, "AlderLake-P [UHD Graphics](0x463A)"},
{0x8086, 0x463D, 0xFFFF, 0xFFFF, "12th Gen Core Processor PCI Express x4 Controller #2(0x463D)"},
{0x8086, 0x463E, 0xFFFF, 0xFFFF, "Alder Lake-P Thunderbolt 4 NHI #0(0x463E)"},
{0x8086, 0x463E, 0x1028, 0x0B10, "Precision 3571(0x1028-0x0B10)"},
{0x8086, 0x463F, 0xFFFF, 0xFFFF, "Alder Lake-P Thunderbolt 4 PCI Express Root Port #1(0x463F)"},
{0x8086, 0x4641, 0xFFFF, 0xFFFF, "12th Gen Core Processor Host Bridge/DRAM Registers(0x4641)"},
{0x8086, 0x4641, 0x1028, 0x0B10, "Precision 3571(0x1028-0x0B10)"},
{0x8086, 0x464D, 0xFFFF, 0xFFFF, "12th Gen Core Processor PCI Express x4 Controller #0(0x464D)"},
{0x8086, 0x464E, 0xFFFF, 0xFFFF, "Alder Lake-N Thunderbolt 4 USB Controller(0x464E)"},
{0x8086, 0x464F, 0xFFFF, 0xFFFF, "12th Gen Core Processor Gaussian & Neural Accelerator(0x464F)"},
{0x8086, 0x464F, 0x1028, 0x0B10, "Precision 3571(0x1028-0x0B10)"},
{0x8086, 0x4650, 0xFFFF, 0xFFFF, "12th Gen Core Processor Host Bridge(0x4650)"},
{0x8086, 0x465D, 0xFFFF, 0xFFFF, "Alder Lake Imaging Signal Processor(0x465D)"},
{0x8086, 0x4660, 0xFFFF, 0xFFFF, "12th Gen Core Processor Host Bridge/DRAM Registers(0x4660)"},
{0x8086, 0x4668, 0xFFFF, 0xFFFF, "12th Gen Core Processor Host Bridge/DRAM Registers(0x4668)"},
{0x8086, 0x466D, 0xFFFF, 0xFFFF, "Alder Lake-P Thunderbolt 4 NHI #1(0x466D)"},
{0x8086, 0x466E, 0xFFFF, 0xFFFF, "Alder Lake-P Thunderbolt 4 PCI Express Root Port #0(0x466E)"},
{0x8086, 0x467D, 0xFFFF, 0xFFFF, "Platform Monitoring Technology(0x467D)"},
{0x8086, 0x467F, 0xFFFF, 0xFFFF, "Volume Management Device NVMe RAID Controller(0x467F)"},
{0x8086, 0x4680, 0xFFFF, 0xFFFF, "AlderLake-S GT1(0x4680)"},
{0x8086, 0x4682, 0xFFFF, 0xFFFF, "Alder Lake-S GT1 [UHD Graphics 730](0x4682)"},
{0x8086, 0x4688, 0xFFFF, 0xFFFF, "Alder Lake-HX GT1 [UHD Graphics 770](0x4688)"},
{0x8086, 0x468A, 0xFFFF, 0xFFFF, "Alder Lake-S [UHD Graphics](0x468A)"},
{0x8086, 0x468B, 0xFFFF, 0xFFFF, "Alder Lake-S [UHD Graphics](0x468B)"},
{0x8086, 0x4690, 0xFFFF, 0xFFFF, "Alder Lake-S GT1 [UHD Graphics 770](0x4690)"},
{0x8086, 0x4692, 0xFFFF, 0xFFFF, "Alder Lake-S GT1 [UHD Graphics 730](0x4692)"},
{0x8086, 0x4693, 0xFFFF, 0xFFFF, "Alder Lake-S GT1 [UHD Graphics 710](0x4693)"},
{0x8086, 0x46A0, 0xFFFF, 0xFFFF, "AlderLake-P GT2(0x46A0)"},
{0x8086, 0x46A1, 0xFFFF, 0xFFFF, "UHD Graphics(0x46A1)"},
{0x8086, 0x46A3, 0xFFFF, 0xFFFF, "Alder Lake-P GT1 [UHD Graphics](0x46A3)"},
{0x8086, 0x46A6, 0xFFFF, 0xFFFF, "Alder Lake-P GT2 [Iris Xe Graphics](0x46A6)"},
{0x8086, 0x46A8, 0xFFFF, 0xFFFF, "Alder Lake-UP3 GT2 [Iris Xe Graphics](0x46A8)"},
{0x8086, 0x46AA, 0xFFFF, 0xFFFF, "Alder Lake-UP4 GT2 [Iris Xe Graphics](0x46AA)"},
{0x8086, 0x46B0, 0xFFFF, 0xFFFF, "AlderLake-P [Iris Xe Graphics](0x46B0)"},
{0x8086, 0x46B1, 0xFFFF, 0xFFFF, "AlderLake-P [Iris Xe Graphics](0x46B1)"},
{0x8086, 0x46B3, 0xFFFF, 0xFFFF, "Alder Lake-UP3 GT1 [UHD Graphics](0x46B3)"},
{0x8086, 0x46B3, 0x1025, 0x161D, "N22C6 [Extensa 15 EX215-55](0x1025-0x161D)"},
{0x8086, 0x46B6, 0xFFFF, 0xFFFF, "AlderLake-P [Iris Xe Graphics](0x46B6)"},
{0x8086, 0x46B8, 0xFFFF, 0xFFFF, "AlderLake-P [Iris Xe Graphics](0x46B8)"},
{0x8086, 0x46BA, 0xFFFF, 0xFFFF, "AlderLake-P [Iris Xe Graphics](0x46BA)"},
{0x8086, 0x46C0, 0xFFFF, 0xFFFF, "AlderLake-M GT1(0x46C0)"},
{0x8086, 0x46C1, 0xFFFF, 0xFFFF, "AlderLake-M [Iris Xe Graphics](0x46C1)"},
{0x8086, 0x46C3, 0xFFFF, 0xFFFF, "Alder Lake-UP4 GT1 [UHD Graphics](0x46C3)"},
{0x8086, 0x46D0, 0xFFFF, 0xFFFF, "Alder Lake-N [UHD Graphics](0x46D0)"},
{0x8086, 0x46D1, 0xFFFF, 0xFFFF, "Alder Lake-N [UHD Graphics](0x46D1)"},
{0x8086, 0x46D2, 0xFFFF, 0xFFFF, "Alder Lake-N [UHD Graphics](0x46D2)"},
{0x8086, 0x46D3, 0xFFFF, 0xFFFF, "Alder Lake-N [Intel Graphics](0x46D3)"},
{0x8086, 0x46D4, 0xFFFF, 0xFFFF, "Alder Lake-N [Intel Graphics](0x46D4)"},
{0x8086, 0x4905, 0xFFFF, 0xFFFF, "DG1 [Iris Xe MAX Graphics](0x4905)"},
{0x8086, 0x4906, 0xFFFF, 0xFFFF, "DG1 [Iris Xe Pod](0x4906)"},
{0x8086, 0x4907, 0xFFFF, 0xFFFF, "SG1 [Server GPU SG-18M](0x4907)"},
{0x8086, 0x4907, 0x193D, 0x4000, "UN-GPU-XG310-32GB-FHFL(0x193D-0x4000)"},
{0x8086, 0x4908, 0xFFFF, 0xFFFF, "DG1 [Iris Xe Graphics](0x4908)"},
{0x8086, 0x4909, 0xFFFF, 0xFFFF, "DG1 [Iris Xe MAX 100](0x4909)"},
{0x8086, 0x4940, 0xFFFF, 0xFFFF, "4xxx Series QAT(0x4940)"},
{0x8086, 0x4941, 0xFFFF, 0xFFFF, "4xxx Series QAT Virtual Function(0x4941)"},
{0x8086, 0x4942, 0xFFFF, 0xFFFF, "401xx Series QAT(0x4942)"},
{0x8086, 0x4943, 0xFFFF, 0xFFFF, "401xx Series QAT Virtual Function(0x4943)"},
{0x8086, 0x4944, 0xFFFF, 0xFFFF, "402xx Series QAT(0x4944)"},
{0x8086, 0x4945, 0xFFFF, 0xFFFF, "402xx Series QAT Virtual Function(0x4945)"},
{0x8086, 0x4946, 0xFFFF, 0xFFFF, "420xx Series QAT(0x4946)"},
{0x8086, 0x4947, 0xFFFF, 0xFFFF, "420xx Series QAT Virtual Function(0x4947)"},
{0x8086, 0x4B00, 0xFFFF, 0xFFFF, "Elkhart Lake eSPI Controller(0x4B00)"},
{0x8086, 0x4B23, 0xFFFF, 0xFFFF, "Elkhart Lake SMBus Controller(0x4B23)"},
{0x8086, 0x4B24, 0xFFFF, 0xFFFF, "Elkhart Lake SPI (Flash) Controller(0x4B24)"},
{0x8086, 0x4B38, 0xFFFF, 0xFFFF, "Elkhart Lake PCH PCI Express Root Port #0(0x4B38)"},
{0x8086, 0x4B39, 0xFFFF, 0xFFFF, "Elkhart Lake PCH PCI Express Root Port #1(0x4B39)"},
{0x8086, 0x4B3C, 0xFFFF, 0xFFFF, "Elkhart Lake PCIe Root Port #4(0x4B3C)"},
{0x8086, 0x4B3E, 0xFFFF, 0xFFFF, "Elkhart Lake PCH PCI Express Root Port #6(0x4B3E)"},
{0x8086, 0x4B4B, 0xFFFF, 0xFFFF, "Elkhart Lake Serial IO I2C Controller #4(0x4B4B)"},
{0x8086, 0x4B4D, 0xFFFF, 0xFFFF, "Elkhart Lake Serial IO UART Controller #2(0x4B4D)"},
{0x8086, 0x4B58, 0xFFFF, 0xFFFF, "Elkhart Lake High Density Audio bus interface(0x4B58)"},
{0x8086, 0x4B63, 0xFFFF, 0xFFFF, "Elkhart Lake SATA AHCI(0x4B63)"},
{0x8086, 0x4B70, 0xFFFF, 0xFFFF, "Elkhart Lake Management Engine Interface(0x4B70)"},
{0x8086, 0x4B7D, 0xFFFF, 0xFFFF, "Elkhart Lake USB 3.10 XHCI(0x4B7D)"},
{0x8086, 0x4B7F, 0xFFFF, 0xFFFF, "Elkhart Lake PMC SRAM(0x4B7F)"},
{0x8086, 0x4C3D, 0xFFFF, 0xFFFF, "Volume Management Device NVMe RAID Controller(0x4C3D)"},
{0x8086, 0x4C8A, 0xFFFF, 0xFFFF, "RocketLake-S GT1 [UHD Graphics 750](0x4C8A)"},
{0x8086, 0x4C8B, 0xFFFF, 0xFFFF, "RocketLake-S GT1 [UHD Graphics 730](0x4C8B)"},
{0x8086, 0x4C90, 0xFFFF, 0xFFFF, "RocketLake-S GT1 [UHD Graphics P750](0x4C90)"},
{0x8086, 0x4C9A, 0xFFFF, 0xFFFF, "RocketLake-S [UHD Graphics](0x4C9A)"},
{0x8086, 0x4D87, 0xFFFF, 0xFFFF, "Jasper Lake eSPI Controller(0x4D87)"},
{0x8086, 0x4DA3, 0xFFFF, 0xFFFF, "Jasper Lake SMBus(0x4DA3)"},
{0x8086, 0x4DA4, 0xFFFF, 0xFFFF, "Jasper Lake SPI Controller(0x4DA4)"},
{0x8086, 0x4DA8, 0xFFFF, 0xFFFF, "Jasper Lake Serial IO UART Controller #0(0x4DA8)"},
{0x8086, 0x4DAB, 0xFFFF, 0xFFFF, "Jasper Lake Serial IO SPI Controller #1(0x4DAB)"},
{0x8086, 0x4DB8, 0xFFFF, 0xFFFF, "Jasper Lake PCIe Root Port #1(0x4DB8)"},
{0x8086, 0x4DB9, 0xFFFF, 0xFFFF, "Jasper Lake PCIe Root Port #2(0x4DB9)"},
{0x8086, 0x4DBC, 0xFFFF, 0xFFFF, "Jasper Lake PCIe Root Port #5(0x4DBC)"},
{0x8086, 0x4DBE, 0xFFFF, 0xFFFF, "Jasper Lake PCIe Root Port #7(0x4DBE)"},
{0x8086, 0x4DC4, 0xFFFF, 0xFFFF, "Jasper Lake eMMC Controller(0x4DC4)"},
{0x8086, 0x4DC5, 0xFFFF, 0xFFFF, "Jasper Lake Serial IO I2C Host Controller #4(0x4DC5)"},
{0x8086, 0x4DC6, 0xFFFF, 0xFFFF, "Jasper Lake Serial IO I2C Host Controller #5(0x4DC6)"},
{0x8086, 0x4DC8, 0xFFFF, 0xFFFF, "Jasper Lake HD Audio(0x4DC8)"},
{0x8086, 0x4DD3, 0xFFFF, 0xFFFF, "Jasper Lake SATA AHCI Controller(0x4DD3)"},
{0x8086, 0x4DE0, 0xFFFF, 0xFFFF, "Management Engine Interface(0x4DE0)"},
{0x8086, 0x4DE8, 0xFFFF, 0xFFFF, "Jasper Lake Serial IO I2C Host Controller #0(0x4DE8)"},
{0x8086, 0x4DE9, 0xFFFF, 0xFFFF, "Jasper Lake Serial IO I2C Host Controller #1(0x4DE9)"},
{0x8086, 0x4DEA, 0xFFFF, 0xFFFF, "Jasper Lake Serial IO I2C Host Controller #2(0x4DEA)"},
{0x8086, 0x4DEB, 0xFFFF, 0xFFFF, "Jasper Lake Serial IO I2C Host Controller #3(0x4DEB)"},
{0x8086, 0x4DED, 0xFFFF, 0xFFFF, "Jasper Lake USB 3.1 xHCI Host Controller(0x4DED)"},
{0x8086, 0x4DEF, 0xFFFF, 0xFFFF, "Jasper Lake Shared SRAM(0x4DEF)"},
{0x8086, 0x4DF0, 0xFFFF, 0xFFFF, "Wi-Fi 6 AX201 160MHz(0x4DF0)"},
{0x8086, 0x4DF8, 0xFFFF, 0xFFFF, "Jasper Lake SD Controller(0x4DF8)"},
{0x8086, 0x4E03, 0xFFFF, 0xFFFF, "Dynamic Tuning service(0x4E03)"},
{0x8086, 0x4E19, 0xFFFF, 0xFFFF, "JasperLake IPU(0x4E19)"},
{0x8086, 0x4E55, 0xFFFF, 0xFFFF, "JasperLake [UHD Graphics](0x4E55)"},
{0x8086, 0x4E61, 0xFFFF, 0xFFFF, "JasperLake [UHD Graphics](0x4E61)"},
{0x8086, 0x4E71, 0xFFFF, 0xFFFF, "JasperLake [UHD Graphics](0x4E71)"},
{0x8086, 0x4F80, 0xFFFF, 0xFFFF, "DG2 [Intel Xe Graphics](0x4F80)"},
{0x8086, 0x4F81, 0xFFFF, 0xFFFF, "DG2 [Intel Xe Graphics](0x4F81)"},
{0x8086, 0x4F82, 0xFFFF, 0xFFFF, "DG2 [Intel Xe Graphics](0x4F82)"},
{0x8086, 0x4F83, 0xFFFF, 0xFFFF, "DG2 [Intel Xe Graphics](0x4F83)"},
{0x8086, 0x4F84, 0xFFFF, 0xFFFF, "DG2 [Intel Xe Graphics](0x4F84)"},
{0x8086, 0x4F85, 0xFFFF, 0xFFFF, "DG2 [Intel Xe Graphics](0x4F85)"},
{0x8086, 0x4F86, 0xFFFF, 0xFFFF, "DG2 [Intel Xe Graphics](0x4F86)"},
{0x8086, 0x4F87, 0xFFFF, 0xFFFF, "DG2 [Intel Xe Graphics](0x4F87)"},
{0x8086, 0x4F88, 0xFFFF, 0xFFFF, "DG2 [Intel Xe Graphics](0x4F88)"},
{0x8086, 0x4F89, 0xFFFF, 0xFFFF, "ACMP [Xe Graphics](0x4F89)"},
{0x8086, 0x4F8C, 0xFFFF, 0xFFFF, "ACMP [Xe Graphics](0x4F8C)"},
{0x8086, 0x4F90, 0xFFFF, 0xFFFF, "DG2 Audio Controller(0x4F90)"},
{0x8086, 0x4F91, 0xFFFF, 0xFFFF, "DG2 Audio Controller(0x4F91)"},
{0x8086, 0x4F92, 0xFFFF, 0xFFFF, "DG2 Audio Controller(0x4F92)"},
{0x8086, 0x5001, 0xFFFF, 0xFFFF, "LE80578(0x5001)"},
{0x8086, 0x5002, 0xFFFF, 0xFFFF, "LE80578 Graphics Processor Unit(0x5002)"},
{0x8086, 0x5009, 0xFFFF, 0xFFFF, "LE80578 Video Display Controller(0x5009)"},
{0x8086, 0x500D, 0xFFFF, 0xFFFF, "LE80578 Expansion Bus(0x500D)"},
{0x8086, 0x500E, 0xFFFF, 0xFFFF, "LE80578 UART Controller(0x500E)"},
{0x8086, 0x500F, 0xFFFF, 0xFFFF, "LE80578 General Purpose IO(0x500F)"},
{0x8086, 0x5010, 0xFFFF, 0xFFFF, "LE80578 I2C Controller(0x5010)"},
{0x8086, 0x5012, 0xFFFF, 0xFFFF, "LE80578 Serial Peripheral Interface Bus(0x5012)"},
{0x8086, 0x5020, 0xFFFF, 0xFFFF, "EP80579 Memory Controller Hub(0x5020)"},
{0x8086, 0x5021, 0xFFFF, 0xFFFF, "EP80579 DRAM Error Reporting Registers(0x5021)"},
{0x8086, 0x5023, 0xFFFF, 0xFFFF, "EP80579 EDMA Controller(0x5023)"},
{0x8086, 0x5024, 0xFFFF, 0xFFFF, "EP80579 PCI Express Port PEA0(0x5024)"},
{0x8086, 0x5025, 0xFFFF, 0xFFFF, "EP80579 PCI Express Port PEA1(0x5025)"},
{0x8086, 0x5028, 0xFFFF, 0xFFFF, "EP80579 S-ATA IDE(0x5028)"},
{0x8086, 0x5029, 0xFFFF, 0xFFFF, "EP80579 S-ATA AHCI(0x5029)"},
{0x8086, 0x502A, 0xFFFF, 0xFFFF, "EP80579 S-ATA Reserved(0x502A)"},
{0x8086, 0x502B, 0xFFFF, 0xFFFF, "EP80579 S-ATA Reserved(0x502B)"},
{0x8086, 0x502C, 0xFFFF, 0xFFFF, "EP80579 Integrated Processor ASU(0x502C)"},
{0x8086, 0x502D, 0xFFFF, 0xFFFF, "EP80579 Integrated Processor with QuickAssist ASU(0x502D)"},
{0x8086, 0x502E, 0xFFFF, 0xFFFF, "EP80579 Reserved(0x502E)"},
{0x8086, 0x502F, 0xFFFF, 0xFFFF, "EP80579 Reserved(0x502F)"},
{0x8086, 0x5030, 0xFFFF, 0xFFFF, "EP80579 Reserved(0x5030)"},
{0x8086, 0x5031, 0xFFFF, 0xFFFF, "EP80579 LPC Bus(0x5031)"},
{0x8086, 0x5032, 0xFFFF, 0xFFFF, "EP80579 SMBus Controller(0x5032)"},
{0x8086, 0x5033, 0xFFFF, 0xFFFF, "EP80579 USB 1.1 Controller(0x5033)"},
{0x8086, 0x5035, 0xFFFF, 0xFFFF, "EP80579 USB 2.0 Controller(0x5035)"},
{0x8086, 0x5037, 0xFFFF, 0xFFFF, "EP80579 PCI-PCI Bridge (transparent mode)(0x5037)"},
{0x8086, 0x5039, 0xFFFF, 0xFFFF, "EP80579 Controller Area Network (CAN) interface #1(0x5039)"},
{0x8086, 0x503A, 0xFFFF, 0xFFFF, "EP80579 Controller Area Network (CAN) interface #2(0x503A)"},
{0x8086, 0x503B, 0xFFFF, 0xFFFF, "EP80579 Synchronous Serial Port (SPP)(0x503B)"},
{0x8086, 0x503C, 0xFFFF, 0xFFFF, "EP80579 IEEE 1588 Hardware Assist(0x503C)"},
{0x8086, 0x503D, 0xFFFF, 0xFFFF, "EP80579 Local Expansion Bus(0x503D)"},
{0x8086, 0x503E, 0xFFFF, 0xFFFF, "EP80579 Global Control Unit (GCU)(0x503E)"},
{0x8086, 0x503F, 0xFFFF, 0xFFFF, "EP80579 Reserved(0x503F)"},
{0x8086, 0x5040, 0xFFFF, 0xFFFF, "EP80579 Integrated Processor Gigabit Ethernet MAC(0x5040)"},
{0x8086, 0x5041, 0xFFFF, 0xFFFF, "EP80579 Integrated Processor with QuickAssist Gigabit Ethernet MAC(0x5041)"},
{0x8086, 0x5042, 0xFFFF, 0xFFFF, "EP80579 Reserved(0x5042)"},
{0x8086, 0x5043, 0xFFFF, 0xFFFF, "EP80579 Reserved(0x5043)"},
{0x8086, 0x5044, 0xFFFF, 0xFFFF, "EP80579 Integrated Processor Gigabit Ethernet MAC(0x5044)"},
{0x8086, 0x5045, 0xFFFF, 0xFFFF, "EP80579 Integrated Processor with QuickAssist Gigabit Ethernet MAC(0x5045)"},
{0x8086, 0x5046, 0xFFFF, 0xFFFF, "EP80579 Reserved(0x5046)"},
{0x8086, 0x5047, 0xFFFF, 0xFFFF, "EP80579 Reserved(0x5047)"},
{0x8086, 0x5048, 0xFFFF, 0xFFFF, "EP80579 Integrated Processor Gigabit Ethernet MAC(0x5048)"},
{0x8086, 0x5049, 0xFFFF, 0xFFFF, "EP80579 Integrated Processor with QuickAssist Gigabit Ethernet MAC(0x5049)"},
{0x8086, 0x504A, 0xFFFF, 0xFFFF, "EP80579 Reserved(0x504A)"},
{0x8086, 0x504B, 0xFFFF, 0xFFFF, "EP80579 Reserved(0x504B)"},
{0x8086, 0x504C, 0xFFFF, 0xFFFF, "EP80579 Integrated Processor with QuickAssist TDM(0x504C)"},
{0x8086, 0x5181, 0xFFFF, 0xFFFF, "Alder Lake PCH-P LPC/eSPI Controller(0x5181)"},
{0x8086, 0x5182, 0xFFFF, 0xFFFF, "Alder Lake PCH eSPI Controller(0x5182)"},
{0x8086, 0x5182, 0x1028, 0x0B10, "Precision 3571(0x1028-0x0B10)"},
{0x8086, 0x5187, 0xFFFF, 0xFFFF, "Alder Lake LPC Controller(0x5187)"},
{0x8086, 0x519D, 0xFFFF, 0xFFFF, "Raptor Lake LPC/eSPI Controller(0x519D)"},
{0x8086, 0x519D, 0x1028, 0x0C06, "Precision 3580(0x1028-0x0C06)"},
{0x8086, 0x51A3, 0xFFFF, 0xFFFF, "Alder Lake PCH-P SMBus Host Controller(0x51A3)"},
{0x8086, 0x51A3, 0x1028, 0x0B10, "Precision 3571(0x1028-0x0B10)"},
{0x8086, 0x51A3, 0x1028, 0x0C06, "Precision 3580(0x1028-0x0C06)"},
{0x8086, 0x51A4, 0xFFFF, 0xFFFF, "Alder Lake-P PCH SPI Controller(0x51A4)"},
{0x8086, 0x51A4, 0x1028, 0x0B10, "Precision 3571(0x1028-0x0B10)"},
{0x8086, 0x51A4, 0x1028, 0x0C06, "Precision 3580(0x1028-0x0C06)"},
{0x8086, 0x51A8, 0xFFFF, 0xFFFF, "Alder Lake PCH UART #0(0x51A8)"},
{0x8086, 0x51A9, 0xFFFF, 0xFFFF, "Alder Lake PCH UART #1(0x51A9)"},
{0x8086, 0x51AA, 0xFFFF, 0xFFFF, "Alder Lake SPI Controller(0x51AA)"},
{0x8086, 0x51AB, 0xFFFF, 0xFFFF, "Alder Lake SPI Controller(0x51AB)"},
{0x8086, 0x51B0, 0xFFFF, 0xFFFF, "Alder Lake PCI Express Root Port #9(0x51B0)"},
{0x8086, 0x51B1, 0xFFFF, 0xFFFF, "Alder Lake PCI Express x1 Root Port #10(0x51B1)"},
{0x8086, 0x51BB, 0xFFFF, 0xFFFF, "Alder Lake-P PCH PCIe Root Port #4(0x51BB)"},
{0x8086, 0x51BD, 0xFFFF, 0xFFFF, "Alder Lake-P PCH PCIe Root Port #6(0x51BD)"},
{0x8086, 0x51BF, 0xFFFF, 0xFFFF, "Alder Lake PCH-P PCI Express Root Port #9(0x51BF)"},
{0x8086, 0x51C5, 0xFFFF, 0xFFFF, "Alder Lake-P Serial IO I2C Controller #0(0x51C5)"},
{0x8086, 0x51C6, 0xFFFF, 0xFFFF, "Alder Lake-P Serial IO I2C Controller #1(0x51C6)"},
{0x8086, 0x51C8, 0xFFFF, 0xFFFF, "Alder Lake PCH-P High Definition Audio Controller(0x51C8)"},
{0x8086, 0x51C8, 0x1028, 0x0B10, "Precision 3571(0x1028-0x0B10)"},
{0x8086, 0x51CA, 0xFFFF, 0xFFFF, "Raptor Lake-P/U/H cAVS(0x51CA)"},
{0x8086, 0x51CA, 0x1028, 0x0C06, "Precision 3580(0x1028-0x0C06)"},
{0x8086, 0x51CC, 0xFFFF, 0xFFFF, "Alder Lake Smart Sound Technology Audio Controller(0x51CC)"},
{0x8086, 0x51D3, 0xFFFF, 0xFFFF, "Alder Lake-P SATA AHCI Controller(0x51D3)"},
{0x8086, 0x51D3, 0x1028, 0x0B10, "Precision 3571(0x1028-0x0B10)"},
{0x8086, 0x51D8, 0xFFFF, 0xFFFF, "Alder Lake-P Serial IO I2C Controller #2(0x51D8)"},
{0x8086, 0x51D9, 0xFFFF, 0xFFFF, "Alder Lake-P Serial IO I2C Controller #3(0x51D9)"},
{0x8086, 0x51E0, 0xFFFF, 0xFFFF, "Alder Lake PCH HECI Controller(0x51E0)"},
{0x8086, 0x51E0, 0x1028, 0x0B10, "Precision 3571(0x1028-0x0B10)"},
{0x8086, 0x51E0, 0x1028, 0x0C06, "Precision 3580(0x1028-0x0C06)"},
{0x8086, 0x51E3, 0xFFFF, 0xFFFF, "Alder Lake AMT SOL Redirection(0x51E3)"},
{0x8086, 0x51E3, 0x1028, 0x0B10, "Precision 3571(0x1028-0x0B10)"},
{0x8086, 0x51E8, 0xFFFF, 0xFFFF, "Alder Lake PCH Serial IO I2C Controller #0(0x51E8)"},
{0x8086, 0x51E8, 0x1028, 0x0B10, "Precision 3571(0x1028-0x0B10)"},
{0x8086, 0x51E8, 0x1028, 0x0C06, "Precision 3580(0x1028-0x0C06)"},
{0x8086, 0x51E9, 0xFFFF, 0xFFFF, "Alder Lake PCH Serial IO I2C Controller #1(0x51E9)"},
{0x8086, 0x51E9, 0x1028, 0x0B10, "Precision 3571(0x1028-0x0B10)"},
{0x8086, 0x51E9, 0x1028, 0x0C06, "Precision 3580(0x1028-0x0C06)"},
{0x8086, 0x51EA, 0xFFFF, 0xFFFF, "Alder Lake PCH Serial IO I2C Controller #2(0x51EA)"},
{0x8086, 0x51EB, 0xFFFF, 0xFFFF, "Alder Lake PCH Serial IO I2C Controller #3(0x51EB)"},
{0x8086, 0x51ED, 0xFFFF, 0xFFFF, "Alder Lake PCH USB 3.2 xHCI Host Controller(0x51ED)"},
{0x8086, 0x51ED, 0x1028, 0x0B10, "Precision 3571(0x1028-0x0B10)"},
{0x8086, 0x51ED, 0x1028, 0x0C06, "Precision 3580(0x1028-0x0C06)"},
{0x8086, 0x51EF, 0xFFFF, 0xFFFF, "Alder Lake PCH Shared SRAM(0x51EF)"},
{0x8086, 0x51EF, 0x1028, 0x0B10, "Precision 3571(0x1028-0x0B10)"},
{0x8086, 0x51EF, 0x1028, 0x0C06, "Precision 3580(0x1028-0x0C06)"},
{0x8086, 0x51F0, 0xFFFF, 0xFFFF, "Alder Lake-P PCH CNVi WiFi(0x51F0)"},
{0x8086, 0x51F0, 0x1A56, 0x1652, "Dual Band Wi-Fi 6(802.11ax) Killer AX1650i 160MHz 2x2 [Cyclone Peak](0x1A56-0x1652)"},
{0x8086, 0x51F0, 0x1A56, 0x1671, "Dual Band Wi-Fi 6E(802.11ax) AX1675s 160MHz 2x2 [Garfield Peak](0x1A56-0x1671)"},
{0x8086, 0x51F0, 0x1A56, 0x1672, "Dual Band Wi-Fi 6E(802.11ax) AX1675i 160MHz 2x2 [Garfield Peak](0x1A56-0x1672)"},
{0x8086, 0x51F0, 0x1A56, 0x1692, "Simultaneous Dual Band(Double Connect) Wi-Fi 6E AX1690i 160MHz 2x2 [Garfield Peak](0x1A56-0x1692)"},
{0x8086, 0x51F0, 0x8086, 0x0034, "Dual Band Wi-Fi 5(802.11ac) Wireless-AC 9560 160MHz 2x2 [Jefferson Peak](0x8086-0x0034)"},
{0x8086, 0x51F0, 0x8086, 0x0070, "Dual Band Wi-Fi 6(802.11ax) AX201 160MHz 2x2 [Harrison Peak](0x8086-0x0070)"},
{0x8086, 0x51F0, 0x8086, 0x0074, "Dual Band Wi-Fi 6(802.11ax) AX201 160MHz 2x2 [Harrison Peak](0x8086-0x0074)"},
{0x8086, 0x51F0, 0x8086, 0x0094, "Dual Band Wi-Fi 6E(802.11ax) AX211 160MHz 2x2 [Garfield Peak](0x8086-0x0094)"},
{0x8086, 0x51F0, 0x8086, 0x00B4, "Simultaneous Dual Band(Double Connect) Wi-Fi 6E AX411 160MHz 2x2 [Garfield Peak](0x8086-0x00B4)"},
{0x8086, 0x51F0, 0x8086, 0x0234, "Dual Band Wi-Fi 5(802.11ac) Wireless-AC 9560 80MHz 2x2 [Jefferson Peak](0x8086-0x0234)"},
{0x8086, 0x51F0, 0x8086, 0x0244, "Single Band Wi-Fi 6(802.11ax) AX101 80MHz 1x1 [Harrison Peak](0x8086-0x0244)"},
{0x8086, 0x51F0, 0x8086, 0x0264, "Dual Band Wi-Fi 5(802.11ac) Wireless-AC 9461 80MHz 1x1 [Jefferson Peak](0x8086-0x0264)"},
{0x8086, 0x51F0, 0x8086, 0x0274, "Dual Band Wi-Fi E(802.11ax) AX203 80MHz 2x2 [Johnson Peak](0x8086-0x0274)"},
{0x8086, 0x51F0, 0x8086, 0x02A4, "Dual Band Wi-Fi 5(802.11ac) Wireless-AC 9462 80MHz 1x1 [Jefferson Peak](0x8086-0x02A4)"},
{0x8086, 0x51F0, 0x8086, 0x4070, "Dual Band Wi-Fi 6(802.11ax) AX201 160MHz 2x2 [Harrison Peak](0x8086-0x4070)"},
{0x8086, 0x51F0, 0x8086, 0x4090, "Dual Band Wi-Fi 6E(802.11ax) AX211 160MHz 2x2 [Garfield Peak](0x8086-0x4090)"},
{0x8086, 0x51F0, 0x8086, 0x42A4, "Dual Band Wi-Fi 5(802.11ac) Wireless-AC 9462 80MHz 1x1 [Jefferson Peak](0x8086-0x42A4)"},
{0x8086, 0x51F1, 0xFFFF, 0xFFFF, "Raptor Lake PCH CNVi WiFi(0x51F1)"},
{0x8086, 0x51F1, 0x8086, 0x4090, "Wi-Fi 6E AX211 160MHz(0x8086-0x4090)"},
{0x8086, 0x51FC, 0xFFFF, 0xFFFF, "Alder Lake-P Integrated Sensor Hub(0x51FC)"},
{0x8086, 0x51FC, 0x1028, 0x0B10, "Precision 3571(0x1028-0x0B10)"},
{0x8086, 0x51FC, 0x1028, 0x0C06, "Precision 3580(0x1028-0x0C06)"},
{0x8086, 0x5200, 0xFFFF, 0xFFFF, "EtherExpress PRO/100 Intelligent Server PCI Bridge(0x5200)"},
{0x8086, 0x5201, 0xFFFF, 0xFFFF, "EtherExpress PRO/100 Intelligent Server Fast Ethernet Controller(0x5201)"},
{0x8086, 0x5201, 0x8086, 0x0001, "EtherExpress PRO/100 Server Ethernet Adapter(0x8086-0x0001)"},
{0x8086, 0x530D, 0xFFFF, 0xFFFF, "80310 (IOP) IO Processor(0x530D)"},
{0x8086, 0x5481, 0xFFFF, 0xFFFF, "Alder Lake-N PCH eSPI Controller(0x5481)"},
{0x8086, 0x54A3, 0xFFFF, 0xFFFF, "Alder Lake-N SMBus(0x54A3)"},
{0x8086, 0x54A4, 0xFFFF, 0xFFFF, "Alder Lake-N SPI (flash) Controller(0x54A4)"},
{0x8086, 0x54A8, 0xFFFF, 0xFFFF, "Alder Lake-N Serial IO UART Host Controller(0x54A8)"},
{0x8086, 0x54B0, 0xFFFF, 0xFFFF, "Alder Lake-N PCI Express Root Port #9(0x54B0)"},
{0x8086, 0x54B1, 0xFFFF, 0xFFFF, "Alder Lake-N PCI Express Root Port #10(0x54B1)"},
{0x8086, 0x54B2, 0xFFFF, 0xFFFF, "Alder Lake-N PCI Express Root Port #11(0x54B2)"},
{0x8086, 0x54B3, 0xFFFF, 0xFFFF, "Alder Lake-N PCI Express Root Port #12(0x54B3)"},
{0x8086, 0x54C8, 0xFFFF, 0xFFFF, "Alder Lake-N PCH High Definition Audio Controller(0x54C8)"},
{0x8086, 0x54D3, 0xFFFF, 0xFFFF, "Alder Lake-N SATA AHCI Controller(0x54D3)"},
{0x8086, 0x54E0, 0xFFFF, 0xFFFF, "Alder Lake-N PCH HECI Controller(0x54E0)"},
{0x8086, 0x54ED, 0xFFFF, 0xFFFF, "Alder Lake-N PCH USB 3.2 xHCI Host Controller(0x54ED)"},
{0x8086, 0x54EF, 0xFFFF, 0xFFFF, "Alder Lake-N PCH Shared SRAM(0x54EF)"},
{0x8086, 0x54F0, 0xFFFF, 0xFFFF, "CNVi: Wi-Fi(0x54F0)"},
{0x8086, 0x54F0, 0x8086, 0x0244, "Wi-Fi 6 AX101NGW(0x8086-0x0244)"},
{0x8086, 0x5502, 0xFFFF, 0xFFFF, "Ethernet Controller (2) I225-LMvP(0x5502)"},
{0x8086, 0x5502, 0x1AB6, 0x0225, "TS4 On-Board 2.5GbE Ethernet Adaptor(0x1AB6-0x0225)"},
{0x8086, 0x5690, 0xFFFF, 0xFFFF, "DG2 [Arc A770M](0x5690)"},
{0x8086, 0x5691, 0xFFFF, 0xFFFF, "DG2 [Arc A730M](0x5691)"},
{0x8086, 0x5692, 0xFFFF, 0xFFFF, "DG2 [Arc A550M](0x5692)"},
{0x8086, 0x5693, 0xFFFF, 0xFFFF, "DG2 [Arc A370M](0x5693)"},
{0x8086, 0x5694, 0xFFFF, 0xFFFF, "DG2 [Arc A350M](0x5694)"},
{0x8086, 0x5695, 0xFFFF, 0xFFFF, "DG2 [Iris Xe MAX A200M](0x5695)"},
{0x8086, 0x5696, 0xFFFF, 0xFFFF, "DG2 [Arc A570M](0x5696)"},
{0x8086, 0x5697, 0xFFFF, 0xFFFF, "DG2 [Arc A530M](0x5697)"},
{0x8086, 0x5698, 0xFFFF, 0xFFFF, "DG2 [Arc Xe Graphics](0x5698)"},
{0x8086, 0x56A0, 0xFFFF, 0xFFFF, "DG2 [Arc A770](0x56A0)"},
{0x8086, 0x56A1, 0xFFFF, 0xFFFF, "DG2 [Arc A750](0x56A1)"},
{0x8086, 0x56A2, 0xFFFF, 0xFFFF, "DG2 [Arc A580](0x56A2)"},
{0x8086, 0x56A3, 0xFFFF, 0xFFFF, "DG2 [Arc Xe Graphics](0x56A3)"},
{0x8086, 0x56A4, 0xFFFF, 0xFFFF, "DG2 [Arc Xe Graphics](0x56A4)"},
{0x8086, 0x56A5, 0xFFFF, 0xFFFF, "DG2 [Arc A380](0x56A5)"},
{0x8086, 0x56A6, 0xFFFF, 0xFFFF, "DG2 [Arc A310](0x56A6)"},
{0x8086, 0x56A7, 0xFFFF, 0xFFFF, "DG2 [Arc Xe Graphics](0x56A7)"},
{0x8086, 0x56A8, 0xFFFF, 0xFFFF, "DG2 [Arc Xe Graphics](0x56A8)"},
{0x8086, 0x56A9, 0xFFFF, 0xFFFF, "DG2 [Arc Xe Graphics](0x56A9)"},
{0x8086, 0x56B0, 0xFFFF, 0xFFFF, "DG2 [Arc Pro A30M](0x56B0)"},
{0x8086, 0x56B1, 0xFFFF, 0xFFFF, "DG2 [Arc Pro A40/A50](0x56B1)"},
{0x8086, 0x56B2, 0xFFFF, 0xFFFF, "DG2 [Arc Pro A60M](0x56B2)"},
{0x8086, 0x56B3, 0xFFFF, 0xFFFF, "DG2 [Arc Pro A60](0x56B3)"},
{0x8086, 0x56BA, 0xFFFF, 0xFFFF, "DG2 [Intel Graphics](0x56BA)"},
{0x8086, 0x56BB, 0xFFFF, 0xFFFF, "DG2 [Intel Graphics](0x56BB)"},
{0x8086, 0x56BC, 0xFFFF, 0xFFFF, "DG2 [Intel Graphics](0x56BC)"},
{0x8086, 0x56BD, 0xFFFF, 0xFFFF, "DG2 [Intel Graphics](0x56BD)"},
{0x8086, 0x56BE, 0xFFFF, 0xFFFF, "DG2 [Arc Graphics A750E](0x56BE)"},
{0x8086, 0x56BF, 0xFFFF, 0xFFFF, "DG2 [Arc Graphics A580E](0x56BF)"},
{0x8086, 0x56C0, 0xFFFF, 0xFFFF, "ATS-M [Data Center GPU Flex 170](0x56C0)"},
{0x8086, 0x56C1, 0xFFFF, 0xFFFF, "ATS-M [Data Center GPU Flex 140](0x56C1)"},
{0x8086, 0x56C2, 0xFFFF, 0xFFFF, "ATS-M [Data Center GPU Flex 170V](0x56C2)"},
{0x8086, 0x5780, 0xFFFF, 0xFFFF, "Thunderbolt 80/120G Bridge [Barlow Ridge Host 80G 2023](0x5780)"},
{0x8086, 0x5781, 0xFFFF, 0xFFFF, "Thunderbolt 80/120G NHI [Barlow Ridge Host 80G 2023](0x5781)"},
{0x8086, 0x5782, 0xFFFF, 0xFFFF, "Thunderbolt 80/120G USB Controller [Barlow Ridge Host 80G 2023](0x5782)"},
{0x8086, 0x5783, 0xFFFF, 0xFFFF, "Thunderbolt Bridge [Barlow Ridge Host 40G 2023](0x5783)"},
{0x8086, 0x5784, 0xFFFF, 0xFFFF, "Thunderbolt NHI [Barlow Ridge Host 40G 2023](0x5784)"},
{0x8086, 0x5785, 0xFFFF, 0xFFFF, "Thunderbolt USB Controller [Barlow Ridge Host 40G 2023](0x5785)"},
{0x8086, 0x5786, 0xFFFF, 0xFFFF, "Thunderbolt 80/120G Bridge [Barlow Ridge Hub 80G 2023](0x5786)"},
{0x8086, 0x5787, 0xFFFF, 0xFFFF, "Thunderbolt 80/120G USB Controller [Barlow Ridge Hub 80G 2023](0x5787)"},
{0x8086, 0x579C, 0xFFFF, 0xFFFF, "Ethernet Connection E825-C for backplane(0x579C)"},
{0x8086, 0x579D, 0xFFFF, 0xFFFF, "Ethernet Connection E825-C for QSFP(0x579D)"},
{0x8086, 0x579E, 0xFFFF, 0xFFFF, "Ethernet Connection E825-C for SFP(0x579E)"},
{0x8086, 0x57A4, 0xFFFF, 0xFFFF, "Thunderbolt Bridge [Barlow Ridge Hub 40G 2023](0x57A4)"},
{0x8086, 0x57A5, 0xFFFF, 0xFFFF, "Thunderbolt USB Controller [Barlow Ridge Hub 40G 2023](0x57A5)"},
{0x8086, 0x57AE, 0xFFFF, 0xFFFF, "Ethernet Controller E610 Backplane(0x57AE)"},
{0x8086, 0x57AF, 0xFFFF, 0xFFFF, "Ethernet Controller E610 SFP(0x57AF)"},
{0x8086, 0x57B0, 0xFFFF, 0xFFFF, "Ethernet Controller E610 10GBASE T(0x57B0)"},
{0x8086, 0x57B1, 0xFFFF, 0xFFFF, "Ethernet Controller E610 2.5GBASE T(0x57B1)"},
{0x8086, 0x57B1, 0x8086, 0x0000, "Ethernet Converged Network Adapter E610(0x8086-0x0000)"},
{0x8086, 0x57B2, 0xFFFF, 0xFFFF, "Ethernet Controller E610 SGMII(0x57B2)"},
{0x8086, 0x5845, 0xFFFF, 0xFFFF, "QEMU NVM Express Controller(0x5845)"},
{0x8086, 0x5845, 0x1AF4, 0x1100, "QEMU Virtual Machine(0x1AF4-0x1100)"},
{0x8086, 0x5900, 0xFFFF, 0xFFFF, "Xeon E3-1200 v6/7th Gen Core Processor Host Bridge/DRAM Registers(0x5900)"},
{0x8086, 0x5901, 0xFFFF, 0xFFFF, "Xeon E3-1200 v6/7th Gen Core Processor PCIe Controller (x16)(0x5901)"},
{0x8086, 0x5902, 0xFFFF, 0xFFFF, "HD Graphics 610(0x5902)"},
{0x8086, 0x5904, 0xFFFF, 0xFFFF, "Xeon E3-1200 v6/7th Gen Core Processor Host Bridge/DRAM Registers(0x5904)"},
{0x8086, 0x5904, 0x1025, 0x115F, "Aspire E5-575G(0x1025-0x115F)"},
{0x8086, 0x5904, 0x17AA, 0x2247, "ThinkPad T570(0x17AA-0x2247)"},
{0x8086, 0x5904, 0x17AA, 0x224F, "ThinkPad X1 Carbon 5th Gen(0x17AA-0x224F)"},
{0x8086, 0x5905, 0xFFFF, 0xFFFF, "Xeon E3-1200 v6/7th Gen Core Processor PCIe Controller (x8)(0x5905)"},
{0x8086, 0x5906, 0xFFFF, 0xFFFF, "HD Graphics 610(0x5906)"},
{0x8086, 0x5909, 0xFFFF, 0xFFFF, "Xeon E3-1200 v6/7th Gen Core Processor PCIe Controller (x4)(0x5909)"},
{0x8086, 0x590B, 0xFFFF, 0xFFFF, "HD Graphics 610(0x590B)"},
{0x8086, 0x590C, 0xFFFF, 0xFFFF, "Xeon E3-1200 v6/7th Gen Core Processor Host Bridge/DRAM Registers(0x590C)"},
{0x8086, 0x590F, 0xFFFF, 0xFFFF, "Xeon E3-1200 v6/7th Gen Core Processor Host Bridge/DRAM Registers(0x590F)"},
{0x8086, 0x590F, 0x1043, 0x8694, "H110I-PLUS Motherboard(0x1043-0x8694)"},
{0x8086, 0x590F, 0x1462, 0x7994, "H110M ECO/GAMING(0x1462-0x7994)"},
{0x8086, 0x590F, 0x1462, 0x7A68, "B250 KRAIT GAMING (MS-7A68)(0x1462-0x7A68)"},
{0x8086, 0x590F, 0x1462, 0x7A72, "H270 PC MATE(0x1462-0x7A72)"},
{0x8086, 0x5910, 0xFFFF, 0xFFFF, "Xeon E3-1200 v6/7th Gen Core Processor Host Bridge/DRAM Registers(0x5910)"},
{0x8086, 0x5911, 0xFFFF, 0xFFFF, "Xeon E3-1200 v6/7th Gen Core Processor Gaussian Mixture Model(0x5911)"},
{0x8086, 0x5912, 0xFFFF, 0xFFFF, "HD Graphics 630(0x5912)"},
{0x8086, 0x5912, 0x1043, 0x8694, "H110I-PLUS Motherboard(0x1043-0x8694)"},
{0x8086, 0x5912, 0x1462, 0x7994, "H110M ECO/GAMING(0x1462-0x7994)"},
{0x8086, 0x5912, 0x1462, 0x7A72, "H270 PC MATE(0x1462-0x7A72)"},
{0x8086, 0x5914, 0xFFFF, 0xFFFF, "Xeon E3-1200 v6/7th Gen Core Processor Host Bridge/DRAM Registers(0x5914)"},
{0x8086, 0x5914, 0x17AA, 0x225D, "ThinkPad T480(0x17AA-0x225D)"},
{0x8086, 0x5916, 0xFFFF, 0xFFFF, "HD Graphics 620(0x5916)"},
{0x8086, 0x5916, 0x1025, 0x1094, "Aspire E5-575G(0x1025-0x1094)"},
{0x8086, 0x5916, 0x17AA, 0x2248, "ThinkPad T570(0x17AA-0x2248)"},
{0x8086, 0x5916, 0x17AA, 0x224F, "ThinkPad X1 Carbon 5th Gen(0x17AA-0x224F)"},
{0x8086, 0x5917, 0xFFFF, 0xFFFF, "UHD Graphics 620(0x5917)"},
{0x8086, 0x5917, 0x17AA, 0x225E, "ThinkPad T480(0x17AA-0x225E)"},
{0x8086, 0x5918, 0xFFFF, 0xFFFF, "Xeon E3-1200 v6/7th Gen Core Processor Host Bridge/DRAM Registers(0x5918)"},
{0x8086, 0x591B, 0xFFFF, 0xFFFF, "HD Graphics 630(0x591B)"},
{0x8086, 0x591C, 0xFFFF, 0xFFFF, "UHD Graphics 615(0x591C)"},
{0x8086, 0x591D, 0xFFFF, 0xFFFF, "HD Graphics P630(0x591D)"},
{0x8086, 0x591E, 0xFFFF, 0xFFFF, "HD Graphics 615(0x591E)"},
{0x8086, 0x591F, 0xFFFF, 0xFFFF, "Xeon E3-1200 v6/7th Gen Core Processor Host Bridge/DRAM Registers(0x591F)"},
{0x8086, 0x5921, 0xFFFF, 0xFFFF, "HD Graphics 620(0x5921)"},
{0x8086, 0x5923, 0xFFFF, 0xFFFF, "HD Graphics 635(0x5923)"},
{0x8086, 0x5926, 0xFFFF, 0xFFFF, "Iris Plus Graphics 640(0x5926)"},
{0x8086, 0x5927, 0xFFFF, 0xFFFF, "Iris Plus Graphics 650(0x5927)"},
{0x8086, 0x5A84, 0xFFFF, 0xFFFF, "Apollo Lake [HD Graphics 505](0x5A84)"},
{0x8086, 0x5A85, 0xFFFF, 0xFFFF, "HD Graphics 500(0x5A85)"},
{0x8086, 0x5A88, 0xFFFF, 0xFFFF, "Celeron N3350/Pentium N4200/Atom E3900 Series Imaging Unit(0x5A88)"},
{0x8086, 0x5A98, 0xFFFF, 0xFFFF, "Celeron N3350/Pentium N4200/Atom E3900 Series Audio Cluster(0x5A98)"},
{0x8086, 0x5A9A, 0xFFFF, 0xFFFF, "Celeron N3350/Pentium N4200/Atom E3900 Series Trusted Execution Engine(0x5A9A)"},
{0x8086, 0x5AA2, 0xFFFF, 0xFFFF, "Celeron N3350/Pentium N4200/Atom E3900 Series Integrated Sensor Hub(0x5AA2)"},
{0x8086, 0x5AA8, 0xFFFF, 0xFFFF, "Celeron N3350/Pentium N4200/Atom E3900 Series USB xHCI(0x5AA8)"},
{0x8086, 0x5AAC, 0xFFFF, 0xFFFF, "Celeron N3350/Pentium N4200/Atom E3900 Series I2C Controller #1(0x5AAC)"},
{0x8086, 0x5AAE, 0xFFFF, 0xFFFF, "Celeron N3350/Pentium N4200/Atom E3900 Series I2C Controller #2(0x5AAE)"},
{0x8086, 0x5AB0, 0xFFFF, 0xFFFF, "Celeron N3350/Pentium N4200/Atom E3900 Series I2C Controller #3(0x5AB0)"},
{0x8086, 0x5AB2, 0xFFFF, 0xFFFF, "Celeron N3350/Pentium N4200/Atom E3900 Series I2C Controller #4(0x5AB2)"},
{0x8086, 0x5AB4, 0xFFFF, 0xFFFF, "Celeron N3350/Pentium N4200/Atom E3900 Series I2C Controller #5(0x5AB4)"},
{0x8086, 0x5AB6, 0xFFFF, 0xFFFF, "Celeron N3350/Pentium N4200/Atom E3900 Series I2C Controller #6(0x5AB6)"},
{0x8086, 0x5AB8, 0xFFFF, 0xFFFF, "Celeron N3350/Pentium N4200/Atom E3900 Series I2C Controller #7(0x5AB8)"},
{0x8086, 0x5ABA, 0xFFFF, 0xFFFF, "Celeron N3350/Pentium N4200/Atom E3900 Series I2C Controller #8(0x5ABA)"},
{0x8086, 0x5ABC, 0xFFFF, 0xFFFF, "Celeron N3350/Pentium N4200/Atom E3900 Series HSUART Controller #1(0x5ABC)"},
{0x8086, 0x5ABE, 0xFFFF, 0xFFFF, "Celeron N3350/Pentium N4200/Atom E3900 Series HSUART Controller #2(0x5ABE)"},
{0x8086, 0x5AC0, 0xFFFF, 0xFFFF, "Celeron N3350/Pentium N4200/Atom E3900 Series HSUART Controller #3(0x5AC0)"},
{0x8086, 0x5AC2, 0xFFFF, 0xFFFF, "Celeron N3350/Pentium N4200/Atom E3900 Series SPI Controller #1(0x5AC2)"},
{0x8086, 0x5AC4, 0xFFFF, 0xFFFF, "Celeron N3350/Pentium N4200/Atom E3900 Series SPI Controller #2(0x5AC4)"},
{0x8086, 0x5AC6, 0xFFFF, 0xFFFF, "Celeron N3350/Pentium N4200/Atom E3900 Series SPI Controller #3(0x5AC6)"},
{0x8086, 0x5AC8, 0xFFFF, 0xFFFF, "Celeron N3350/Pentium N4200/Atom E3900 Series PWM Pin Controller(0x5AC8)"},
{0x8086, 0x5ACA, 0xFFFF, 0xFFFF, "Celeron N3350/Pentium N4200/Atom E3900 Series SDXC/MMC Host Controller(0x5ACA)"},
{0x8086, 0x5ACC, 0xFFFF, 0xFFFF, "Celeron N3350/Pentium N4200/Atom E3900 Series eMMC Controller(0x5ACC)"},
{0x8086, 0x5AD0, 0xFFFF, 0xFFFF, "Celeron N3350/Pentium N4200/Atom E3900 Series SDIO Controller(0x5AD0)"},
{0x8086, 0x5AD4, 0xFFFF, 0xFFFF, "Celeron N3350/Pentium N4200/Atom E3900 Series SMBus Controller(0x5AD4)"},
{0x8086, 0x5AD6, 0xFFFF, 0xFFFF, "Celeron N3350/Pentium N4200/Atom E3900 Series PCI Express Port B #1(0x5AD6)"},
{0x8086, 0x5AD7, 0xFFFF, 0xFFFF, "Celeron N3350/Pentium N4200/Atom E3900 Series PCI Express Port B #2(0x5AD7)"},
{0x8086, 0x5AD8, 0xFFFF, 0xFFFF, "Celeron N3350/Pentium N4200/Atom E3900 Series PCI Express Port A #1(0x5AD8)"},
{0x8086, 0x5AD9, 0xFFFF, 0xFFFF, "Celeron N3350/Pentium N4200/Atom E3900 Series PCI Express Port A #2(0x5AD9)"},
{0x8086, 0x5ADA, 0xFFFF, 0xFFFF, "Celeron N3350/Pentium N4200/Atom E3900 Series PCI Express Port A #3(0x5ADA)"},
{0x8086, 0x5ADB, 0xFFFF, 0xFFFF, "Celeron N3350/Pentium N4200/Atom E3900 Series PCI Express Port A #4(0x5ADB)"},
{0x8086, 0x5AE3, 0xFFFF, 0xFFFF, "Celeron N3350/Pentium N4200/Atom E3900 Series SATA AHCI Controller(0x5AE3)"},
{0x8086, 0x5AE8, 0xFFFF, 0xFFFF, "Celeron N3350/Pentium N4200/Atom E3900 Series Low Pin Count Interface(0x5AE8)"},
{0x8086, 0x5AEE, 0xFFFF, 0xFFFF, "Celeron N3350/Pentium N4200/Atom E3900 Series HSUART Controller #4(0x5AEE)"},
{0x8086, 0x5AF0, 0xFFFF, 0xFFFF, "Celeron N3350/Pentium N4200/Atom E3900 Series Host Bridge(0x5AF0)"},
{0x8086, 0x6420, 0xFFFF, 0xFFFF, "Lunar Lake [Intel Graphics](0x6420)"},
{0x8086, 0x643E, 0xFFFF, 0xFFFF, "Lunar Lake NPU(0x643E)"},
{0x8086, 0x64A0, 0xFFFF, 0xFFFF, "Lunar Lake [Intel Graphics](0x64A0)"},
{0x8086, 0x64B0, 0xFFFF, 0xFFFF, "Lunar Lake [Intel Graphics](0x64B0)"},
{0x8086, 0x65C0, 0xFFFF, 0xFFFF, "5100 Chipset Memory Controller Hub(0x65C0)"},
{0x8086, 0x65E2, 0xFFFF, 0xFFFF, "5100 Chipset PCI Express x4 Port 2(0x65E2)"},
{0x8086, 0x65E3, 0xFFFF, 0xFFFF, "5100 Chipset PCI Express x4 Port 3(0x65E3)"},
{0x8086, 0x65E4, 0xFFFF, 0xFFFF, "5100 Chipset PCI Express x4 Port 4(0x65E4)"},
{0x8086, 0x65E5, 0xFFFF, 0xFFFF, "5100 Chipset PCI Express x4 Port 5(0x65E5)"},
{0x8086, 0x65E6, 0xFFFF, 0xFFFF, "5100 Chipset PCI Express x4 Port 6(0x65E6)"},
{0x8086, 0x65E7, 0xFFFF, 0xFFFF, "5100 Chipset PCI Express x4 Port 7(0x65E7)"},
{0x8086, 0x65F0, 0xFFFF, 0xFFFF, "5100 Chipset FSB Registers(0x65F0)"},
{0x8086, 0x65F0, 0x1028, 0x020F, "PowerEdge R300(0x1028-0x020F)"},
{0x8086, 0x65F0, 0x1028, 0x0210, "PowerEdge T300(0x1028-0x0210)"},
{0x8086, 0x65F1, 0xFFFF, 0xFFFF, "5100 Chipset Reserved Registers(0x65F1)"},
{0x8086, 0x65F1, 0x1028, 0x0210, "PowerEdge T300(0x1028-0x0210)"},
{0x8086, 0x65F3, 0xFFFF, 0xFFFF, "5100 Chipset Reserved Registers(0x65F3)"},
{0x8086, 0x65F5, 0xFFFF, 0xFFFF, "5100 Chipset DDR Channel 0 Registers(0x65F5)"},
{0x8086, 0x65F6, 0xFFFF, 0xFFFF, "5100 Chipset DDR Channel 1 Registers(0x65F6)"},
{0x8086, 0x65F7, 0xFFFF, 0xFFFF, "5100 Chipset PCI Express x8 Port 2-3(0x65F7)"},
{0x8086, 0x65F8, 0xFFFF, 0xFFFF, "5100 Chipset PCI Express x8 Port 4-5(0x65F8)"},
{0x8086, 0x65F9, 0xFFFF, 0xFFFF, "5100 Chipset PCI Express x8 Port 6-7(0x65F9)"},
{0x8086, 0x65FA, 0xFFFF, 0xFFFF, "5100 Chipset PCI Express x16 Port 4-7(0x65FA)"},
{0x8086, 0x65FF, 0xFFFF, 0xFFFF, "5100 Chipset DMA Engine(0x65FF)"},
{0x8086, 0x6F00, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D DMI2(0x6F00)"},
{0x8086, 0x6F00, 0x15D9, 0x0832, "X10SRL-F(0x15D9-0x0832)"},
{0x8086, 0x6F01, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D PCI Express Root Port 0(0x6F01)"},
{0x8086, 0x6F02, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D PCI Express Root Port 1(0x6F02)"},
{0x8086, 0x6F03, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D PCI Express Root Port 1(0x6F03)"},
{0x8086, 0x6F04, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D PCI Express Root Port 2(0x6F04)"},
{0x8086, 0x6F05, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D PCI Express Root Port 2(0x6F05)"},
{0x8086, 0x6F06, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D PCI Express Root Port 2(0x6F06)"},
{0x8086, 0x6F07, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D PCI Express Root Port 2(0x6F07)"},
{0x8086, 0x6F08, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D PCI Express Root Port 3(0x6F08)"},
{0x8086, 0x6F09, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D PCI Express Root Port 3(0x6F09)"},
{0x8086, 0x6F0A, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D PCI Express Root Port 3(0x6F0A)"},
{0x8086, 0x6F0B, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D PCI Express Root Port 3(0x6F0B)"},
{0x8086, 0x6F10, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D IIO Debug(0x6F10)"},
{0x8086, 0x6F11, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D IIO Debug(0x6F11)"},
{0x8086, 0x6F12, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D IIO Debug(0x6F12)"},
{0x8086, 0x6F13, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D IIO Debug(0x6F13)"},
{0x8086, 0x6F14, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D IIO Debug(0x6F14)"},
{0x8086, 0x6F15, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D IIO Debug(0x6F15)"},
{0x8086, 0x6F16, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D IIO Debug(0x6F16)"},
{0x8086, 0x6F17, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D IIO Debug(0x6F17)"},
{0x8086, 0x6F18, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D IIO Debug(0x6F18)"},
{0x8086, 0x6F19, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D IIO Debug(0x6F19)"},
{0x8086, 0x6F1A, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D IIO Debug(0x6F1A)"},
{0x8086, 0x6F1B, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D IIO Debug(0x6F1B)"},
{0x8086, 0x6F1C, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D IIO Debug(0x6F1C)"},
{0x8086, 0x6F1D, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D R2PCIe Agent(0x6F1D)"},
{0x8086, 0x6F1E, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Ubox(0x6F1E)"},
{0x8086, 0x6F1F, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Ubox(0x6F1F)"},
{0x8086, 0x6F20, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Crystal Beach DMA Channel 0(0x6F20)"},
{0x8086, 0x6F20, 0x15D9, 0x0832, "X10SRL-F(0x15D9-0x0832)"},
{0x8086, 0x6F21, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Crystal Beach DMA Channel 1(0x6F21)"},
{0x8086, 0x6F21, 0x15D9, 0x0832, "X10SRL-F(0x15D9-0x0832)"},
{0x8086, 0x6F22, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Crystal Beach DMA Channel 2(0x6F22)"},
{0x8086, 0x6F22, 0x15D9, 0x0832, "X10SRL-F(0x15D9-0x0832)"},
{0x8086, 0x6F23, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Crystal Beach DMA Channel 3(0x6F23)"},
{0x8086, 0x6F23, 0x15D9, 0x0832, "X10SRL-F(0x15D9-0x0832)"},
{0x8086, 0x6F24, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Crystal Beach DMA Channel 4(0x6F24)"},
{0x8086, 0x6F24, 0x15D9, 0x0832, "X10SRL-F(0x15D9-0x0832)"},
{0x8086, 0x6F25, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Crystal Beach DMA Channel 5(0x6F25)"},
{0x8086, 0x6F25, 0x15D9, 0x0832, "X10SRL-F(0x15D9-0x0832)"},
{0x8086, 0x6F26, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Crystal Beach DMA Channel 6(0x6F26)"},
{0x8086, 0x6F26, 0x15D9, 0x0832, "X10SRL-F(0x15D9-0x0832)"},
{0x8086, 0x6F27, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Crystal Beach DMA Channel 7(0x6F27)"},
{0x8086, 0x6F27, 0x15D9, 0x0832, "X10SRL-F(0x15D9-0x0832)"},
{0x8086, 0x6F28, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Map/VTd_Misc/System Management(0x6F28)"},
{0x8086, 0x6F28, 0x15D9, 0x0832, "X10SRL-F(0x15D9-0x0832)"},
{0x8086, 0x6F29, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D IIO Hot Plug(0x6F29)"},
{0x8086, 0x6F29, 0x15D9, 0x0832, "X10SRL-F(0x15D9-0x0832)"},
{0x8086, 0x6F2A, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D IIO RAS/Control Status/Global Errors(0x6F2A)"},
{0x8086, 0x6F2A, 0x15D9, 0x0832, "X10SRL-F(0x15D9-0x0832)"},
{0x8086, 0x6F2C, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D I/O APIC(0x6F2C)"},
{0x8086, 0x6F2C, 0x15D9, 0x0832, "X10SRL-F(0x15D9-0x0832)"},
{0x8086, 0x6F30, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Home Agent 0(0x6F30)"},
{0x8086, 0x6F32, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D QPI Link 0(0x6F32)"},
{0x8086, 0x6F33, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D QPI Link 1(0x6F33)"},
{0x8086, 0x6F34, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D R2PCIe Agent(0x6F34)"},
{0x8086, 0x6F36, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D R3 QPI Link 0/1(0x6F36)"},
{0x8086, 0x6F37, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D R3 QPI Link 0/1(0x6F37)"},
{0x8086, 0x6F38, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Home Agent 1(0x6F38)"},
{0x8086, 0x6F39, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D IO Performance Monitoring(0x6F39)"},
{0x8086, 0x6F3A, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D QPI Link 2(0x6F3A)"},
{0x8086, 0x6F3E, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D R3 QPI Link 2(0x6F3E)"},
{0x8086, 0x6F3F, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D R3 QPI Link 2(0x6F3F)"},
{0x8086, 0x6F40, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D QPI Link 2(0x6F40)"},
{0x8086, 0x6F41, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D R3 QPI Link 2(0x6F41)"},
{0x8086, 0x6F43, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D QPI Link 2(0x6F43)"},
{0x8086, 0x6F45, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D QPI Link 2 Debug(0x6F45)"},
{0x8086, 0x6F46, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D QPI Link 2 Debug(0x6F46)"},
{0x8086, 0x6F47, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D QPI Link 2 Debug(0x6F47)"},
{0x8086, 0x6F50, 0xFFFF, 0xFFFF, "Xeon Processor D Family QuickData Technology Register DMA Channel 0(0x6F50)"},
{0x8086, 0x6F51, 0xFFFF, 0xFFFF, "Xeon Processor D Family QuickData Technology Register DMA Channel 1(0x6F51)"},
{0x8086, 0x6F52, 0xFFFF, 0xFFFF, "Xeon Processor D Family QuickData Technology Register DMA Channel 2(0x6F52)"},
{0x8086, 0x6F53, 0xFFFF, 0xFFFF, "Xeon Processor D Family QuickData Technology Register DMA Channel 3(0x6F53)"},
{0x8086, 0x6F54, 0xFFFF, 0xFFFF, "Xeon Processor D Family QuickAssist Technology(0x6F54)"},
{0x8086, 0x6F55, 0xFFFF, 0xFFFF, "Xeon Processor D Family QuickAssist Technology Virtual Fuction(0x6F55)"},
{0x8086, 0x6F60, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Home Agent 1(0x6F60)"},
{0x8086, 0x6F68, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Target Address/Thermal/RAS(0x6F68)"},
{0x8086, 0x6F6A, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Channel Target Address Decoder(0x6F6A)"},
{0x8086, 0x6F6B, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Channel Target Address Decoder(0x6F6B)"},
{0x8086, 0x6F6C, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Channel Target Address Decoder(0x6F6C)"},
{0x8086, 0x6F6D, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Channel Target Address Decoder(0x6F6D)"},
{0x8086, 0x6F6E, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D DDRIO Channel 2/3 Broadcast(0x6F6E)"},
{0x8086, 0x6F6F, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D DDRIO Global Broadcast(0x6F6F)"},
{0x8086, 0x6F70, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Home Agent 0 Debug(0x6F70)"},
{0x8086, 0x6F71, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Memory Controller 0 - Target Address/Thermal/RAS(0x6F71)"},
{0x8086, 0x6F76, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D R3 QPI Link Debug(0x6F76)"},
{0x8086, 0x6F78, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Home Agent 1 Debug(0x6F78)"},
{0x8086, 0x6F79, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Target Address/Thermal/RAS(0x6F79)"},
{0x8086, 0x6F7D, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Ubox(0x6F7D)"},
{0x8086, 0x6F7E, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D R3 QPI Link Debug(0x6F7E)"},
{0x8086, 0x6F80, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D QPI Link 0(0x6F80)"},
{0x8086, 0x6F81, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D R3 QPI Link 0/1(0x6F81)"},
{0x8086, 0x6F83, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D QPI Link 0(0x6F83)"},
{0x8086, 0x6F85, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D QPI Link 0 Debug(0x6F85)"},
{0x8086, 0x6F86, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D QPI Link 0 Debug(0x6F86)"},
{0x8086, 0x6F87, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D QPI Link 0 Debug(0x6F87)"},
{0x8086, 0x6F88, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Power Control Unit(0x6F88)"},
{0x8086, 0x6F8A, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Power Control Unit(0x6F8A)"},
{0x8086, 0x6F90, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D QPI Link 1(0x6F90)"},
{0x8086, 0x6F93, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D QPI Link 1(0x6F93)"},
{0x8086, 0x6F95, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D QPI Link 1 Debug(0x6F95)"},
{0x8086, 0x6F96, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D QPI Link 1 Debug(0x6F96)"},
{0x8086, 0x6F98, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Power Control Unit(0x6F98)"},
{0x8086, 0x6F99, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Power Control Unit(0x6F99)"},
{0x8086, 0x6F9A, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Power Control Unit(0x6F9A)"},
{0x8086, 0x6F9C, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Power Control Unit(0x6F9C)"},
{0x8086, 0x6FA0, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Home Agent 0(0x6FA0)"},
{0x8086, 0x6FA8, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Memory Controller 0 - Target Address/Thermal/RAS(0x6FA8)"},
{0x8086, 0x6FAA, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Memory Controller 0 - Channel Target Address Decoder(0x6FAA)"},
{0x8086, 0x6FAB, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Memory Controller 0 - Channel Target Address Decoder(0x6FAB)"},
{0x8086, 0x6FAC, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Memory Controller 0 - Channel Target Address Decoder(0x6FAC)"},
{0x8086, 0x6FAD, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Memory Controller 0 - Channel Target Address Decoder(0x6FAD)"},
{0x8086, 0x6FAE, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D DDRIO Channel 0/1 Broadcast(0x6FAE)"},
{0x8086, 0x6FAF, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D DDRIO Global Broadcast(0x6FAF)"},
{0x8086, 0x6FB0, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Memory Controller 0 - Channel 0 Thermal Control(0x6FB0)"},
{0x8086, 0x6FB1, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Memory Controller 0 - Channel 1 Thermal Control(0x6FB1)"},
{0x8086, 0x6FB2, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Memory Controller 0 - Channel 0 Error(0x6FB2)"},
{0x8086, 0x6FB3, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Memory Controller 0 - Channel 1 Error(0x6FB3)"},
{0x8086, 0x6FB4, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Memory Controller 0 - Channel 2 Thermal Control(0x6FB4)"},
{0x8086, 0x6FB5, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Memory Controller 0 - Channel 3 Thermal Control(0x6FB5)"},
{0x8086, 0x6FB6, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Memory Controller 0 - Channel 2 Error(0x6FB6)"},
{0x8086, 0x6FB7, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Memory Controller 0 - Channel 3 Error(0x6FB7)"},
{0x8086, 0x6FB8, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D DDRIO Channel 2/3 Interface(0x6FB8)"},
{0x8086, 0x6FB9, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D DDRIO Channel 2/3 Interface(0x6FB9)"},
{0x8086, 0x6FBA, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D DDRIO Channel 2/3 Interface(0x6FBA)"},
{0x8086, 0x6FBB, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D DDRIO Channel 2/3 Interface(0x6FBB)"},
{0x8086, 0x6FBC, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D DDRIO Channel 0/1 Interface(0x6FBC)"},
{0x8086, 0x6FBD, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D DDRIO Channel 0/1 Interface(0x6FBD)"},
{0x8086, 0x6FBE, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D DDRIO Channel 0/1 Interface(0x6FBE)"},
{0x8086, 0x6FBF, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D DDRIO Channel 0/1 Interface(0x6FBF)"},
{0x8086, 0x6FC0, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Power Control Unit(0x6FC0)"},
{0x8086, 0x6FC1, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Power Control Unit(0x6FC1)"},
{0x8086, 0x6FC2, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Power Control Unit(0x6FC2)"},
{0x8086, 0x6FC3, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Power Control Unit(0x6FC3)"},
{0x8086, 0x6FC4, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Power Control Unit(0x6FC4)"},
{0x8086, 0x6FC5, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Power Control Unit(0x6FC5)"},
{0x8086, 0x6FC6, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Power Control Unit(0x6FC6)"},
{0x8086, 0x6FC7, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Power Control Unit(0x6FC7)"},
{0x8086, 0x6FC8, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Power Control Unit(0x6FC8)"},
{0x8086, 0x6FC9, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Power Control Unit(0x6FC9)"},
{0x8086, 0x6FCA, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Power Control Unit(0x6FCA)"},
{0x8086, 0x6FCB, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Power Control Unit(0x6FCB)"},
{0x8086, 0x6FCC, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Power Control Unit(0x6FCC)"},
{0x8086, 0x6FCD, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Power Control Unit(0x6FCD)"},
{0x8086, 0x6FCE, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Power Control Unit(0x6FCE)"},
{0x8086, 0x6FCF, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Power Control Unit(0x6FCF)"},
{0x8086, 0x6FD0, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Memory Controller 1 - Channel 0 Thermal Control(0x6FD0)"},
{0x8086, 0x6FD1, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Memory Controller 1 - Channel 1 Thermal Control(0x6FD1)"},
{0x8086, 0x6FD2, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Memory Controller 1 - Channel 0 Error(0x6FD2)"},
{0x8086, 0x6FD3, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Memory Controller 1 - Channel 1 Error(0x6FD3)"},
{0x8086, 0x6FD4, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Memory Controller 1 - Channel 2 Thermal Control(0x6FD4)"},
{0x8086, 0x6FD5, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Memory Controller 1 - Channel 3 Thermal Control(0x6FD5)"},
{0x8086, 0x6FD6, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Memory Controller 1 - Channel 2 Error(0x6FD6)"},
{0x8086, 0x6FD7, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Memory Controller 1 - Channel 3 Error(0x6FD7)"},
{0x8086, 0x6FE0, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Caching Agent(0x6FE0)"},
{0x8086, 0x6FE1, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Caching Agent(0x6FE1)"},
{0x8086, 0x6FE2, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Caching Agent(0x6FE2)"},
{0x8086, 0x6FE3, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Caching Agent(0x6FE3)"},
{0x8086, 0x6FE4, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Caching Agent(0x6FE4)"},
{0x8086, 0x6FE5, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Caching Agent(0x6FE5)"},
{0x8086, 0x6FE6, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Caching Agent(0x6FE6)"},
{0x8086, 0x6FE7, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Caching Agent(0x6FE7)"},
{0x8086, 0x6FE8, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Caching Agent(0x6FE8)"},
{0x8086, 0x6FE9, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Caching Agent(0x6FE9)"},
{0x8086, 0x6FEA, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Caching Agent(0x6FEA)"},
{0x8086, 0x6FEB, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Caching Agent(0x6FEB)"},
{0x8086, 0x6FEC, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Caching Agent(0x6FEC)"},
{0x8086, 0x6FED, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Caching Agent(0x6FED)"},
{0x8086, 0x6FEE, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Caching Agent(0x6FEE)"},
{0x8086, 0x6FEF, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Caching Agent(0x6FEF)"},
{0x8086, 0x6FF0, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Caching Agent(0x6FF0)"},
{0x8086, 0x6FF1, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Caching Agent(0x6FF1)"},
{0x8086, 0x6FF8, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Caching Agent(0x6FF8)"},
{0x8086, 0x6FF9, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Caching Agent(0x6FF9)"},
{0x8086, 0x6FFA, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Caching Agent(0x6FFA)"},
{0x8086, 0x6FFB, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Caching Agent(0x6FFB)"},
{0x8086, 0x6FFC, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Caching Agent(0x6FFC)"},
{0x8086, 0x6FFD, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Caching Agent(0x6FFD)"},
{0x8086, 0x6FFE, 0xFFFF, 0xFFFF, "Xeon E7 v4/Xeon E5 v4/Xeon E3 v4/Xeon D Caching Agent(0x6FFE)"},
{0x8086, 0x7000, 0xFFFF, 0xFFFF, "82371SB PIIX3 ISA [Natoma/Triton II](0x7000)"},
{0x8086, 0x7000, 0x01DE, 0xFFFD, "Propolis Virtual PIIX3 ISA Controller(0x01DE-0xFFFD)"},
{0x8086, 0x7000, 0x1AF4, 0x1100, "Qemu virtual machine(0x1AF4-0x1100)"},
{0x8086, 0x7010, 0xFFFF, 0xFFFF, "82371SB PIIX3 IDE [Natoma/Triton II](0x7010)"},
{0x8086, 0x7010, 0x1AF4, 0x1100, "Qemu virtual machine(0x1AF4-0x1100)"},
{0x8086, 0x7020, 0xFFFF, 0xFFFF, "82371SB PIIX3 USB [Natoma/Triton II](0x7020)"},
{0x8086, 0x7020, 0x1AF4, 0x1100, "QEMU Virtual Machine(0x1AF4-0x1100)"},
{0x8086, 0x7030, 0xFFFF, 0xFFFF, "430VX - 82437VX TVX [Triton VX](0x7030)"},
{0x8086, 0x7050, 0xFFFF, 0xFFFF, "Intercast Video Capture Card(0x7050)"},
{0x8086, 0x7051, 0xFFFF, 0xFFFF, "PB 642365-003 (Business Video Conferencing Card)(0x7051)"},
{0x8086, 0x7100, 0xFFFF, 0xFFFF, "430TX - 82439TX MTXC(0x7100)"},
{0x8086, 0x7110, 0xFFFF, 0xFFFF, "82371AB/EB/MB PIIX4 ISA(0x7110)"},
{0x8086, 0x7110, 0x15AD, 0x1976, "Virtual Machine Chipset(0x15AD-0x1976)"},
{0x8086, 0x7111, 0xFFFF, 0xFFFF, "82371AB/EB/MB PIIX4 IDE(0x7111)"},
{0x8086, 0x7111, 0x15AD, 0x1976, "Virtual Machine Chipset(0x15AD-0x1976)"},
{0x8086, 0x7112, 0xFFFF, 0xFFFF, "82371AB/EB/MB PIIX4 USB(0x7112)"},
{0x8086, 0x7112, 0x15AD, 0x1976, "Virtual Machine Chipset(0x15AD-0x1976)"},
{0x8086, 0x7112, 0x1AF4, 0x1100, "QEMU Virtual Machine(0x1AF4-0x1100)"},
{0x8086, 0x7113, 0xFFFF, 0xFFFF, "82371AB/EB/MB PIIX4 ACPI(0x7113)"},
{0x8086, 0x7113, 0x01DE, 0xFFFC, "Propolis Virtual PIIX4 PM Controller(0x01DE-0xFFFC)"},
{0x8086, 0x7113, 0x15AD, 0x1976, "Virtual Machine Chipset(0x15AD-0x1976)"},
{0x8086, 0x7113, 0x1AF4, 0x1100, "Qemu virtual machine(0x1AF4-0x1100)"},
{0x8086, 0x7120, 0xFFFF, 0xFFFF, "82810 GMCH (Graphics Memory Controller Hub)(0x7120)"},
{0x8086, 0x7120, 0x4C53, 0x1040, "CL7 mainboard(0x4C53-0x1040)"},
{0x8086, 0x7120, 0x4C53, 0x1060, "PC7 mainboard(0x4C53-0x1060)"},
{0x8086, 0x7121, 0xFFFF, 0xFFFF, "82810 (CGC) Chipset Graphics Controller(0x7121)"},
{0x8086, 0x7121, 0x4C53, 0x1040, "CL7 mainboard(0x4C53-0x1040)"},
{0x8086, 0x7121, 0x4C53, 0x1060, "PC7 mainboard(0x4C53-0x1060)"},
{0x8086, 0x7121, 0x8086, 0x4341, "Cayman (CA810) Mainboard(0x8086-0x4341)"},
{0x8086, 0x7122, 0xFFFF, 0xFFFF, "82810 DC-100 (GMCH) Graphics Memory Controller Hub(0x7122)"},
{0x8086, 0x7123, 0xFFFF, 0xFFFF, "82810 DC-100 (CGC) Chipset Graphics Controller(0x7123)"},
{0x8086, 0x7124, 0xFFFF, 0xFFFF, "82810E DC-133 (GMCH) Graphics Memory Controller Hub(0x7124)"},
{0x8086, 0x7124, 0x1028, 0x00B4, "OptiPlex GX110(0x1028-0x00B4)"},
{0x8086, 0x7125, 0xFFFF, 0xFFFF, "82810E DC-133 (CGC) Chipset Graphics Controller(0x7125)"},
{0x8086, 0x7125, 0x1028, 0x00B4, "OptiPlex GX110(0x1028-0x00B4)"},
{0x8086, 0x7126, 0xFFFF, 0xFFFF, "82810 DC-133 System and Graphics Controller(0x7126)"},
{0x8086, 0x7128, 0xFFFF, 0xFFFF, "82810-M DC-100 System and Graphics Controller(0x7128)"},
{0x8086, 0x712A, 0xFFFF, 0xFFFF, "82810-M DC-133 System and Graphics Controller(0x712A)"},
{0x8086, 0x7180, 0xFFFF, 0xFFFF, "440LX/EX - 82443LX/EX Host bridge(0x7180)"},
{0x8086, 0x7181, 0xFFFF, 0xFFFF, "440LX/EX - 82443LX/EX AGP bridge(0x7181)"},
{0x8086, 0x7190, 0xFFFF, 0xFFFF, "440BX/ZX/DX - 82443BX/ZX/DX Host bridge(0x7190)"},
{0x8086, 0x7190, 0x0E11, 0x0500, "Armada 1750 Laptop System Chipset(0x0E11-0x0500)"},
{0x8086, 0x7190, 0x0E11, 0xB110, "Armada M700/E500(0x0E11-0xB110)"},
{0x8086, 0x7190, 0x1028, 0x008E, "PowerEdge 1300 mainboard(0x1028-0x008E)"},
{0x8086, 0x7190, 0x1043, 0x803B, "CUBX-L/E Mainboard(0x1043-0x803B)"},
{0x8086, 0x7190, 0x1179, 0x0001, "Toshiba Tecra 8100 Laptop System Chipset(0x1179-0x0001)"},
{0x8086, 0x7190, 0x15AD, 0x1976, "Virtual Machine Chipset(0x15AD-0x1976)"},
{0x8086, 0x7190, 0x4C53, 0x1050, "CT7 mainboard(0x4C53-0x1050)"},
{0x8086, 0x7190, 0x4C53, 0x1051, "CE7 mainboard(0x4C53-0x1051)"},
{0x8086, 0x7191, 0xFFFF, 0xFFFF, "440BX/ZX/DX - 82443BX/ZX/DX AGP bridge(0x7191)"},
{0x8086, 0x7191, 0x1028, 0x008E, "PowerEdge 1300 mainboard(0x1028-0x008E)"},
{0x8086, 0x7192, 0xFFFF, 0xFFFF, "440BX/ZX/DX - 82443BX/ZX/DX Host bridge (AGP disabled)(0x7192)"},
{0x8086, 0x7192, 0x0E11, 0x0460, "Armada 1700 Laptop System Chipset(0x0E11-0x0460)"},
{0x8086, 0x7192, 0x1179, 0x0001, "Satellite 4010(0x1179-0x0001)"},
{0x8086, 0x7192, 0x4C53, 0x1000, "CC7/CR7/CP7/VC7/VP7/VR7 mainboard(0x4C53-0x1000)"},
{0x8086, 0x7192, 0x8086, 0x7190, "Dell PowerEdge 350(0x8086-0x7190)"},
{0x8086, 0x7194, 0xFFFF, 0xFFFF, "82440MX Host Bridge(0x7194)"},
{0x8086, 0x7194, 0x1033, 0x0000, "Versa Note Vxi(0x1033-0x0000)"},
{0x8086, 0x7194, 0x4C53, 0x10A0, "CA3/CR3 mainboard(0x4C53-0x10A0)"},
{0x8086, 0x7195, 0xFFFF, 0xFFFF, "82440MX AC'97 Audio Controller(0x7195)"},
{0x8086, 0x7195, 0x1033, 0x80CC, "Versa Note VXi(0x1033-0x80CC)"},
{0x8086, 0x7195, 0x10CF, 0x1099, "QSound_SigmaTel Stac97 PCI Audio(0x10CF-0x1099)"},
{0x8086, 0x7195, 0x11D4, 0x0040, "SoundMAX Integrated Digital Audio(0x11D4-0x0040)"},
{0x8086, 0x7195, 0x11D4, 0x0048, "SoundMAX Integrated Digital Audio(0x11D4-0x0048)"},
{0x8086, 0x7196, 0xFFFF, 0xFFFF, "82440MX AC'97 Modem Controller(0x7196)"},
{0x8086, 0x7198, 0xFFFF, 0xFFFF, "82440MX ISA Bridge(0x7198)"},
{0x8086, 0x7199, 0xFFFF, 0xFFFF, "82440MX EIDE Controller(0x7199)"},
{0x8086, 0x719A, 0xFFFF, 0xFFFF, "82440MX USB Universal Host Controller(0x719A)"},
{0x8086, 0x719B, 0xFFFF, 0xFFFF, "82440MX Power Management Controller(0x719B)"},
{0x8086, 0x71A0, 0xFFFF, 0xFFFF, "440GX - 82443GX Host bridge(0x71A0)"},
{0x8086, 0x71A0, 0x4C53, 0x1050, "CT7 mainboard(0x4C53-0x1050)"},
{0x8086, 0x71A0, 0x4C53, 0x1051, "CE7 mainboard(0x4C53-0x1051)"},
{0x8086, 0x71A1, 0xFFFF, 0xFFFF, "440GX - 82443GX AGP bridge(0x71A1)"},
{0x8086, 0x71A2, 0xFFFF, 0xFFFF, "440GX - 82443GX Host bridge (AGP disabled)(0x71A2)"},
{0x8086, 0x71A2, 0x4C53, 0x1000, "CC7/CR7/CP7/VC7/VP7/VR7 mainboard(0x4C53-0x1000)"},
{0x8086, 0x7360, 0xFFFF, 0xFFFF, "XMM7360 LTE Advanced Modem(0x7360)"},
{0x8086, 0x7560, 0xFFFF, 0xFFFF, "XMM7560 LTE Advanced Pro Modem(0x7560)"},
{0x8086, 0x7600, 0xFFFF, 0xFFFF, "82372FB PIIX5 ISA(0x7600)"},
{0x8086, 0x7601, 0xFFFF, 0xFFFF, "82372FB PIIX5 IDE(0x7601)"},
{0x8086, 0x7602, 0xFFFF, 0xFFFF, "82372FB PIIX5 USB(0x7602)"},
{0x8086, 0x7603, 0xFFFF, 0xFFFF, "82372FB PIIX5 SMBus(0x7603)"},
{0x8086, 0x7800, 0xFFFF, 0xFFFF, "82740 (i740) AGP Graphics Accelerator(0x7800)"},
{0x8086, 0x7800, 0x003D, 0x0008, "Starfighter AGP(0x003D-0x0008)"},
{0x8086, 0x7800, 0x003D, 0x000B, "Starfighter AGP(0x003D-0x000B)"},
{0x8086, 0x7800, 0x1092, 0x0100, "Stealth II G460(0x1092-0x0100)"},
{0x8086, 0x7800, 0x10B4, 0x201A, "Lightspeed 740(0x10B4-0x201A)"},
{0x8086, 0x7800, 0x10B4, 0x202F, "Lightspeed 740(0x10B4-0x202F)"},
{0x8086, 0x7800, 0x8086, 0x0000, "Terminator 2x/i(0x8086-0x0000)"},
{0x8086, 0x7800, 0x8086, 0x0100, "Intel740 Graphics Accelerator(0x8086-0x0100)"},
{0x8086, 0x7A04, 0xFFFF, 0xFFFF, "Raptor Lake LPC/eSPI Controller(0x7A04)"},
{0x8086, 0x7A23, 0xFFFF, 0xFFFF, "Raptor Lake-S PCH SMBus Controller(0x7A23)"},
{0x8086, 0x7A24, 0xFFFF, 0xFFFF, "Raptor Lake SPI (flash) Controller(0x7A24)"},
{0x8086, 0x7A27, 0xFFFF, 0xFFFF, "Raptor Lake-S PCH Shared SRAM(0x7A27)"},
{0x8086, 0x7A30, 0xFFFF, 0xFFFF, "Raptor Lake PCI Express Root Port #9(0x7A30)"},
{0x8086, 0x7A38, 0xFFFF, 0xFFFF, "Raptor Lake PCI Express Root Port #1(0x7A38)"},
{0x8086, 0x7A3A, 0xFFFF, 0xFFFF, "Raptor Point-S PCH - PCI Express Root Port 3(0x7A3A)"},
{0x8086, 0x7A3B, 0xFFFF, 0xFFFF, "Raptor Lake PCI Express Root Port #4(0x7A3B)"},
{0x8086, 0x7A40, 0xFFFF, 0xFFFF, "Raptor Lake PCI Express Root Port #17(0x7A40)"},
{0x8086, 0x7A44, 0xFFFF, 0xFFFF, "Raptor Lake PCI Express Root Port #21(0x7A44)"},
{0x8086, 0x7A48, 0xFFFF, 0xFFFF, "Raptor Lake PCI Express Root Port #25(0x7A48)"},
{0x8086, 0x7A4C, 0xFFFF, 0xFFFF, "Raptor Lake Serial IO I2C Host Controller #0(0x7A4C)"},
{0x8086, 0x7A4D, 0xFFFF, 0xFFFF, "Raptor Lake Serial IO I2C Host Controller #1(0x7A4D)"},
{0x8086, 0x7A4E, 0xFFFF, 0xFFFF, "Raptor Lake Serial IO I2C Host Controller #2(0x7A4E)"},
{0x8086, 0x7A50, 0xFFFF, 0xFFFF, "Raptor Lake High Definition Audio Controller(0x7A50)"},
{0x8086, 0x7A60, 0xFFFF, 0xFFFF, "Raptor Lake USB 3.2 Gen 2x2 (20 Gb/s) XHCI Host Controller(0x7A60)"},
{0x8086, 0x7A62, 0xFFFF, 0xFFFF, "Raptor Lake SATA AHCI Controller(0x7A62)"},
{0x8086, 0x7A68, 0xFFFF, 0xFFFF, "Raptor Lake CSME HECI #1(0x7A68)"},
{0x8086, 0x7A69, 0xFFFF, 0xFFFF, "Raptor Lake CSME HECI #2(0x7A69)"},
{0x8086, 0x7A70, 0xFFFF, 0xFFFF, "Raptor Lake-S PCH CNVi WiFi(0x7A70)"},
{0x8086, 0x7A70, 0x8086, 0x0090, "WiFi 6E AX211 160MHz(0x8086-0x0090)"},
{0x8086, 0x7A84, 0xFFFF, 0xFFFF, "Z690 Chipset LPC/eSPI Controller(0x7A84)"},
{0x8086, 0x7A85, 0xFFFF, 0xFFFF, "Alder Lake-S PCH PCI Express Root Port #?-?-?-?-?-(0x7A85)"},
{0x8086, 0x7AA3, 0xFFFF, 0xFFFF, "Alder Lake-S PCH SMBus Controller(0x7AA3)"},
{0x8086, 0x7AA4, 0xFFFF, 0xFFFF, "Alder Lake-S PCH SPI Controller(0x7AA4)"},
{0x8086, 0x7AA7, 0xFFFF, 0xFFFF, "Alder Lake-S PCH Shared SRAM(0x7AA7)"},
{0x8086, 0x7AA8, 0xFFFF, 0xFFFF, "Alder Lake-S PCH Serial IO UART #0(0x7AA8)"},
{0x8086, 0x7AAB, 0xFFFF, 0xFFFF, "Alder Lake-S PCH Serial IO SPI Controller #1(0x7AAB)"},
{0x8086, 0x7AB0, 0xFFFF, 0xFFFF, "Alder Lake-S PCH PCI Express Root Port #9(0x7AB0)"},
{0x8086, 0x7AB4, 0xFFFF, 0xFFFF, "Alder Lake-S PCH PCI Express Root Port #13(0x7AB4)"},
{0x8086, 0x7AB8, 0xFFFF, 0xFFFF, "Alder Lake-S PCH PCI Express Root Port #1(0x7AB8)"},
{0x8086, 0x7AB9, 0xFFFF, 0xFFFF, "Alder Lake-S PCH PCI Express Root Port #2(0x7AB9)"},
{0x8086, 0x7ABA, 0xFFFF, 0xFFFF, "Alder Lake-S PCH PCI Express Root Port #3(0x7ABA)"},
{0x8086, 0x7ABC, 0xFFFF, 0xFFFF, "Alder Lake-S PCH PCI Express Root Port #5(0x7ABC)"},
{0x8086, 0x7ABD, 0xFFFF, 0xFFFF, "Alder Lake-S PCH PCI Express Root Port #6(0x7ABD)"},
{0x8086, 0x7ABF, 0xFFFF, 0xFFFF, "Alder Lake-S PCH PCI Express Root Port #8(0x7ABF)"},
{0x8086, 0x7AC4, 0xFFFF, 0xFFFF, "Alder Lake-S PCH PCI Express Root Port #21(0x7AC4)"},
{0x8086, 0x7AC8, 0xFFFF, 0xFFFF, "Alder Lake-S PCH PCI Express Root Port #25(0x7AC8)"},
{0x8086, 0x7ACC, 0xFFFF, 0xFFFF, "Alder Lake-S PCH Serial IO I2C Controller #0(0x7ACC)"},
{0x8086, 0x7ACD, 0xFFFF, 0xFFFF, "Alder Lake-S PCH Serial IO I2C Controller #1(0x7ACD)"},
{0x8086, 0x7ACE, 0xFFFF, 0xFFFF, "Alder Lake-S PCH Serial IO I2C Controller #2(0x7ACE)"},
{0x8086, 0x7ACF, 0xFFFF, 0xFFFF, "Alder Lake-S PCH Serial IO I2C Controller #3(0x7ACF)"},
{0x8086, 0x7AD0, 0xFFFF, 0xFFFF, "Alder Lake-S HD Audio Controller(0x7AD0)"},
{0x8086, 0x7AE0, 0xFFFF, 0xFFFF, "Alder Lake-S PCH USB 3.2 Gen 2x2 XHCI Controller(0x7AE0)"},
{0x8086, 0x7AE2, 0xFFFF, 0xFFFF, "Alder Lake-S PCH SATA Controller [AHCI Mode](0x7AE2)"},
{0x8086, 0x7AE8, 0xFFFF, 0xFFFF, "Alder Lake-S PCH HECI Controller #1(0x7AE8)"},
{0x8086, 0x7AF0, 0xFFFF, 0xFFFF, "Alder Lake-S PCH CNVi WiFi(0x7AF0)"},
{0x8086, 0x7AF0, 0x8086, 0x0034, "Wireless-AC 9560(0x8086-0x0034)"},
{0x8086, 0x7AF0, 0x8086, 0x0070, "Wi-Fi 6 AX201 160MHz(0x8086-0x0070)"},
{0x8086, 0x7AF0, 0x8086, 0x0094, "Wi-Fi 6 AX201 160MHz(0x8086-0x0094)"},
{0x8086, 0x7AFC, 0xFFFF, 0xFFFF, "Alder Lake-S PCH Serial IO I2C Controller #4(0x7AFC)"},
{0x8086, 0x7AFD, 0xFFFF, 0xFFFF, "Alder Lake-S PCH Serial IO I2C Controller #5(0x7AFD)"},
{0x8086, 0x7D03, 0xFFFF, 0xFFFF, "Meteor Lake-P Dynamic Tuning Technology(0x7D03)"},
{0x8086, 0x7D0B, 0xFFFF, 0xFFFF, "Volume Management Device NVMe RAID Controller Intel Corporation(0x7D0B)"},
{0x8086, 0x7D0D, 0xFFFF, 0xFFFF, "Meteor Lake-P Platform Monitoring Technology(0x7D0D)"},
{0x8086, 0x7D19, 0xFFFF, 0xFFFF, "Meteor Lake IPU(0x7D19)"},
{0x8086, 0x7D1D, 0xFFFF, 0xFFFF, "Meteor Lake NPU(0x7D1D)"},
{0x8086, 0x7D40, 0xFFFF, 0xFFFF, "Meteor Lake-M [Intel Graphics](0x7D40)"},
{0x8086, 0x7D41, 0xFFFF, 0xFFFF, "Arrow Lake-U [Intel Graphics](0x7D41)"},
{0x8086, 0x7D45, 0xFFFF, 0xFFFF, "Meteor Lake-P [Intel Graphics](0x7D45)"},
{0x8086, 0x7D51, 0xFFFF, 0xFFFF, "Arrow Lake-P [Intel Graphics](0x7D51)"},
{0x8086, 0x7D55, 0xFFFF, 0xFFFF, "Meteor Lake-P [Intel Arc Graphics](0x7D55)"},
{0x8086, 0x7D60, 0xFFFF, 0xFFFF, "Meteor Lake-M [Intel Graphics](0x7D60)"},
{0x8086, 0x7D67, 0xFFFF, 0xFFFF, "Arrow Lake-U [Intel Graphics](0x7D67)"},
{0x8086, 0x7DD1, 0xFFFF, 0xFFFF, "Arrow Lake-P [Intel Graphics](0x7DD1)"},
{0x8086, 0x7DD5, 0xFFFF, 0xFFFF, "Meteor Lake-P [Intel Graphics](0x7DD5)"},
{0x8086, 0x7E01, 0xFFFF, 0xFFFF, "Meteor Lake-P LPC/eSPI Controller(0x7E01)"},
{0x8086, 0x7E22, 0xFFFF, 0xFFFF, "Meteor Lake-P SMBus Controller(0x7E22)"},
{0x8086, 0x7E23, 0xFFFF, 0xFFFF, "Meteor Lake-P SPI Controller(0x7E23)"},
{0x8086, 0x7E24, 0xFFFF, 0xFFFF, "Meteor Lake-P Trace Hub(0x7E24)"},
{0x8086, 0x7E25, 0xFFFF, 0xFFFF, "Meteor Lake-P Serial IO UART Controller #0(0x7E25)"},
{0x8086, 0x7E26, 0xFFFF, 0xFFFF, "Meteor Lake-P Serial IO UART Controller #1(0x7E26)"},
{0x8086, 0x7E27, 0xFFFF, 0xFFFF, "Meteor Lake-P Serial IO SPI Controller #0(0x7E27)"},
{0x8086, 0x7E28, 0xFFFF, 0xFFFF, "Meteor Lake-P HD Audio Controller(0x7E28)"},
{0x8086, 0x7E30, 0xFFFF, 0xFFFF, "Meteor Lake-P Serial IO SPI Controller #1(0x7E30)"},
{0x8086, 0x7E40, 0xFFFF, 0xFFFF, "Meteor Lake PCH CNVi WiFi(0x7E40)"},
{0x8086, 0x7E40, 0x8086, 0x0094, "Wi-Fi 6E AX211 160MHz(0x8086-0x0094)"},
{0x8086, 0x7E45, 0xFFFF, 0xFFFF, "Meteor Lake-P Integrated Sensor Hub(0x7E45)"},
{0x8086, 0x7E46, 0xFFFF, 0xFFFF, "Meteor Lake-P Serial IO SPI Controller #2(0x7E46)"},
{0x8086, 0x7E4C, 0xFFFF, 0xFFFF, "Meteor Lake-P Gaussian & Neural-Network Accelerator(0x7E4C)"},
{0x8086, 0x7E50, 0xFFFF, 0xFFFF, "Meteor Lake-P Serial IO I2C Controller #4(0x7E50)"},
{0x8086, 0x7E51, 0xFFFF, 0xFFFF, "Meteor Lake-P Serial IO I2C Controller #5(0x7E51)"},
{0x8086, 0x7E52, 0xFFFF, 0xFFFF, "Meteor Lake-P Serial IO UART Controller #2(0x7E52)"},
{0x8086, 0x7E70, 0xFFFF, 0xFFFF, "Meteor Lake-P CSME HECI #1(0x7E70)"},
{0x8086, 0x7E73, 0xFFFF, 0xFFFF, "Meteor Lake-P Keyboard and Text (KT) Redirection(0x7E73)"},
{0x8086, 0x7E78, 0xFFFF, 0xFFFF, "Meteor Lake-P Serial IO I2C Controller #0(0x7E78)"},
{0x8086, 0x7E79, 0xFFFF, 0xFFFF, "Meteor Lake-P Serial IO I2C Controller #1(0x7E79)"},
{0x8086, 0x7E7A, 0xFFFF, 0xFFFF, "Meteor Lake-P Serial IO I2C Controller #2(0x7E7A)"},
{0x8086, 0x7E7B, 0xFFFF, 0xFFFF, "Meteor Lake-P Serial IO I2C Controller #3(0x7E7B)"},
{0x8086, 0x7E7D, 0xFFFF, 0xFFFF, "Meteor Lake-P USB 3.2 Gen 2x1 xHCI Host Controller(0x7E7D)"},
{0x8086, 0x7E7E, 0xFFFF, 0xFFFF, "Meteor Lake-P USB Device Controller(0x7E7E)"},
{0x8086, 0x7EC0, 0xFFFF, 0xFFFF, "Meteor Lake-P Thunderbolt 4 USB Controller(0x7EC0)"},
{0x8086, 0x7EC2, 0xFFFF, 0xFFFF, "Meteor Lake-P Thunderbolt 4 NHI #0(0x7EC2)"},
{0x8086, 0x7EC3, 0xFFFF, 0xFFFF, "Meteor Lake-P Thunderbolt 4 NHI #1(0x7EC3)"},
{0x8086, 0x7EC4, 0xFFFF, 0xFFFF, "Meteor Lake-P Thunderbolt 4 PCI Express Root Port #0(0x7EC4)"},
{0x8086, 0x7EC5, 0xFFFF, 0xFFFF, "Meteor Lake-P Thunderbolt 4 PCI Express Root Port #1(0x7EC5)"},
{0x8086, 0x7EC6, 0xFFFF, 0xFFFF, "Meteor Lake-P Thunderbolt 4 PCI Express Root Port #2(0x7EC6)"},
{0x8086, 0x7EC7, 0xFFFF, 0xFFFF, "Meteor Lake-P Thunderbolt 4 PCI Express Root Port #3(0x7EC7)"},
{0x8086, 0x8002, 0xFFFF, 0xFFFF, "Trusted Execution Technology Registers(0x8002)"},
{0x8086, 0x8003, 0xFFFF, 0xFFFF, "Trusted Execution Technology Registers(0x8003)"},
{0x8086, 0x8100, 0xFFFF, 0xFFFF, "US15W/US15X SCH [Poulsbo] Host Bridge(0x8100)"},
{0x8086, 0x8101, 0xFFFF, 0xFFFF, "US15L/UL11L SCH [Poulsbo] Host Bridge(0x8101)"},
{0x8086, 0x8108, 0xFFFF, 0xFFFF, "US15W/US15X SCH [Poulsbo] Graphics Controller(0x8108)"},
{0x8086, 0x8109, 0xFFFF, 0xFFFF, "US15L/UL11L SCH [Poulsbo] Graphics Controller(0x8109)"},
{0x8086, 0x8110, 0xFFFF, 0xFFFF, "US15W/US15X/US15L/UL11L SCH [Poulsbo] PCI Express Port 1(0x8110)"},
{0x8086, 0x8112, 0xFFFF, 0xFFFF, "US15W/US15X/US15L/UL11L SCH [Poulsbo] PCI Express Port 2(0x8112)"},
{0x8086, 0x8114, 0xFFFF, 0xFFFF, "US15W/US15X/US15L/UL11L SCH [Poulsbo] USB UHCI Controller #1(0x8114)"},
{0x8086, 0x8115, 0xFFFF, 0xFFFF, "US15W/US15X/US15L/UL11L SCH [Poulsbo] USB UHCI Controller #2(0x8115)"},
{0x8086, 0x8116, 0xFFFF, 0xFFFF, "US15W/US15X/US15L/UL11L SCH [Poulsbo] USB UHCI Controller #3(0x8116)"},
{0x8086, 0x8117, 0xFFFF, 0xFFFF, "US15W/US15X/US15L/UL11L SCH [Poulsbo] USB EHCI Controller(0x8117)"},
{0x8086, 0x8118, 0xFFFF, 0xFFFF, "US15W/US15X/US15L/UL11L SCH [Poulsbo] USB Client Controller(0x8118)"},
{0x8086, 0x8119, 0xFFFF, 0xFFFF, "US15W/US15X/US15L/UL11L SCH [Poulsbo] LPC Bridge(0x8119)"},
{0x8086, 0x811A, 0xFFFF, 0xFFFF, "US15W/US15X/US15L/UL11L SCH [Poulsbo] IDE Controller(0x811A)"},
{0x8086, 0x811B, 0xFFFF, 0xFFFF, "US15W/US15X/US15L/UL11L SCH [Poulsbo] HD Audio Controller(0x811B)"},
{0x8086, 0x811C, 0xFFFF, 0xFFFF, "US15W/US15X/US15L/UL11L SCH [Poulsbo] SDIO/MMC Controller #1(0x811C)"},
{0x8086, 0x811D, 0xFFFF, 0xFFFF, "US15W/US15X/US15L/UL11L SCH [Poulsbo] SDIO/MMC Controller #2(0x811D)"},
{0x8086, 0x811E, 0xFFFF, 0xFFFF, "US15W/US15X/US15L/UL11L SCH [Poulsbo] SDIO/MMC Controller #3(0x811E)"},
{0x8086, 0x8180, 0xFFFF, 0xFFFF, "Atom Processor E6xx PCI Express Port 3(0x8180)"},
{0x8086, 0x8181, 0xFFFF, 0xFFFF, "Atom Processor E6xx PCI Express Port 4(0x8181)"},
{0x8086, 0x8182, 0xFFFF, 0xFFFF, "Atom Processor E6xx Integrated Graphics Controller(0x8182)"},
{0x8086, 0x8183, 0xFFFF, 0xFFFF, "Atom Processor E6xx Configuration Unit(0x8183)"},
{0x8086, 0x8184, 0xFFFF, 0xFFFF, "Atom Processor E6xx PCI Express Port 1(0x8184)"},
{0x8086, 0x8185, 0xFFFF, 0xFFFF, "Atom Processor E6xx PCI Express Port 2(0x8185)"},
{0x8086, 0x8186, 0xFFFF, 0xFFFF, "Atom Processor E6xx LPC Bridge(0x8186)"},
{0x8086, 0x84C4, 0xFFFF, 0xFFFF, "450KX/GX [Orion] - 82454KX/GX PCI bridge(0x84C4)"},
{0x8086, 0x84C5, 0xFFFF, 0xFFFF, "450KX/GX [Orion] - 82453KX/GX Memory controller(0x84C5)"},
{0x8086, 0x84CA, 0xFFFF, 0xFFFF, "450NX - 82451NX Memory & I/O Controller(0x84CA)"},
{0x8086, 0x84CB, 0xFFFF, 0xFFFF, "450NX - 82454NX/84460GX PCI Expander Bridge(0x84CB)"},
{0x8086, 0x84E0, 0xFFFF, 0xFFFF, "460GX - 84460GX System Address Controller (SAC)(0x84E0)"},
{0x8086, 0x84E1, 0xFFFF, 0xFFFF, "460GX - 84460GX System Data Controller (SDC)(0x84E1)"},
{0x8086, 0x84E2, 0xFFFF, 0xFFFF, "460GX - 84460GX AGP Bridge (GXB function 2)(0x84E2)"},
{0x8086, 0x84E3, 0xFFFF, 0xFFFF, "460GX - 84460GX Memory Address Controller (MAC)(0x84E3)"},
{0x8086, 0x84E4, 0xFFFF, 0xFFFF, "460GX - 84460GX Memory Data Controller (MDC)(0x84E4)"},
{0x8086, 0x84E6, 0xFFFF, 0xFFFF, "460GX - 82466GX Wide and fast PCI eXpander Bridge (WXB)(0x84E6)"},
{0x8086, 0x84EA, 0xFFFF, 0xFFFF, "460GX - 84460GX AGP Bridge (GXB function 1)(0x84EA)"},
{0x8086, 0x8500, 0xFFFF, 0xFFFF, "IXP4XX Network Processor (IXP420/421/422/425/IXC1100)(0x8500)"},
{0x8086, 0x8500, 0x1993, 0x0DED, "mGuard-PCI AV#2(0x1993-0x0DED)"},
{0x8086, 0x8500, 0x1993, 0x0DEE, "mGuard-PCI AV#1(0x1993-0x0DEE)"},
{0x8086, 0x8500, 0x1993, 0x0DEF, "mGuard-PCI AV#0(0x1993-0x0DEF)"},
{0x8086, 0x8603, 0xFFFF, 0xFFFF, "Ice Lake-LP Dynamic Tuning Processor Participant(0x8603)"},
{0x8086, 0x87C0, 0xFFFF, 0xFFFF, "UHD Graphics 617(0x87C0)"},
{0x8086, 0x87CA, 0xFFFF, 0xFFFF, "UHD Graphics 617(0x87CA)"},
{0x8086, 0x8800, 0xFFFF, 0xFFFF, "Platform Controller Hub EG20T PCI Express Port(0x8800)"},
{0x8086, 0x8801, 0xFFFF, 0xFFFF, "Platform Controller Hub EG20T Packet Hub(0x8801)"},
{0x8086, 0x8802, 0xFFFF, 0xFFFF, "Platform Controller Hub EG20T Gigabit Ethernet Controller(0x8802)"},
{0x8086, 0x8803, 0xFFFF, 0xFFFF, "Platform Controller Hub EG20T General Purpose IO Controller(0x8803)"},
{0x8086, 0x8804, 0xFFFF, 0xFFFF, "Platform Controller Hub EG20T USB OHCI Controller #4(0x8804)"},
{0x8086, 0x8805, 0xFFFF, 0xFFFF, "Platform Controller Hub EG20T USB OHCI Controller #5(0x8805)"},
{0x8086, 0x8806, 0xFFFF, 0xFFFF, "Platform Controller Hub EG20T USB OHCI Controller #6(0x8806)"},
{0x8086, 0x8807, 0xFFFF, 0xFFFF, "Platform Controller Hub EG20T USB2 EHCI Controller #2(0x8807)"},
{0x8086, 0x8808, 0xFFFF, 0xFFFF, "Platform Controller Hub EG20T USB Client Controller(0x8808)"},
{0x8086, 0x8809, 0xFFFF, 0xFFFF, "Platform Controller Hub EG20T SDIO Controller #1(0x8809)"},
{0x8086, 0x880A, 0xFFFF, 0xFFFF, "Platform Controller Hub EG20T SDIO Controller #2(0x880A)"},
{0x8086, 0x880B, 0xFFFF, 0xFFFF, "Platform Controller Hub EG20T SATA AHCI Controller(0x880B)"},
{0x8086, 0x880C, 0xFFFF, 0xFFFF, "Platform Controller Hub EG20T USB OHCI Controller #1(0x880C)"},
{0x8086, 0x880D, 0xFFFF, 0xFFFF, "Platform Controller Hub EG20T USB OHCI Controller #2(0x880D)"},
{0x8086, 0x880E, 0xFFFF, 0xFFFF, "Platform Controller Hub EG20T USB OHCI Controller #3(0x880E)"},
{0x8086, 0x880F, 0xFFFF, 0xFFFF, "Platform Controller Hub EG20T USB2 EHCI Controller #1(0x880F)"},
{0x8086, 0x8810, 0xFFFF, 0xFFFF, "Platform Controller Hub EG20T DMA Controller #1(0x8810)"},
{0x8086, 0x8811, 0xFFFF, 0xFFFF, "Platform Controller Hub EG20T UART Controller 0(0x8811)"},
{0x8086, 0x8812, 0xFFFF, 0xFFFF, "Platform Controller Hub EG20T UART Controller 1(0x8812)"},
{0x8086, 0x8813, 0xFFFF, 0xFFFF, "Platform Controller Hub EG20T UART Controller 2(0x8813)"},
{0x8086, 0x8814, 0xFFFF, 0xFFFF, "Platform Controller Hub EG20T UART Controller 3(0x8814)"},
{0x8086, 0x8815, 0xFFFF, 0xFFFF, "Platform Controller Hub EG20T DMA Controller #2(0x8815)"},
{0x8086, 0x8816, 0xFFFF, 0xFFFF, "Platform Controller Hub EG20T Serial Peripheral Interface Bus(0x8816)"},
{0x8086, 0x8817, 0xFFFF, 0xFFFF, "Platform Controller Hub EG20T I2C Controller(0x8817)"},
{0x8086, 0x8818, 0xFFFF, 0xFFFF, "Platform Controller Hub EG20T Controller Area Network (CAN) Controller(0x8818)"},
{0x8086, 0x8819, 0xFFFF, 0xFFFF, "Platform Controller Hub EG20T IEEE 1588 Hardware Assist(0x8819)"},
{0x8086, 0x8A03, 0xFFFF, 0xFFFF, "Processor Power and Thermal Controller(0x8A03)"},
{0x8086, 0x8A0D, 0xFFFF, 0xFFFF, "Ice Lake Thunderbolt 3 NHI #1(0x8A0D)"},
{0x8086, 0x8A11, 0xFFFF, 0xFFFF, "GNA Scoring Accelerator Module(0x8A11)"},
{0x8086, 0x8A12, 0xFFFF, 0xFFFF, "Ice Lake-LP Processor Host Bridge/DRAM Registers(0x8A12)"},
{0x8086, 0x8A13, 0xFFFF, 0xFFFF, "Ice Lake Thunderbolt 3 USB Controller(0x8A13)"},
{0x8086, 0x8A14, 0xFFFF, 0xFFFF, "Ice Lake Processor Host Bridge/DRAM Registers(0x8A14)"},
{0x8086, 0x8A17, 0xFFFF, 0xFFFF, "Ice Lake Thunderbolt 3 NHI #0(0x8A17)"},
{0x8086, 0x8A19, 0xFFFF, 0xFFFF, "Image Signal Processor(0x8A19)"},
{0x8086, 0x8A1D, 0xFFFF, 0xFFFF, "Ice Lake Thunderbolt 3 PCI Express Root Port #0(0x8A1D)"},
{0x8086, 0x8A1F, 0xFFFF, 0xFFFF, "Ice Lake Thunderbolt 3 PCI Express Root Port #1(0x8A1F)"},
{0x8086, 0x8A21, 0xFFFF, 0xFFFF, "Ice Lake Thunderbolt 3 PCI Express Root Port #2(0x8A21)"},
{0x8086, 0x8A23, 0xFFFF, 0xFFFF, "Ice Lake Thunderbolt 3 PCI Express Root Port #3(0x8A23)"},
{0x8086, 0x8A51, 0xFFFF, 0xFFFF, "Iris Plus Graphics G7 (Ice Lake)(0x8A51)"},
{0x8086, 0x8A52, 0xFFFF, 0xFFFF, "Iris Plus Graphics G7(0x8A52)"},
{0x8086, 0x8A53, 0xFFFF, 0xFFFF, "Iris Plus Graphics G7(0x8A53)"},
{0x8086, 0x8A56, 0xFFFF, 0xFFFF, "Iris Plus Graphics G1 (Ice Lake)(0x8A56)"},
{0x8086, 0x8A58, 0xFFFF, 0xFFFF, "Ice Lake-Y GT1 [UHD Graphics G1](0x8A58)"},
{0x8086, 0x8A5A, 0xFFFF, 0xFFFF, "Iris Plus Graphics G4 (Ice Lake)(0x8A5A)"},
{0x8086, 0x8A5C, 0xFFFF, 0xFFFF, "Iris Plus Graphics G4 (Ice Lake)(0x8A5C)"},
{0x8086, 0x8C00, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset Family 4-port SATA Controller 1 [IDE mode](0x8C00)"},
{0x8086, 0x8C01, 0xFFFF, 0xFFFF, "8 Series Chipset Family 4-port SATA Controller 1 [IDE mode] - Mobile(0x8C01)"},
{0x8086, 0x8C02, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset Family 6-port SATA Controller 1 [AHCI mode](0x8C02)"},
{0x8086, 0x8C02, 0x1028, 0x05D7, "Alienware X51 R2(0x1028-0x05D7)"},
{0x8086, 0x8C02, 0x103C, 0x1998, "EliteDesk 800 G1(0x103C-0x1998)"},
{0x8086, 0x8C02, 0x17AA, 0x3098, "ThinkCentre E73(0x17AA-0x3098)"},
{0x8086, 0x8C02, 0x17AA, 0x309F, "ThinkCentre M83(0x17AA-0x309F)"},
{0x8086, 0x8C03, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset Family 6-port SATA Controller 1 [AHCI mode](0x8C03)"},
{0x8086, 0x8C03, 0x103C, 0x1909, "ZBook 15(0x103C-0x1909)"},
{0x8086, 0x8C03, 0x17AA, 0x220E, "ThinkPad T440p(0x17AA-0x220E)"},
{0x8086, 0x8C04, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset Family SATA Controller 1 [RAID mode](0x8C04)"},
{0x8086, 0x8C05, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset Family SATA Controller 1 [RAID mode](0x8C05)"},
{0x8086, 0x8C06, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset Family SATA Controller 1 [RAID mode](0x8C06)"},
{0x8086, 0x8C07, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset Family SATA Controller 1 [RAID mode](0x8C07)"},
{0x8086, 0x8C08, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset Family 2-port SATA Controller 2 [IDE mode](0x8C08)"},
{0x8086, 0x8C09, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset Family 2-port SATA Controller 2 [IDE mode](0x8C09)"},
{0x8086, 0x8C0E, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset Family SATA Controller 1 [RAID mode](0x8C0E)"},
{0x8086, 0x8C0F, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset Family SATA Controller 1 [RAID mode](0x8C0F)"},
{0x8086, 0x8C10, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset Family PCI Express Root Port #1(0x8C10)"},
{0x8086, 0x8C10, 0x103C, 0x1998, "EliteDesk 800 G1(0x103C-0x1998)"},
{0x8086, 0x8C10, 0x1043, 0x8534, "ASUS H81I-PLUS(0x1043-0x8534)"},
{0x8086, 0x8C10, 0x17AA, 0x220E, "ThinkPad T440p(0x17AA-0x220E)"},
{0x8086, 0x8C10, 0x17AA, 0x3098, "ThinkCentre E73(0x17AA-0x3098)"},
{0x8086, 0x8C11, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset Family PCI Express Root Port #1(0x8C11)"},
{0x8086, 0x8C12, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset Family PCI Express Root Port #2(0x8C12)"},
{0x8086, 0x8C12, 0x103C, 0x1998, "EliteDesk 800 G1(0x103C-0x1998)"},
{0x8086, 0x8C12, 0x17AA, 0x220E, "ThinkPad T440p(0x17AA-0x220E)"},
{0x8086, 0x8C13, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset Family PCI Express Root Port #2(0x8C13)"},
{0x8086, 0x8C14, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset Family PCI Express Root Port #3(0x8C14)"},
{0x8086, 0x8C15, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset Family PCI Express Root Port #3(0x8C15)"},
{0x8086, 0x8C16, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset Family PCI Express Root Port #4(0x8C16)"},
{0x8086, 0x8C17, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset Family PCI Express Root Port #4(0x8C17)"},
{0x8086, 0x8C18, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset Family PCI Express Root Port #5(0x8C18)"},
{0x8086, 0x8C19, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset Family PCI Express Root Port #5(0x8C19)"},
{0x8086, 0x8C1A, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset Family PCI Express Root Port #6(0x8C1A)"},
{0x8086, 0x8C1A, 0x17AA, 0x3098, "ThinkCentre E73(0x17AA-0x3098)"},
{0x8086, 0x8C1B, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset Family PCI Express Root Port #6(0x8C1B)"},
{0x8086, 0x8C1C, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset Family PCI Express Root Port #7(0x8C1C)"},
{0x8086, 0x8C1D, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset Family PCI Express Root Port #7(0x8C1D)"},
{0x8086, 0x8C1E, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset Family PCI Express Root Port #8(0x8C1E)"},
{0x8086, 0x8C1F, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset Family PCI Express Root Port #8(0x8C1F)"},
{0x8086, 0x8C20, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset High Definition Audio Controller(0x8C20)"},
{0x8086, 0x8C20, 0x1028, 0x05D7, "Alienware X51 R2(0x1028-0x05D7)"},
{0x8086, 0x8C20, 0x103C, 0x1909, "ZBook 15(0x103C-0x1909)"},
{0x8086, 0x8C20, 0x103C, 0x1998, "EliteDesk 800 G1(0x103C-0x1998)"},
{0x8086, 0x8C20, 0x17AA, 0x220E, "ThinkPad T440p(0x17AA-0x220E)"},
{0x8086, 0x8C20, 0x17AA, 0x309F, "ThinkCentre M83(0x17AA-0x309F)"},
{0x8086, 0x8C21, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset High Definition Audio Controller(0x8C21)"},
{0x8086, 0x8C22, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset Family SMBus Controller(0x8C22)"},
{0x8086, 0x8C22, 0x1028, 0x05D7, "Alienware X51 R2(0x1028-0x05D7)"},
{0x8086, 0x8C22, 0x103C, 0x1909, "ZBook 15(0x103C-0x1909)"},
{0x8086, 0x8C22, 0x103C, 0x1998, "EliteDesk 800 G1(0x103C-0x1998)"},
{0x8086, 0x8C22, 0x17AA, 0x220E, "ThinkPad T440p(0x17AA-0x220E)"},
{0x8086, 0x8C22, 0x17AA, 0x3098, "ThinkCentre E73(0x17AA-0x3098)"},
{0x8086, 0x8C22, 0x17AA, 0x309F, "ThinkCentre M83(0x17AA-0x309F)"},
{0x8086, 0x8C23, 0xFFFF, 0xFFFF, "8 Series Chipset Family CHAP Counters(0x8C23)"},
{0x8086, 0x8C24, 0xFFFF, 0xFFFF, "8 Series Chipset Family Thermal Management Controller(0x8C24)"},
{0x8086, 0x8C26, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset Family USB EHCI #1(0x8C26)"},
{0x8086, 0x8C26, 0x1028, 0x05D7, "Alienware X51 R2(0x1028-0x05D7)"},
{0x8086, 0x8C26, 0x103C, 0x1909, "ZBook 15(0x103C-0x1909)"},
{0x8086, 0x8C26, 0x103C, 0x1998, "EliteDesk 800 G1(0x103C-0x1998)"},
{0x8086, 0x8C26, 0x17AA, 0x220E, "ThinkPad T440p(0x17AA-0x220E)"},
{0x8086, 0x8C26, 0x17AA, 0x2210, "ThinkPad T540p(0x17AA-0x2210)"},
{0x8086, 0x8C26, 0x17AA, 0x3098, "ThinkCentre E73(0x17AA-0x3098)"},
{0x8086, 0x8C26, 0x17AA, 0x309F, "ThinkCentre M83(0x17AA-0x309F)"},
{0x8086, 0x8C26, 0x2210, 0x17AA, "ThinkPad T540p(0x2210-0x17AA)"},
{0x8086, 0x8C2D, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset Family USB EHCI #2(0x8C2D)"},
{0x8086, 0x8C2D, 0x1028, 0x05D7, "Alienware X51 R2(0x1028-0x05D7)"},
{0x8086, 0x8C2D, 0x103C, 0x1909, "ZBook 15(0x103C-0x1909)"},
{0x8086, 0x8C2D, 0x103C, 0x1998, "EliteDesk 800 G1(0x103C-0x1998)"},
{0x8086, 0x8C2D, 0x17AA, 0x220E, "ThinkPad T440p(0x17AA-0x220E)"},
{0x8086, 0x8C2D, 0x17AA, 0x3098, "ThinkCentre E73(0x17AA-0x3098)"},
{0x8086, 0x8C2D, 0x17AA, 0x309F, "ThinkCentre M83(0x17AA-0x309F)"},
{0x8086, 0x8C31, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset Family USB xHCI(0x8C31)"},
{0x8086, 0x8C31, 0x1028, 0x05D7, "Alienware X51 R2(0x1028-0x05D7)"},
{0x8086, 0x8C31, 0x103C, 0x1909, "ZBook 15(0x103C-0x1909)"},
{0x8086, 0x8C31, 0x103C, 0x1998, "EliteDesk 800 G1(0x103C-0x1998)"},
{0x8086, 0x8C31, 0x17AA, 0x220E, "ThinkPad T440p(0x17AA-0x220E)"},
{0x8086, 0x8C31, 0x17AA, 0x3098, "ThinkCentre E73(0x17AA-0x3098)"},
{0x8086, 0x8C31, 0x17AA, 0x309F, "ThinkCentre M83(0x17AA-0x309F)"},
{0x8086, 0x8C33, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset Family LAN Controller(0x8C33)"},
{0x8086, 0x8C34, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset Family NAND Controller(0x8C34)"},
{0x8086, 0x8C3A, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset Family MEI Controller #1(0x8C3A)"},
{0x8086, 0x8C3A, 0x1028, 0x05D7, "Alienware X51 R2(0x1028-0x05D7)"},
{0x8086, 0x8C3A, 0x103C, 0x1909, "ZBook 15(0x103C-0x1909)"},
{0x8086, 0x8C3A, 0x103C, 0x1998, "EliteDesk 800 G1(0x103C-0x1998)"},
{0x8086, 0x8C3A, 0x17AA, 0x220E, "ThinkPad T440p(0x17AA-0x220E)"},
{0x8086, 0x8C3A, 0x17AA, 0x3098, "ThinkCentre E73(0x17AA-0x3098)"},
{0x8086, 0x8C3A, 0x17AA, 0x309F, "ThinkCentre M83(0x17AA-0x309F)"},
{0x8086, 0x8C3B, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset Family MEI Controller #2(0x8C3B)"},
{0x8086, 0x8C3C, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset Family IDE-r Controller(0x8C3C)"},
{0x8086, 0x8C3D, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset Family KT Controller(0x8C3D)"},
{0x8086, 0x8C3D, 0x103C, 0x1998, "EliteDesk 800 G1(0x103C-0x1998)"},
{0x8086, 0x8C40, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset Family LPC Controller(0x8C40)"},
{0x8086, 0x8C41, 0xFFFF, 0xFFFF, "8 Series Chipset Family Mobile Super SKU LPC Controller(0x8C41)"},
{0x8086, 0x8C42, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset Family Desktop Super SKU LPC Controller(0x8C42)"},
{0x8086, 0x8C43, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset Family LPC Controller(0x8C43)"},
{0x8086, 0x8C44, 0xFFFF, 0xFFFF, "Z87 Express LPC Controller(0x8C44)"},
{0x8086, 0x8C45, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset Family LPC Controller(0x8C45)"},
{0x8086, 0x8C46, 0xFFFF, 0xFFFF, "Z85 Express LPC Controller(0x8C46)"},
{0x8086, 0x8C47, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset Family LPC Controller(0x8C47)"},
{0x8086, 0x8C48, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset Family LPC Controller(0x8C48)"},
{0x8086, 0x8C49, 0xFFFF, 0xFFFF, "HM86 Express LPC Controller(0x8C49)"},
{0x8086, 0x8C4A, 0xFFFF, 0xFFFF, "H87 Express LPC Controller(0x8C4A)"},
{0x8086, 0x8C4A, 0x1028, 0x05D7, "Alienware X51 R2(0x1028-0x05D7)"},
{0x8086, 0x8C4B, 0xFFFF, 0xFFFF, "HM87 Express LPC Controller(0x8C4B)"},
{0x8086, 0x8C4C, 0xFFFF, 0xFFFF, "Q85 Express LPC Controller(0x8C4C)"},
{0x8086, 0x8C4C, 0x17AA, 0x309F, "ThinkCentre M83(0x17AA-0x309F)"},
{0x8086, 0x8C4D, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset Family LPC Controller(0x8C4D)"},
{0x8086, 0x8C4E, 0xFFFF, 0xFFFF, "Q87 Express LPC Controller(0x8C4E)"},
{0x8086, 0x8C4E, 0x103C, 0x1998, "EliteDesk 800 G1(0x103C-0x1998)"},
{0x8086, 0x8C4F, 0xFFFF, 0xFFFF, "QM87 Express LPC Controller(0x8C4F)"},
{0x8086, 0x8C4F, 0x103C, 0x1909, "ZBook 15(0x103C-0x1909)"},
{0x8086, 0x8C4F, 0x17AA, 0x220E, "ThinkPad T440p(0x17AA-0x220E)"},
{0x8086, 0x8C50, 0xFFFF, 0xFFFF, "B85 Express LPC Controller(0x8C50)"},
{0x8086, 0x8C51, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset Family LPC Controller(0x8C51)"},
{0x8086, 0x8C52, 0xFFFF, 0xFFFF, "C222 Series Chipset Family Server Essential SKU LPC Controller(0x8C52)"},
{0x8086, 0x8C53, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset Family LPC Controller(0x8C53)"},
{0x8086, 0x8C54, 0xFFFF, 0xFFFF, "C224 Series Chipset Family Server Standard SKU LPC Controller(0x8C54)"},
{0x8086, 0x8C55, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset Family LPC Controller(0x8C55)"},
{0x8086, 0x8C56, 0xFFFF, 0xFFFF, "C226 Series Chipset Family Server Advanced SKU LPC Controller(0x8C56)"},
{0x8086, 0x8C57, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset Family LPC Controller(0x8C57)"},
{0x8086, 0x8C58, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset Family WS SKU LPC Controller(0x8C58)"},
{0x8086, 0x8C59, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset Family LPC Controller(0x8C59)"},
{0x8086, 0x8C5A, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset Family LPC Controller(0x8C5A)"},
{0x8086, 0x8C5B, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset Family LPC Controller(0x8C5B)"},
{0x8086, 0x8C5C, 0xFFFF, 0xFFFF, "H81 Express LPC Controller(0x8C5C)"},
{0x8086, 0x8C5C, 0x17AA, 0x3098, "ThinkCentre E73(0x17AA-0x3098)"},
{0x8086, 0x8C5D, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset Family LPC Controller(0x8C5D)"},
{0x8086, 0x8C5E, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset Family LPC Controller(0x8C5E)"},
{0x8086, 0x8C5F, 0xFFFF, 0xFFFF, "8 Series/C220 Series Chipset Family LPC Controller(0x8C5F)"},
{0x8086, 0x8C80, 0xFFFF, 0xFFFF, "9 Series Chipset Family SATA Controller [IDE Mode](0x8C80)"},
{0x8086, 0x8C81, 0xFFFF, 0xFFFF, "9 Series Chipset Family SATA Controller [IDE Mode](0x8C81)"},
{0x8086, 0x8C82, 0xFFFF, 0xFFFF, "9 Series Chipset Family SATA Controller [AHCI Mode](0x8C82)"},
{0x8086, 0x8C83, 0xFFFF, 0xFFFF, "9 Series Chipset Family SATA Controller [AHCI Mode](0x8C83)"},
{0x8086, 0x8C84, 0xFFFF, 0xFFFF, "9 Series Chipset Family SATA Controller [RAID Mode](0x8C84)"},
{0x8086, 0x8C85, 0xFFFF, 0xFFFF, "9 Series Chipset Family SATA Controller [RAID Mode](0x8C85)"},
{0x8086, 0x8C86, 0xFFFF, 0xFFFF, "9 Series Chipset Family SATA Controller [RAID Mode](0x8C86)"},
{0x8086, 0x8C87, 0xFFFF, 0xFFFF, "9 Series Chipset Family SATA Controller [RAID Mode](0x8C87)"},
{0x8086, 0x8C88, 0xFFFF, 0xFFFF, "9 Series Chipset Family SATA Controller [IDE Mode](0x8C88)"},
{0x8086, 0x8C89, 0xFFFF, 0xFFFF, "9 Series Chipset Family SATA Controller [IDE Mode](0x8C89)"},
{0x8086, 0x8C8E, 0xFFFF, 0xFFFF, "9 Series Chipset Family SATA Controller [RAID Mode](0x8C8E)"},
{0x8086, 0x8C8F, 0xFFFF, 0xFFFF, "9 Series Chipset Family SATA Controller [RAID Mode](0x8C8F)"},
{0x8086, 0x8C90, 0xFFFF, 0xFFFF, "9 Series Chipset Family PCI Express Root Port 1(0x8C90)"},
{0x8086, 0x8C92, 0xFFFF, 0xFFFF, "9 Series Chipset Family PCI Express Root Port 2(0x8C92)"},
{0x8086, 0x8C94, 0xFFFF, 0xFFFF, "9 Series Chipset Family PCI Express Root Port 3(0x8C94)"},
{0x8086, 0x8C96, 0xFFFF, 0xFFFF, "9 Series Chipset Family PCI Express Root Port 4(0x8C96)"},
{0x8086, 0x8C98, 0xFFFF, 0xFFFF, "9 Series Chipset Family PCI Express Root Port 5(0x8C98)"},
{0x8086, 0x8C9A, 0xFFFF, 0xFFFF, "9 Series Chipset Family PCI Express Root Port 6(0x8C9A)"},
{0x8086, 0x8C9C, 0xFFFF, 0xFFFF, "9 Series Chipset Family PCI Express Root Port 7(0x8C9C)"},
{0x8086, 0x8C9E, 0xFFFF, 0xFFFF, "9 Series Chipset Family PCI Express Root Port 8(0x8C9E)"},
{0x8086, 0x8CA0, 0xFFFF, 0xFFFF, "9 Series Chipset Family HD Audio Controller(0x8CA0)"},
{0x8086, 0x8CA2, 0xFFFF, 0xFFFF, "9 Series Chipset Family SMBus Controller(0x8CA2)"},
{0x8086, 0x8CA4, 0xFFFF, 0xFFFF, "9 Series Chipset Family Thermal Controller(0x8CA4)"},
{0x8086, 0x8CA6, 0xFFFF, 0xFFFF, "9 Series Chipset Family USB EHCI Controller #1(0x8CA6)"},
{0x8086, 0x8CAD, 0xFFFF, 0xFFFF, "9 Series Chipset Family USB EHCI Controller #2(0x8CAD)"},
{0x8086, 0x8CB1, 0xFFFF, 0xFFFF, "9 Series Chipset Family USB xHCI Controller(0x8CB1)"},
{0x8086, 0x8CB3, 0xFFFF, 0xFFFF, "9 Series Chipset Family LAN Controller(0x8CB3)"},
{0x8086, 0x8CBA, 0xFFFF, 0xFFFF, "9 Series Chipset Family ME Interface #1(0x8CBA)"},
{0x8086, 0x8CBB, 0xFFFF, 0xFFFF, "9 Series Chipset Family ME Interface #2(0x8CBB)"},
{0x8086, 0x8CBC, 0xFFFF, 0xFFFF, "9 Series Chipset Family IDE-R Controller(0x8CBC)"},
{0x8086, 0x8CBD, 0xFFFF, 0xFFFF, "9 Series Chipset Family KT Controller(0x8CBD)"},
{0x8086, 0x8CC1, 0xFFFF, 0xFFFF, "9 Series Chipset Family LPC Controller(0x8CC1)"},
{0x8086, 0x8CC2, 0xFFFF, 0xFFFF, "9 Series Chipset Family LPC Controller(0x8CC2)"},
{0x8086, 0x8CC3, 0xFFFF, 0xFFFF, "HM97 Chipset LPC Controller(0x8CC3)"},
{0x8086, 0x8CC4, 0xFFFF, 0xFFFF, "Z97 Chipset LPC Controller(0x8CC4)"},
{0x8086, 0x8CC5, 0xFFFF, 0xFFFF, "QM97 Chipset LPC Controller(0x8CC5)"},
{0x8086, 0x8CC6, 0xFFFF, 0xFFFF, "H97 Chipset LPC Controller(0x8CC6)"},
{0x8086, 0x8D00, 0xFFFF, 0xFFFF, "C610/X99 series chipset 4-port SATA Controller [IDE mode](0x8D00)"},
{0x8086, 0x8D02, 0xFFFF, 0xFFFF, "C610/X99 series chipset 6-Port SATA Controller [AHCI mode](0x8D02)"},
{0x8086, 0x8D04, 0xFFFF, 0xFFFF, "C610/X99 series chipset SATA Controller [RAID mode](0x8D04)"},
{0x8086, 0x8D06, 0xFFFF, 0xFFFF, "C610/X99 series chipset SATA Controller [RAID mode](0x8D06)"},
{0x8086, 0x8D06, 0x17AA, 0x1031, "ThinkServer RAID 110i(0x17AA-0x1031)"},
{0x8086, 0x8D08, 0xFFFF, 0xFFFF, "C610/X99 series chipset 2-port SATA Controller [IDE mode](0x8D08)"},
{0x8086, 0x8D0E, 0xFFFF, 0xFFFF, "C610/X99 series chipset SATA Controller [RAID mode](0x8D0E)"},
{0x8086, 0x8D10, 0xFFFF, 0xFFFF, "C610/X99 series chipset PCI Express Root Port #1(0x8D10)"},
{0x8086, 0x8D11, 0xFFFF, 0xFFFF, "C610/X99 series chipset PCI Express Root Port #1(0x8D11)"},
{0x8086, 0x8D12, 0xFFFF, 0xFFFF, "C610/X99 series chipset PCI Express Root Port #2(0x8D12)"},
{0x8086, 0x8D13, 0xFFFF, 0xFFFF, "C610/X99 series chipset PCI Express Root Port #2(0x8D13)"},
{0x8086, 0x8D14, 0xFFFF, 0xFFFF, "C610/X99 series chipset PCI Express Root Port #3(0x8D14)"},
{0x8086, 0x8D15, 0xFFFF, 0xFFFF, "C610/X99 series chipset PCI Express Root Port #3(0x8D15)"},
{0x8086, 0x8D16, 0xFFFF, 0xFFFF, "C610/X99 series chipset PCI Express Root Port #4(0x8D16)"},
{0x8086, 0x8D17, 0xFFFF, 0xFFFF, "C610/X99 series chipset PCI Express Root Port #4(0x8D17)"},
{0x8086, 0x8D18, 0xFFFF, 0xFFFF, "C610/X99 series chipset PCI Express Root Port #5(0x8D18)"},
{0x8086, 0x8D19, 0xFFFF, 0xFFFF, "C610/X99 series chipset PCI Express Root Port #5(0x8D19)"},
{0x8086, 0x8D1A, 0xFFFF, 0xFFFF, "C610/X99 series chipset PCI Express Root Port #6(0x8D1A)"},
{0x8086, 0x8D1B, 0xFFFF, 0xFFFF, "C610/X99 series chipset PCI Express Root Port #6(0x8D1B)"},
{0x8086, 0x8D1C, 0xFFFF, 0xFFFF, "C610/X99 series chipset PCI Express Root Port #7(0x8D1C)"},
{0x8086, 0x8D1D, 0xFFFF, 0xFFFF, "C610/X99 series chipset PCI Express Root Port #7(0x8D1D)"},
{0x8086, 0x8D1E, 0xFFFF, 0xFFFF, "C610/X99 series chipset PCI Express Root Port #8(0x8D1E)"},
{0x8086, 0x8D1F, 0xFFFF, 0xFFFF, "C610/X99 series chipset PCI Express Root Port #8(0x8D1F)"},
{0x8086, 0x8D20, 0xFFFF, 0xFFFF, "C610/X99 series chipset HD Audio Controller(0x8D20)"},
{0x8086, 0x8D21, 0xFFFF, 0xFFFF, "C610/X99 series chipset HD Audio Controller(0x8D21)"},
{0x8086, 0x8D22, 0xFFFF, 0xFFFF, "C610/X99 series chipset SMBus Controller(0x8D22)"},
{0x8086, 0x8D22, 0x15D9, 0x0832, "X10SRL-F(0x15D9-0x0832)"},
{0x8086, 0x8D24, 0xFFFF, 0xFFFF, "C610/X99 series chipset Thermal Subsystem(0x8D24)"},
{0x8086, 0x8D26, 0xFFFF, 0xFFFF, "C610/X99 series chipset USB Enhanced Host Controller #1(0x8D26)"},
{0x8086, 0x8D26, 0x15D9, 0x0832, "X10SRL-F(0x15D9-0x0832)"},
{0x8086, 0x8D2D, 0xFFFF, 0xFFFF, "C610/X99 series chipset USB Enhanced Host Controller #2(0x8D2D)"},
{0x8086, 0x8D2D, 0x15D9, 0x0832, "X10SRL-F(0x15D9-0x0832)"},
{0x8086, 0x8D31, 0xFFFF, 0xFFFF, "C610/X99 series chipset USB xHCI Host Controller(0x8D31)"},
{0x8086, 0x8D31, 0x15D9, 0x0832, "X10SRL-F(0x15D9-0x0832)"},
{0x8086, 0x8D33, 0xFFFF, 0xFFFF, "C610/X99 series chipset LAN Controller(0x8D33)"},
{0x8086, 0x8D34, 0xFFFF, 0xFFFF, "C610/X99 series chipset NAND Controller(0x8D34)"},
{0x8086, 0x8D3A, 0xFFFF, 0xFFFF, "C610/X99 series chipset MEI Controller #1(0x8D3A)"},
{0x8086, 0x8D3A, 0x15D9, 0x0832, "X10SRL-F(0x15D9-0x0832)"},
{0x8086, 0x8D3B, 0xFFFF, 0xFFFF, "C610/X99 series chipset MEI Controller #2(0x8D3B)"},
{0x8086, 0x8D3B, 0x15D9, 0x0832, "X10SRL-F(0x15D9-0x0832)"},
{0x8086, 0x8D3C, 0xFFFF, 0xFFFF, "C610/X99 series chipset IDE-r Controller(0x8D3C)"},
{0x8086, 0x8D3D, 0xFFFF, 0xFFFF, "C610/X99 series chipset KT Controller(0x8D3D)"},
{0x8086, 0x8D40, 0xFFFF, 0xFFFF, "C610/X99 series chipset LPC Controller(0x8D40)"},
{0x8086, 0x8D41, 0xFFFF, 0xFFFF, "C610/X99 series chipset LPC Controller(0x8D41)"},
{0x8086, 0x8D42, 0xFFFF, 0xFFFF, "C610/X99 series chipset LPC Controller(0x8D42)"},
{0x8086, 0x8D43, 0xFFFF, 0xFFFF, "C610/X99 series chipset LPC Controller(0x8D43)"},
{0x8086, 0x8D44, 0xFFFF, 0xFFFF, "C610/X99 series chipset LPC Controller(0x8D44)"},
{0x8086, 0x8D44, 0x15D9, 0x0832, "X10SRL-F(0x15D9-0x0832)"},
{0x8086, 0x8D45, 0xFFFF, 0xFFFF, "C610/X99 series chipset LPC Controller(0x8D45)"},
{0x8086, 0x8D46, 0xFFFF, 0xFFFF, "C610/X99 series chipset LPC Controller(0x8D46)"},
{0x8086, 0x8D47, 0xFFFF, 0xFFFF, "C610/X99 series chipset LPC Controller(0x8D47)"},
{0x8086, 0x8D48, 0xFFFF, 0xFFFF, "C610/X99 series chipset LPC Controller(0x8D48)"},
{0x8086, 0x8D49, 0xFFFF, 0xFFFF, "C610/X99 series chipset LPC Controller(0x8D49)"},
{0x8086, 0x8D4A, 0xFFFF, 0xFFFF, "C610/X99 series chipset LPC Controller(0x8D4A)"},
{0x8086, 0x8D4B, 0xFFFF, 0xFFFF, "C610/X99 series chipset LPC Controller(0x8D4B)"},
{0x8086, 0x8D4C, 0xFFFF, 0xFFFF, "C610/X99 series chipset LPC Controller(0x8D4C)"},
{0x8086, 0x8D4D, 0xFFFF, 0xFFFF, "C610/X99 series chipset LPC Controller(0x8D4D)"},
{0x8086, 0x8D4E, 0xFFFF, 0xFFFF, "C610/X99 series chipset LPC Controller(0x8D4E)"},
{0x8086, 0x8D4F, 0xFFFF, 0xFFFF, "C610/X99 series chipset LPC Controller(0x8D4F)"},
{0x8086, 0x8D60, 0xFFFF, 0xFFFF, "C610/X99 series chipset sSATA Controller [IDE mode](0x8D60)"},
{0x8086, 0x8D62, 0xFFFF, 0xFFFF, "C610/X99 series chipset sSATA Controller [AHCI mode](0x8D62)"},
{0x8086, 0x8D64, 0xFFFF, 0xFFFF, "C610/X99 series chipset sSATA Controller [RAID mode](0x8D64)"},
{0x8086, 0x8D66, 0xFFFF, 0xFFFF, "C610/X99 series chipset sSATA Controller [RAID mode](0x8D66)"},
{0x8086, 0x8D68, 0xFFFF, 0xFFFF, "C610/X99 series chipset sSATA Controller [IDE mode](0x8D68)"},
{0x8086, 0x8D6E, 0xFFFF, 0xFFFF, "C610/X99 series chipset sSATA Controller [RAID mode](0x8D6E)"},
{0x8086, 0x8D7C, 0xFFFF, 0xFFFF, "C610/X99 series chipset SPSR(0x8D7C)"},
{0x8086, 0x8D7C, 0x15D9, 0x0832, "X10SRL-F(0x15D9-0x0832)"},
{0x8086, 0x8D7D, 0xFFFF, 0xFFFF, "C610/X99 series chipset MS SMBus 0(0x8D7D)"},
{0x8086, 0x8D7E, 0xFFFF, 0xFFFF, "C610/X99 series chipset MS SMBus 1(0x8D7E)"},
{0x8086, 0x8D7F, 0xFFFF, 0xFFFF, "C610/X99 series chipset MS SMBus 2(0x8D7F)"},
{0x8086, 0x9000, 0xFFFF, 0xFFFF, "IXP2000 Family Network Processor(0x9000)"},
{0x8086, 0x9001, 0xFFFF, 0xFFFF, "IXP2400 Network Processor(0x9001)"},
{0x8086, 0x9002, 0xFFFF, 0xFFFF, "IXP2300 Network Processor(0x9002)"},
{0x8086, 0x9004, 0xFFFF, 0xFFFF, "IXP2800 Network Processor(0x9004)"},
{0x8086, 0x9621, 0xFFFF, 0xFFFF, "Integrated RAID(0x9621)"},
{0x8086, 0x9622, 0xFFFF, 0xFFFF, "Integrated RAID(0x9622)"},
{0x8086, 0x9641, 0xFFFF, 0xFFFF, "Integrated RAID(0x9641)"},
{0x8086, 0x96A1, 0xFFFF, 0xFFFF, "Integrated RAID(0x96A1)"},
{0x8086, 0x9840, 0xFFFF, 0xFFFF, "Lakefield GT2 [UHD Graphics](0x9840)"},
{0x8086, 0x9841, 0xFFFF, 0xFFFF, "Lakefield GT1.5 [UHD Graphics](0x9841)"},
{0x8086, 0x9A01, 0xFFFF, 0xFFFF, "11th Gen Core Processor PCIe Controller #1(0x9A01)"},
{0x8086, 0x9A03, 0xFFFF, 0xFFFF, "TigerLake-LP Dynamic Tuning Processor Participant(0x9A03)"},
{0x8086, 0x9A09, 0xFFFF, 0xFFFF, "11th Gen Core Processor PCIe Controller(0x9A09)"},
{0x8086, 0x9A0B, 0xFFFF, 0xFFFF, "Volume Management Device NVMe RAID Controller(0x9A0B)"},
{0x8086, 0x9A0D, 0xFFFF, 0xFFFF, "Tigerlake Telemetry Aggregator Driver(0x9A0D)"},
{0x8086, 0x9A0F, 0xFFFF, 0xFFFF, "11th Gen Core Processor PCIe Controller #0(0x9A0F)"},
{0x8086, 0x9A11, 0xFFFF, 0xFFFF, "GNA Scoring Accelerator module(0x9A11)"},
{0x8086, 0x9A13, 0xFFFF, 0xFFFF, "Tiger Lake-LP Thunderbolt 4 USB Controller(0x9A13)"},
{0x8086, 0x9A14, 0xFFFF, 0xFFFF, "11th Gen Core Processor Host Bridge/DRAM Registers(0x9A14)"},
{0x8086, 0x9A17, 0xFFFF, 0xFFFF, "Tiger Lake-H Thunderbolt 4 USB Controller(0x9A17)"},
{0x8086, 0x9A1B, 0xFFFF, 0xFFFF, "Tiger Lake-LP Thunderbolt 4 NHI #0(0x9A1B)"},
{0x8086, 0x9A1D, 0xFFFF, 0xFFFF, "Tiger Lake-LP Thunderbolt 4 NHI #1(0x9A1D)"},
{0x8086, 0x9A1F, 0xFFFF, 0xFFFF, "Tiger Lake-H Thunderbolt 4 NHI #0(0x9A1F)"},
{0x8086, 0x9A21, 0xFFFF, 0xFFFF, "Tiger Lake-H Thunderbolt 4 NHI #1(0x9A21)"},
{0x8086, 0x9A23, 0xFFFF, 0xFFFF, "Tiger Lake-LP Thunderbolt 4 PCI Express Root Port #0(0x9A23)"},
{0x8086, 0x9A25, 0xFFFF, 0xFFFF, "Tiger Lake-LP Thunderbolt 4 PCI Express Root Port #1(0x9A25)"},
{0x8086, 0x9A26, 0xFFFF, 0xFFFF, "11th Gen Core Processor Host Bridge/DRAM Registers(0x9A26)"},
{0x8086, 0x9A27, 0xFFFF, 0xFFFF, "Tiger Lake-LP Thunderbolt 4 PCI Express Root Port #2(0x9A27)"},
{0x8086, 0x9A29, 0xFFFF, 0xFFFF, "Tiger Lake-LP Thunderbolt 4 PCI Express Root Port #3(0x9A29)"},
{0x8086, 0x9A2B, 0xFFFF, 0xFFFF, "Tiger Lake-H Thunderbolt 4 PCI Express Root Port #0(0x9A2B)"},
{0x8086, 0x9A2D, 0xFFFF, 0xFFFF, "Tiger Lake-H Thunderbolt 4 PCI Express Root Port #1(0x9A2D)"},
{0x8086, 0x9A2F, 0xFFFF, 0xFFFF, "Tiger Lake-H Thunderbolt 4 PCI Express Root Port #2(0x9A2F)"},
{0x8086, 0x9A31, 0xFFFF, 0xFFFF, "Tiger Lake-H Thunderbolt 4 PCI Express Root Port #3(0x9A31)"},
{0x8086, 0x9A33, 0xFFFF, 0xFFFF, "Tiger Lake Trace Hub(0x9A33)"},
{0x8086, 0x9A36, 0xFFFF, 0xFFFF, "11th Gen Core Processor Host Bridge/DRAM Registers(0x9A36)"},
{0x8086, 0x9A40, 0xFFFF, 0xFFFF, "Tiger Lake-UP4 GT2 [Iris Xe Graphics](0x9A40)"},
{0x8086, 0x9A49, 0xFFFF, 0xFFFF, "TigerLake-LP GT2 [Iris Xe Graphics](0x9A49)"},
{0x8086, 0x9A60, 0xFFFF, 0xFFFF, "TigerLake-H GT1 [UHD Graphics](0x9A60)"},
{0x8086, 0x9A68, 0xFFFF, 0xFFFF, "TigerLake-H GT1 [UHD Graphics](0x9A68)"},
{0x8086, 0x9A70, 0xFFFF, 0xFFFF, "Tiger Lake-H GT1 [UHD Graphics](0x9A70)"},
{0x8086, 0x9A78, 0xFFFF, 0xFFFF, "Tiger Lake-LP GT2 [UHD Graphics G4](0x9A78)"},
{0x8086, 0x9B21, 0xFFFF, 0xFFFF, "Comet Lake-U GT2 [UHD Graphics 620](0x9B21)"},
{0x8086, 0x9B33, 0xFFFF, 0xFFFF, "Comet Lake-S 6c Host Bridge/DRAM Controller(0x9B33)"},
{0x8086, 0x9B41, 0xFFFF, 0xFFFF, "CometLake-U GT2 [UHD Graphics](0x9B41)"},
{0x8086, 0x9B41, 0x1028, 0x09BD, "Latitude 7310(0x1028-0x09BD)"},
{0x8086, 0x9B41, 0x1028, 0x09BE, "Latitude 7410(0x1028-0x09BE)"},
{0x8086, 0x9B43, 0xFFFF, 0xFFFF, "10th Gen Core Processor Host Bridge/DRAM Registers(0x9B43)"},
{0x8086, 0x9B44, 0xFFFF, 0xFFFF, "10th Gen Core Processor Host Bridge/DRAM Registers(0x9B44)"},
{0x8086, 0x9B51, 0xFFFF, 0xFFFF, "10th Gen Core Processor Host Bridge/DRAM Registers(0x9B51)"},
{0x8086, 0x9B53, 0xFFFF, 0xFFFF, "Comet Lake-S 6c Host Bridge/DRAM Controller(0x9B53)"},
{0x8086, 0x9B54, 0xFFFF, 0xFFFF, "10th Gen Core Processor Host Bridge/DRAM Registers(0x9B54)"},
{0x8086, 0x9B61, 0xFFFF, 0xFFFF, "Comet Lake-U v1 4c Host Bridge/DRAM Controller(0x9B61)"},
{0x8086, 0x9B61, 0x1028, 0x09BE, "Latitude 7410(0x1028-0x09BE)"},
{0x8086, 0x9B63, 0xFFFF, 0xFFFF, "10th Gen Core Processor Host Bridge/DRAM Registers(0x9B63)"},
{0x8086, 0x9B64, 0xFFFF, 0xFFFF, "10th Gen Core Processor Host Bridge/DRAM Registers(0x9B64)"},
{0x8086, 0x9BA4, 0xFFFF, 0xFFFF, "Comet Lake-H GT1 [UHD Graphics 610](0x9BA4)"},
{0x8086, 0x9BA8, 0xFFFF, 0xFFFF, "CometLake-S GT1 [UHD Graphics 610](0x9BA8)"},
{0x8086, 0x9BAA, 0xFFFF, 0xFFFF, "Comet Lake UHD Graphics(0x9BAA)"},
{0x8086, 0x9BAC, 0xFFFF, 0xFFFF, "Comet Lake UHD Graphics(0x9BAC)"},
{0x8086, 0x9BC4, 0xFFFF, 0xFFFF, "CometLake-H GT2 [UHD Graphics](0x9BC4)"},
{0x8086, 0x9BC5, 0xFFFF, 0xFFFF, "CometLake-S GT2 [UHD Graphics 630](0x9BC5)"},
{0x8086, 0x9BC6, 0xFFFF, 0xFFFF, "Comet Lake-S GT2 [UHD Graphics P630](0x9BC6)"},
{0x8086, 0x9BC8, 0xFFFF, 0xFFFF, "CometLake-S GT2 [UHD Graphics 630](0x9BC8)"},
{0x8086, 0x9BCA, 0xFFFF, 0xFFFF, "Comet Lake UHD Graphics(0x9BCA)"},
{0x8086, 0x9BCC, 0xFFFF, 0xFFFF, "Comet Lake UHD Graphics(0x9BCC)"},
{0x8086, 0x9BE6, 0xFFFF, 0xFFFF, "Comet Lake-S GT2 [UHD Graphics P630](0x9BE6)"},
{0x8086, 0x9BF6, 0xFFFF, 0xFFFF, "Coffee Lake-S GT2 [UHD Graphics P630](0x9BF6)"},
{0x8086, 0x9C00, 0xFFFF, 0xFFFF, "8 Series SATA Controller 1 [IDE mode](0x9C00)"},
{0x8086, 0x9C01, 0xFFFF, 0xFFFF, "8 Series SATA Controller 1 [IDE mode](0x9C01)"},
{0x8086, 0x9C02, 0xFFFF, 0xFFFF, "8 Series SATA Controller 1 [AHCI mode](0x9C02)"},
{0x8086, 0x9C03, 0xFFFF, 0xFFFF, "8 Series SATA Controller 1 [AHCI mode](0x9C03)"},
{0x8086, 0x9C03, 0x17AA, 0x2214, "ThinkPad X240(0x17AA-0x2214)"},
{0x8086, 0x9C04, 0xFFFF, 0xFFFF, "8 Series SATA Controller 1 [RAID mode](0x9C04)"},
{0x8086, 0x9C05, 0xFFFF, 0xFFFF, "8 Series SATA Controller 1 [RAID mode](0x9C05)"},
{0x8086, 0x9C06, 0xFFFF, 0xFFFF, "8 Series SATA Controller 1 [RAID mode](0x9C06)"},
{0x8086, 0x9C07, 0xFFFF, 0xFFFF, "8 Series SATA Controller 1 [RAID mode](0x9C07)"},
{0x8086, 0x9C08, 0xFFFF, 0xFFFF, "8 Series SATA Controller 2 [IDE mode](0x9C08)"},
{0x8086, 0x9C09, 0xFFFF, 0xFFFF, "8 Series SATA Controller 2 [IDE mode](0x9C09)"},
{0x8086, 0x9C0A, 0xFFFF, 0xFFFF, "8 Series SATA Controller [Reserved](0x9C0A)"},
{0x8086, 0x9C0B, 0xFFFF, 0xFFFF, "8 Series SATA Controller [Reserved](0x9C0B)"},
{0x8086, 0x9C0C, 0xFFFF, 0xFFFF, "8 Series SATA Controller [Reserved](0x9C0C)"},
{0x8086, 0x9C0D, 0xFFFF, 0xFFFF, "8 Series SATA Controller [Reserved](0x9C0D)"},
{0x8086, 0x9C0E, 0xFFFF, 0xFFFF, "8 Series SATA Controller 1 [RAID mode](0x9C0E)"},
{0x8086, 0x9C0F, 0xFFFF, 0xFFFF, "8 Series SATA Controller 1 [RAID mode](0x9C0F)"},
{0x8086, 0x9C10, 0xFFFF, 0xFFFF, "8 Series PCI Express Root Port 1(0x9C10)"},
{0x8086, 0x9C11, 0xFFFF, 0xFFFF, "8 Series PCI Express Root Port 1(0x9C11)"},
{0x8086, 0x9C12, 0xFFFF, 0xFFFF, "8 Series PCI Express Root Port 2(0x9C12)"},
{0x8086, 0x9C13, 0xFFFF, 0xFFFF, "8 Series PCI Express Root Port 2(0x9C13)"},
{0x8086, 0x9C14, 0xFFFF, 0xFFFF, "8 Series PCI Express Root Port 3(0x9C14)"},
{0x8086, 0x9C15, 0xFFFF, 0xFFFF, "8 Series PCI Express Root Port 3(0x9C15)"},
{0x8086, 0x9C16, 0xFFFF, 0xFFFF, "8 Series PCI Express Root Port 4(0x9C16)"},
{0x8086, 0x9C17, 0xFFFF, 0xFFFF, "8 Series PCI Express Root Port 4(0x9C17)"},
{0x8086, 0x9C18, 0xFFFF, 0xFFFF, "8 Series PCI Express Root Port 5(0x9C18)"},
{0x8086, 0x9C19, 0xFFFF, 0xFFFF, "8 Series PCI Express Root Port 5(0x9C19)"},
{0x8086, 0x9C1A, 0xFFFF, 0xFFFF, "8 Series PCI Express Root Port 6(0x9C1A)"},
{0x8086, 0x9C1B, 0xFFFF, 0xFFFF, "8 Series PCI Express Root Port 6(0x9C1B)"},
{0x8086, 0x9C1C, 0xFFFF, 0xFFFF, "8 Series PCI Express Root Port 7(0x9C1C)"},
{0x8086, 0x9C1D, 0xFFFF, 0xFFFF, "8 Series PCI Express Root Port 7(0x9C1D)"},
{0x8086, 0x9C1E, 0xFFFF, 0xFFFF, "8 Series PCI Express Root Port 8(0x9C1E)"},
{0x8086, 0x9C1F, 0xFFFF, 0xFFFF, "8 Series PCI Express Root Port 8(0x9C1F)"},
{0x8086, 0x9C20, 0xFFFF, 0xFFFF, "8 Series HD Audio Controller(0x9C20)"},
{0x8086, 0x9C20, 0x17AA, 0x2214, "ThinkPad X240(0x17AA-0x2214)"},
{0x8086, 0x9C21, 0xFFFF, 0xFFFF, "8 Series HD Audio Controller(0x9C21)"},
{0x8086, 0x9C22, 0xFFFF, 0xFFFF, "8 Series SMBus Controller(0x9C22)"},
{0x8086, 0x9C22, 0x17AA, 0x2214, "ThinkPad X240(0x17AA-0x2214)"},
{0x8086, 0x9C23, 0xFFFF, 0xFFFF, "8 Series CHAP Counters(0x9C23)"},
{0x8086, 0x9C24, 0xFFFF, 0xFFFF, "8 Series Thermal(0x9C24)"},
{0x8086, 0x9C26, 0xFFFF, 0xFFFF, "8 Series USB EHCI #1(0x9C26)"},
{0x8086, 0x9C26, 0x17AA, 0x220C, "T440s(0x17AA-0x220C)"},
{0x8086, 0x9C26, 0x17AA, 0x2214, "ThinkPad X240(0x17AA-0x2214)"},
{0x8086, 0x9C2D, 0xFFFF, 0xFFFF, "8 Series USB EHCI #2(0x9C2D)"},
{0x8086, 0x9C31, 0xFFFF, 0xFFFF, "8 Series USB xHCI HC(0x9C31)"},
{0x8086, 0x9C31, 0x17AA, 0x2214, "ThinkPad X240(0x17AA-0x2214)"},
{0x8086, 0x9C31, 0x8086, 0x7270, "Apple MacBookAir6,2 / MacBookPro11,1(0x8086-0x7270)"},
{0x8086, 0x9C35, 0xFFFF, 0xFFFF, "8 Series SDIO Controller(0x9C35)"},
{0x8086, 0x9C36, 0xFFFF, 0xFFFF, "8 Series Audio DSP Controller(0x9C36)"},
{0x8086, 0x9C3A, 0xFFFF, 0xFFFF, "8 Series HECI #0(0x9C3A)"},
{0x8086, 0x9C3A, 0x17AA, 0x2214, "ThinkPad X240(0x17AA-0x2214)"},
{0x8086, 0x9C3B, 0xFFFF, 0xFFFF, "8 Series HECI #1(0x9C3B)"},
{0x8086, 0x9C3C, 0xFFFF, 0xFFFF, "8 Series HECI IDER(0x9C3C)"},
{0x8086, 0x9C3D, 0xFFFF, 0xFFFF, "8 Series HECI KT(0x9C3D)"},
{0x8086, 0x9C40, 0xFFFF, 0xFFFF, "8 Series LPC Controller(0x9C40)"},
{0x8086, 0x9C41, 0xFFFF, 0xFFFF, "8 Series LPC Controller(0x9C41)"},
{0x8086, 0x9C42, 0xFFFF, 0xFFFF, "8 Series LPC Controller(0x9C42)"},
{0x8086, 0x9C43, 0xFFFF, 0xFFFF, "8 Series LPC Controller(0x9C43)"},
{0x8086, 0x9C43, 0x17AA, 0x2214, "ThinkPad X240(0x17AA-0x2214)"},
{0x8086, 0x9C44, 0xFFFF, 0xFFFF, "8 Series LPC Controller(0x9C44)"},
{0x8086, 0x9C45, 0xFFFF, 0xFFFF, "8 Series LPC Controller(0x9C45)"},
{0x8086, 0x9C46, 0xFFFF, 0xFFFF, "8 Series LPC Controller(0x9C46)"},
{0x8086, 0x9C47, 0xFFFF, 0xFFFF, "8 Series LPC Controller(0x9C47)"},
{0x8086, 0x9C60, 0xFFFF, 0xFFFF, "8 Series Low Power Sub-System DMA(0x9C60)"},
{0x8086, 0x9C61, 0xFFFF, 0xFFFF, "8 Series I2C Controller #0(0x9C61)"},
{0x8086, 0x9C62, 0xFFFF, 0xFFFF, "8 Series I2C Controller #1(0x9C62)"},
{0x8086, 0x9C63, 0xFFFF, 0xFFFF, "8 Series UART Controller #0(0x9C63)"},
{0x8086, 0x9C64, 0xFFFF, 0xFFFF, "8 Series UART Controller #1(0x9C64)"},
{0x8086, 0x9C65, 0xFFFF, 0xFFFF, "8 Series SPI Controller #0(0x9C65)"},
{0x8086, 0x9C66, 0xFFFF, 0xFFFF, "8 Series SPI Controller #1(0x9C66)"},
{0x8086, 0x9C83, 0xFFFF, 0xFFFF, "Wildcat Point-LP SATA Controller [AHCI Mode](0x9C83)"},
{0x8086, 0x9C85, 0xFFFF, 0xFFFF, "Wildcat Point-LP SATA Controller [RAID Mode](0x9C85)"},
{0x8086, 0x9C87, 0xFFFF, 0xFFFF, "Wildcat Point-LP SATA Controller [RAID Mode](0x9C87)"},
{0x8086, 0x9C8F, 0xFFFF, 0xFFFF, "Wildcat Point-LP SATA Controller [RAID Mode](0x9C8F)"},
{0x8086, 0x9C90, 0xFFFF, 0xFFFF, "Wildcat Point-LP PCI Express Root Port #1(0x9C90)"},
{0x8086, 0x9C92, 0xFFFF, 0xFFFF, "Wildcat Point-LP PCI Express Root Port #2(0x9C92)"},
{0x8086, 0x9C94, 0xFFFF, 0xFFFF, "Wildcat Point-LP PCI Express Root Port #3(0x9C94)"},
{0x8086, 0x9C96, 0xFFFF, 0xFFFF, "Wildcat Point-LP PCI Express Root Port #4(0x9C96)"},
{0x8086, 0x9C98, 0xFFFF, 0xFFFF, "Wildcat Point-LP PCI Express Root Port #5(0x9C98)"},
{0x8086, 0x9C9A, 0xFFFF, 0xFFFF, "Wildcat Point-LP PCI Express Root Port #6(0x9C9A)"},
{0x8086, 0x9CA0, 0xFFFF, 0xFFFF, "Wildcat Point-LP High Definition Audio Controller(0x9CA0)"},
{0x8086, 0x9CA2, 0xFFFF, 0xFFFF, "Wildcat Point-LP SMBus Controller(0x9CA2)"},
{0x8086, 0x9CA4, 0xFFFF, 0xFFFF, "Wildcat Point-LP Thermal Management Controller(0x9CA4)"},
{0x8086, 0x9CA6, 0xFFFF, 0xFFFF, "Wildcat Point-LP USB EHCI Controller(0x9CA6)"},
{0x8086, 0x9CB1, 0xFFFF, 0xFFFF, "Wildcat Point-LP USB xHCI Controller(0x9CB1)"},
{0x8086, 0x9CB5, 0xFFFF, 0xFFFF, "Wildcat Point-LP Secure Digital IO Controller(0x9CB5)"},
{0x8086, 0x9CB6, 0xFFFF, 0xFFFF, "Wildcat Point-LP Smart Sound Technology Controller(0x9CB6)"},
{0x8086, 0x9CBA, 0xFFFF, 0xFFFF, "Wildcat Point-LP MEI Controller #1(0x9CBA)"},
{0x8086, 0x9CBB, 0xFFFF, 0xFFFF, "Wildcat Point-LP MEI Controller #2(0x9CBB)"},
{0x8086, 0x9CBC, 0xFFFF, 0xFFFF, "Wildcat Point-LP IDE-r Controller(0x9CBC)"},
{0x8086, 0x9CBD, 0xFFFF, 0xFFFF, "Wildcat Point-LP KT Controller(0x9CBD)"},
{0x8086, 0x9CC1, 0xFFFF, 0xFFFF, "Wildcat Point-LP LPC Controller(0x9CC1)"},
{0x8086, 0x9CC2, 0xFFFF, 0xFFFF, "Wildcat Point-LP LPC Controller(0x9CC2)"},
{0x8086, 0x9CC3, 0xFFFF, 0xFFFF, "Wildcat Point-LP LPC Controller(0x9CC3)"},
{0x8086, 0x9CC5, 0xFFFF, 0xFFFF, "Wildcat Point-LP LPC Controller(0x9CC5)"},
{0x8086, 0x9CC6, 0xFFFF, 0xFFFF, "Wildcat Point-LP LPC Controller(0x9CC6)"},
{0x8086, 0x9CC7, 0xFFFF, 0xFFFF, "Wildcat Point-LP LPC Controller(0x9CC7)"},
{0x8086, 0x9CC9, 0xFFFF, 0xFFFF, "Wildcat Point-LP LPC Controller(0x9CC9)"},
{0x8086, 0x9CE0, 0xFFFF, 0xFFFF, "Wildcat Point-LP Serial IO DMA Controller(0x9CE0)"},
{0x8086, 0x9CE1, 0xFFFF, 0xFFFF, "Wildcat Point-LP Serial IO I2C Controller #0(0x9CE1)"},
{0x8086, 0x9CE2, 0xFFFF, 0xFFFF, "Wildcat Point-LP Serial IO I2C Controller #1(0x9CE2)"},
{0x8086, 0x9CE3, 0xFFFF, 0xFFFF, "Wildcat Point-LP Serial IO UART Controller #0(0x9CE3)"},
{0x8086, 0x9CE4, 0xFFFF, 0xFFFF, "Wildcat Point-LP Serial IO UART Controller #1(0x9CE4)"},
{0x8086, 0x9CE5, 0xFFFF, 0xFFFF, "Wildcat Point-LP Serial IO GSPI Controller #0(0x9CE5)"},
{0x8086, 0x9CE6, 0xFFFF, 0xFFFF, "Wildcat Point-LP Serial IO GSPI Controller #1(0x9CE6)"},
{0x8086, 0x9D03, 0xFFFF, 0xFFFF, "Sunrise Point-LP SATA Controller [AHCI mode](0x9D03)"},
{0x8086, 0x9D03, 0x1025, 0x115F, "Acer Aspire E5-575G(0x1025-0x115F)"},
{0x8086, 0x9D03, 0x1028, 0x06DC, "Latitude E7470(0x1028-0x06DC)"},
{0x8086, 0x9D03, 0x1028, 0x06E6, "Latitude 11 5175 2-in-1(0x1028-0x06E6)"},
{0x8086, 0x9D03, 0x1028, 0x06F3, "Latitude 3570(0x1028-0x06F3)"},
{0x8086, 0x9D03, 0x103C, 0x8079, "EliteBook 840 G3(0x103C-0x8079)"},
{0x8086, 0x9D03, 0x17AA, 0x225D, "ThinkPad T480(0x17AA-0x225D)"},
{0x8086, 0x9D03, 0x17AA, 0x382A, "B51-80 Laptop(0x17AA-0x382A)"},
{0x8086, 0x9D10, 0xFFFF, 0xFFFF, "Sunrise Point-LP PCI Express Root Port #1(0x9D10)"},
{0x8086, 0x9D11, 0xFFFF, 0xFFFF, "Sunrise Point-LP PCI Express Root Port #2(0x9D11)"},
{0x8086, 0x9D12, 0xFFFF, 0xFFFF, "Sunrise Point-LP PCI Express Root Port #3(0x9D12)"},
{0x8086, 0x9D13, 0xFFFF, 0xFFFF, "Sunrise Point-LP PCI Express Root Port #4(0x9D13)"},
{0x8086, 0x9D14, 0xFFFF, 0xFFFF, "Sunrise Point-LP PCI Express Root Port #5(0x9D14)"},
{0x8086, 0x9D14, 0x17AA, 0x382A, "B51-80 Laptop(0x17AA-0x382A)"},
{0x8086, 0x9D15, 0xFFFF, 0xFFFF, "Sunrise Point-LP PCI Express Root Port #6(0x9D15)"},
{0x8086, 0x9D15, 0x17AA, 0x382A, "B51-80 Laptop(0x17AA-0x382A)"},
{0x8086, 0x9D16, 0xFFFF, 0xFFFF, "Sunrise Point-LP PCI Express Root Port #7(0x9D16)"},
{0x8086, 0x9D17, 0xFFFF, 0xFFFF, "Sunrise Point-LP PCI Express Root Port #8(0x9D17)"},
{0x8086, 0x9D18, 0xFFFF, 0xFFFF, "Sunrise Point-LP PCI Express Root Port #9(0x9D18)"},
{0x8086, 0x9D18, 0x17AA, 0x2247, "ThinkPad T570(0x17AA-0x2247)"},
{0x8086, 0x9D18, 0x17AA, 0x382A, "B51-80 Laptop(0x17AA-0x382A)"},
{0x8086, 0x9D19, 0xFFFF, 0xFFFF, "Sunrise Point-LP PCI Express Root Port #10(0x9D19)"},
{0x8086, 0x9D1A, 0xFFFF, 0xFFFF, "Sunrise Point-LP PCI Express Root Port #11(0x9D1A)"},
{0x8086, 0x9D21, 0xFFFF, 0xFFFF, "Sunrise Point-LP PMC(0x9D21)"},
{0x8086, 0x9D21, 0x1025, 0x115F, "Acer Aspire E5-575G(0x1025-0x115F)"},
{0x8086, 0x9D21, 0x1028, 0x06D6, "Latitude 7275 tablet(0x1028-0x06D6)"},
{0x8086, 0x9D21, 0x1028, 0x06DC, "Latitude E7470(0x1028-0x06DC)"},
{0x8086, 0x9D21, 0x1028, 0x06E6, "Latitude 11 5175 2-in-1(0x1028-0x06E6)"},
{0x8086, 0x9D21, 0x1028, 0x06F3, "Latitude 3570(0x1028-0x06F3)"},
{0x8086, 0x9D21, 0x103C, 0x8079, "EliteBook 840 G3(0x103C-0x8079)"},
{0x8086, 0x9D21, 0x17AA, 0x2247, "ThinkPad T570(0x17AA-0x2247)"},
{0x8086, 0x9D21, 0x17AA, 0x224F, "ThinkPad X1 Carbon 5th Gen(0x17AA-0x224F)"},
{0x8086, 0x9D21, 0x17AA, 0x225D, "ThinkPad T480(0x17AA-0x225D)"},
{0x8086, 0x9D21, 0x17AA, 0x382A, "B51-80 Laptop(0x17AA-0x382A)"},
{0x8086, 0x9D23, 0xFFFF, 0xFFFF, "Sunrise Point-LP SMBus(0x9D23)"},
{0x8086, 0x9D23, 0x1025, 0x115F, "Acer Aspire E5-575G(0x1025-0x115F)"},
{0x8086, 0x9D23, 0x1028, 0x06D6, "Latitude 7275 tablet(0x1028-0x06D6)"},
{0x8086, 0x9D23, 0x1028, 0x06DC, "Latitude E7470(0x1028-0x06DC)"},
{0x8086, 0x9D23, 0x1028, 0x06E6, "Latitude 11 5175 2-in-1(0x1028-0x06E6)"},
{0x8086, 0x9D23, 0x1028, 0x06F3, "Latitude 3570(0x1028-0x06F3)"},
{0x8086, 0x9D23, 0x103C, 0x8079, "EliteBook 840 G3(0x103C-0x8079)"},
{0x8086, 0x9D23, 0x17AA, 0x2247, "ThinkPad T570(0x17AA-0x2247)"},
{0x8086, 0x9D23, 0x17AA, 0x224F, "ThinkPad X1 Carbon 5th Gen(0x17AA-0x224F)"},
{0x8086, 0x9D23, 0x17AA, 0x225D, "ThinkPad T480(0x17AA-0x225D)"},
{0x8086, 0x9D23, 0x17AA, 0x382A, "B51-80 Laptop(0x17AA-0x382A)"},
{0x8086, 0x9D27, 0xFFFF, 0xFFFF, "Sunrise Point-LP Serial IO UART Controller #0(0x9D27)"},
{0x8086, 0x9D28, 0xFFFF, 0xFFFF, "Sunrise Point-LP Serial IO UART Controller #1(0x9D28)"},
{0x8086, 0x9D29, 0xFFFF, 0xFFFF, "Sunrise Point-LP Serial IO SPI Controller #0(0x9D29)"},
{0x8086, 0x9D2A, 0xFFFF, 0xFFFF, "Sunrise Point-LP Serial IO SPI Controller #1(0x9D2A)"},
{0x8086, 0x9D2D, 0xFFFF, 0xFFFF, "Sunrise Point-LP Secure Digital IO Controller(0x9D2D)"},
{0x8086, 0x9D2F, 0xFFFF, 0xFFFF, "Sunrise Point-LP USB 3.0 xHCI Controller(0x9D2F)"},
{0x8086, 0x9D2F, 0x1025, 0x115F, "Acer Aspire E5-575G(0x1025-0x115F)"},
{0x8086, 0x9D2F, 0x1028, 0x06D6, "Latitude 7275 tablet(0x1028-0x06D6)"},
{0x8086, 0x9D2F, 0x1028, 0x06DC, "Latitude E7470(0x1028-0x06DC)"},
{0x8086, 0x9D2F, 0x1028, 0x06E6, "Latitude 11 5175 2-in-1(0x1028-0x06E6)"},
{0x8086, 0x9D2F, 0x1028, 0x06F3, "Latitude 3570(0x1028-0x06F3)"},
{0x8086, 0x9D2F, 0x103C, 0x8079, "EliteBook 840 G3(0x103C-0x8079)"},
{0x8086, 0x9D2F, 0x17AA, 0x2247, "ThinkPad T570(0x17AA-0x2247)"},
{0x8086, 0x9D2F, 0x17AA, 0x225D, "ThinkPad T480(0x17AA-0x225D)"},
{0x8086, 0x9D2F, 0x17AA, 0x382A, "B51-80 Laptop(0x17AA-0x382A)"},
{0x8086, 0x9D31, 0xFFFF, 0xFFFF, "Sunrise Point-LP Thermal subsystem(0x9D31)"},
{0x8086, 0x9D31, 0x1025, 0x115F, "Acer Aspire E5-575G(0x1025-0x115F)"},
{0x8086, 0x9D31, 0x1028, 0x06D6, "Latitude 7275 tablet(0x1028-0x06D6)"},
{0x8086, 0x9D31, 0x1028, 0x06DC, "Latitude E7470(0x1028-0x06DC)"},
{0x8086, 0x9D31, 0x1028, 0x06E6, "Latitude 11 5175 2-in-1(0x1028-0x06E6)"},
{0x8086, 0x9D31, 0x1028, 0x06F3, "Latitude 3570(0x1028-0x06F3)"},
{0x8086, 0x9D31, 0x103C, 0x8079, "EliteBook 840 G3(0x103C-0x8079)"},
{0x8086, 0x9D31, 0x17AA, 0x2247, "ThinkPad T570(0x17AA-0x2247)"},
{0x8086, 0x9D31, 0x17AA, 0x224F, "ThinkPad X1 Carbon 5th Gen(0x17AA-0x224F)"},
{0x8086, 0x9D31, 0x17AA, 0x225D, "ThinkPad T480(0x17AA-0x225D)"},
{0x8086, 0x9D31, 0x17AA, 0x382A, "B51-80 Laptop(0x17AA-0x382A)"},
{0x8086, 0x9D32, 0xFFFF, 0xFFFF, "CSI-2 Host Controller(0x9D32)"},
{0x8086, 0x9D32, 0x1028, 0x06D6, "Latitude 7275 tablet(0x1028-0x06D6)"},
{0x8086, 0x9D32, 0x1028, 0x06E6, "Latitude 11 5175 2-in-1(0x1028-0x06E6)"},
{0x8086, 0x9D35, 0xFFFF, 0xFFFF, "Sunrise Point-LP Integrated Sensor Hub(0x9D35)"},
{0x8086, 0x9D35, 0x1028, 0x06D6, "Latitude 7275 tablet(0x1028-0x06D6)"},
{0x8086, 0x9D35, 0x1028, 0x06E6, "Latitude 11 5175 2-in-1(0x1028-0x06E6)"},
{0x8086, 0x9D3A, 0xFFFF, 0xFFFF, "Sunrise Point-LP CSME HECI #1(0x9D3A)"},
{0x8086, 0x9D3A, 0x1025, 0x115F, "Acer Aspire E5-575G(0x1025-0x115F)"},
{0x8086, 0x9D3A, 0x1028, 0x06D6, "Latitude 7275 tablet(0x1028-0x06D6)"},
{0x8086, 0x9D3A, 0x1028, 0x06DC, "Latitude E7470(0x1028-0x06DC)"},
{0x8086, 0x9D3A, 0x1028, 0x06E6, "Latitude 11 5175 2-in-1(0x1028-0x06E6)"},
{0x8086, 0x9D3A, 0x1028, 0x06F3, "Latitude 3570(0x1028-0x06F3)"},
{0x8086, 0x9D3A, 0x103C, 0x8079, "EliteBook 840 G3(0x103C-0x8079)"},
{0x8086, 0x9D3A, 0x17AA, 0x2247, "ThinkPad T570(0x17AA-0x2247)"},
{0x8086, 0x9D3A, 0x17AA, 0x224F, "ThinkPad X1 Carbon 5th Gen(0x17AA-0x224F)"},
{0x8086, 0x9D3A, 0x17AA, 0x225D, "ThinkPad T480(0x17AA-0x225D)"},
{0x8086, 0x9D3A, 0x17AA, 0x382A, "B51-80 Laptop(0x17AA-0x382A)"},
{0x8086, 0x9D3D, 0xFFFF, 0xFFFF, "Sunrise Point-LP Active Management Technology - SOL(0x9D3D)"},
{0x8086, 0x9D3D, 0x103C, 0x8079, "EliteBook 840 G3(0x103C-0x8079)"},
{0x8086, 0x9D3D, 0x17AA, 0x2247, "ThinkPad T570(0x17AA-0x2247)"},
{0x8086, 0x9D3E, 0xFFFF, 0xFFFF, "iTouch Controller(0x9D3E)"},
{0x8086, 0x9D43, 0xFFFF, 0xFFFF, "Sunrise Point-LP LPC Controller(0x9D43)"},
{0x8086, 0x9D43, 0x17AA, 0x382A, "B51-80 Laptop(0x17AA-0x382A)"},
{0x8086, 0x9D46, 0xFFFF, 0xFFFF, "LPC/eSPI Controller(0x9D46)"},
{0x8086, 0x9D46, 0x1028, 0x06D6, "Latitude 7275 tablet(0x1028-0x06D6)"},
{0x8086, 0x9D46, 0x1028, 0x06E6, "Latitude 11 5175 2-in-1(0x1028-0x06E6)"},
{0x8086, 0x9D48, 0xFFFF, 0xFFFF, "Sunrise Point-LP LPC Controller(0x9D48)"},
{0x8086, 0x9D48, 0x1028, 0x06DC, "Latitude E7470(0x1028-0x06DC)"},
{0x8086, 0x9D48, 0x1028, 0x06F3, "Latitude 3570(0x1028-0x06F3)"},
{0x8086, 0x9D48, 0x103C, 0x8079, "EliteBook 840 G3(0x103C-0x8079)"},
{0x8086, 0x9D48, 0x17AA, 0x2247, "ThinkPad T570(0x17AA-0x2247)"},
{0x8086, 0x9D4E, 0xFFFF, 0xFFFF, "Sunrise Point LPC/eSPI Controller(0x9D4E)"},
{0x8086, 0x9D4E, 0x17AA, 0x225D, "ThinkPad T480(0x17AA-0x225D)"},
{0x8086, 0x9D50, 0xFFFF, 0xFFFF, "Sunrise Point LPC Controller(0x9D50)"},
{0x8086, 0x9D56, 0xFFFF, 0xFFFF, "Sunrise Point-LP LPC Controller(0x9D56)"},
{0x8086, 0x9D58, 0xFFFF, 0xFFFF, "Sunrise Point-LP LPC Controller(0x9D58)"},
{0x8086, 0x9D58, 0x1025, 0x115F, "Acer Aspire E5-575G(0x1025-0x115F)"},
{0x8086, 0x9D58, 0x17AA, 0x2247, "ThinkPad T570(0x17AA-0x2247)"},
{0x8086, 0x9D58, 0x17AA, 0x224F, "ThinkPad X1 Carbon 5th Gen(0x17AA-0x224F)"},
{0x8086, 0x9D60, 0xFFFF, 0xFFFF, "Sunrise Point-LP Serial IO I2C Controller #0(0x9D60)"},
{0x8086, 0x9D60, 0x1025, 0x115F, "Acer Aspire E5-575G(0x1025-0x115F)"},
{0x8086, 0x9D60, 0x1028, 0x06D6, "Latitude 7275 tablet(0x1028-0x06D6)"},
{0x8086, 0x9D60, 0x1028, 0x06E6, "Latitude 11 5175 2-in-1(0x1028-0x06E6)"},
{0x8086, 0x9D60, 0x1028, 0x06F3, "Latitude 3570(0x1028-0x06F3)"},
{0x8086, 0x9D60, 0x103C, 0x8079, "EliteBook 840 G3(0x103C-0x8079)"},
{0x8086, 0x9D60, 0x17AA, 0x225D, "ThinkPad T480(0x17AA-0x225D)"},
{0x8086, 0x9D60, 0x8086, 0x9D60, "100 Series PCH/Sunrise Point PCH I2C0 [Skylake/Kaby Lake LPSS I2C](0x8086-0x9D60)"},
{0x8086, 0x9D61, 0xFFFF, 0xFFFF, "Sunrise Point-LP Serial IO I2C Controller #1(0x9D61)"},
{0x8086, 0x9D61, 0x1028, 0x06D6, "Latitude 7275 tablet(0x1028-0x06D6)"},
{0x8086, 0x9D61, 0x1028, 0x06E6, "Latitude 11 5175 2-in-1(0x1028-0x06E6)"},
{0x8086, 0x9D62, 0xFFFF, 0xFFFF, "Sunrise Point-LP Serial IO I2C Controller #2(0x9D62)"},
{0x8086, 0x9D62, 0x1028, 0x06D6, "Latitude 7275 tablet(0x1028-0x06D6)"},
{0x8086, 0x9D62, 0x1028, 0x06E6, "Latitude 11 5175 2-in-1(0x1028-0x06E6)"},
{0x8086, 0x9D63, 0xFFFF, 0xFFFF, "Sunrise Point-LP Serial IO I2C Controller #3(0x9D63)"},
{0x8086, 0x9D64, 0xFFFF, 0xFFFF, "Sunrise Point-LP Serial IO I2C Controller #4(0x9D64)"},
{0x8086, 0x9D65, 0xFFFF, 0xFFFF, "Sunrise Point-LP Serial IO I2C Controller #5(0x9D65)"},
{0x8086, 0x9D66, 0xFFFF, 0xFFFF, "Sunrise Point-LP Serial IO UART Controller #2(0x9D66)"},
{0x8086, 0x9D70, 0xFFFF, 0xFFFF, "Sunrise Point-LP HD Audio(0x9D70)"},
{0x8086, 0x9D70, 0x1028, 0x06D6, "Latitude 7275 tablet(0x1028-0x06D6)"},
{0x8086, 0x9D70, 0x1028, 0x06DC, "Latitude E7470(0x1028-0x06DC)"},
{0x8086, 0x9D70, 0x1028, 0x06E6, "Latitude 11 5175 2-in-1(0x1028-0x06E6)"},
{0x8086, 0x9D70, 0x1028, 0x06F3, "Latitude 3570(0x1028-0x06F3)"},
{0x8086, 0x9D70, 0x103C, 0x8079, "EliteBook 840 G3(0x103C-0x8079)"},
{0x8086, 0x9D70, 0x17AA, 0x2247, "ThinkPad T570(0x17AA-0x2247)"},
{0x8086, 0x9D70, 0x17AA, 0x382A, "B51-80 Laptop(0x17AA-0x382A)"},
{0x8086, 0x9D71, 0xFFFF, 0xFFFF, "Sunrise Point-LP HD Audio(0x9D71)"},
{0x8086, 0x9D71, 0x1025, 0x1094, "Acer Aspire E5-575G(0x1025-0x1094)"},
{0x8086, 0x9D71, 0x17AA, 0x224F, "ThinkPad X1 Carbon 5th Gen(0x17AA-0x224F)"},
{0x8086, 0x9D71, 0x17AA, 0x225D, "ThinkPad T480(0x17AA-0x225D)"},
{0x8086, 0x9D84, 0xFFFF, 0xFFFF, "Cannon Point-LP LPC Controller(0x9D84)"},
{0x8086, 0x9D84, 0x1028, 0x089E, "Inspiron 5482(0x1028-0x089E)"},
{0x8086, 0x9DA3, 0xFFFF, 0xFFFF, "Cannon Point-LP SMBus Controller(0x9DA3)"},
{0x8086, 0x9DA4, 0xFFFF, 0xFFFF, "Cannon Point-LP SPI Controller(0x9DA4)"},
{0x8086, 0x9DA8, 0xFFFF, 0xFFFF, "Cannon Point-LP Serial IO UART Controller #2(0x9DA8)"},
{0x8086, 0x9DAA, 0xFFFF, 0xFFFF, "Cannon Point-LP Serial IO SPI Controller(0x9DAA)"},
{0x8086, 0x9DAB, 0xFFFF, 0xFFFF, "Cannon Point-LP Serial IO SPI Controller(0x9DAB)"},
{0x8086, 0x9DB0, 0xFFFF, 0xFFFF, "Cannon Point-LP PCI Express Root Port #9(0x9DB0)"},
{0x8086, 0x9DB1, 0xFFFF, 0xFFFF, "Cannon Point-LP PCI Express Root Port #10(0x9DB1)"},
{0x8086, 0x9DB2, 0xFFFF, 0xFFFF, "Cannon Point-LP PCI Express Root Port #1(0x9DB2)"},
{0x8086, 0x9DB4, 0xFFFF, 0xFFFF, "Cannon Point-LP PCI Express Root Port #13(0x9DB4)"},
{0x8086, 0x9DB4, 0x1028, 0x089E, "Inspiron 5482(0x1028-0x089E)"},
{0x8086, 0x9DB6, 0xFFFF, 0xFFFF, "Cannon Point-LP PCI Express Root Port #15(0x9DB6)"},
{0x8086, 0x9DB8, 0xFFFF, 0xFFFF, "Cannon Point-LP PCI Express Root Port #1(0x9DB8)"},
{0x8086, 0x9DBC, 0xFFFF, 0xFFFF, "Cannon Point-LP PCI Express Root Port #5(0x9DBC)"},
{0x8086, 0x9DBE, 0xFFFF, 0xFFFF, "Cannon Point-LP PCI Express Root Port #7(0x9DBE)"},
{0x8086, 0x9DBF, 0xFFFF, 0xFFFF, "Cannon Point PCI Express Root Port #8(0x9DBF)"},
{0x8086, 0x9DC4, 0xFFFF, 0xFFFF, "Cannon Point-LP SD Host Controller(0x9DC4)"},
{0x8086, 0x9DC5, 0xFFFF, 0xFFFF, "Cannon Point-LP Serial IO I2C Host Controller(0x9DC5)"},
{0x8086, 0x9DC8, 0xFFFF, 0xFFFF, "Cannon Point-LP High Definition Audio Controller(0x9DC8)"},
{0x8086, 0x9DC8, 0x1028, 0x089E, "Inspiron 5482(0x1028-0x089E)"},
{0x8086, 0x9DD3, 0xFFFF, 0xFFFF, "Cannon Point-LP SATA Controller [AHCI Mode](0x9DD3)"},
{0x8086, 0x9DE0, 0xFFFF, 0xFFFF, "Cannon Point-LP MEI Controller #1(0x9DE0)"},
{0x8086, 0x9DE3, 0xFFFF, 0xFFFF, "Cannon Point-LP Keyboard and Text (KT) Redirection(0x9DE3)"},
{0x8086, 0x9DE8, 0xFFFF, 0xFFFF, "Cannon Point-LP Serial IO I2C Controller #0(0x9DE8)"},
{0x8086, 0x9DE8, 0x1028, 0x089E, "Inspiron 5482(0x1028-0x089E)"},
{0x8086, 0x9DE9, 0xFFFF, 0xFFFF, "Cannon Point-LP Serial IO I2C Controller #1(0x9DE9)"},
{0x8086, 0x9DE9, 0x1028, 0x089E, "Inspiron 5482(0x1028-0x089E)"},
{0x8086, 0x9DED, 0xFFFF, 0xFFFF, "Cannon Point-LP USB 3.1 xHCI Controller(0x9DED)"},
{0x8086, 0x9DEF, 0xFFFF, 0xFFFF, "Cannon Point-LP Shared SRAM(0x9DEF)"},
{0x8086, 0x9DF0, 0xFFFF, 0xFFFF, "Cannon Point-LP CNVi [Wireless-AC](0x9DF0)"},
{0x8086, 0x9DF5, 0xFFFF, 0xFFFF, "BayHubTech Integrated SD controller(0x9DF5)"},
{0x8086, 0x9DF9, 0xFFFF, 0xFFFF, "Cannon Point-LP Thermal Controller(0x9DF9)"},
{0x8086, 0x9DFC, 0xFFFF, 0xFFFF, "Cannon Point-LP Integrated Sensor Hub(0x9DFC)"},
{0x8086, 0xA000, 0xFFFF, 0xFFFF, "Atom Processor D4xx/D5xx/N4xx/N5xx DMI Bridge(0xA000)"},
{0x8086, 0xA000, 0x1458, 0x5000, "GA-D525TUD(0x1458-0x5000)"},
{0x8086, 0xA000, 0x8086, 0x4F4D, "DeskTop Board D510MO(0x8086-0x4F4D)"},
{0x8086, 0xA000, 0x8086, 0x544B, "Desktop Board D425KT(0x8086-0x544B)"},
{0x8086, 0xA001, 0xFFFF, 0xFFFF, "Atom Processor D4xx/D5xx/N4xx/N5xx Integrated Graphics Controller(0xA001)"},
{0x8086, 0xA001, 0x1458, 0xD000, "GA-D525TUD(0x1458-0xD000)"},
{0x8086, 0xA001, 0x8086, 0x4F4D, "DeskTop Board D510MO(0x8086-0x4F4D)"},
{0x8086, 0xA001, 0x8086, 0x544B, "Desktop Board D425KT(0x8086-0x544B)"},
{0x8086, 0xA002, 0xFFFF, 0xFFFF, "Atom Processor D4xx/D5xx/N4xx/N5xx Integrated Graphics Controller(0xA002)"},
{0x8086, 0xA003, 0xFFFF, 0xFFFF, "Atom Processor D4xx/D5xx/N4xx/N5xx CHAPS counter(0xA003)"},
{0x8086, 0xA010, 0xFFFF, 0xFFFF, "Atom Processor D4xx/D5xx/N4xx/N5xx DMI Bridge(0xA010)"},
{0x8086, 0xA010, 0x1043, 0x83AC, "Eee PC 1015PX(0x1043-0x83AC)"},
{0x8086, 0xA010, 0x144D, 0xC072, "Notebook N150P(0x144D-0xC072)"},
{0x8086, 0xA011, 0xFFFF, 0xFFFF, "Atom Processor D4xx/D5xx/N4xx/N5xx Integrated Graphics Controller(0xA011)"},
{0x8086, 0xA011, 0x1043, 0x83AC, "Eee PC 1015PX(0x1043-0x83AC)"},
{0x8086, 0xA011, 0x144D, 0xC072, "Notebook N150P(0x144D-0xC072)"},
{0x8086, 0xA012, 0xFFFF, 0xFFFF, "Atom Processor D4xx/D5xx/N4xx/N5xx Integrated Graphics Controller(0xA012)"},
{0x8086, 0xA012, 0x1043, 0x83AC, "Eee PC 1015PX(0x1043-0x83AC)"},
{0x8086, 0xA012, 0x144D, 0xC072, "Notebook N150P(0x144D-0xC072)"},
{0x8086, 0xA013, 0xFFFF, 0xFFFF, "Atom Processor D4xx/D5xx/N4xx/N5xx CHAPS counter(0xA013)"},
{0x8086, 0xA082, 0xFFFF, 0xFFFF, "Tiger Lake-LP LPC Controller(0xA082)"},
{0x8086, 0xA0A3, 0xFFFF, 0xFFFF, "Tiger Lake-LP SMBus Controller(0xA0A3)"},
{0x8086, 0xA0A4, 0xFFFF, 0xFFFF, "Tiger Lake-LP SPI Controller(0xA0A4)"},
{0x8086, 0xA0A6, 0xFFFF, 0xFFFF, "Tiger Lake-LP Trace Hub(0xA0A6)"},
{0x8086, 0xA0A8, 0xFFFF, 0xFFFF, "Tiger Lake-LP Serial IO UART Controller #0(0xA0A8)"},
{0x8086, 0xA0A9, 0xFFFF, 0xFFFF, "Tiger Lake-LP Serial IO UART Controller #1(0xA0A9)"},
{0x8086, 0xA0AB, 0xFFFF, 0xFFFF, "Tiger Lake-LP Serial IO SPI Controller #1(0xA0AB)"},
{0x8086, 0xA0B0, 0xFFFF, 0xFFFF, "Tiger Lake-LP PCI Express Root Port #9(0xA0B0)"},
{0x8086, 0xA0B1, 0xFFFF, 0xFFFF, "Tiger Lake-LP PCI Express Root Port #10(0xA0B1)"},
{0x8086, 0xA0B3, 0xFFFF, 0xFFFF, "Tiger Lake-LP PCI Express Root Port #12(0xA0B3)"},
{0x8086, 0xA0BC, 0xFFFF, 0xFFFF, "Tiger Lake-LP PCI Express Root Port #5(0xA0BC)"},
{0x8086, 0xA0BD, 0xFFFF, 0xFFFF, "Tigerlake PCH-LP PCI Express Root Port #6(0xA0BD)"},
{0x8086, 0xA0BE, 0xFFFF, 0xFFFF, "Tiger Lake-LP PCI Express Root Port #7(0xA0BE)"},
{0x8086, 0xA0BF, 0xFFFF, 0xFFFF, "Tiger Lake-LP PCI Express Root Port #8(0xA0BF)"},
{0x8086, 0xA0C5, 0xFFFF, 0xFFFF, "Tiger Lake-LP Serial IO I2C Controller #4(0xA0C5)"},
{0x8086, 0xA0C6, 0xFFFF, 0xFFFF, "Tiger Lake-LP Serial IO I2C Controller #5(0xA0C6)"},
{0x8086, 0xA0C8, 0xFFFF, 0xFFFF, "Tiger Lake-LP Smart Sound Technology Audio Controller(0xA0C8)"},
{0x8086, 0xA0D3, 0xFFFF, 0xFFFF, "Tiger Lake-LP SATA Controller(0xA0D3)"},
{0x8086, 0xA0E0, 0xFFFF, 0xFFFF, "Tiger Lake-LP Management Engine Interface(0xA0E0)"},
{0x8086, 0xA0E3, 0xFFFF, 0xFFFF, "Tiger Lake-LP Active Management Technology - SOL(0xA0E3)"},
{0x8086, 0xA0E8, 0xFFFF, 0xFFFF, "Tiger Lake-LP Serial IO I2C Controller #0(0xA0E8)"},
{0x8086, 0xA0E9, 0xFFFF, 0xFFFF, "Tiger Lake-LP Serial IO I2C Controller #1(0xA0E9)"},
{0x8086, 0xA0EA, 0xFFFF, 0xFFFF, "Tiger Lake-LP Serial IO I2C Controller #2(0xA0EA)"},
{0x8086, 0xA0EB, 0xFFFF, 0xFFFF, "Tiger Lake-LP Serial IO I2C Controller #3(0xA0EB)"},
{0x8086, 0xA0ED, 0xFFFF, 0xFFFF, "Tiger Lake-LP USB 3.2 Gen 2x1 xHCI Host Controller(0xA0ED)"},
{0x8086, 0xA0EF, 0xFFFF, 0xFFFF, "Tiger Lake-LP Shared SRAM(0xA0EF)"},
{0x8086, 0xA0F0, 0xFFFF, 0xFFFF, "Wi-Fi 6 AX201(0xA0F0)"},
{0x8086, 0xA0F0, 0x8086, 0x0244, "Wi-Fi 6 AX101NGW(0x8086-0x0244)"},
{0x8086, 0xA0FC, 0xFFFF, 0xFFFF, "Tiger Lake-LP Integrated Sensor Hub(0xA0FC)"},
{0x8086, 0xA102, 0xFFFF, 0xFFFF, "Q170/Q150/B150/H170/H110/Z170/CM236 Chipset SATA Controller [AHCI Mode](0xA102)"},
{0x8086, 0xA102, 0x1043, 0x8694, "H110I-PLUS Motherboard(0x1043-0x8694)"},
{0x8086, 0xA102, 0x1462, 0x7994, "H110M ECO/GAMING(0x1462-0x7994)"},
{0x8086, 0xA103, 0xFFFF, 0xFFFF, "HM170/QM170 Chipset SATA Controller [AHCI Mode](0xA103)"},
{0x8086, 0xA103, 0x1028, 0x06E4, "XPS 15 9550(0x1028-0x06E4)"},
{0x8086, 0xA103, 0x103C, 0x825B, "OMEN-17-w001nv(0x103C-0x825B)"},
{0x8086, 0xA105, 0xFFFF, 0xFFFF, "Sunrise Point-H SATA Controller [RAID mode](0xA105)"},
{0x8086, 0xA106, 0xFFFF, 0xFFFF, "Q170/H170/Z170/CM236 Chipset SATA Controller [RAID Mode](0xA106)"},
{0x8086, 0xA107, 0xFFFF, 0xFFFF, "HM170/QM170 Chipset SATA Controller [RAID Mode](0xA107)"},
{0x8086, 0xA10F, 0xFFFF, 0xFFFF, "Sunrise Point-H SATA Controller [RAID mode](0xA10F)"},
{0x8086, 0xA110, 0xFFFF, 0xFFFF, "100 Series/C230 Series Chipset Family PCI Express Root Port #1(0xA110)"},
{0x8086, 0xA111, 0xFFFF, 0xFFFF, "100 Series/C230 Series Chipset Family PCI Express Root Port #2(0xA111)"},
{0x8086, 0xA112, 0xFFFF, 0xFFFF, "100 Series/C230 Series Chipset Family PCI Express Root Port #3(0xA112)"},
{0x8086, 0xA113, 0xFFFF, 0xFFFF, "100 Series/C230 Series Chipset Family PCI Express Root Port #4(0xA113)"},
{0x8086, 0xA114, 0xFFFF, 0xFFFF, "100 Series/C230 Series Chipset Family PCI Express Root Port #5(0xA114)"},
{0x8086, 0xA114, 0x1043, 0x8694, "H110I-PLUS Motherboard(0x1043-0x8694)"},
{0x8086, 0xA115, 0xFFFF, 0xFFFF, "100 Series/C230 Series Chipset Family PCI Express Root Port #6(0xA115)"},
{0x8086, 0xA116, 0xFFFF, 0xFFFF, "100 Series/C230 Series Chipset Family PCI Express Root Port #7(0xA116)"},
{0x8086, 0xA117, 0xFFFF, 0xFFFF, "100 Series/C230 Series Chipset Family PCI Express Root Port #8(0xA117)"},
{0x8086, 0xA118, 0xFFFF, 0xFFFF, "100 Series/C230 Series Chipset Family PCI Express Root Port #9(0xA118)"},
{0x8086, 0xA118, 0x1043, 0x8694, "H110I-PLUS Motherboard(0x1043-0x8694)"},
{0x8086, 0xA119, 0xFFFF, 0xFFFF, "100 Series/C230 Series Chipset Family PCI Express Root Port #10(0xA119)"},
{0x8086, 0xA119, 0x1043, 0x8694, "H110I-PLUS Motherboard(0x1043-0x8694)"},
{0x8086, 0xA11A, 0xFFFF, 0xFFFF, "100 Series/C230 Series Chipset Family PCI Express Root Port #11(0xA11A)"},
{0x8086, 0xA11B, 0xFFFF, 0xFFFF, "100 Series/C230 Series Chipset Family PCI Express Root Port #12(0xA11B)"},
{0x8086, 0xA11C, 0xFFFF, 0xFFFF, "100 Series/C230 Series Chipset Family PCI Express Root Port #13(0xA11C)"},
{0x8086, 0xA11D, 0xFFFF, 0xFFFF, "100 Series/C230 Series Chipset Family PCI Express Root Port #14(0xA11D)"},
{0x8086, 0xA11E, 0xFFFF, 0xFFFF, "100 Series/C230 Series Chipset Family PCI Express Root Port #15(0xA11E)"},
{0x8086, 0xA11F, 0xFFFF, 0xFFFF, "100 Series/C230 Series Chipset Family PCI Express Root Port #16(0xA11F)"},
{0x8086, 0xA120, 0xFFFF, 0xFFFF, "100 Series/C230 Series Chipset Family P2SB(0xA120)"},
{0x8086, 0xA121, 0xFFFF, 0xFFFF, "100 Series/C230 Series Chipset Family Power Management Controller(0xA121)"},
{0x8086, 0xA121, 0x1028, 0x06E4, "XPS 15 9550(0x1028-0x06E4)"},
{0x8086, 0xA121, 0x103C, 0x825B, "OMEN-17-w001nv(0x103C-0x825B)"},
{0x8086, 0xA121, 0x1043, 0x8694, "H110I-PLUS Motherboard(0x1043-0x8694)"},
{0x8086, 0xA121, 0x1462, 0x7994, "H110M ECO/GAMING(0x1462-0x7994)"},
{0x8086, 0xA122, 0xFFFF, 0xFFFF, "Sunrise Point-H cAVS(0xA122)"},
{0x8086, 0xA123, 0xFFFF, 0xFFFF, "100 Series/C230 Series Chipset Family SMBus(0xA123)"},
{0x8086, 0xA123, 0x1028, 0x06E4, "XPS 15 9550(0x1028-0x06E4)"},
{0x8086, 0xA123, 0x103C, 0x825B, "OMEN-17-w001nv(0x103C-0x825B)"},
{0x8086, 0xA123, 0x1043, 0x8694, "H110I-PLUS Motherboard(0x1043-0x8694)"},
{0x8086, 0xA123, 0x1462, 0x7994, "H110M ECO/GAMING(0x1462-0x7994)"},
{0x8086, 0xA124, 0xFFFF, 0xFFFF, "100 Series/C230 Series Chipset Family SPI Controller(0xA124)"},
{0x8086, 0xA125, 0xFFFF, 0xFFFF, "100 Series/C230 Series Chipset Family Gigabit Ethernet Controller(0xA125)"},
{0x8086, 0xA126, 0xFFFF, 0xFFFF, "100 Series/C230 Series Chipset Family Trace Hub(0xA126)"},
{0x8086, 0xA127, 0xFFFF, 0xFFFF, "100 Series/C230 Series Chipset Family Serial IO UART #0(0xA127)"},
{0x8086, 0xA128, 0xFFFF, 0xFFFF, "100 Series/C230 Series Chipset Family Serial IO UART #1(0xA128)"},
{0x8086, 0xA129, 0xFFFF, 0xFFFF, "100 Series/C230 Series Chipset Family Serial IO GSPI #0(0xA129)"},
{0x8086, 0xA12A, 0xFFFF, 0xFFFF, "100 Series/C230 Series Chipset Family Serial IO GSPI #1(0xA12A)"},
{0x8086, 0xA12F, 0xFFFF, 0xFFFF, "100 Series/C230 Series Chipset Family USB 3.0 xHCI Controller(0xA12F)"},
{0x8086, 0xA12F, 0x1028, 0x06E4, "XPS 15 9550(0x1028-0x06E4)"},
{0x8086, 0xA12F, 0x103C, 0x825B, "OMEN-17-w001nv(0x103C-0x825B)"},
{0x8086, 0xA12F, 0x1043, 0x8694, "H110I-PLUS Motherboard(0x1043-0x8694)"},
{0x8086, 0xA12F, 0x1462, 0x7994, "H110M ECO/GAMING(0x1462-0x7994)"},
{0x8086, 0xA130, 0xFFFF, 0xFFFF, "100 Series/C230 Series Chipset Family USB Device Controller (OTG)(0xA130)"},
{0x8086, 0xA131, 0xFFFF, 0xFFFF, "100 Series/C230 Series Chipset Family Thermal Subsystem(0xA131)"},
{0x8086, 0xA131, 0x1028, 0x06E4, "XPS 15 9550(0x1028-0x06E4)"},
{0x8086, 0xA131, 0x103C, 0x825B, "OMEN-17-w001nv(0x103C-0x825B)"},
{0x8086, 0xA131, 0x1462, 0x7994, "H110M ECO/GAMING(0x1462-0x7994)"},
{0x8086, 0xA133, 0xFFFF, 0xFFFF, "Sunrise Point-H Northpeak ACPI Function(0xA133)"},
{0x8086, 0xA135, 0xFFFF, 0xFFFF, "100 Series/C230 Series Chipset Family Integrated Sensor Hub(0xA135)"},
{0x8086, 0xA13A, 0xFFFF, 0xFFFF, "100 Series/C230 Series Chipset Family MEI Controller #1(0xA13A)"},
{0x8086, 0xA13A, 0x1028, 0x06E4, "XPS 15 9550(0x1028-0x06E4)"},
{0x8086, 0xA13A, 0x103C, 0x825B, "OMEN-17-w001nv(0x103C-0x825B)"},
{0x8086, 0xA13A, 0x1043, 0x8694, "H110I-PLUS Motherboard(0x1043-0x8694)"},
{0x8086, 0xA13A, 0x1462, 0x7994, "H110M ECO/GAMING(0x1462-0x7994)"},
{0x8086, 0xA13B, 0xFFFF, 0xFFFF, "100 Series/C230 Series Chipset Family MEI Controller #2(0xA13B)"},
{0x8086, 0xA13C, 0xFFFF, 0xFFFF, "100 Series/C230 Series Chipset Family IDE Redirection(0xA13C)"},
{0x8086, 0xA13D, 0xFFFF, 0xFFFF, "100 Series/C230 Series Chipset Family KT Redirection(0xA13D)"},
{0x8086, 0xA13E, 0xFFFF, 0xFFFF, "100 Series/C230 Series Chipset Family MEI Controller #3(0xA13E)"},
{0x8086, 0xA140, 0xFFFF, 0xFFFF, "Sunrise Point-H LPC Controller(0xA140)"},
{0x8086, 0xA141, 0xFFFF, 0xFFFF, "Sunrise Point-H LPC Controller(0xA141)"},
{0x8086, 0xA142, 0xFFFF, 0xFFFF, "Sunrise Point-H LPC Controller(0xA142)"},
{0x8086, 0xA143, 0xFFFF, 0xFFFF, "H110 Chipset LPC/eSPI Controller(0xA143)"},
{0x8086, 0xA143, 0x1043, 0x8694, "H110I-PLUS Motherboard(0x1043-0x8694)"},
{0x8086, 0xA143, 0x1462, 0x7994, "H110M ECO/GAMING(0x1462-0x7994)"},
{0x8086, 0xA144, 0xFFFF, 0xFFFF, "H170 Chipset LPC/eSPI Controller(0xA144)"},
{0x8086, 0xA145, 0xFFFF, 0xFFFF, "Z170 Chipset LPC/eSPI Controller(0xA145)"},
{0x8086, 0xA146, 0xFFFF, 0xFFFF, "Q170 Chipset LPC/eSPI Controller(0xA146)"},
{0x8086, 0xA147, 0xFFFF, 0xFFFF, "Q150 Chipset LPC/eSPI Controller(0xA147)"},
{0x8086, 0xA148, 0xFFFF, 0xFFFF, "B150 Chipset LPC/eSPI Controller(0xA148)"},
{0x8086, 0xA149, 0xFFFF, 0xFFFF, "C236 Chipset LPC/eSPI Controller(0xA149)"},
{0x8086, 0xA14A, 0xFFFF, 0xFFFF, "C232 Chipset LPC/eSPI Controller(0xA14A)"},
{0x8086, 0xA14B, 0xFFFF, 0xFFFF, "Sunrise Point-H LPC Controller(0xA14B)"},
{0x8086, 0xA14C, 0xFFFF, 0xFFFF, "Sunrise Point-H LPC Controller(0xA14C)"},
{0x8086, 0xA14D, 0xFFFF, 0xFFFF, "QM170 Chipset LPC/eSPI Controller(0xA14D)"},
{0x8086, 0xA14E, 0xFFFF, 0xFFFF, "HM170 Chipset LPC/eSPI Controller(0xA14E)"},
{0x8086, 0xA14E, 0x1028, 0x06E4, "XPS 15 9550(0x1028-0x06E4)"},
{0x8086, 0xA14E, 0x103C, 0x825B, "OMEN-17-w001nv(0x103C-0x825B)"},
{0x8086, 0xA14F, 0xFFFF, 0xFFFF, "Sunrise Point-H LPC Controller(0xA14F)"},
{0x8086, 0xA150, 0xFFFF, 0xFFFF, "CM236 Chipset LPC/eSPI Controller(0xA150)"},
{0x8086, 0xA151, 0xFFFF, 0xFFFF, "Sunrise Point-H LPC Controller(0xA151)"},
{0x8086, 0xA152, 0xFFFF, 0xFFFF, "HM175 Chipset LPC/eSPI Controller(0xA152)"},
{0x8086, 0xA153, 0xFFFF, 0xFFFF, "QM175 Chipset LPC/eSPI Controller(0xA153)"},
{0x8086, 0xA154, 0xFFFF, 0xFFFF, "CM238 Chipset LPC/eSPI Controller(0xA154)"},
{0x8086, 0xA155, 0xFFFF, 0xFFFF, "Sunrise Point-H LPC Controller(0xA155)"},
{0x8086, 0xA156, 0xFFFF, 0xFFFF, "Sunrise Point-H LPC Controller(0xA156)"},
{0x8086, 0xA157, 0xFFFF, 0xFFFF, "Sunrise Point-H LPC Controller(0xA157)"},
{0x8086, 0xA158, 0xFFFF, 0xFFFF, "Sunrise Point-H LPC Controller(0xA158)"},
{0x8086, 0xA159, 0xFFFF, 0xFFFF, "Sunrise Point-H LPC Controller(0xA159)"},
{0x8086, 0xA15A, 0xFFFF, 0xFFFF, "Sunrise Point-H LPC Controller(0xA15A)"},
{0x8086, 0xA15B, 0xFFFF, 0xFFFF, "Sunrise Point-H LPC Controller(0xA15B)"},
{0x8086, 0xA15C, 0xFFFF, 0xFFFF, "Sunrise Point-H LPC Controller(0xA15C)"},
{0x8086, 0xA15D, 0xFFFF, 0xFFFF, "Sunrise Point-H LPC Controller(0xA15D)"},
{0x8086, 0xA15E, 0xFFFF, 0xFFFF, "Sunrise Point-H LPC Controller(0xA15E)"},
{0x8086, 0xA15F, 0xFFFF, 0xFFFF, "Sunrise Point-H LPC Controller(0xA15F)"},
{0x8086, 0xA160, 0xFFFF, 0xFFFF, "100 Series/C230 Series Chipset Family Serial IO I2C Controller #0(0xA160)"},
{0x8086, 0xA160, 0x1028, 0x06E4, "XPS 15 9550(0x1028-0x06E4)"},
{0x8086, 0xA160, 0x103C, 0x825B, "OMEN-17-w001nv(0x103C-0x825B)"},
{0x8086, 0xA161, 0xFFFF, 0xFFFF, "100 Series/C230 Series Chipset Family Serial IO I2C Controller #1(0xA161)"},
{0x8086, 0xA161, 0x1028, 0x06E4, "XPS 15 9550(0x1028-0x06E4)"},
{0x8086, 0xA162, 0xFFFF, 0xFFFF, "100 Series/C230 Series Chipset Family Serial IO I2C Controller #2(0xA162)"},
{0x8086, 0xA163, 0xFFFF, 0xFFFF, "100 Series/C230 Series Chipset Family Serial IO I2C Controller #3(0xA163)"},
{0x8086, 0xA166, 0xFFFF, 0xFFFF, "100 Series/C230 Series Chipset Family Serial IO UART Controller #2(0xA166)"},
{0x8086, 0xA167, 0xFFFF, 0xFFFF, "100 Series/C230 Series Chipset Family PCI Express Root Port #17(0xA167)"},
{0x8086, 0xA168, 0xFFFF, 0xFFFF, "100 Series/C230 Series Chipset Family PCI Express Root Port #18(0xA168)"},
{0x8086, 0xA169, 0xFFFF, 0xFFFF, "100 Series/C230 Series Chipset Family PCI Express Root Port #19(0xA169)"},
{0x8086, 0xA16A, 0xFFFF, 0xFFFF, "100 Series/C230 Series Chipset Family PCI Express Root Port #20(0xA16A)"},
{0x8086, 0xA170, 0xFFFF, 0xFFFF, "100 Series/C230 Series Chipset Family HD Audio Controller(0xA170)"},
{0x8086, 0xA170, 0x1028, 0x06E4, "XPS 15 9550(0x1028-0x06E4)"},
{0x8086, 0xA170, 0x103C, 0x825B, "OMEN-17-w001nv(0x103C-0x825B)"},
{0x8086, 0xA170, 0x1043, 0x86C7, "H110I-PLUS Motherboard(0x1043-0x86C7)"},
{0x8086, 0xA170, 0x1462, 0xF994, "H110M ECO/GAMING(0x1462-0xF994)"},
{0x8086, 0xA171, 0xFFFF, 0xFFFF, "CM238 HD Audio Controller(0xA171)"},
{0x8086, 0xA182, 0xFFFF, 0xFFFF, "C620 Series Chipset Family SATA Controller [AHCI mode](0xA182)"},
{0x8086, 0xA186, 0xFFFF, 0xFFFF, "C620 Series Chipset Family SATA Controller [RAID mode](0xA186)"},
{0x8086, 0xA190, 0xFFFF, 0xFFFF, "C620 Series Chipset Family PCI Express Root Port #1(0xA190)"},
{0x8086, 0xA191, 0xFFFF, 0xFFFF, "C620 Series Chipset Family PCI Express Root Port #2(0xA191)"},
{0x8086, 0xA192, 0xFFFF, 0xFFFF, "C620 Series Chipset Family PCI Express Root Port #3(0xA192)"},
{0x8086, 0xA193, 0xFFFF, 0xFFFF, "C620 Series Chipset Family PCI Express Root Port #4(0xA193)"},
{0x8086, 0xA194, 0xFFFF, 0xFFFF, "C620 Series Chipset Family PCI Express Root Port #5(0xA194)"},
{0x8086, 0xA195, 0xFFFF, 0xFFFF, "C620 Series Chipset Family PCI Express Root Port #6(0xA195)"},
{0x8086, 0xA196, 0xFFFF, 0xFFFF, "C620 Series Chipset Family PCI Express Root Port #7(0xA196)"},
{0x8086, 0xA197, 0xFFFF, 0xFFFF, "C620 Series Chipset Family PCI Express Root Port #8(0xA197)"},
{0x8086, 0xA198, 0xFFFF, 0xFFFF, "C620 Series Chipset Family PCI Express Root Port #9(0xA198)"},
{0x8086, 0xA199, 0xFFFF, 0xFFFF, "C620 Series Chipset Family PCI Express Root Port #10(0xA199)"},
{0x8086, 0xA19A, 0xFFFF, 0xFFFF, "C620 Series Chipset Family PCI Express Root Port #11(0xA19A)"},
{0x8086, 0xA19B, 0xFFFF, 0xFFFF, "C620 Series Chipset Family PCI Express Root Port #12(0xA19B)"},
{0x8086, 0xA19C, 0xFFFF, 0xFFFF, "C620 Series Chipset Family PCI Express Root Port #13(0xA19C)"},
{0x8086, 0xA19D, 0xFFFF, 0xFFFF, "C620 Series Chipset Family PCI Express Root Port #14(0xA19D)"},
{0x8086, 0xA19E, 0xFFFF, 0xFFFF, "C620 Series Chipset Family PCI Express Root Port #15(0xA19E)"},
{0x8086, 0xA19F, 0xFFFF, 0xFFFF, "C620 Series Chipset Family PCI Express Root Port #16(0xA19F)"},
{0x8086, 0xA1A0, 0xFFFF, 0xFFFF, "C620 Series Chipset Family P2SB(0xA1A0)"},
{0x8086, 0xA1A1, 0xFFFF, 0xFFFF, "C620 Series Chipset Family Power Management Controller(0xA1A1)"},
{0x8086, 0xA1A1, 0x15D9, 0x095D, "X11SPM-TF(0x15D9-0x095D)"},
{0x8086, 0xA1A2, 0xFFFF, 0xFFFF, "C620 Series Chipset Family cAVS(0xA1A2)"},
{0x8086, 0xA1A3, 0xFFFF, 0xFFFF, "C620 Series Chipset Family SMBus(0xA1A3)"},
{0x8086, 0xA1A3, 0x15D9, 0x095D, "X11SPM-TF(0x15D9-0x095D)"},
{0x8086, 0xA1A4, 0xFFFF, 0xFFFF, "C620 Series Chipset Family SPI Controller(0xA1A4)"},
{0x8086, 0xA1A4, 0x15D9, 0x095D, "X11SPM-TF(0x15D9-0x095D)"},
{0x8086, 0xA1A6, 0xFFFF, 0xFFFF, "C620 Series Chipset Family Trace Hub(0xA1A6)"},
{0x8086, 0xA1AF, 0xFFFF, 0xFFFF, "C620 Series Chipset Family USB 3.0 xHCI Controller(0xA1AF)"},
{0x8086, 0xA1AF, 0x15D9, 0x095D, "X11SPM-TF(0x15D9-0x095D)"},
{0x8086, 0xA1B1, 0xFFFF, 0xFFFF, "C620 Series Chipset Family Thermal Subsystem(0xA1B1)"},
{0x8086, 0xA1B1, 0x15D9, 0x095D, "X11SPM-TF(0x15D9-0x095D)"},
{0x8086, 0xA1BA, 0xFFFF, 0xFFFF, "C620 Series Chipset Family MEI Controller #1(0xA1BA)"},
{0x8086, 0xA1BA, 0x15D9, 0x095D, "X11SPM-TF(0x15D9-0x095D)"},
{0x8086, 0xA1BB, 0xFFFF, 0xFFFF, "C620 Series Chipset Family MEI Controller #2(0xA1BB)"},
{0x8086, 0xA1BB, 0x15D9, 0x095D, "X11SPM-TF(0x15D9-0x095D)"},
{0x8086, 0xA1BC, 0xFFFF, 0xFFFF, "C620 Series Chipset Family IDE Redirection(0xA1BC)"},
{0x8086, 0xA1BD, 0xFFFF, 0xFFFF, "C620 Series Chipset Family KT Redirection(0xA1BD)"},
{0x8086, 0xA1BE, 0xFFFF, 0xFFFF, "C620 Series Chipset Family MEI Controller #3(0xA1BE)"},
{0x8086, 0xA1BE, 0x15D9, 0x095D, "X11SPM-TF(0x15D9-0x095D)"},
{0x8086, 0xA1C1, 0xFFFF, 0xFFFF, "C621 Series Chipset LPC/eSPI Controller(0xA1C1)"},
{0x8086, 0xA1C2, 0xFFFF, 0xFFFF, "C622 Series Chipset LPC/eSPI Controller(0xA1C2)"},
{0x8086, 0xA1C2, 0x15D9, 0x095D, "X11SPM-TF(0x15D9-0x095D)"},
{0x8086, 0xA1C3, 0xFFFF, 0xFFFF, "C624 Series Chipset LPC/eSPI Controller(0xA1C3)"},
{0x8086, 0xA1C4, 0xFFFF, 0xFFFF, "C625 Series Chipset LPC/eSPI Controller(0xA1C4)"},
{0x8086, 0xA1C5, 0xFFFF, 0xFFFF, "C626 Series Chipset LPC/eSPI Controller(0xA1C5)"},
{0x8086, 0xA1C6, 0xFFFF, 0xFFFF, "C627 Series Chipset LPC/eSPI Controller(0xA1C6)"},
{0x8086, 0xA1C7, 0xFFFF, 0xFFFF, "C628 Series Chipset LPC/eSPI Controller(0xA1C7)"},
{0x8086, 0xA1D2, 0xFFFF, 0xFFFF, "C620 Series Chipset Family SSATA Controller [AHCI mode](0xA1D2)"},
{0x8086, 0xA1D6, 0xFFFF, 0xFFFF, "C620 Series Chipset Family SSATA Controller [RAID mode](0xA1D6)"},
{0x8086, 0xA1E7, 0xFFFF, 0xFFFF, "C620 Series Chipset Family PCI Express Root Port #17(0xA1E7)"},
{0x8086, 0xA1E8, 0xFFFF, 0xFFFF, "C620 Series Chipset Family PCI Express Root Port #18(0xA1E8)"},
{0x8086, 0xA1E9, 0xFFFF, 0xFFFF, "C620 Series Chipset Family PCI Express Root Port #19(0xA1E9)"},
{0x8086, 0xA1EA, 0xFFFF, 0xFFFF, "C620 Series Chipset Family PCI Express Root Port #20(0xA1EA)"},
{0x8086, 0xA1EC, 0xFFFF, 0xFFFF, "C620 Series Chipset Family MROM 0(0xA1EC)"},
{0x8086, 0xA1ED, 0xFFFF, 0xFFFF, "C620 Series Chipset Family MROM 1(0xA1ED)"},
{0x8086, 0xA1F8, 0xFFFF, 0xFFFF, "Lewisburg IE: HECI #1(0xA1F8)"},
{0x8086, 0xA1F9, 0xFFFF, 0xFFFF, "Lewisburg IE: HECI #2(0xA1F9)"},
{0x8086, 0xA1FA, 0xFFFF, 0xFFFF, "Lewisburg IE: IDE-r(0xA1FA)"},
{0x8086, 0xA1FB, 0xFFFF, 0xFFFF, "Lewisburg IE: KT Controller(0xA1FB)"},
{0x8086, 0xA1FC, 0xFFFF, 0xFFFF, "Lewisburg IE: HECI #3(0xA1FC)"},
{0x8086, 0xA202, 0xFFFF, 0xFFFF, "Lewisburg SATA Controller [AHCI mode](0xA202)"},
{0x8086, 0xA206, 0xFFFF, 0xFFFF, "Lewisburg SATA Controller [RAID mode](0xA206)"},
{0x8086, 0xA223, 0xFFFF, 0xFFFF, "Lewisburg SMBus(0xA223)"},
{0x8086, 0xA224, 0xFFFF, 0xFFFF, "Lewisburg SPI Controller(0xA224)"},
{0x8086, 0xA242, 0xFFFF, 0xFFFF, "Lewisburg LPC or eSPI Controller(0xA242)"},
{0x8086, 0xA243, 0xFFFF, 0xFFFF, "Lewisburg LPC or eSPI Controller(0xA243)"},
{0x8086, 0xA252, 0xFFFF, 0xFFFF, "Lewisburg SSATA Controller [AHCI mode](0xA252)"},
{0x8086, 0xA256, 0xFFFF, 0xFFFF, "Lewisburg SSATA Controller [RAID mode](0xA256)"},
{0x8086, 0xA282, 0xFFFF, 0xFFFF, "200 Series PCH SATA controller [AHCI mode](0xA282)"},
{0x8086, 0xA282, 0x1462, 0x7A72, "H270 PC MATE(0x1462-0x7A72)"},
{0x8086, 0xA286, 0xFFFF, 0xFFFF, "200 Series PCH SATA controller [RAID mode](0xA286)"},
{0x8086, 0xA290, 0xFFFF, 0xFFFF, "200 Series PCH PCI Express Root Port #1(0xA290)"},
{0x8086, 0xA291, 0xFFFF, 0xFFFF, "200 Series PCH PCI Express Root Port #2(0xA291)"},
{0x8086, 0xA292, 0xFFFF, 0xFFFF, "200 Series PCH PCI Express Root Port #3(0xA292)"},
{0x8086, 0xA293, 0xFFFF, 0xFFFF, "200 Series PCH PCI Express Root Port #4(0xA293)"},
{0x8086, 0xA294, 0xFFFF, 0xFFFF, "200 Series PCH PCI Express Root Port #5(0xA294)"},
{0x8086, 0xA294, 0x1462, 0x7A72, "H270 PC MATE(0x1462-0x7A72)"},
{0x8086, 0xA295, 0xFFFF, 0xFFFF, "200 Series PCH PCI Express Root Port #6(0xA295)"},
{0x8086, 0xA296, 0xFFFF, 0xFFFF, "200 Series PCH PCI Express Root Port #7(0xA296)"},
{0x8086, 0xA296, 0x1462, 0x7A72, "H270 PC MATE(0x1462-0x7A72)"},
{0x8086, 0xA297, 0xFFFF, 0xFFFF, "200 Series PCH PCI Express Root Port #8(0xA297)"},
{0x8086, 0xA298, 0xFFFF, 0xFFFF, "200 Series PCH PCI Express Root Port #9(0xA298)"},
{0x8086, 0xA298, 0x1462, 0x7A72, "H270 PC MATE(0x1462-0x7A72)"},
{0x8086, 0xA299, 0xFFFF, 0xFFFF, "200 Series PCH PCI Express Root Port #10(0xA299)"},
{0x8086, 0xA29A, 0xFFFF, 0xFFFF, "200 Series PCH PCI Express Root Port #11(0xA29A)"},
{0x8086, 0xA29B, 0xFFFF, 0xFFFF, "200 Series PCH PCI Express Root Port #12(0xA29B)"},
{0x8086, 0xA29C, 0xFFFF, 0xFFFF, "200 Series PCH PCI Express Root Port #13(0xA29C)"},
{0x8086, 0xA29D, 0xFFFF, 0xFFFF, "200 Series PCH PCI Express Root Port #14(0xA29D)"},
{0x8086, 0xA29E, 0xFFFF, 0xFFFF, "200 Series PCH PCI Express Root Port #15(0xA29E)"},
{0x8086, 0xA29F, 0xFFFF, 0xFFFF, "200 Series PCH PCI Express Root Port #16(0xA29F)"},
{0x8086, 0xA2A0, 0xFFFF, 0xFFFF, "200 Series/Z370 Chipset Family P2SB(0xA2A0)"},
{0x8086, 0xA2A1, 0xFFFF, 0xFFFF, "200 Series/Z370 Chipset Family Power Management Controller(0xA2A1)"},
{0x8086, 0xA2A1, 0x1462, 0x7A72, "H270 PC MATE(0x1462-0x7A72)"},
{0x8086, 0xA2A3, 0xFFFF, 0xFFFF, "200 Series/Z370 Chipset Family SMBus Controller(0xA2A3)"},
{0x8086, 0xA2A3, 0x1462, 0x7A72, "H270 PC MATE(0x1462-0x7A72)"},
{0x8086, 0xA2A4, 0xFFFF, 0xFFFF, "200 Series/Z370 Chipset Family SPI Controller(0xA2A4)"},
{0x8086, 0xA2A5, 0xFFFF, 0xFFFF, "200 Series/Z370 Chipset Family Gigabit Ethernet Controller(0xA2A5)"},
{0x8086, 0xA2A6, 0xFFFF, 0xFFFF, "200 Series/Z370 Chipset Family Trace Hub(0xA2A6)"},
{0x8086, 0xA2A7, 0xFFFF, 0xFFFF, "200 Series/Z370 Chipset Family Serial IO UART Controller #0(0xA2A7)"},
{0x8086, 0xA2A8, 0xFFFF, 0xFFFF, "200 Series/Z370 Chipset Family Serial IO UART Controller #1(0xA2A8)"},
{0x8086, 0xA2A9, 0xFFFF, 0xFFFF, "200 Series/Z370 Chipset Family Serial IO SPI Controller #0(0xA2A9)"},
{0x8086, 0xA2AA, 0xFFFF, 0xFFFF, "200 Series/Z370 Chipset Family Serial IO SPI Controller #1(0xA2AA)"},
{0x8086, 0xA2AF, 0xFFFF, 0xFFFF, "200 Series/Z370 Chipset Family USB 3.0 xHCI Controller(0xA2AF)"},
{0x8086, 0xA2AF, 0x1462, 0x7A72, "H270 PC MATE(0x1462-0x7A72)"},
{0x8086, 0xA2B1, 0xFFFF, 0xFFFF, "200 Series PCH Thermal Subsystem(0xA2B1)"},
{0x8086, 0xA2B1, 0x1462, 0x7A72, "H270 PC MATE(0x1462-0x7A72)"},
{0x8086, 0xA2BA, 0xFFFF, 0xFFFF, "200 Series PCH CSME HECI #1(0xA2BA)"},
{0x8086, 0xA2BA, 0x1462, 0x7A72, "H270 PC MATE(0x1462-0x7A72)"},
{0x8086, 0xA2BB, 0xFFFF, 0xFFFF, "200 Series PCH CSME HECI #2(0xA2BB)"},
{0x8086, 0xA2BD, 0xFFFF, 0xFFFF, "200 Series Chipset Family KT Redirection(0xA2BD)"},
{0x8086, 0xA2C4, 0xFFFF, 0xFFFF, "200 Series PCH LPC Controller (H270)(0xA2C4)"},
{0x8086, 0xA2C4, 0x1462, 0x7A72, "H270 PC MATE(0x1462-0x7A72)"},
{0x8086, 0xA2C5, 0xFFFF, 0xFFFF, "200 Series PCH LPC Controller (Z270)(0xA2C5)"},
{0x8086, 0xA2C6, 0xFFFF, 0xFFFF, "200 Series PCH LPC Controller (Q270)(0xA2C6)"},
{0x8086, 0xA2C7, 0xFFFF, 0xFFFF, "200 Series PCH LPC Controller (Q250)(0xA2C7)"},
{0x8086, 0xA2C8, 0xFFFF, 0xFFFF, "200 Series PCH LPC Controller (B250)(0xA2C8)"},
{0x8086, 0xA2C9, 0xFFFF, 0xFFFF, "Z370 Chipset LPC/eSPI Controller(0xA2C9)"},
{0x8086, 0xA2D2, 0xFFFF, 0xFFFF, "X299 Chipset LPC/eSPI Controller(0xA2D2)"},
{0x8086, 0xA2D3, 0xFFFF, 0xFFFF, "C422 Chipset LPC/eSPI Controller(0xA2D3)"},
{0x8086, 0xA2E0, 0xFFFF, 0xFFFF, "200 Series PCH Serial IO I2C Controller #0(0xA2E0)"},
{0x8086, 0xA2E1, 0xFFFF, 0xFFFF, "200 Series PCH Serial IO I2C Controller #1(0xA2E1)"},
{0x8086, 0xA2E2, 0xFFFF, 0xFFFF, "200 Series PCH Serial IO I2C Controller #2(0xA2E2)"},
{0x8086, 0xA2E3, 0xFFFF, 0xFFFF, "200 Series PCH Serial IO I2C Controller #3(0xA2E3)"},
{0x8086, 0xA2E6, 0xFFFF, 0xFFFF, "200 Series PCH Serial IO UART Controller #2(0xA2E6)"},
{0x8086, 0xA2E7, 0xFFFF, 0xFFFF, "200 Series PCH PCI Express Root Port #17(0xA2E7)"},
{0x8086, 0xA2E8, 0xFFFF, 0xFFFF, "200 Series PCH PCI Express Root Port #18(0xA2E8)"},
{0x8086, 0xA2E9, 0xFFFF, 0xFFFF, "200 Series PCH PCI Express Root Port #19(0xA2E9)"},
{0x8086, 0xA2EA, 0xFFFF, 0xFFFF, "200 Series PCH PCI Express Root Port #20(0xA2EA)"},
{0x8086, 0xA2EB, 0xFFFF, 0xFFFF, "200 Series PCH PCI Express Root Port #21(0xA2EB)"},
{0x8086, 0xA2EC, 0xFFFF, 0xFFFF, "200 Series PCH PCI Express Root Port #22(0xA2EC)"},
{0x8086, 0xA2ED, 0xFFFF, 0xFFFF, "200 Series PCH PCI Express Root Port #23(0xA2ED)"},
{0x8086, 0xA2EE, 0xFFFF, 0xFFFF, "200 Series PCH PCI Express Root Port #24(0xA2EE)"},
{0x8086, 0xA2F0, 0xFFFF, 0xFFFF, "200 Series PCH HD Audio(0xA2F0)"},
{0x8086, 0xA2F0, 0x1462, 0x7A72, "H270 PC MATE(0x1462-0x7A72)"},
{0x8086, 0xA2F0, 0x1462, 0xFA72, "H270 PC MATE(0x1462-0xFA72)"},
{0x8086, 0xA303, 0xFFFF, 0xFFFF, "H310 Chipset LPC/eSPI Controller(0xA303)"},
{0x8086, 0xA304, 0xFFFF, 0xFFFF, "H370 Chipset LPC/eSPI Controller(0xA304)"},
{0x8086, 0xA304, 0x1028, 0x0869, "Vostro 3470(0x1028-0x0869)"},
{0x8086, 0xA305, 0xFFFF, 0xFFFF, "Z390 Chipset LPC/eSPI Controller(0xA305)"},
{0x8086, 0xA306, 0xFFFF, 0xFFFF, "Q370 Chipset LPC/eSPI Controller(0xA306)"},
{0x8086, 0xA308, 0xFFFF, 0xFFFF, "300 Series Chipset Family LPC Controller(0xA308)"},
{0x8086, 0xA309, 0xFFFF, 0xFFFF, "Cannon Point-LP LPC Controller(0xA309)"},
{0x8086, 0xA30C, 0xFFFF, 0xFFFF, "QM370 Chipset LPC/eSPI Controller(0xA30C)"},
{0x8086, 0xA30D, 0xFFFF, 0xFFFF, "HM470 Chipset LPC/eSPI Controller(0xA30D)"},
{0x8086, 0xA30E, 0xFFFF, 0xFFFF, "Cannon Lake LPC Controller(0xA30E)"},
{0x8086, 0xA323, 0xFFFF, 0xFFFF, "Cannon Lake PCH SMBus Controller(0xA323)"},
{0x8086, 0xA323, 0x1028, 0x0869, "Vostro 3470(0x1028-0x0869)"},
{0x8086, 0xA324, 0xFFFF, 0xFFFF, "Cannon Lake PCH SPI Controller(0xA324)"},
{0x8086, 0xA324, 0x1028, 0x0869, "Vostro 3470(0x1028-0x0869)"},
{0x8086, 0xA328, 0xFFFF, 0xFFFF, "Cannon Lake PCH Serial IO UART Host Controller(0xA328)"},
{0x8086, 0xA32B, 0xFFFF, 0xFFFF, "Cannon Lake PCH SPI Host Controller(0xA32B)"},
{0x8086, 0xA32C, 0xFFFF, 0xFFFF, "Cannon Lake PCH PCI Express Root Port #21(0xA32C)"},
{0x8086, 0xA32D, 0xFFFF, 0xFFFF, "Cannon Lake PCH PCI Express Root Port #22(0xA32D)"},
{0x8086, 0xA32E, 0xFFFF, 0xFFFF, "Cannon Lake PCH PCI Express Root Port #23(0xA32E)"},
{0x8086, 0xA32F, 0xFFFF, 0xFFFF, "Cannon Lake PCH PCI Express Root Port #24(0xA32F)"},
{0x8086, 0xA330, 0xFFFF, 0xFFFF, "Cannon Lake PCH PCI Express Root Port #9(0xA330)"},
{0x8086, 0xA331, 0xFFFF, 0xFFFF, "Cannon Lake PCH PCI Express Root Port #10(0xA331)"},
{0x8086, 0xA332, 0xFFFF, 0xFFFF, "Cannon Lake PCH PCI Express Root Port #11(0xA332)"},
{0x8086, 0xA333, 0xFFFF, 0xFFFF, "Cannon Lake PCH PCI Express Root Port #12(0xA333)"},
{0x8086, 0xA334, 0xFFFF, 0xFFFF, "Cannon Lake PCH PCI Express Root Port #13(0xA334)"},
{0x8086, 0xA335, 0xFFFF, 0xFFFF, "Cannon Lake PCH PCI Express Root Port #14(0xA335)"},
{0x8086, 0xA336, 0xFFFF, 0xFFFF, "Cannon Lake PCH PCI Express Root Port #15(0xA336)"},
{0x8086, 0xA337, 0xFFFF, 0xFFFF, "Cannon Lake PCH PCI Express Root Port #16(0xA337)"},
{0x8086, 0xA338, 0xFFFF, 0xFFFF, "Cannon Lake PCH PCI Express Root Port #1(0xA338)"},
{0x8086, 0xA339, 0xFFFF, 0xFFFF, "Cannon Lake PCH PCI Express Root Port #2(0xA339)"},
{0x8086, 0xA33A, 0xFFFF, 0xFFFF, "Cannon Lake PCH PCI Express Root Port #3(0xA33A)"},
{0x8086, 0xA33B, 0xFFFF, 0xFFFF, "Cannon Lake PCH PCI Express Root Port #4(0xA33B)"},
{0x8086, 0xA33C, 0xFFFF, 0xFFFF, "Cannon Lake PCH PCI Express Root Port #5(0xA33C)"},
{0x8086, 0xA33D, 0xFFFF, 0xFFFF, "Cannon Lake PCH PCI Express Root Port #6(0xA33D)"},
{0x8086, 0xA33E, 0xFFFF, 0xFFFF, "Cannon Lake PCH PCI Express Root Port #7(0xA33E)"},
{0x8086, 0xA33F, 0xFFFF, 0xFFFF, "Cannon Lake PCH PCI Express Root Port #8(0xA33F)"},
{0x8086, 0xA340, 0xFFFF, 0xFFFF, "Cannon Lake PCH PCI Express Root Port #17(0xA340)"},
{0x8086, 0xA341, 0xFFFF, 0xFFFF, "Cannon Lake PCH PCI Express Root Port #18(0xA341)"},
{0x8086, 0xA342, 0xFFFF, 0xFFFF, "Cannon Lake PCH PCI Express Root Port #19(0xA342)"},
{0x8086, 0xA343, 0xFFFF, 0xFFFF, "Cannon Lake PCH PCI Express Root Port #20(0xA343)"},
{0x8086, 0xA348, 0xFFFF, 0xFFFF, "Cannon Lake PCH cAVS(0xA348)"},
{0x8086, 0xA348, 0x1028, 0x0869, "Vostro 3470(0x1028-0x0869)"},
{0x8086, 0xA352, 0xFFFF, 0xFFFF, "Cannon Lake PCH SATA AHCI Controller(0xA352)"},
{0x8086, 0xA352, 0x1028, 0x0869, "Vostro 3470(0x1028-0x0869)"},
{0x8086, 0xA353, 0xFFFF, 0xFFFF, "Cannon Lake Mobile PCH SATA AHCI Controller(0xA353)"},
{0x8086, 0xA360, 0xFFFF, 0xFFFF, "Cannon Lake PCH HECI Controller(0xA360)"},
{0x8086, 0xA360, 0x1028, 0x0869, "Vostro 3470(0x1028-0x0869)"},
{0x8086, 0xA363, 0xFFFF, 0xFFFF, "Cannon Lake PCH Active Management Technology - SOL(0xA363)"},
{0x8086, 0xA364, 0xFFFF, 0xFFFF, "Cannon Lake PCH HECI Controller #2(0xA364)"},
{0x8086, 0xA368, 0xFFFF, 0xFFFF, "Cannon Lake PCH Serial IO I2C Controller #0(0xA368)"},
{0x8086, 0xA369, 0xFFFF, 0xFFFF, "Cannon Lake PCH Serial IO I2C Controller #1(0xA369)"},
{0x8086, 0xA36A, 0xFFFF, 0xFFFF, "Cannon Lake PCH Serial IO I2C Controller #2(0xA36A)"},
{0x8086, 0xA36B, 0xFFFF, 0xFFFF, "Cannon Lake PCH Serial IO I2C Controller #3(0xA36B)"},
{0x8086, 0xA36D, 0xFFFF, 0xFFFF, "Cannon Lake PCH USB 3.1 xHCI Host Controller(0xA36D)"},
{0x8086, 0xA36D, 0x1028, 0x0869, "Vostro 3470(0x1028-0x0869)"},
{0x8086, 0xA36F, 0xFFFF, 0xFFFF, "Cannon Lake PCH Shared SRAM(0xA36F)"},
{0x8086, 0xA370, 0xFFFF, 0xFFFF, "Cannon Lake PCH CNVi WiFi(0xA370)"},
{0x8086, 0xA370, 0x1A56, 0x1552, "Killer(R) Wireless-AC 1550i Wireless Network Adapter (9560NGW)(0x1A56-0x1552)"},
{0x8086, 0xA370, 0x8086, 0x0034, "Wireless-AC 9560(0x8086-0x0034)"},
{0x8086, 0xA379, 0xFFFF, 0xFFFF, "Cannon Lake PCH Thermal Controller(0xA379)"},
{0x8086, 0xA379, 0x1028, 0x0869, "Vostro 3470(0x1028-0x0869)"},
{0x8086, 0xA382, 0xFFFF, 0xFFFF, "400 Series Chipset Family SATA AHCI Controller(0xA382)"},
{0x8086, 0xA394, 0xFFFF, 0xFFFF, "Comet Lake PCI Express Root Port #05(0xA394)"},
{0x8086, 0xA397, 0xFFFF, 0xFFFF, "Comet Lake PCI Express Root Port #08(0xA397)"},
{0x8086, 0xA398, 0xFFFF, 0xFFFF, "Comet Lake PCI Express Root Port 9(0xA398)"},
{0x8086, 0xA39A, 0xFFFF, 0xFFFF, "Comet Lake PCI Express Root Port 11(0xA39A)"},
{0x8086, 0xA3A1, 0xFFFF, 0xFFFF, "Cannon Lake PCH Power Management Controller(0xA3A1)"},
{0x8086, 0xA3A3, 0xFFFF, 0xFFFF, "Comet Lake PCH-V SMBus Host Controller(0xA3A3)"},
{0x8086, 0xA3AF, 0xFFFF, 0xFFFF, "Comet Lake PCH-V USB Controller(0xA3AF)"},
{0x8086, 0xA3B1, 0xFFFF, 0xFFFF, "Comet Lake PCH-V Thermal Subsystem(0xA3B1)"},
{0x8086, 0xA3BA, 0xFFFF, 0xFFFF, "Comet Lake PCH-V HECI Controller(0xA3BA)"},
{0x8086, 0xA3C8, 0xFFFF, 0xFFFF, "B460 Chipset LPC/eSPI Controller(0xA3C8)"},
{0x8086, 0xA3DA, 0xFFFF, 0xFFFF, "H410 Chipset LPC/eSPI Controller(0xA3DA)"},
{0x8086, 0xA3EB, 0xFFFF, 0xFFFF, "Comet Lake PCI Express Root Port #21(0xA3EB)"},
{0x8086, 0xA3F0, 0xFFFF, 0xFFFF, "Comet Lake PCH-V cAVS(0xA3F0)"},
{0x8086, 0xA620, 0xFFFF, 0xFFFF, "6400/6402 Advanced Memory Buffer (AMB)(0xA620)"},
{0x8086, 0xA703, 0xFFFF, 0xFFFF, "Raptor Lake-S Host Bridge/DRAM Controller(0xA703)"},
{0x8086, 0xA706, 0xFFFF, 0xFFFF, "Raptor Lake-P 6p+8e cores Host Bridge/DRAM Controller(0xA706)"},
{0x8086, 0xA706, 0x1028, 0x0C06, "Precision 3580(0x1028-0x0C06)"},
{0x8086, 0xA707, 0xFFFF, 0xFFFF, "Raptor Lake-P/U 4p+8e cores Host Bridge/DRAM Controller(0xA707)"},
{0x8086, 0xA708, 0xFFFF, 0xFFFF, "Raptor Lake-P/U 2p+8e cores Host Bridge/DRAM Controller(0xA708)"},
{0x8086, 0xA70D, 0xFFFF, 0xFFFF, "Raptor Lake PCI Express 5.0 Graphics Port (PEG010)(0xA70D)"},
{0x8086, 0xA71D, 0xFFFF, 0xFFFF, "Raptor Lake Dynamic Platform and Thermal Framework Processor Participant(0xA71D)"},
{0x8086, 0xA71D, 0x1028, 0x0C06, "Precision 3580(0x1028-0x0C06)"},
{0x8086, 0xA71E, 0xFFFF, 0xFFFF, "Raptor Lake-P Thunderbolt 4 USB Controller(0xA71E)"},
{0x8086, 0xA71E, 0x1028, 0x0C06, "Precision 3580(0x1028-0x0C06)"},
{0x8086, 0xA720, 0xFFFF, 0xFFFF, "Raptor Lake-P [UHD Graphics](0xA720)"},
{0x8086, 0xA721, 0xFFFF, 0xFFFF, "Raptor Lake-P [UHD Graphics](0xA721)"},
{0x8086, 0xA72F, 0xFFFF, 0xFFFF, "Raptor Lake-P Thunderbolt 4 PCI Express Root Port #2(0xA72F)"},
{0x8086, 0xA73E, 0xFFFF, 0xFFFF, "Raptor Lake-P Thunderbolt 4 NHI #0(0xA73E)"},
{0x8086, 0xA73E, 0x1028, 0x0C06, "Precision 3580(0x1028-0x0C06)"},
{0x8086, 0xA740, 0xFFFF, 0xFFFF, "Raptor Lake-S 8+12 - Host Bridge/DRAM Controller(0xA740)"},
{0x8086, 0xA74D, 0xFFFF, 0xFFFF, "Raptor Lake PCIe 4.0 Graphics Port(0xA74D)"},
{0x8086, 0xA74F, 0xFFFF, 0xFFFF, "GNA Scoring Accelerator module(0xA74F)"},
{0x8086, 0xA74F, 0x1028, 0x0C06, "Precision 3580(0x1028-0x0C06)"},
{0x8086, 0xA76D, 0xFFFF, 0xFFFF, "Raptor Lake-P Thunderbolt 4 NHI #1(0xA76D)"},
{0x8086, 0xA76E, 0xFFFF, 0xFFFF, "Raptor Lake-P Thunderbolt 4 PCI Express Root Port #0(0xA76E)"},
{0x8086, 0xA77D, 0xFFFF, 0xFFFF, "Raptor Lake Crashlog and Telemetry(0xA77D)"},
{0x8086, 0xA77D, 0x1028, 0x0C06, "Precision 3580(0x1028-0x0C06)"},
{0x8086, 0xA77F, 0xFFFF, 0xFFFF, "Volume Management Device NVMe RAID Controller Intel Corporation(0xA77F)"},
{0x8086, 0xA780, 0xFFFF, 0xFFFF, "Raptor Lake-S GT1 [UHD Graphics 770](0xA780)"},
{0x8086, 0xA781, 0xFFFF, 0xFFFF, "Raptor Lake-S UHD Graphics(0xA781)"},
{0x8086, 0xA782, 0xFFFF, 0xFFFF, "Raptor Lake-S UHD Graphics(0xA782)"},
{0x8086, 0xA783, 0xFFFF, 0xFFFF, "Raptor Lake-S UHD Graphics(0xA783)"},
{0x8086, 0xA788, 0xFFFF, 0xFFFF, "Raptor Lake-S UHD Graphics(0xA788)"},
{0x8086, 0xA789, 0xFFFF, 0xFFFF, "Raptor Lake-S UHD Graphics(0xA789)"},
{0x8086, 0xA78A, 0xFFFF, 0xFFFF, "Raptor Lake-S UHD Graphics(0xA78A)"},
{0x8086, 0xA78B, 0xFFFF, 0xFFFF, "Raptor Lake-S UHD Graphics(0xA78B)"},
{0x8086, 0xA7A0, 0xFFFF, 0xFFFF, "Raptor Lake-P [Iris Xe Graphics](0xA7A0)"},
{0x8086, 0xA7A0, 0x1028, 0x0C06, "Precision 3580(0x1028-0x0C06)"},
{0x8086, 0xA7A1, 0xFFFF, 0xFFFF, "Raptor Lake-P [Iris Xe Graphics](0xA7A1)"},
{0x8086, 0xA7A8, 0xFFFF, 0xFFFF, "Raptor Lake-P [UHD Graphics](0xA7A8)"},
{0x8086, 0xA7A9, 0xFFFF, 0xFFFF, "Raptor Lake-P [UHD Graphics](0xA7A9)"},
{0x8086, 0xA7AA, 0xFFFF, 0xFFFF, "Raptor Lake-P [Intel Graphics](0xA7AA)"},
{0x8086, 0xA7AB, 0xFFFF, 0xFFFF, "Raptor Lake-P [Intel Graphics](0xA7AB)"},
{0x8086, 0xA7AC, 0xFFFF, 0xFFFF, "Raptor Lake-U [Intel Graphics](0xA7AC)"},
{0x8086, 0xA7AD, 0xFFFF, 0xFFFF, "Raptor Lake-U [Intel Graphics](0xA7AD)"},
{0x8086, 0xA806, 0xFFFF, 0xFFFF, "Lunar Lake-M LPC/eSPI Controller(0xA806)"},
{0x8086, 0xA822, 0xFFFF, 0xFFFF, "Lunar Lake-M SMbus Controller(0xA822)"},
{0x8086, 0xA823, 0xFFFF, 0xFFFF, "Lunar Lake-M SPI Controller(0xA823)"},
{0x8086, 0xA824, 0xFFFF, 0xFFFF, "Lunar Lake-M Trace Hub(0xA824)"},
{0x8086, 0xA825, 0xFFFF, 0xFFFF, "Lunar Lake-M Serial IO UART Controller #0(0xA825)"},
{0x8086, 0xA826, 0xFFFF, 0xFFFF, "Lunar Lake-M Serial IO UART Controller #1(0xA826)"},
{0x8086, 0xA827, 0xFFFF, 0xFFFF, "Lunar Lake-M Serial IO SPI Controller #0(0xA827)"},
{0x8086, 0xA828, 0xFFFF, 0xFFFF, "Lunar Lake-M HD Audio Controller(0xA828)"},
{0x8086, 0xA830, 0xFFFF, 0xFFFF, "Lunar Lake-M Serial IO SPI Controller #1(0xA830)"},
{0x8086, 0xA831, 0xFFFF, 0xFFFF, "Lunar Lake-M Thunderbolt 4 USB Controller(0xA831)"},
{0x8086, 0xA833, 0xFFFF, 0xFFFF, "Lunar Lake-M Thunderbolt 4 NHI #0(0xA833)"},
{0x8086, 0xA834, 0xFFFF, 0xFFFF, "Lunar Lake-M Thunderbolt 4 NHI #1(0xA834)"},
{0x8086, 0xA838, 0xFFFF, 0xFFFF, "Lunar Lake-M PCI Express Root Port #1(0xA838)"},
{0x8086, 0xA839, 0xFFFF, 0xFFFF, "Lunar Lake-M PCI Express Root Port #2(0xA839)"},
{0x8086, 0xA83A, 0xFFFF, 0xFFFF, "Lunar Lake-M PCI Express Root Port #3(0xA83A)"},
{0x8086, 0xA83B, 0xFFFF, 0xFFFF, "Lunar Lake-M PCI Express Root Port #4(0xA83B)"},
{0x8086, 0xA83C, 0xFFFF, 0xFFFF, "Lunar Lake-M PCI Express Root Port #5(0xA83C)"},
{0x8086, 0xA83D, 0xFFFF, 0xFFFF, "Lunar Lake-M PCI Express Root Port #6(0xA83D)"},
{0x8086, 0xA845, 0xFFFF, 0xFFFF, "Lunar Lake-M Integrated Sensor Hub(0xA845)"},
{0x8086, 0xA847, 0xFFFF, 0xFFFF, "Lunar Lake-M UFS Controller(0xA847)"},
{0x8086, 0xA84E, 0xFFFF, 0xFFFF, "Lunar Lake-M Thunderbolt 4 PCI Express Root Port #0(0xA84E)"},
{0x8086, 0xA84F, 0xFFFF, 0xFFFF, "Lunar Lake-M Thunderbolt 4 PCI Express Root Port #1(0xA84F)"},
{0x8086, 0xA860, 0xFFFF, 0xFFFF, "Lunar Lake-M Thunderbolt 4 PCI Express Root Port #2(0xA860)"},
{0x8086, 0xA878, 0xFFFF, 0xFFFF, "Lunar Lake-M Serial IO I2C Controller #0(0xA878)"},
{0x8086, 0xA879, 0xFFFF, 0xFFFF, "Lunar Lake-M Serial IO I2C Controller #1(0xA879)"},
{0x8086, 0xA87A, 0xFFFF, 0xFFFF, "Lunar Lake-M Serial IO I2C Controller #2(0xA87A)"},
{0x8086, 0xA87B, 0xFFFF, 0xFFFF, "Lunar Lake-M Serial IO I2C Controller #3(0xA87B)"},
{0x8086, 0xA87D, 0xFFFF, 0xFFFF, "Lunar Lake-M USB 3.2 Gen 2x1 xHCI Host Controller(0xA87D)"},
{0x8086, 0xABC0, 0xFFFF, 0xFFFF, "Omni-Path Fabric Switch Silicon 100 Series(0xABC0)"},
{0x8086, 0xAD0B, 0xFFFF, 0xFFFF, "Volume Management Device NVMe RAID Controller Intel Corporation(0xAD0B)"},
{0x8086, 0xAD1D, 0xFFFF, 0xFFFF, "Arrow Lake NPU(0xAD1D)"},
{0x8086, 0xB03E, 0xFFFF, 0xFFFF, "Panther Lake NPU(0xB03E)"},
{0x8086, 0xB152, 0xFFFF, 0xFFFF, "21152 PCI-to-PCI Bridge(0xB152)"},
{0x8086, 0xB152, 0x8086, 0xB152, "21152 PCI-to-PCI Bridge(0x8086-0xB152)"},
{0x8086, 0xB154, 0xFFFF, 0xFFFF, "21154 PCI-to-PCI Bridge(0xB154)"},
{0x8086, 0xB555, 0xFFFF, 0xFFFF, "21555 Non transparent PCI-to-PCI Bridge(0xB555)"},
{0x8086, 0xB555, 0x12C7, 0x5005, "SS7HD PCI Adaptor Card(0x12C7-0x5005)"},
{0x8086, 0xB555, 0x12C7, 0x5006, "SS7HDC cPCI Adaptor Card(0x12C7-0x5006)"},
{0x8086, 0xB555, 0x12D9, 0x000A, "PCI VoIP Gateway(0x12D9-0x000A)"},
{0x8086, 0xB555, 0x4C53, 0x1050, "CT7 mainboard(0x4C53-0x1050)"},
{0x8086, 0xB555, 0x4C53, 0x1051, "CE7 mainboard(0x4C53-0x1051)"},
{0x8086, 0xB555, 0xE4BF, 0x1000, "CC8-1-BLUES(0xE4BF-0x1000)"},
{0x8086, 0xD130, 0xFFFF, 0xFFFF, "Core Processor DMI(0xD130)"},
{0x8086, 0xD130, 0x15D9, 0x0605, "X8SIL(0x15D9-0x0605)"},
{0x8086, 0xD131, 0xFFFF, 0xFFFF, "Core Processor DMI(0xD131)"},
{0x8086, 0xD131, 0x1028, 0x02DA, "OptiPlex 980(0x1028-0x02DA)"},
{0x8086, 0xD131, 0x15D9, 0x060D, "C7SIM-Q Motherboard(0x15D9-0x060D)"},
{0x8086, 0xD132, 0xFFFF, 0xFFFF, "Core Processor DMI(0xD132)"},
{0x8086, 0xD132, 0x1028, 0x040B, "Latitude E6510(0x1028-0x040B)"},
{0x8086, 0xD133, 0xFFFF, 0xFFFF, "Core Processor DMI(0xD133)"},
{0x8086, 0xD134, 0xFFFF, 0xFFFF, "Core Processor DMI(0xD134)"},
{0x8086, 0xD135, 0xFFFF, 0xFFFF, "Core Processor DMI(0xD135)"},
{0x8086, 0xD136, 0xFFFF, 0xFFFF, "Core Processor DMI(0xD136)"},
{0x8086, 0xD137, 0xFFFF, 0xFFFF, "Core Processor DMI(0xD137)"},
{0x8086, 0xD138, 0xFFFF, 0xFFFF, "Core Processor PCI Express Root Port 1(0xD138)"},
{0x8086, 0xD138, 0x1028, 0x02DA, "OptiPlex 980(0x1028-0x02DA)"},
{0x8086, 0xD138, 0x1028, 0x040B, "Latitude E6510(0x1028-0x040B)"},
{0x8086, 0xD138, 0x15D9, 0x060D, "C7SIM-Q Motherboard(0x15D9-0x060D)"},
{0x8086, 0xD139, 0xFFFF, 0xFFFF, "Core Processor PCI Express Root Port 2(0xD139)"},
{0x8086, 0xD13A, 0xFFFF, 0xFFFF, "Core Processor PCI Express Root Port 3(0xD13A)"},
{0x8086, 0xD13B, 0xFFFF, 0xFFFF, "Core Processor PCI Express Root Port 4(0xD13B)"},
{0x8086, 0xD150, 0xFFFF, 0xFFFF, "Core Processor QPI Link(0xD150)"},
{0x8086, 0xD151, 0xFFFF, 0xFFFF, "Core Processor QPI Routing and Protocol Registers(0xD151)"},
{0x8086, 0xD155, 0xFFFF, 0xFFFF, "Core Processor System Management Registers(0xD155)"},
{0x8086, 0xD156, 0xFFFF, 0xFFFF, "Core Processor Semaphore and Scratchpad Registers(0xD156)"},
{0x8086, 0xD157, 0xFFFF, 0xFFFF, "Core Processor System Control and Status Registers(0xD157)"},
{0x8086, 0xD158, 0xFFFF, 0xFFFF, "Core Processor Miscellaneous Registers(0xD158)"},
{0x8086, 0xE202, 0xFFFF, 0xFFFF, "Battlemage G21 [Intel Graphics](0xE202)"},
{0x8086, 0xE20B, 0xFFFF, 0xFFFF, "Battlemage G21 [Intel Graphics](0xE20B)"},
{0x8086, 0xE20C, 0xFFFF, 0xFFFF, "Battlemage G21 [Intel Graphics](0xE20C)"},
{0x8086, 0xE20D, 0xFFFF, 0xFFFF, "Battlemage G21 [Intel Graphics](0xE20D)"},
{0x8086, 0xE212, 0xFFFF, 0xFFFF, "Battlemage G21 [Intel Graphics](0xE212)"},
{0x8086, 0xF1A5, 0xFFFF, 0xFFFF, "SSD 600P Series(0xF1A5)"},
{0x8086, 0xF1A5, 0x8086, 0x390A, "SSDPEKKW256G7 256GB(0x8086-0x390A)"},
{0x8086, 0xF1A6, 0xFFFF, 0xFFFF, "SSD DC P4101/Pro 7600p/760p/E 6100p Series(0xF1A6)"},
{0x8086, 0xF1A6, 0x8086, 0x390B, "SSD Pro 7600p/760p/E 6100p Series [NVM Express](0x8086-0x390B)"},
{0x8086, 0xF1A7, 0xFFFF, 0xFFFF, "SSD 700p Series(0xF1A7)"},
{0x8086, 0xF1A8, 0xFFFF, 0xFFFF, "SSD 660P Series(0xF1A8)"},
{0x8086, 0xF1AA, 0xFFFF, 0xFFFF, "SSD 670p Series [Keystone Harbor](0xF1AA)"},
{0x8086, 0xFAF0, 0xFFFF, 0xFFFF, "SSD 665p Series [Neptune Harbor Refresh](0xFAF0)"},
}; /* pci_vid_8086[] */

static pci_id_t const pci_vid_8088[] = {
{0x8088, 0xFFFF, 0xFFFF, 0xFFFF, "Beijing Wangxun Technology Co., Ltd.(0x8088)"},
{0x8088, 0x0100, 0xFFFF, 0xFFFF, "WX1860AL-W Gigabit Ethernet Controller(0x0100)"},
{0x8088, 0x0101, 0xFFFF, 0xFFFF, "WX1860A2 Gigabit Ethernet Controller(0x0101)"},
{0x8088, 0x0101, 0x4C52, 0x2024, "LRES2024PT Dual-port 1Gb Ethernet Network Adapter(0x4C52-0x2024)"},
{0x8088, 0x0101, 0x4C52, 0x2025, "LRES2025PT Quad-port 1Gb Ethernet Network Adapter(0x4C52-0x2025)"},
{0x8088, 0x0101, 0x4C52, 0x2027, "LRES2027PF Dual-port 1Gb Ethernet Server Adapter(0x4C52-0x2027)"},
{0x8088, 0x0101, 0x4C52, 0x3018, "LRES3018PT Dual-port 1Gb Ethernet Server Adapter for OCP(0x4C52-0x3018)"},
{0x8088, 0x0101, 0x8088, 0x0201, "Dual-Port Ethernet Network Adaptor SF200T(0x8088-0x0201)"},
{0x8088, 0x0101, 0x8088, 0x0501, "Dual-Port Ethernet Network Adapter SF200T-C101(0x8088-0x0501)"},
{0x8088, 0x0101, 0x8088, 0x0901, "Dual-Port Ethernet Network Adapter SF200T-B401(0x8088-0x0901)"},
{0x8088, 0x0101, 0x8088, 0x0B01, "Dual-Port Ethernet Network Adapter SF200T-B402(0x8088-0x0B01)"},
{0x8088, 0x0101, 0x8088, 0x4201, "Dual-Port Ethernet Network Adaptor SF200T (WOL)(0x8088-0x4201)"},
{0x8088, 0x0101, 0x8088, 0x8201, "Dual-Port Ethernet Network Adaptor SF200T (NCSI)(0x8088-0x8201)"},
{0x8088, 0x0101, 0x8088, 0xC201, "Dual-Port Ethernet Network Adaptor SF200T (WOL, NCSI)(0x8088-0xC201)"},
{0x8088, 0x0102, 0xFFFF, 0xFFFF, "WX1860A2S Gigabit Ethernet Controller(0x0102)"},
{0x8088, 0x0102, 0x8088, 0x0210, "Dual-Port Ethernet Network Adaptor SF200T-S(0x8088-0x0210)"},
{0x8088, 0x0103, 0xFFFF, 0xFFFF, "WX1860A4 Gigabit Ethernet Controller(0x0103)"},
{0x8088, 0x0103, 0x1BD4, 0x009E, "ENPW2100-T4(0x1BD4-0x009E)"},
{0x8088, 0x0103, 0x4C52, 0x2028, "LRES2028PF Quad-port 1Gb Ethernet Server Adapter(0x4C52-0x2028)"},
{0x8088, 0x0103, 0x4C52, 0x3019, "LRES3019PT Quad-port 1Gb Ethernet Server Adapter for OCP(0x4C52-0x3019)"},
{0x8088, 0x0103, 0x8088, 0x0401, "Qual-Port Ethernet Network Adaptor SF400T(0x8088-0x0401)"},
{0x8088, 0x0103, 0x8088, 0x0440, "Qual-Port Ethernet Network Adaptor SF400-OCP(0x8088-0x0440)"},
{0x8088, 0x0103, 0x8088, 0x0A01, "Quad-Port Ethernet Network Adapter SF400T-B401(0x8088-0x0A01)"},
{0x8088, 0x0103, 0x8088, 0x0C01, "Quad-Port Ethernet Network Adapter SF400T-B402(0x8088-0x0C01)"},
{0x8088, 0x0103, 0x8088, 0x4401, "Quad-Port Ethernet Network Adapter SF400T (WOL)(0x8088-0x4401)"},
{0x8088, 0x0103, 0x8088, 0x8103, "Quad-Port Ethernet Network Adaptor SF400T (NCSI)(0x8088-0x8103)"},
{0x8088, 0x0103, 0x8088, 0x8401, "Quad-Port Ethernet Network Adapter SF400T (NCSI)(0x8088-0x8401)"},
{0x8088, 0x0103, 0x8088, 0xC103, "Quad-Port Ethernet Network Adaptor SF400T (WOL, NCSI)(0x8088-0xC103)"},
{0x8088, 0x0103, 0x8088, 0xC401, "Quad-Port Ethernet Network Adapter SF400T (WOL, NCSI)(0x8088-0xC401)"},
{0x8088, 0x0104, 0xFFFF, 0xFFFF, "WX1860A4S Gigabit Ethernet Controller(0x0104)"},
{0x8088, 0x0104, 0x8088, 0x0410, "Qual-Port Ethernet Network Adaptor SF400T-S(0x8088-0x0410)"},
{0x8088, 0x0105, 0xFFFF, 0xFFFF, "WX1860AL2 Gigabit Ethernet Controller(0x0105)"},
{0x8088, 0x0105, 0x8088, 0x0202, "Dual-Port Ethernet Network Adaptor SF200HT(0x8088-0x0202)"},
{0x8088, 0x0105, 0x8088, 0x4202, "Dual-Port Ethernet Network Adaptor SF200HT (WOL)(0x8088-0x4202)"},
{0x8088, 0x0105, 0x8088, 0x8202, "Dual-Port Ethernet Network Adaptor SF200HT (NCSI)(0x8088-0x8202)"},
{0x8088, 0x0105, 0x8088, 0xC202, "Dual-Port Ethernet Network Adaptor SF200HT (WOL, NCSI)(0x8088-0xC202)"},
{0x8088, 0x0106, 0xFFFF, 0xFFFF, "WX1860AL2S Gigabit Ethernet Controller(0x0106)"},
{0x8088, 0x0106, 0x8088, 0x0220, "Dual-Port Ethernet Network Adaptor SF200HT-S(0x8088-0x0220)"},
{0x8088, 0x0107, 0xFFFF, 0xFFFF, "WX1860AL4 Gigabit Ethernet Controller(0x0107)"},
{0x8088, 0x0107, 0x8088, 0x0402, "Qual-Port Ethernet Network Adaptor SF400HT(0x8088-0x0402)"},
{0x8088, 0x0107, 0x8088, 0x4402, "Quad-Port Ethernet Network Adaptor SF400HT (WOL)(0x8088-0x4402)"},
{0x8088, 0x0107, 0x8088, 0x8402, "Quad-Port Ethernet Network Adaptor SF400HT (NCSI)(0x8088-0x8402)"},
{0x8088, 0x0107, 0x8088, 0xC402, "Quad-Port Ethernet Network Adaptor SF400HT (WOL, NCSI)(0x8088-0xC402)"},
{0x8088, 0x0108, 0xFFFF, 0xFFFF, "WX1860AL4S Gigabit Ethernet Controller(0x0108)"},
{0x8088, 0x0108, 0x8088, 0x0420, "Qual-Port Ethernet Network Adaptor SF400HT-S(0x8088-0x0420)"},
{0x8088, 0x0109, 0xFFFF, 0xFFFF, "WX1860-LC Gigabit Ethernet Controller(0x0109)"},
{0x8088, 0x010A, 0xFFFF, 0xFFFF, "WX1860A1 Gigabit Ethernet Controller(0x010A)"},
{0x8088, 0x010A, 0x4C52, 0x2026, "LRES2026PF Single-port 1Gb Ethernet Network Adapter(0x4C52-0x2026)"},
{0x8088, 0x010A, 0x4C52, 0x2034, "LRES2034PT Single-port 1Gb Ethernet Network Adapter(0x4C52-0x2034)"},
{0x8088, 0x010B, 0xFFFF, 0xFFFF, "WX1860AL1 Gigabit Ethernet Controller(0x010B)"},
{0x8088, 0x010B, 0x4C52, 0x2215, "LRES2215PT Single-port 1Gb Ethernet Network Adapter(0x4C52-0x2215)"},
{0x8088, 0x010B, 0x8088, 0x0102, "Single-Port Ethernet Network Adaptor SF100HT(0x8088-0x0102)"},
{0x8088, 0x010B, 0x8088, 0x4102, "Single-Port Ethernet Network Adaptor SF100HT (WOL)(0x8088-0x4102)"},
{0x8088, 0x010B, 0x8088, 0x8102, "Single-Port Ethernet Network Adaptor SF100HT (NCSI)(0x8088-0x8102)"},
{0x8088, 0x010B, 0x8088, 0xC102, "Single-Port Ethernet Network Adaptor SF100HT (WOL, NCSI)(0x8088-0xC102)"},
{0x8088, 0x0111, 0xFFFF, 0xFFFF, "WX1860A2 Ethernet Controller Virtual Function(0x0111)"},
{0x8088, 0x0113, 0xFFFF, 0xFFFF, "WX1860A4 Ethernet Controller Virtual Function(0x0113)"},
{0x8088, 0x0115, 0xFFFF, 0xFFFF, "WX1860AL2 Ethernet Controller Virtual Function(0x0115)"},
{0x8088, 0x0117, 0xFFFF, 0xFFFF, "WX1860AL4 Ethernet Controller Virtual Function(0x0117)"},
{0x8088, 0x0119, 0xFFFF, 0xFFFF, "WX1860-LC Gigabit Ethernet Controller Virtual Function(0x0119)"},
{0x8088, 0x011A, 0xFFFF, 0xFFFF, "WX1860A1 Gigabit Ethernet Controller Virtual Function(0x011A)"},
{0x8088, 0x011B, 0xFFFF, 0xFFFF, "WX1860AL1 Gigabit Ethernet Controller Virtual Function(0x011B)"},
{0x8088, 0x1000, 0xFFFF, 0xFFFF, "Ethernet Controller SP1000A Virtual Function for 10GbE SFP+(0x1000)"},
{0x8088, 0x1001, 0xFFFF, 0xFFFF, "Ethernet Controller SP1000A for 10GbE SFP+(0x1001)"},
{0x8088, 0x1001, 0x1BD4, 0x0084, "Ethernet Controller SP1000A for 10GbE SFP+(lldp)(0x1BD4-0x0084)"},
{0x8088, 0x1001, 0x1BD4, 0x0085, "Ethernet Controller SP1000A for 10GBASE-T(0x1BD4-0x0085)"},
{0x8088, 0x1001, 0x4C52, 0x1002, "LRES1002PF Dual-port 10Gb Ethernet Server Adapter(0x4C52-0x1002)"},
{0x8088, 0x1001, 0x4C52, 0x1003, "LRES1003PF Single-port 10Gb Ethernet Server Adapter(0x4C52-0x1003)"},
{0x8088, 0x1001, 0x4C52, 0x3001, "LRES3001PF Dual-port 10Gb Ethernet Server Adapter for OCP(0x4C52-0x3001)"},
{0x8088, 0x1001, 0x8088, 0x0000, "Ethernet Network Adaptor RP1000 for 10GbE SFP+(0x8088-0x0000)"},
{0x8088, 0x1001, 0x8088, 0x0300, "Ethernet Network Adaptor RP1000-A03 for 10GbE SFP+(0x8088-0x0300)"},
{0x8088, 0x1001, 0x8088, 0x0400, "Ethernet Network Adaptor RP1000-A04 for 10GbE SFP+(0x8088-0x0400)"},
{0x8088, 0x2000, 0xFFFF, 0xFFFF, "Ethernet Controller WX1820AL Virtual Function for 10GbE SFP+(0x2000)"},
{0x8088, 0x2001, 0xFFFF, 0xFFFF, "Ethernet Controller WX1820AL for 10GbE SFP+(0x2001)"},
{0x8088, 0x2001, 0x8088, 0x2000, "Ethernet Network Adaptor RP2000 for 10GbE SFP+(0x8088-0x2000)"},
{0x8088, 0x2001, 0x8088, 0x2300, "Ethernet Network Adaptor RP2000-A03 for 10GbE SFP+(0x8088-0x2300)"},
{0x8088, 0x2001, 0x8088, 0x2400, "Ethernet Network Adaptor RP2000-A04 for 10GbE SFP+(0x8088-0x2400)"},
}; /* pci_vid_8088[] */

static pci_id_t const pci_vid_80EE[] = {
{0x80EE, 0xFFFF, 0xFFFF, 0xFFFF, "InnoTek Systemberatung GmbH(0x80EE)"},
{0x80EE, 0xBEEF, 0xFFFF, 0xFFFF, "VirtualBox Graphics Adapter(0xBEEF)"},
{0x80EE, 0xCAFE, 0xFFFF, 0xFFFF, "VirtualBox Guest Service(0xCAFE)"},
}; /* pci_vid_80EE[] */

static pci_id_t const pci_vid_8322[] = {
{0x8322, 0xFFFF, 0xFFFF, 0xFFFF, "Sodick America Corp.(0x8322)"},
}; /* pci_vid_8322[] */

static pci_id_t const pci_vid_8384[] = {
{0x8384, 0xFFFF, 0xFFFF, 0xFFFF, "SigmaTel(0x8384)"},
}; /* pci_vid_8384[] */

static pci_id_t const pci_vid_8401[] = {
{0x8401, 0xFFFF, 0xFFFF, 0xFFFF, "TRENDware International Inc.(0x8401)"},
}; /* pci_vid_8401[] */

static pci_id_t const pci_vid_8510[] = {
{0x8510, 0xFFFF, 0xFFFF, 0xFFFF, "Sietium Semiconductor Co., Ltd.(0x8510)"},
{0x8510, 0x0201, 0xFFFF, 0xFFFF, "GenBu02 Series GPU(0x0201)"},
{0x8510, 0x0201, 0x8510, 0x0001, "GB2062-PUB-LPDDR(0x8510-0x0001)"},
{0x8510, 0x0201, 0x8510, 0x0002, "GB2062-PCIe-C0(0x8510-0x0002)"},
{0x8510, 0x0201, 0x8510, 0x0003, "GB2062-PCIe-C41(0x8510-0x0003)"},
{0x8510, 0x0201, 0x8510, 0x0004, "GB2062-PCIe-HIEILP4(0x8510-0x0004)"},
{0x8510, 0x0201, 0x8510, 0x0005, "CQ2040-PCIe-C21(0x8510-0x0005)"},
{0x8510, 0x0201, 0x8510, 0x0007, "GB2062-PCIe-C40(0x8510-0x0007)"},
{0x8510, 0x0201, 0x8510, 0x0008, "CQ2040-MXM-M60(0x8510-0x0008)"},
{0x8510, 0x0201, 0x8510, 0x0009, "GB2062-PCIe-C20(0x8510-0x0009)"},
{0x8510, 0x0201, 0x8510, 0x000C, "CQ2040-PUB(0x8510-0x000C)"},
{0x8510, 0x0201, 0x8510, 0x0201, "GB2062-PUB-DDR(0x8510-0x0201)"},
}; /* pci_vid_8510[] */

static pci_id_t const pci_vid_8686[] = {
{0x8686, 0xFFFF, 0xFFFF, 0xFFFF, "SAP(0x8686)"},
{0x8686, 0x1010, 0xFFFF, 0xFFFF, "vSMP Foundation controller [vSMP CTL](0x1010)"},
{0x8686, 0x1011, 0xFFFF, 0xFFFF, "vSMP Foundation MEX/FLX controller [vSMP CTL](0x1011)"},
}; /* pci_vid_8686[] */

static pci_id_t const pci_vid_8800[] = {
{0x8800, 0xFFFF, 0xFFFF, 0xFFFF, "Trigem Computer Inc.(0x8800)"},
{0x8800, 0x2008, 0xFFFF, 0xFFFF, "Video assistant component(0x2008)"},
}; /* pci_vid_8800[] */

static pci_id_t const pci_vid_8820[] = {
{0x8820, 0xFFFF, 0xFFFF, 0xFFFF, "Stryker Corporation(0x8820)"},
{0x8820, 0x2724, 0xFFFF, 0xFFFF, "Mako Front Side Motor Controller [cPCI](0x2724)"},
}; /* pci_vid_8820[] */

static pci_id_t const pci_vid_8848[] = {
{0x8848, 0xFFFF, 0xFFFF, 0xFFFF, "MUCSE(0x8848)"},
{0x8848, 0x1000, 0xFFFF, 0xFFFF, "Ethernet Controller N10 Series for 10GbE or 40GbE (Dual-port)(0x1000)"},
{0x8848, 0x1000, 0x4C52, 0x3032, "LRES3032PF Dual-port 10Gb Ethernet Server Adapter for OCP(0x4C52-0x3032)"},
{0x8848, 0x1000, 0x8848, 0x8410, "Ethernet Network Adapter N10G-X2-DC for 10GbE SFP+ 2-port(0x8848-0x8410)"},
{0x8848, 0x1001, 0xFFFF, 0xFFFF, "Ethernet Controller N400 Series for 1GbE (Dual-port)(0x1001)"},
{0x8848, 0x1003, 0xFFFF, 0xFFFF, "Ethernet Controller N400 Series for 10GbE (Single-port)(0x1003)"},
{0x8848, 0x1003, 0x4C52, 0x1050, "LRES1050PF Single-port 10Gb Ethernet Network Adapter(0x4C52-0x1050)"},
{0x8848, 0x1020, 0xFFFF, 0xFFFF, "Ethernet Controller N10 Series for 10GbE (Quad-port)(0x1020)"},
{0x8848, 0x1020, 0x4C52, 0x1030, "LRES1030PF Quad-port 10Gb Ethernet Server Adapter(0x4C52-0x1030)"},
{0x8848, 0x1020, 0x4C52, 0x1031, "LRES1031PF Dual-port 10Gb Ethernet Server Adapter(0x4C52-0x1031)"},
{0x8848, 0x1020, 0x4C52, 0x3031, "LRES3031PF Quad-port 10Gb Ethernet Server Adapter for OCP(0x4C52-0x3031)"},
{0x8848, 0x1020, 0x8848, 0x8451, "Ethernet Network Adapter N10G-X4-QC for 10GbE SFP+ 4-port(0x8848-0x8451)"},
{0x8848, 0x1021, 0xFFFF, 0xFFFF, "Ethernet Controller N400 Series for 1GbE (Quad-port)(0x1021)"},
{0x8848, 0x1021, 0x4C52, 0x1032, "LRES1032PF Quad-port 1Gb Ethernet Network Adapter(0x4C52-0x1032)"},
{0x8848, 0x1021, 0x4C52, 0x1039, "LRES1039PT Quad-port 1Gb Ethernet Network Adapter(0x4C52-0x1039)"},
{0x8848, 0x1060, 0xFFFF, 0xFFFF, "Ethernet Controller N10 Series for 1GbE or 10GbE (8-port)(0x1060)"},
{0x8848, 0x1080, 0xFFFF, 0xFFFF, "Ethernet Controller N10 Series Virtual Function(0x1080)"},
{0x8848, 0x1081, 0xFFFF, 0xFFFF, "Ethernet Controller N400 Series Virtual Function(0x1081)"},
{0x8848, 0x1083, 0xFFFF, 0xFFFF, "Ethernet Controller N400 Series Virtual Function(0x1083)"},
{0x8848, 0x8308, 0xFFFF, 0xFFFF, "Ethernet Controller N500 Series for 1GbE (Quad-port, Copper RJ45)(0x8308)"},
{0x8848, 0x8308, 0x193D, 0x1088, "NIC-ETH3M0T-3S-4P(0x193D-0x1088)"},
{0x8848, 0x8308, 0x4C52, 0x1048, "LRES1048PT Quad-port 1Gb Ethernet Network Adapter(0x4C52-0x1048)"},
{0x8848, 0x8308, 0x4C52, 0x3044, "LRES3044PT Quad-port 1Gb Ethernet Server Adapter for OCP(0x4C52-0x3044)"},
{0x8848, 0x8309, 0xFFFF, 0xFFFF, "Ethernet Controller N500 Series Virtual Function(0x8309)"},
{0x8848, 0x8318, 0xFFFF, 0xFFFF, "Ethernet Controller N500 Series for 1GbE (Dual-port, Copper RJ45)(0x8318)"},
{0x8848, 0x8318, 0x4C52, 0x1049, "LRES1049PT Dual-port 1Gb Ethernet Network Adapter(0x4C52-0x1049)"},
{0x8848, 0x8318, 0x4C52, 0x3043, "LRES3043PT Dual-port 1Gb Ethernet Server Adapter for OCP(0x4C52-0x3043)"},
}; /* pci_vid_8848[] */

static pci_id_t const pci_vid_8866[] = {
{0x8866, 0xFFFF, 0xFFFF, 0xFFFF, "T-Square Design Inc.(0x8866)"},
}; /* pci_vid_8866[] */

static pci_id_t const pci_vid_8888[] = {
{0x8888, 0xFFFF, 0xFFFF, 0xFFFF, "Silicon Magic(0x8888)"},
{0x8888, 0x8504, 0xFFFF, 0xFFFF, "AVMatrix VC42(0x8504)"},
}; /* pci_vid_8888[] */

static pci_id_t const pci_vid_8912[] = {
{0x8912, 0xFFFF, 0xFFFF, 0xFFFF, "TRX(0x8912)"},
}; /* pci_vid_8912[] */

static pci_id_t const pci_vid_8C4A[] = {
{0x8C4A, 0xFFFF, 0xFFFF, 0xFFFF, "Winbond(0x8C4A)"},
{0x8C4A, 0x1980, 0xFFFF, 0xFFFF, "W89C940 misprogrammed [ne2k](0x1980)"},
}; /* pci_vid_8C4A[] */

static pci_id_t const pci_vid_8E0E[] = {
{0x8E0E, 0xFFFF, 0xFFFF, 0xFFFF, "Computone Corporation(0x8E0E)"},
}; /* pci_vid_8E0E[] */

static pci_id_t const pci_vid_8E2E[] = {
{0x8E2E, 0xFFFF, 0xFFFF, 0xFFFF, "KTI(0x8E2E)"},
{0x8E2E, 0x3000, 0xFFFF, 0xFFFF, "ET32P2(0x3000)"},
}; /* pci_vid_8E2E[] */

static pci_id_t const pci_vid_9004[] = {
{0x9004, 0xFFFF, 0xFFFF, 0xFFFF, "Adaptec(0x9004)"},
{0x9004, 0x0078, 0xFFFF, 0xFFFF, "AHA-2940U_CN(0x0078)"},
{0x9004, 0x1078, 0xFFFF, 0xFFFF, "AIC-7810(0x1078)"},
{0x9004, 0x1160, 0xFFFF, 0xFFFF, "AIC-1160 [Family Fibre Channel Adapter](0x1160)"},
{0x9004, 0x2178, 0xFFFF, 0xFFFF, "AIC-7821(0x2178)"},
{0x9004, 0x3860, 0xFFFF, 0xFFFF, "AHA-2930CU(0x3860)"},
{0x9004, 0x3B78, 0xFFFF, 0xFFFF, "AHA-4844W/4844UW(0x3B78)"},
{0x9004, 0x5075, 0xFFFF, 0xFFFF, "AIC-755x(0x5075)"},
{0x9004, 0x5078, 0xFFFF, 0xFFFF, "AIC-7850T/7856T [AVA-2902/4/6 / AHA-2910](0x5078)"},
{0x9004, 0x5078, 0x9004, 0x7850, "AIC-7850T/7856T [AVA-290x / AHA-2910](0x9004-0x7850)"},
{0x9004, 0x5175, 0xFFFF, 0xFFFF, "AIC-755x(0x5175)"},
{0x9004, 0x5178, 0xFFFF, 0xFFFF, "AIC-7851(0x5178)"},
{0x9004, 0x5275, 0xFFFF, 0xFFFF, "AIC-755x(0x5275)"},
{0x9004, 0x5278, 0xFFFF, 0xFFFF, "AIC-7852(0x5278)"},
{0x9004, 0x5375, 0xFFFF, 0xFFFF, "AIC-755x(0x5375)"},
{0x9004, 0x5378, 0xFFFF, 0xFFFF, "AIC-7850(0x5378)"},
{0x9004, 0x5475, 0xFFFF, 0xFFFF, "AIC-755x(0x5475)"},
{0x9004, 0x5478, 0xFFFF, 0xFFFF, "AIC-7850(0x5478)"},
{0x9004, 0x5575, 0xFFFF, 0xFFFF, "AVA-2930(0x5575)"},
{0x9004, 0x5578, 0xFFFF, 0xFFFF, "AIC-7855(0x5578)"},
{0x9004, 0x5647, 0xFFFF, 0xFFFF, "ANA-7711 TCP Offload Engine(0x5647)"},
{0x9004, 0x5647, 0x9004, 0x7710, "ANA-7711F TCP Offload Engine - Optical(0x9004-0x7710)"},
{0x9004, 0x5647, 0x9004, 0x7711, "ANA-7711LP TCP Offload Engine - Copper(0x9004-0x7711)"},
{0x9004, 0x5675, 0xFFFF, 0xFFFF, "AIC-755x(0x5675)"},
{0x9004, 0x5678, 0xFFFF, 0xFFFF, "AIC-7856(0x5678)"},
{0x9004, 0x5775, 0xFFFF, 0xFFFF, "AIC-755x(0x5775)"},
{0x9004, 0x5778, 0xFFFF, 0xFFFF, "AIC-7850(0x5778)"},
{0x9004, 0x5800, 0xFFFF, 0xFFFF, "AIC-5800(0x5800)"},
{0x9004, 0x5900, 0xFFFF, 0xFFFF, "ANA-5910/5930/5940 ATM155 & 25 LAN Adapter(0x5900)"},
{0x9004, 0x5905, 0xFFFF, 0xFFFF, "ANA-5910A/5930A/5940A ATM Adapter(0x5905)"},
{0x9004, 0x6038, 0xFFFF, 0xFFFF, "AIC-3860(0x6038)"},
{0x9004, 0x6075, 0xFFFF, 0xFFFF, "AIC-1480 / APA-1480(0x6075)"},
{0x9004, 0x6075, 0x9004, 0x7560, "AIC-1480 / APA-1480 Cardbus(0x9004-0x7560)"},
{0x9004, 0x6078, 0xFFFF, 0xFFFF, "AIC-7860(0x6078)"},
{0x9004, 0x6178, 0xFFFF, 0xFFFF, "AIC-7861(0x6178)"},
{0x9004, 0x6178, 0x9004, 0x7861, "AHA-2940AU Single(0x9004-0x7861)"},
{0x9004, 0x6278, 0xFFFF, 0xFFFF, "AIC-7860(0x6278)"},
{0x9004, 0x6378, 0xFFFF, 0xFFFF, "AIC-7860(0x6378)"},
{0x9004, 0x6478, 0xFFFF, 0xFFFF, "AIC-786x(0x6478)"},
{0x9004, 0x6578, 0xFFFF, 0xFFFF, "AIC-786x(0x6578)"},
{0x9004, 0x6678, 0xFFFF, 0xFFFF, "AIC-786x(0x6678)"},
{0x9004, 0x6778, 0xFFFF, 0xFFFF, "AIC-786x(0x6778)"},
{0x9004, 0x6915, 0xFFFF, 0xFFFF, "ANA620xx/ANA69011A(0x6915)"},
{0x9004, 0x6915, 0x9004, 0x0008, "ANA69011A/TX 10/100(0x9004-0x0008)"},
{0x9004, 0x6915, 0x9004, 0x0009, "ANA69011A/TX 10/100(0x9004-0x0009)"},
{0x9004, 0x6915, 0x9004, 0x0010, "ANA62022 2-port 10/100(0x9004-0x0010)"},
{0x9004, 0x6915, 0x9004, 0x0018, "ANA62044 4-port 10/100(0x9004-0x0018)"},
{0x9004, 0x6915, 0x9004, 0x0019, "ANA62044 4-port 10/100(0x9004-0x0019)"},
{0x9004, 0x6915, 0x9004, 0x0020, "ANA62022 2-port 10/100(0x9004-0x0020)"},
{0x9004, 0x6915, 0x9004, 0x0028, "ANA69011A/TX 10/100(0x9004-0x0028)"},
{0x9004, 0x6915, 0x9004, 0x8008, "ANA69011A/TX 64 bit 10/100(0x9004-0x8008)"},
{0x9004, 0x6915, 0x9004, 0x8009, "ANA69011A/TX 64 bit 10/100(0x9004-0x8009)"},
{0x9004, 0x6915, 0x9004, 0x8010, "ANA62022 2-port 64 bit 10/100(0x9004-0x8010)"},
{0x9004, 0x6915, 0x9004, 0x8018, "ANA62044 4-port 64 bit 10/100(0x9004-0x8018)"},
{0x9004, 0x6915, 0x9004, 0x8019, "ANA62044 4-port 64 bit 10/100(0x9004-0x8019)"},
{0x9004, 0x6915, 0x9004, 0x8020, "ANA62022 2-port 64 bit 10/100(0x9004-0x8020)"},
{0x9004, 0x6915, 0x9004, 0x8028, "ANA69011A/TX 64 bit 10/100(0x9004-0x8028)"},
{0x9004, 0x7078, 0xFFFF, 0xFFFF, "AHA-294x / AIC-7870(0x7078)"},
{0x9004, 0x7178, 0xFFFF, 0xFFFF, "AIC-7870P/7871 [AHA-2940/W/S76](0x7178)"},
{0x9004, 0x7278, 0xFFFF, 0xFFFF, "AHA-3940/3940W / AIC-7872(0x7278)"},
{0x9004, 0x7378, 0xFFFF, 0xFFFF, "AHA-3985 / AIC-7873(0x7378)"},
{0x9004, 0x7478, 0xFFFF, 0xFFFF, "AHA-2944/2944W / AIC-7874(0x7478)"},
{0x9004, 0x7578, 0xFFFF, 0xFFFF, "AHA-3944/3944W / AIC-7875(0x7578)"},
{0x9004, 0x7678, 0xFFFF, 0xFFFF, "AHA-4944W/UW / AIC-7876(0x7678)"},
{0x9004, 0x7710, 0xFFFF, 0xFFFF, "ANA-7711F Network Accelerator Card (NAC) - Optical(0x7710)"},
{0x9004, 0x7711, 0xFFFF, 0xFFFF, "ANA-7711C Network Accelerator Card (NAC) - Copper(0x7711)"},
{0x9004, 0x7778, 0xFFFF, 0xFFFF, "AIC-787x(0x7778)"},
{0x9004, 0x7810, 0xFFFF, 0xFFFF, "AIC-7810(0x7810)"},
{0x9004, 0x7815, 0xFFFF, 0xFFFF, "AIC-7815 RAID+Memory Controller IC(0x7815)"},
{0x9004, 0x7815, 0x9004, 0x7815, "ARO-1130U2 RAID Controller(0x9004-0x7815)"},
{0x9004, 0x7815, 0x9004, 0x7840, "AIC-7815 RAID+Memory Controller IC(0x9004-0x7840)"},
{0x9004, 0x7850, 0xFFFF, 0xFFFF, "AIC-7850(0x7850)"},
{0x9004, 0x7855, 0xFFFF, 0xFFFF, "AHA-2930(0x7855)"},
{0x9004, 0x7860, 0xFFFF, 0xFFFF, "AIC-7860(0x7860)"},
{0x9004, 0x7870, 0xFFFF, 0xFFFF, "AIC-7870(0x7870)"},
{0x9004, 0x7871, 0xFFFF, 0xFFFF, "AHA-2940(0x7871)"},
{0x9004, 0x7872, 0xFFFF, 0xFFFF, "AHA-3940(0x7872)"},
{0x9004, 0x7873, 0xFFFF, 0xFFFF, "AHA-3980(0x7873)"},
{0x9004, 0x7874, 0xFFFF, 0xFFFF, "AHA-2944(0x7874)"},
{0x9004, 0x7880, 0xFFFF, 0xFFFF, "AIC-7880P(0x7880)"},
{0x9004, 0x7890, 0xFFFF, 0xFFFF, "AIC-7890(0x7890)"},
{0x9004, 0x7891, 0xFFFF, 0xFFFF, "AIC-789x(0x7891)"},
{0x9004, 0x7892, 0xFFFF, 0xFFFF, "AIC-789x(0x7892)"},
{0x9004, 0x7893, 0xFFFF, 0xFFFF, "AIC-789x(0x7893)"},
{0x9004, 0x7894, 0xFFFF, 0xFFFF, "AIC-789x(0x7894)"},
{0x9004, 0x7895, 0xFFFF, 0xFFFF, "AHA-2940U/UW / AHA-39xx / AIC-7895(0x7895)"},
{0x9004, 0x7895, 0x9004, 0x7890, "AHA-2940U/2940UW Dual AHA-394xAU/AUW/AUWD AIC-7895B(0x9004-0x7890)"},
{0x9004, 0x7895, 0x9004, 0x7891, "AHA-2940U/2940UW Dual(0x9004-0x7891)"},
{0x9004, 0x7895, 0x9004, 0x7892, "AHA-3940AU/AUW/AUWD/UWD(0x9004-0x7892)"},
{0x9004, 0x7895, 0x9004, 0x7894, "AHA-3944AUWD(0x9004-0x7894)"},
{0x9004, 0x7895, 0x9004, 0x7895, "AHA-2940U/2940UW Dual AHA-394xAU/AUW/AUWD AIC-7895B(0x9004-0x7895)"},
{0x9004, 0x7895, 0x9004, 0x7896, "AHA-2940U/2940UW Dual AHA-394xAU/AUW/AUWD AIC-7895B(0x9004-0x7896)"},
{0x9004, 0x7895, 0x9004, 0x7897, "AHA-2940U/2940UW Dual AHA-394xAU/AUW/AUWD AIC-7895B(0x9004-0x7897)"},
{0x9004, 0x7896, 0xFFFF, 0xFFFF, "AIC-789x(0x7896)"},
{0x9004, 0x7897, 0xFFFF, 0xFFFF, "AIC-789x(0x7897)"},
{0x9004, 0x8078, 0xFFFF, 0xFFFF, "AIC-7880U(0x8078)"},
{0x9004, 0x8078, 0x9004, 0x7880, "AIC-7880P Ultra/Ultra Wide SCSI Chipset(0x9004-0x7880)"},
{0x9004, 0x8178, 0xFFFF, 0xFFFF, "AIC-7870P/7881U [AHA-2940U/UW/D/S76](0x8178)"},
{0x9004, 0x8178, 0x9004, 0x7881, "AHA-2940UW SCSI Host Adapter(0x9004-0x7881)"},
{0x9004, 0x8278, 0xFFFF, 0xFFFF, "AHA-3940U/UW/UWD / AIC-7882U(0x8278)"},
{0x9004, 0x8378, 0xFFFF, 0xFFFF, "AHA-3940U/UW / AIC-7883U(0x8378)"},
{0x9004, 0x8478, 0xFFFF, 0xFFFF, "AHA-2944UW / AIC-7884U(0x8478)"},
{0x9004, 0x8578, 0xFFFF, 0xFFFF, "AHA-3944U/UWD / AIC-7885(0x8578)"},
{0x9004, 0x8678, 0xFFFF, 0xFFFF, "AHA-4944UW / AIC-7886(0x8678)"},
{0x9004, 0x8778, 0xFFFF, 0xFFFF, "AHA-2940UW Pro / AIC-788x(0x8778)"},
{0x9004, 0x8778, 0x9004, 0x7887, "2940UW Pro Ultra-Wide SCSI Controller(0x9004-0x7887)"},
{0x9004, 0x8878, 0xFFFF, 0xFFFF, "AHA-2930UW / AIC-7888(0x8878)"},
{0x9004, 0x8878, 0x9004, 0x7888, "AHA-2930UW SCSI Controller(0x9004-0x7888)"},
{0x9004, 0x8B78, 0xFFFF, 0xFFFF, "ABA-1030(0x8B78)"},
{0x9004, 0xEC78, 0xFFFF, 0xFFFF, "AHA-4944W/UW(0xEC78)"},
}; /* pci_vid_9004[] */

static pci_id_t const pci_vid_9005[] = {
{0x9005, 0xFFFF, 0xFFFF, 0xFFFF, "Adaptec(0x9005)"},
{0x9005, 0x0010, 0xFFFF, 0xFFFF, "AHA-2940U2/U2W(0x0010)"},
{0x9005, 0x0010, 0x9005, 0x2180, "AHA-2940U2 SCSI Controller(0x9005-0x2180)"},
{0x9005, 0x0010, 0x9005, 0x8100, "AHA-2940U2B SCSI Controller(0x9005-0x8100)"},
{0x9005, 0x0010, 0x9005, 0xA100, "AHA-2940U2B SCSI Controller(0x9005-0xA100)"},
{0x9005, 0x0010, 0x9005, 0xA180, "AIC-3860Q [AHA-2940U2W/GE] SCSI Controller(0x9005-0xA180)"},
{0x9005, 0x0010, 0x9005, 0xE100, "AHA-2950U2B SCSI Controller(0x9005-0xE100)"},
{0x9005, 0x0011, 0xFFFF, 0xFFFF, "AHA-2930U2(0x0011)"},
{0x9005, 0x0013, 0xFFFF, 0xFFFF, "78902(0x0013)"},
{0x9005, 0x0013, 0x9005, 0x0003, "AAA-131U2 Array1000 1 Channel RAID Controller(0x9005-0x0003)"},
{0x9005, 0x0013, 0x9005, 0x000F, "AIC7890_ARO(0x9005-0x000F)"},
{0x9005, 0x001F, 0xFFFF, 0xFFFF, "AHA-2940U2/U2W / 7890/7891(0x001F)"},
{0x9005, 0x001F, 0x9005, 0x000F, "2940U2W SCSI Controller(0x9005-0x000F)"},
{0x9005, 0x001F, 0x9005, 0xA180, "2940U2W SCSI Controller(0x9005-0xA180)"},
{0x9005, 0x0020, 0xFFFF, 0xFFFF, "AIC-7890(0x0020)"},
{0x9005, 0x002F, 0xFFFF, 0xFFFF, "AIC-7890(0x002F)"},
{0x9005, 0x0030, 0xFFFF, 0xFFFF, "AIC-7890(0x0030)"},
{0x9005, 0x003F, 0xFFFF, 0xFFFF, "AIC-7890(0x003F)"},
{0x9005, 0x0050, 0xFFFF, 0xFFFF, "AHA-3940U2x/395U2x(0x0050)"},
{0x9005, 0x0050, 0x9005, 0xF500, "AHA-3950U2B(0x9005-0xF500)"},
{0x9005, 0x0050, 0x9005, 0xFFFF, "AHA-3950U2B(0x9005-0xFFFF)"},
{0x9005, 0x0051, 0xFFFF, 0xFFFF, "AHA-3950U2D(0x0051)"},
{0x9005, 0x0051, 0x9005, 0xB500, "AHA-3950U2D(0x9005-0xB500)"},
{0x9005, 0x0053, 0xFFFF, 0xFFFF, "AIC-7896 SCSI Controller(0x0053)"},
{0x9005, 0x0053, 0x9005, 0xFFFF, "AIC-7896 SCSI Controller mainboard implementation(0x9005-0xFFFF)"},
{0x9005, 0x005F, 0xFFFF, 0xFFFF, "AIC-7896U2/7897U2(0x005F)"},
{0x9005, 0x0080, 0xFFFF, 0xFFFF, "AIC-7892A U160/m(0x0080)"},
{0x9005, 0x0080, 0x0E11, 0xE2A0, "Compaq 64-Bit/66MHz Wide Ultra3 SCSI Adapter(0x0E11-0xE2A0)"},
{0x9005, 0x0080, 0x9005, 0x6220, "AHA-29160C(0x9005-0x6220)"},
{0x9005, 0x0080, 0x9005, 0x62A0, "29160N Ultra160 SCSI Controller(0x9005-0x62A0)"},
{0x9005, 0x0080, 0x9005, 0xE220, "29160LP Low Profile Ultra160 SCSI Controller(0x9005-0xE220)"},
{0x9005, 0x0080, 0x9005, 0xE2A0, "29160 Ultra160 SCSI Controller(0x9005-0xE2A0)"},
{0x9005, 0x0081, 0xFFFF, 0xFFFF, "AIC-7892B U160/m(0x0081)"},
{0x9005, 0x0081, 0x9005, 0x62A1, "19160 Ultra160 SCSI Controller(0x9005-0x62A1)"},
{0x9005, 0x0083, 0xFFFF, 0xFFFF, "AIC-7892D U160/m(0x0083)"},
{0x9005, 0x008F, 0xFFFF, 0xFFFF, "AIC-7892P U160/m(0x008F)"},
{0x9005, 0x008F, 0x1179, 0x0001, "Magnia Z310(0x1179-0x0001)"},
{0x9005, 0x008F, 0x15D9, 0x9005, "Onboard SCSI Host Adapter(0x15D9-0x9005)"},
{0x9005, 0x0092, 0xFFFF, 0xFFFF, "AVC-2010 [VideoH!](0x0092)"},
{0x9005, 0x0093, 0xFFFF, 0xFFFF, "AVC-2410 [VideoH!](0x0093)"},
{0x9005, 0x00C0, 0xFFFF, 0xFFFF, "AHA-3960D / AIC-7899A U160/m(0x00C0)"},
{0x9005, 0x00C0, 0x0E11, 0xF620, "Compaq 64-Bit/66MHz Dual Channel Wide Ultra3 SCSI Adapter(0x0E11-0xF620)"},
{0x9005, 0x00C0, 0x9005, 0xF620, "AHA-3960D U160/m(0x9005-0xF620)"},
{0x9005, 0x00C1, 0xFFFF, 0xFFFF, "AIC-7899B U160/m(0x00C1)"},
{0x9005, 0x00C3, 0xFFFF, 0xFFFF, "AIC-7899D U160/m(0x00C3)"},
{0x9005, 0x00C5, 0xFFFF, 0xFFFF, "RAID subsystem HBA(0x00C5)"},
{0x9005, 0x00C5, 0x1028, 0x00C5, "PowerEdge 2400,2500,2550,4400(0x1028-0x00C5)"},
{0x9005, 0x00CF, 0xFFFF, 0xFFFF, "AIC-7899P U160/m(0x00CF)"},
{0x9005, 0x00CF, 0x1028, 0x00CE, "PowerEdge 1400(0x1028-0x00CE)"},
{0x9005, 0x00CF, 0x1028, 0x00D1, "PowerEdge 2550(0x1028-0x00D1)"},
{0x9005, 0x00CF, 0x1028, 0x00D9, "PowerEdge 2500(0x1028-0x00D9)"},
{0x9005, 0x00CF, 0x10F1, 0x2462, "Thunder K7 S2462(0x10F1-0x2462)"},
{0x9005, 0x00CF, 0x15D9, 0x9005, "Onboard SCSI Host Adapter(0x15D9-0x9005)"},
{0x9005, 0x00CF, 0x8086, 0x3411, "SDS2 Mainboard(0x8086-0x3411)"},
{0x9005, 0x0241, 0xFFFF, 0xFFFF, "Serial ATA II RAID 1420SA(0x0241)"},
{0x9005, 0x0242, 0xFFFF, 0xFFFF, "Serial ATA II RAID 1220SA(0x0242)"},
{0x9005, 0x0243, 0xFFFF, 0xFFFF, "Serial ATA II RAID 1430SA(0x0243)"},
{0x9005, 0x0244, 0xFFFF, 0xFFFF, "eSATA II RAID 1225SA(0x0244)"},
{0x9005, 0x0250, 0xFFFF, 0xFFFF, "ServeRAID Controller(0x0250)"},
{0x9005, 0x0250, 0x1014, 0x0279, "ServeRAID 6M(0x1014-0x0279)"},
{0x9005, 0x0250, 0x1014, 0x028C, "ServeRAID 6i/6i+(0x1014-0x028C)"},
{0x9005, 0x0250, 0x1014, 0x028E, "ServeRAID 7k(0x1014-0x028E)"},
{0x9005, 0x0279, 0xFFFF, 0xFFFF, "ServeRAID 6M(0x0279)"},
{0x9005, 0x0283, 0xFFFF, 0xFFFF, "AAC-RAID(0x0283)"},
{0x9005, 0x0283, 0x9005, 0x0283, "Catapult(0x9005-0x0283)"},
{0x9005, 0x0284, 0xFFFF, 0xFFFF, "AAC-RAID(0x0284)"},
{0x9005, 0x0284, 0x9005, 0x0284, "Tomcat(0x9005-0x0284)"},
{0x9005, 0x0285, 0xFFFF, 0xFFFF, "AAC-RAID(0x0285)"},
{0x9005, 0x0285, 0x0E11, 0x0295, "SATA 6Ch (Bearcat)(0x0E11-0x0295)"},
{0x9005, 0x0285, 0x1014, 0x02F2, "ServeRAID 8i(0x1014-0x02F2)"},
{0x9005, 0x0285, 0x1028, 0x0287, "PowerEdge Expandable RAID Controller 320/DC(0x1028-0x0287)"},
{0x9005, 0x0285, 0x1028, 0x0291, "CERC SATA RAID 2 PCI SATA 6ch (DellCorsair)(0x1028-0x0291)"},
{0x9005, 0x0285, 0x103C, 0x3227, "AAR-2610SA(0x103C-0x3227)"},
{0x9005, 0x0285, 0x108E, 0x0286, "Sun StorageTek SAS RAID HBA, Internal(0x108E-0x0286)"},
{0x9005, 0x0285, 0x108E, 0x0287, "STK RAID EXT(0x108E-0x0287)"},
{0x9005, 0x0285, 0x108E, 0x7AAC, "STK RAID REM(0x108E-0x7AAC)"},
{0x9005, 0x0285, 0x108E, 0x7AAE, "STK RAID EX(0x108E-0x7AAE)"},
{0x9005, 0x0285, 0x15D9, 0x02B5, "SMC AOC-USAS-S4i(0x15D9-0x02B5)"},
{0x9005, 0x0285, 0x15D9, 0x02B6, "SMC AOC-USAS-S8i(0x15D9-0x02B6)"},
{0x9005, 0x0285, 0x15D9, 0x02C9, "SMC AOC-USAS-S4iR(0x15D9-0x02C9)"},
{0x9005, 0x0285, 0x15D9, 0x02CA, "SMC AOC-USAS-S8iR(0x15D9-0x02CA)"},
{0x9005, 0x0285, 0x15D9, 0x02D2, "SMC AOC-USAS-S8i-LP(0x15D9-0x02D2)"},
{0x9005, 0x0285, 0x15D9, 0x02D3, "SMC AOC-USAS-S8iR-LP(0x15D9-0x02D3)"},
{0x9005, 0x0285, 0x17AA, 0x0286, "Legend S220 (Legend Crusader)(0x17AA-0x0286)"},
{0x9005, 0x0285, 0x17AA, 0x0287, "Legend S230 (Legend Vulcan)(0x17AA-0x0287)"},
{0x9005, 0x0285, 0x9005, 0x0285, "2200S (Vulcan)(0x9005-0x0285)"},
{0x9005, 0x0285, 0x9005, 0x0286, "2120S (Crusader)(0x9005-0x0286)"},
{0x9005, 0x0285, 0x9005, 0x0287, "2200S (Vulcan-2m)(0x9005-0x0287)"},
{0x9005, 0x0285, 0x9005, 0x0288, "3230S (Harrier)(0x9005-0x0288)"},
{0x9005, 0x0285, 0x9005, 0x0289, "3240S (Tornado)(0x9005-0x0289)"},
{0x9005, 0x0285, 0x9005, 0x028A, "ASR-2020ZCR(0x9005-0x028A)"},
{0x9005, 0x0285, 0x9005, 0x028B, "ASR-2025ZCR (Terminator)(0x9005-0x028B)"},
{0x9005, 0x0285, 0x9005, 0x028E, "ASR-2020SA (Skyhawk)(0x9005-0x028E)"},
{0x9005, 0x0285, 0x9005, 0x028F, "ASR-2025SA(0x9005-0x028F)"},
{0x9005, 0x0285, 0x9005, 0x0290, "AAR-2410SA PCI SATA 4ch (Jaguar II)(0x9005-0x0290)"},
{0x9005, 0x0285, 0x9005, 0x0292, "AAR-2810SA PCI SATA 8ch (Corsair-8)(0x9005-0x0292)"},
{0x9005, 0x0285, 0x9005, 0x0293, "AAR-21610SA PCI SATA 16ch (Corsair-16)(0x9005-0x0293)"},
{0x9005, 0x0285, 0x9005, 0x0294, "ESD SO-DIMM PCI-X SATA ZCR (Prowler)(0x9005-0x0294)"},
{0x9005, 0x0285, 0x9005, 0x0296, "ASR-2240S(0x9005-0x0296)"},
{0x9005, 0x0285, 0x9005, 0x0297, "ASR-4005SAS(0x9005-0x0297)"},
{0x9005, 0x0285, 0x9005, 0x0298, "ASR-4000(0x9005-0x0298)"},
{0x9005, 0x0285, 0x9005, 0x0299, "ASR-4800SAS(0x9005-0x0299)"},
{0x9005, 0x0285, 0x9005, 0x029A, "4805SAS(0x9005-0x029A)"},
{0x9005, 0x0285, 0x9005, 0x02A4, "ICP ICP9085LI(0x9005-0x02A4)"},
{0x9005, 0x0285, 0x9005, 0x02A5, "ICP ICP5085BR(0x9005-0x02A5)"},
{0x9005, 0x0285, 0x9005, 0x02B5, "ASR5800(0x9005-0x02B5)"},
{0x9005, 0x0285, 0x9005, 0x02B6, "ASR5805(0x9005-0x02B6)"},
{0x9005, 0x0285, 0x9005, 0x02B7, "ASR5808(0x9005-0x02B7)"},
{0x9005, 0x0285, 0x9005, 0x02B8, "ICP5445SL(0x9005-0x02B8)"},
{0x9005, 0x0285, 0x9005, 0x02B9, "ICP5085SL(0x9005-0x02B9)"},
{0x9005, 0x0285, 0x9005, 0x02BA, "ICP5805SL(0x9005-0x02BA)"},
{0x9005, 0x0285, 0x9005, 0x02BB, "3405(0x9005-0x02BB)"},
{0x9005, 0x0285, 0x9005, 0x02BC, "3805(0x9005-0x02BC)"},
{0x9005, 0x0285, 0x9005, 0x02BD, "31205(0x9005-0x02BD)"},
{0x9005, 0x0285, 0x9005, 0x02BE, "31605(0x9005-0x02BE)"},
{0x9005, 0x0285, 0x9005, 0x02BF, "ICP ICP5045BL(0x9005-0x02BF)"},
{0x9005, 0x0285, 0x9005, 0x02C0, "ICP ICP5085BL(0x9005-0x02C0)"},
{0x9005, 0x0285, 0x9005, 0x02C1, "ICP ICP5125BR(0x9005-0x02C1)"},
{0x9005, 0x0285, 0x9005, 0x02C2, "ICP ICP5165BR(0x9005-0x02C2)"},
{0x9005, 0x0285, 0x9005, 0x02C3, "51205(0x9005-0x02C3)"},
{0x9005, 0x0285, 0x9005, 0x02C4, "51605(0x9005-0x02C4)"},
{0x9005, 0x0285, 0x9005, 0x02C5, "ICP ICP5125SL(0x9005-0x02C5)"},
{0x9005, 0x0285, 0x9005, 0x02C6, "ICP ICP5165SL(0x9005-0x02C6)"},
{0x9005, 0x0285, 0x9005, 0x02C7, "3085(0x9005-0x02C7)"},
{0x9005, 0x0285, 0x9005, 0x02C8, "ICP5805BL(0x9005-0x02C8)"},
{0x9005, 0x0285, 0x9005, 0x02CE, "51245(0x9005-0x02CE)"},
{0x9005, 0x0285, 0x9005, 0x02CF, "51645(0x9005-0x02CF)"},
{0x9005, 0x0285, 0x9005, 0x02D0, "52445(0x9005-0x02D0)"},
{0x9005, 0x0285, 0x9005, 0x02D1, "5405(0x9005-0x02D1)"},
{0x9005, 0x0285, 0x9005, 0x02D4, "ASR-2045(0x9005-0x02D4)"},
{0x9005, 0x0285, 0x9005, 0x02D5, "ASR-2405(0x9005-0x02D5)"},
{0x9005, 0x0285, 0x9005, 0x02D6, "ASR-2445(0x9005-0x02D6)"},
{0x9005, 0x0285, 0x9005, 0x02D7, "ASR-2805(0x9005-0x02D7)"},
{0x9005, 0x0285, 0x9005, 0x02D8, "5405G(0x9005-0x02D8)"},
{0x9005, 0x0285, 0x9005, 0x02D9, "5445G(0x9005-0x02D9)"},
{0x9005, 0x0285, 0x9005, 0x02DA, "5805G(0x9005-0x02DA)"},
{0x9005, 0x0285, 0x9005, 0x02DB, "5085G(0x9005-0x02DB)"},
{0x9005, 0x0285, 0x9005, 0x02DC, "51245G(0x9005-0x02DC)"},
{0x9005, 0x0285, 0x9005, 0x02DD, "51645G(0x9005-0x02DD)"},
{0x9005, 0x0285, 0x9005, 0x02DE, "52445G(0x9005-0x02DE)"},
{0x9005, 0x0285, 0x9005, 0x02DF, "ASR-2045G(0x9005-0x02DF)"},
{0x9005, 0x0285, 0x9005, 0x02E0, "ASR-2405G(0x9005-0x02E0)"},
{0x9005, 0x0285, 0x9005, 0x02E1, "ASR-2445G(0x9005-0x02E1)"},
{0x9005, 0x0285, 0x9005, 0x02E2, "ASR-2805G(0x9005-0x02E2)"},
{0x9005, 0x0286, 0xFFFF, 0xFFFF, "AAC-RAID (Rocket)(0x0286)"},
{0x9005, 0x0286, 0x1014, 0x034D, "8s(0x1014-0x034D)"},
{0x9005, 0x0286, 0x1014, 0x9540, "ServeRAID 8k/8k-l4(0x1014-0x9540)"},
{0x9005, 0x0286, 0x1014, 0x9580, "ServeRAID 8k/8k-l8(0x1014-0x9580)"},
{0x9005, 0x0286, 0x9005, 0x028C, "ASR-2230S + ASR-2230SLP PCI-X (Lancer)(0x9005-0x028C)"},
{0x9005, 0x0286, 0x9005, 0x028D, "ASR-2130S(0x9005-0x028D)"},
{0x9005, 0x0286, 0x9005, 0x029B, "ASR-2820SA(0x9005-0x029B)"},
{0x9005, 0x0286, 0x9005, 0x029C, "ASR-2620SA(0x9005-0x029C)"},
{0x9005, 0x0286, 0x9005, 0x029D, "ASR-2420SA(0x9005-0x029D)"},
{0x9005, 0x0286, 0x9005, 0x029E, "ICP ICP9024R0(0x9005-0x029E)"},
{0x9005, 0x0286, 0x9005, 0x029F, "ICP ICP9014R0(0x9005-0x029F)"},
{0x9005, 0x0286, 0x9005, 0x02A0, "ICP ICP9047MA(0x9005-0x02A0)"},
{0x9005, 0x0286, 0x9005, 0x02A1, "ICP ICP9087MA(0x9005-0x02A1)"},
{0x9005, 0x0286, 0x9005, 0x02A2, "3800(0x9005-0x02A2)"},
{0x9005, 0x0286, 0x9005, 0x02A3, "ICP ICP5445AU(0x9005-0x02A3)"},
{0x9005, 0x0286, 0x9005, 0x02A4, "ICP ICP9085LI(0x9005-0x02A4)"},
{0x9005, 0x0286, 0x9005, 0x02A5, "ICP ICP5085BR(0x9005-0x02A5)"},
{0x9005, 0x0286, 0x9005, 0x02A6, "ICP9067MA(0x9005-0x02A6)"},
{0x9005, 0x0286, 0x9005, 0x02A7, "3805(0x9005-0x02A7)"},
{0x9005, 0x0286, 0x9005, 0x02A8, "3400(0x9005-0x02A8)"},
{0x9005, 0x0286, 0x9005, 0x02A9, "ICP ICP5085AU(0x9005-0x02A9)"},
{0x9005, 0x0286, 0x9005, 0x02AA, "ICP ICP5045AU(0x9005-0x02AA)"},
{0x9005, 0x0286, 0x9005, 0x02AC, "1800(0x9005-0x02AC)"},
{0x9005, 0x0286, 0x9005, 0x02B3, "2400(0x9005-0x02B3)"},
{0x9005, 0x0286, 0x9005, 0x02B4, "ICP ICP5045AL(0x9005-0x02B4)"},
{0x9005, 0x0286, 0x9005, 0x0800, "Callisto(0x9005-0x0800)"},
{0x9005, 0x028B, 0xFFFF, 0xFFFF, "Series 6 - 6G SAS/PCIe 2(0x028B)"},
{0x9005, 0x028B, 0x9005, 0x0200, "Series 6 Entry Level - ASR-6405E - 4 internal 6G SAS ports(0x9005-0x0200)"},
{0x9005, 0x028B, 0x9005, 0x0201, "Series 6 Entry Level - ASR-6805E - 8 internal 6G SAS ports(0x9005-0x0201)"},
{0x9005, 0x028B, 0x9005, 0x0300, "Series 6 - ASR-6405 - 4 internal 6G SAS ports(0x9005-0x0300)"},
{0x9005, 0x028B, 0x9005, 0x0301, "Series 6 - ASR-6805 - 8 internal 6G SAS ports(0x9005-0x0301)"},
{0x9005, 0x028B, 0x9005, 0x0302, "Series 6 - ASR-6445 - 4 internal and 4 external 6G SAS ports(0x9005-0x0302)"},
{0x9005, 0x028B, 0x9005, 0x0310, "Series 6 Connectors on Top - ASR-6405T - 4 internal 6G SAS ports(0x9005-0x0310)"},
{0x9005, 0x028B, 0x9005, 0x0311, "Series 6 Connectors on Top - ASR-6805T - 8 internal 6G SAS(0x9005-0x0311)"},
{0x9005, 0x028B, 0x9005, 0x0400, "Series 6 - ASR-61205 - 12 internal 6G SAS ports(0x9005-0x0400)"},
{0x9005, 0x028B, 0x9005, 0x0401, "Series 6 - ASR-61605 - 16 internal 6G SAS ports(0x9005-0x0401)"},
{0x9005, 0x028B, 0x9005, 0x0403, "Series 6 - ASR-62405 - 24 internal 6G SAS ports(0x9005-0x0403)"},
{0x9005, 0x028C, 0xFFFF, 0xFFFF, "Series 7 6G SAS/PCIe 3(0x028C)"},
{0x9005, 0x028C, 0x9005, 0x0500, "Series 7 - ASR-7805 - 8 internal 6G SAS Port/PCIe 3.0(0x9005-0x0500)"},
{0x9005, 0x028C, 0x9005, 0x0501, "Series 7 - ASR-71605 - 16 internal 6G SAS Port/PCIe 3.0(0x9005-0x0501)"},
{0x9005, 0x028C, 0x9005, 0x0502, "Series 7 - ASR-71685 - 16 internal 8 external 6G SAS Port/PCIe 3.0(0x9005-0x0502)"},
{0x9005, 0x028C, 0x9005, 0x0503, "Series 7 - ASR-72405 - 24 internal 0 external 6G SAS Port/PCIe 3.0(0x9005-0x0503)"},
{0x9005, 0x028C, 0x9005, 0x0504, "Series 7 - ASR-7885 - 8 internal 8 external 6G SAS Port/PCIe 3.0(0x9005-0x0504)"},
{0x9005, 0x028C, 0x9005, 0x0505, "Series 7 Entry Level - ASR-71685E - 16 internal 8 external 6G SAS Port/PCIe 3.0(0x9005-0x0505)"},
{0x9005, 0x028C, 0x9005, 0x0506, "Series 7 Entry Level - ASR-72405E - 24 internal 0 external 6G SAS Port/PCIe 3.0(0x9005-0x0506)"},
{0x9005, 0x028D, 0xFFFF, 0xFFFF, "Series 8 12G SAS/PCIe 3(0x028D)"},
{0x9005, 0x028D, 0x9005, 0x0550, "Series 8 - ASR-82405 - 24 internal 0 external 12G SAS Port/PCIe 3.0(0x9005-0x0550)"},
{0x9005, 0x028D, 0x9005, 0x0551, "Series 8 - ASR-81605 - 16 internal 0 external 12G SAS Port/PCIe 3.0(0x9005-0x0551)"},
{0x9005, 0x028D, 0x9005, 0x0552, "Series 8 - ASR-8805 - 8 internal 0 external 12G SAS Port/PCIe 3.0(0x9005-0x0552)"},
{0x9005, 0x028D, 0x9005, 0x0553, "Series 8 - ASR-8085 - 0 internal 8 external 12G SAS Port/PCIe 3.0(0x9005-0x0553)"},
{0x9005, 0x028D, 0x9005, 0x0554, "Series 8 - ASR-8885 - 8 internal 8 external 12G SAS Port/PCIe 3.0(0x9005-0x0554)"},
{0x9005, 0x028F, 0xFFFF, 0xFFFF, "Smart Storage PQI SAS(0x028F)"},
{0x9005, 0x028F, 0x103C, 0x0600, "Smart Array P408i-p SR Gen10(0x103C-0x0600)"},
{0x9005, 0x028F, 0x103C, 0x0601, "Smart Array P408e-p SR Gen10(0x103C-0x0601)"},
{0x9005, 0x028F, 0x103C, 0x0602, "Smart Array P408i-a SR Gen10(0x103C-0x0602)"},
{0x9005, 0x028F, 0x103C, 0x0603, "Smart Array P408i-c SR Gen10(0x103C-0x0603)"},
{0x9005, 0x028F, 0x103C, 0x0650, "Smart Array E208i-p SR Gen10(0x103C-0x0650)"},
{0x9005, 0x028F, 0x103C, 0x0651, "Smart Array E208e-p SR Gen10(0x103C-0x0651)"},
{0x9005, 0x028F, 0x103C, 0x0652, "Smart Array E208i-c SR Gen10(0x103C-0x0652)"},
{0x9005, 0x028F, 0x103C, 0x0654, "Smart Array E208i-a SR Gen10(0x103C-0x0654)"},
{0x9005, 0x028F, 0x103C, 0x0655, "Smart Array P408e-m SR Gen10(0x103C-0x0655)"},
{0x9005, 0x028F, 0x103C, 0x0700, "Smart Array P204i-c SR Gen10(0x103C-0x0700)"},
{0x9005, 0x028F, 0x103C, 0x0701, "Smart Array P204i-b SR Gen10(0x103C-0x0701)"},
{0x9005, 0x028F, 0x103C, 0x1100, "Smart Array P816i-a SR Gen10(0x103C-0x1100)"},
{0x9005, 0x028F, 0x103C, 0x1101, "Smart Array P416ie-m SR G10(0x103C-0x1101)"},
{0x9005, 0x028F, 0x105B, 0x1211, "HBA 8238-16i(0x105B-0x1211)"},
{0x9005, 0x028F, 0x105B, 0x1321, "HBA 8242-24i(0x105B-0x1321)"},
{0x9005, 0x028F, 0x1137, 0x02F8, "24G TriMode M1 RAID 4GB FBWC 32D(0x1137-0x02F8)"},
{0x9005, 0x028F, 0x1137, 0x02F9, "24G TriMode M1 RAID 4GB FBWC 16D(0x1137-0x02F9)"},
{0x9005, 0x028F, 0x1137, 0x02FA, "24G TriMode M1 HBA 16D(0x1137-0x02FA)"},
{0x9005, 0x028F, 0x13FE, 0x8312, "SKY-9200 MIC-8312BridgeB(0x13FE-0x8312)"},
{0x9005, 0x028F, 0x152D, 0x8A22, "QS-8204-8i(0x152D-0x8A22)"},
{0x9005, 0x028F, 0x152D, 0x8A23, "QS-8238-16i(0x152D-0x8A23)"},
{0x9005, 0x028F, 0x152D, 0x8A24, "QS-8236-16i(0x152D-0x8A24)"},
{0x9005, 0x028F, 0x152D, 0x8A36, "QS-8240-24i(0x152D-0x8A36)"},
{0x9005, 0x028F, 0x152D, 0x8A37, "QS-8242-24i(0x152D-0x8A37)"},
{0x9005, 0x028F, 0x1590, 0x0294, "SR932i-p Gen10+(0x1590-0x0294)"},
{0x9005, 0x028F, 0x1590, 0x02DC, "SR416i-a Gen10+(0x1590-0x02DC)"},
{0x9005, 0x028F, 0x193D, 0x1104, "RAID P2404-Mf-4i-2GB(0x193D-0x1104)"},
{0x9005, 0x028F, 0x193D, 0x1105, "RAID P4408-Mf-8i-2GB(0x193D-0x1105)"},
{0x9005, 0x028F, 0x193D, 0x1106, "RAID P2404-Mf-4i-1GB(0x193D-0x1106)"},
{0x9005, 0x028F, 0x193D, 0x1107, "RAID P4408-Mf-8i-4GB(0x193D-0x1107)"},
{0x9005, 0x028F, 0x193D, 0x8460, "HBA H460-M1(0x193D-0x8460)"},
{0x9005, 0x028F, 0x193D, 0x8461, "HBA H460-B1(0x193D-0x8461)"},
{0x9005, 0x028F, 0x193D, 0xC460, "RAID P460-M2(0x193D-0xC460)"},
{0x9005, 0x028F, 0x193D, 0xC461, "RAID P460-B2(0x193D-0xC461)"},
{0x9005, 0x028F, 0x193D, 0xF460, "RAID P460-M4(0x193D-0xF460)"},
{0x9005, 0x028F, 0x193D, 0xF461, "RAID P460-B4(0x193D-0xF461)"},
{0x9005, 0x028F, 0x19E5, 0xD227, "SmartROC-HD SR465C-M 4G(0x19E5-0xD227)"},
{0x9005, 0x028F, 0x19E5, 0xD228, "SmartROC SR455C-M 2G(0x19E5-0xD228)"},
{0x9005, 0x028F, 0x19E5, 0xD229, "SmartIOC SR155-M(0x19E5-0xD229)"},
{0x9005, 0x028F, 0x19E5, 0xD22A, "SmartIOC-HD SR765-M(0x19E5-0xD22A)"},
{0x9005, 0x028F, 0x19E5, 0xD22B, "SmartROC-e SR455C-ME 4G(0x19E5-0xD22B)"},
{0x9005, 0x028F, 0x19E5, 0xD22C, "SmartROC SR455C-M 4G(0x19E5-0xD22C)"},
{0x9005, 0x028F, 0x1BD4, 0x0045, "SMART-HBA 8242-24i(0x1BD4-0x0045)"},
{0x9005, 0x028F, 0x1BD4, 0x0046, "RAID 8236-16i(0x1BD4-0x0046)"},
{0x9005, 0x028F, 0x1BD4, 0x0047, "RAID 8240-24i(0x1BD4-0x0047)"},
{0x9005, 0x028F, 0x1BD4, 0x0048, "SMART-HBA 8238-16i(0x1BD4-0x0048)"},
{0x9005, 0x028F, 0x1BD4, 0x004A, "PM8222-SHBA(0x1BD4-0x004A)"},
{0x9005, 0x028F, 0x1BD4, 0x004B, "RAID PM8204-2GB(0x1BD4-0x004B)"},
{0x9005, 0x028F, 0x1BD4, 0x004C, "RAID PM8204-4GB(0x1BD4-0x004C)"},
{0x9005, 0x028F, 0x1BD4, 0x004F, "PM8222-HBA(0x1BD4-0x004F)"},
{0x9005, 0x028F, 0x1BD4, 0x006B, "RS0800M5H24I(0x1BD4-0x006B)"},
{0x9005, 0x028F, 0x1BD4, 0x006C, "RS0800M5E8i(0x1BD4-0x006C)"},
{0x9005, 0x028F, 0x1BD4, 0x006D, "RS0800M5H8i(0x1BD4-0x006D)"},
{0x9005, 0x028F, 0x1BD4, 0x006F, "RS0804M5R16i(0x1BD4-0x006F)"},
{0x9005, 0x028F, 0x1BD4, 0x0070, "RS0800M5E24i(0x1BD4-0x0070)"},
{0x9005, 0x028F, 0x1BD4, 0x0071, "RS0800M5H16i(0x1BD4-0x0071)"},
{0x9005, 0x028F, 0x1BD4, 0x0072, "RS0800M5E16i(0x1BD4-0x0072)"},
{0x9005, 0x028F, 0x1BD4, 0x0077, "RS0800M5E16iM(0x1BD4-0x0077)"},
{0x9005, 0x028F, 0x1BD4, 0x0078, "RS0800M5E24iM(0x1BD4-0x0078)"},
{0x9005, 0x028F, 0x1BD4, 0x0079, "RS0800M5H24iM(0x1BD4-0x0079)"},
{0x9005, 0x028F, 0x1BD4, 0x0080, "RS0804M5R16iM(0x1BD4-0x0080)"},
{0x9005, 0x028F, 0x1BD4, 0x0086, "RT0800M7E(0x1BD4-0x0086)"},
{0x9005, 0x028F, 0x1BD4, 0x0087, "RT0800M7H(0x1BD4-0x0087)"},
{0x9005, 0x028F, 0x1BD4, 0x0088, "RT0804M7R(0x1BD4-0x0088)"},
{0x9005, 0x028F, 0x1BD4, 0x0089, "RT0808M7R(0x1BD4-0x0089)"},
{0x9005, 0x028F, 0x1CC4, 0x0101, "Ramaxel FBGF-RAD PM8204(0x1CC4-0x0101)"},
{0x9005, 0x028F, 0x1CC4, 0x0201, "Ramaxel FBGF-RAD PM8222(0x1CC4-0x0201)"},
{0x9005, 0x028F, 0x1D49, 0x0220, "ThinkSystem 4350-8i SAS/SATA 12Gb HBA(0x1D49-0x0220)"},
{0x9005, 0x028F, 0x1D49, 0x0221, "ThinkSystem 4350-16i SAS/SATA 12Gb HBA(0x1D49-0x0221)"},
{0x9005, 0x028F, 0x1D49, 0x0520, "ThinkSystem RAID 5350-8i PCIe 12Gb Adapter(0x1D49-0x0520)"},
{0x9005, 0x028F, 0x1D49, 0x0522, "ThinkSystem RAID 5350-8i PCIe 12Gb Internal Adapter(0x1D49-0x0522)"},
{0x9005, 0x028F, 0x1D49, 0x0620, "ThinkSystem RAID 9350-8i 2GB Flash PCIe 12Gb Adapter(0x1D49-0x0620)"},
{0x9005, 0x028F, 0x1D49, 0x0621, "ThinkSystem RAID 9350-8i 2GB Flash PCIe 12Gb Internal Adapter(0x1D49-0x0621)"},
{0x9005, 0x028F, 0x1D49, 0x0622, "ThinkSystem RAID 9350-16i 4GB Flash PCIe 12Gb Adapter(0x1D49-0x0622)"},
{0x9005, 0x028F, 0x1D49, 0x0623, "ThinkSystem RAID 9350-16i 4GB Flash PCIe 12Gb Internal Adapter(0x1D49-0x0623)"},
{0x9005, 0x028F, 0x9005, 0x0608, "SmartRAID 3162-8i /e(0x9005-0x0608)"},
{0x9005, 0x028F, 0x9005, 0x0800, "SmartRAID 3154-8i(0x9005-0x0800)"},
{0x9005, 0x028F, 0x9005, 0x0801, "SmartRAID 3152-8i(0x9005-0x0801)"},
{0x9005, 0x028F, 0x9005, 0x0802, "SmartRAID 3151-4i(0x9005-0x0802)"},
{0x9005, 0x028F, 0x9005, 0x0803, "SmartRAID 3101-4i(0x9005-0x0803)"},
{0x9005, 0x028F, 0x9005, 0x0804, "SmartRAID 3154-8e(0x9005-0x0804)"},
{0x9005, 0x028F, 0x9005, 0x0805, "SmartRAID 3102-8i(0x9005-0x0805)"},
{0x9005, 0x028F, 0x9005, 0x0806, "SmartRAID 3100(0x9005-0x0806)"},
{0x9005, 0x028F, 0x9005, 0x0807, "SmartRAID 3162-8i(0x9005-0x0807)"},
{0x9005, 0x028F, 0x9005, 0x0808, "SmartRAID 3101E-4i(0x9005-0x0808)"},
{0x9005, 0x028F, 0x9005, 0x0809, "SmartRAID 3102E-8i(0x9005-0x0809)"},
{0x9005, 0x028F, 0x9005, 0x0900, "SmartHBA 2100-8i(0x9005-0x0900)"},
{0x9005, 0x028F, 0x9005, 0x0901, "SmartHBA 2100-4i(0x9005-0x0901)"},
{0x9005, 0x028F, 0x9005, 0x0902, "HBA 1100-8i(0x9005-0x0902)"},
{0x9005, 0x028F, 0x9005, 0x0903, "HBA 1100-4i(0x9005-0x0903)"},
{0x9005, 0x028F, 0x9005, 0x0904, "SmartHBA 2100-8e(0x9005-0x0904)"},
{0x9005, 0x028F, 0x9005, 0x0905, "HBA 1100-8e(0x9005-0x0905)"},
{0x9005, 0x028F, 0x9005, 0x0906, "SmartHBA 2100-4i4e(0x9005-0x0906)"},
{0x9005, 0x028F, 0x9005, 0x0907, "HBA 1100(0x9005-0x0907)"},
{0x9005, 0x028F, 0x9005, 0x0908, "SmartHBA 2100(0x9005-0x0908)"},
{0x9005, 0x028F, 0x9005, 0x090A, "SmartHBA 2100A-8i(0x9005-0x090A)"},
{0x9005, 0x028F, 0x9005, 0x1200, "SmartRAID 3154-24i(0x9005-0x1200)"},
{0x9005, 0x028F, 0x9005, 0x1201, "SmartRAID 3154-8i16e(0x9005-0x1201)"},
{0x9005, 0x028F, 0x9005, 0x1202, "SmartRAID 3154-8i8e(0x9005-0x1202)"},
{0x9005, 0x028F, 0x9005, 0x1280, "HBA 1100-16i(0x9005-0x1280)"},
{0x9005, 0x028F, 0x9005, 0x1281, "HBA 1100-16e(0x9005-0x1281)"},
{0x9005, 0x028F, 0x9005, 0x1282, "SmartHBA 2100-16i(0x9005-0x1282)"},
{0x9005, 0x028F, 0x9005, 0x1300, "HBA 1100-8i8e(0x9005-0x1300)"},
{0x9005, 0x028F, 0x9005, 0x1301, "HBA 1100-24i(0x9005-0x1301)"},
{0x9005, 0x028F, 0x9005, 0x1302, "SmartHBA 2100-8i8e(0x9005-0x1302)"},
{0x9005, 0x028F, 0x9005, 0x1303, "SmartHBA 2100-24i(0x9005-0x1303)"},
{0x9005, 0x028F, 0x9005, 0x1380, "SmartRAID 3154-16i(0x9005-0x1380)"},
{0x9005, 0x028F, 0x9005, 0x1400, "SmartRAID Ultra 3258p-16i /e(0x9005-0x1400)"},
{0x9005, 0x028F, 0x9005, 0x1402, "HBA Ultra 1200p-16i(0x9005-0x1402)"},
{0x9005, 0x028F, 0x9005, 0x1410, "HBA Ultra 1200-16e(0x9005-0x1410)"},
{0x9005, 0x028F, 0x9005, 0x1430, "SmartRAID Ultra 3254-16e /e(0x9005-0x1430)"},
{0x9005, 0x028F, 0x9005, 0x1441, "HBA Ultra 1200p-32i(0x9005-0x1441)"},
{0x9005, 0x028F, 0x9005, 0x1450, "SmartRAID Ultra 3258p-32i /e(0x9005-0x1450)"},
{0x9005, 0x028F, 0x9005, 0x1462, "HBA 1200-8i(0x9005-0x1462)"},
{0x9005, 0x028F, 0x9005, 0x1471, "SmartRAID 3254-16i /e(0x9005-0x1471)"},
{0x9005, 0x028F, 0x9005, 0x1472, "SmartRAID 3258-16i /e(0x9005-0x1472)"},
{0x9005, 0x028F, 0x9005, 0x1475, "SmartRAID 3254-16e /e(0x9005-0x1475)"},
{0x9005, 0x028F, 0x9005, 0x14A0, "SmartRAID 3254-8i(0x9005-0x14A0)"},
{0x9005, 0x028F, 0x9005, 0x14A1, "SmartRAID 3204-8i(0x9005-0x14A1)"},
{0x9005, 0x028F, 0x9005, 0x14A2, "SmartRAID 3252-8i(0x9005-0x14A2)"},
{0x9005, 0x028F, 0x9005, 0x14A4, "SmartRAID 3254-8i /e(0x9005-0x14A4)"},
{0x9005, 0x028F, 0x9005, 0x14A5, "SmartRAID 3252-8i /e(0x9005-0x14A5)"},
{0x9005, 0x028F, 0x9005, 0x14A6, "SmartRAID 3204-8i /e(0x9005-0x14A6)"},
{0x9005, 0x028F, 0x9005, 0x14C0, "SmartHBA 2200-16i(0x9005-0x14C0)"},
{0x9005, 0x028F, 0x9005, 0x14C1, "HBA 1200-16i(0x9005-0x14C1)"},
{0x9005, 0x028F, 0x9005, 0x14C3, "HBA 1200-16e(0x9005-0x14C3)"},
{0x9005, 0x028F, 0x9005, 0x14C4, "HBA 1200-8e(0x9005-0x14C4)"},
{0x9005, 0x0410, 0xFFFF, 0xFFFF, "AIC-9410W SAS (Razor HBA RAID)(0x0410)"},
{0x9005, 0x0410, 0x9005, 0x0410, "ASC-48300(Spirit RAID)(0x9005-0x0410)"},
{0x9005, 0x0410, 0x9005, 0x0411, "ASC-58300 (Oakmont RAID)(0x9005-0x0411)"},
{0x9005, 0x0412, 0xFFFF, 0xFFFF, "AIC-9410W SAS (Razor HBA non-RAID)(0x0412)"},
{0x9005, 0x0412, 0x9005, 0x0412, "ASC-48300 (Spirit non-RAID)(0x9005-0x0412)"},
{0x9005, 0x0412, 0x9005, 0x0413, "ASC-58300 (Oakmont non-RAID)(0x9005-0x0413)"},
{0x9005, 0x0415, 0xFFFF, 0xFFFF, "ASC-58300 SAS (Razor-External HBA RAID)(0x0415)"},
{0x9005, 0x0416, 0xFFFF, 0xFFFF, "ASC-58300 SAS (Razor-External HBA non-RAID)(0x0416)"},
{0x9005, 0x041E, 0xFFFF, 0xFFFF, "AIC-9410W SAS (Razor ASIC non-RAID)(0x041E)"},
{0x9005, 0x041F, 0xFFFF, 0xFFFF, "AIC-9410W SAS (Razor ASIC RAID)(0x041F)"},
{0x9005, 0x041F, 0x9005, 0x041F, "AIC-9410W SAS (Razor ASIC RAID)(0x9005-0x041F)"},
{0x9005, 0x042F, 0xFFFF, 0xFFFF, "VSC7250/7251 SAS (Aurora ASIC non-RAID)(0x042F)"},
{0x9005, 0x0430, 0xFFFF, 0xFFFF, "AIC-9405W SAS (Razor-Lite HBA RAID)(0x0430)"},
{0x9005, 0x0430, 0x9005, 0x0430, "ASC-44300 (Spirit-Lite RAID)(0x9005-0x0430)"},
{0x9005, 0x0432, 0xFFFF, 0xFFFF, "AIC-9405W SAS (Razor-Lite HBA non-RAID)(0x0432)"},
{0x9005, 0x0432, 0x9005, 0x0432, "ASC-44300 (Spirit-Lite non-RAID)(0x9005-0x0432)"},
{0x9005, 0x043E, 0xFFFF, 0xFFFF, "AIC-9405W SAS (Razor-Lite ASIC non-RAID)(0x043E)"},
{0x9005, 0x043F, 0xFFFF, 0xFFFF, "AIC-9405W SAS (Razor-Lite ASIC RAID)(0x043F)"},
{0x9005, 0x0450, 0xFFFF, 0xFFFF, "ASC-1405 Unified Serial HBA(0x0450)"},
{0x9005, 0x0500, 0xFFFF, 0xFFFF, "Obsidian chipset SCSI controller(0x0500)"},
{0x9005, 0x0500, 0x1014, 0x02C1, "PCI-X DDR 3Gb SAS Adapter (572A/572C)(0x1014-0x02C1)"},
{0x9005, 0x0500, 0x1014, 0x02C2, "PCI-X DDR 3Gb SAS RAID Adapter (572B/572D)(0x1014-0x02C2)"},
{0x9005, 0x0503, 0xFFFF, 0xFFFF, "Scamp chipset SCSI controller(0x0503)"},
{0x9005, 0x0503, 0x1014, 0x02BF, "Quad Channel PCI-X DDR U320 SCSI RAID Adapter (571E)(0x1014-0x02BF)"},
{0x9005, 0x0503, 0x1014, 0x02C3, "PCI-X DDR 3Gb SAS RAID Adapter (572F)(0x1014-0x02C3)"},
{0x9005, 0x0503, 0x1014, 0x02D5, "Quad Channel PCI-X DDR U320 SCSI RAID Adapter (571F)(0x1014-0x02D5)"},
{0x9005, 0x0910, 0xFFFF, 0xFFFF, "AUA-3100B(0x0910)"},
{0x9005, 0x091E, 0xFFFF, 0xFFFF, "AUA-3100B(0x091E)"},
{0x9005, 0x8000, 0xFFFF, 0xFFFF, "ASC-29320A U320(0x8000)"},
{0x9005, 0x800F, 0xFFFF, 0xFFFF, "AIC-7901 U320(0x800F)"},
{0x9005, 0x8010, 0xFFFF, 0xFFFF, "ASC-39320 U320(0x8010)"},
{0x9005, 0x8011, 0xFFFF, 0xFFFF, "ASC-39320D(0x8011)"},
{0x9005, 0x8011, 0x0E11, 0x00AC, "ASC-39320D U320(0x0E11-0x00AC)"},
{0x9005, 0x8011, 0x9005, 0x0041, "ASC-39320D U320(0x9005-0x0041)"},
{0x9005, 0x8012, 0xFFFF, 0xFFFF, "ASC-29320 U320(0x8012)"},
{0x9005, 0x8013, 0xFFFF, 0xFFFF, "ASC-29320B U320(0x8013)"},
{0x9005, 0x8014, 0xFFFF, 0xFFFF, "ASC-29320LP U320(0x8014)"},
{0x9005, 0x8015, 0xFFFF, 0xFFFF, "ASC-39320B U320(0x8015)"},
{0x9005, 0x8016, 0xFFFF, 0xFFFF, "ASC-39320A U320(0x8016)"},
{0x9005, 0x8017, 0xFFFF, 0xFFFF, "ASC-29320ALP U320(0x8017)"},
{0x9005, 0x8017, 0x9005, 0x0044, "ASC-29320ALP PCIx U320(0x9005-0x0044)"},
{0x9005, 0x8017, 0x9005, 0x0045, "ASC-29320LPE PCIe U320(0x9005-0x0045)"},
{0x9005, 0x801C, 0xFFFF, 0xFFFF, "ASC-39320D U320(0x801C)"},
{0x9005, 0x801D, 0xFFFF, 0xFFFF, "AIC-7902B U320(0x801D)"},
{0x9005, 0x801D, 0x1014, 0x02CC, "ServeRAID 7e(0x1014-0x02CC)"},
{0x9005, 0x801E, 0xFFFF, 0xFFFF, "AIC-7901A U320(0x801E)"},
{0x9005, 0x801F, 0xFFFF, 0xFFFF, "AIC-7902 U320(0x801F)"},
{0x9005, 0x801F, 0x1734, 0x1011, "PRIMERGY RX300 onboard SCSI(0x1734-0x1011)"},
{0x9005, 0x8080, 0xFFFF, 0xFFFF, "ASC-29320A U320 w/HostRAID(0x8080)"},
{0x9005, 0x8081, 0xFFFF, 0xFFFF, "PMC-Sierra PM8001 SAS HBA [Series 6H](0x8081)"},
{0x9005, 0x8081, 0x9005, 0x0400, "Adaptec SAS HBA 6405H(0x9005-0x0400)"},
{0x9005, 0x8081, 0x9005, 0x0800, "Adaptec SAS HBA 6805H(0x9005-0x0800)"},
{0x9005, 0x8088, 0xFFFF, 0xFFFF, "PMC-Sierra PM8018 SAS HBA [Series 7H](0x8088)"},
{0x9005, 0x8088, 0x9005, 0x0008, "Adaptec SAS HBA 7085H(0x9005-0x0008)"},
{0x9005, 0x8088, 0x9005, 0x0016, "Adaptec SAS HBA 70165H(0x9005-0x0016)"},
{0x9005, 0x8088, 0x9005, 0x0800, "Adaptec SAS HBA 7805H(0x9005-0x0800)"},
{0x9005, 0x8088, 0x9005, 0x1600, "Adaptec SAS HBA 71605H(0x9005-0x1600)"},
{0x9005, 0x8089, 0xFFFF, 0xFFFF, "PMC-Sierra PM8019 SAS encryption HBA [Series 7He](0x8089)"},
{0x9005, 0x808F, 0xFFFF, 0xFFFF, "AIC-7901 U320 w/HostRAID(0x808F)"},
{0x9005, 0x808F, 0x1028, 0x0168, "Precision Workstation 670 Mainboard(0x1028-0x0168)"},
{0x9005, 0x8090, 0xFFFF, 0xFFFF, "ASC-39320 U320 w/HostRAID(0x8090)"},
{0x9005, 0x8091, 0xFFFF, 0xFFFF, "ASC-39320D U320 w/HostRAID(0x8091)"},
{0x9005, 0x8092, 0xFFFF, 0xFFFF, "ASC-29320 U320 w/HostRAID(0x8092)"},
{0x9005, 0x8093, 0xFFFF, 0xFFFF, "ASC-29320B U320 w/HostRAID(0x8093)"},
{0x9005, 0x8094, 0xFFFF, 0xFFFF, "ASC-29320LP U320 w/HostRAID(0x8094)"},
{0x9005, 0x8095, 0xFFFF, 0xFFFF, "ASC-39320(B) U320 w/HostRAID(0x8095)"},
{0x9005, 0x8096, 0xFFFF, 0xFFFF, "ASC-39320A U320 w/HostRAID(0x8096)"},
{0x9005, 0x8097, 0xFFFF, 0xFFFF, "ASC-29320ALP U320 w/HostRAID(0x8097)"},
{0x9005, 0x809C, 0xFFFF, 0xFFFF, "ASC-39320D(B) U320 w/HostRAID(0x809C)"},
{0x9005, 0x809D, 0xFFFF, 0xFFFF, "AIC-7902(B) U320 w/HostRAID(0x809D)"},
{0x9005, 0x809D, 0x1014, 0x02CC, "ServeRAID 7e(0x1014-0x02CC)"},
{0x9005, 0x809E, 0xFFFF, 0xFFFF, "AIC-7901A U320 w/HostRAID(0x809E)"},
{0x9005, 0x809F, 0xFFFF, 0xFFFF, "AIC-7902 U320 w/HostRAID(0x809F)"},
}; /* pci_vid_9005[] */

static pci_id_t const pci_vid_907F[] = {
{0x907F, 0xFFFF, 0xFFFF, 0xFFFF, "Atronics(0x907F)"},
{0x907F, 0x2015, 0xFFFF, 0xFFFF, "IDE-2015PL(0x2015)"},
}; /* pci_vid_907F[] */

static pci_id_t const pci_vid_919A[] = {
{0x919A, 0xFFFF, 0xFFFF, 0xFFFF, "Gigapixel Corp(0x919A)"},
}; /* pci_vid_919A[] */

static pci_id_t const pci_vid_9412[] = {
{0x9412, 0xFFFF, 0xFFFF, 0xFFFF, "Holtek(0x9412)"},
{0x9412, 0x6565, 0xFFFF, 0xFFFF, "6565(0x6565)"},
}; /* pci_vid_9412[] */

static pci_id_t const pci_vid_9413[] = {
{0x9413, 0xFFFF, 0xFFFF, 0xFFFF, "Softlogic Co., Ltd.(0x9413)"},
{0x9413, 0x6010, 0xFFFF, 0xFFFF, "SOLO6010 MPEG-4 Video encoder/decoder(0x6010)"},
{0x9413, 0x6110, 0xFFFF, 0xFFFF, "SOLO6110 H.264 Video encoder/decoder(0x6110)"},
}; /* pci_vid_9413[] */

static pci_id_t const pci_vid_9618[] = {
{0x9618, 0xFFFF, 0xFFFF, 0xFFFF, "JusonTech Corporation(0x9618)"},
{0x9618, 0x0001, 0xFFFF, 0xFFFF, "JusonTech Gigabit Ethernet Controller(0x0001)"},
}; /* pci_vid_9618[] */

static pci_id_t const pci_vid_9699[] = {
{0x9699, 0xFFFF, 0xFFFF, 0xFFFF, "Omni Media Technology Inc(0x9699)"},
{0x9699, 0x6565, 0xFFFF, 0xFFFF, "6565(0x6565)"},
}; /* pci_vid_9699[] */

static pci_id_t const pci_vid_9710[] = {
{0x9710, 0xFFFF, 0xFFFF, 0xFFFF, "MosChip Semiconductor Technology Ltd.(0x9710)"},
{0x9710, 0x9250, 0xFFFF, 0xFFFF, "PCI-to-PCI bridge [MCS9250](0x9250)"},
{0x9710, 0x9805, 0xFFFF, 0xFFFF, "PCI 1 port parallel adapter(0x9805)"},
{0x9710, 0x9815, 0xFFFF, 0xFFFF, "PCI 9815 Multi-I/O Controller(0x9815)"},
{0x9710, 0x9815, 0x1000, 0x0020, "2P0S (2 port parallel adaptor)(0x1000-0x0020)"},
{0x9710, 0x9820, 0xFFFF, 0xFFFF, "PCI 9820 Multi-I/O Controller(0x9820)"},
{0x9710, 0x9835, 0xFFFF, 0xFFFF, "PCI 9835 Multi-I/O Controller(0x9835)"},
{0x9710, 0x9835, 0x1000, 0x0002, "2S (16C550 UART)(0x1000-0x0002)"},
{0x9710, 0x9835, 0x1000, 0x0012, "1P2S(0x1000-0x0012)"},
{0x9710, 0x9845, 0xFFFF, 0xFFFF, "PCI 9845 Multi-I/O Controller(0x9845)"},
{0x9710, 0x9845, 0x1000, 0x0004, "0P4S (4 port 16550A serial card)(0x1000-0x0004)"},
{0x9710, 0x9845, 0x1000, 0x0006, "0P6S (6 port 16550a serial card)(0x1000-0x0006)"},
{0x9710, 0x9845, 0x1000, 0x0014, "1P4S (1 Parallel / 4 16550A Serial Port Adapter)(0x1000-0x0014)"},
{0x9710, 0x9855, 0xFFFF, 0xFFFF, "PCI 9855 Multi-I/O Controller(0x9855)"},
{0x9710, 0x9855, 0x1000, 0x0014, "1P4S(0x1000-0x0014)"},
{0x9710, 0x9855, 0x1000, 0x0022, "2P2S (2 Parallel / 2 16550A Serial Port Adapter)(0x1000-0x0022)"},
{0x9710, 0x9865, 0xFFFF, 0xFFFF, "PCI 9865 Multi-I/O Controller(0x9865)"},
{0x9710, 0x9900, 0xFFFF, 0xFFFF, "MCS9900 Multi-I/O Controller(0x9900)"},
{0x9710, 0x9901, 0xFFFF, 0xFFFF, "PCIe 9901 Multi-I/O Controller(0x9901)"},
{0x9710, 0x9904, 0xFFFF, 0xFFFF, "4-Port PCIe Serial Adapter(0x9904)"},
{0x9710, 0x9912, 0xFFFF, 0xFFFF, "PCIe 9912 Multi-I/O Controller(0x9912)"},
{0x9710, 0x9922, 0xFFFF, 0xFFFF, "MCS9922 PCIe Multi-I/O Controller(0x9922)"},
{0x9710, 0x9990, 0xFFFF, 0xFFFF, "MCS9990 PCIe to 4-Port USB 2.0 Host Controller(0x9990)"},
}; /* pci_vid_9710[] */

static pci_id_t const pci_vid_9850[] = {
{0x9850, 0xFFFF, 0xFFFF, 0xFFFF, "3Com (wrong ID)(0x9850)"},
}; /* pci_vid_9850[] */

static pci_id_t const pci_vid_9902[] = {
{0x9902, 0xFFFF, 0xFFFF, 0xFFFF, "Stargen Inc.(0x9902)"},
{0x9902, 0x0001, 0xFFFF, 0xFFFF, "SG2010 PCI over Starfabric Bridge(0x0001)"},
{0x9902, 0x0002, 0xFFFF, 0xFFFF, "SG2010 PCI to Starfabric Gateway(0x0002)"},
{0x9902, 0x0003, 0xFFFF, 0xFFFF, "SG1010 Starfabric Switch and PCI Bridge(0x0003)"},
}; /* pci_vid_9902[] */

static pci_id_t const pci_vid_9A11[] = {
{0x9A11, 0xFFFF, 0xFFFF, 0xFFFF, "Tiger Lake-H Gaussian & Neural Accelerator(0x9A11)"},
}; /* pci_vid_9A11[] */

static pci_id_t const pci_vid_9D32[] = {
{0x9D32, 0xFFFF, 0xFFFF, 0xFFFF, "Beijing Starblaze Technology Co. Ltd.(0x9D32)"},
{0x9D32, 0x0000, 0xFFFF, 0xFFFF, "STAR1000 PCIe NVMe SSD Controller(0x0000)"},
{0x9D32, 0x1000, 0xFFFF, 0xFFFF, "STAR1000 PCIe NVMe SSD Controller(0x1000)"},
{0x9D32, 0x1001, 0xFFFF, 0xFFFF, "STAR1000P PCIe NVMe SSD Controller(0x1001)"},
{0x9D32, 0x1201, 0xFFFF, 0xFFFF, "STAR1200C NVMe SSD(0x1201)"},
{0x9D32, 0x1202, 0xFFFF, 0xFFFF, "STAR1200I NVMe SSD(0x1202)"},
{0x9D32, 0x1203, 0xFFFF, 0xFFFF, "STAR1200L NVMe SSD(0x1203)"},
{0x9D32, 0x1204, 0xFFFF, 0xFFFF, "STAR1200E NVMe SSD(0x1204)"},
{0x9D32, 0x1500, 0xFFFF, 0xFFFF, "STAR1500 PCIe NVMe SSD Controller(0x1500)"},
{0x9D32, 0x1501, 0xFFFF, 0xFFFF, "STAR1500C NVMe SSD(0x1501)"},
{0x9D32, 0x1502, 0xFFFF, 0xFFFF, "STAR1500E NVMe SSD(0x1502)"},
{0x9D32, 0x1504, 0xFFFF, 0xFFFF, "STAR1500L NVMe SSD(0x1504)"},
{0x9D32, 0x2000, 0xFFFF, 0xFFFF, "STAR2000 NVMe Controller(0x2000)"},
{0x9D32, 0x2001, 0xFFFF, 0xFFFF, "STAR2000E NVMe SSD(0x2001)"},
{0x9D32, 0x2002, 0xFFFF, 0xFFFF, "STAR2000C NVMe SSD(0x2002)"},
{0x9D32, 0x2003, 0xFFFF, 0xFFFF, "STAR2000L NVMe SSD(0x2003)"},
{0x9D32, 0x2004, 0xFFFF, 0xFFFF, "EAST 2000K SSD(0x2004)"},
{0x9D32, 0x2008, 0xFFFF, 0xFFFF, "STAR2008 PCIE NVMe SSD Controller(0x2008)"},
{0x9D32, 0x2010, 0xFFFF, 0xFFFF, "STAR2010 PCIE NVMe Secure SSD Controller(0x2010)"},
{0x9D32, 0xBB5B, 0xFFFF, 0xFFFF, "Asgard AN3+ NVMe SSD(0xBB5B)"},
{0x9D32, 0xFC22, 0xFFFF, 0xFFFF, "Asgard AN3+ NVMe SSD(0xFC22)"},
}; /* pci_vid_9D32[] */

static pci_id_t const pci_vid_A000[] = {
{0xA000, 0xFFFF, 0xFFFF, 0xFFFF, "Asix Electronics Corporation (Wrong ID)(0xA000)"},
}; /* pci_vid_A000[] */

static pci_id_t const pci_vid_A0A0[] = {
{0xA0A0, 0xFFFF, 0xFFFF, 0xFFFF, "AOPEN Inc.(0xA0A0)"},
}; /* pci_vid_A0A0[] */

static pci_id_t const pci_vid_A0F1[] = {
{0xA0F1, 0xFFFF, 0xFFFF, 0xFFFF, "UNISYS Corporation(0xA0F1)"},
}; /* pci_vid_A0F1[] */

static pci_id_t const pci_vid_A200[] = {
{0xA200, 0xFFFF, 0xFFFF, 0xFFFF, "NEC Corporation(0xA200)"},
}; /* pci_vid_A200[] */

static pci_id_t const pci_vid_A259[] = {
{0xA259, 0xFFFF, 0xFFFF, 0xFFFF, "Hewlett Packard(0xA259)"},
}; /* pci_vid_A259[] */

static pci_id_t const pci_vid_A25B[] = {
{0xA25B, 0xFFFF, 0xFFFF, 0xFFFF, "Hewlett Packard GmbH PL24-MKT(0xA25B)"},
}; /* pci_vid_A25B[] */

static pci_id_t const pci_vid_A304[] = {
{0xA304, 0xFFFF, 0xFFFF, 0xFFFF, "Sony(0xA304)"},
}; /* pci_vid_A304[] */

static pci_id_t const pci_vid_A727[] = {
{0xA727, 0xFFFF, 0xFFFF, 0xFFFF, "3Com Corporation(0xA727)"},
{0xA727, 0x0013, 0xFFFF, 0xFFFF, "3CRPAG175 Wireless PC Card(0x0013)"},
{0xA727, 0x6803, 0xFFFF, 0xFFFF, "3CRDAG675B Wireless 11a/b/g Adapter(0x6803)"},
}; /* pci_vid_A727[] */

static pci_id_t const pci_vid_AA00[] = {
{0xAA00, 0xFFFF, 0xFFFF, 0xFFFF, "iTuner(0xAA00)"},
}; /* pci_vid_AA00[] */

static pci_id_t const pci_vid_AA01[] = {
{0xAA01, 0xFFFF, 0xFFFF, 0xFFFF, "iTuner(0xAA01)"},
}; /* pci_vid_AA01[] */

static pci_id_t const pci_vid_AA02[] = {
{0xAA02, 0xFFFF, 0xFFFF, 0xFFFF, "iTuner(0xAA02)"},
}; /* pci_vid_AA02[] */

static pci_id_t const pci_vid_AA03[] = {
{0xAA03, 0xFFFF, 0xFFFF, 0xFFFF, "iTuner(0xAA03)"},
}; /* pci_vid_AA03[] */

static pci_id_t const pci_vid_AA04[] = {
{0xAA04, 0xFFFF, 0xFFFF, 0xFFFF, "iTuner(0xAA04)"},
}; /* pci_vid_AA04[] */

static pci_id_t const pci_vid_AA05[] = {
{0xAA05, 0xFFFF, 0xFFFF, 0xFFFF, "iTuner(0xAA05)"},
}; /* pci_vid_AA05[] */

static pci_id_t const pci_vid_AA06[] = {
{0xAA06, 0xFFFF, 0xFFFF, 0xFFFF, "iTuner(0xAA06)"},
}; /* pci_vid_AA06[] */

static pci_id_t const pci_vid_AA07[] = {
{0xAA07, 0xFFFF, 0xFFFF, 0xFFFF, "iTuner(0xAA07)"},
}; /* pci_vid_AA07[] */

static pci_id_t const pci_vid_AA08[] = {
{0xAA08, 0xFFFF, 0xFFFF, 0xFFFF, "iTuner(0xAA08)"},
}; /* pci_vid_AA08[] */

static pci_id_t const pci_vid_AA09[] = {
{0xAA09, 0xFFFF, 0xFFFF, 0xFFFF, "iTuner(0xAA09)"},
}; /* pci_vid_AA09[] */

static pci_id_t const pci_vid_AA0A[] = {
{0xAA0A, 0xFFFF, 0xFFFF, 0xFFFF, "iTuner(0xAA0A)"},
}; /* pci_vid_AA0A[] */

static pci_id_t const pci_vid_AA0B[] = {
{0xAA0B, 0xFFFF, 0xFFFF, 0xFFFF, "iTuner(0xAA0B)"},
}; /* pci_vid_AA0B[] */

static pci_id_t const pci_vid_AA0C[] = {
{0xAA0C, 0xFFFF, 0xFFFF, 0xFFFF, "iTuner(0xAA0C)"},
}; /* pci_vid_AA0C[] */

static pci_id_t const pci_vid_AA0D[] = {
{0xAA0D, 0xFFFF, 0xFFFF, 0xFFFF, "iTuner(0xAA0D)"},
}; /* pci_vid_AA0D[] */

static pci_id_t const pci_vid_AA0E[] = {
{0xAA0E, 0xFFFF, 0xFFFF, 0xFFFF, "iTuner(0xAA0E)"},
}; /* pci_vid_AA0E[] */

static pci_id_t const pci_vid_AA0F[] = {
{0xAA0F, 0xFFFF, 0xFFFF, 0xFFFF, "iTuner(0xAA0F)"},
}; /* pci_vid_AA0F[] */

static pci_id_t const pci_vid_AA42[] = {
{0xAA42, 0xFFFF, 0xFFFF, 0xFFFF, "Scitex Digital Video(0xAA42)"},
}; /* pci_vid_AA42[] */

static pci_id_t const pci_vid_AA55[] = {
{0xAA55, 0xFFFF, 0xFFFF, 0xFFFF, "Ncomputing X300 PCI-Engine(0xAA55)"},
}; /* pci_vid_AA55[] */

static pci_id_t const pci_vid_AAAA[] = {
{0xAAAA, 0xFFFF, 0xFFFF, 0xFFFF, "Adnaco Technology Inc.(0xAAAA)"},
{0xAAAA, 0x0001, 0xFFFF, 0xFFFF, "H1 PCIe over fiber optic host controller(0x0001)"},
{0xAAAA, 0x0002, 0xFFFF, 0xFFFF, "R1BP1 PCIe over fiber optic expansion chassis(0x0002)"},
}; /* pci_vid_AAAA[] */

static pci_id_t const pci_vid_ABCD[] = {
{0xABCD, 0xFFFF, 0xFFFF, 0xFFFF, "Vadatech Inc.(0xABCD)"},
}; /* pci_vid_ABCD[] */

static pci_id_t const pci_vid_AC1E[] = {
{0xAC1E, 0xFFFF, 0xFFFF, 0xFFFF, "Digital Receiver Technology Inc(0xAC1E)"},
}; /* pci_vid_AC1E[] */

static pci_id_t const pci_vid_AC3D[] = {
{0xAC3D, 0xFFFF, 0xFFFF, 0xFFFF, "Actuality Systems(0xAC3D)"},
}; /* pci_vid_AC3D[] */

static pci_id_t const pci_vid_AD00[] = {
{0xAD00, 0xFFFF, 0xFFFF, 0xFFFF, "Alta Data Technologies LLC(0xAD00)"},
}; /* pci_vid_AD00[] */

static pci_id_t const pci_vid_AECB[] = {
{0xAECB, 0xFFFF, 0xFFFF, 0xFFFF, "Adrienne Electronics Corporation(0xAECB)"},
{0xAECB, 0x6250, 0xFFFF, 0xFFFF, "VITC/LTC Timecode Reader card [PCI-VLTC/RDR](0x6250)"},
}; /* pci_vid_AECB[] */

static pci_id_t const pci_vid_AFFE[] = {
{0xAFFE, 0xFFFF, 0xFFFF, 0xFFFF, "Sirrix AG security technologies(0xAFFE)"},
{0xAFFE, 0x01E1, 0xFFFF, 0xFFFF, "PCI1E1 1-port ISDN E1 interface(0x01E1)"},
{0xAFFE, 0x02E1, 0xFFFF, 0xFFFF, "PCI2E1 2-port ISDN E1 interface(0x02E1)"},
{0xAFFE, 0x450E, 0xFFFF, 0xFFFF, "PCI4S0EC 4-port ISDN S0 interface(0x450E)"},
{0xAFFE, 0xDEAD, 0xFFFF, 0xFFFF, "Sirrix.PCI4S0 4-port ISDN S0 interface(0xDEAD)"},
}; /* pci_vid_AFFE[] */

static pci_id_t const pci_vid_B100[] = {
{0xB100, 0xFFFF, 0xFFFF, 0xFFFF, "OpenVox Communication Co. Ltd.(0xB100)"},
}; /* pci_vid_B100[] */

static pci_id_t const pci_vid_B10B[] = {
{0xB10B, 0xFFFF, 0xFFFF, 0xFFFF, "Uakron PCI Project(0xB10B)"},
}; /* pci_vid_B10B[] */

static pci_id_t const pci_vid_B1B3[] = {
{0xB1B3, 0xFFFF, 0xFFFF, 0xFFFF, "Shiva Europe Limited(0xB1B3)"},
}; /* pci_vid_B1B3[] */

static pci_id_t const pci_vid_B1D9[] = {
{0xB1D9, 0xFFFF, 0xFFFF, 0xFFFF, "ATCOM Technology co., LTD.(0xB1D9)"},
}; /* pci_vid_B1D9[] */

static pci_id_t const pci_vid_BD11[] = {
{0xBD11, 0xFFFF, 0xFFFF, 0xFFFF, "Pinnacle Systems, Inc. (Wrong ID)(0xBD11)"},
}; /* pci_vid_BD11[] */

static pci_id_t const pci_vid_BDBD[] = {
{0xBDBD, 0xFFFF, 0xFFFF, 0xFFFF, "Blackmagic Design(0xBDBD)"},
{0xBDBD, 0xA106, 0xFFFF, 0xFFFF, "Multibridge Extreme(0xA106)"},
{0xBDBD, 0xA117, 0xFFFF, 0xFFFF, "Intensity Pro(0xA117)"},
{0xBDBD, 0xA11A, 0xFFFF, 0xFFFF, "DeckLink HD Extreme 2(0xA11A)"},
{0xBDBD, 0xA11B, 0xFFFF, 0xFFFF, "DeckLink SDI/Duo/Quad(0xA11B)"},
{0xBDBD, 0xA11C, 0xFFFF, 0xFFFF, "DeckLink HD Extreme 3(0xA11C)"},
{0xBDBD, 0xA11D, 0xFFFF, 0xFFFF, "DeckLink Studio(0xA11D)"},
{0xBDBD, 0xA11E, 0xFFFF, 0xFFFF, "DeckLink Optical Fibre(0xA11E)"},
{0xBDBD, 0xA120, 0xFFFF, 0xFFFF, "Decklink Studio 2(0xA120)"},
{0xBDBD, 0xA121, 0xFFFF, 0xFFFF, "DeckLink HD Extreme 3D/3D+(0xA121)"},
{0xBDBD, 0xA124, 0xFFFF, 0xFFFF, "Intensity Extreme(0xA124)"},
{0xBDBD, 0xA126, 0xFFFF, 0xFFFF, "Intensity Shuttle(0xA126)"},
{0xBDBD, 0xA127, 0xFFFF, 0xFFFF, "UltraStudio Express(0xA127)"},
{0xBDBD, 0xA129, 0xFFFF, 0xFFFF, "UltraStudio Mini Recorder(0xA129)"},
{0xBDBD, 0xA12A, 0xFFFF, 0xFFFF, "UltraStudio Mini Monitor(0xA12A)"},
{0xBDBD, 0xA12D, 0xFFFF, 0xFFFF, "UltraStudio 4K(0xA12D)"},
{0xBDBD, 0xA12E, 0xFFFF, 0xFFFF, "DeckLink 4K Extreme(0xA12E)"},
{0xBDBD, 0xA12F, 0xFFFF, 0xFFFF, "DeckLink Mini Monitor(0xA12F)"},
{0xBDBD, 0xA130, 0xFFFF, 0xFFFF, "DeckLink Mini Recorder(0xA130)"},
{0xBDBD, 0xA132, 0xFFFF, 0xFFFF, "UltraStudio 4K(0xA132)"},
{0xBDBD, 0xA136, 0xFFFF, 0xFFFF, "DeckLink 4K Extreme 12G(0xA136)"},
{0xBDBD, 0xA137, 0xFFFF, 0xFFFF, "DeckLink Studio 4K(0xA137)"},
{0xBDBD, 0xA138, 0xFFFF, 0xFFFF, "Decklink SDI 4K(0xA138)"},
{0xBDBD, 0xA139, 0xFFFF, 0xFFFF, "Intensity Pro 4K(0xA139)"},
{0xBDBD, 0xA13B, 0xFFFF, 0xFFFF, "DeckLink Micro Recorder(0xA13B)"},
{0xBDBD, 0xA13D, 0xFFFF, 0xFFFF, "DeckLink 4K Pro(0xA13D)"},
{0xBDBD, 0xA13E, 0xFFFF, 0xFFFF, "UltraStudio 4K Extreme(0xA13E)"},
{0xBDBD, 0xA13F, 0xFFFF, 0xFFFF, "DeckLink Quad 2(0xA13F)"},
{0xBDBD, 0xA140, 0xFFFF, 0xFFFF, "DeckLink Duo 2(0xA140)"},
{0xBDBD, 0xA141, 0xFFFF, 0xFFFF, "UltraStudio 4K Extreme 3(0xA141)"},
{0xBDBD, 0xA142, 0xFFFF, 0xFFFF, "UltraStudio HD Mini(0xA142)"},
{0xBDBD, 0xA143, 0xFFFF, 0xFFFF, "DeckLink Mini Recorder 4K(0xA143)"},
{0xBDBD, 0xA144, 0xFFFF, 0xFFFF, "DeckLink Mini Monitor 4K(0xA144)"},
{0xBDBD, 0xA148, 0xFFFF, 0xFFFF, "DeckLink SDI Micro(0xA148)"},
{0xBDBD, 0xA14B, 0xFFFF, 0xFFFF, "DeckLink 8K Pro(0xA14B)"},
{0xBDBD, 0xA14E, 0xFFFF, 0xFFFF, "DeckLink Quad HDMI Recorder(0xA14E)"},
{0xBDBD, 0xA1FF, 0xFFFF, 0xFFFF, "eGPU RX580(0xA1FF)"},
}; /* pci_vid_BDBD[] */

static pci_id_t const pci_vid_C001[] = {
{0xC001, 0xFFFF, 0xFFFF, 0xFFFF, "TSI Telsys(0xC001)"},
}; /* pci_vid_C001[] */

static pci_id_t const pci_vid_C0A9[] = {
{0xC0A9, 0xFFFF, 0xFFFF, 0xFFFF, "Micron/Crucial Technology(0xC0A9)"},
{0xC0A9, 0x2263, 0xFFFF, 0xFFFF, "P1 NVMe PCIe SSD[Frampton](0x2263)"},
{0xC0A9, 0x5403, 0xFFFF, 0xFFFF, "P1 NVMe PCIe SSD[Frampton2](0x5403)"},
{0xC0A9, 0x5407, 0xFFFF, 0xFFFF, "P5 Plus NVMe PCIe SSD(0x5407)"},
{0xC0A9, 0x540A, 0xFFFF, 0xFFFF, "P2 [Nick P2] / P3 / P3 Plus NVMe PCIe SSD (DRAM-less)(0x540A)"},
{0xC0A9, 0x5412, 0xFFFF, 0xFFFF, "P5 NVMe PCIe SSD[SlashP5](0x5412)"},
{0xC0A9, 0x5415, 0xFFFF, 0xFFFF, "T500 NVMe PCIe SSD(0x5415)"},
{0xC0A9, 0x5419, 0xFFFF, 0xFFFF, "T700 NVMe PCIe SSD(0x5419)"},
{0xC0A9, 0x5421, 0xFFFF, 0xFFFF, "P3 Plus NVMe PCIe SSD (DRAM-less)(0x5421)"},
}; /* pci_vid_C0A9[] */

static pci_id_t const pci_vid_C0DE[] = {
{0xC0DE, 0xFFFF, 0xFFFF, 0xFFFF, "Motorola(0xC0DE)"},
}; /* pci_vid_C0DE[] */

static pci_id_t const pci_vid_C0FE[] = {
{0xC0FE, 0xFFFF, 0xFFFF, 0xFFFF, "Motion Engineering, Inc.(0xC0FE)"},
}; /* pci_vid_C0FE[] */

static pci_id_t const pci_vid_CA01[] = {
{0xCA01, 0xFFFF, 0xFFFF, 0xFFFF, "I-TEK OptoElectronics Co., LTD.(0xCA01)"},
{0xCA01, 0x0212, 0xFFFF, 0xFFFF, "Vulcan-CL CameraLink Frame Grabber(0x0212)"},
}; /* pci_vid_CA01[] */

static pci_id_t const pci_vid_CA02[] = {
{0xCA02, 0xFFFF, 0xFFFF, 0xFFFF, "I-TEK OptoElectronics Co., LTD.(0xCA02)"},
{0xCA02, 0x0213, 0xFFFF, 0xFFFF, "Vulcan-CXP Frame Grabber(0x0213)"},
}; /* pci_vid_CA02[] */

static pci_id_t const pci_vid_CA3B[] = {
{0xCA3B, 0xFFFF, 0xFFFF, 0xFFFF, "Cambrionix Ltd.(0xCA3B)"},
}; /* pci_vid_CA3B[] */

static pci_id_t const pci_vid_CA50[] = {
{0xCA50, 0xFFFF, 0xFFFF, 0xFFFF, "Varian Australia Pty Ltd(0xCA50)"},
}; /* pci_vid_CA50[] */

static pci_id_t const pci_vid_CACE[] = {
{0xCACE, 0xFFFF, 0xFFFF, 0xFFFF, "CACE Technologies, Inc.(0xCACE)"},
{0xCACE, 0x0001, 0xFFFF, 0xFFFF, "TurboCap Port A(0x0001)"},
{0xCACE, 0x0002, 0xFFFF, 0xFFFF, "TurboCap Port B(0x0002)"},
{0xCACE, 0x0023, 0xFFFF, 0xFFFF, "AirPcap N(0x0023)"},
}; /* pci_vid_CACE[] */

static pci_id_t const pci_vid_CAED[] = {
{0xCAED, 0xFFFF, 0xFFFF, 0xFFFF, "Canny Edge(0xCAED)"},
}; /* pci_vid_CAED[] */

static pci_id_t const pci_vid_CAFE[] = {
{0xCAFE, 0xFFFF, 0xFFFF, 0xFFFF, "Chrysalis-ITS(0xCAFE)"},
{0xCAFE, 0x0003, 0xFFFF, 0xFFFF, "Luna K3 Hardware Security Module(0x0003)"},
{0xCAFE, 0x0006, 0xFFFF, 0xFFFF, "Luna PCI-e 3000 Hardware Security Module(0x0006)"},
{0xCAFE, 0x0007, 0xFFFF, 0xFFFF, "Luna K6 Hardware Security Module(0x0007)"},
{0xCAFE, 0x0008, 0xFFFF, 0xFFFF, "Luna K7 Hardware Security Module(0x0008)"},
}; /* pci_vid_CAFE[] */

static pci_id_t const pci_vid_CC53[] = {
{0xCC53, 0xFFFF, 0xFFFF, 0xFFFF, "ScaleFlux Inc.(0xCC53)"},
{0xCC53, 0x0001, 0xFFFF, 0xFFFF, "CSS 1000(0x0001)"},
{0xCC53, 0x0010, 0xFFFF, 0xFFFF, "CSD 3310(0x0010)"},
}; /* pci_vid_CC53[] */

static pci_id_t const pci_vid_CCCC[] = {
{0xCCCC, 0xFFFF, 0xFFFF, 0xFFFF, "Catapult Communications(0xCCCC)"},
}; /* pci_vid_CCCC[] */

static pci_id_t const pci_vid_CCEC[] = {
{0xCCEC, 0xFFFF, 0xFFFF, 0xFFFF, "Curtiss-Wright Controls Embedded Computing(0xCCEC)"},
}; /* pci_vid_CCEC[] */

static pci_id_t const pci_vid_CDDD[] = {
{0xCDDD, 0xFFFF, 0xFFFF, 0xFFFF, "Tyzx, Inc.(0xCDDD)"},
{0xCDDD, 0x0101, 0xFFFF, 0xFFFF, "DeepSea 1 High Speed Stereo Vision Frame Grabber(0x0101)"},
{0xCDDD, 0x0200, 0xFFFF, 0xFFFF, "DeepSea 2 High Speed Stereo Vision Frame Grabber(0x0200)"},
}; /* pci_vid_CDDD[] */

static pci_id_t const pci_vid_CDFA[] = {
{0xCDFA, 0xFFFF, 0xFFFF, 0xFFFF, "NextSilicon Ltd(0xCDFA)"},
{0xCDFA, 0x0007, 0xFFFF, 0xFFFF, "Maverick(0x0007)"},
}; /* pci_vid_CDFA[] */

static pci_id_t const pci_vid_CEBA[] = {
{0xCEBA, 0xFFFF, 0xFFFF, 0xFFFF, "KEBA AG(0xCEBA)"},
}; /* pci_vid_CEBA[] */

static pci_id_t const pci_vid_CF86[] = {
{0xCF86, 0xFFFF, 0xFFFF, 0xFFFF, "Spectrum-4TOR(0xCF86)"},
{0xCF86, 0x0276, 0xFFFF, 0xFFFF, "Spectrum-4TOR in Flash Recovery Mode(0x0276)"},
}; /* pci_vid_CF86[] */

static pci_id_t const pci_vid_D063[] = {
{0xD063, 0xFFFF, 0xFFFF, 0xFFFF, "SolidRun(0xD063)"},
{0xD063, 0x1000, 0xFFFF, 0xFFFF, "SolidNET DPU(0x1000)"},
{0xD063, 0x1500, 0xFFFF, 0xFFFF, "Emulated NVMe(0x1500)"},
}; /* pci_vid_D063[] */

static pci_id_t const pci_vid_D161[] = {
{0xD161, 0xFFFF, 0xFFFF, 0xFFFF, "Digium, Inc.(0xD161)"},
{0xD161, 0x0120, 0xFFFF, 0xFFFF, "Wildcard TE120P single-span T1/E1/J1 card(0x0120)"},
{0xD161, 0x0205, 0xFFFF, 0xFFFF, "Wildcard TE205P/TE207P dual-span T1/E1/J1 card 5.0V(0x0205)"},
{0xD161, 0x0210, 0xFFFF, 0xFFFF, "Wildcard TE210P/TE212P dual-span T1/E1/J1 card 3.3V(0x0210)"},
{0xD161, 0x0220, 0xFFFF, 0xFFFF, "Wildcard TE220 dual-span T1/E1/J1 card 3.3V (PCI-Express)(0x0220)"},
{0xD161, 0x0405, 0xFFFF, 0xFFFF, "Wildcard TE405P/TE407P quad-span T1/E1/J1 card 5.0V(0x0405)"},
{0xD161, 0x0410, 0xFFFF, 0xFFFF, "Wildcard TE410P/TE412P quad-span T1/E1/J1 card 3.3V(0x0410)"},
{0xD161, 0x0420, 0xFFFF, 0xFFFF, "Wildcard TE420P quad-span T1/E1/J1 card 3.3V (PCI-Express)(0x0420)"},
{0xD161, 0x0800, 0xFFFF, 0xFFFF, "Wildcard TDM800P 8-port analog card(0x0800)"},
{0xD161, 0x1205, 0xFFFF, 0xFFFF, "Wildcard TE205P/TE207P dual-span T1/E1/J1 card 5.0V (u1)(0x1205)"},
{0xD161, 0x1220, 0xFFFF, 0xFFFF, "Wildcard TE220 dual-span T1/E1/J1 card 3.3V (PCI-Express) (5th gen)(0x1220)"},
{0xD161, 0x1405, 0xFFFF, 0xFFFF, "Wildcard TE405P/TE407P quad-span T1/E1/J1 card 5.0V (u1)(0x1405)"},
{0xD161, 0x1410, 0xFFFF, 0xFFFF, "Wildcard TE410P quad-span T1/E1/J1 card 3.3V (5th Gen)(0x1410)"},
{0xD161, 0x1420, 0xFFFF, 0xFFFF, "Wildcard TE420 quad-span T1/E1/J1 card 3.3V (PCI-Express) (5th gen)(0x1420)"},
{0xD161, 0x1820, 0xFFFF, 0xFFFF, "Wildcard TE820 octal-span T1/E1/J1 card 3.3V (PCI-Express)(0x1820)"},
{0xD161, 0x2400, 0xFFFF, 0xFFFF, "Wildcard TDM2400P 24-port analog card(0x2400)"},
{0xD161, 0x3400, 0xFFFF, 0xFFFF, "Wildcard TC400P transcoder base card(0x3400)"},
{0xD161, 0x8000, 0xFFFF, 0xFFFF, "Wildcard TE121 single-span T1/E1/J1 card (PCI-Express)(0x8000)"},
{0xD161, 0x8001, 0xFFFF, 0xFFFF, "Wildcard TE122 single-span T1/E1/J1 card(0x8001)"},
{0xD161, 0x8002, 0xFFFF, 0xFFFF, "Wildcard AEX800 8-port analog card (PCI-Express)(0x8002)"},
{0xD161, 0x8003, 0xFFFF, 0xFFFF, "Wildcard AEX2400 24-port analog card (PCI-Express)(0x8003)"},
{0xD161, 0x8004, 0xFFFF, 0xFFFF, "Wildcard TCE400P transcoder base card(0x8004)"},
{0xD161, 0x8005, 0xFFFF, 0xFFFF, "Wildcard TDM410 4-port analog card(0x8005)"},
{0xD161, 0x8006, 0xFFFF, 0xFFFF, "Wildcard AEX410 4-port analog card (PCI-Express)(0x8006)"},
{0xD161, 0x8007, 0xFFFF, 0xFFFF, "Hx8 Series 8-port Base Card(0x8007)"},
{0xD161, 0x8008, 0xFFFF, 0xFFFF, "Hx8 Series 8-port Base Card (PCI-Express)(0x8008)"},
{0xD161, 0x800A, 0xFFFF, 0xFFFF, "Wildcard TE133 single-span T1/E1/J1 card (PCI Express)(0x800A)"},
{0xD161, 0x800B, 0xFFFF, 0xFFFF, "Wildcard TE134 single-span T1/E1/J1 card(0x800B)"},
{0xD161, 0x800C, 0xFFFF, 0xFFFF, "Wildcard A8A 8-port analog card(0x800C)"},
{0xD161, 0x800D, 0xFFFF, 0xFFFF, "Wildcard A8B 8-port analog card (PCI-Express)(0x800D)"},
{0xD161, 0x800E, 0xFFFF, 0xFFFF, "Wildcard TE235/TE435 quad-span T1/E1/J1 card (PCI-Express)(0x800E)"},
{0xD161, 0x800F, 0xFFFF, 0xFFFF, "Wildcard A4A 4-port analog card(0x800F)"},
{0xD161, 0x8010, 0xFFFF, 0xFFFF, "Wildcard A4B 4-port analog card (PCI-Express)(0x8010)"},
{0xD161, 0x8013, 0xFFFF, 0xFFFF, "Wildcard TE236/TE436 quad-span T1/E1/J1 card(0x8013)"},
{0xD161, 0xB410, 0xFFFF, 0xFFFF, "Wildcard B410 quad-BRI card(0xB410)"},
}; /* pci_vid_D161[] */

static pci_id_t const pci_vid_D209[] = {
{0xD209, 0xFFFF, 0xFFFF, 0xFFFF, "Ultimarc(0xD209)"},
{0xD209, 0x1500, 0xFFFF, 0xFFFF, "PAC Drive(0x1500)"},
{0xD209, 0x15A2, 0xFFFF, 0xFFFF, "SpinTrak(0x15A2)"},
{0xD209, 0x1601, 0xFFFF, 0xFFFF, "AimTrak(0x1601)"},
}; /* pci_vid_D209[] */

static pci_id_t const pci_vid_D20C[] = {
{0xD20C, 0xFFFF, 0xFFFF, 0xFFFF, "Chengdu BeiZhongWangXin Technology Co., Ltd.(0xD20C)"},
{0xD20C, 0x5010, 0xFFFF, 0xFFFF, "NE5000 Ethernet Controller(0x5010)"},
{0xD20C, 0x5011, 0xFFFF, 0xFFFF, "NE5000 Ethernet Controller(0x5011)"},
{0xD20C, 0x5011, 0xD20C, 0xE220, "N5 Series 2-port 25GbE Network Adapter(0xD20C-0xE220)"},
{0xD20C, 0x5011, 0xD20C, 0xE221, "N5S Series 2-port 25GbE Network Adapter(0xD20C-0xE221)"},
{0xD20C, 0x5011, 0xD20C, 0xE22C, "N5 Series 2-port 25GbE Network Adapter for OCP(0xD20C-0xE22C)"},
{0xD20C, 0x5011, 0xD20C, 0xE22D, "N5S Series 2-port 25GbE Network Adapter for OCP(0xD20C-0xE22D)"},
{0xD20C, 0x6010, 0xFFFF, 0xFFFF, "NE6000 Ethernet Controller(0x6010)"},
{0xD20C, 0x6011, 0xFFFF, 0xFFFF, "NE6000 Ethernet Controller(0x6011)"},
{0xD20C, 0x6011, 0xD20C, 0xA141, "N6S Series 4-port 10GbE Network Adapter(0xD20C-0xA141)"},
{0xD20C, 0x6011, 0xD20C, 0xA221, "N6S Series 2-port 25GbE Network Adapter(0xD20C-0xA221)"},
{0xD20C, 0x6011, 0xD20C, 0xA241, "N6S Series 4-port 25GbE Network Adapter(0xD20C-0xA241)"},
{0xD20C, 0x6011, 0xD20C, 0xA421, "N6S Series 2-port 40GbE Network Adapter(0xD20C-0xA421)"},
{0xD20C, 0x6011, 0xD20C, 0xAA21, "N6S Series 2-port 100GbE Network Adapter(0xD20C-0xAA21)"},
{0xD20C, 0x6011, 0xD20C, 0xD221, "N6S Series 2-port 25GbE Network Adapter with DPI(0xD20C-0xD221)"},
{0xD20C, 0x6011, 0xD20C, 0xDA21, "N6S Series 2-port 100GbE Network Adapter with DPI(0xD20C-0xDA21)"},
{0xD20C, 0x6011, 0xD20C, 0xEA20, "N6 Series 2-port 100GbE Network Adapter(0xD20C-0xEA20)"},
{0xD20C, 0x6011, 0xD20C, 0xEA21, "N6S Series 2-port 100GbE Network Adapter(0xD20C-0xEA21)"},
{0xD20C, 0x6011, 0xD20C, 0xEA2C, "N6 Series 2-port 100GbE Network Adapter for OCP(0xD20C-0xEA2C)"},
{0xD20C, 0x6011, 0xD20C, 0xEA2D, "N6S Series 2-port 100GbE Network Adapter for OCP(0xD20C-0xEA2D)"},
}; /* pci_vid_D20C[] */

static pci_id_t const pci_vid_D4D4[] = {
{0xD4D4, 0xFFFF, 0xFFFF, 0xFFFF, "Dy4 Systems Inc(0xD4D4)"},
{0xD4D4, 0x0601, 0xFFFF, 0xFFFF, "PCI Mezzanine Card(0x0601)"},
}; /* pci_vid_D4D4[] */

static pci_id_t const pci_vid_D531[] = {
{0xD531, 0xFFFF, 0xFFFF, 0xFFFF, "I+ME ACTIA GmbH(0xD531)"},
}; /* pci_vid_D531[] */

static pci_id_t const pci_vid_D84D[] = {
{0xD84D, 0xFFFF, 0xFFFF, 0xFFFF, "Exsys(0xD84D)"},
}; /* pci_vid_D84D[] */

static pci_id_t const pci_vid_DADA[] = {
{0xDADA, 0xFFFF, 0xFFFF, 0xFFFF, "Datapath Limited(0xDADA)"},
{0xDADA, 0x0133, 0xFFFF, 0xFFFF, "VisionRGB-X2(0x0133)"},
{0xDADA, 0x0139, 0xFFFF, 0xFFFF, "VisionRGB-E1(0x0139)"},
{0xDADA, 0x0144, 0xFFFF, 0xFFFF, "VisionSD8(0x0144)"},
{0xDADA, 0x0150, 0xFFFF, 0xFFFF, "VisionRGB-E2(0x0150)"},
{0xDADA, 0x0151, 0xFFFF, 0xFFFF, "VisionSD4+1(0x0151)"},
{0xDADA, 0x0159, 0xFFFF, 0xFFFF, "VisionAV(0x0159)"},
{0xDADA, 0x0161, 0xFFFF, 0xFFFF, "DGC161(0x0161)"},
{0xDADA, 0x0165, 0xFFFF, 0xFFFF, "DGC165(0x0165)"},
{0xDADA, 0x0167, 0xFFFF, 0xFFFF, "DGC167(0x0167)"},
{0xDADA, 0x0168, 0xFFFF, 0xFFFF, "DGC168(0x0168)"},
{0xDADA, 0x1139, 0xFFFF, 0xFFFF, "VisionRGB-E1S(0x1139)"},
{0xDADA, 0x1150, 0xFFFF, 0xFFFF, "VisionRGB-E2S(0x1150)"},
{0xDADA, 0x1151, 0xFFFF, 0xFFFF, "VisionSD4+1S(0x1151)"},
{0xDADA, 0x1153, 0xFFFF, 0xFFFF, "VisionDVI-DL(0x1153)"},
{0xDADA, 0x1154, 0xFFFF, 0xFFFF, "VisionSDI2(0x1154)"},
}; /* pci_vid_DADA[] */

static pci_id_t const pci_vid_DB10[] = {
{0xDB10, 0xFFFF, 0xFFFF, 0xFFFF, "Diablo Technologies(0xDB10)"},
}; /* pci_vid_DB10[] */

static pci_id_t const pci_vid_DC93[] = {
{0xDC93, 0xFFFF, 0xFFFF, 0xFFFF, "Dawicontrol GmbH(0xDC93)"},
}; /* pci_vid_DC93[] */

static pci_id_t const pci_vid_DCBA[] = {
{0xDCBA, 0xFFFF, 0xFFFF, 0xFFFF, "Dynamic Engineering(0xDCBA)"},
{0xDCBA, 0x0046, 0xFFFF, 0xFFFF, "PCIe Altera Cyclone IV(0x0046)"},
{0xDCBA, 0x0047, 0xFFFF, 0xFFFF, "VPX-RCB(0x0047)"},
{0xDCBA, 0x0048, 0xFFFF, 0xFFFF, "PMC-Biserial-III-BAE9(0x0048)"},
{0xDCBA, 0x004E, 0xFFFF, 0xFFFF, "PC104p-Biserial-III-NVY5(0x004E)"},
{0xDCBA, 0x004F, 0xFFFF, 0xFFFF, "PC104p-Biserial-III-NVY6(0x004F)"},
{0xDCBA, 0x0052, 0xFFFF, 0xFFFF, "PCIeBiSerialDb37 BA22 LVDS IO(0x0052)"},
{0xDCBA, 0x0066, 0xFFFF, 0xFFFF, "PMC-OctalUART-232(0x0066)"},
}; /* pci_vid_DCBA[] */

static pci_id_t const pci_vid_DD01[] = {
{0xDD01, 0xFFFF, 0xFFFF, 0xFFFF, "Digital Devices GmbH(0xDD01)"},
{0xDD01, 0x0003, 0xFFFF, 0xFFFF, "Octopus DVB Adapter(0x0003)"},
{0xDD01, 0x0003, 0xDD01, 0x0001, "Octopus DVB adapter(0xDD01-0x0001)"},
{0xDD01, 0x0003, 0xDD01, 0x0002, "Octopus LE DVB adapter(0xDD01-0x0002)"},
{0xDD01, 0x0003, 0xDD01, 0x0003, "Octopus OEM(0xDD01-0x0003)"},
{0xDD01, 0x0003, 0xDD01, 0x0004, "Octopus V3 DVB adapter(0xDD01-0x0004)"},
{0xDD01, 0x0003, 0xDD01, 0x0010, "Octopus Mini(0xDD01-0x0010)"},
{0xDD01, 0x0003, 0xDD01, 0x0020, "Cine S2 V6 DVB adapter(0xDD01-0x0020)"},
{0xDD01, 0x0003, 0xDD01, 0x0021, "Cine S2 V6.5 DVB adapter(0xDD01-0x0021)"},
{0xDD01, 0x0003, 0xDD01, 0x0030, "Cine CT V6.1 DVB adapter(0xDD01-0x0030)"},
{0xDD01, 0x0003, 0xDD01, 0xDB03, "Mystique SaTiX-S2 V3 DVB adapter(0xDD01-0xDB03)"},
{0xDD01, 0x0006, 0xFFFF, 0xFFFF, "Cine V7(0x0006)"},
{0xDD01, 0x0007, 0xFFFF, 0xFFFF, "Max(0x0007)"},
{0xDD01, 0x0007, 0xDD01, 0x0023, "Max S8 4/8(0xDD01-0x0023)"},
{0xDD01, 0x0011, 0xFFFF, 0xFFFF, "Octopus CI DVB Adapter(0x0011)"},
{0xDD01, 0x0011, 0xDD01, 0x0040, "Octopus CI(0xDD01-0x0040)"},
{0xDD01, 0x0011, 0xDD01, 0x0041, "Octopus CI Single(0xDD01-0x0041)"},
{0xDD01, 0x0201, 0xFFFF, 0xFFFF, "Resi DVB-C Modulator(0x0201)"},
{0xDD01, 0x0201, 0xDD01, 0x0001, "Resi DVB-C Modulator(0xDD01-0x0001)"},
}; /* pci_vid_DD01[] */

static pci_id_t const pci_vid_DEAD[] = {
{0xDEAD, 0xFFFF, 0xFFFF, 0xFFFF, "Indigita Corporation(0xDEAD)"},
}; /* pci_vid_DEAD[] */

static pci_id_t const pci_vid_DEAF[] = {
{0xDEAF, 0xFFFF, 0xFFFF, 0xFFFF, "Middle Digital Inc.(0xDEAF)"},
{0xDEAF, 0x9050, 0xFFFF, 0xFFFF, "PC Weasel Virtual VGA(0x9050)"},
{0xDEAF, 0x9051, 0xFFFF, 0xFFFF, "PC Weasel Serial Port(0x9051)"},
{0xDEAF, 0x9052, 0xFFFF, 0xFFFF, "PC Weasel Watchdog Timer(0x9052)"},
}; /* pci_vid_DEAF[] */

static pci_id_t const pci_vid_DEDA[] = {
{0xDEDA, 0xFFFF, 0xFFFF, 0xFFFF, "XIMEA(0xDEDA)"},
{0xDEDA, 0x4001, 0xFFFF, 0xFFFF, "CB or MX camera(0x4001)"},
{0xDEDA, 0x4021, 0xFFFF, 0xFFFF, "MT camera(0x4021)"},
}; /* pci_vid_DEDA[] */

static pci_id_t const pci_vid_E000[] = {
{0xE000, 0xFFFF, 0xFFFF, 0xFFFF, "Winbond(0xE000)"},
{0xE000, 0xE000, 0xFFFF, 0xFFFF, "W89C940(0xE000)"},
}; /* pci_vid_E000[] */

static pci_id_t const pci_vid_E159[] = {
{0xE159, 0xFFFF, 0xFFFF, 0xFFFF, "Tiger Jet Network Inc. / ICP DAS(0xE159)"},
{0xE159, 0x0001, 0xFFFF, 0xFFFF, "Tiger3XX Modem/ISDN interface(0x0001)"},
{0xE159, 0x0001, 0x0059, 0x0001, "128k ISDN-S/T Adapter(0x0059-0x0001)"},
{0xE159, 0x0001, 0x0059, 0x0003, "128k ISDN-U Adapter(0x0059-0x0003)"},
{0xE159, 0x0001, 0x00A7, 0x0001, "TELES.S0/PCI 2.x ISDN Adapter(0x00A7-0x0001)"},
{0xE159, 0x0001, 0x8086, 0x0003, "Digium X100P/X101P analogue PSTN FXO interface(0x8086-0x0003)"},
{0xE159, 0x0001, 0xB100, 0x0003, "OpenVox A400P 4-port analog card(0xB100-0x0003)"},
{0xE159, 0x0001, 0xB1D9, 0x0003, "AX400P 4-port analog card(0xB1D9-0x0003)"},
{0xE159, 0x0002, 0xFFFF, 0xFFFF, "Tiger100APC ISDN chipset(0x0002)"},
}; /* pci_vid_E159[] */

static pci_id_t const pci_vid_E1C5[] = {
{0xE1C5, 0xFFFF, 0xFFFF, 0xFFFF, "Elcus(0xE1C5)"},
}; /* pci_vid_E1C5[] */

static pci_id_t const pci_vid_E4BF[] = {
{0xE4BF, 0xFFFF, 0xFFFF, 0xFFFF, "EKF Elektronik GmbH(0xE4BF)"},
{0xE4BF, 0x0CCD, 0xFFFF, 0xFFFF, "CCD-CALYPSO(0x0CCD)"},
{0xE4BF, 0x0CD1, 0xFFFF, 0xFFFF, "CD1-OPERA(0x0CD1)"},
{0xE4BF, 0x0CD2, 0xFFFF, 0xFFFF, "CD2-BEBOP(0x0CD2)"},
{0xE4BF, 0x0CD3, 0xFFFF, 0xFFFF, "CD3-JIVE(0x0CD3)"},
{0xE4BF, 0x50C1, 0xFFFF, 0xFFFF, "PC1-GROOVE(0x50C1)"},
{0xE4BF, 0x50C2, 0xFFFF, 0xFFFF, "PC2-LIMBO(0x50C2)"},
{0xE4BF, 0x53C1, 0xFFFF, 0xFFFF, "SC1-ALLEGRO(0x53C1)"},
{0xE4BF, 0xCC47, 0xFFFF, 0xFFFF, "CCG-RUMBA(0xCC47)"},
{0xE4BF, 0xCC4D, 0xFFFF, 0xFFFF, "CCM-BOOGIE(0xCC4D)"},
}; /* pci_vid_E4BF[] */

static pci_id_t const pci_vid_E4E4[] = {
{0xE4E4, 0xFFFF, 0xFFFF, 0xFFFF, "Xorcom(0xE4E4)"},
}; /* pci_vid_E4E4[] */

static pci_id_t const pci_vid_E55E[] = {
{0xE55E, 0xFFFF, 0xFFFF, 0xFFFF, "Essence Technology, Inc.(0xE55E)"},
}; /* pci_vid_E55E[] */

static pci_id_t const pci_vid_EA01[] = {
{0xEA01, 0xFFFF, 0xFFFF, 0xFFFF, "Eagle Technology(0xEA01)"},
{0xEA01, 0x000A, 0xFFFF, 0xFFFF, "PCI-773 Temperature Card(0x000A)"},
{0xEA01, 0x0032, 0xFFFF, 0xFFFF, "PCI-730 & PC104P-30 Card(0x0032)"},
{0xEA01, 0x003E, 0xFFFF, 0xFFFF, "PCI-762 Opto-Isolator Card(0x003E)"},
{0xEA01, 0x0041, 0xFFFF, 0xFFFF, "PCI-763 Reed Relay Card(0x0041)"},
{0xEA01, 0x0043, 0xFFFF, 0xFFFF, "PCI-769 Opto-Isolator Reed Relay Combo Card(0x0043)"},
{0xEA01, 0x0046, 0xFFFF, 0xFFFF, "PCI-766 Analog Output Card(0x0046)"},
{0xEA01, 0x0052, 0xFFFF, 0xFFFF, "PCI-703 Analog I/O Card(0x0052)"},
{0xEA01, 0x0800, 0xFFFF, 0xFFFF, "PCI-800 Digital I/O Card(0x0800)"},
}; /* pci_vid_EA01[] */

static pci_id_t const pci_vid_EA50[] = {
{0xEA50, 0xFFFF, 0xFFFF, 0xFFFF, "Emerson Automation Solutions(0xEA50)"},
}; /* pci_vid_EA50[] */

static pci_id_t const pci_vid_EA60[] = {
{0xEA60, 0xFFFF, 0xFFFF, 0xFFFF, "RME(0xEA60)"},
{0xEA60, 0x9896, 0xFFFF, 0xFFFF, "Digi32(0x9896)"},
{0xEA60, 0x9897, 0xFFFF, 0xFFFF, "Digi32 Pro(0x9897)"},
{0xEA60, 0x9898, 0xFFFF, 0xFFFF, "Digi32/8(0x9898)"},
}; /* pci_vid_EA60[] */

static pci_id_t const pci_vid_EABB[] = {
{0xEABB, 0xFFFF, 0xFFFF, 0xFFFF, "Aashima Technology B.V.(0xEABB)"},
}; /* pci_vid_EABB[] */

static pci_id_t const pci_vid_EACE[] = {
{0xEACE, 0xFFFF, 0xFFFF, 0xFFFF, "Endace Measurement Systems, Ltd(0xEACE)"},
{0xEACE, 0x3100, 0xFFFF, 0xFFFF, "DAG 3.10 OC-3/OC-12(0x3100)"},
{0xEACE, 0x3200, 0xFFFF, 0xFFFF, "DAG 3.2x OC-3/OC-12(0x3200)"},
{0xEACE, 0x320E, 0xFFFF, 0xFFFF, "DAG 3.2E Fast Ethernet(0x320E)"},
{0xEACE, 0x340E, 0xFFFF, 0xFFFF, "DAG 3.4E Fast Ethernet(0x340E)"},
{0xEACE, 0x341E, 0xFFFF, 0xFFFF, "DAG 3.41E Fast Ethernet(0x341E)"},
{0xEACE, 0x3500, 0xFFFF, 0xFFFF, "DAG 3.5 OC-3/OC-12(0x3500)"},
{0xEACE, 0x351C, 0xFFFF, 0xFFFF, "DAG 3.5ECM Fast Ethernet(0x351C)"},
{0xEACE, 0x360D, 0xFFFF, 0xFFFF, "DAG 3.6D DS3(0x360D)"},
{0xEACE, 0x360E, 0xFFFF, 0xFFFF, "DAG 3.6E Fast Ethernet(0x360E)"},
{0xEACE, 0x368E, 0xFFFF, 0xFFFF, "DAG 3.6E Gig Ethernet(0x368E)"},
{0xEACE, 0x3707, 0xFFFF, 0xFFFF, "DAG 3.7T T1/E1/J1(0x3707)"},
{0xEACE, 0x370D, 0xFFFF, 0xFFFF, "DAG 3.7D DS3/E3(0x370D)"},
{0xEACE, 0x378E, 0xFFFF, 0xFFFF, "DAG 3.7G Gig Ethernet(0x378E)"},
{0xEACE, 0x3800, 0xFFFF, 0xFFFF, "DAG 3.8S OC-3/OC-12(0x3800)"},
{0xEACE, 0x4100, 0xFFFF, 0xFFFF, "DAG 4.10 OC-48(0x4100)"},
{0xEACE, 0x4110, 0xFFFF, 0xFFFF, "DAG 4.11 OC-48(0x4110)"},
{0xEACE, 0x4220, 0xFFFF, 0xFFFF, "DAG 4.2 OC-48(0x4220)"},
{0xEACE, 0x422E, 0xFFFF, 0xFFFF, "DAG 4.2GE Gig Ethernet(0x422E)"},
{0xEACE, 0x4230, 0xFFFF, 0xFFFF, "DAG 4.2S OC-48(0x4230)"},
{0xEACE, 0x423E, 0xFFFF, 0xFFFF, "DAG 4.2GE Gig Ethernet(0x423E)"},
{0xEACE, 0x4300, 0xFFFF, 0xFFFF, "DAG 4.3S OC-48(0x4300)"},
{0xEACE, 0x430E, 0xFFFF, 0xFFFF, "DAG 4.3GE Gig Ethernet(0x430E)"},
{0xEACE, 0x452E, 0xFFFF, 0xFFFF, "DAG 4.5G2 Gig Ethernet(0x452E)"},
{0xEACE, 0x454E, 0xFFFF, 0xFFFF, "DAG 4.5G4 Gig Ethernet(0x454E)"},
{0xEACE, 0x45B8, 0xFFFF, 0xFFFF, "DAG 4.5Z8 Gig Ethernet(0x45B8)"},
{0xEACE, 0x45BE, 0xFFFF, 0xFFFF, "DAG 4.5Z2 Gig Ethernet(0x45BE)"},
{0xEACE, 0x520E, 0xFFFF, 0xFFFF, "DAG 5.2X 10G Ethernet(0x520E)"},
{0xEACE, 0x521A, 0xFFFF, 0xFFFF, "DAG 5.2SXA 10G Ethernet/OC-192(0x521A)"},
{0xEACE, 0x5400, 0xFFFF, 0xFFFF, "DAG 5.4S-12 OC-3/OC-12(0x5400)"},
{0xEACE, 0x5401, 0xFFFF, 0xFFFF, "DAG 5.4SG-48 Gig Ethernet/OC-3/OC-12/OC-48(0x5401)"},
{0xEACE, 0x540A, 0xFFFF, 0xFFFF, "DAG 5.4GA Gig Ethernet(0x540A)"},
{0xEACE, 0x541A, 0xFFFF, 0xFFFF, "DAG 5.4SA-12 OC-3/OC-12(0x541A)"},
{0xEACE, 0x542A, 0xFFFF, 0xFFFF, "DAG 5.4SGA-48 Gig Ethernet/OC-3/OC-12/OC-48(0x542A)"},
{0xEACE, 0x6000, 0xFFFF, 0xFFFF, "DAG 6.0SE 10G Ethernet/OC-192(0x6000)"},
{0xEACE, 0x6100, 0xFFFF, 0xFFFF, "DAG 6.1SE 10G Ethernet/OC-192(0x6100)"},
{0xEACE, 0x6200, 0xFFFF, 0xFFFF, "DAG 6.2SE 10G Ethernet/OC-192(0x6200)"},
{0xEACE, 0x7100, 0xFFFF, 0xFFFF, "DAG 7.1S OC-3/OC-12(0x7100)"},
{0xEACE, 0x7400, 0xFFFF, 0xFFFF, "DAG 7.4S OC-3/OC-12(0x7400)"},
{0xEACE, 0x7401, 0xFFFF, 0xFFFF, "DAG 7.4S48 OC-48(0x7401)"},
{0xEACE, 0x752E, 0xFFFF, 0xFFFF, "DAG 7.5G2 Gig Ethernet(0x752E)"},
{0xEACE, 0x754E, 0xFFFF, 0xFFFF, "DAG 7.5G4 Gig Ethernet(0x754E)"},
{0xEACE, 0x8100, 0xFFFF, 0xFFFF, "DAG 8.1X 10G Ethernet(0x8100)"},
{0xEACE, 0x8101, 0xFFFF, 0xFFFF, "DAG 8.1SX 10G Ethernet/OC-192(0x8101)"},
{0xEACE, 0x8102, 0xFFFF, 0xFFFF, "DAG 8.1X 10G Ethernet(0x8102)"},
{0xEACE, 0x820E, 0xFFFF, 0xFFFF, "DAG 8.2X 10G Ethernet(0x820E)"},
{0xEACE, 0x820F, 0xFFFF, 0xFFFF, "DAG 8.2X 10G Ethernet (2nd bus)(0x820F)"},
{0xEACE, 0x8400, 0xFFFF, 0xFFFF, "DAG 8.4I Infiniband x4 SDR(0x8400)"},
{0xEACE, 0x8500, 0xFFFF, 0xFFFF, "DAG 8.5I Infiniband x4 DDR(0x8500)"},
{0xEACE, 0x9200, 0xFFFF, 0xFFFF, "DAG 9.2SX2 10G Ethernet(0x9200)"},
{0xEACE, 0x920E, 0xFFFF, 0xFFFF, "DAG 9.2X2 10G Ethernet(0x920E)"},
{0xEACE, 0x9540, 0xFFFF, 0xFFFF, "DAG 9.5G4 Gig Ethernet(0x9540)"},
{0xEACE, 0x954F, 0xFFFF, 0xFFFF, "DAG 9.5G4F Gig Ethernet(0x954F)"},
{0xEACE, 0xA120, 0xFFFF, 0xFFFF, "DAG 10X2-P 10G Ethernet(0xA120)"},
{0xEACE, 0xA12E, 0xFFFF, 0xFFFF, "DAG 10X2-S 10G Ethernet(0xA12E)"},
{0xEACE, 0xA140, 0xFFFF, 0xFFFF, "DAG 10X4-P 10/40G Ethernet(0xA140)"},
{0xEACE, 0xA14E, 0xFFFF, 0xFFFF, "DAG 10X4-S 10/40G Ethernet(0xA14E)"},
{0xEACE, 0xEACE, 0xFFFF, 0xFFFF, "vDAG virtual device(0xEACE)"},
}; /* pci_vid_EACE[] */

static pci_id_t const pci_vid_EC80[] = {
{0xEC80, 0xFFFF, 0xFFFF, 0xFFFF, "Belkin Corporation(0xEC80)"},
{0xEC80, 0xEC00, 0xFFFF, 0xFFFF, "F5D6000(0xEC00)"},
}; /* pci_vid_EC80[] */

static pci_id_t const pci_vid_ECC0[] = {
{0xECC0, 0xFFFF, 0xFFFF, 0xFFFF, "Echo Digital Audio Corporation(0xECC0)"},
}; /* pci_vid_ECC0[] */

static pci_id_t const pci_vid_EDD8[] = {
{0xEDD8, 0xFFFF, 0xFFFF, 0xFFFF, "ARK Logic Inc(0xEDD8)"},
{0xEDD8, 0xA091, 0xFFFF, 0xFFFF, "1000PV [Stingray](0xA091)"},
{0xEDD8, 0xA099, 0xFFFF, 0xFFFF, "2000PV [Stingray](0xA099)"},
{0xEDD8, 0xA0A1, 0xFFFF, 0xFFFF, "2000MT(0xA0A1)"},
{0xEDD8, 0xA0A9, 0xFFFF, 0xFFFF, "2000MI(0xA0A9)"},
}; /* pci_vid_EDD8[] */

static pci_id_t const pci_vid_F043[] = {
{0xF043, 0xFFFF, 0xFFFF, 0xFFFF, "ASUSTeK Computer Inc. (Wrong ID)(0xF043)"},
}; /* pci_vid_F043[] */

static pci_id_t const pci_vid_F05B[] = {
{0xF05B, 0xFFFF, 0xFFFF, 0xFFFF, "Foxconn International, Inc. (Wrong ID)(0xF05B)"},
}; /* pci_vid_F05B[] */

static pci_id_t const pci_vid_F111[] = {
{0xF111, 0xFFFF, 0xFFFF, 0xFFFF, "Framework Computer Inc.(0xF111)"},
}; /* pci_vid_F111[] */

static pci_id_t const pci_vid_F117[] = {
{0xF117, 0xFFFF, 0xFFFF, 0xFFFF, "Cerio(0xF117)"},
{0xF117, 0x1000, 0xFFFF, 0xFFFF, "Emulated PCIe Switch(0x1000)"},
{0xF117, 0x1010, 0xFFFF, 0xFFFF, "Placeholder Device(0x1010)"},
{0xF117, 0x1020, 0xFFFF, 0xFFFF, "Pseudo-Device(0x1020)"},
{0xF117, 0x1030, 0xFFFF, 0xFFFF, "Test Device(0x1030)"},
}; /* pci_vid_F117[] */

static pci_id_t const pci_vid_F15E[] = {
{0xF15E, 0xFFFF, 0xFFFF, 0xFFFF, "SiFive, Inc.(0xF15E)"},
{0xF15E, 0x0000, 0xFFFF, 0xFFFF, "FU740-C000 RISC-V SoC PCI Express x8 to AXI4 Bridge(0x0000)"},
}; /* pci_vid_F15E[] */

static pci_id_t const pci_vid_F1D0[] = {
{0xF1D0, 0xFFFF, 0xFFFF, 0xFFFF, "AJA Video(0xF1D0)"},
{0xF1D0, 0xC0FE, 0xFFFF, 0xFFFF, "Xena HS/HD-R(0xC0FE)"},
{0xF1D0, 0xC0FF, 0xFFFF, 0xFFFF, "Kona/Xena 2(0xC0FF)"},
{0xF1D0, 0xCAFE, 0xFFFF, 0xFFFF, "Kona SD(0xCAFE)"},
{0xF1D0, 0xCFEE, 0xFFFF, 0xFFFF, "Xena LS/SD-22-DA/SD-DA(0xCFEE)"},
{0xF1D0, 0xDAFE, 0xFFFF, 0xFFFF, "Corvid 1(0xDAFE)"},
{0xF1D0, 0xDAFF, 0xFFFF, 0xFFFF, "KONA LHi(0xDAFF)"},
{0xF1D0, 0xDB00, 0xFFFF, 0xFFFF, "IoExpress(0xDB00)"},
{0xF1D0, 0xDB01, 0xFFFF, 0xFFFF, "Corvid22(0xDB01)"},
{0xF1D0, 0xDB02, 0xFFFF, 0xFFFF, "Kona 3G(0xDB02)"},
{0xF1D0, 0xDB03, 0xFFFF, 0xFFFF, "Corvid 3G(0xDB03)"},
{0xF1D0, 0xDB04, 0xFFFF, 0xFFFF, "Kona 3G QUAD(0xDB04)"},
{0xF1D0, 0xDB05, 0xFFFF, 0xFFFF, "Kona LHe+(0xDB05)"},
{0xF1D0, 0xDB06, 0xFFFF, 0xFFFF, "IoXT(0xDB06)"},
{0xF1D0, 0xDB07, 0xFFFF, 0xFFFF, "Kona 3G P2P(0xDB07)"},
{0xF1D0, 0xDB08, 0xFFFF, 0xFFFF, "Kona 3G QUAD P2P(0xDB08)"},
{0xF1D0, 0xDB09, 0xFFFF, 0xFFFF, "Corvid 24(0xDB09)"},
{0xF1D0, 0xDB11, 0xFFFF, 0xFFFF, "T-Tap(0xDB11)"},
{0xF1D0, 0xDCAF, 0xFFFF, 0xFFFF, "Kona HD(0xDCAF)"},
{0xF1D0, 0xDFEE, 0xFFFF, 0xFFFF, "Xena HD-DA(0xDFEE)"},
{0xF1D0, 0xEB07, 0xFFFF, 0xFFFF, "Io4K(0xEB07)"},
{0xF1D0, 0xEB0A, 0xFFFF, 0xFFFF, "Io4K UFC(0xEB0A)"},
{0xF1D0, 0xEB0B, 0xFFFF, 0xFFFF, "Kona 4(0xEB0B)"},
{0xF1D0, 0xEB0C, 0xFFFF, 0xFFFF, "Kona 4 UFC(0xEB0C)"},
{0xF1D0, 0xEB0D, 0xFFFF, 0xFFFF, "Corvid 88(0xEB0D)"},
{0xF1D0, 0xEB0E, 0xFFFF, 0xFFFF, "Corvid 44(0xEB0E)"},
{0xF1D0, 0xEB16, 0xFFFF, 0xFFFF, "Corvid HEVC(0xEB16)"},
{0xF1D0, 0xEB16, 0x10CF, 0x1049, "Corvid HEVC M31(0x10CF-0x1049)"},
{0xF1D0, 0xEB18, 0xFFFF, 0xFFFF, "Corvid HB-R(0xEB18)"},
{0xF1D0, 0xEB1A, 0xFFFF, 0xFFFF, "Kona IP 1SFP(0xEB1A)"},
{0xF1D0, 0xEB1C, 0xFFFF, 0xFFFF, "Kona IP 2SFP(0xEB1C)"},
{0xF1D0, 0xEB1D, 0xFFFF, 0xFFFF, "Io4KPlus(0xEB1D)"},
{0xF1D0, 0xEB1E, 0xFFFF, 0xFFFF, "IoIP(0xEB1E)"},
{0xF1D0, 0xEB1F, 0xFFFF, 0xFFFF, "Kona 5(0xEB1F)"},
{0xF1D0, 0xEB23, 0xFFFF, 0xFFFF, "Kona 1(0xEB23)"},
{0xF1D0, 0xEB24, 0xFFFF, 0xFFFF, "Kona HDMI(0xEB24)"},
{0xF1D0, 0xEB25, 0xFFFF, 0xFFFF, "Corvid 44 12g(0xEB25)"},
{0xF1D0, 0xEB26, 0xFFFF, 0xFFFF, "T-Tap Pro(0xEB26)"},
{0xF1D0, 0xEB27, 0xFFFF, 0xFFFF, "IoX3(0xEB27)"},
{0xF1D0, 0xEFAC, 0xFFFF, 0xFFFF, "Xena SD-MM/SD-22-MM(0xEFAC)"},
{0xF1D0, 0xFACD, 0xFFFF, 0xFFFF, "Xena HD-MM(0xFACD)"},
}; /* pci_vid_F1D0[] */

static pci_id_t const pci_vid_F5F5[] = {
{0xF5F5, 0xFFFF, 0xFFFF, 0xFFFF, "F5 Networks, Inc.(0xF5F5)"},
}; /* pci_vid_F5F5[] */

static pci_id_t const pci_vid_F849[] = {
{0xF849, 0xFFFF, 0xFFFF, 0xFFFF, "ASRock Incorporation (Wrong ID)(0xF849)"},
}; /* pci_vid_F849[] */

static pci_id_t const pci_vid_FA57[] = {
{0xFA57, 0xFFFF, 0xFFFF, 0xFFFF, "Interagon AS(0xFA57)"},
{0xFA57, 0x0001, 0xFFFF, 0xFFFF, "PMC [Pattern Matching Chip](0x0001)"},
}; /* pci_vid_FA57[] */

static pci_id_t const pci_vid_FAB7[] = {
{0xFAB7, 0xFFFF, 0xFFFF, 0xFFFF, "Fabric7 Systems, Inc.(0xFAB7)"},
}; /* pci_vid_FAB7[] */

static pci_id_t const pci_vid_FE19[] = {
{0xFE19, 0xFFFF, 0xFFFF, 0xFFFF, "TenaFe, Inc.(0xFE19)"},
{0xFE19, 0x0001, 0xFFFF, 0xFFFF, "TC2200/TC2201 NVMe Controller (DRAM-less)(0x0001)"},
}; /* pci_vid_FE19[] */

static pci_id_t const pci_vid_FEBD[] = {
{0xFEBD, 0xFFFF, 0xFFFF, 0xFFFF, "Ultraview Corp.(0xFEBD)"},
}; /* pci_vid_FEBD[] */

static pci_id_t const pci_vid_FEDA[] = {
{0xFEDA, 0xFFFF, 0xFFFF, 0xFFFF, "Broadcom Inc(0xFEDA)"},
{0xFEDA, 0xA0FA, 0xFFFF, 0xFFFF, "BCM4210 iLine10 HomePNA 2.0(0xA0FA)"},
{0xFEDA, 0xA10E, 0xFFFF, 0xFFFF, "BCM4230 iLine10 HomePNA 2.0(0xA10E)"},
}; /* pci_vid_FEDA[] */

static pci_id_t const pci_vid_FEDE[] = {
{0xFEDE, 0xFFFF, 0xFFFF, 0xFFFF, "Fedetec Inc.(0xFEDE)"},
{0xFEDE, 0x0003, 0xFFFF, 0xFFFF, "TABIC PCI v3(0x0003)"},
}; /* pci_vid_FEDE[] */

static pci_id_t const pci_vid_FFE1[] = {
{0xFFE1, 0xFFFF, 0xFFFF, 0xFFFF, "Suzhou XiongLi Technology Inc.(0xFFE1)"},
{0xFFE1, 0xD200, 0xFFFF, 0xFFFF, "XL82101/82102 PCI Express Gigabit Ethernet Controller(0xD200)"},
}; /* pci_vid_FFE1[] */

static pci_id_t const pci_vid_FFFD[] = {
{0xFFFD, 0xFFFF, 0xFFFF, 0xFFFF, "XenSource, Inc.(0xFFFD)"},
{0xFFFD, 0x0101, 0xFFFF, 0xFFFF, "PCI Event Channel Controller(0x0101)"},
}; /* pci_vid_FFFD[] */

static pci_id_t const pci_vid_FFFE[] = {
{0xFFFE, 0xFFFF, 0xFFFF, 0xFFFF, "VMWare Inc (temporary ID)(0xFFFE)"},
{0xFFFE, 0x0710, 0xFFFF, 0xFFFF, "Virtual SVGA(0x0710)"},
}; /* pci_vid_FFFE[] */

static pci_id_t const pci_vid_FFFF[] = {
{0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, "Illegal Vendor ID(0xFFFF)"},
}; /* pci_vid_FFFF[] */

static pci_vid_index_t const pci_vid_index[] = {
{0x0001, 1, pci_vid_0001 },
{0x0010, 2, pci_vid_0010 },
{0x0014, 21, pci_vid_0014 },
{0x0018, 2, pci_vid_0018 },
{0x001C, 4, pci_vid_001C },
{0x003D, 1, pci_vid_003D },
{0x0059, 1, pci_vid_0059 },
{0x0070, 2, pci_vid_0070 },
{0x0071, 1, pci_vid_0071 },
{0x0095, 2, pci_vid_0095 },
{0x00A7, 1, pci_vid_00A7 },
{0x0100, 1, pci_vid_0100 },
{0x0123, 1, pci_vid_0123 },
{0x0128, 1, pci_vid_0128 },
{0x018A, 2, pci_vid_018A },
{0x01DE, 4, pci_vid_01DE },
{0x0200, 1, pci_vid_0200 },
{0x021B, 2, pci_vid_021B },
{0x025E, 33, pci_vid_025E },
{0x0270, 1, pci_vid_0270 },
{0x0291, 1, pci_vid_0291 },
{0x02AC, 2, pci_vid_02AC },
{0x02E0, 1, pci_vid_02E0 },
{0x0303, 1, pci_vid_0303 },
{0x0308, 1, pci_vid_0308 },
{0x0315, 1, pci_vid_0315 },
{0x0357, 2, pci_vid_0357 },
{0x0432, 2, pci_vid_0432 },
{0x0497, 1, pci_vid_0497 },
{0x060E, 2, pci_vid_060E },
{0x0675, 5, pci_vid_0675 },
{0x0721, 1, pci_vid_0721 },
{0x0731, 38, pci_vid_0731 },
{0x0777, 1, pci_vid_0777 },
{0x0795, 3, pci_vid_0795 },
{0x07D1, 1, pci_vid_07D1 },
{0x0824, 1, pci_vid_0824 },
{0x0925, 1, pci_vid_0925 },
{0x0A89, 1, pci_vid_0A89 },
{0x0B0B, 15, pci_vid_0B0B },
{0x0BAE, 1, pci_vid_0BAE },
{0x0CCD, 7, pci_vid_0CCD },
{0x0E11, 109, pci_vid_0E11 },
{0x0E55, 1, pci_vid_0E55 },
{0x0EAC, 2, pci_vid_0EAC },
{0x0F62, 1, pci_vid_0F62 },
{0x1000, 806, pci_vid_1000 },
{0x1001, 10, pci_vid_1001 },
{0x1002, 3254, pci_vid_1002 },
{0x1003, 2, pci_vid_1003 },
{0x1004, 34, pci_vid_1004 },
{0x1005, 8, pci_vid_1005 },
{0x1006, 1, pci_vid_1006 },
{0x1007, 1, pci_vid_1007 },
{0x1008, 1, pci_vid_1008 },
{0x100A, 1, pci_vid_100A },
{0x100B, 40, pci_vid_100B },
{0x100C, 7, pci_vid_100C },
{0x100D, 1, pci_vid_100D },
{0x100E, 5, pci_vid_100E },
{0x1010, 1, pci_vid_1010 },
{0x1011, 103, pci_vid_1011 },
{0x1012, 1, pci_vid_1012 },
{0x1013, 54, pci_vid_1013 },
{0x1014, 163, pci_vid_1014 },
{0x1015, 1, pci_vid_1015 },
{0x1016, 1, pci_vid_1016 },
{0x1017, 2, pci_vid_1017 },
{0x1018, 1, pci_vid_1018 },
{0x1019, 2, pci_vid_1019 },
{0x101A, 17, pci_vid_101A },
{0x101B, 2, pci_vid_101B },
{0x101C, 12, pci_vid_101C },
{0x101D, 1, pci_vid_101D },
{0x101E, 26, pci_vid_101E },
{0x101F, 1, pci_vid_101F },
{0x1020, 1, pci_vid_1020 },
{0x1021, 1, pci_vid_1021 },
{0x1022, 691, pci_vid_1022 },
{0x1023, 56, pci_vid_1023 },
{0x1024, 4, pci_vid_1024 },
{0x1025, 59, pci_vid_1025 },
{0x1028, 48, pci_vid_1028 },
{0x1029, 1, pci_vid_1029 },
{0x102A, 12, pci_vid_102A },
{0x102B, 303, pci_vid_102B },
{0x102C, 26, pci_vid_102C },
{0x102D, 2, pci_vid_102D },
{0x102E, 1, pci_vid_102E },
{0x102F, 18, pci_vid_102F },
{0x1030, 1, pci_vid_1030 },
{0x1031, 5, pci_vid_1031 },
{0x1032, 1, pci_vid_1032 },
{0x1033, 78, pci_vid_1033 },
{0x1034, 1, pci_vid_1034 },
{0x1035, 1, pci_vid_1035 },
{0x1036, 2, pci_vid_1036 },
{0x1037, 1, pci_vid_1037 },
{0x1038, 1, pci_vid_1038 },
{0x1039, 187, pci_vid_1039 },
{0x103A, 1, pci_vid_103A },
{0x103B, 1, pci_vid_103B },
{0x103C, 147, pci_vid_103C },
{0x103E, 1, pci_vid_103E },
{0x103F, 1, pci_vid_103F },
{0x1040, 1, pci_vid_1040 },
{0x1041, 1, pci_vid_1041 },
{0x1042, 6, pci_vid_1042 },
{0x1043, 7, pci_vid_1043 },
{0x1044, 44, pci_vid_1044 },
{0x1045, 24, pci_vid_1045 },
{0x1046, 1, pci_vid_1046 },
{0x1047, 1, pci_vid_1047 },
{0x1048, 7, pci_vid_1048 },
{0x1049, 1, pci_vid_1049 },
{0x104A, 30, pci_vid_104A },
{0x104B, 4, pci_vid_104B },
{0x104C, 290, pci_vid_104C },
{0x104D, 47, pci_vid_104D },
{0x104E, 7, pci_vid_104E },
{0x104F, 1, pci_vid_104F },
{0x1050, 20, pci_vid_1050 },
{0x1051, 1, pci_vid_1051 },
{0x1052, 1, pci_vid_1052 },
{0x1053, 1, pci_vid_1053 },
{0x1054, 17, pci_vid_1054 },
{0x1055, 8, pci_vid_1055 },
{0x1056, 1, pci_vid_1056 },
{0x1057, 85, pci_vid_1057 },
{0x1058, 1, pci_vid_1058 },
{0x1059, 3, pci_vid_1059 },
{0x105A, 81, pci_vid_105A },
{0x105B, 3, pci_vid_105B },
{0x105C, 1, pci_vid_105C },
{0x105D, 37, pci_vid_105D },
{0x105E, 1, pci_vid_105E },
{0x105F, 1, pci_vid_105F },
{0x1060, 23, pci_vid_1060 },
{0x1061, 3, pci_vid_1061 },
{0x1062, 1, pci_vid_1062 },
{0x1063, 1, pci_vid_1063 },
{0x1064, 2, pci_vid_1064 },
{0x1065, 1, pci_vid_1065 },
{0x1066, 8, pci_vid_1066 },
{0x1067, 5, pci_vid_1067 },
{0x1068, 1, pci_vid_1068 },
{0x1069, 25, pci_vid_1069 },
{0x106A, 1, pci_vid_106A },
{0x106B, 80, pci_vid_106B },
{0x106C, 7, pci_vid_106C },
{0x106D, 1, pci_vid_106D },
{0x106E, 1, pci_vid_106E },
{0x106F, 1, pci_vid_106F },
{0x1070, 1, pci_vid_1070 },
{0x1071, 2, pci_vid_1071 },
{0x1072, 1, pci_vid_1072 },
{0x1073, 28, pci_vid_1073 },
{0x1074, 2, pci_vid_1074 },
{0x1075, 1, pci_vid_1075 },
{0x1076, 1, pci_vid_1076 },
{0x1077, 259, pci_vid_1077 },
{0x1078, 13, pci_vid_1078 },
{0x1079, 1, pci_vid_1079 },
{0x107A, 1, pci_vid_107A },
{0x107B, 1, pci_vid_107B },
{0x107C, 1, pci_vid_107C },
{0x107D, 2, pci_vid_107D },
{0x107E, 17, pci_vid_107E },
{0x107F, 2, pci_vid_107F },
{0x1080, 4, pci_vid_1080 },
{0x1081, 2, pci_vid_1081 },
{0x1082, 1, pci_vid_1082 },
{0x1083, 2, pci_vid_1083 },
{0x1084, 1, pci_vid_1084 },
{0x1086, 1, pci_vid_1086 },
{0x1087, 1, pci_vid_1087 },
{0x1088, 1, pci_vid_1088 },
{0x1089, 1, pci_vid_1089 },
{0x108A, 5, pci_vid_108A },
{0x108C, 1, pci_vid_108C },
{0x108D, 20, pci_vid_108D },
{0x108E, 58, pci_vid_108E },
{0x108F, 1, pci_vid_108F },
{0x1090, 3, pci_vid_1090 },
{0x1091, 11, pci_vid_1091 },
{0x1092, 24, pci_vid_1092 },
{0x1093, 781, pci_vid_1093 },
{0x1094, 1, pci_vid_1094 },
{0x1095, 36, pci_vid_1095 },
{0x1096, 1, pci_vid_1096 },
{0x1097, 1, pci_vid_1097 },
{0x1098, 3, pci_vid_1098 },
{0x1099, 1, pci_vid_1099 },
{0x109A, 1, pci_vid_109A },
{0x109B, 1, pci_vid_109B },
{0x109C, 1, pci_vid_109C },
{0x109D, 1, pci_vid_109D },
{0x109E, 190, pci_vid_109E },
{0x109F, 1, pci_vid_109F },
{0x10A0, 1, pci_vid_10A0 },
{0x10A1, 1, pci_vid_10A1 },
{0x10A2, 1, pci_vid_10A2 },
{0x10A3, 1, pci_vid_10A3 },
{0x10A4, 1, pci_vid_10A4 },
{0x10A5, 3, pci_vid_10A5 },
{0x10A6, 1, pci_vid_10A6 },
{0x10A7, 1, pci_vid_10A7 },
{0x10A8, 2, pci_vid_10A8 },
{0x10A9, 32, pci_vid_10A9 },
{0x10AA, 4, pci_vid_10AA },
{0x10AB, 1, pci_vid_10AB },
{0x10AC, 1, pci_vid_10AC },
{0x10AD, 7, pci_vid_10AD },
{0x10AE, 1, pci_vid_10AE },
{0x10AF, 1, pci_vid_10AF },
{0x10B0, 1, pci_vid_10B0 },
{0x10B1, 1, pci_vid_10B1 },
{0x10B2, 1, pci_vid_10B2 },
{0x10B3, 3, pci_vid_10B3 },
{0x10B4, 3, pci_vid_10B4 },
{0x10B5, 276, pci_vid_10B5 },
{0x10B6, 25, pci_vid_10B6 },
{0x10B7, 132, pci_vid_10B7 },
{0x10B8, 21, pci_vid_10B8 },
{0x10B9, 121, pci_vid_10B9 },
{0x10BA, 6, pci_vid_10BA },
{0x10BB, 1, pci_vid_10BB },
{0x10BC, 1, pci_vid_10BC },
{0x10BD, 2, pci_vid_10BD },
{0x10BE, 1, pci_vid_10BE },
{0x10BF, 1, pci_vid_10BF },
{0x10C0, 2, pci_vid_10C0 },
{0x10C1, 1, pci_vid_10C1 },
{0x10C2, 1, pci_vid_10C2 },
{0x10C3, 1, pci_vid_10C3 },
{0x10C4, 1, pci_vid_10C4 },
{0x10C5, 1, pci_vid_10C5 },
{0x10C6, 1, pci_vid_10C6 },
{0x10C7, 1, pci_vid_10C7 },
{0x10C8, 47, pci_vid_10C8 },
{0x10C9, 1, pci_vid_10C9 },
{0x10CA, 1, pci_vid_10CA },
{0x10CB, 1, pci_vid_10CB },
{0x10CC, 3, pci_vid_10CC },
{0x10CD, 9, pci_vid_10CD },
{0x10CE, 1, pci_vid_10CE },
{0x10CF, 14, pci_vid_10CF },
{0x10D1, 1, pci_vid_10D1 },
{0x10D2, 1, pci_vid_10D2 },
{0x10D3, 1, pci_vid_10D3 },
{0x10D4, 1, pci_vid_10D4 },
{0x10D5, 1, pci_vid_10D5 },
{0x10D6, 1, pci_vid_10D6 },
{0x10D7, 1, pci_vid_10D7 },
{0x10D8, 1, pci_vid_10D8 },
{0x10D9, 8, pci_vid_10D9 },
{0x10DA, 3, pci_vid_10DA },
{0x10DB, 1, pci_vid_10DB },
{0x10DC, 6, pci_vid_10DC },
{0x10DD, 3, pci_vid_10DD },
{0x10DE, 3319, pci_vid_10DE },
{0x10DF, 127, pci_vid_10DF },
{0x10E0, 7, pci_vid_10E0 },
{0x10E1, 5, pci_vid_10E1 },
{0x10E2, 1, pci_vid_10E2 },
{0x10E3, 11, pci_vid_10E3 },
{0x10E4, 2, pci_vid_10E4 },
{0x10E5, 1, pci_vid_10E5 },
{0x10E6, 1, pci_vid_10E6 },
{0x10E7, 1, pci_vid_10E7 },
{0x10E8, 36, pci_vid_10E8 },
{0x10E9, 1, pci_vid_10E9 },
{0x10EA, 10, pci_vid_10EA },
{0x10EB, 3, pci_vid_10EB },
{0x10EC, 246, pci_vid_10EC },
{0x10ED, 2, pci_vid_10ED },
{0x10EE, 47, pci_vid_10EE },
{0x10EF, 2, pci_vid_10EF },
{0x10F0, 1, pci_vid_10F0 },
{0x10F1, 3, pci_vid_10F1 },
{0x10F2, 1, pci_vid_10F2 },
{0x10F3, 1, pci_vid_10F3 },
{0x10F4, 1, pci_vid_10F4 },
{0x10F5, 2, pci_vid_10F5 },
{0x10F6, 1, pci_vid_10F6 },
{0x10F7, 1, pci_vid_10F7 },
{0x10F8, 1, pci_vid_10F8 },
{0x10F9, 1, pci_vid_10F9 },
{0x10FA, 2, pci_vid_10FA },
{0x10FB, 2, pci_vid_10FB },
{0x10FC, 3, pci_vid_10FC },
{0x10FD, 1, pci_vid_10FD },
{0x10FE, 1, pci_vid_10FE },
{0x10FF, 1, pci_vid_10FF },
{0x1100, 1, pci_vid_1100 },
{0x1101, 9, pci_vid_1101 },
{0x1102, 148, pci_vid_1102 },
{0x1103, 53, pci_vid_1103 },
{0x1104, 1, pci_vid_1104 },
{0x1105, 15, pci_vid_1105 },
{0x1106, 579, pci_vid_1106 },
{0x1107, 2, pci_vid_1107 },
{0x1108, 9, pci_vid_1108 },
{0x1109, 2, pci_vid_1109 },
{0x110A, 33, pci_vid_110A },
{0x110B, 3, pci_vid_110B },
{0x110C, 1, pci_vid_110C },
{0x110D, 1, pci_vid_110D },
{0x110E, 1, pci_vid_110E },
{0x110F, 1, pci_vid_110F },
{0x1110, 3, pci_vid_1110 },
{0x1111, 1, pci_vid_1111 },
{0x1112, 5, pci_vid_1112 },
{0x1113, 17, pci_vid_1113 },
{0x1114, 2, pci_vid_1114 },
{0x1115, 1, pci_vid_1115 },
{0x1116, 12, pci_vid_1116 },
{0x1117, 3, pci_vid_1117 },
{0x1118, 1, pci_vid_1118 },
{0x1119, 72, pci_vid_1119 },
{0x111A, 17, pci_vid_111A },
{0x111B, 1, pci_vid_111B },
{0x111C, 2, pci_vid_111C },
{0x111D, 63, pci_vid_111D },
{0x111E, 1, pci_vid_111E },
{0x111F, 3, pci_vid_111F },
{0x1120, 4, pci_vid_1120 },
{0x1121, 1, pci_vid_1121 },
{0x1122, 1, pci_vid_1122 },
{0x1123, 1, pci_vid_1123 },
{0x1124, 2, pci_vid_1124 },
{0x1125, 1, pci_vid_1125 },
{0x1126, 1, pci_vid_1126 },
{0x1127, 8, pci_vid_1127 },
{0x1129, 1, pci_vid_1129 },
{0x112A, 1, pci_vid_112A },
{0x112B, 2, pci_vid_112B },
{0x112C, 1, pci_vid_112C },
{0x112D, 1, pci_vid_112D },
{0x112E, 1, pci_vid_112E },
{0x112F, 5, pci_vid_112F },
{0x1130, 1, pci_vid_1130 },
{0x1131, 241, pci_vid_1131 },
{0x1132, 1, pci_vid_1132 },
{0x1133, 92, pci_vid_1133 },
{0x1134, 5, pci_vid_1134 },
{0x1135, 2, pci_vid_1135 },
{0x1136, 2, pci_vid_1136 },
{0x1137, 91, pci_vid_1137 },
{0x1138, 2, pci_vid_1138 },
{0x1139, 2, pci_vid_1139 },
{0x113A, 1, pci_vid_113A },
{0x113B, 1, pci_vid_113B },
{0x113C, 7, pci_vid_113C },
{0x113D, 1, pci_vid_113D },
{0x113E, 1, pci_vid_113E },
{0x113F, 8, pci_vid_113F },
{0x1140, 1, pci_vid_1140 },
{0x1141, 1, pci_vid_1141 },
{0x1142, 6, pci_vid_1142 },
{0x1143, 1, pci_vid_1143 },
{0x1144, 2, pci_vid_1144 },
{0x1145, 11, pci_vid_1145 },
{0x1146, 1, pci_vid_1146 },
{0x1147, 1, pci_vid_1147 },
{0x1148, 83, pci_vid_1148 },
{0x1149, 1, pci_vid_1149 },
{0x114A, 6, pci_vid_114A },
{0x114B, 1, pci_vid_114B },
{0x114C, 1, pci_vid_114C },
{0x114D, 1, pci_vid_114D },
{0x114E, 1, pci_vid_114E },
{0x114F, 64, pci_vid_114F },
{0x1150, 1, pci_vid_1150 },
{0x1151, 1, pci_vid_1151 },
{0x1152, 1, pci_vid_1152 },
{0x1153, 1, pci_vid_1153 },
{0x1154, 1, pci_vid_1154 },
{0x1155, 1, pci_vid_1155 },
{0x1156, 1, pci_vid_1156 },
{0x1157, 1, pci_vid_1157 },
{0x1158, 4, pci_vid_1158 },
{0x1159, 3, pci_vid_1159 },
{0x115A, 1, pci_vid_115A },
{0x115B, 1, pci_vid_115B },
{0x115C, 1, pci_vid_115C },
{0x115D, 37, pci_vid_115D },
{0x115E, 1, pci_vid_115E },
{0x115F, 1, pci_vid_115F },
{0x1160, 1, pci_vid_1160 },
{0x1161, 1, pci_vid_1161 },
{0x1162, 1, pci_vid_1162 },
{0x1163, 4, pci_vid_1163 },
{0x1164, 1, pci_vid_1164 },
{0x1165, 2, pci_vid_1165 },
{0x1166, 84, pci_vid_1166 },
{0x1167, 1, pci_vid_1167 },
{0x1168, 1, pci_vid_1168 },
{0x1169, 1, pci_vid_1169 },
{0x116A, 5, pci_vid_116A },
{0x116B, 1, pci_vid_116B },
{0x116C, 1, pci_vid_116C },
{0x116D, 1, pci_vid_116D },
{0x116E, 1, pci_vid_116E },
{0x116F, 1, pci_vid_116F },
{0x1170, 1, pci_vid_1170 },
{0x1171, 1, pci_vid_1171 },
{0x1172, 4, pci_vid_1172 },
{0x1173, 1, pci_vid_1173 },
{0x1174, 1, pci_vid_1174 },
{0x1175, 1, pci_vid_1175 },
{0x1176, 1, pci_vid_1176 },
{0x1177, 1, pci_vid_1177 },
{0x1178, 2, pci_vid_1178 },
{0x1179, 41, pci_vid_1179 },
{0x117A, 1, pci_vid_117A },
{0x117B, 1, pci_vid_117B },
{0x117C, 66, pci_vid_117C },
{0x117D, 1, pci_vid_117D },
{0x117E, 1, pci_vid_117E },
{0x117F, 1, pci_vid_117F },
{0x1180, 140, pci_vid_1180 },
{0x1181, 1, pci_vid_1181 },
{0x1183, 1, pci_vid_1183 },
{0x1184, 1, pci_vid_1184 },
{0x1185, 1, pci_vid_1185 },
{0x1186, 35, pci_vid_1186 },
{0x1187, 1, pci_vid_1187 },
{0x1188, 1, pci_vid_1188 },
{0x1189, 1, pci_vid_1189 },
{0x118A, 1, pci_vid_118A },
{0x118B, 1, pci_vid_118B },
{0x118C, 3, pci_vid_118C },
{0x118D, 19, pci_vid_118D },
{0x118E, 1, pci_vid_118E },
{0x118F, 1, pci_vid_118F },
{0x1190, 2, pci_vid_1190 },
{0x1191, 24, pci_vid_1191 },
{0x1192, 1, pci_vid_1192 },
{0x1193, 3, pci_vid_1193 },
{0x1194, 1, pci_vid_1194 },
{0x1195, 1, pci_vid_1195 },
{0x1196, 1, pci_vid_1196 },
{0x1197, 2, pci_vid_1197 },
{0x1198, 1, pci_vid_1198 },
{0x1199, 2, pci_vid_1199 },
{0x119A, 1, pci_vid_119A },
{0x119B, 2, pci_vid_119B },
{0x119C, 1, pci_vid_119C },
{0x119D, 1, pci_vid_119D },
{0x119E, 3, pci_vid_119E },
{0x119F, 4, pci_vid_119F },
{0x11A0, 1, pci_vid_11A0 },
{0x11A1, 1, pci_vid_11A1 },
{0x11A2, 1, pci_vid_11A2 },
{0x11A3, 1, pci_vid_11A3 },
{0x11A4, 1, pci_vid_11A4 },
{0x11A5, 1, pci_vid_11A5 },
{0x11A6, 1, pci_vid_11A6 },
{0x11A7, 1, pci_vid_11A7 },
{0x11A8, 1, pci_vid_11A8 },
{0x11A9, 2, pci_vid_11A9 },
{0x11AA, 1, pci_vid_11AA },
{0x11AB, 230, pci_vid_11AB },
{0x11AC, 1, pci_vid_11AC },
{0x11AD, 11, pci_vid_11AD },
{0x11AE, 1, pci_vid_11AE },
{0x11AF, 5, pci_vid_11AF },
{0x11B0, 6, pci_vid_11B0 },
{0x11B1, 1, pci_vid_11B1 },
{0x11B2, 1, pci_vid_11B2 },
{0x11B3, 1, pci_vid_11B3 },
{0x11B4, 1, pci_vid_11B4 },
{0x11B5, 1, pci_vid_11B5 },
{0x11B6, 1, pci_vid_11B6 },
{0x11B7, 1, pci_vid_11B7 },
{0x11B8, 2, pci_vid_11B8 },
{0x11B9, 2, pci_vid_11B9 },
{0x11BA, 1, pci_vid_11BA },
{0x11BB, 1, pci_vid_11BB },
{0x11BC, 2, pci_vid_11BC },
{0x11BD, 13, pci_vid_11BD },
{0x11BE, 1, pci_vid_11BE },
{0x11BF, 1, pci_vid_11BF },
{0x11C0, 1, pci_vid_11C0 },
{0x11C1, 140, pci_vid_11C1 },
{0x11C2, 1, pci_vid_11C2 },
{0x11C3, 1, pci_vid_11C3 },
{0x11C4, 1, pci_vid_11C4 },
{0x11C5, 1, pci_vid_11C5 },
{0x11C6, 1, pci_vid_11C6 },
{0x11C7, 1, pci_vid_11C7 },
{0x11C8, 4, pci_vid_11C8 },
{0x11C9, 3, pci_vid_11C9 },
{0x11CA, 1, pci_vid_11CA },
{0x11CB, 6, pci_vid_11CB },
{0x11CC, 1, pci_vid_11CC },
{0x11CD, 1, pci_vid_11CD },
{0x11CE, 1, pci_vid_11CE },
{0x11CF, 1, pci_vid_11CF },
{0x11D0, 1, pci_vid_11D0 },
{0x11D1, 3, pci_vid_11D1 },
{0x11D2, 1, pci_vid_11D2 },
{0x11D3, 1, pci_vid_11D3 },
{0x11D4, 3, pci_vid_11D4 },
{0x11D5, 3, pci_vid_11D5 },
{0x11D6, 1, pci_vid_11D6 },
{0x11D7, 1, pci_vid_11D7 },
{0x11D8, 1, pci_vid_11D8 },
{0x11D9, 1, pci_vid_11D9 },
{0x11DA, 1, pci_vid_11DA },
{0x11DB, 1, pci_vid_11DB },
{0x11DC, 1, pci_vid_11DC },
{0x11DD, 1, pci_vid_11DD },
{0x11DE, 11, pci_vid_11DE },
{0x11DF, 1, pci_vid_11DF },
{0x11E0, 1, pci_vid_11E0 },
{0x11E1, 1, pci_vid_11E1 },
{0x11E2, 1, pci_vid_11E2 },
{0x11E3, 37, pci_vid_11E3 },
{0x11E4, 1, pci_vid_11E4 },
{0x11E5, 1, pci_vid_11E5 },
{0x11E6, 1, pci_vid_11E6 },
{0x11E7, 1, pci_vid_11E7 },
{0x11E8, 1, pci_vid_11E8 },
{0x11E9, 1, pci_vid_11E9 },
{0x11EA, 1, pci_vid_11EA },
{0x11EB, 1, pci_vid_11EB },
{0x11EC, 3, pci_vid_11EC },
{0x11ED, 1, pci_vid_11ED },
{0x11EE, 1, pci_vid_11EE },
{0x11EF, 1, pci_vid_11EF },
{0x11F0, 8, pci_vid_11F0 },
{0x11F1, 1, pci_vid_11F1 },
{0x11F2, 1, pci_vid_11F2 },
{0x11F3, 2, pci_vid_11F3 },
{0x11F4, 2, pci_vid_11F4 },
{0x11F5, 1, pci_vid_11F5 },
{0x11F6, 9, pci_vid_11F6 },
{0x11F7, 1, pci_vid_11F7 },
{0x11F8, 32, pci_vid_11F8 },
{0x11F9, 1, pci_vid_11F9 },
{0x11FA, 1, pci_vid_11FA },
{0x11FB, 1, pci_vid_11FB },
{0x11FC, 1, pci_vid_11FC },
{0x11FD, 1, pci_vid_11FD },
{0x11FE, 64, pci_vid_11FE },
{0x11FF, 2, pci_vid_11FF },
{0x1200, 1, pci_vid_1200 },
{0x1201, 1, pci_vid_1201 },
{0x1202, 6, pci_vid_1202 },
{0x1203, 1, pci_vid_1203 },
{0x1204, 2, pci_vid_1204 },
{0x1205, 1, pci_vid_1205 },
{0x1206, 1, pci_vid_1206 },
{0x1208, 2, pci_vid_1208 },
{0x1209, 1, pci_vid_1209 },
{0x120A, 1, pci_vid_120A },
{0x120B, 1, pci_vid_120B },
{0x120C, 1, pci_vid_120C },
{0x120D, 1, pci_vid_120D },
{0x120E, 16, pci_vid_120E },
{0x120F, 2, pci_vid_120F },
{0x1210, 1, pci_vid_1210 },
{0x1211, 1, pci_vid_1211 },
{0x1213, 1, pci_vid_1213 },
{0x1214, 1, pci_vid_1214 },
{0x1215, 1, pci_vid_1215 },
{0x1216, 1, pci_vid_1216 },
{0x1217, 59, pci_vid_1217 },
{0x1218, 1, pci_vid_1218 },
{0x1219, 1, pci_vid_1219 },
{0x121A, 45, pci_vid_121A },
{0x121B, 1, pci_vid_121B },
{0x121C, 1, pci_vid_121C },
{0x121D, 1, pci_vid_121D },
{0x121E, 2, pci_vid_121E },
{0x121F, 1, pci_vid_121F },
{0x1220, 2, pci_vid_1220 },
{0x1221, 6, pci_vid_1221 },
{0x1222, 1, pci_vid_1222 },
{0x1223, 11, pci_vid_1223 },
{0x1224, 1, pci_vid_1224 },
{0x1225, 1, pci_vid_1225 },
{0x1227, 5, pci_vid_1227 },
{0x1228, 1, pci_vid_1228 },
{0x1229, 1, pci_vid_1229 },
{0x122A, 1, pci_vid_122A },
{0x122B, 1, pci_vid_122B },
{0x122C, 1, pci_vid_122C },
{0x122D, 7, pci_vid_122D },
{0x122E, 4, pci_vid_122E },
{0x122F, 1, pci_vid_122F },
{0x1230, 1, pci_vid_1230 },
{0x1231, 6, pci_vid_1231 },
{0x1232, 1, pci_vid_1232 },
{0x1233, 1, pci_vid_1233 },
{0x1235, 1, pci_vid_1235 },
{0x1236, 3, pci_vid_1236 },
{0x1237, 1, pci_vid_1237 },
{0x1238, 1, pci_vid_1238 },
{0x1239, 1, pci_vid_1239 },
{0x123A, 1, pci_vid_123A },
{0x123B, 1, pci_vid_123B },
{0x123C, 1, pci_vid_123C },
{0x123D, 12, pci_vid_123D },
{0x123E, 1, pci_vid_123E },
{0x123F, 16, pci_vid_123F },
{0x1240, 1, pci_vid_1240 },
{0x1241, 1, pci_vid_1241 },
{0x1242, 7, pci_vid_1242 },
{0x1243, 1, pci_vid_1243 },
{0x1244, 12, pci_vid_1244 },
{0x1245, 1, pci_vid_1245 },
{0x1246, 1, pci_vid_1246 },
{0x1247, 1, pci_vid_1247 },
{0x1248, 1, pci_vid_1248 },
{0x1249, 1, pci_vid_1249 },
{0x124A, 1, pci_vid_124A },
{0x124B, 3, pci_vid_124B },
{0x124C, 1, pci_vid_124C },
{0x124D, 5, pci_vid_124D },
{0x124E, 1, pci_vid_124E },
{0x124F, 2, pci_vid_124F },
{0x1250, 1, pci_vid_1250 },
{0x1251, 1, pci_vid_1251 },
{0x1253, 1, pci_vid_1253 },
{0x1254, 3, pci_vid_1254 },
{0x1255, 6, pci_vid_1255 },
{0x1256, 4, pci_vid_1256 },
{0x1257, 1, pci_vid_1257 },
{0x1258, 1, pci_vid_1258 },
{0x1259, 6, pci_vid_1259 },
{0x125A, 1, pci_vid_125A },
{0x125B, 9, pci_vid_125B },
{0x125C, 3, pci_vid_125C },
{0x125D, 46, pci_vid_125D },
{0x125E, 1, pci_vid_125E },
{0x125F, 4, pci_vid_125F },
{0x1260, 38, pci_vid_1260 },
{0x1261, 1, pci_vid_1261 },
{0x1262, 1, pci_vid_1262 },
{0x1263, 1, pci_vid_1263 },
{0x1264, 1, pci_vid_1264 },
{0x1265, 1, pci_vid_1265 },
{0x1266, 4, pci_vid_1266 },
{0x1267, 3, pci_vid_1267 },
{0x1268, 1, pci_vid_1268 },
{0x1269, 2, pci_vid_1269 },
{0x126A, 1, pci_vid_126A },
{0x126B, 1, pci_vid_126B },
{0x126C, 3, pci_vid_126C },
{0x126D, 1, pci_vid_126D },
{0x126E, 1, pci_vid_126E },
{0x126F, 20, pci_vid_126F },
{0x1270, 1, pci_vid_1270 },
{0x1271, 1, pci_vid_1271 },
{0x1272, 1, pci_vid_1272 },
{0x1273, 2, pci_vid_1273 },
{0x1274, 71, pci_vid_1274 },
{0x1275, 1, pci_vid_1275 },
{0x1276, 1, pci_vid_1276 },
{0x1277, 1, pci_vid_1277 },
{0x1278, 5, pci_vid_1278 },
{0x1279, 7, pci_vid_1279 },
{0x127A, 116, pci_vid_127A },
{0x127B, 1, pci_vid_127B },
{0x127C, 1, pci_vid_127C },
{0x127D, 1, pci_vid_127D },
{0x127E, 2, pci_vid_127E },
{0x127F, 1, pci_vid_127F },
{0x1280, 1, pci_vid_1280 },
{0x1281, 1, pci_vid_1281 },
{0x1282, 7, pci_vid_1282 },
{0x1283, 17, pci_vid_1283 },
{0x1284, 1, pci_vid_1284 },
{0x1285, 2, pci_vid_1285 },
{0x1286, 1, pci_vid_1286 },
{0x1287, 3, pci_vid_1287 },
{0x1288, 1, pci_vid_1288 },
{0x1289, 1, pci_vid_1289 },
{0x128A, 1, pci_vid_128A },
{0x128B, 1, pci_vid_128B },
{0x128C, 1, pci_vid_128C },
{0x128D, 2, pci_vid_128D },
{0x128E, 6, pci_vid_128E },
{0x128F, 1, pci_vid_128F },
{0x1290, 1, pci_vid_1290 },
{0x1291, 1, pci_vid_1291 },
{0x1292, 2, pci_vid_1292 },
{0x1293, 1, pci_vid_1293 },
{0x1294, 1, pci_vid_1294 },
{0x1295, 3, pci_vid_1295 },
{0x1296, 1, pci_vid_1296 },
{0x1297, 2, pci_vid_1297 },
{0x1298, 1, pci_vid_1298 },
{0x1299, 1, pci_vid_1299 },
{0x129A, 8, pci_vid_129A },
{0x129B, 1, pci_vid_129B },
{0x129C, 1, pci_vid_129C },
{0x129D, 1, pci_vid_129D },
{0x129E, 1, pci_vid_129E },
{0x129F, 1, pci_vid_129F },
{0x12A0, 1, pci_vid_12A0 },
{0x12A1, 1, pci_vid_12A1 },
{0x12A2, 1, pci_vid_12A2 },
{0x12A3, 2, pci_vid_12A3 },
{0x12A4, 1, pci_vid_12A4 },
{0x12A5, 1, pci_vid_12A5 },
{0x12A6, 1, pci_vid_12A6 },
{0x12A7, 1, pci_vid_12A7 },
{0x12A8, 1, pci_vid_12A8 },
{0x12A9, 1, pci_vid_12A9 },
{0x12AA, 1, pci_vid_12AA },
{0x12AB, 9, pci_vid_12AB },
{0x12AC, 1, pci_vid_12AC },
{0x12AD, 1, pci_vid_12AD },
{0x12AE, 8, pci_vid_12AE },
{0x12AF, 2, pci_vid_12AF },
{0x12B0, 1, pci_vid_12B0 },
{0x12B1, 1, pci_vid_12B1 },
{0x12B2, 1, pci_vid_12B2 },
{0x12B3, 1, pci_vid_12B3 },
{0x12B4, 1, pci_vid_12B4 },
{0x12B5, 1, pci_vid_12B5 },
{0x12B6, 1, pci_vid_12B6 },
{0x12B7, 1, pci_vid_12B7 },
{0x12B8, 1, pci_vid_12B8 },
{0x12B9, 22, pci_vid_12B9 },
{0x12BA, 1, pci_vid_12BA },
{0x12BB, 1, pci_vid_12BB },
{0x12BC, 1, pci_vid_12BC },
{0x12BD, 1, pci_vid_12BD },
{0x12BE, 4, pci_vid_12BE },
{0x12BF, 1, pci_vid_12BF },
{0x12C0, 1, pci_vid_12C0 },
{0x12C1, 1, pci_vid_12C1 },
{0x12C2, 1, pci_vid_12C2 },
{0x12C3, 3, pci_vid_12C3 },
{0x12C4, 29, pci_vid_12C4 },
{0x12C5, 6, pci_vid_12C5 },
{0x12C6, 1, pci_vid_12C6 },
{0x12C7, 5, pci_vid_12C7 },
{0x12C8, 1, pci_vid_12C8 },
{0x12C9, 1, pci_vid_12C9 },
{0x12CA, 1, pci_vid_12CA },
{0x12CB, 3, pci_vid_12CB },
{0x12CC, 1, pci_vid_12CC },
{0x12CD, 1, pci_vid_12CD },
{0x12CE, 1, pci_vid_12CE },
{0x12CF, 1, pci_vid_12CF },
{0x12D0, 1, pci_vid_12D0 },
{0x12D1, 1, pci_vid_12D1 },
{0x12D2, 29, pci_vid_12D2 },
{0x12D3, 1, pci_vid_12D3 },
{0x12D4, 2, pci_vid_12D4 },
{0x12D5, 3, pci_vid_12D5 },
{0x12D6, 1, pci_vid_12D6 },
{0x12D7, 1, pci_vid_12D7 },
{0x12D8, 28, pci_vid_12D8 },
{0x12D9, 7, pci_vid_12D9 },
{0x12DA, 1, pci_vid_12DA },
{0x12DB, 1, pci_vid_12DB },
{0x12DC, 1, pci_vid_12DC },
{0x12DD, 1, pci_vid_12DD },
{0x12DE, 2, pci_vid_12DE },
{0x12DF, 1, pci_vid_12DF },
{0x12E0, 4, pci_vid_12E0 },
{0x12E1, 1, pci_vid_12E1 },
{0x12E2, 1, pci_vid_12E2 },
{0x12E3, 1, pci_vid_12E3 },
{0x12E4, 1, pci_vid_12E4 },
{0x12E5, 1, pci_vid_12E5 },
{0x12E6, 1, pci_vid_12E6 },
{0x12E7, 1, pci_vid_12E7 },
{0x12E8, 1, pci_vid_12E8 },
{0x12E9, 1, pci_vid_12E9 },
{0x12EA, 1, pci_vid_12EA },
{0x12EB, 36, pci_vid_12EB },
{0x12EC, 1, pci_vid_12EC },
{0x12ED, 1, pci_vid_12ED },
{0x12EE, 1, pci_vid_12EE },
{0x12EF, 1, pci_vid_12EF },
{0x12F0, 1, pci_vid_12F0 },
{0x12F1, 1, pci_vid_12F1 },
{0x12F2, 1, pci_vid_12F2 },
{0x12F3, 1, pci_vid_12F3 },
{0x12F4, 1, pci_vid_12F4 },
{0x12F5, 1, pci_vid_12F5 },
{0x12F6, 1, pci_vid_12F6 },
{0x12F7, 1, pci_vid_12F7 },
{0x12F8, 2, pci_vid_12F8 },
{0x12F9, 1, pci_vid_12F9 },
{0x12FB, 15, pci_vid_12FB },
{0x12FC, 1, pci_vid_12FC },
{0x12FD, 1, pci_vid_12FD },
{0x12FE, 1, pci_vid_12FE },
{0x12FF, 1, pci_vid_12FF },
{0x1300, 1, pci_vid_1300 },
{0x1302, 1, pci_vid_1302 },
{0x1303, 2, pci_vid_1303 },
{0x1304, 1, pci_vid_1304 },
{0x1305, 1, pci_vid_1305 },
{0x1306, 1, pci_vid_1306 },
{0x1307, 77, pci_vid_1307 },
{0x1308, 3, pci_vid_1308 },
{0x1309, 1, pci_vid_1309 },
{0x130A, 1, pci_vid_130A },
{0x130B, 1, pci_vid_130B },
{0x130C, 1, pci_vid_130C },
{0x130D, 1, pci_vid_130D },
{0x130E, 1, pci_vid_130E },
{0x130F, 1, pci_vid_130F },
{0x1310, 1, pci_vid_1310 },
{0x1311, 1, pci_vid_1311 },
{0x1312, 1, pci_vid_1312 },
{0x1313, 1, pci_vid_1313 },
{0x1315, 1, pci_vid_1315 },
{0x1316, 1, pci_vid_1316 },
{0x1317, 14, pci_vid_1317 },
{0x1318, 2, pci_vid_1318 },
{0x1319, 7, pci_vid_1319 },
{0x131A, 1, pci_vid_131A },
{0x131C, 1, pci_vid_131C },
{0x131D, 1, pci_vid_131D },
{0x131E, 1, pci_vid_131E },
{0x131F, 40, pci_vid_131F },
{0x1320, 1, pci_vid_1320 },
{0x1321, 1, pci_vid_1321 },
{0x1322, 1, pci_vid_1322 },
{0x1323, 1, pci_vid_1323 },
{0x1324, 1, pci_vid_1324 },
{0x1325, 1, pci_vid_1325 },
{0x1326, 1, pci_vid_1326 },
{0x1327, 1, pci_vid_1327 },
{0x1328, 1, pci_vid_1328 },
{0x1329, 1, pci_vid_1329 },
{0x132A, 1, pci_vid_132A },
{0x132B, 1, pci_vid_132B },
{0x132C, 1, pci_vid_132C },
{0x132D, 1, pci_vid_132D },
{0x1330, 1, pci_vid_1330 },
{0x1331, 6, pci_vid_1331 },
{0x1332, 4, pci_vid_1332 },
{0x1334, 1, pci_vid_1334 },
{0x1335, 1, pci_vid_1335 },
{0x1337, 1, pci_vid_1337 },
{0x1338, 1, pci_vid_1338 },
{0x133A, 1, pci_vid_133A },
{0x133B, 1, pci_vid_133B },
{0x133C, 1, pci_vid_133C },
{0x133D, 1, pci_vid_133D },
{0x133E, 1, pci_vid_133E },
{0x133F, 1, pci_vid_133F },
{0x1340, 1, pci_vid_1340 },
{0x1341, 1, pci_vid_1341 },
{0x1342, 1, pci_vid_1342 },
{0x1343, 1, pci_vid_1343 },
{0x1344, 137, pci_vid_1344 },
{0x1345, 1, pci_vid_1345 },
{0x1347, 1, pci_vid_1347 },
{0x1349, 1, pci_vid_1349 },
{0x134A, 3, pci_vid_134A },
{0x134B, 1, pci_vid_134B },
{0x134C, 1, pci_vid_134C },
{0x134D, 13, pci_vid_134D },
{0x134E, 1, pci_vid_134E },
{0x134F, 1, pci_vid_134F },
{0x1350, 1, pci_vid_1350 },
{0x1351, 1, pci_vid_1351 },
{0x1353, 7, pci_vid_1353 },
{0x1354, 1, pci_vid_1354 },
{0x1355, 1, pci_vid_1355 },
{0x1356, 1, pci_vid_1356 },
{0x1359, 1, pci_vid_1359 },
{0x135A, 91, pci_vid_135A },
{0x135B, 1, pci_vid_135B },
{0x135C, 22, pci_vid_135C },
{0x135D, 1, pci_vid_135D },
{0x135E, 10, pci_vid_135E },
{0x135F, 1, pci_vid_135F },
{0x1360, 24, pci_vid_1360 },
{0x1361, 1, pci_vid_1361 },
{0x1362, 1, pci_vid_1362 },
{0x1363, 1, pci_vid_1363 },
{0x1364, 1, pci_vid_1364 },
{0x1365, 1, pci_vid_1365 },
{0x1366, 1, pci_vid_1366 },
{0x1367, 1, pci_vid_1367 },
{0x1368, 1, pci_vid_1368 },
{0x1369, 1, pci_vid_1369 },
{0x136A, 5, pci_vid_136A },
{0x136B, 2, pci_vid_136B },
{0x136C, 1, pci_vid_136C },
{0x136D, 1, pci_vid_136D },
{0x136F, 1, pci_vid_136F },
{0x1370, 1, pci_vid_1370 },
{0x1371, 3, pci_vid_1371 },
{0x1373, 1, pci_vid_1373 },
{0x1374, 43, pci_vid_1374 },
{0x1375, 1, pci_vid_1375 },
{0x1376, 1, pci_vid_1376 },
{0x1377, 1, pci_vid_1377 },
{0x1378, 1, pci_vid_1378 },
{0x1379, 1, pci_vid_1379 },
{0x137A, 2, pci_vid_137A },
{0x137B, 1, pci_vid_137B },
{0x137C, 1, pci_vid_137C },
{0x137D, 1, pci_vid_137D },
{0x137E, 1, pci_vid_137E },
{0x137F, 1, pci_vid_137F },
{0x1380, 1, pci_vid_1380 },
{0x1381, 1, pci_vid_1381 },
{0x1382, 12, pci_vid_1382 },
{0x1383, 1, pci_vid_1383 },
{0x1384, 1, pci_vid_1384 },
{0x1385, 6, pci_vid_1385 },
{0x1386, 1, pci_vid_1386 },
{0x1387, 1, pci_vid_1387 },
{0x1388, 1, pci_vid_1388 },
{0x1389, 2, pci_vid_1389 },
{0x138A, 2, pci_vid_138A },
{0x138B, 1, pci_vid_138B },
{0x138C, 1, pci_vid_138C },
{0x138D, 1, pci_vid_138D },
{0x138E, 1, pci_vid_138E },
{0x138F, 1, pci_vid_138F },
{0x1390, 1, pci_vid_1390 },
{0x1391, 1, pci_vid_1391 },
{0x1392, 1, pci_vid_1392 },
{0x1393, 36, pci_vid_1393 },
{0x1394, 4, pci_vid_1394 },
{0x1395, 1, pci_vid_1395 },
{0x1396, 1, pci_vid_1396 },
{0x1397, 50, pci_vid_1397 },
{0x1398, 1, pci_vid_1398 },
{0x1399, 1, pci_vid_1399 },
{0x139A, 4, pci_vid_139A },
{0x139B, 1, pci_vid_139B },
{0x139C, 1, pci_vid_139C },
{0x139D, 1, pci_vid_139D },
{0x139E, 1, pci_vid_139E },
{0x139F, 1, pci_vid_139F },
{0x13A0, 1, pci_vid_13A0 },
{0x13A1, 1, pci_vid_13A1 },
{0x13A2, 1, pci_vid_13A2 },
{0x13A3, 31, pci_vid_13A3 },
{0x13A4, 1, pci_vid_13A4 },
{0x13A5, 1, pci_vid_13A5 },
{0x13A6, 1, pci_vid_13A6 },
{0x13A7, 1, pci_vid_13A7 },
{0x13A8, 8, pci_vid_13A8 },
{0x13A9, 1, pci_vid_13A9 },
{0x13AA, 1, pci_vid_13AA },
{0x13AB, 1, pci_vid_13AB },
{0x13AC, 1, pci_vid_13AC },
{0x13AD, 1, pci_vid_13AD },
{0x13AE, 1, pci_vid_13AE },
{0x13AF, 1, pci_vid_13AF },
{0x13B0, 1, pci_vid_13B0 },
{0x13B1, 1, pci_vid_13B1 },
{0x13B2, 1, pci_vid_13B2 },
{0x13B3, 1, pci_vid_13B3 },
{0x13B4, 1, pci_vid_13B4 },
{0x13B5, 1, pci_vid_13B5 },
{0x13B6, 1, pci_vid_13B6 },
{0x13B7, 1, pci_vid_13B7 },
{0x13B8, 1, pci_vid_13B8 },
{0x13B9, 1, pci_vid_13B9 },
{0x13BA, 1, pci_vid_13BA },
{0x13BB, 1, pci_vid_13BB },
{0x13BC, 1, pci_vid_13BC },
{0x13BD, 1, pci_vid_13BD },
{0x13BE, 1, pci_vid_13BE },
{0x13BF, 1, pci_vid_13BF },
{0x13C0, 8, pci_vid_13C0 },
{0x13C1, 9, pci_vid_13C1 },
{0x13C2, 3, pci_vid_13C2 },
{0x13C3, 1, pci_vid_13C3 },
{0x13C4, 1, pci_vid_13C4 },
{0x13C5, 1, pci_vid_13C5 },
{0x13C6, 6, pci_vid_13C6 },
{0x13C7, 6, pci_vid_13C7 },
{0x13C8, 1, pci_vid_13C8 },
{0x13C9, 1, pci_vid_13C9 },
{0x13CA, 1, pci_vid_13CA },
{0x13CB, 1, pci_vid_13CB },
{0x13CC, 1, pci_vid_13CC },
{0x13CD, 1, pci_vid_13CD },
{0x13CE, 1, pci_vid_13CE },
{0x13CF, 1, pci_vid_13CF },
{0x13D0, 4, pci_vid_13D0 },
{0x13D1, 5, pci_vid_13D1 },
{0x13D2, 1, pci_vid_13D2 },
{0x13D4, 1, pci_vid_13D4 },
{0x13D5, 1, pci_vid_13D5 },
{0x13D6, 1, pci_vid_13D6 },
{0x13D7, 1, pci_vid_13D7 },
{0x13D8, 1, pci_vid_13D8 },
{0x13D9, 1, pci_vid_13D9 },
{0x13DA, 1, pci_vid_13DA },
{0x13DB, 1, pci_vid_13DB },
{0x13DC, 1, pci_vid_13DC },
{0x13DD, 1, pci_vid_13DD },
{0x13DE, 1, pci_vid_13DE },
{0x13DF, 3, pci_vid_13DF },
{0x13E0, 1, pci_vid_13E0 },
{0x13E1, 1, pci_vid_13E1 },
{0x13E2, 1, pci_vid_13E2 },
{0x13E3, 1, pci_vid_13E3 },
{0x13E4, 1, pci_vid_13E4 },
{0x13E5, 1, pci_vid_13E5 },
{0x13E6, 1, pci_vid_13E6 },
{0x13E7, 1, pci_vid_13E7 },
{0x13E8, 1, pci_vid_13E8 },
{0x13E9, 1, pci_vid_13E9 },
{0x13EA, 1, pci_vid_13EA },
{0x13EB, 1, pci_vid_13EB },
{0x13EC, 2, pci_vid_13EC },
{0x13ED, 1, pci_vid_13ED },
{0x13EE, 1, pci_vid_13EE },
{0x13EF, 1, pci_vid_13EF },
{0x13F0, 7, pci_vid_13F0 },
{0x13F1, 1, pci_vid_13F1 },
{0x13F2, 1, pci_vid_13F2 },
{0x13F3, 1, pci_vid_13F3 },
{0x13F4, 2, pci_vid_13F4 },
{0x13F5, 1, pci_vid_13F5 },
{0x13F6, 59, pci_vid_13F6 },
{0x13F7, 1, pci_vid_13F7 },
{0x13F8, 1, pci_vid_13F8 },
{0x13F9, 1, pci_vid_13F9 },
{0x13FA, 1, pci_vid_13FA },
{0x13FB, 1, pci_vid_13FB },
{0x13FC, 1, pci_vid_13FC },
{0x13FD, 1, pci_vid_13FD },
{0x13FE, 23, pci_vid_13FE },
{0x13FF, 1, pci_vid_13FF },
{0x1400, 2, pci_vid_1400 },
{0x1401, 1, pci_vid_1401 },
{0x1402, 77, pci_vid_1402 },
{0x1403, 1, pci_vid_1403 },
{0x1404, 1, pci_vid_1404 },
{0x1405, 1, pci_vid_1405 },
{0x1406, 1, pci_vid_1406 },
{0x1407, 24, pci_vid_1407 },
{0x1408, 1, pci_vid_1408 },
{0x1409, 13, pci_vid_1409 },
{0x140A, 1, pci_vid_140A },
{0x140B, 1, pci_vid_140B },
{0x140C, 1, pci_vid_140C },
{0x140D, 1, pci_vid_140D },
{0x140E, 1, pci_vid_140E },
{0x140F, 1, pci_vid_140F },
{0x1410, 1, pci_vid_1410 },
{0x1411, 1, pci_vid_1411 },
{0x1412, 36, pci_vid_1412 },
{0x1413, 1, pci_vid_1413 },
{0x1414, 20, pci_vid_1414 },
{0x1415, 166, pci_vid_1415 },
{0x1416, 1, pci_vid_1416 },
{0x1417, 1, pci_vid_1417 },
{0x1418, 1, pci_vid_1418 },
{0x1419, 1, pci_vid_1419 },
{0x141A, 1, pci_vid_141A },
{0x141B, 1, pci_vid_141B },
{0x141D, 1, pci_vid_141D },
{0x141E, 1, pci_vid_141E },
{0x141F, 1, pci_vid_141F },
{0x1420, 3, pci_vid_1420 },
{0x1421, 1, pci_vid_1421 },
{0x1422, 1, pci_vid_1422 },
{0x1423, 1, pci_vid_1423 },
{0x1424, 1, pci_vid_1424 },
{0x1425, 674, pci_vid_1425 },
{0x1426, 1, pci_vid_1426 },
{0x1427, 1, pci_vid_1427 },
{0x1428, 1, pci_vid_1428 },
{0x1429, 1, pci_vid_1429 },
{0x142A, 1, pci_vid_142A },
{0x142B, 1, pci_vid_142B },
{0x142C, 1, pci_vid_142C },
{0x142D, 1, pci_vid_142D },
{0x142E, 3, pci_vid_142E },
{0x142F, 1, pci_vid_142F },
{0x1430, 1, pci_vid_1430 },
{0x1431, 1, pci_vid_1431 },
{0x1432, 2, pci_vid_1432 },
{0x1433, 1, pci_vid_1433 },
{0x1435, 10, pci_vid_1435 },
{0x1436, 1, pci_vid_1436 },
{0x1437, 1, pci_vid_1437 },
{0x1438, 1, pci_vid_1438 },
{0x1439, 1, pci_vid_1439 },
{0x143A, 1, pci_vid_143A },
{0x143B, 1, pci_vid_143B },
{0x143C, 1, pci_vid_143C },
{0x143D, 1, pci_vid_143D },
{0x143E, 1, pci_vid_143E },
{0x143F, 1, pci_vid_143F },
{0x1440, 1, pci_vid_1440 },
{0x1441, 1, pci_vid_1441 },
{0x1442, 1, pci_vid_1442 },
{0x1443, 1, pci_vid_1443 },
{0x1444, 1, pci_vid_1444 },
{0x1445, 1, pci_vid_1445 },
{0x1446, 1, pci_vid_1446 },
{0x1447, 1, pci_vid_1447 },
{0x1448, 1, pci_vid_1448 },
{0x1449, 1, pci_vid_1449 },
{0x144A, 15, pci_vid_144A },
{0x144B, 1, pci_vid_144B },
{0x144C, 1, pci_vid_144C },
{0x144D, 165, pci_vid_144D },
{0x144E, 1, pci_vid_144E },
{0x144F, 1, pci_vid_144F },
{0x1450, 1, pci_vid_1450 },
{0x1451, 1, pci_vid_1451 },
{0x1453, 1, pci_vid_1453 },
{0x1454, 1, pci_vid_1454 },
{0x1455, 1, pci_vid_1455 },
{0x1456, 1, pci_vid_1456 },
{0x1457, 1, pci_vid_1457 },
{0x1458, 4, pci_vid_1458 },
{0x1459, 1, pci_vid_1459 },
{0x145A, 1, pci_vid_145A },
{0x145B, 1, pci_vid_145B },
{0x145C, 1, pci_vid_145C },
{0x145D, 1, pci_vid_145D },
{0x145E, 1, pci_vid_145E },
{0x145F, 2, pci_vid_145F },
{0x1460, 1, pci_vid_1460 },
{0x1461, 6, pci_vid_1461 },
{0x1462, 4, pci_vid_1462 },
{0x1463, 1, pci_vid_1463 },
{0x1464, 1, pci_vid_1464 },
{0x1465, 1, pci_vid_1465 },
{0x1466, 1, pci_vid_1466 },
{0x1467, 1, pci_vid_1467 },
{0x1468, 1, pci_vid_1468 },
{0x1469, 1, pci_vid_1469 },
{0x146A, 3, pci_vid_146A },
{0x146B, 1, pci_vid_146B },
{0x146C, 2, pci_vid_146C },
{0x146D, 1, pci_vid_146D },
{0x146E, 1, pci_vid_146E },
{0x146F, 1, pci_vid_146F },
{0x1470, 1, pci_vid_1470 },
{0x1471, 1, pci_vid_1471 },
{0x1472, 1, pci_vid_1472 },
{0x1473, 1, pci_vid_1473 },
{0x1474, 1, pci_vid_1474 },
{0x1475, 1, pci_vid_1475 },
{0x1476, 1, pci_vid_1476 },
{0x1477, 1, pci_vid_1477 },
{0x1478, 1, pci_vid_1478 },
{0x1479, 1, pci_vid_1479 },
{0x147A, 1, pci_vid_147A },
{0x147B, 2, pci_vid_147B },
{0x147C, 1, pci_vid_147C },
{0x147D, 1, pci_vid_147D },
{0x147E, 1, pci_vid_147E },
{0x147F, 1, pci_vid_147F },
{0x1480, 1, pci_vid_1480 },
{0x1481, 1, pci_vid_1481 },
{0x1482, 2, pci_vid_1482 },
{0x1483, 1, pci_vid_1483 },
{0x1484, 1, pci_vid_1484 },
{0x1485, 1, pci_vid_1485 },
{0x1486, 1, pci_vid_1486 },
{0x1487, 1, pci_vid_1487 },
{0x1489, 1, pci_vid_1489 },
{0x148A, 1, pci_vid_148A },
{0x148B, 1, pci_vid_148B },
{0x148C, 3, pci_vid_148C },
{0x148D, 2, pci_vid_148D },
{0x148E, 1, pci_vid_148E },
{0x148F, 1, pci_vid_148F },
{0x1490, 1, pci_vid_1490 },
{0x1491, 1, pci_vid_1491 },
{0x1492, 1, pci_vid_1492 },
{0x1493, 1, pci_vid_1493 },
{0x1494, 1, pci_vid_1494 },
{0x1495, 1, pci_vid_1495 },
{0x1496, 1, pci_vid_1496 },
{0x1497, 2, pci_vid_1497 },
{0x1498, 10, pci_vid_1498 },
{0x1499, 1, pci_vid_1499 },
{0x149A, 1, pci_vid_149A },
{0x149B, 1, pci_vid_149B },
{0x149C, 1, pci_vid_149C },
{0x149D, 2, pci_vid_149D },
{0x149E, 1, pci_vid_149E },
{0x149F, 1, pci_vid_149F },
{0x14A0, 1, pci_vid_14A0 },
{0x14A1, 2, pci_vid_14A1 },
{0x14A2, 1, pci_vid_14A2 },
{0x14A3, 1, pci_vid_14A3 },
{0x14A4, 12, pci_vid_14A4 },
{0x14A5, 1, pci_vid_14A5 },
{0x14A6, 1, pci_vid_14A6 },
{0x14A7, 1, pci_vid_14A7 },
{0x14A8, 1, pci_vid_14A8 },
{0x14A9, 1, pci_vid_14A9 },
{0x14AA, 1, pci_vid_14AA },
{0x14AB, 1, pci_vid_14AB },
{0x14AC, 1, pci_vid_14AC },
{0x14AD, 1, pci_vid_14AD },
{0x14AE, 1, pci_vid_14AE },
{0x14AF, 2, pci_vid_14AF },
{0x14B0, 1, pci_vid_14B0 },
{0x14B1, 1, pci_vid_14B1 },
{0x14B2, 1, pci_vid_14B2 },
{0x14B3, 2, pci_vid_14B3 },
{0x14B4, 1, pci_vid_14B4 },
{0x14B5, 9, pci_vid_14B5 },
{0x14B6, 1, pci_vid_14B6 },
{0x14B7, 2, pci_vid_14B7 },
{0x14B8, 1, pci_vid_14B8 },
{0x14B9, 9, pci_vid_14B9 },
{0x14BA, 2, pci_vid_14BA },
{0x14BB, 1, pci_vid_14BB },
{0x14BC, 3, pci_vid_14BC },
{0x14BD, 1, pci_vid_14BD },
{0x14BE, 1, pci_vid_14BE },
{0x14BF, 1, pci_vid_14BF },
{0x14C0, 2, pci_vid_14C0 },
{0x14C1, 7, pci_vid_14C1 },
{0x14C2, 1, pci_vid_14C2 },
{0x14C3, 15, pci_vid_14C3 },
{0x14C4, 1, pci_vid_14C4 },
{0x14C5, 1, pci_vid_14C5 },
{0x14C6, 1, pci_vid_14C6 },
{0x14C7, 1, pci_vid_14C7 },
{0x14C8, 1, pci_vid_14C8 },
{0x14C9, 1, pci_vid_14C9 },
{0x14CA, 1, pci_vid_14CA },
{0x14CB, 1, pci_vid_14CB },
{0x14CC, 1, pci_vid_14CC },
{0x14CD, 4, pci_vid_14CD },
{0x14CE, 1, pci_vid_14CE },
{0x14CF, 1, pci_vid_14CF },
{0x14D0, 1, pci_vid_14D0 },
{0x14D1, 1, pci_vid_14D1 },
{0x14D2, 24, pci_vid_14D2 },
{0x14D3, 4, pci_vid_14D3 },
{0x14D4, 1, pci_vid_14D4 },
{0x14D5, 1, pci_vid_14D5 },
{0x14D6, 3, pci_vid_14D6 },
{0x14D7, 1, pci_vid_14D7 },
{0x14D8, 1, pci_vid_14D8 },
{0x14D9, 3, pci_vid_14D9 },
{0x14DA, 1, pci_vid_14DA },
{0x14DB, 3, pci_vid_14DB },
{0x14DC, 13, pci_vid_14DC },
{0x14DD, 1, pci_vid_14DD },
{0x14DE, 1, pci_vid_14DE },
{0x14DF, 1, pci_vid_14DF },
{0x14E1, 1, pci_vid_14E1 },
{0x14E2, 1, pci_vid_14E2 },
{0x14E3, 1, pci_vid_14E3 },
{0x14E4, 861, pci_vid_14E4 },
{0x14E5, 1, pci_vid_14E5 },
{0x14E6, 1, pci_vid_14E6 },
{0x14E7, 1, pci_vid_14E7 },
{0x14E8, 1, pci_vid_14E8 },
{0x14E9, 1, pci_vid_14E9 },
{0x14EA, 4, pci_vid_14EA },
{0x14EB, 1, pci_vid_14EB },
{0x14EC, 2, pci_vid_14EC },
{0x14ED, 1, pci_vid_14ED },
{0x14EE, 1, pci_vid_14EE },
{0x14EF, 1, pci_vid_14EF },
{0x14F0, 1, pci_vid_14F0 },
{0x14F1, 284, pci_vid_14F1 },
{0x14F2, 6, pci_vid_14F2 },
{0x14F3, 5, pci_vid_14F3 },
{0x14F4, 1, pci_vid_14F4 },
{0x14F5, 1, pci_vid_14F5 },
{0x14F6, 1, pci_vid_14F6 },
{0x14F7, 1, pci_vid_14F7 },
{0x14F8, 2, pci_vid_14F8 },
{0x14F9, 1, pci_vid_14F9 },
{0x14FA, 1, pci_vid_14FA },
{0x14FB, 1, pci_vid_14FB },
{0x14FC, 4, pci_vid_14FC },
{0x14FD, 1, pci_vid_14FD },
{0x14FE, 1, pci_vid_14FE },
{0x14FF, 1, pci_vid_14FF },
{0x1500, 2, pci_vid_1500 },
{0x1501, 1, pci_vid_1501 },
{0x1502, 1, pci_vid_1502 },
{0x1503, 1, pci_vid_1503 },
{0x1504, 1, pci_vid_1504 },
{0x1505, 1, pci_vid_1505 },
{0x1506, 1, pci_vid_1506 },
{0x1507, 10, pci_vid_1507 },
{0x1508, 1, pci_vid_1508 },
{0x1509, 1, pci_vid_1509 },
{0x150A, 1, pci_vid_150A },
{0x150B, 1, pci_vid_150B },
{0x150C, 1, pci_vid_150C },
{0x150D, 1, pci_vid_150D },
{0x150E, 1, pci_vid_150E },
{0x150F, 1, pci_vid_150F },
{0x1510, 1, pci_vid_1510 },
{0x1511, 1, pci_vid_1511 },
{0x1512, 1, pci_vid_1512 },
{0x1513, 1, pci_vid_1513 },
{0x1514, 1, pci_vid_1514 },
{0x1515, 1, pci_vid_1515 },
{0x1516, 5, pci_vid_1516 },
{0x1517, 1, pci_vid_1517 },
{0x1518, 1, pci_vid_1518 },
{0x1519, 1, pci_vid_1519 },
{0x151A, 4, pci_vid_151A },
{0x151B, 1, pci_vid_151B },
{0x151C, 3, pci_vid_151C },
{0x151D, 1, pci_vid_151D },
{0x151E, 1, pci_vid_151E },
{0x151F, 2, pci_vid_151F },
{0x1520, 1, pci_vid_1520 },
{0x1521, 1, pci_vid_1521 },
{0x1522, 34, pci_vid_1522 },
{0x1523, 1, pci_vid_1523 },
{0x1524, 24, pci_vid_1524 },
{0x1525, 1, pci_vid_1525 },
{0x1526, 1, pci_vid_1526 },
{0x1527, 1, pci_vid_1527 },
{0x1528, 1, pci_vid_1528 },
{0x1529, 1, pci_vid_1529 },
{0x152A, 1, pci_vid_152A },
{0x152B, 1, pci_vid_152B },
{0x152C, 1, pci_vid_152C },
{0x152D, 1, pci_vid_152D },
{0x152E, 1, pci_vid_152E },
{0x152F, 1, pci_vid_152F },
{0x1530, 1, pci_vid_1530 },
{0x1531, 1, pci_vid_1531 },
{0x1532, 2, pci_vid_1532 },
{0x1533, 1, pci_vid_1533 },
{0x1534, 1, pci_vid_1534 },
{0x1535, 1, pci_vid_1535 },
{0x1536, 1, pci_vid_1536 },
{0x1537, 1, pci_vid_1537 },
{0x1538, 2, pci_vid_1538 },
{0x1539, 1, pci_vid_1539 },
{0x153A, 1, pci_vid_153A },
{0x153B, 4, pci_vid_153B },
{0x153C, 1, pci_vid_153C },
{0x153D, 1, pci_vid_153D },
{0x153E, 1, pci_vid_153E },
{0x153F, 2, pci_vid_153F },
{0x1540, 1, pci_vid_1540 },
{0x1541, 1, pci_vid_1541 },
{0x1542, 13, pci_vid_1542 },
{0x1543, 3, pci_vid_1543 },
{0x1544, 1, pci_vid_1544 },
{0x1545, 1, pci_vid_1545 },
{0x1546, 1, pci_vid_1546 },
{0x1547, 1, pci_vid_1547 },
{0x1548, 1, pci_vid_1548 },
{0x1549, 1, pci_vid_1549 },
{0x154A, 1, pci_vid_154A },
{0x154B, 1, pci_vid_154B },
{0x154C, 1, pci_vid_154C },
{0x154D, 1, pci_vid_154D },
{0x154E, 1, pci_vid_154E },
{0x154F, 1, pci_vid_154F },
{0x1550, 1, pci_vid_1550 },
{0x1551, 1, pci_vid_1551 },
{0x1552, 1, pci_vid_1552 },
{0x1553, 1, pci_vid_1553 },
{0x1554, 1, pci_vid_1554 },
{0x1555, 1, pci_vid_1555 },
{0x1556, 11, pci_vid_1556 },
{0x1557, 1, pci_vid_1557 },
{0x1558, 2, pci_vid_1558 },
{0x1559, 1, pci_vid_1559 },
{0x155A, 1, pci_vid_155A },
{0x155B, 1, pci_vid_155B },
{0x155C, 1, pci_vid_155C },
{0x155D, 1, pci_vid_155D },
{0x155E, 1, pci_vid_155E },
{0x155F, 1, pci_vid_155F },
{0x1560, 1, pci_vid_1560 },
{0x1561, 1, pci_vid_1561 },
{0x1562, 1, pci_vid_1562 },
{0x1563, 1, pci_vid_1563 },
{0x1564, 1, pci_vid_1564 },
{0x1565, 1, pci_vid_1565 },
{0x1566, 1, pci_vid_1566 },
{0x1567, 1, pci_vid_1567 },
{0x1568, 1, pci_vid_1568 },
{0x1569, 1, pci_vid_1569 },
{0x156A, 1, pci_vid_156A },
{0x156B, 1, pci_vid_156B },
{0x156C, 1, pci_vid_156C },
{0x156D, 1, pci_vid_156D },
{0x156E, 1, pci_vid_156E },
{0x156F, 1, pci_vid_156F },
{0x1570, 1, pci_vid_1570 },
{0x1571, 20, pci_vid_1571 },
{0x1572, 1, pci_vid_1572 },
{0x1573, 1, pci_vid_1573 },
{0x1574, 1, pci_vid_1574 },
{0x1575, 1, pci_vid_1575 },
{0x1576, 1, pci_vid_1576 },
{0x1578, 3, pci_vid_1578 },
{0x1579, 1, pci_vid_1579 },
{0x157A, 1, pci_vid_157A },
{0x157B, 1, pci_vid_157B },
{0x157C, 2, pci_vid_157C },
{0x157D, 1, pci_vid_157D },
{0x157E, 1, pci_vid_157E },
{0x157F, 1, pci_vid_157F },
{0x1580, 1, pci_vid_1580 },
{0x1581, 1, pci_vid_1581 },
{0x1582, 1, pci_vid_1582 },
{0x1583, 1, pci_vid_1583 },
{0x1584, 1, pci_vid_1584 },
{0x1585, 1, pci_vid_1585 },
{0x1586, 1, pci_vid_1586 },
{0x1587, 1, pci_vid_1587 },
{0x1588, 1, pci_vid_1588 },
{0x1589, 3, pci_vid_1589 },
{0x158A, 1, pci_vid_158A },
{0x158B, 1, pci_vid_158B },
{0x158C, 1, pci_vid_158C },
{0x158D, 1, pci_vid_158D },
{0x158E, 1, pci_vid_158E },
{0x158F, 1, pci_vid_158F },
{0x1590, 7, pci_vid_1590 },
{0x1591, 1, pci_vid_1591 },
{0x1592, 9, pci_vid_1592 },
{0x1593, 1, pci_vid_1593 },
{0x1594, 1, pci_vid_1594 },
{0x1595, 1, pci_vid_1595 },
{0x1596, 1, pci_vid_1596 },
{0x1597, 1, pci_vid_1597 },
{0x1598, 1, pci_vid_1598 },
{0x1599, 1, pci_vid_1599 },
{0x159A, 1, pci_vid_159A },
{0x159B, 2, pci_vid_159B },
{0x159C, 1, pci_vid_159C },
{0x159D, 1, pci_vid_159D },
{0x159E, 1, pci_vid_159E },
{0x159F, 1, pci_vid_159F },
{0x15A0, 1, pci_vid_15A0 },
{0x15A1, 1, pci_vid_15A1 },
{0x15A2, 2, pci_vid_15A2 },
{0x15A3, 1, pci_vid_15A3 },
{0x15A4, 1, pci_vid_15A4 },
{0x15A5, 1, pci_vid_15A5 },
{0x15A6, 1, pci_vid_15A6 },
{0x15A7, 1, pci_vid_15A7 },
{0x15A8, 1, pci_vid_15A8 },
{0x15AA, 1, pci_vid_15AA },
{0x15AB, 1, pci_vid_15AB },
{0x15AC, 2, pci_vid_15AC },
{0x15AD, 19, pci_vid_15AD },
{0x15AE, 1, pci_vid_15AE },
{0x15B0, 1, pci_vid_15B0 },
{0x15B1, 1, pci_vid_15B1 },
{0x15B2, 1, pci_vid_15B2 },
{0x15B3, 270, pci_vid_15B3 },
{0x15B4, 1, pci_vid_15B4 },
{0x15B5, 1, pci_vid_15B5 },
{0x15B6, 17, pci_vid_15B6 },
{0x15B7, 33, pci_vid_15B7 },
{0x15B8, 11, pci_vid_15B8 },
{0x15B9, 1, pci_vid_15B9 },
{0x15BA, 1, pci_vid_15BA },
{0x15BB, 1, pci_vid_15BB },
{0x15BC, 19, pci_vid_15BC },
{0x15BD, 1, pci_vid_15BD },
{0x15BE, 1, pci_vid_15BE },
{0x15BF, 1, pci_vid_15BF },
{0x15C0, 1, pci_vid_15C0 },
{0x15C1, 1, pci_vid_15C1 },
{0x15C2, 1, pci_vid_15C2 },
{0x15C3, 1, pci_vid_15C3 },
{0x15C4, 1, pci_vid_15C4 },
{0x15C5, 2, pci_vid_15C5 },
{0x15C6, 1, pci_vid_15C6 },
{0x15C7, 2, pci_vid_15C7 },
{0x15C8, 1, pci_vid_15C8 },
{0x15C9, 1, pci_vid_15C9 },
{0x15CA, 1, pci_vid_15CA },
{0x15CB, 1, pci_vid_15CB },
{0x15CC, 1, pci_vid_15CC },
{0x15CD, 1, pci_vid_15CD },
{0x15CE, 1, pci_vid_15CE },
{0x15CF, 2, pci_vid_15CF },
{0x15D1, 1, pci_vid_15D1 },
{0x15D2, 1, pci_vid_15D2 },
{0x15D3, 1, pci_vid_15D3 },
{0x15D4, 1, pci_vid_15D4 },
{0x15D5, 1, pci_vid_15D5 },
{0x15D6, 1, pci_vid_15D6 },
{0x15D7, 1, pci_vid_15D7 },
{0x15D8, 1, pci_vid_15D8 },
{0x15D9, 4, pci_vid_15D9 },
{0x15DA, 1, pci_vid_15DA },
{0x15DB, 1, pci_vid_15DB },
{0x15DC, 2, pci_vid_15DC },
{0x15DD, 1, pci_vid_15DD },
{0x15DE, 1, pci_vid_15DE },
{0x15DF, 1, pci_vid_15DF },
{0x15E0, 1, pci_vid_15E0 },
{0x15E1, 1, pci_vid_15E1 },
{0x15E2, 2, pci_vid_15E2 },
{0x15E3, 1, pci_vid_15E3 },
{0x15E4, 1, pci_vid_15E4 },
{0x15E5, 1, pci_vid_15E5 },
{0x15E6, 1, pci_vid_15E6 },
{0x15E7, 1, pci_vid_15E7 },
{0x15E8, 3, pci_vid_15E8 },
{0x15E9, 2, pci_vid_15E9 },
{0x15EA, 1, pci_vid_15EA },
{0x15EB, 1, pci_vid_15EB },
{0x15EC, 3, pci_vid_15EC },
{0x15ED, 1, pci_vid_15ED },
{0x15EE, 1, pci_vid_15EE },
{0x15EF, 1, pci_vid_15EF },
{0x15F0, 1, pci_vid_15F0 },
{0x15F1, 1, pci_vid_15F1 },
{0x15F2, 1, pci_vid_15F2 },
{0x15F3, 1, pci_vid_15F3 },
{0x15F4, 1, pci_vid_15F4 },
{0x15F5, 1, pci_vid_15F5 },
{0x15F6, 1, pci_vid_15F6 },
{0x15F7, 1, pci_vid_15F7 },
{0x15F8, 1, pci_vid_15F8 },
{0x15F9, 1, pci_vid_15F9 },
{0x15FA, 1, pci_vid_15FA },
{0x15FB, 1, pci_vid_15FB },
{0x15FC, 1, pci_vid_15FC },
{0x15FD, 1, pci_vid_15FD },
{0x15FE, 1, pci_vid_15FE },
{0x15FF, 1, pci_vid_15FF },
{0x1600, 1, pci_vid_1600 },
{0x1601, 1, pci_vid_1601 },
{0x1602, 1, pci_vid_1602 },
{0x1603, 1, pci_vid_1603 },
{0x1604, 1, pci_vid_1604 },
{0x1605, 1, pci_vid_1605 },
{0x1606, 1, pci_vid_1606 },
{0x1607, 1, pci_vid_1607 },
{0x1608, 1, pci_vid_1608 },
{0x1609, 1, pci_vid_1609 },
{0x1612, 1, pci_vid_1612 },
{0x1618, 13, pci_vid_1618 },
{0x1619, 15, pci_vid_1619 },
{0x161F, 1, pci_vid_161F },
{0x1621, 8, pci_vid_1621 },
{0x1626, 2, pci_vid_1626 },
{0x1629, 10, pci_vid_1629 },
{0x1631, 1, pci_vid_1631 },
{0x1638, 2, pci_vid_1638 },
{0x163C, 3, pci_vid_163C },
{0x1641, 1, pci_vid_1641 },
{0x1642, 1, pci_vid_1642 },
{0x1657, 19, pci_vid_1657 },
{0x165A, 5, pci_vid_165A },
{0x165C, 70, pci_vid_165C },
{0x165D, 1, pci_vid_165D },
{0x165F, 2, pci_vid_165F },
{0x1661, 1, pci_vid_1661 },
{0x1665, 3, pci_vid_1665 },
{0x1668, 2, pci_vid_1668 },
{0x166D, 5, pci_vid_166D },
{0x1677, 4, pci_vid_1677 },
{0x1678, 2, pci_vid_1678 },
{0x1679, 2, pci_vid_1679 },
{0x167B, 5, pci_vid_167B },
{0x167D, 2, pci_vid_167D },
{0x167E, 1, pci_vid_167E },
{0x1681, 1, pci_vid_1681 },
{0x1682, 3, pci_vid_1682 },
{0x1688, 2, pci_vid_1688 },
{0x168A, 7, pci_vid_168A },
{0x168C, 246, pci_vid_168C },
{0x1695, 1, pci_vid_1695 },
{0x169C, 2, pci_vid_169C },
{0x169D, 1, pci_vid_169D },
{0x16A5, 1, pci_vid_16A5 },
{0x16AB, 5, pci_vid_16AB },
{0x16AE, 6, pci_vid_16AE },
{0x16AF, 1, pci_vid_16AF },
{0x16B4, 1, pci_vid_16B4 },
{0x16B8, 1, pci_vid_16B8 },
{0x16BE, 1, pci_vid_16BE },
{0x16C3, 5, pci_vid_16C3 },
{0x16C6, 3, pci_vid_16C6 },
{0x16C8, 1, pci_vid_16C8 },
{0x16C9, 1, pci_vid_16C9 },
{0x16CA, 2, pci_vid_16CA },
{0x16CD, 12, pci_vid_16CD },
{0x16CE, 1, pci_vid_16CE },
{0x16D5, 102, pci_vid_16D5 },
{0x16DA, 2, pci_vid_16DA },
{0x16DF, 1, pci_vid_16DF },
{0x16E2, 61, pci_vid_16E2 },
{0x16E3, 2, pci_vid_16E3 },
{0x16E5, 3, pci_vid_16E5 },
{0x16EC, 7, pci_vid_16EC },
{0x16ED, 2, pci_vid_16ED },
{0x16F2, 3, pci_vid_16F2 },
{0x16F3, 1, pci_vid_16F3 },
{0x16F4, 2, pci_vid_16F4 },
{0x16F6, 1, pci_vid_16F6 },
{0x1702, 1, pci_vid_1702 },
{0x1705, 1, pci_vid_1705 },
{0x170B, 2, pci_vid_170B },
{0x170C, 1, pci_vid_170C },
{0x1719, 2, pci_vid_1719 },
{0x1725, 2, pci_vid_1725 },
{0x172A, 2, pci_vid_172A },
{0x1734, 2, pci_vid_1734 },
{0x1735, 1, pci_vid_1735 },
{0x1737, 9, pci_vid_1737 },
{0x173B, 7, pci_vid_173B },
{0x1743, 2, pci_vid_1743 },
{0x1745, 4, pci_vid_1745 },
{0x1749, 1, pci_vid_1749 },
{0x174B, 1, pci_vid_174B },
{0x174D, 1, pci_vid_174D },
{0x175C, 1, pci_vid_175C },
{0x175E, 1, pci_vid_175E },
{0x1760, 37, pci_vid_1760 },
{0x1761, 1, pci_vid_1761 },
{0x1771, 1, pci_vid_1771 },
{0x1775, 1, pci_vid_1775 },
{0x177D, 114, pci_vid_177D },
{0x1787, 1, pci_vid_1787 },
{0x1789, 1, pci_vid_1789 },
{0x1796, 29, pci_vid_1796 },
{0x1797, 13, pci_vid_1797 },
{0x1799, 6, pci_vid_1799 },
{0x179A, 2, pci_vid_179A },
{0x179C, 9, pci_vid_179C },
{0x17A0, 7, pci_vid_17A0 },
{0x17AA, 8, pci_vid_17AA },
{0x17AB, 1, pci_vid_17AB },
{0x17AF, 1, pci_vid_17AF },
{0x17B3, 2, pci_vid_17B3 },
{0x17B4, 6, pci_vid_17B4 },
{0x17C0, 1, pci_vid_17C0 },
{0x17C2, 1, pci_vid_17C2 },
{0x17C3, 1, pci_vid_17C3 },
{0x17CB, 32, pci_vid_17CB },
{0x17CC, 3, pci_vid_17CC },
{0x17CD, 1, pci_vid_17CD },
{0x17CF, 1, pci_vid_17CF },
{0x17D3, 47, pci_vid_17D3 },
{0x17D5, 30, pci_vid_17D5 },
{0x17DB, 3, pci_vid_17DB },
{0x17DE, 1, pci_vid_17DE },
{0x17DF, 46, pci_vid_17DF },
{0x17E4, 3, pci_vid_17E4 },
{0x17E6, 8, pci_vid_17E6 },
{0x17EE, 1, pci_vid_17EE },
{0x17F2, 1, pci_vid_17F2 },
{0x17F3, 27, pci_vid_17F3 },
{0x17F7, 1, pci_vid_17F7 },
{0x17F9, 1, pci_vid_17F9 },
{0x17FC, 1, pci_vid_17FC },
{0x17FE, 6, pci_vid_17FE },
{0x17FF, 1, pci_vid_17FF },
{0x1800, 2, pci_vid_1800 },
{0x1803, 1, pci_vid_1803 },
{0x1804, 2, pci_vid_1804 },
{0x1805, 30, pci_vid_1805 },
{0x1809, 1, pci_vid_1809 },
{0x180C, 1, pci_vid_180C },
{0x1813, 5, pci_vid_1813 },
{0x1814, 84, pci_vid_1814 },
{0x1815, 1, pci_vid_1815 },
{0x1820, 1, pci_vid_1820 },
{0x1822, 2, pci_vid_1822 },
{0x182D, 3, pci_vid_182D },
{0x182E, 2, pci_vid_182E },
{0x182F, 2, pci_vid_182F },
{0x1830, 5, pci_vid_1830 },
{0x183B, 5, pci_vid_183B },
{0x1846, 1, pci_vid_1846 },
{0x1849, 2, pci_vid_1849 },
{0x184A, 2, pci_vid_184A },
{0x1850, 2, pci_vid_1850 },
{0x1851, 1, pci_vid_1851 },
{0x1852, 1, pci_vid_1852 },
{0x1853, 1, pci_vid_1853 },
{0x1854, 1, pci_vid_1854 },
{0x185B, 2, pci_vid_185B },
{0x185F, 1, pci_vid_185F },
{0x1864, 2, pci_vid_1864 },
{0x1867, 6, pci_vid_1867 },
{0x186C, 8, pci_vid_186C },
{0x186F, 1, pci_vid_186F },
{0x1876, 4, pci_vid_1876 },
{0x187E, 3, pci_vid_187E },
{0x1885, 1, pci_vid_1885 },
{0x1888, 5, pci_vid_1888 },
{0x188A, 1, pci_vid_188A },
{0x1890, 1, pci_vid_1890 },
{0x1894, 1, pci_vid_1894 },
{0x1896, 9, pci_vid_1896 },
{0x1897, 1, pci_vid_1897 },
{0x18A1, 1, pci_vid_18A1 },
{0x18A2, 2, pci_vid_18A2 },
{0x18A3, 1, pci_vid_18A3 },
{0x18AC, 8, pci_vid_18AC },
{0x18B8, 2, pci_vid_18B8 },
{0x18BC, 1, pci_vid_18BC },
{0x18C3, 3, pci_vid_18C3 },
{0x18C8, 1, pci_vid_18C8 },
{0x18C9, 1, pci_vid_18C9 },
{0x18CA, 6, pci_vid_18CA },
{0x18D2, 2, pci_vid_18D2 },
{0x18D4, 1, pci_vid_18D4 },
{0x18D8, 1, pci_vid_18D8 },
{0x18DD, 2, pci_vid_18DD },
{0x18DF, 1, pci_vid_18DF },
{0x18E6, 2, pci_vid_18E6 },
{0x18EB, 1, pci_vid_18EB },
{0x18EC, 50, pci_vid_18EC },
{0x18EE, 1, pci_vid_18EE },
{0x18F1, 1, pci_vid_18F1 },
{0x18F4, 31, pci_vid_18F4 },
{0x18F6, 7, pci_vid_18F6 },
{0x18F7, 30, pci_vid_18F7 },
{0x18FB, 1, pci_vid_18FB },
{0x1904, 3, pci_vid_1904 },
{0x1905, 1, pci_vid_1905 },
{0x1912, 11, pci_vid_1912 },
{0x1919, 1, pci_vid_1919 },
{0x1923, 5, pci_vid_1923 },
{0x1924, 129, pci_vid_1924 },
{0x192A, 2, pci_vid_192A },
{0x192E, 1, pci_vid_192E },
{0x1931, 2, pci_vid_1931 },
{0x1932, 1, pci_vid_1932 },
{0x193C, 1, pci_vid_193C },
{0x193D, 1, pci_vid_193D },
{0x193F, 13, pci_vid_193F },
{0x1942, 3, pci_vid_1942 },
{0x1945, 2, pci_vid_1945 },
{0x1947, 2, pci_vid_1947 },
{0x1948, 1, pci_vid_1948 },
{0x194A, 10, pci_vid_194A },
{0x1954, 1, pci_vid_1954 },
{0x1957, 87, pci_vid_1957 },
{0x1958, 1, pci_vid_1958 },
{0x1959, 15, pci_vid_1959 },
{0x1966, 8, pci_vid_1966 },
{0x1969, 28, pci_vid_1969 },
{0x196A, 4, pci_vid_196A },
{0x196D, 1, pci_vid_196D },
{0x196E, 1, pci_vid_196E },
{0x1971, 5, pci_vid_1971 },
{0x1974, 7, pci_vid_1974 },
{0x1976, 1, pci_vid_1976 },
{0x1977, 1, pci_vid_1977 },
{0x197B, 32, pci_vid_197B },
{0x1982, 3, pci_vid_1982 },
{0x1987, 12, pci_vid_1987 },
{0x1989, 3, pci_vid_1989 },
{0x198A, 1, pci_vid_198A },
{0x1993, 1, pci_vid_1993 },
{0x1999, 2, pci_vid_1999 },
{0x199A, 1, pci_vid_199A },
{0x199D, 3, pci_vid_199D },
{0x199F, 3, pci_vid_199F },
{0x19A2, 34, pci_vid_19A2 },
{0x19A4, 1, pci_vid_19A4 },
{0x19A8, 1, pci_vid_19A8 },
{0x19AC, 2, pci_vid_19AC },
{0x19AE, 3, pci_vid_19AE },
{0x19BA, 2, pci_vid_19BA },
{0x19C1, 1, pci_vid_19C1 },
{0x19D1, 1, pci_vid_19D1 },
{0x19D4, 1, pci_vid_19D4 },
{0x19DA, 1, pci_vid_19DA },
{0x19DE, 1, pci_vid_19DE },
{0x19E2, 1, pci_vid_19E2 },
{0x19E3, 4, pci_vid_19E3 },
{0x19E5, 99, pci_vid_19E5 },
{0x19E7, 6, pci_vid_19E7 },
{0x19EE, 1, pci_vid_19EE },
{0x19F1, 1, pci_vid_19F1 },
{0x19FF, 1, pci_vid_19FF },
{0x1A03, 5, pci_vid_1A03 },
{0x1A05, 1, pci_vid_1A05 },
{0x1A07, 5, pci_vid_1A07 },
{0x1A08, 2, pci_vid_1A08 },
{0x1A0D, 1, pci_vid_1A0D },
{0x1A0E, 10, pci_vid_1A0E },
{0x1A17, 2, pci_vid_1A17 },
{0x1A1D, 2, pci_vid_1A1D },
{0x1A1E, 1, pci_vid_1A1E },
{0x1A22, 1, pci_vid_1A22 },
{0x1A29, 5, pci_vid_1A29 },
{0x1A2B, 7, pci_vid_1A2B },
{0x1A30, 4, pci_vid_1A30 },
{0x1A32, 1, pci_vid_1A32 },
{0x1A3B, 2, pci_vid_1A3B },
{0x1A41, 6, pci_vid_1A41 },
{0x1A4A, 14, pci_vid_1A4A },
{0x1A51, 1, pci_vid_1A51 },
{0x1A55, 17, pci_vid_1A55 },
{0x1A56, 1, pci_vid_1A56 },
{0x1A57, 1, pci_vid_1A57 },
{0x1A58, 1, pci_vid_1A58 },
{0x1A5D, 1, pci_vid_1A5D },
{0x1A5E, 1, pci_vid_1A5E },
{0x1A5F, 1, pci_vid_1A5F },
{0x1A68, 1, pci_vid_1A68 },
{0x1A71, 1, pci_vid_1A71 },
{0x1A73, 2, pci_vid_1A73 },
{0x1A76, 1, pci_vid_1A76 },
{0x1A77, 1, pci_vid_1A77 },
{0x1A78, 10, pci_vid_1A78 },
{0x1A84, 2, pci_vid_1A84 },
{0x1A88, 2, pci_vid_1A88 },
{0x1A8A, 1, pci_vid_1A8A },
{0x1A8C, 2, pci_vid_1A8C },
{0x1A8E, 2, pci_vid_1A8E },
{0x1AA8, 3, pci_vid_1AA8 },
{0x1AA9, 9, pci_vid_1AA9 },
{0x1AAB, 2, pci_vid_1AAB },
{0x1AAE, 1, pci_vid_1AAE },
{0x1AB4, 1, pci_vid_1AB4 },
{0x1AB6, 2, pci_vid_1AB6 },
{0x1AB8, 4, pci_vid_1AB8 },
{0x1AB9, 1, pci_vid_1AB9 },
{0x1AC1, 2, pci_vid_1AC1 },
{0x1AC8, 1, pci_vid_1AC8 },
{0x1ACC, 1, pci_vid_1ACC },
{0x1AD7, 3, pci_vid_1AD7 },
{0x1ADE, 5, pci_vid_1ADE },
{0x1AE0, 4, pci_vid_1AE0 },
{0x1AE3, 1, pci_vid_1AE3 },
{0x1AE7, 2, pci_vid_1AE7 },
{0x1AE8, 31, pci_vid_1AE8 },
{0x1AE9, 7, pci_vid_1AE9 },
{0x1AEA, 4, pci_vid_1AEA },
{0x1AEC, 1, pci_vid_1AEC },
{0x1AED, 17, pci_vid_1AED },
{0x1AEE, 1, pci_vid_1AEE },
{0x1AF4, 24, pci_vid_1AF4 },
{0x1AF5, 1, pci_vid_1AF5 },
{0x1AFA, 1, pci_vid_1AFA },
{0x1B00, 4, pci_vid_1B00 },
{0x1B03, 3, pci_vid_1B03 },
{0x1B08, 1, pci_vid_1B08 },
{0x1B0A, 2, pci_vid_1B0A },
{0x1B13, 1, pci_vid_1B13 },
{0x1B1A, 2, pci_vid_1B1A },
{0x1B1C, 1, pci_vid_1B1C },
{0x1B21, 41, pci_vid_1B21 },
{0x1B26, 11, pci_vid_1B26 },
{0x1B2C, 1, pci_vid_1B2C },
{0x1B36, 23, pci_vid_1B36 },
{0x1B37, 18, pci_vid_1B37 },
{0x1B39, 2, pci_vid_1B39 },
{0x1B3A, 2, pci_vid_1B3A },
{0x1B3E, 4, pci_vid_1B3E },
{0x1B40, 1, pci_vid_1B40 },
{0x1B47, 3, pci_vid_1B47 },
{0x1B4B, 57, pci_vid_1B4B },
{0x1B4C, 1, pci_vid_1B4C },
{0x1B55, 7, pci_vid_1B55 },
{0x1B5E, 15, pci_vid_1B5E },
{0x1B61, 1, pci_vid_1B61 },
{0x1B66, 2, pci_vid_1B66 },
{0x1B6F, 5, pci_vid_1B6F },
{0x1B73, 6, pci_vid_1B73 },
{0x1B74, 7, pci_vid_1B74 },
{0x1B79, 1, pci_vid_1B79 },
{0x1B85, 6, pci_vid_1B85 },
{0x1B94, 2, pci_vid_1B94 },
{0x1B96, 19, pci_vid_1B96 },
{0x1B9A, 1, pci_vid_1B9A },
{0x1BAA, 1, pci_vid_1BAA },
{0x1BAD, 3, pci_vid_1BAD },
{0x1BB0, 3, pci_vid_1BB0 },
{0x1BB1, 66, pci_vid_1BB1 },
{0x1BB3, 10, pci_vid_1BB3 },
{0x1BB5, 1, pci_vid_1BB5 },
{0x1BBF, 3, pci_vid_1BBF },
{0x1BC0, 10, pci_vid_1BC0 },
{0x1BCD, 2, pci_vid_1BCD },
{0x1BCF, 2, pci_vid_1BCF },
{0x1BD0, 18, pci_vid_1BD0 },
{0x1BD4, 12, pci_vid_1BD4 },
{0x1BEE, 18, pci_vid_1BEE },
{0x1BEF, 2, pci_vid_1BEF },
{0x1BF4, 3, pci_vid_1BF4 },
{0x1BF5, 2, pci_vid_1BF5 },
{0x1BFC, 1, pci_vid_1BFC },
{0x1BFD, 1, pci_vid_1BFD },
{0x1C00, 7, pci_vid_1C00 },
{0x1C09, 13, pci_vid_1C09 },
{0x1C1C, 2, pci_vid_1C1C },
{0x1C1F, 12, pci_vid_1C1F },
{0x1C28, 2, pci_vid_1C28 },
{0x1C2C, 40, pci_vid_1C2C },
{0x1C32, 1, pci_vid_1C32 },
{0x1C33, 1, pci_vid_1C33 },
{0x1C36, 3, pci_vid_1C36 },
{0x1C3B, 3, pci_vid_1C3B },
{0x1C44, 3, pci_vid_1C44 },
{0x1C58, 7, pci_vid_1C58 },
{0x1C5C, 46, pci_vid_1C5C },
{0x1C5F, 114, pci_vid_1C5F },
{0x1C63, 2, pci_vid_1C63 },
{0x1C7E, 2, pci_vid_1C7E },
{0x1C7F, 2, pci_vid_1C7F },
{0x1C8A, 2, pci_vid_1C8A },
{0x1C8C, 1, pci_vid_1C8C },
{0x1CB0, 17, pci_vid_1CB0 },
{0x1CB1, 1, pci_vid_1CB1 },
{0x1CB5, 2, pci_vid_1CB5 },
{0x1CB8, 1, pci_vid_1CB8 },
{0x1CC1, 24, pci_vid_1CC1 },
{0x1CC4, 53, pci_vid_1CC4 },
{0x1CC5, 3, pci_vid_1CC5 },
{0x1CC7, 3, pci_vid_1CC7 },
{0x1CCF, 2, pci_vid_1CCF },
{0x1CD2, 8, pci_vid_1CD2 },
{0x1CD7, 9, pci_vid_1CD7 },
{0x1CDD, 1, pci_vid_1CDD },
{0x1CE4, 14, pci_vid_1CE4 },
{0x1CF0, 1, pci_vid_1CF0 },
{0x1CF7, 1, pci_vid_1CF7 },
{0x1CFA, 1, pci_vid_1CFA },
{0x1CFD, 2, pci_vid_1CFD },
{0x1D00, 1, pci_vid_1D00 },
{0x1D05, 1, pci_vid_1D05 },
{0x1D0F, 12, pci_vid_1D0F },
{0x1D17, 92, pci_vid_1D17 },
{0x1D18, 2, pci_vid_1D18 },
{0x1D1C, 5, pci_vid_1D1C },
{0x1D1D, 3, pci_vid_1D1D },
{0x1D21, 1, pci_vid_1D21 },
{0x1D22, 4, pci_vid_1D22 },
{0x1D26, 6, pci_vid_1D26 },
{0x1D37, 5, pci_vid_1D37 },
{0x1D40, 4, pci_vid_1D40 },
{0x1D44, 2, pci_vid_1D44 },
{0x1D49, 1, pci_vid_1D49 },
{0x1D4C, 1, pci_vid_1D4C },
{0x1D5C, 1, pci_vid_1D5C },
{0x1D61, 1, pci_vid_1D61 },
{0x1D62, 1, pci_vid_1D62 },
{0x1D65, 2, pci_vid_1D65 },
{0x1D69, 3, pci_vid_1D69 },
{0x1D6A, 25, pci_vid_1D6A },
{0x1D6C, 45, pci_vid_1D6C },
{0x1D72, 1, pci_vid_1D72 },
{0x1D78, 62, pci_vid_1D78 },
{0x1D79, 6, pci_vid_1D79 },
{0x1D7C, 2, pci_vid_1D7C },
{0x1D82, 5, pci_vid_1D82 },
{0x1D87, 7, pci_vid_1D87 },
{0x1D89, 2, pci_vid_1D89 },
{0x1D8F, 1, pci_vid_1D8F },
{0x1D92, 1, pci_vid_1D92 },
{0x1D93, 1, pci_vid_1D93 },
{0x1D94, 30, pci_vid_1D94 },
{0x1D95, 3, pci_vid_1D95 },
{0x1D97, 12, pci_vid_1D97 },
{0x1D9B, 3, pci_vid_1D9B },
{0x1DA1, 1, pci_vid_1DA1 },
{0x1DA2, 3, pci_vid_1DA2 },
{0x1DA3, 6, pci_vid_1DA3 },
{0x1DA8, 3, pci_vid_1DA8 },
{0x1DAD, 2, pci_vid_1DAD },
{0x1DB2, 1, pci_vid_1DB2 },
{0x1DB7, 23, pci_vid_1DB7 },
{0x1DBB, 1, pci_vid_1DBB },
{0x1DBE, 27, pci_vid_1DBE },
{0x1DBF, 2, pci_vid_1DBF },
{0x1DC2, 1, pci_vid_1DC2 },
{0x1DC5, 3, pci_vid_1DC5 },
{0x1DCD, 1, pci_vid_1DCD },
{0x1DCF, 1, pci_vid_1DCF },
{0x1DD3, 1, pci_vid_1DD3 },
{0x1DD4, 4, pci_vid_1DD4 },
{0x1DD8, 218, pci_vid_1DD8 },
{0x1DDD, 1, pci_vid_1DDD },
{0x1DE0, 6, pci_vid_1DE0 },
{0x1DE1, 5, pci_vid_1DE1 },
{0x1DE4, 2, pci_vid_1DE4 },
{0x1DE5, 4, pci_vid_1DE5 },
{0x1DED, 8, pci_vid_1DED },
{0x1DEE, 4, pci_vid_1DEE },
{0x1DEF, 27, pci_vid_1DEF },
{0x1DF3, 29, pci_vid_1DF3 },
{0x1DF5, 3, pci_vid_1DF5 },
{0x1DF7, 4, pci_vid_1DF7 },
{0x1DF8, 9, pci_vid_1DF8 },
{0x1DFA, 1, pci_vid_1DFA },
{0x1DFC, 2, pci_vid_1DFC },
{0x1E0D, 1, pci_vid_1E0D },
{0x1E0F, 102, pci_vid_1E0F },
{0x1E17, 1, pci_vid_1E17 },
{0x1E18, 1, pci_vid_1E18 },
{0x1E24, 8, pci_vid_1E24 },
{0x1E26, 1, pci_vid_1E26 },
{0x1E36, 17, pci_vid_1E36 },
{0x1E38, 2, pci_vid_1E38 },
{0x1E39, 1, pci_vid_1E39 },
{0x1E3A, 2, pci_vid_1E3A },
{0x1E3B, 116, pci_vid_1E3B },
{0x1E3D, 1, pci_vid_1E3D },
{0x1E43, 4, pci_vid_1E43 },
{0x1E44, 1, pci_vid_1E44 },
{0x1E49, 11, pci_vid_1E49 },
{0x1E4B, 9, pci_vid_1E4B },
{0x1E4C, 3, pci_vid_1E4C },
{0x1E50, 1, pci_vid_1E50 },
{0x1E52, 9, pci_vid_1E52 },
{0x1E57, 3, pci_vid_1E57 },
{0x1E59, 2, pci_vid_1E59 },
{0x1E5D, 3, pci_vid_1E5D },
{0x1E60, 2, pci_vid_1E60 },
{0x1E67, 2, pci_vid_1E67 },
{0x1E68, 2, pci_vid_1E68 },
{0x1E6B, 1, pci_vid_1E6B },
{0x1E7B, 1, pci_vid_1E7B },
{0x1E7C, 2, pci_vid_1E7C },
{0x1E7E, 2, pci_vid_1E7E },
{0x1E7F, 3, pci_vid_1E7F },
{0x1E81, 13, pci_vid_1E81 },
{0x1E83, 1, pci_vid_1E83 },
{0x1E85, 1, pci_vid_1E85 },
{0x1E89, 3, pci_vid_1E89 },
{0x1E93, 1, pci_vid_1E93 },
{0x1E94, 1, pci_vid_1E94 },
{0x1E95, 13, pci_vid_1E95 },
{0x1E96, 1, pci_vid_1E96 },
{0x1E9F, 1, pci_vid_1E9F },
{0x1EA0, 5, pci_vid_1EA0 },
{0x1EA7, 3, pci_vid_1EA7 },
{0x1EAB, 3, pci_vid_1EAB },
{0x1EAC, 3, pci_vid_1EAC },
{0x1EAE, 1, pci_vid_1EAE },
{0x1EB1, 2, pci_vid_1EB1 },
{0x1EB4, 2, pci_vid_1EB4 },
{0x1EB6, 1, pci_vid_1EB6 },
{0x1EB9, 2, pci_vid_1EB9 },
{0x1EBD, 2, pci_vid_1EBD },
{0x1EC6, 22, pci_vid_1EC6 },
{0x1EC8, 13, pci_vid_1EC8 },
{0x1EC9, 1, pci_vid_1EC9 },
{0x1ECA, 2, pci_vid_1ECA },
{0x1ED0, 2, pci_vid_1ED0 },
{0x1ED2, 7, pci_vid_1ED2 },
{0x1ED3, 1, pci_vid_1ED3 },
{0x1ED5, 27, pci_vid_1ED5 },
{0x1ED8, 3, pci_vid_1ED8 },
{0x1ED9, 1, pci_vid_1ED9 },
{0x1EE1, 6, pci_vid_1EE1 },
{0x1EE4, 2, pci_vid_1EE4 },
{0x1EE9, 1, pci_vid_1EE9 },
{0x1EEC, 3, pci_vid_1EEC },
{0x1EED, 36, pci_vid_1EED },
{0x1EF6, 1, pci_vid_1EF6 },
{0x1EF7, 1, pci_vid_1EF7 },
{0x1EFB, 1, pci_vid_1EFB },
{0x1EFF, 1, pci_vid_1EFF },
{0x1F02, 1, pci_vid_1F02 },
{0x1F03, 8, pci_vid_1F03 },
{0x1F0A, 2, pci_vid_1F0A },
{0x1F0F, 36, pci_vid_1F0F },
{0x1F16, 2, pci_vid_1F16 },
{0x1F17, 1, pci_vid_1F17 },
{0x1F24, 4, pci_vid_1F24 },
{0x1F2F, 7, pci_vid_1F2F },
{0x1F31, 2, pci_vid_1F31 },
{0x1F3F, 38, pci_vid_1F3F },
{0x1F40, 9, pci_vid_1F40 },
{0x1F44, 1, pci_vid_1F44 },
{0x1F47, 3, pci_vid_1F47 },
{0x1F4B, 1, pci_vid_1F4B },
{0x1F52, 1, pci_vid_1F52 },
{0x1F56, 1, pci_vid_1F56 },
{0x1F60, 3, pci_vid_1F60 },
{0x1F67, 10, pci_vid_1F67 },
{0x1FAA, 3, pci_vid_1FAA },
{0x1FAB, 7, pci_vid_1FAB },
{0x1FB0, 25, pci_vid_1FB0 },
{0x1FC0, 3, pci_vid_1FC0 },
{0x1FC1, 3, pci_vid_1FC1 },
{0x1FC9, 48, pci_vid_1FC9 },
{0x1FCC, 3, pci_vid_1FCC },
{0x1FCE, 2, pci_vid_1FCE },
{0x1FD4, 3, pci_vid_1FD4 },
{0x1FDE, 3, pci_vid_1FDE },
{0x1FE0, 4, pci_vid_1FE0 },
{0x1FE4, 6, pci_vid_1FE4 },
{0x1FE9, 1, pci_vid_1FE9 },
{0x1FF2, 18, pci_vid_1FF2 },
{0x1FF4, 4, pci_vid_1FF4 },
{0x1FF8, 3, pci_vid_1FF8 },
{0x1FF9, 1, pci_vid_1FF9 },
{0x2000, 2, pci_vid_2000 },
{0x2001, 1, pci_vid_2001 },
{0x2003, 2, pci_vid_2003 },
{0x2004, 1, pci_vid_2004 },
{0x202C, 2, pci_vid_202C },
{0x2036, 3, pci_vid_2036 },
{0x2046, 1, pci_vid_2046 },
{0x2048, 1, pci_vid_2048 },
{0x20F4, 1, pci_vid_20F4 },
{0x2116, 1, pci_vid_2116 },
{0x21B4, 1, pci_vid_21B4 },
{0x21C3, 1, pci_vid_21C3 },
{0x22B8, 2, pci_vid_22B8 },
{0x22DB, 2, pci_vid_22DB },
{0x2304, 1, pci_vid_2304 },
{0x2321, 1, pci_vid_2321 },
{0x2348, 2, pci_vid_2348 },
{0x256C, 2, pci_vid_256C },
{0x2646, 27, pci_vid_2646 },
{0x270B, 1, pci_vid_270B },
{0x270F, 1, pci_vid_270F },
{0x2711, 1, pci_vid_2711 },
{0x2782, 1, pci_vid_2782 },
{0x2955, 2, pci_vid_2955 },
{0x2A15, 1, pci_vid_2A15 },
{0x2A18, 1, pci_vid_2A18 },
{0x2BD8, 1, pci_vid_2BD8 },
{0x3000, 1, pci_vid_3000 },
{0x3100, 1, pci_vid_3100 },
{0x3112, 1, pci_vid_3112 },
{0x3130, 1, pci_vid_3130 },
{0x3142, 1, pci_vid_3142 },
{0x31AB, 2, pci_vid_31AB },
{0x328F, 3, pci_vid_328F },
{0x3388, 28, pci_vid_3388 },
{0x3411, 1, pci_vid_3411 },
{0x3442, 3, pci_vid_3442 },
{0x3475, 1, pci_vid_3475 },
{0x34BA, 1, pci_vid_34BA },
{0x3513, 1, pci_vid_3513 },
{0x369A, 1, pci_vid_369A },
{0x37D9, 5, pci_vid_37D9 },
{0x3842, 1, pci_vid_3842 },
{0x38EF, 1, pci_vid_38EF },
{0x393E, 1, pci_vid_393E },
{0x3D3D, 49, pci_vid_3D3D },
{0x4005, 16, pci_vid_4005 },
{0x4033, 2, pci_vid_4033 },
{0x4040, 20, pci_vid_4040 },
{0x4143, 1, pci_vid_4143 },
{0x4144, 2, pci_vid_4144 },
{0x4150, 4, pci_vid_4150 },
{0x415A, 1, pci_vid_415A },
{0x416C, 3, pci_vid_416C },
{0x4242, 1, pci_vid_4242 },
{0x4254, 1, pci_vid_4254 },
{0x4321, 1, pci_vid_4321 },
{0x4348, 8, pci_vid_4348 },
{0x434E, 1, pci_vid_434E },
{0x4444, 64, pci_vid_4444 },
{0x4468, 1, pci_vid_4468 },
{0x4594, 1, pci_vid_4594 },
{0x45FB, 1, pci_vid_45FB },
{0x4624, 4, pci_vid_4624 },
{0x4651, 1, pci_vid_4651 },
{0x4680, 1, pci_vid_4680 },
{0x4843, 1, pci_vid_4843 },
{0x4916, 2, pci_vid_4916 },
{0x4943, 1, pci_vid_4943 },
{0x494F, 123, pci_vid_494F },
{0x4978, 1, pci_vid_4978 },
{0x4A14, 3, pci_vid_4A14 },
{0x4B10, 1, pci_vid_4B10 },
{0x4B43, 1, pci_vid_4B43 },
{0x4C48, 1, pci_vid_4C48 },
{0x4C4D, 3, pci_vid_4C4D },
{0x4C52, 9, pci_vid_4C52 },
{0x4C53, 6, pci_vid_4C53 },
{0x4CA1, 1, pci_vid_4CA1 },
{0x4D51, 2, pci_vid_4D51 },
{0x4D54, 1, pci_vid_4D54 },
{0x4D56, 10, pci_vid_4D56 },
{0x4DDC, 27, pci_vid_4DDC },
{0x4E4C, 1, pci_vid_4E4C },
{0x4E58, 2, pci_vid_4E58 },
{0x5045, 2, pci_vid_5045 },
{0x5046, 2, pci_vid_5046 },
{0x5053, 2, pci_vid_5053 },
{0x50B2, 1, pci_vid_50B2 },
{0x50CE, 5, pci_vid_50CE },
{0x5136, 1, pci_vid_5136 },
{0x5143, 1, pci_vid_5143 },
{0x5145, 2, pci_vid_5145 },
{0x5168, 3, pci_vid_5168 },
{0x5301, 2, pci_vid_5301 },
{0x5333, 146, pci_vid_5333 },
{0x5431, 1, pci_vid_5431 },
{0x544C, 2, pci_vid_544C },
{0x544D, 17, pci_vid_544D },
{0x5452, 2, pci_vid_5452 },
{0x5455, 2, pci_vid_5455 },
{0x5456, 1, pci_vid_5456 },
{0x5519, 1, pci_vid_5519 },
{0x5544, 2, pci_vid_5544 },
{0x5555, 4, pci_vid_5555 },
{0x5646, 1, pci_vid_5646 },
{0x5654, 1, pci_vid_5654 },
{0x5678, 1, pci_vid_5678 },
{0x5700, 1, pci_vid_5700 },
{0x5845, 1, pci_vid_5845 },
{0x584D, 1, pci_vid_584D },
{0x5851, 4, pci_vid_5851 },
{0x5853, 6, pci_vid_5853 },
{0x5854, 1, pci_vid_5854 },
{0x5ACE, 1, pci_vid_5ACE },
{0x6205, 1, pci_vid_6205 },
{0x6209, 1, pci_vid_6209 },
{0x631C, 3, pci_vid_631C },
{0x6356, 1, pci_vid_6356 },
{0x6374, 2, pci_vid_6374 },
{0x6409, 1, pci_vid_6409 },
{0x6549, 2, pci_vid_6549 },
{0x6590, 1, pci_vid_6590 },
{0x6666, 12, pci_vid_6666 },
{0x6688, 5, pci_vid_6688 },
{0x6704, 1, pci_vid_6704 },
{0x6766, 11, pci_vid_6766 },
{0x6899, 1, pci_vid_6899 },
{0x6900, 1, pci_vid_6900 },
{0x6903, 1, pci_vid_6903 },
{0x6909, 1, pci_vid_6909 },
{0x6910, 1, pci_vid_6910 },
{0x6F67, 1, pci_vid_6F67 },
{0x7063, 4, pci_vid_7063 },
{0x7284, 1, pci_vid_7284 },
{0x7357, 2, pci_vid_7357 },
{0x7377, 1, pci_vid_7377 },
{0x7401, 2, pci_vid_7401 },
{0x7470, 1, pci_vid_7470 },
{0x7526, 3, pci_vid_7526 },
{0x7604, 1, pci_vid_7604 },
{0x78C0, 3, pci_vid_78C0 },
{0x7BDE, 1, pci_vid_7BDE },
{0x7FED, 1, pci_vid_7FED },
{0x8008, 4, pci_vid_8008 },
{0x807D, 1, pci_vid_807D },
{0x8086, 8918, pci_vid_8086 },
{0x8088, 77, pci_vid_8088 },
{0x80EE, 3, pci_vid_80EE },
{0x8322, 1, pci_vid_8322 },
{0x8384, 1, pci_vid_8384 },
{0x8401, 1, pci_vid_8401 },
{0x8510, 12, pci_vid_8510 },
{0x8686, 3, pci_vid_8686 },
{0x8800, 2, pci_vid_8800 },
{0x8820, 2, pci_vid_8820 },
{0x8848, 27, pci_vid_8848 },
{0x8866, 1, pci_vid_8866 },
{0x8888, 2, pci_vid_8888 },
{0x8912, 1, pci_vid_8912 },
{0x8C4A, 2, pci_vid_8C4A },
{0x8E0E, 1, pci_vid_8E0E },
{0x8E2E, 2, pci_vid_8E2E },
{0x9004, 110, pci_vid_9004 },
{0x9005, 396, pci_vid_9005 },
{0x907F, 2, pci_vid_907F },
{0x919A, 1, pci_vid_919A },
{0x9412, 2, pci_vid_9412 },
{0x9413, 3, pci_vid_9413 },
{0x9618, 2, pci_vid_9618 },
{0x9699, 2, pci_vid_9699 },
{0x9710, 23, pci_vid_9710 },
{0x9850, 1, pci_vid_9850 },
{0x9902, 4, pci_vid_9902 },
{0x9A11, 1, pci_vid_9A11 },
{0x9D32, 21, pci_vid_9D32 },
{0xA000, 1, pci_vid_A000 },
{0xA0A0, 1, pci_vid_A0A0 },
{0xA0F1, 1, pci_vid_A0F1 },
{0xA200, 1, pci_vid_A200 },
{0xA259, 1, pci_vid_A259 },
{0xA25B, 1, pci_vid_A25B },
{0xA304, 1, pci_vid_A304 },
{0xA727, 3, pci_vid_A727 },
{0xAA00, 1, pci_vid_AA00 },
{0xAA01, 1, pci_vid_AA01 },
{0xAA02, 1, pci_vid_AA02 },
{0xAA03, 1, pci_vid_AA03 },
{0xAA04, 1, pci_vid_AA04 },
{0xAA05, 1, pci_vid_AA05 },
{0xAA06, 1, pci_vid_AA06 },
{0xAA07, 1, pci_vid_AA07 },
{0xAA08, 1, pci_vid_AA08 },
{0xAA09, 1, pci_vid_AA09 },
{0xAA0A, 1, pci_vid_AA0A },
{0xAA0B, 1, pci_vid_AA0B },
{0xAA0C, 1, pci_vid_AA0C },
{0xAA0D, 1, pci_vid_AA0D },
{0xAA0E, 1, pci_vid_AA0E },
{0xAA0F, 1, pci_vid_AA0F },
{0xAA42, 1, pci_vid_AA42 },
{0xAA55, 1, pci_vid_AA55 },
{0xAAAA, 3, pci_vid_AAAA },
{0xABCD, 1, pci_vid_ABCD },
{0xAC1E, 1, pci_vid_AC1E },
{0xAC3D, 1, pci_vid_AC3D },
{0xAD00, 1, pci_vid_AD00 },
{0xAECB, 2, pci_vid_AECB },
{0xAFFE, 5, pci_vid_AFFE },
{0xB100, 1, pci_vid_B100 },
{0xB10B, 1, pci_vid_B10B },
{0xB1B3, 1, pci_vid_B1B3 },
{0xB1D9, 1, pci_vid_B1D9 },
{0xBD11, 1, pci_vid_BD11 },
{0xBDBD, 37, pci_vid_BDBD },
{0xC001, 1, pci_vid_C001 },
{0xC0A9, 9, pci_vid_C0A9 },
{0xC0DE, 1, pci_vid_C0DE },
{0xC0FE, 1, pci_vid_C0FE },
{0xCA01, 2, pci_vid_CA01 },
{0xCA02, 2, pci_vid_CA02 },
{0xCA3B, 1, pci_vid_CA3B },
{0xCA50, 1, pci_vid_CA50 },
{0xCACE, 4, pci_vid_CACE },
{0xCAED, 1, pci_vid_CAED },
{0xCAFE, 5, pci_vid_CAFE },
{0xCC53, 3, pci_vid_CC53 },
{0xCCCC, 1, pci_vid_CCCC },
{0xCCEC, 1, pci_vid_CCEC },
{0xCDDD, 3, pci_vid_CDDD },
{0xCDFA, 2, pci_vid_CDFA },
{0xCEBA, 1, pci_vid_CEBA },
{0xCF86, 2, pci_vid_CF86 },
{0xD063, 3, pci_vid_D063 },
{0xD161, 35, pci_vid_D161 },
{0xD209, 4, pci_vid_D209 },
{0xD20C, 20, pci_vid_D20C },
{0xD4D4, 2, pci_vid_D4D4 },
{0xD531, 1, pci_vid_D531 },
{0xD84D, 1, pci_vid_D84D },
{0xDADA, 16, pci_vid_DADA },
{0xDB10, 1, pci_vid_DB10 },
{0xDC93, 1, pci_vid_DC93 },
{0xDCBA, 8, pci_vid_DCBA },
{0xDD01, 19, pci_vid_DD01 },
{0xDEAD, 1, pci_vid_DEAD },
{0xDEAF, 4, pci_vid_DEAF },
{0xDEDA, 3, pci_vid_DEDA },
{0xE000, 2, pci_vid_E000 },
{0xE159, 9, pci_vid_E159 },
{0xE1C5, 1, pci_vid_E1C5 },
{0xE4BF, 10, pci_vid_E4BF },
{0xE4E4, 1, pci_vid_E4E4 },
{0xE55E, 1, pci_vid_E55E },
{0xEA01, 9, pci_vid_EA01 },
{0xEA50, 1, pci_vid_EA50 },
{0xEA60, 4, pci_vid_EA60 },
{0xEABB, 1, pci_vid_EABB },
{0xEACE, 58, pci_vid_EACE },
{0xEC80, 2, pci_vid_EC80 },
{0xECC0, 1, pci_vid_ECC0 },
{0xEDD8, 5, pci_vid_EDD8 },
{0xF043, 1, pci_vid_F043 },
{0xF05B, 1, pci_vid_F05B },
{0xF111, 1, pci_vid_F111 },
{0xF117, 5, pci_vid_F117 },
{0xF15E, 2, pci_vid_F15E },
{0xF1D0, 41, pci_vid_F1D0 },
{0xF5F5, 1, pci_vid_F5F5 },
{0xF849, 1, pci_vid_F849 },
{0xFA57, 2, pci_vid_FA57 },
{0xFAB7, 1, pci_vid_FAB7 },
{0xFE19, 2, pci_vid_FE19 },
{0xFEBD, 1, pci_vid_FEBD },
{0xFEDA, 3, pci_vid_FEDA },
{0xFEDE, 2, pci_vid_FEDE },
{0xFFE1, 2, pci_vid_FFE1 },
{0xFFFD, 2, pci_vid_FFFD },
{0xFFFE, 2, pci_vid_FFFE },
{0xFFFF, 1, pci_vid_FFFF },
}; /* We have 2388 VIDs */

static int vid_search(const void *key, const void *tbl_entry)
{
    return (int)*(const uint16_t *)key -
           (int)((const pci_vid_index_t *)tbl_entry)->vid;
}

const char *pci_id_str(uint16_t vid, uint16_t did, uint16_t svid, uint16_t ssid)
{
    unsigned int i;
    static const char *not_found = "Not found";
    pci_vid_index_t const *index_ptr;
    pci_id_t const *ids_ptr;

    index_ptr = bsearch(&vid, pci_vid_index, array_length(pci_vid_index), sizeof pci_vid_index[0], vid_search);

    if(index_ptr == NULL)
        return not_found;

    ids_ptr = index_ptr->ids_ptr;
    for(i = 0; i < index_ptr->count; ids_ptr++, i++)
        if(vid == ids_ptr->vid &&
           did == ids_ptr->did &&
           svid == ids_ptr->svid &&
           ssid == ids_ptr->ssid)
           return ids_ptr->name;
    return  not_found;

}
